/*!
 * jQuery JavaScript Library v2.1.4
 * http://jquery.com/
 *
 * Includes Sizzle.js
 * http://sizzlejs.com/
 *
 * Copyright 2005, 2014 jQuery Foundation, Inc. and other contributors
 * Released under the MIT license
 * http://jquery.org/license
 *
 * Date: 2015-04-28T16:01Z
 */

(function( global, factory ) {

	if ( typeof module === "object" && typeof module.exports === "object" ) {
		// For CommonJS and CommonJS-like environments where a proper `window`
		// is present, execute the factory and get jQuery.
		// For environments that do not have a `window` with a `document`
		// (such as Node.js), expose a factory as module.exports.
		// This accentuates the need for the creation of a real `window`.
		// e.g. var jQuery = require("jquery")(window);
		// See ticket #14549 for more info.
		module.exports = global.document ?
			factory( global, true ) :
			function( w ) {
				if ( !w.document ) {
					throw new Error( "jQuery requires a window with a document" );
				}
				return factory( w );
			};
	} else {
		factory( global );
	}

// Pass this if window is not defined yet
}(typeof window !== "undefined" ? window : this, function( window, noGlobal ) {

// Support: Firefox 18+
// Can't be in strict mode, several libs including ASP.NET trace
// the stack via arguments.caller.callee and Firefox dies if
// you try to trace through "use strict" call chains. (#13335)
//

var arr = [];

var slice = arr.slice;

var concat = arr.concat;

var push = arr.push;

var indexOf = arr.indexOf;

var class2type = {};

var toString = class2type.toString;

var hasOwn = class2type.hasOwnProperty;

var support = {};



var
	// Use the correct document accordingly with window argument (sandbox)
	document = window.document,

	version = "2.1.4",

	// Define a local copy of jQuery
	jQuery = function( selector, context ) {
		// The jQuery object is actually just the init constructor 'enhanced'
		// Need init if jQuery is called (just allow error to be thrown if not included)
		return new jQuery.fn.init( selector, context );
	},

	// Support: Android<4.1
	// Make sure we trim BOM and NBSP
	rtrim = /^[\s\uFEFF\xA0]+|[\s\uFEFF\xA0]+$/g,

	// Matches dashed string for camelizing
	rmsPrefix = /^-ms-/,
	rdashAlpha = /-([\da-z])/gi,

	// Used by jQuery.camelCase as callback to replace()
	fcamelCase = function( all, letter ) {
		return letter.toUpperCase();
	};

jQuery.fn = jQuery.prototype = {
	// The current version of jQuery being used
	jquery: version,

	constructor: jQuery,

	// Start with an empty selector
	selector: "",

	// The default length of a jQuery object is 0
	length: 0,

	toArray: function() {
		return slice.call( this );
	},

	// Get the Nth element in the matched element set OR
	// Get the whole matched element set as a clean array
	get: function( num ) {
		return num != null ?

			// Return just the one element from the set
			( num < 0 ? this[ num + this.length ] : this[ num ] ) :

			// Return all the elements in a clean array
			slice.call( this );
	},

	// Take an array of elements and push it onto the stack
	// (returning the new matched element set)
	pushStack: function( elems ) {

		// Build a new jQuery matched element set
		var ret = jQuery.merge( this.constructor(), elems );

		// Add the old object onto the stack (as a reference)
		ret.prevObject = this;
		ret.context = this.context;

		// Return the newly-formed element set
		return ret;
	},

	// Execute a callback for every element in the matched set.
	// (You can seed the arguments with an array of args, but this is
	// only used internally.)
	each: function( callback, args ) {
		return jQuery.each( this, callback, args );
	},

	map: function( callback ) {
		return this.pushStack( jQuery.map(this, function( elem, i ) {
			return callback.call( elem, i, elem );
		}));
	},

	slice: function() {
		return this.pushStack( slice.apply( this, arguments ) );
	},

	first: function() {
		return this.eq( 0 );
	},

	last: function() {
		return this.eq( -1 );
	},

	eq: function( i ) {
		var len = this.length,
			j = +i + ( i < 0 ? len : 0 );
		return this.pushStack( j >= 0 && j < len ? [ this[j] ] : [] );
	},

	end: function() {
		return this.prevObject || this.constructor(null);
	},

	// For internal use only.
	// Behaves like an Array's method, not like a jQuery method.
	push: push,
	sort: arr.sort,
	splice: arr.splice
};

jQuery.extend = jQuery.fn.extend = function() {
	var options, name, src, copy, copyIsArray, clone,
		target = arguments[0] || {},
		i = 1,
		length = arguments.length,
		deep = false;

	// Handle a deep copy situation
	if ( typeof target === "boolean" ) {
		deep = target;

		// Skip the boolean and the target
		target = arguments[ i ] || {};
		i++;
	}

	// Handle case when target is a string or something (possible in deep copy)
	if ( typeof target !== "object" && !jQuery.isFunction(target) ) {
		target = {};
	}

	// Extend jQuery itself if only one argument is passed
	if ( i === length ) {
		target = this;
		i--;
	}

	for ( ; i < length; i++ ) {
		// Only deal with non-null/undefined values
		if ( (options = arguments[ i ]) != null ) {
			// Extend the base object
			for ( name in options ) {
				src = target[ name ];
				copy = options[ name ];

				// Prevent never-ending loop
				if ( target === copy ) {
					continue;
				}

				// Recurse if we're merging plain objects or arrays
				if ( deep && copy && ( jQuery.isPlainObject(copy) || (copyIsArray = jQuery.isArray(copy)) ) ) {
					if ( copyIsArray ) {
						copyIsArray = false;
						clone = src && jQuery.isArray(src) ? src : [];

					} else {
						clone = src && jQuery.isPlainObject(src) ? src : {};
					}

					// Never move original objects, clone them
					target[ name ] = jQuery.extend( deep, clone, copy );

				// Don't bring in undefined values
				} else if ( copy !== undefined ) {
					target[ name ] = copy;
				}
			}
		}
	}

	// Return the modified object
	return target;
};

jQuery.extend({
	// Unique for each copy of jQuery on the page
	expando: "jQuery" + ( version + Math.random() ).replace( /\D/g, "" ),

	// Assume jQuery is ready without the ready module
	isReady: true,

	error: function( msg ) {
		throw new Error( msg );
	},

	noop: function() {},

	isFunction: function( obj ) {
		return jQuery.type(obj) === "function";
	},

	isArray: Array.isArray,

	isWindow: function( obj ) {
		return obj != null && obj === obj.window;
	},

	isNumeric: function( obj ) {
		// parseFloat NaNs numeric-cast false positives (null|true|false|"")
		// ...but misinterprets leading-number strings, particularly hex literals ("0x...")
		// subtraction forces infinities to NaN
		// adding 1 corrects loss of precision from parseFloat (#15100)
		return !jQuery.isArray( obj ) && (obj - parseFloat( obj ) + 1) >= 0;
	},

	isPlainObject: function( obj ) {
		// Not plain objects:
		// - Any object or value whose internal [[Class]] property is not "[object Object]"
		// - DOM nodes
		// - window
		if ( jQuery.type( obj ) !== "object" || obj.nodeType || jQuery.isWindow( obj ) ) {
			return false;
		}

		if ( obj.constructor &&
				!hasOwn.call( obj.constructor.prototype, "isPrototypeOf" ) ) {
			return false;
		}

		// If the function hasn't returned already, we're confident that
		// |obj| is a plain object, created by {} or constructed with new Object
		return true;
	},

	isEmptyObject: function( obj ) {
		var name;
		for ( name in obj ) {
			return false;
		}
		return true;
	},

	type: function( obj ) {
		if ( obj == null ) {
			return obj + "";
		}
		// Support: Android<4.0, iOS<6 (functionish RegExp)
		return typeof obj === "object" || typeof obj === "function" ?
			class2type[ toString.call(obj) ] || "object" :
			typeof obj;
	},

	// Evaluates a script in a global context
	globalEval: function( code ) {
		var script,
			indirect = eval;

		code = jQuery.trim( code );

		if ( code ) {
			// If the code includes a valid, prologue position
			// strict mode pragma, execute code by injecting a
			// script tag into the document.
			if ( code.indexOf("use strict") === 1 ) {
				script = document.createElement("script");
				script.text = code;
				document.head.appendChild( script ).parentNode.removeChild( script );
			} else {
			// Otherwise, avoid the DOM node creation, insertion
			// and removal by using an indirect global eval
				indirect( code );
			}
		}
	},

	// Convert dashed to camelCase; used by the css and data modules
	// Support: IE9-11+
	// Microsoft forgot to hump their vendor prefix (#9572)
	camelCase: function( string ) {
		return string.replace( rmsPrefix, "ms-" ).replace( rdashAlpha, fcamelCase );
	},

	nodeName: function( elem, name ) {
		return elem.nodeName && elem.nodeName.toLowerCase() === name.toLowerCase();
	},

	// args is for internal usage only
	each: function( obj, callback, args ) {
		var value,
			i = 0,
			length = obj.length,
			isArray = isArraylike( obj );

		if ( args ) {
			if ( isArray ) {
				for ( ; i < length; i++ ) {
					value = callback.apply( obj[ i ], args );

					if ( value === false ) {
						break;
					}
				}
			} else {
				for ( i in obj ) {
					value = callback.apply( obj[ i ], args );

					if ( value === false ) {
						break;
					}
				}
			}

		// A special, fast, case for the most common use of each
		} else {
			if ( isArray ) {
				for ( ; i < length; i++ ) {
					value = callback.call( obj[ i ], i, obj[ i ] );

					if ( value === false ) {
						break;
					}
				}
			} else {
				for ( i in obj ) {
					value = callback.call( obj[ i ], i, obj[ i ] );

					if ( value === false ) {
						break;
					}
				}
			}
		}

		return obj;
	},

	// Support: Android<4.1
	trim: function( text ) {
		return text == null ?
			"" :
			( text + "" ).replace( rtrim, "" );
	},

	// results is for internal usage only
	makeArray: function( arr, results ) {
		var ret = results || [];

		if ( arr != null ) {
			if ( isArraylike( Object(arr) ) ) {
				jQuery.merge( ret,
					typeof arr === "string" ?
					[ arr ] : arr
				);
			} else {
				push.call( ret, arr );
			}
		}

		return ret;
	},

	inArray: function( elem, arr, i ) {
		return arr == null ? -1 : indexOf.call( arr, elem, i );
	},

	merge: function( first, second ) {
		var len = +second.length,
			j = 0,
			i = first.length;

		for ( ; j < len; j++ ) {
			first[ i++ ] = second[ j ];
		}

		first.length = i;

		return first;
	},

	grep: function( elems, callback, invert ) {
		var callbackInverse,
			matches = [],
			i = 0,
			length = elems.length,
			callbackExpect = !invert;

		// Go through the array, only saving the items
		// that pass the validator function
		for ( ; i < length; i++ ) {
			callbackInverse = !callback( elems[ i ], i );
			if ( callbackInverse !== callbackExpect ) {
				matches.push( elems[ i ] );
			}
		}

		return matches;
	},

	// arg is for internal usage only
	map: function( elems, callback, arg ) {
		var value,
			i = 0,
			length = elems.length,
			isArray = isArraylike( elems ),
			ret = [];

		// Go through the array, translating each of the items to their new values
		if ( isArray ) {
			for ( ; i < length; i++ ) {
				value = callback( elems[ i ], i, arg );

				if ( value != null ) {
					ret.push( value );
				}
			}

		// Go through every key on the object,
		} else {
			for ( i in elems ) {
				value = callback( elems[ i ], i, arg );

				if ( value != null ) {
					ret.push( value );
				}
			}
		}

		// Flatten any nested arrays
		return concat.apply( [], ret );
	},

	// A global GUID counter for objects
	guid: 1,

	// Bind a function to a context, optionally partially applying any
	// arguments.
	proxy: function( fn, context ) {
		var tmp, args, proxy;

		if ( typeof context === "string" ) {
			tmp = fn[ context ];
			context = fn;
			fn = tmp;
		}

		// Quick check to determine if target is callable, in the spec
		// this throws a TypeError, but we will just return undefined.
		if ( !jQuery.isFunction( fn ) ) {
			return undefined;
		}

		// Simulated bind
		args = slice.call( arguments, 2 );
		proxy = function() {
			return fn.apply( context || this, args.concat( slice.call( arguments ) ) );
		};

		// Set the guid of unique handler to the same of original handler, so it can be removed
		proxy.guid = fn.guid = fn.guid || jQuery.guid++;

		return proxy;
	},

	now: Date.now,

	// jQuery.support is not used in Core but other projects attach their
	// properties to it so it needs to exist.
	support: support
});

// Populate the class2type map
jQuery.each("Boolean Number String Function Array Date RegExp Object Error".split(" "), function(i, name) {
	class2type[ "[object " + name + "]" ] = name.toLowerCase();
});

function isArraylike( obj ) {

	// Support: iOS 8.2 (not reproducible in simulator)
	// `in` check used to prevent JIT error (gh-2145)
	// hasOwn isn't used here due to false negatives
	// regarding Nodelist length in IE
	var length = "length" in obj && obj.length,
		type = jQuery.type( obj );

	if ( type === "function" || jQuery.isWindow( obj ) ) {
		return false;
	}

	if ( obj.nodeType === 1 && length ) {
		return true;
	}

	return type === "array" || length === 0 ||
		typeof length === "number" && length > 0 && ( length - 1 ) in obj;
}
var Sizzle =
/*!
 * Sizzle CSS Selector Engine v2.2.0-pre
 * http://sizzlejs.com/
 *
 * Copyright 2008, 2014 jQuery Foundation, Inc. and other contributors
 * Released under the MIT license
 * http://jquery.org/license
 *
 * Date: 2014-12-16
 */
(function( window ) {

var i,
	support,
	Expr,
	getText,
	isXML,
	tokenize,
	compile,
	select,
	outermostContext,
	sortInput,
	hasDuplicate,

	// Local document vars
	setDocument,
	document,
	docElem,
	documentIsHTML,
	rbuggyQSA,
	rbuggyMatches,
	matches,
	contains,

	// Instance-specific data
	expando = "sizzle" + 1 * new Date(),
	preferredDoc = window.document,
	dirruns = 0,
	done = 0,
	classCache = createCache(),
	tokenCache = createCache(),
	compilerCache = createCache(),
	sortOrder = function( a, b ) {
		if ( a === b ) {
			hasDuplicate = true;
		}
		return 0;
	},

	// General-purpose constants
	MAX_NEGATIVE = 1 << 31,

	// Instance methods
	hasOwn = ({}).hasOwnProperty,
	arr = [],
	pop = arr.pop,
	push_native = arr.push,
	push = arr.push,
	slice = arr.slice,
	// Use a stripped-down indexOf as it's faster than native
	// http://jsperf.com/thor-indexof-vs-for/5
	indexOf = function( list, elem ) {
		var i = 0,
			len = list.length;
		for ( ; i < len; i++ ) {
			if ( list[i] === elem ) {
				return i;
			}
		}
		return -1;
	},

	booleans = "checked|selected|async|autofocus|autoplay|controls|defer|disabled|hidden|ismap|loop|multiple|open|readonly|required|scoped",

	// Regular expressions

	// Whitespace characters http://www.w3.org/TR/css3-selectors/#whitespace
	whitespace = "[\\x20\\t\\r\\n\\f]",
	// http://www.w3.org/TR/css3-syntax/#characters
	characterEncoding = "(?:\\\\.|[\\w-]|[^\\x00-\\xa0])+",

	// Loosely modeled on CSS identifier characters
	// An unquoted value should be a CSS identifier http://www.w3.org/TR/css3-selectors/#attribute-selectors
	// Proper syntax: http://www.w3.org/TR/CSS21/syndata.html#value-def-identifier
	identifier = characterEncoding.replace( "w", "w#" ),

	// Attribute selectors: http://www.w3.org/TR/selectors/#attribute-selectors
	attributes = "\\[" + whitespace + "*(" + characterEncoding + ")(?:" + whitespace +
		// Operator (capture 2)
		"*([*^$|!~]?=)" + whitespace +
		// "Attribute values must be CSS identifiers [capture 5] or strings [capture 3 or capture 4]"
		"*(?:'((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\"|(" + identifier + "))|)" + whitespace +
		"*\\]",

	pseudos = ":(" + characterEncoding + ")(?:\\((" +
		// To reduce the number of selectors needing tokenize in the preFilter, prefer arguments:
		// 1. quoted (capture 3; capture 4 or capture 5)
		"('((?:\\\\.|[^\\\\'])*)'|\"((?:\\\\.|[^\\\\\"])*)\")|" +
		// 2. simple (capture 6)
		"((?:\\\\.|[^\\\\()[\\]]|" + attributes + ")*)|" +
		// 3. anything else (capture 2)
		".*" +
		")\\)|)",

	// Leading and non-escaped trailing whitespace, capturing some non-whitespace characters preceding the latter
	rwhitespace = new RegExp( whitespace + "+", "g" ),
	rtrim = new RegExp( "^" + whitespace + "+|((?:^|[^\\\\])(?:\\\\.)*)" + whitespace + "+$", "g" ),

	rcomma = new RegExp( "^" + whitespace + "*," + whitespace + "*" ),
	rcombinators = new RegExp( "^" + whitespace + "*([>+~]|" + whitespace + ")" + whitespace + "*" ),

	rattributeQuotes = new RegExp( "=" + whitespace + "*([^\\]'\"]*?)" + whitespace + "*\\]", "g" ),

	rpseudo = new RegExp( pseudos ),
	ridentifier = new RegExp( "^" + identifier + "$" ),

	matchExpr = {
		"ID": new RegExp( "^#(" + characterEncoding + ")" ),
		"CLASS": new RegExp( "^\\.(" + characterEncoding + ")" ),
		"TAG": new RegExp( "^(" + characterEncoding.replace( "w", "w*" ) + ")" ),
		"ATTR": new RegExp( "^" + attributes ),
		"PSEUDO": new RegExp( "^" + pseudos ),
		"CHILD": new RegExp( "^:(only|first|last|nth|nth-last)-(child|of-type)(?:\\(" + whitespace +
			"*(even|odd|(([+-]|)(\\d*)n|)" + whitespace + "*(?:([+-]|)" + whitespace +
			"*(\\d+)|))" + whitespace + "*\\)|)", "i" ),
		"bool": new RegExp( "^(?:" + booleans + ")$", "i" ),
		// For use in libraries implementing .is()
		// We use this for POS matching in `select`
		"needsContext": new RegExp( "^" + whitespace + "*[>+~]|:(even|odd|eq|gt|lt|nth|first|last)(?:\\(" +
			whitespace + "*((?:-\\d)?\\d*)" + whitespace + "*\\)|)(?=[^-]|$)", "i" )
	},

	rinputs = /^(?:input|select|textarea|button)$/i,
	rheader = /^h\d$/i,

	rnative = /^[^{]+\{\s*\[native \w/,

	// Easily-parseable/retrievable ID or TAG or CLASS selectors
	rquickExpr = /^(?:#([\w-]+)|(\w+)|\.([\w-]+))$/,

	rsibling = /[+~]/,
	rescape = /'|\\/g,

	// CSS escapes http://www.w3.org/TR/CSS21/syndata.html#escaped-characters
	runescape = new RegExp( "\\\\([\\da-f]{1,6}" + whitespace + "?|(" + whitespace + ")|.)", "ig" ),
	funescape = function( _, escaped, escapedWhitespace ) {
		var high = "0x" + escaped - 0x10000;
		// NaN means non-codepoint
		// Support: Firefox<24
		// Workaround erroneous numeric interpretation of +"0x"
		return high !== high || escapedWhitespace ?
			escaped :
			high < 0 ?
				// BMP codepoint
				String.fromCharCode( high + 0x10000 ) :
				// Supplemental Plane codepoint (surrogate pair)
				String.fromCharCode( high >> 10 | 0xD800, high & 0x3FF | 0xDC00 );
	},

	// Used for iframes
	// See setDocument()
	// Removing the function wrapper causes a "Permission Denied"
	// error in IE
	unloadHandler = function() {
		setDocument();
	};

// Optimize for push.apply( _, NodeList )
try {
	push.apply(
		(arr = slice.call( preferredDoc.childNodes )),
		preferredDoc.childNodes
	);
	// Support: Android<4.0
	// Detect silently failing push.apply
	arr[ preferredDoc.childNodes.length ].nodeType;
} catch ( e ) {
	push = { apply: arr.length ?

		// Leverage slice if possible
		function( target, els ) {
			push_native.apply( target, slice.call(els) );
		} :

		// Support: IE<9
		// Otherwise append directly
		function( target, els ) {
			var j = target.length,
				i = 0;
			// Can't trust NodeList.length
			while ( (target[j++] = els[i++]) ) {}
			target.length = j - 1;
		}
	};
}

function Sizzle( selector, context, results, seed ) {
	var match, elem, m, nodeType,
		// QSA vars
		i, groups, old, nid, newContext, newSelector;

	if ( ( context ? context.ownerDocument || context : preferredDoc ) !== document ) {
		setDocument( context );
	}

	context = context || document;
	results = results || [];
	nodeType = context.nodeType;

	if ( typeof selector !== "string" || !selector ||
		nodeType !== 1 && nodeType !== 9 && nodeType !== 11 ) {

		return results;
	}

	if ( !seed && documentIsHTML ) {

		// Try to shortcut find operations when possible (e.g., not under DocumentFragment)
		if ( nodeType !== 11 && (match = rquickExpr.exec( selector )) ) {
			// Speed-up: Sizzle("#ID")
			if ( (m = match[1]) ) {
				if ( nodeType === 9 ) {
					elem = context.getElementById( m );
					// Check parentNode to catch when Blackberry 4.6 returns
					// nodes that are no longer in the document (jQuery #6963)
					if ( elem && elem.parentNode ) {
						// Handle the case where IE, Opera, and Webkit return items
						// by name instead of ID
						if ( elem.id === m ) {
							results.push( elem );
							return results;
						}
					} else {
						return results;
					}
				} else {
					// Context is not a document
					if ( context.ownerDocument && (elem = context.ownerDocument.getElementById( m )) &&
						contains( context, elem ) && elem.id === m ) {
						results.push( elem );
						return results;
					}
				}

			// Speed-up: Sizzle("TAG")
			} else if ( match[2] ) {
				push.apply( results, context.getElementsByTagName( selector ) );
				return results;

			// Speed-up: Sizzle(".CLASS")
			} else if ( (m = match[3]) && support.getElementsByClassName ) {
				push.apply( results, context.getElementsByClassName( m ) );
				return results;
			}
		}

		// QSA path
		if ( support.qsa && (!rbuggyQSA || !rbuggyQSA.test( selector )) ) {
			nid = old = expando;
			newContext = context;
			newSelector = nodeType !== 1 && selector;

			// qSA works strangely on Element-rooted queries
			// We can work around this by specifying an extra ID on the root
			// and working up from there (Thanks to Andrew Dupont for the technique)
			// IE 8 doesn't work on object elements
			if ( nodeType === 1 && context.nodeName.toLowerCase() !== "object" ) {
				groups = tokenize( selector );

				if ( (old = context.getAttribute("id")) ) {
					nid = old.replace( rescape, "\\$&" );
				} else {
					context.setAttribute( "id", nid );
				}
				nid = "[id='" + nid + "'] ";

				i = groups.length;
				while ( i-- ) {
					groups[i] = nid + toSelector( groups[i] );
				}
				newContext = rsibling.test( selector ) && testContext( context.parentNode ) || context;
				newSelector = groups.join(",");
			}

			if ( newSelector ) {
				try {
					push.apply( results,
						newContext.querySelectorAll( newSelector )
					);
					return results;
				} catch(qsaError) {
				} finally {
					if ( !old ) {
						context.removeAttribute("id");
					}
				}
			}
		}
	}

	// All others
	return select( selector.replace( rtrim, "$1" ), context, results, seed );
}

/**
 * Create key-value caches of limited size
 * @returns {Function(string, Object)} Returns the Object data after storing it on itself with
 *	property name the (space-suffixed) string and (if the cache is larger than Expr.cacheLength)
 *	deleting the oldest entry
 */
function createCache() {
	var keys = [];

	function cache( key, value ) {
		// Use (key + " ") to avoid collision with native prototype properties (see Issue #157)
		if ( keys.push( key + " " ) > Expr.cacheLength ) {
			// Only keep the most recent entries
			delete cache[ keys.shift() ];
		}
		return (cache[ key + " " ] = value);
	}
	return cache;
}

/**
 * Mark a function for special use by Sizzle
 * @param {Function} fn The function to mark
 */
function markFunction( fn ) {
	fn[ expando ] = true;
	return fn;
}

/**
 * Support testing using an element
 * @param {Function} fn Passed the created div and expects a boolean result
 */
function assert( fn ) {
	var div = document.createElement("div");

	try {
		return !!fn( div );
	} catch (e) {
		return false;
	} finally {
		// Remove from its parent by default
		if ( div.parentNode ) {
			div.parentNode.removeChild( div );
		}
		// release memory in IE
		div = null;
	}
}

/**
 * Adds the same handler for all of the specified attrs
 * @param {String} attrs Pipe-separated list of attributes
 * @param {Function} handler The method that will be applied
 */
function addHandle( attrs, handler ) {
	var arr = attrs.split("|"),
		i = attrs.length;

	while ( i-- ) {
		Expr.attrHandle[ arr[i] ] = handler;
	}
}

/**
 * Checks document order of two siblings
 * @param {Element} a
 * @param {Element} b
 * @returns {Number} Returns less than 0 if a precedes b, greater than 0 if a follows b
 */
function siblingCheck( a, b ) {
	var cur = b && a,
		diff = cur && a.nodeType === 1 && b.nodeType === 1 &&
			( ~b.sourceIndex || MAX_NEGATIVE ) -
			( ~a.sourceIndex || MAX_NEGATIVE );

	// Use IE sourceIndex if available on both nodes
	if ( diff ) {
		return diff;
	}

	// Check if b follows a
	if ( cur ) {
		while ( (cur = cur.nextSibling) ) {
			if ( cur === b ) {
				return -1;
			}
		}
	}

	return a ? 1 : -1;
}

/**
 * Returns a function to use in pseudos for input types
 * @param {String} type
 */
function createInputPseudo( type ) {
	return function( elem ) {
		var name = elem.nodeName.toLowerCase();
		return name === "input" && elem.type === type;
	};
}

/**
 * Returns a function to use in pseudos for buttons
 * @param {String} type
 */
function createButtonPseudo( type ) {
	return function( elem ) {
		var name = elem.nodeName.toLowerCase();
		return (name === "input" || name === "button") && elem.type === type;
	};
}

/**
 * Returns a function to use in pseudos for positionals
 * @param {Function} fn
 */
function createPositionalPseudo( fn ) {
	return markFunction(function( argument ) {
		argument = +argument;
		return markFunction(function( seed, matches ) {
			var j,
				matchIndexes = fn( [], seed.length, argument ),
				i = matchIndexes.length;

			// Match elements found at the specified indexes
			while ( i-- ) {
				if ( seed[ (j = matchIndexes[i]) ] ) {
					seed[j] = !(matches[j] = seed[j]);
				}
			}
		});
	});
}

/**
 * Checks a node for validity as a Sizzle context
 * @param {Element|Object=} context
 * @returns {Element|Object|Boolean} The input node if acceptable, otherwise a falsy value
 */
function testContext( context ) {
	return context && typeof context.getElementsByTagName !== "undefined" && context;
}

// Expose support vars for convenience
support = Sizzle.support = {};

/**
 * Detects XML nodes
 * @param {Element|Object} elem An element or a document
 * @returns {Boolean} True iff elem is a non-HTML XML node
 */
isXML = Sizzle.isXML = function( elem ) {
	// documentElement is verified for cases where it doesn't yet exist
	// (such as loading iframes in IE - #4833)
	var documentElement = elem && (elem.ownerDocument || elem).documentElement;
	return documentElement ? documentElement.nodeName !== "HTML" : false;
};

/**
 * Sets document-related variables once based on the current document
 * @param {Element|Object} [doc] An element or document object to use to set the document
 * @returns {Object} Returns the current document
 */
setDocument = Sizzle.setDocument = function( node ) {
	var hasCompare, parent,
		doc = node ? node.ownerDocument || node : preferredDoc;

	// If no document and documentElement is available, return
	if ( doc === document || doc.nodeType !== 9 || !doc.documentElement ) {
		return document;
	}

	// Set our document
	document = doc;
	docElem = doc.documentElement;
	parent = doc.defaultView;

	// Support: IE>8
	// If iframe document is assigned to "document" variable and if iframe has been reloaded,
	// IE will throw "permission denied" error when accessing "document" variable, see jQuery #13936
	// IE6-8 do not support the defaultView property so parent will be undefined
	if ( parent && parent !== parent.top ) {
		// IE11 does not have attachEvent, so all must suffer
		if ( parent.addEventListener ) {
			parent.addEventListener( "unload", unloadHandler, false );
		} else if ( parent.attachEvent ) {
			parent.attachEvent( "onunload", unloadHandler );
		}
	}

	/* Support tests
	---------------------------------------------------------------------- */
	documentIsHTML = !isXML( doc );

	/* Attributes
	---------------------------------------------------------------------- */

	// Support: IE<8
	// Verify that getAttribute really returns attributes and not properties
	// (excepting IE8 booleans)
	support.attributes = assert(function( div ) {
		div.className = "i";
		return !div.getAttribute("className");
	});

	/* getElement(s)By*
	---------------------------------------------------------------------- */

	// Check if getElementsByTagName("*") returns only elements
	support.getElementsByTagName = assert(function( div ) {
		div.appendChild( doc.createComment("") );
		return !div.getElementsByTagName("*").length;
	});

	// Support: IE<9
	support.getElementsByClassName = rnative.test( doc.getElementsByClassName );

	// Support: IE<10
	// Check if getElementById returns elements by name
	// The broken getElementById methods don't pick up programatically-set names,
	// so use a roundabout getElementsByName test
	support.getById = assert(function( div ) {
		docElem.appendChild( div ).id = expando;
		return !doc.getElementsByName || !doc.getElementsByName( expando ).length;
	});

	// ID find and filter
	if ( support.getById ) {
		Expr.find["ID"] = function( id, context ) {
			if ( typeof context.getElementById !== "undefined" && documentIsHTML ) {
				var m = context.getElementById( id );
				// Check parentNode to catch when Blackberry 4.6 returns
				// nodes that are no longer in the document #6963
				return m && m.parentNode ? [ m ] : [];
			}
		};
		Expr.filter["ID"] = function( id ) {
			var attrId = id.replace( runescape, funescape );
			return function( elem ) {
				return elem.getAttribute("id") === attrId;
			};
		};
	} else {
		// Support: IE6/7
		// getElementById is not reliable as a find shortcut
		delete Expr.find["ID"];

		Expr.filter["ID"] =  function( id ) {
			var attrId = id.replace( runescape, funescape );
			return function( elem ) {
				var node = typeof elem.getAttributeNode !== "undefined" && elem.getAttributeNode("id");
				return node && node.value === attrId;
			};
		};
	}

	// Tag
	Expr.find["TAG"] = support.getElementsByTagName ?
		function( tag, context ) {
			if ( typeof context.getElementsByTagName !== "undefined" ) {
				return context.getElementsByTagName( tag );

			// DocumentFragment nodes don't have gEBTN
			} else if ( support.qsa ) {
				return context.querySelectorAll( tag );
			}
		} :

		function( tag, context ) {
			var elem,
				tmp = [],
				i = 0,
				// By happy coincidence, a (broken) gEBTN appears on DocumentFragment nodes too
				results = context.getElementsByTagName( tag );

			// Filter out possible comments
			if ( tag === "*" ) {
				while ( (elem = results[i++]) ) {
					if ( elem.nodeType === 1 ) {
						tmp.push( elem );
					}
				}

				return tmp;
			}
			return results;
		};

	// Class
	Expr.find["CLASS"] = support.getElementsByClassName && function( className, context ) {
		if ( documentIsHTML ) {
			return context.getElementsByClassName( className );
		}
	};

	/* QSA/matchesSelector
	---------------------------------------------------------------------- */

	// QSA and matchesSelector support

	// matchesSelector(:active) reports false when true (IE9/Opera 11.5)
	rbuggyMatches = [];

	// qSa(:focus) reports false when true (Chrome 21)
	// We allow this because of a bug in IE8/9 that throws an error
	// whenever `document.activeElement` is accessed on an iframe
	// So, we allow :focus to pass through QSA all the time to avoid the IE error
	// See http://bugs.jquery.com/ticket/13378
	rbuggyQSA = [];

	if ( (support.qsa = rnative.test( doc.querySelectorAll )) ) {
		// Build QSA regex
		// Regex strategy adopted from Diego Perini
		assert(function( div ) {
			// Select is set to empty string on purpose
			// This is to test IE's treatment of not explicitly
			// setting a boolean content attribute,
			// since its presence should be enough
			// http://bugs.jquery.com/ticket/12359
			docElem.appendChild( div ).innerHTML = "<a id='" + expando + "'></a>" +
				"<select id='" + expando + "-\f]' msallowcapture=''>" +
				"<option selected=''></option></select>";

			// Support: IE8, Opera 11-12.16
			// Nothing should be selected when empty strings follow ^= or $= or *=
			// The test attribute must be unknown in Opera but "safe" for WinRT
			// http://msdn.microsoft.com/en-us/library/ie/hh465388.aspx#attribute_section
			if ( div.querySelectorAll("[msallowcapture^='']").length ) {
				rbuggyQSA.push( "[*^$]=" + whitespace + "*(?:''|\"\")" );
			}

			// Support: IE8
			// Boolean attributes and "value" are not treated correctly
			if ( !div.querySelectorAll("[selected]").length ) {
				rbuggyQSA.push( "\\[" + whitespace + "*(?:value|" + booleans + ")" );
			}

			// Support: Chrome<29, Android<4.2+, Safari<7.0+, iOS<7.0+, PhantomJS<1.9.7+
			if ( !div.querySelectorAll( "[id~=" + expando + "-]" ).length ) {
				rbuggyQSA.push("~=");
			}

			// Webkit/Opera - :checked should return selected option elements
			// http://www.w3.org/TR/2011/REC-css3-selectors-20110929/#checked
			// IE8 throws error here and will not see later tests
			if ( !div.querySelectorAll(":checked").length ) {
				rbuggyQSA.push(":checked");
			}

			// Support: Safari 8+, iOS 8+
			// https://bugs.webkit.org/show_bug.cgi?id=136851
			// In-page `selector#id sibing-combinator selector` fails
			if ( !div.querySelectorAll( "a#" + expando + "+*" ).length ) {
				rbuggyQSA.push(".#.+[+~]");
			}
		});

		assert(function( div ) {
			// Support: Windows 8 Native Apps
			// The type and name attributes are restricted during .innerHTML assignment
			var input = doc.createElement("input");
			input.setAttribute( "type", "hidden" );
			div.appendChild( input ).setAttribute( "name", "D" );

			// Support: IE8
			// Enforce case-sensitivity of name attribute
			if ( div.querySelectorAll("[name=d]").length ) {
				rbuggyQSA.push( "name" + whitespace + "*[*^$|!~]?=" );
			}

			// FF 3.5 - :enabled/:disabled and hidden elements (hidden elements are still enabled)
			// IE8 throws error here and will not see later tests
			if ( !div.querySelectorAll(":enabled").length ) {
				rbuggyQSA.push( ":enabled", ":disabled" );
			}

			// Opera 10-11 does not throw on post-comma invalid pseudos
			div.querySelectorAll("*,:x");
			rbuggyQSA.push(",.*:");
		});
	}

	if ( (support.matchesSelector = rnative.test( (matches = docElem.matches ||
		docElem.webkitMatchesSelector ||
		docElem.mozMatchesSelector ||
		docElem.oMatchesSelector ||
		docElem.msMatchesSelector) )) ) {

		assert(function( div ) {
			// Check to see if it's possible to do matchesSelector
			// on a disconnected node (IE 9)
			support.disconnectedMatch = matches.call( div, "div" );

			// This should fail with an exception
			// Gecko does not error, returns false instead
			matches.call( div, "[s!='']:x" );
			rbuggyMatches.push( "!=", pseudos );
		});
	}

	rbuggyQSA = rbuggyQSA.length && new RegExp( rbuggyQSA.join("|") );
	rbuggyMatches = rbuggyMatches.length && new RegExp( rbuggyMatches.join("|") );

	/* Contains
	---------------------------------------------------------------------- */
	hasCompare = rnative.test( docElem.compareDocumentPosition );

	// Element contains another
	// Purposefully does not implement inclusive descendent
	// As in, an element does not contain itself
	contains = hasCompare || rnative.test( docElem.contains ) ?
		function( a, b ) {
			var adown = a.nodeType === 9 ? a.documentElement : a,
				bup = b && b.parentNode;
			return a === bup || !!( bup && bup.nodeType === 1 && (
				adown.contains ?
					adown.contains( bup ) :
					a.compareDocumentPosition && a.compareDocumentPosition( bup ) & 16
			));
		} :
		function( a, b ) {
			if ( b ) {
				while ( (b = b.parentNode) ) {
					if ( b === a ) {
						return true;
					}
				}
			}
			return false;
		};

	/* Sorting
	---------------------------------------------------------------------- */

	// Document order sorting
	sortOrder = hasCompare ?
	function( a, b ) {

		// Flag for duplicate removal
		if ( a === b ) {
			hasDuplicate = true;
			return 0;
		}

		// Sort on method existence if only one input has compareDocumentPosition
		var compare = !a.compareDocumentPosition - !b.compareDocumentPosition;
		if ( compare ) {
			return compare;
		}

		// Calculate position if both inputs belong to the same document
		compare = ( a.ownerDocument || a ) === ( b.ownerDocument || b ) ?
			a.compareDocumentPosition( b ) :

			// Otherwise we know they are disconnected
			1;

		// Disconnected nodes
		if ( compare & 1 ||
			(!support.sortDetached && b.compareDocumentPosition( a ) === compare) ) {

			// Choose the first element that is related to our preferred document
			if ( a === doc || a.ownerDocument === preferredDoc && contains(preferredDoc, a) ) {
				return -1;
			}
			if ( b === doc || b.ownerDocument === preferredDoc && contains(preferredDoc, b) ) {
				return 1;
			}

			// Maintain original order
			return sortInput ?
				( indexOf( sortInput, a ) - indexOf( sortInput, b ) ) :
				0;
		}

		return compare & 4 ? -1 : 1;
	} :
	function( a, b ) {
		// Exit early if the nodes are identical
		if ( a === b ) {
			hasDuplicate = true;
			return 0;
		}

		var cur,
			i = 0,
			aup = a.parentNode,
			bup = b.parentNode,
			ap = [ a ],
			bp = [ b ];

		// Parentless nodes are either documents or disconnected
		if ( !aup || !bup ) {
			return a === doc ? -1 :
				b === doc ? 1 :
				aup ? -1 :
				bup ? 1 :
				sortInput ?
				( indexOf( sortInput, a ) - indexOf( sortInput, b ) ) :
				0;

		// If the nodes are siblings, we can do a quick check
		} else if ( aup === bup ) {
			return siblingCheck( a, b );
		}

		// Otherwise we need full lists of their ancestors for comparison
		cur = a;
		while ( (cur = cur.parentNode) ) {
			ap.unshift( cur );
		}
		cur = b;
		while ( (cur = cur.parentNode) ) {
			bp.unshift( cur );
		}

		// Walk down the tree looking for a discrepancy
		while ( ap[i] === bp[i] ) {
			i++;
		}

		return i ?
			// Do a sibling check if the nodes have a common ancestor
			siblingCheck( ap[i], bp[i] ) :

			// Otherwise nodes in our document sort first
			ap[i] === preferredDoc ? -1 :
			bp[i] === preferredDoc ? 1 :
			0;
	};

	return doc;
};

Sizzle.matches = function( expr, elements ) {
	return Sizzle( expr, null, null, elements );
};

Sizzle.matchesSelector = function( elem, expr ) {
	// Set document vars if needed
	if ( ( elem.ownerDocument || elem ) !== document ) {
		setDocument( elem );
	}

	// Make sure that attribute selectors are quoted
	expr = expr.replace( rattributeQuotes, "='$1']" );

	if ( support.matchesSelector && documentIsHTML &&
		( !rbuggyMatches || !rbuggyMatches.test( expr ) ) &&
		( !rbuggyQSA     || !rbuggyQSA.test( expr ) ) ) {

		try {
			var ret = matches.call( elem, expr );

			// IE 9's matchesSelector returns false on disconnected nodes
			if ( ret || support.disconnectedMatch ||
					// As well, disconnected nodes are said to be in a document
					// fragment in IE 9
					elem.document && elem.document.nodeType !== 11 ) {
				return ret;
			}
		} catch (e) {}
	}

	return Sizzle( expr, document, null, [ elem ] ).length > 0;
};

Sizzle.contains = function( context, elem ) {
	// Set document vars if needed
	if ( ( context.ownerDocument || context ) !== document ) {
		setDocument( context );
	}
	return contains( context, elem );
};

Sizzle.attr = function( elem, name ) {
	// Set document vars if needed
	if ( ( elem.ownerDocument || elem ) !== document ) {
		setDocument( elem );
	}

	var fn = Expr.attrHandle[ name.toLowerCase() ],
		// Don't get fooled by Object.prototype properties (jQuery #13807)
		val = fn && hasOwn.call( Expr.attrHandle, name.toLowerCase() ) ?
			fn( elem, name, !documentIsHTML ) :
			undefined;

	return val !== undefined ?
		val :
		support.attributes || !documentIsHTML ?
			elem.getAttribute( name ) :
			(val = elem.getAttributeNode(name)) && val.specified ?
				val.value :
				null;
};

Sizzle.error = function( msg ) {
	throw new Error( "Syntax error, unrecognized expression: " + msg );
};

/**
 * Document sorting and removing duplicates
 * @param {ArrayLike} results
 */
Sizzle.uniqueSort = function( results ) {
	var elem,
		duplicates = [],
		j = 0,
		i = 0;

	// Unless we *know* we can detect duplicates, assume their presence
	hasDuplicate = !support.detectDuplicates;
	sortInput = !support.sortStable && results.slice( 0 );
	results.sort( sortOrder );

	if ( hasDuplicate ) {
		while ( (elem = results[i++]) ) {
			if ( elem === results[ i ] ) {
				j = duplicates.push( i );
			}
		}
		while ( j-- ) {
			results.splice( duplicates[ j ], 1 );
		}
	}

	// Clear input after sorting to release objects
	// See https://github.com/jquery/sizzle/pull/225
	sortInput = null;

	return results;
};

/**
 * Utility function for retrieving the text value of an array of DOM nodes
 * @param {Array|Element} elem
 */
getText = Sizzle.getText = function( elem ) {
	var node,
		ret = "",
		i = 0,
		nodeType = elem.nodeType;

	if ( !nodeType ) {
		// If no nodeType, this is expected to be an array
		while ( (node = elem[i++]) ) {
			// Do not traverse comment nodes
			ret += getText( node );
		}
	} else if ( nodeType === 1 || nodeType === 9 || nodeType === 11 ) {
		// Use textContent for elements
		// innerText usage removed for consistency of new lines (jQuery #11153)
		if ( typeof elem.textContent === "string" ) {
			return elem.textContent;
		} else {
			// Traverse its children
			for ( elem = elem.firstChild; elem; elem = elem.nextSibling ) {
				ret += getText( elem );
			}
		}
	} else if ( nodeType === 3 || nodeType === 4 ) {
		return elem.nodeValue;
	}
	// Do not include comment or processing instruction nodes

	return ret;
};

Expr = Sizzle.selectors = {

	// Can be adjusted by the user
	cacheLength: 50,

	createPseudo: markFunction,

	match: matchExpr,

	attrHandle: {},

	find: {},

	relative: {
		">": { dir: "parentNode", first: true },
		" ": { dir: "parentNode" },
		"+": { dir: "previousSibling", first: true },
		"~": { dir: "previousSibling" }
	},

	preFilter: {
		"ATTR": function( match ) {
			match[1] = match[1].replace( runescape, funescape );

			// Move the given value to match[3] whether quoted or unquoted
			match[3] = ( match[3] || match[4] || match[5] || "" ).replace( runescape, funescape );

			if ( match[2] === "~=" ) {
				match[3] = " " + match[3] + " ";
			}

			return match.slice( 0, 4 );
		},

		"CHILD": function( match ) {
			/* matches from matchExpr["CHILD"]
				1 type (only|nth|...)
				2 what (child|of-type)
				3 argument (even|odd|\d*|\d*n([+-]\d+)?|...)
				4 xn-component of xn+y argument ([+-]?\d*n|)
				5 sign of xn-component
				6 x of xn-component
				7 sign of y-component
				8 y of y-component
			*/
			match[1] = match[1].toLowerCase();

			if ( match[1].slice( 0, 3 ) === "nth" ) {
				// nth-* requires argument
				if ( !match[3] ) {
					Sizzle.error( match[0] );
				}

				// numeric x and y parameters for Expr.filter.CHILD
				// remember that false/true cast respectively to 0/1
				match[4] = +( match[4] ? match[5] + (match[6] || 1) : 2 * ( match[3] === "even" || match[3] === "odd" ) );
				match[5] = +( ( match[7] + match[8] ) || match[3] === "odd" );

			// other types prohibit arguments
			} else if ( match[3] ) {
				Sizzle.error( match[0] );
			}

			return match;
		},

		"PSEUDO": function( match ) {
			var excess,
				unquoted = !match[6] && match[2];

			if ( matchExpr["CHILD"].test( match[0] ) ) {
				return null;
			}

			// Accept quoted arguments as-is
			if ( match[3] ) {
				match[2] = match[4] || match[5] || "";

			// Strip excess characters from unquoted arguments
			} else if ( unquoted && rpseudo.test( unquoted ) &&
				// Get excess from tokenize (recursively)
				(excess = tokenize( unquoted, true )) &&
				// advance to the next closing parenthesis
				(excess = unquoted.indexOf( ")", unquoted.length - excess ) - unquoted.length) ) {

				// excess is a negative index
				match[0] = match[0].slice( 0, excess );
				match[2] = unquoted.slice( 0, excess );
			}

			// Return only captures needed by the pseudo filter method (type and argument)
			return match.slice( 0, 3 );
		}
	},

	filter: {

		"TAG": function( nodeNameSelector ) {
			var nodeName = nodeNameSelector.replace( runescape, funescape ).toLowerCase();
			return nodeNameSelector === "*" ?
				function() { return true; } :
				function( elem ) {
					return elem.nodeName && elem.nodeName.toLowerCase() === nodeName;
				};
		},

		"CLASS": function( className ) {
			var pattern = classCache[ className + " " ];

			return pattern ||
				(pattern = new RegExp( "(^|" + whitespace + ")" + className + "(" + whitespace + "|$)" )) &&
				classCache( className, function( elem ) {
					return pattern.test( typeof elem.className === "string" && elem.className || typeof elem.getAttribute !== "undefined" && elem.getAttribute("class") || "" );
				});
		},

		"ATTR": function( name, operator, check ) {
			return function( elem ) {
				var result = Sizzle.attr( elem, name );

				if ( result == null ) {
					return operator === "!=";
				}
				if ( !operator ) {
					return true;
				}

				result += "";

				return operator === "=" ? result === check :
					operator === "!=" ? result !== check :
					operator === "^=" ? check && result.indexOf( check ) === 0 :
					operator === "*=" ? check && result.indexOf( check ) > -1 :
					operator === "$=" ? check && result.slice( -check.length ) === check :
					operator === "~=" ? ( " " + result.replace( rwhitespace, " " ) + " " ).indexOf( check ) > -1 :
					operator === "|=" ? result === check || result.slice( 0, check.length + 1 ) === check + "-" :
					false;
			};
		},

		"CHILD": function( type, what, argument, first, last ) {
			var simple = type.slice( 0, 3 ) !== "nth",
				forward = type.slice( -4 ) !== "last",
				ofType = what === "of-type";

			return first === 1 && last === 0 ?

				// Shortcut for :nth-*(n)
				function( elem ) {
					return !!elem.parentNode;
				} :

				function( elem, context, xml ) {
					var cache, outerCache, node, diff, nodeIndex, start,
						dir = simple !== forward ? "nextSibling" : "previousSibling",
						parent = elem.parentNode,
						name = ofType && elem.nodeName.toLowerCase(),
						useCache = !xml && !ofType;

					if ( parent ) {

						// :(first|last|only)-(child|of-type)
						if ( simple ) {
							while ( dir ) {
								node = elem;
								while ( (node = node[ dir ]) ) {
									if ( ofType ? node.nodeName.toLowerCase() === name : node.nodeType === 1 ) {
										return false;
									}
								}
								// Reverse direction for :only-* (if we haven't yet done so)
								start = dir = type === "only" && !start && "nextSibling";
							}
							return true;
						}

						start = [ forward ? parent.firstChild : parent.lastChild ];

						// non-xml :nth-child(...) stores cache data on `parent`
						if ( forward && useCache ) {
							// Seek `elem` from a previously-cached index
							outerCache = parent[ expando ] || (parent[ expando ] = {});
							cache = outerCache[ type ] || [];
							nodeIndex = cache[0] === dirruns && cache[1];
							diff = cache[0] === dirruns && cache[2];
							node = nodeIndex && parent.childNodes[ nodeIndex ];

							while ( (node = ++nodeIndex && node && node[ dir ] ||

								// Fallback to seeking `elem` from the start
								(diff = nodeIndex = 0) || start.pop()) ) {

								// When found, cache indexes on `parent` and break
								if ( node.nodeType === 1 && ++diff && node === elem ) {
									outerCache[ type ] = [ dirruns, nodeIndex, diff ];
									break;
								}
							}

						// Use previously-cached element index if available
						} else if ( useCache && (cache = (elem[ expando ] || (elem[ expando ] = {}))[ type ]) && cache[0] === dirruns ) {
							diff = cache[1];

						// xml :nth-child(...) or :nth-last-child(...) or :nth(-last)?-of-type(...)
						} else {
							// Use the same loop as above to seek `elem` from the start
							while ( (node = ++nodeIndex && node && node[ dir ] ||
								(diff = nodeIndex = 0) || start.pop()) ) {

								if ( ( ofType ? node.nodeName.toLowerCase() === name : node.nodeType === 1 ) && ++diff ) {
									// Cache the index of each encountered element
									if ( useCache ) {
										(node[ expando ] || (node[ expando ] = {}))[ type ] = [ dirruns, diff ];
									}

									if ( node === elem ) {
										break;
									}
								}
							}
						}

						// Incorporate the offset, then check against cycle size
						diff -= last;
						return diff === first || ( diff % first === 0 && diff / first >= 0 );
					}
				};
		},

		"PSEUDO": function( pseudo, argument ) {
			// pseudo-class names are case-insensitive
			// http://www.w3.org/TR/selectors/#pseudo-classes
			// Prioritize by case sensitivity in case custom pseudos are added with uppercase letters
			// Remember that setFilters inherits from pseudos
			var args,
				fn = Expr.pseudos[ pseudo ] || Expr.setFilters[ pseudo.toLowerCase() ] ||
					Sizzle.error( "unsupported pseudo: " + pseudo );

			// The user may use createPseudo to indicate that
			// arguments are needed to create the filter function
			// just as Sizzle does
			if ( fn[ expando ] ) {
				return fn( argument );
			}

			// But maintain support for old signatures
			if ( fn.length > 1 ) {
				args = [ pseudo, pseudo, "", argument ];
				return Expr.setFilters.hasOwnProperty( pseudo.toLowerCase() ) ?
					markFunction(function( seed, matches ) {
						var idx,
							matched = fn( seed, argument ),
							i = matched.length;
						while ( i-- ) {
							idx = indexOf( seed, matched[i] );
							seed[ idx ] = !( matches[ idx ] = matched[i] );
						}
					}) :
					function( elem ) {
						return fn( elem, 0, args );
					};
			}

			return fn;
		}
	},

	pseudos: {
		// Potentially complex pseudos
		"not": markFunction(function( selector ) {
			// Trim the selector passed to compile
			// to avoid treating leading and trailing
			// spaces as combinators
			var input = [],
				results = [],
				matcher = compile( selector.replace( rtrim, "$1" ) );

			return matcher[ expando ] ?
				markFunction(function( seed, matches, context, xml ) {
					var elem,
						unmatched = matcher( seed, null, xml, [] ),
						i = seed.length;

					// Match elements unmatched by `matcher`
					while ( i-- ) {
						if ( (elem = unmatched[i]) ) {
							seed[i] = !(matches[i] = elem);
						}
					}
				}) :
				function( elem, context, xml ) {
					input[0] = elem;
					matcher( input, null, xml, results );
					// Don't keep the element (issue #299)
					input[0] = null;
					return !results.pop();
				};
		}),

		"has": markFunction(function( selector ) {
			return function( elem ) {
				return Sizzle( selector, elem ).length > 0;
			};
		}),

		"contains": markFunction(function( text ) {
			text = text.replace( runescape, funescape );
			return function( elem ) {
				return ( elem.textContent || elem.innerText || getText( elem ) ).indexOf( text ) > -1;
			};
		}),

		// "Whether an element is represented by a :lang() selector
		// is based solely on the element's language value
		// being equal to the identifier C,
		// or beginning with the identifier C immediately followed by "-".
		// The matching of C against the element's language value is performed case-insensitively.
		// The identifier C does not have to be a valid language name."
		// http://www.w3.org/TR/selectors/#lang-pseudo
		"lang": markFunction( function( lang ) {
			// lang value must be a valid identifier
			if ( !ridentifier.test(lang || "") ) {
				Sizzle.error( "unsupported lang: " + lang );
			}
			lang = lang.replace( runescape, funescape ).toLowerCase();
			return function( elem ) {
				var elemLang;
				do {
					if ( (elemLang = documentIsHTML ?
						elem.lang :
						elem.getAttribute("xml:lang") || elem.getAttribute("lang")) ) {

						elemLang = elemLang.toLowerCase();
						return elemLang === lang || elemLang.indexOf( lang + "-" ) === 0;
					}
				} while ( (elem = elem.parentNode) && elem.nodeType === 1 );
				return false;
			};
		}),

		// Miscellaneous
		"target": function( elem ) {
			var hash = window.location && window.location.hash;
			return hash && hash.slice( 1 ) === elem.id;
		},

		"root": function( elem ) {
			return elem === docElem;
		},

		"focus": function( elem ) {
			return elem === document.activeElement && (!document.hasFocus || document.hasFocus()) && !!(elem.type || elem.href || ~elem.tabIndex);
		},

		// Boolean properties
		"enabled": function( elem ) {
			return elem.disabled === false;
		},

		"disabled": function( elem ) {
			return elem.disabled === true;
		},

		"checked": function( elem ) {
			// In CSS3, :checked should return both checked and selected elements
			// http://www.w3.org/TR/2011/REC-css3-selectors-20110929/#checked
			var nodeName = elem.nodeName.toLowerCase();
			return (nodeName === "input" && !!elem.checked) || (nodeName === "option" && !!elem.selected);
		},

		"selected": function( elem ) {
			// Accessing this property makes selected-by-default
			// options in Safari work properly
			if ( elem.parentNode ) {
				elem.parentNode.selectedIndex;
			}

			return elem.selected === true;
		},

		// Contents
		"empty": function( elem ) {
			// http://www.w3.org/TR/selectors/#empty-pseudo
			// :empty is negated by element (1) or content nodes (text: 3; cdata: 4; entity ref: 5),
			//   but not by others (comment: 8; processing instruction: 7; etc.)
			// nodeType < 6 works because attributes (2) do not appear as children
			for ( elem = elem.firstChild; elem; elem = elem.nextSibling ) {
				if ( elem.nodeType < 6 ) {
					return false;
				}
			}
			return true;
		},

		"parent": function( elem ) {
			return !Expr.pseudos["empty"]( elem );
		},

		// Element/input types
		"header": function( elem ) {
			return rheader.test( elem.nodeName );
		},

		"input": function( elem ) {
			return rinputs.test( elem.nodeName );
		},

		"button": function( elem ) {
			var name = elem.nodeName.toLowerCase();
			return name === "input" && elem.type === "button" || name === "button";
		},

		"text": function( elem ) {
			var attr;
			return elem.nodeName.toLowerCase() === "input" &&
				elem.type === "text" &&

				// Support: IE<8
				// New HTML5 attribute values (e.g., "search") appear with elem.type === "text"
				( (attr = elem.getAttribute("type")) == null || attr.toLowerCase() === "text" );
		},

		// Position-in-collection
		"first": createPositionalPseudo(function() {
			return [ 0 ];
		}),

		"last": createPositionalPseudo(function( matchIndexes, length ) {
			return [ length - 1 ];
		}),

		"eq": createPositionalPseudo(function( matchIndexes, length, argument ) {
			return [ argument < 0 ? argument + length : argument ];
		}),

		"even": createPositionalPseudo(function( matchIndexes, length ) {
			var i = 0;
			for ( ; i < length; i += 2 ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"odd": createPositionalPseudo(function( matchIndexes, length ) {
			var i = 1;
			for ( ; i < length; i += 2 ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"lt": createPositionalPseudo(function( matchIndexes, length, argument ) {
			var i = argument < 0 ? argument + length : argument;
			for ( ; --i >= 0; ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		}),

		"gt": createPositionalPseudo(function( matchIndexes, length, argument ) {
			var i = argument < 0 ? argument + length : argument;
			for ( ; ++i < length; ) {
				matchIndexes.push( i );
			}
			return matchIndexes;
		})
	}
};

Expr.pseudos["nth"] = Expr.pseudos["eq"];

// Add button/input type pseudos
for ( i in { radio: true, checkbox: true, file: true, password: true, image: true } ) {
	Expr.pseudos[ i ] = createInputPseudo( i );
}
for ( i in { submit: true, reset: true } ) {
	Expr.pseudos[ i ] = createButtonPseudo( i );
}

// Easy API for creating new setFilters
function setFilters() {}
setFilters.prototype = Expr.filters = Expr.pseudos;
Expr.setFilters = new setFilters();

tokenize = Sizzle.tokenize = function( selector, parseOnly ) {
	var matched, match, tokens, type,
		soFar, groups, preFilters,
		cached = tokenCache[ selector + " " ];

	if ( cached ) {
		return parseOnly ? 0 : cached.slice( 0 );
	}

	soFar = selector;
	groups = [];
	preFilters = Expr.preFilter;

	while ( soFar ) {

		// Comma and first run
		if ( !matched || (match = rcomma.exec( soFar )) ) {
			if ( match ) {
				// Don't consume trailing commas as valid
				soFar = soFar.slice( match[0].length ) || soFar;
			}
			groups.push( (tokens = []) );
		}

		matched = false;

		// Combinators
		if ( (match = rcombinators.exec( soFar )) ) {
			matched = match.shift();
			tokens.push({
				value: matched,
				// Cast descendant combinators to space
				type: match[0].replace( rtrim, " " )
			});
			soFar = soFar.slice( matched.length );
		}

		// Filters
		for ( type in Expr.filter ) {
			if ( (match = matchExpr[ type ].exec( soFar )) && (!preFilters[ type ] ||
				(match = preFilters[ type ]( match ))) ) {
				matched = match.shift();
				tokens.push({
					value: matched,
					type: type,
					matches: match
				});
				soFar = soFar.slice( matched.length );
			}
		}

		if ( !matched ) {
			break;
		}
	}

	// Return the length of the invalid excess
	// if we're just parsing
	// Otherwise, throw an error or return tokens
	return parseOnly ?
		soFar.length :
		soFar ?
			Sizzle.error( selector ) :
			// Cache the tokens
			tokenCache( selector, groups ).slice( 0 );
};

function toSelector( tokens ) {
	var i = 0,
		len = tokens.length,
		selector = "";
	for ( ; i < len; i++ ) {
		selector += tokens[i].value;
	}
	return selector;
}

function addCombinator( matcher, combinator, base ) {
	var dir = combinator.dir,
		checkNonElements = base && dir === "parentNode",
		doneName = done++;

	return combinator.first ?
		// Check against closest ancestor/preceding element
		function( elem, context, xml ) {
			while ( (elem = elem[ dir ]) ) {
				if ( elem.nodeType === 1 || checkNonElements ) {
					return matcher( elem, context, xml );
				}
			}
		} :

		// Check against all ancestor/preceding elements
		function( elem, context, xml ) {
			var oldCache, outerCache,
				newCache = [ dirruns, doneName ];

			// We can't set arbitrary data on XML nodes, so they don't benefit from dir caching
			if ( xml ) {
				while ( (elem = elem[ dir ]) ) {
					if ( elem.nodeType === 1 || checkNonElements ) {
						if ( matcher( elem, context, xml ) ) {
							return true;
						}
					}
				}
			} else {
				while ( (elem = elem[ dir ]) ) {
					if ( elem.nodeType === 1 || checkNonElements ) {
						outerCache = elem[ expando ] || (elem[ expando ] = {});
						if ( (oldCache = outerCache[ dir ]) &&
							oldCache[ 0 ] === dirruns && oldCache[ 1 ] === doneName ) {

							// Assign to newCache so results back-propagate to previous elements
							return (newCache[ 2 ] = oldCache[ 2 ]);
						} else {
							// Reuse newcache so results back-propagate to previous elements
							outerCache[ dir ] = newCache;

							// A match means we're done; a fail means we have to keep checking
							if ( (newCache[ 2 ] = matcher( elem, context, xml )) ) {
								return true;
							}
						}
					}
				}
			}
		};
}

function elementMatcher( matchers ) {
	return matchers.length > 1 ?
		function( elem, context, xml ) {
			var i = matchers.length;
			while ( i-- ) {
				if ( !matchers[i]( elem, context, xml ) ) {
					return false;
				}
			}
			return true;
		} :
		matchers[0];
}

function multipleContexts( selector, contexts, results ) {
	var i = 0,
		len = contexts.length;
	for ( ; i < len; i++ ) {
		Sizzle( selector, contexts[i], results );
	}
	return results;
}

function condense( unmatched, map, filter, context, xml ) {
	var elem,
		newUnmatched = [],
		i = 0,
		len = unmatched.length,
		mapped = map != null;

	for ( ; i < len; i++ ) {
		if ( (elem = unmatched[i]) ) {
			if ( !filter || filter( elem, context, xml ) ) {
				newUnmatched.push( elem );
				if ( mapped ) {
					map.push( i );
				}
			}
		}
	}

	return newUnmatched;
}

function setMatcher( preFilter, selector, matcher, postFilter, postFinder, postSelector ) {
	if ( postFilter && !postFilter[ expando ] ) {
		postFilter = setMatcher( postFilter );
	}
	if ( postFinder && !postFinder[ expando ] ) {
		postFinder = setMatcher( postFinder, postSelector );
	}
	return markFunction(function( seed, results, context, xml ) {
		var temp, i, elem,
			preMap = [],
			postMap = [],
			preexisting = results.length,

			// Get initial elements from seed or context
			elems = seed || multipleContexts( selector || "*", context.nodeType ? [ context ] : context, [] ),

			// Prefilter to get matcher input, preserving a map for seed-results synchronization
			matcherIn = preFilter && ( seed || !selector ) ?
				condense( elems, preMap, preFilter, context, xml ) :
				elems,

			matcherOut = matcher ?
				// If we have a postFinder, or filtered seed, or non-seed postFilter or preexisting results,
				postFinder || ( seed ? preFilter : preexisting || postFilter ) ?

					// ...intermediate processing is necessary
					[] :

					// ...otherwise use results directly
					results :
				matcherIn;

		// Find primary matches
		if ( matcher ) {
			matcher( matcherIn, matcherOut, context, xml );
		}

		// Apply postFilter
		if ( postFilter ) {
			temp = condense( matcherOut, postMap );
			postFilter( temp, [], context, xml );

			// Un-match failing elements by moving them back to matcherIn
			i = temp.length;
			while ( i-- ) {
				if ( (elem = temp[i]) ) {
					matcherOut[ postMap[i] ] = !(matcherIn[ postMap[i] ] = elem);
				}
			}
		}

		if ( seed ) {
			if ( postFinder || preFilter ) {
				if ( postFinder ) {
					// Get the final matcherOut by condensing this intermediate into postFinder contexts
					temp = [];
					i = matcherOut.length;
					while ( i-- ) {
						if ( (elem = matcherOut[i]) ) {
							// Restore matcherIn since elem is not yet a final match
							temp.push( (matcherIn[i] = elem) );
						}
					}
					postFinder( null, (matcherOut = []), temp, xml );
				}

				// Move matched elements from seed to results to keep them synchronized
				i = matcherOut.length;
				while ( i-- ) {
					if ( (elem = matcherOut[i]) &&
						(temp = postFinder ? indexOf( seed, elem ) : preMap[i]) > -1 ) {

						seed[temp] = !(results[temp] = elem);
					}
				}
			}

		// Add elements to results, through postFinder if defined
		} else {
			matcherOut = condense(
				matcherOut === results ?
					matcherOut.splice( preexisting, matcherOut.length ) :
					matcherOut
			);
			if ( postFinder ) {
				postFinder( null, results, matcherOut, xml );
			} else {
				push.apply( results, matcherOut );
			}
		}
	});
}

function matcherFromTokens( tokens ) {
	var checkContext, matcher, j,
		len = tokens.length,
		leadingRelative = Expr.relative[ tokens[0].type ],
		implicitRelative = leadingRelative || Expr.relative[" "],
		i = leadingRelative ? 1 : 0,

		// The foundational matcher ensures that elements are reachable from top-level context(s)
		matchContext = addCombinator( function( elem ) {
			return elem === checkContext;
		}, implicitRelative, true ),
		matchAnyContext = addCombinator( function( elem ) {
			return indexOf( checkContext, elem ) > -1;
		}, implicitRelative, true ),
		matchers = [ function( elem, context, xml ) {
			var ret = ( !leadingRelative && ( xml || context !== outermostContext ) ) || (
				(checkContext = context).nodeType ?
					matchContext( elem, context, xml ) :
					matchAnyContext( elem, context, xml ) );
			// Avoid hanging onto element (issue #299)
			checkContext = null;
			return ret;
		} ];

	for ( ; i < len; i++ ) {
		if ( (matcher = Expr.relative[ tokens[i].type ]) ) {
			matchers = [ addCombinator(elementMatcher( matchers ), matcher) ];
		} else {
			matcher = Expr.filter[ tokens[i].type ].apply( null, tokens[i].matches );

			// Return special upon seeing a positional matcher
			if ( matcher[ expando ] ) {
				// Find the next relative operator (if any) for proper handling
				j = ++i;
				for ( ; j < len; j++ ) {
					if ( Expr.relative[ tokens[j].type ] ) {
						break;
					}
				}
				return setMatcher(
					i > 1 && elementMatcher( matchers ),
					i > 1 && toSelector(
						// If the preceding token was a descendant combinator, insert an implicit any-element `*`
						tokens.slice( 0, i - 1 ).concat({ value: tokens[ i - 2 ].type === " " ? "*" : "" })
					).replace( rtrim, "$1" ),
					matcher,
					i < j && matcherFromTokens( tokens.slice( i, j ) ),
					j < len && matcherFromTokens( (tokens = tokens.slice( j )) ),
					j < len && toSelector( tokens )
				);
			}
			matchers.push( matcher );
		}
	}

	return elementMatcher( matchers );
}

function matcherFromGroupMatchers( elementMatchers, setMatchers ) {
	var bySet = setMatchers.length > 0,
		byElement = elementMatchers.length > 0,
		superMatcher = function( seed, context, xml, results, outermost ) {
			var elem, j, matcher,
				matchedCount = 0,
				i = "0",
				unmatched = seed && [],
				setMatched = [],
				contextBackup = outermostContext,
				// We must always have either seed elements or outermost context
				elems = seed || byElement && Expr.find["TAG"]( "*", outermost ),
				// Use integer dirruns iff this is the outermost matcher
				dirrunsUnique = (dirruns += contextBackup == null ? 1 : Math.random() || 0.1),
				len = elems.length;

			if ( outermost ) {
				outermostContext = context !== document && context;
			}

			// Add elements passing elementMatchers directly to results
			// Keep `i` a string if there are no elements so `matchedCount` will be "00" below
			// Support: IE<9, Safari
			// Tolerate NodeList properties (IE: "length"; Safari: <number>) matching elements by id
			for ( ; i !== len && (elem = elems[i]) != null; i++ ) {
				if ( byElement && elem ) {
					j = 0;
					while ( (matcher = elementMatchers[j++]) ) {
						if ( matcher( elem, context, xml ) ) {
							results.push( elem );
							break;
						}
					}
					if ( outermost ) {
						dirruns = dirrunsUnique;
					}
				}

				// Track unmatched elements for set filters
				if ( bySet ) {
					// They will have gone through all possible matchers
					if ( (elem = !matcher && elem) ) {
						matchedCount--;
					}

					// Lengthen the array for every element, matched or not
					if ( seed ) {
						unmatched.push( elem );
					}
				}
			}

			// Apply set filters to unmatched elements
			matchedCount += i;
			if ( bySet && i !== matchedCount ) {
				j = 0;
				while ( (matcher = setMatchers[j++]) ) {
					matcher( unmatched, setMatched, context, xml );
				}

				if ( seed ) {
					// Reintegrate element matches to eliminate the need for sorting
					if ( matchedCount > 0 ) {
						while ( i-- ) {
							if ( !(unmatched[i] || setMatched[i]) ) {
								setMatched[i] = pop.call( results );
							}
						}
					}

					// Discard index placeholder values to get only actual matches
					setMatched = condense( setMatched );
				}

				// Add matches to results
				push.apply( results, setMatched );

				// Seedless set matches succeeding multiple successful matchers stipulate sorting
				if ( outermost && !seed && setMatched.length > 0 &&
					( matchedCount + setMatchers.length ) > 1 ) {

					Sizzle.uniqueSort( results );
				}
			}

			// Override manipulation of globals by nested matchers
			if ( outermost ) {
				dirruns = dirrunsUnique;
				outermostContext = contextBackup;
			}

			return unmatched;
		};

	return bySet ?
		markFunction( superMatcher ) :
		superMatcher;
}

compile = Sizzle.compile = function( selector, match /* Internal Use Only */ ) {
	var i,
		setMatchers = [],
		elementMatchers = [],
		cached = compilerCache[ selector + " " ];

	if ( !cached ) {
		// Generate a function of recursive functions that can be used to check each element
		if ( !match ) {
			match = tokenize( selector );
		}
		i = match.length;
		while ( i-- ) {
			cached = matcherFromTokens( match[i] );
			if ( cached[ expando ] ) {
				setMatchers.push( cached );
			} else {
				elementMatchers.push( cached );
			}
		}

		// Cache the compiled function
		cached = compilerCache( selector, matcherFromGroupMatchers( elementMatchers, setMatchers ) );

		// Save selector and tokenization
		cached.selector = selector;
	}
	return cached;
};

/**
 * A low-level selection function that works with Sizzle's compiled
 *  selector functions
 * @param {String|Function} selector A selector or a pre-compiled
 *  selector function built with Sizzle.compile
 * @param {Element} context
 * @param {Array} [results]
 * @param {Array} [seed] A set of elements to match against
 */
select = Sizzle.select = function( selector, context, results, seed ) {
	var i, tokens, token, type, find,
		compiled = typeof selector === "function" && selector,
		match = !seed && tokenize( (selector = compiled.selector || selector) );

	results = results || [];

	// Try to minimize operations if there is no seed and only one group
	if ( match.length === 1 ) {

		// Take a shortcut and set the context if the root selector is an ID
		tokens = match[0] = match[0].slice( 0 );
		if ( tokens.length > 2 && (token = tokens[0]).type === "ID" &&
				support.getById && context.nodeType === 9 && documentIsHTML &&
				Expr.relative[ tokens[1].type ] ) {

			context = ( Expr.find["ID"]( token.matches[0].replace(runescape, funescape), context ) || [] )[0];
			if ( !context ) {
				return results;

			// Precompiled matchers will still verify ancestry, so step up a level
			} else if ( compiled ) {
				context = context.parentNode;
			}

			selector = selector.slice( tokens.shift().value.length );
		}

		// Fetch a seed set for right-to-left matching
		i = matchExpr["needsContext"].test( selector ) ? 0 : tokens.length;
		while ( i-- ) {
			token = tokens[i];

			// Abort if we hit a combinator
			if ( Expr.relative[ (type = token.type) ] ) {
				break;
			}
			if ( (find = Expr.find[ type ]) ) {
				// Search, expanding context for leading sibling combinators
				if ( (seed = find(
					token.matches[0].replace( runescape, funescape ),
					rsibling.test( tokens[0].type ) && testContext( context.parentNode ) || context
				)) ) {

					// If seed is empty or no tokens remain, we can return early
					tokens.splice( i, 1 );
					selector = seed.length && toSelector( tokens );
					if ( !selector ) {
						push.apply( results, seed );
						return results;
					}

					break;
				}
			}
		}
	}

	// Compile and execute a filtering function if one is not provided
	// Provide `match` to avoid retokenization if we modified the selector above
	( compiled || compile( selector, match ) )(
		seed,
		context,
		!documentIsHTML,
		results,
		rsibling.test( selector ) && testContext( context.parentNode ) || context
	);
	return results;
};

// One-time assignments

// Sort stability
support.sortStable = expando.split("").sort( sortOrder ).join("") === expando;

// Support: Chrome 14-35+
// Always assume duplicates if they aren't passed to the comparison function
support.detectDuplicates = !!hasDuplicate;

// Initialize against the default document
setDocument();

// Support: Webkit<537.32 - Safari 6.0.3/Chrome 25 (fixed in Chrome 27)
// Detached nodes confoundingly follow *each other*
support.sortDetached = assert(function( div1 ) {
	// Should return 1, but returns 4 (following)
	return div1.compareDocumentPosition( document.createElement("div") ) & 1;
});

// Support: IE<8
// Prevent attribute/property "interpolation"
// http://msdn.microsoft.com/en-us/library/ms536429%28VS.85%29.aspx
if ( !assert(function( div ) {
	div.innerHTML = "<a href='#'></a>";
	return div.firstChild.getAttribute("href") === "#" ;
}) ) {
	addHandle( "type|href|height|width", function( elem, name, isXML ) {
		if ( !isXML ) {
			return elem.getAttribute( name, name.toLowerCase() === "type" ? 1 : 2 );
		}
	});
}

// Support: IE<9
// Use defaultValue in place of getAttribute("value")
if ( !support.attributes || !assert(function( div ) {
	div.innerHTML = "<input/>";
	div.firstChild.setAttribute( "value", "" );
	return div.firstChild.getAttribute( "value" ) === "";
}) ) {
	addHandle( "value", function( elem, name, isXML ) {
		if ( !isXML && elem.nodeName.toLowerCase() === "input" ) {
			return elem.defaultValue;
		}
	});
}

// Support: IE<9
// Use getAttributeNode to fetch booleans when getAttribute lies
if ( !assert(function( div ) {
	return div.getAttribute("disabled") == null;
}) ) {
	addHandle( booleans, function( elem, name, isXML ) {
		var val;
		if ( !isXML ) {
			return elem[ name ] === true ? name.toLowerCase() :
					(val = elem.getAttributeNode( name )) && val.specified ?
					val.value :
				null;
		}
	});
}

return Sizzle;

})( window );



jQuery.find = Sizzle;
jQuery.expr = Sizzle.selectors;
jQuery.expr[":"] = jQuery.expr.pseudos;
jQuery.unique = Sizzle.uniqueSort;
jQuery.text = Sizzle.getText;
jQuery.isXMLDoc = Sizzle.isXML;
jQuery.contains = Sizzle.contains;



var rneedsContext = jQuery.expr.match.needsContext;

var rsingleTag = (/^<(\w+)\s*\/?>(?:<\/\1>|)$/);



var risSimple = /^.[^:#\[\.,]*$/;

// Implement the identical functionality for filter and not
function winnow( elements, qualifier, not ) {
	if ( jQuery.isFunction( qualifier ) ) {
		return jQuery.grep( elements, function( elem, i ) {
			/* jshint -W018 */
			return !!qualifier.call( elem, i, elem ) !== not;
		});

	}

	if ( qualifier.nodeType ) {
		return jQuery.grep( elements, function( elem ) {
			return ( elem === qualifier ) !== not;
		});

	}

	if ( typeof qualifier === "string" ) {
		if ( risSimple.test( qualifier ) ) {
			return jQuery.filter( qualifier, elements, not );
		}

		qualifier = jQuery.filter( qualifier, elements );
	}

	return jQuery.grep( elements, function( elem ) {
		return ( indexOf.call( qualifier, elem ) >= 0 ) !== not;
	});
}

jQuery.filter = function( expr, elems, not ) {
	var elem = elems[ 0 ];

	if ( not ) {
		expr = ":not(" + expr + ")";
	}

	return elems.length === 1 && elem.nodeType === 1 ?
		jQuery.find.matchesSelector( elem, expr ) ? [ elem ] : [] :
		jQuery.find.matches( expr, jQuery.grep( elems, function( elem ) {
			return elem.nodeType === 1;
		}));
};

jQuery.fn.extend({
	find: function( selector ) {
		var i,
			len = this.length,
			ret = [],
			self = this;

		if ( typeof selector !== "string" ) {
			return this.pushStack( jQuery( selector ).filter(function() {
				for ( i = 0; i < len; i++ ) {
					if ( jQuery.contains( self[ i ], this ) ) {
						return true;
					}
				}
			}) );
		}

		for ( i = 0; i < len; i++ ) {
			jQuery.find( selector, self[ i ], ret );
		}

		// Needed because $( selector, context ) becomes $( context ).find( selector )
		ret = this.pushStack( len > 1 ? jQuery.unique( ret ) : ret );
		ret.selector = this.selector ? this.selector + " " + selector : selector;
		return ret;
	},
	filter: function( selector ) {
		return this.pushStack( winnow(this, selector || [], false) );
	},
	not: function( selector ) {
		return this.pushStack( winnow(this, selector || [], true) );
	},
	is: function( selector ) {
		return !!winnow(
			this,

			// If this is a positional/relative selector, check membership in the returned set
			// so $("p:first").is("p:last") won't return true for a doc with two "p".
			typeof selector === "string" && rneedsContext.test( selector ) ?
				jQuery( selector ) :
				selector || [],
			false
		).length;
	}
});


// Initialize a jQuery object


// A central reference to the root jQuery(document)
var rootjQuery,

	// A simple way to check for HTML strings
	// Prioritize #id over <tag> to avoid XSS via location.hash (#9521)
	// Strict HTML recognition (#11290: must start with <)
	rquickExpr = /^(?:\s*(<[\w\W]+>)[^>]*|#([\w-]*))$/,

	init = jQuery.fn.init = function( selector, context ) {
		var match, elem;

		// HANDLE: $(""), $(null), $(undefined), $(false)
		if ( !selector ) {
			return this;
		}

		// Handle HTML strings
		if ( typeof selector === "string" ) {
			if ( selector[0] === "<" && selector[ selector.length - 1 ] === ">" && selector.length >= 3 ) {
				// Assume that strings that start and end with <> are HTML and skip the regex check
				match = [ null, selector, null ];

			} else {
				match = rquickExpr.exec( selector );
			}

			// Match html or make sure no context is specified for #id
			if ( match && (match[1] || !context) ) {

				// HANDLE: $(html) -> $(array)
				if ( match[1] ) {
					context = context instanceof jQuery ? context[0] : context;

					// Option to run scripts is true for back-compat
					// Intentionally let the error be thrown if parseHTML is not present
					jQuery.merge( this, jQuery.parseHTML(
						match[1],
						context && context.nodeType ? context.ownerDocument || context : document,
						true
					) );

					// HANDLE: $(html, props)
					if ( rsingleTag.test( match[1] ) && jQuery.isPlainObject( context ) ) {
						for ( match in context ) {
							// Properties of context are called as methods if possible
							if ( jQuery.isFunction( this[ match ] ) ) {
								this[ match ]( context[ match ] );

							// ...and otherwise set as attributes
							} else {
								this.attr( match, context[ match ] );
							}
						}
					}

					return this;

				// HANDLE: $(#id)
				} else {
					elem = document.getElementById( match[2] );

					// Support: Blackberry 4.6
					// gEBID returns nodes no longer in the document (#6963)
					if ( elem && elem.parentNode ) {
						// Inject the element directly into the jQuery object
						this.length = 1;
						this[0] = elem;
					}

					this.context = document;
					this.selector = selector;
					return this;
				}

			// HANDLE: $(expr, $(...))
			} else if ( !context || context.jquery ) {
				return ( context || rootjQuery ).find( selector );

			// HANDLE: $(expr, context)
			// (which is just equivalent to: $(context).find(expr)
			} else {
				return this.constructor( context ).find( selector );
			}

		// HANDLE: $(DOMElement)
		} else if ( selector.nodeType ) {
			this.context = this[0] = selector;
			this.length = 1;
			return this;

		// HANDLE: $(function)
		// Shortcut for document ready
		} else if ( jQuery.isFunction( selector ) ) {
			return typeof rootjQuery.ready !== "undefined" ?
				rootjQuery.ready( selector ) :
				// Execute immediately if ready is not present
				selector( jQuery );
		}

		if ( selector.selector !== undefined ) {
			this.selector = selector.selector;
			this.context = selector.context;
		}

		return jQuery.makeArray( selector, this );
	};

// Give the init function the jQuery prototype for later instantiation
init.prototype = jQuery.fn;

// Initialize central reference
rootjQuery = jQuery( document );


var rparentsprev = /^(?:parents|prev(?:Until|All))/,
	// Methods guaranteed to produce a unique set when starting from a unique set
	guaranteedUnique = {
		children: true,
		contents: true,
		next: true,
		prev: true
	};

jQuery.extend({
	dir: function( elem, dir, until ) {
		var matched = [],
			truncate = until !== undefined;

		while ( (elem = elem[ dir ]) && elem.nodeType !== 9 ) {
			if ( elem.nodeType === 1 ) {
				if ( truncate && jQuery( elem ).is( until ) ) {
					break;
				}
				matched.push( elem );
			}
		}
		return matched;
	},

	sibling: function( n, elem ) {
		var matched = [];

		for ( ; n; n = n.nextSibling ) {
			if ( n.nodeType === 1 && n !== elem ) {
				matched.push( n );
			}
		}

		return matched;
	}
});

jQuery.fn.extend({
	has: function( target ) {
		var targets = jQuery( target, this ),
			l = targets.length;

		return this.filter(function() {
			var i = 0;
			for ( ; i < l; i++ ) {
				if ( jQuery.contains( this, targets[i] ) ) {
					return true;
				}
			}
		});
	},

	closest: function( selectors, context ) {
		var cur,
			i = 0,
			l = this.length,
			matched = [],
			pos = rneedsContext.test( selectors ) || typeof selectors !== "string" ?
				jQuery( selectors, context || this.context ) :
				0;

		for ( ; i < l; i++ ) {
			for ( cur = this[i]; cur && cur !== context; cur = cur.parentNode ) {
				// Always skip document fragments
				if ( cur.nodeType < 11 && (pos ?
					pos.index(cur) > -1 :

					// Don't pass non-elements to Sizzle
					cur.nodeType === 1 &&
						jQuery.find.matchesSelector(cur, selectors)) ) {

					matched.push( cur );
					break;
				}
			}
		}

		return this.pushStack( matched.length > 1 ? jQuery.unique( matched ) : matched );
	},

	// Determine the position of an element within the set
	index: function( elem ) {

		// No argument, return index in parent
		if ( !elem ) {
			return ( this[ 0 ] && this[ 0 ].parentNode ) ? this.first().prevAll().length : -1;
		}

		// Index in selector
		if ( typeof elem === "string" ) {
			return indexOf.call( jQuery( elem ), this[ 0 ] );
		}

		// Locate the position of the desired element
		return indexOf.call( this,

			// If it receives a jQuery object, the first element is used
			elem.jquery ? elem[ 0 ] : elem
		);
	},

	add: function( selector, context ) {
		return this.pushStack(
			jQuery.unique(
				jQuery.merge( this.get(), jQuery( selector, context ) )
			)
		);
	},

	addBack: function( selector ) {
		return this.add( selector == null ?
			this.prevObject : this.prevObject.filter(selector)
		);
	}
});

function sibling( cur, dir ) {
	while ( (cur = cur[dir]) && cur.nodeType !== 1 ) {}
	return cur;
}

jQuery.each({
	parent: function( elem ) {
		var parent = elem.parentNode;
		return parent && parent.nodeType !== 11 ? parent : null;
	},
	parents: function( elem ) {
		return jQuery.dir( elem, "parentNode" );
	},
	parentsUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "parentNode", until );
	},
	next: function( elem ) {
		return sibling( elem, "nextSibling" );
	},
	prev: function( elem ) {
		return sibling( elem, "previousSibling" );
	},
	nextAll: function( elem ) {
		return jQuery.dir( elem, "nextSibling" );
	},
	prevAll: function( elem ) {
		return jQuery.dir( elem, "previousSibling" );
	},
	nextUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "nextSibling", until );
	},
	prevUntil: function( elem, i, until ) {
		return jQuery.dir( elem, "previousSibling", until );
	},
	siblings: function( elem ) {
		return jQuery.sibling( ( elem.parentNode || {} ).firstChild, elem );
	},
	children: function( elem ) {
		return jQuery.sibling( elem.firstChild );
	},
	contents: function( elem ) {
		return elem.contentDocument || jQuery.merge( [], elem.childNodes );
	}
}, function( name, fn ) {
	jQuery.fn[ name ] = function( until, selector ) {
		var matched = jQuery.map( this, fn, until );

		if ( name.slice( -5 ) !== "Until" ) {
			selector = until;
		}

		if ( selector && typeof selector === "string" ) {
			matched = jQuery.filter( selector, matched );
		}

		if ( this.length > 1 ) {
			// Remove duplicates
			if ( !guaranteedUnique[ name ] ) {
				jQuery.unique( matched );
			}

			// Reverse order for parents* and prev-derivatives
			if ( rparentsprev.test( name ) ) {
				matched.reverse();
			}
		}

		return this.pushStack( matched );
	};
});
var rnotwhite = (/\S+/g);



// String to Object options format cache
var optionsCache = {};

// Convert String-formatted options into Object-formatted ones and store in cache
function createOptions( options ) {
	var object = optionsCache[ options ] = {};
	jQuery.each( options.match( rnotwhite ) || [], function( _, flag ) {
		object[ flag ] = true;
	});
	return object;
}

/*
 * Create a callback list using the following parameters:
 *
 *	options: an optional list of space-separated options that will change how
 *			the callback list behaves or a more traditional option object
 *
 * By default a callback list will act like an event callback list and can be
 * "fired" multiple times.
 *
 * Possible options:
 *
 *	once:			will ensure the callback list can only be fired once (like a Deferred)
 *
 *	memory:			will keep track of previous values and will call any callback added
 *					after the list has been fired right away with the latest "memorized"
 *					values (like a Deferred)
 *
 *	unique:			will ensure a callback can only be added once (no duplicate in the list)
 *
 *	stopOnFalse:	interrupt callings when a callback returns false
 *
 */
jQuery.Callbacks = function( options ) {

	// Convert options from String-formatted to Object-formatted if needed
	// (we check in cache first)
	options = typeof options === "string" ?
		( optionsCache[ options ] || createOptions( options ) ) :
		jQuery.extend( {}, options );

	var // Last fire value (for non-forgettable lists)
		memory,
		// Flag to know if list was already fired
		fired,
		// Flag to know if list is currently firing
		firing,
		// First callback to fire (used internally by add and fireWith)
		firingStart,
		// End of the loop when firing
		firingLength,
		// Index of currently firing callback (modified by remove if needed)
		firingIndex,
		// Actual callback list
		list = [],
		// Stack of fire calls for repeatable lists
		stack = !options.once && [],
		// Fire callbacks
		fire = function( data ) {
			memory = options.memory && data;
			fired = true;
			firingIndex = firingStart || 0;
			firingStart = 0;
			firingLength = list.length;
			firing = true;
			for ( ; list && firingIndex < firingLength; firingIndex++ ) {
				if ( list[ firingIndex ].apply( data[ 0 ], data[ 1 ] ) === false && options.stopOnFalse ) {
					memory = false; // To prevent further calls using add
					break;
				}
			}
			firing = false;
			if ( list ) {
				if ( stack ) {
					if ( stack.length ) {
						fire( stack.shift() );
					}
				} else if ( memory ) {
					list = [];
				} else {
					self.disable();
				}
			}
		},
		// Actual Callbacks object
		self = {
			// Add a callback or a collection of callbacks to the list
			add: function() {
				if ( list ) {
					// First, we save the current length
					var start = list.length;
					(function add( args ) {
						jQuery.each( args, function( _, arg ) {
							var type = jQuery.type( arg );
							if ( type === "function" ) {
								if ( !options.unique || !self.has( arg ) ) {
									list.push( arg );
								}
							} else if ( arg && arg.length && type !== "string" ) {
								// Inspect recursively
								add( arg );
							}
						});
					})( arguments );
					// Do we need to add the callbacks to the
					// current firing batch?
					if ( firing ) {
						firingLength = list.length;
					// With memory, if we're not firing then
					// we should call right away
					} else if ( memory ) {
						firingStart = start;
						fire( memory );
					}
				}
				return this;
			},
			// Remove a callback from the list
			remove: function() {
				if ( list ) {
					jQuery.each( arguments, function( _, arg ) {
						var index;
						while ( ( index = jQuery.inArray( arg, list, index ) ) > -1 ) {
							list.splice( index, 1 );
							// Handle firing indexes
							if ( firing ) {
								if ( index <= firingLength ) {
									firingLength--;
								}
								if ( index <= firingIndex ) {
									firingIndex--;
								}
							}
						}
					});
				}
				return this;
			},
			// Check if a given callback is in the list.
			// If no argument is given, return whether or not list has callbacks attached.
			has: function( fn ) {
				return fn ? jQuery.inArray( fn, list ) > -1 : !!( list && list.length );
			},
			// Remove all callbacks from the list
			empty: function() {
				list = [];
				firingLength = 0;
				return this;
			},
			// Have the list do nothing anymore
			disable: function() {
				list = stack = memory = undefined;
				return this;
			},
			// Is it disabled?
			disabled: function() {
				return !list;
			},
			// Lock the list in its current state
			lock: function() {
				stack = undefined;
				if ( !memory ) {
					self.disable();
				}
				return this;
			},
			// Is it locked?
			locked: function() {
				return !stack;
			},
			// Call all callbacks with the given context and arguments
			fireWith: function( context, args ) {
				if ( list && ( !fired || stack ) ) {
					args = args || [];
					args = [ context, args.slice ? args.slice() : args ];
					if ( firing ) {
						stack.push( args );
					} else {
						fire( args );
					}
				}
				return this;
			},
			// Call all the callbacks with the given arguments
			fire: function() {
				self.fireWith( this, arguments );
				return this;
			},
			// To know if the callbacks have already been called at least once
			fired: function() {
				return !!fired;
			}
		};

	return self;
};


jQuery.extend({

	Deferred: function( func ) {
		var tuples = [
				// action, add listener, listener list, final state
				[ "resolve", "done", jQuery.Callbacks("once memory"), "resolved" ],
				[ "reject", "fail", jQuery.Callbacks("once memory"), "rejected" ],
				[ "notify", "progress", jQuery.Callbacks("memory") ]
			],
			state = "pending",
			promise = {
				state: function() {
					return state;
				},
				always: function() {
					deferred.done( arguments ).fail( arguments );
					return this;
				},
				then: function( /* fnDone, fnFail, fnProgress */ ) {
					var fns = arguments;
					return jQuery.Deferred(function( newDefer ) {
						jQuery.each( tuples, function( i, tuple ) {
							var fn = jQuery.isFunction( fns[ i ] ) && fns[ i ];
							// deferred[ done | fail | progress ] for forwarding actions to newDefer
							deferred[ tuple[1] ](function() {
								var returned = fn && fn.apply( this, arguments );
								if ( returned && jQuery.isFunction( returned.promise ) ) {
									returned.promise()
										.done( newDefer.resolve )
										.fail( newDefer.reject )
										.progress( newDefer.notify );
								} else {
									newDefer[ tuple[ 0 ] + "With" ]( this === promise ? newDefer.promise() : this, fn ? [ returned ] : arguments );
								}
							});
						});
						fns = null;
					}).promise();
				},
				// Get a promise for this deferred
				// If obj is provided, the promise aspect is added to the object
				promise: function( obj ) {
					return obj != null ? jQuery.extend( obj, promise ) : promise;
				}
			},
			deferred = {};

		// Keep pipe for back-compat
		promise.pipe = promise.then;

		// Add list-specific methods
		jQuery.each( tuples, function( i, tuple ) {
			var list = tuple[ 2 ],
				stateString = tuple[ 3 ];

			// promise[ done | fail | progress ] = list.add
			promise[ tuple[1] ] = list.add;

			// Handle state
			if ( stateString ) {
				list.add(function() {
					// state = [ resolved | rejected ]
					state = stateString;

				// [ reject_list | resolve_list ].disable; progress_list.lock
				}, tuples[ i ^ 1 ][ 2 ].disable, tuples[ 2 ][ 2 ].lock );
			}

			// deferred[ resolve | reject | notify ]
			deferred[ tuple[0] ] = function() {
				deferred[ tuple[0] + "With" ]( this === deferred ? promise : this, arguments );
				return this;
			};
			deferred[ tuple[0] + "With" ] = list.fireWith;
		});

		// Make the deferred a promise
		promise.promise( deferred );

		// Call given func if any
		if ( func ) {
			func.call( deferred, deferred );
		}

		// All done!
		return deferred;
	},

	// Deferred helper
	when: function( subordinate /* , ..., subordinateN */ ) {
		var i = 0,
			resolveValues = slice.call( arguments ),
			length = resolveValues.length,

			// the count of uncompleted subordinates
			remaining = length !== 1 || ( subordinate && jQuery.isFunction( subordinate.promise ) ) ? length : 0,

			// the master Deferred. If resolveValues consist of only a single Deferred, just use that.
			deferred = remaining === 1 ? subordinate : jQuery.Deferred(),

			// Update function for both resolve and progress values
			updateFunc = function( i, contexts, values ) {
				return function( value ) {
					contexts[ i ] = this;
					values[ i ] = arguments.length > 1 ? slice.call( arguments ) : value;
					if ( values === progressValues ) {
						deferred.notifyWith( contexts, values );
					} else if ( !( --remaining ) ) {
						deferred.resolveWith( contexts, values );
					}
				};
			},

			progressValues, progressContexts, resolveContexts;

		// Add listeners to Deferred subordinates; treat others as resolved
		if ( length > 1 ) {
			progressValues = new Array( length );
			progressContexts = new Array( length );
			resolveContexts = new Array( length );
			for ( ; i < length; i++ ) {
				if ( resolveValues[ i ] && jQuery.isFunction( resolveValues[ i ].promise ) ) {
					resolveValues[ i ].promise()
						.done( updateFunc( i, resolveContexts, resolveValues ) )
						.fail( deferred.reject )
						.progress( updateFunc( i, progressContexts, progressValues ) );
				} else {
					--remaining;
				}
			}
		}

		// If we're not waiting on anything, resolve the master
		if ( !remaining ) {
			deferred.resolveWith( resolveContexts, resolveValues );
		}

		return deferred.promise();
	}
});


// The deferred used on DOM ready
var readyList;

jQuery.fn.ready = function( fn ) {
	// Add the callback
	jQuery.ready.promise().done( fn );

	return this;
};

jQuery.extend({
	// Is the DOM ready to be used? Set to true once it occurs.
	isReady: false,

	// A counter to track how many items to wait for before
	// the ready event fires. See #6781
	readyWait: 1,

	// Hold (or release) the ready event
	holdReady: function( hold ) {
		if ( hold ) {
			jQuery.readyWait++;
		} else {
			jQuery.ready( true );
		}
	},

	// Handle when the DOM is ready
	ready: function( wait ) {

		// Abort if there are pending holds or we're already ready
		if ( wait === true ? --jQuery.readyWait : jQuery.isReady ) {
			return;
		}

		// Remember that the DOM is ready
		jQuery.isReady = true;

		// If a normal DOM Ready event fired, decrement, and wait if need be
		if ( wait !== true && --jQuery.readyWait > 0 ) {
			return;
		}

		// If there are functions bound, to execute
		readyList.resolveWith( document, [ jQuery ] );

		// Trigger any bound ready events
		if ( jQuery.fn.triggerHandler ) {
			jQuery( document ).triggerHandler( "ready" );
			jQuery( document ).off( "ready" );
		}
	}
});

/**
 * The ready event handler and self cleanup method
 */
function completed() {
	document.removeEventListener( "DOMContentLoaded", completed, false );
	window.removeEventListener( "load", completed, false );
	jQuery.ready();
}

jQuery.ready.promise = function( obj ) {
	if ( !readyList ) {

		readyList = jQuery.Deferred();

		// Catch cases where $(document).ready() is called after the browser event has already occurred.
		// We once tried to use readyState "interactive" here, but it caused issues like the one
		// discovered by ChrisS here: http://bugs.jquery.com/ticket/12282#comment:15
		if ( document.readyState === "complete" ) {
			// Handle it asynchronously to allow scripts the opportunity to delay ready
			setTimeout( jQuery.ready );

		} else {

			// Use the handy event callback
			document.addEventListener( "DOMContentLoaded", completed, false );

			// A fallback to window.onload, that will always work
			window.addEventListener( "load", completed, false );
		}
	}
	return readyList.promise( obj );
};

// Kick off the DOM ready check even if the user does not
jQuery.ready.promise();




// Multifunctional method to get and set values of a collection
// The value/s can optionally be executed if it's a function
var access = jQuery.access = function( elems, fn, key, value, chainable, emptyGet, raw ) {
	var i = 0,
		len = elems.length,
		bulk = key == null;

	// Sets many values
	if ( jQuery.type( key ) === "object" ) {
		chainable = true;
		for ( i in key ) {
			jQuery.access( elems, fn, i, key[i], true, emptyGet, raw );
		}

	// Sets one value
	} else if ( value !== undefined ) {
		chainable = true;

		if ( !jQuery.isFunction( value ) ) {
			raw = true;
		}

		if ( bulk ) {
			// Bulk operations run against the entire set
			if ( raw ) {
				fn.call( elems, value );
				fn = null;

			// ...except when executing function values
			} else {
				bulk = fn;
				fn = function( elem, key, value ) {
					return bulk.call( jQuery( elem ), value );
				};
			}
		}

		if ( fn ) {
			for ( ; i < len; i++ ) {
				fn( elems[i], key, raw ? value : value.call( elems[i], i, fn( elems[i], key ) ) );
			}
		}
	}

	return chainable ?
		elems :

		// Gets
		bulk ?
			fn.call( elems ) :
			len ? fn( elems[0], key ) : emptyGet;
};


/**
 * Determines whether an object can have data
 */
jQuery.acceptData = function( owner ) {
	// Accepts only:
	//  - Node
	//    - Node.ELEMENT_NODE
	//    - Node.DOCUMENT_NODE
	//  - Object
	//    - Any
	/* jshint -W018 */
	return owner.nodeType === 1 || owner.nodeType === 9 || !( +owner.nodeType );
};


function Data() {
	// Support: Android<4,
	// Old WebKit does not have Object.preventExtensions/freeze method,
	// return new empty object instead with no [[set]] accessor
	Object.defineProperty( this.cache = {}, 0, {
		get: function() {
			return {};
		}
	});

	this.expando = jQuery.expando + Data.uid++;
}

Data.uid = 1;
Data.accepts = jQuery.acceptData;

Data.prototype = {
	key: function( owner ) {
		// We can accept data for non-element nodes in modern browsers,
		// but we should not, see #8335.
		// Always return the key for a frozen object.
		if ( !Data.accepts( owner ) ) {
			return 0;
		}

		var descriptor = {},
			// Check if the owner object already has a cache key
			unlock = owner[ this.expando ];

		// If not, create one
		if ( !unlock ) {
			unlock = Data.uid++;

			// Secure it in a non-enumerable, non-writable property
			try {
				descriptor[ this.expando ] = { value: unlock };
				Object.defineProperties( owner, descriptor );

			// Support: Android<4
			// Fallback to a less secure definition
			} catch ( e ) {
				descriptor[ this.expando ] = unlock;
				jQuery.extend( owner, descriptor );
			}
		}

		// Ensure the cache object
		if ( !this.cache[ unlock ] ) {
			this.cache[ unlock ] = {};
		}

		return unlock;
	},
	set: function( owner, data, value ) {
		var prop,
			// There may be an unlock assigned to this node,
			// if there is no entry for this "owner", create one inline
			// and set the unlock as though an owner entry had always existed
			unlock = this.key( owner ),
			cache = this.cache[ unlock ];

		// Handle: [ owner, key, value ] args
		if ( typeof data === "string" ) {
			cache[ data ] = value;

		// Handle: [ owner, { properties } ] args
		} else {
			// Fresh assignments by object are shallow copied
			if ( jQuery.isEmptyObject( cache ) ) {
				jQuery.extend( this.cache[ unlock ], data );
			// Otherwise, copy the properties one-by-one to the cache object
			} else {
				for ( prop in data ) {
					cache[ prop ] = data[ prop ];
				}
			}
		}
		return cache;
	},
	get: function( owner, key ) {
		// Either a valid cache is found, or will be created.
		// New caches will be created and the unlock returned,
		// allowing direct access to the newly created
		// empty data object. A valid owner object must be provided.
		var cache = this.cache[ this.key( owner ) ];

		return key === undefined ?
			cache : cache[ key ];
	},
	access: function( owner, key, value ) {
		var stored;
		// In cases where either:
		//
		//   1. No key was specified
		//   2. A string key was specified, but no value provided
		//
		// Take the "read" path and allow the get method to determine
		// which value to return, respectively either:
		//
		//   1. The entire cache object
		//   2. The data stored at the key
		//
		if ( key === undefined ||
				((key && typeof key === "string") && value === undefined) ) {

			stored = this.get( owner, key );

			return stored !== undefined ?
				stored : this.get( owner, jQuery.camelCase(key) );
		}

		// [*]When the key is not a string, or both a key and value
		// are specified, set or extend (existing objects) with either:
		//
		//   1. An object of properties
		//   2. A key and value
		//
		this.set( owner, key, value );

		// Since the "set" path can have two possible entry points
		// return the expected data based on which path was taken[*]
		return value !== undefined ? value : key;
	},
	remove: function( owner, key ) {
		var i, name, camel,
			unlock = this.key( owner ),
			cache = this.cache[ unlock ];

		if ( key === undefined ) {
			this.cache[ unlock ] = {};

		} else {
			// Support array or space separated string of keys
			if ( jQuery.isArray( key ) ) {
				// If "name" is an array of keys...
				// When data is initially created, via ("key", "val") signature,
				// keys will be converted to camelCase.
				// Since there is no way to tell _how_ a key was added, remove
				// both plain key and camelCase key. #12786
				// This will only penalize the array argument path.
				name = key.concat( key.map( jQuery.camelCase ) );
			} else {
				camel = jQuery.camelCase( key );
				// Try the string as a key before any manipulation
				if ( key in cache ) {
					name = [ key, camel ];
				} else {
					// If a key with the spaces exists, use it.
					// Otherwise, create an array by matching non-whitespace
					name = camel;
					name = name in cache ?
						[ name ] : ( name.match( rnotwhite ) || [] );
				}
			}

			i = name.length;
			while ( i-- ) {
				delete cache[ name[ i ] ];
			}
		}
	},
	hasData: function( owner ) {
		return !jQuery.isEmptyObject(
			this.cache[ owner[ this.expando ] ] || {}
		);
	},
	discard: function( owner ) {
		if ( owner[ this.expando ] ) {
			delete this.cache[ owner[ this.expando ] ];
		}
	}
};
var data_priv = new Data();

var data_user = new Data();



//	Implementation Summary
//
//	1. Enforce API surface and semantic compatibility with 1.9.x branch
//	2. Improve the module's maintainability by reducing the storage
//		paths to a single mechanism.
//	3. Use the same single mechanism to support "private" and "user" data.
//	4. _Never_ expose "private" data to user code (TODO: Drop _data, _removeData)
//	5. Avoid exposing implementation details on user objects (eg. expando properties)
//	6. Provide a clear path for implementation upgrade to WeakMap in 2014

var rbrace = /^(?:\{[\w\W]*\}|\[[\w\W]*\])$/,
	rmultiDash = /([A-Z])/g;

function dataAttr( elem, key, data ) {
	var name;

	// If nothing was found internally, try to fetch any
	// data from the HTML5 data-* attribute
	if ( data === undefined && elem.nodeType === 1 ) {
		name = "data-" + key.replace( rmultiDash, "-$1" ).toLowerCase();
		data = elem.getAttribute( name );

		if ( typeof data === "string" ) {
			try {
				data = data === "true" ? true :
					data === "false" ? false :
					data === "null" ? null :
					// Only convert to a number if it doesn't change the string
					+data + "" === data ? +data :
					rbrace.test( data ) ? jQuery.parseJSON( data ) :
					data;
			} catch( e ) {}

			// Make sure we set the data so it isn't changed later
			data_user.set( elem, key, data );
		} else {
			data = undefined;
		}
	}
	return data;
}

jQuery.extend({
	hasData: function( elem ) {
		return data_user.hasData( elem ) || data_priv.hasData( elem );
	},

	data: function( elem, name, data ) {
		return data_user.access( elem, name, data );
	},

	removeData: function( elem, name ) {
		data_user.remove( elem, name );
	},

	// TODO: Now that all calls to _data and _removeData have been replaced
	// with direct calls to data_priv methods, these can be deprecated.
	_data: function( elem, name, data ) {
		return data_priv.access( elem, name, data );
	},

	_removeData: function( elem, name ) {
		data_priv.remove( elem, name );
	}
});

jQuery.fn.extend({
	data: function( key, value ) {
		var i, name, data,
			elem = this[ 0 ],
			attrs = elem && elem.attributes;

		// Gets all values
		if ( key === undefined ) {
			if ( this.length ) {
				data = data_user.get( elem );

				if ( elem.nodeType === 1 && !data_priv.get( elem, "hasDataAttrs" ) ) {
					i = attrs.length;
					while ( i-- ) {

						// Support: IE11+
						// The attrs elements can be null (#14894)
						if ( attrs[ i ] ) {
							name = attrs[ i ].name;
							if ( name.indexOf( "data-" ) === 0 ) {
								name = jQuery.camelCase( name.slice(5) );
								dataAttr( elem, name, data[ name ] );
							}
						}
					}
					data_priv.set( elem, "hasDataAttrs", true );
				}
			}

			return data;
		}

		// Sets multiple values
		if ( typeof key === "object" ) {
			return this.each(function() {
				data_user.set( this, key );
			});
		}

		return access( this, function( value ) {
			var data,
				camelKey = jQuery.camelCase( key );

			// The calling jQuery object (element matches) is not empty
			// (and therefore has an element appears at this[ 0 ]) and the
			// `value` parameter was not undefined. An empty jQuery object
			// will result in `undefined` for elem = this[ 0 ] which will
			// throw an exception if an attempt to read a data cache is made.
			if ( elem && value === undefined ) {
				// Attempt to get data from the cache
				// with the key as-is
				data = data_user.get( elem, key );
				if ( data !== undefined ) {
					return data;
				}

				// Attempt to get data from the cache
				// with the key camelized
				data = data_user.get( elem, camelKey );
				if ( data !== undefined ) {
					return data;
				}

				// Attempt to "discover" the data in
				// HTML5 custom data-* attrs
				data = dataAttr( elem, camelKey, undefined );
				if ( data !== undefined ) {
					return data;
				}

				// We tried really hard, but the data doesn't exist.
				return;
			}

			// Set the data...
			this.each(function() {
				// First, attempt to store a copy or reference of any
				// data that might've been store with a camelCased key.
				var data = data_user.get( this, camelKey );

				// For HTML5 data-* attribute interop, we have to
				// store property names with dashes in a camelCase form.
				// This might not apply to all properties...*
				data_user.set( this, camelKey, value );

				// *... In the case of properties that might _actually_
				// have dashes, we need to also store a copy of that
				// unchanged property.
				if ( key.indexOf("-") !== -1 && data !== undefined ) {
					data_user.set( this, key, value );
				}
			});
		}, null, value, arguments.length > 1, null, true );
	},

	removeData: function( key ) {
		return this.each(function() {
			data_user.remove( this, key );
		});
	}
});


jQuery.extend({
	queue: function( elem, type, data ) {
		var queue;

		if ( elem ) {
			type = ( type || "fx" ) + "queue";
			queue = data_priv.get( elem, type );

			// Speed up dequeue by getting out quickly if this is just a lookup
			if ( data ) {
				if ( !queue || jQuery.isArray( data ) ) {
					queue = data_priv.access( elem, type, jQuery.makeArray(data) );
				} else {
					queue.push( data );
				}
			}
			return queue || [];
		}
	},

	dequeue: function( elem, type ) {
		type = type || "fx";

		var queue = jQuery.queue( elem, type ),
			startLength = queue.length,
			fn = queue.shift(),
			hooks = jQuery._queueHooks( elem, type ),
			next = function() {
				jQuery.dequeue( elem, type );
			};

		// If the fx queue is dequeued, always remove the progress sentinel
		if ( fn === "inprogress" ) {
			fn = queue.shift();
			startLength--;
		}

		if ( fn ) {

			// Add a progress sentinel to prevent the fx queue from being
			// automatically dequeued
			if ( type === "fx" ) {
				queue.unshift( "inprogress" );
			}

			// Clear up the last queue stop function
			delete hooks.stop;
			fn.call( elem, next, hooks );
		}

		if ( !startLength && hooks ) {
			hooks.empty.fire();
		}
	},

	// Not public - generate a queueHooks object, or return the current one
	_queueHooks: function( elem, type ) {
		var key = type + "queueHooks";
		return data_priv.get( elem, key ) || data_priv.access( elem, key, {
			empty: jQuery.Callbacks("once memory").add(function() {
				data_priv.remove( elem, [ type + "queue", key ] );
			})
		});
	}
});

jQuery.fn.extend({
	queue: function( type, data ) {
		var setter = 2;

		if ( typeof type !== "string" ) {
			data = type;
			type = "fx";
			setter--;
		}

		if ( arguments.length < setter ) {
			return jQuery.queue( this[0], type );
		}

		return data === undefined ?
			this :
			this.each(function() {
				var queue = jQuery.queue( this, type, data );

				// Ensure a hooks for this queue
				jQuery._queueHooks( this, type );

				if ( type === "fx" && queue[0] !== "inprogress" ) {
					jQuery.dequeue( this, type );
				}
			});
	},
	dequeue: function( type ) {
		return this.each(function() {
			jQuery.dequeue( this, type );
		});
	},
	clearQueue: function( type ) {
		return this.queue( type || "fx", [] );
	},
	// Get a promise resolved when queues of a certain type
	// are emptied (fx is the type by default)
	promise: function( type, obj ) {
		var tmp,
			count = 1,
			defer = jQuery.Deferred(),
			elements = this,
			i = this.length,
			resolve = function() {
				if ( !( --count ) ) {
					defer.resolveWith( elements, [ elements ] );
				}
			};

		if ( typeof type !== "string" ) {
			obj = type;
			type = undefined;
		}
		type = type || "fx";

		while ( i-- ) {
			tmp = data_priv.get( elements[ i ], type + "queueHooks" );
			if ( tmp && tmp.empty ) {
				count++;
				tmp.empty.add( resolve );
			}
		}
		resolve();
		return defer.promise( obj );
	}
});
var pnum = (/[+-]?(?:\d*\.|)\d+(?:[eE][+-]?\d+|)/).source;

var cssExpand = [ "Top", "Right", "Bottom", "Left" ];

var isHidden = function( elem, el ) {
		// isHidden might be called from jQuery#filter function;
		// in that case, element will be second argument
		elem = el || elem;
		return jQuery.css( elem, "display" ) === "none" || !jQuery.contains( elem.ownerDocument, elem );
	};

var rcheckableType = (/^(?:checkbox|radio)$/i);



(function() {
	var fragment = document.createDocumentFragment(),
		div = fragment.appendChild( document.createElement( "div" ) ),
		input = document.createElement( "input" );

	// Support: Safari<=5.1
	// Check state lost if the name is set (#11217)
	// Support: Windows Web Apps (WWA)
	// `name` and `type` must use .setAttribute for WWA (#14901)
	input.setAttribute( "type", "radio" );
	input.setAttribute( "checked", "checked" );
	input.setAttribute( "name", "t" );

	div.appendChild( input );

	// Support: Safari<=5.1, Android<4.2
	// Older WebKit doesn't clone checked state correctly in fragments
	support.checkClone = div.cloneNode( true ).cloneNode( true ).lastChild.checked;

	// Support: IE<=11+
	// Make sure textarea (and checkbox) defaultValue is properly cloned
	div.innerHTML = "<textarea>x</textarea>";
	support.noCloneChecked = !!div.cloneNode( true ).lastChild.defaultValue;
})();
var strundefined = typeof undefined;



support.focusinBubbles = "onfocusin" in window;


var
	rkeyEvent = /^key/,
	rmouseEvent = /^(?:mouse|pointer|contextmenu)|click/,
	rfocusMorph = /^(?:focusinfocus|focusoutblur)$/,
	rtypenamespace = /^([^.]*)(?:\.(.+)|)$/;

function returnTrue() {
	return true;
}

function returnFalse() {
	return false;
}

function safeActiveElement() {
	try {
		return document.activeElement;
	} catch ( err ) { }
}

/*
 * Helper functions for managing events -- not part of the public interface.
 * Props to Dean Edwards' addEvent library for many of the ideas.
 */
jQuery.event = {

	global: {},

	add: function( elem, types, handler, data, selector ) {

		var handleObjIn, eventHandle, tmp,
			events, t, handleObj,
			special, handlers, type, namespaces, origType,
			elemData = data_priv.get( elem );

		// Don't attach events to noData or text/comment nodes (but allow plain objects)
		if ( !elemData ) {
			return;
		}

		// Caller can pass in an object of custom data in lieu of the handler
		if ( handler.handler ) {
			handleObjIn = handler;
			handler = handleObjIn.handler;
			selector = handleObjIn.selector;
		}

		// Make sure that the handler has a unique ID, used to find/remove it later
		if ( !handler.guid ) {
			handler.guid = jQuery.guid++;
		}

		// Init the element's event structure and main handler, if this is the first
		if ( !(events = elemData.events) ) {
			events = elemData.events = {};
		}
		if ( !(eventHandle = elemData.handle) ) {
			eventHandle = elemData.handle = function( e ) {
				// Discard the second event of a jQuery.event.trigger() and
				// when an event is called after a page has unloaded
				return typeof jQuery !== strundefined && jQuery.event.triggered !== e.type ?
					jQuery.event.dispatch.apply( elem, arguments ) : undefined;
			};
		}

		// Handle multiple events separated by a space
		types = ( types || "" ).match( rnotwhite ) || [ "" ];
		t = types.length;
		while ( t-- ) {
			tmp = rtypenamespace.exec( types[t] ) || [];
			type = origType = tmp[1];
			namespaces = ( tmp[2] || "" ).split( "." ).sort();

			// There *must* be a type, no attaching namespace-only handlers
			if ( !type ) {
				continue;
			}

			// If event changes its type, use the special event handlers for the changed type
			special = jQuery.event.special[ type ] || {};

			// If selector defined, determine special event api type, otherwise given type
			type = ( selector ? special.delegateType : special.bindType ) || type;

			// Update special based on newly reset type
			special = jQuery.event.special[ type ] || {};

			// handleObj is passed to all event handlers
			handleObj = jQuery.extend({
				type: type,
				origType: origType,
				data: data,
				handler: handler,
				guid: handler.guid,
				selector: selector,
				needsContext: selector && jQuery.expr.match.needsContext.test( selector ),
				namespace: namespaces.join(".")
			}, handleObjIn );

			// Init the event handler queue if we're the first
			if ( !(handlers = events[ type ]) ) {
				handlers = events[ type ] = [];
				handlers.delegateCount = 0;

				// Only use addEventListener if the special events handler returns false
				if ( !special.setup || special.setup.call( elem, data, namespaces, eventHandle ) === false ) {
					if ( elem.addEventListener ) {
						elem.addEventListener( type, eventHandle, false );
					}
				}
			}

			if ( special.add ) {
				special.add.call( elem, handleObj );

				if ( !handleObj.handler.guid ) {
					handleObj.handler.guid = handler.guid;
				}
			}

			// Add to the element's handler list, delegates in front
			if ( selector ) {
				handlers.splice( handlers.delegateCount++, 0, handleObj );
			} else {
				handlers.push( handleObj );
			}

			// Keep track of which events have ever been used, for event optimization
			jQuery.event.global[ type ] = true;
		}

	},

	// Detach an event or set of events from an element
	remove: function( elem, types, handler, selector, mappedTypes ) {

		var j, origCount, tmp,
			events, t, handleObj,
			special, handlers, type, namespaces, origType,
			elemData = data_priv.hasData( elem ) && data_priv.get( elem );

		if ( !elemData || !(events = elemData.events) ) {
			return;
		}

		// Once for each type.namespace in types; type may be omitted
		types = ( types || "" ).match( rnotwhite ) || [ "" ];
		t = types.length;
		while ( t-- ) {
			tmp = rtypenamespace.exec( types[t] ) || [];
			type = origType = tmp[1];
			namespaces = ( tmp[2] || "" ).split( "." ).sort();

			// Unbind all events (on this namespace, if provided) for the element
			if ( !type ) {
				for ( type in events ) {
					jQuery.event.remove( elem, type + types[ t ], handler, selector, true );
				}
				continue;
			}

			special = jQuery.event.special[ type ] || {};
			type = ( selector ? special.delegateType : special.bindType ) || type;
			handlers = events[ type ] || [];
			tmp = tmp[2] && new RegExp( "(^|\\.)" + namespaces.join("\\.(?:.*\\.|)") + "(\\.|$)" );

			// Remove matching events
			origCount = j = handlers.length;
			while ( j-- ) {
				handleObj = handlers[ j ];

				if ( ( mappedTypes || origType === handleObj.origType ) &&
					( !handler || handler.guid === handleObj.guid ) &&
					( !tmp || tmp.test( handleObj.namespace ) ) &&
					( !selector || selector === handleObj.selector || selector === "**" && handleObj.selector ) ) {
					handlers.splice( j, 1 );

					if ( handleObj.selector ) {
						handlers.delegateCount--;
					}
					if ( special.remove ) {
						special.remove.call( elem, handleObj );
					}
				}
			}

			// Remove generic event handler if we removed something and no more handlers exist
			// (avoids potential for endless recursion during removal of special event handlers)
			if ( origCount && !handlers.length ) {
				if ( !special.teardown || special.teardown.call( elem, namespaces, elemData.handle ) === false ) {
					jQuery.removeEvent( elem, type, elemData.handle );
				}

				delete events[ type ];
			}
		}

		// Remove the expando if it's no longer used
		if ( jQuery.isEmptyObject( events ) ) {
			delete elemData.handle;
			data_priv.remove( elem, "events" );
		}
	},

	trigger: function( event, data, elem, onlyHandlers ) {

		var i, cur, tmp, bubbleType, ontype, handle, special,
			eventPath = [ elem || document ],
			type = hasOwn.call( event, "type" ) ? event.type : event,
			namespaces = hasOwn.call( event, "namespace" ) ? event.namespace.split(".") : [];

		cur = tmp = elem = elem || document;

		// Don't do events on text and comment nodes
		if ( elem.nodeType === 3 || elem.nodeType === 8 ) {
			return;
		}

		// focus/blur morphs to focusin/out; ensure we're not firing them right now
		if ( rfocusMorph.test( type + jQuery.event.triggered ) ) {
			return;
		}

		if ( type.indexOf(".") >= 0 ) {
			// Namespaced trigger; create a regexp to match event type in handle()
			namespaces = type.split(".");
			type = namespaces.shift();
			namespaces.sort();
		}
		ontype = type.indexOf(":") < 0 && "on" + type;

		// Caller can pass in a jQuery.Event object, Object, or just an event type string
		event = event[ jQuery.expando ] ?
			event :
			new jQuery.Event( type, typeof event === "object" && event );

		// Trigger bitmask: & 1 for native handlers; & 2 for jQuery (always true)
		event.isTrigger = onlyHandlers ? 2 : 3;
		event.namespace = namespaces.join(".");
		event.namespace_re = event.namespace ?
			new RegExp( "(^|\\.)" + namespaces.join("\\.(?:.*\\.|)") + "(\\.|$)" ) :
			null;

		// Clean up the event in case it is being reused
		event.result = undefined;
		if ( !event.target ) {
			event.target = elem;
		}

		// Clone any incoming data and prepend the event, creating the handler arg list
		data = data == null ?
			[ event ] :
			jQuery.makeArray( data, [ event ] );

		// Allow special events to draw outside the lines
		special = jQuery.event.special[ type ] || {};
		if ( !onlyHandlers && special.trigger && special.trigger.apply( elem, data ) === false ) {
			return;
		}

		// Determine event propagation path in advance, per W3C events spec (#9951)
		// Bubble up to document, then to window; watch for a global ownerDocument var (#9724)
		if ( !onlyHandlers && !special.noBubble && !jQuery.isWindow( elem ) ) {

			bubbleType = special.delegateType || type;
			if ( !rfocusMorph.test( bubbleType + type ) ) {
				cur = cur.parentNode;
			}
			for ( ; cur; cur = cur.parentNode ) {
				eventPath.push( cur );
				tmp = cur;
			}

			// Only add window if we got to document (e.g., not plain obj or detached DOM)
			if ( tmp === (elem.ownerDocument || document) ) {
				eventPath.push( tmp.defaultView || tmp.parentWindow || window );
			}
		}

		// Fire handlers on the event path
		i = 0;
		while ( (cur = eventPath[i++]) && !event.isPropagationStopped() ) {

			event.type = i > 1 ?
				bubbleType :
				special.bindType || type;

			// jQuery handler
			handle = ( data_priv.get( cur, "events" ) || {} )[ event.type ] && data_priv.get( cur, "handle" );
			if ( handle ) {
				handle.apply( cur, data );
			}

			// Native handler
			handle = ontype && cur[ ontype ];
			if ( handle && handle.apply && jQuery.acceptData( cur ) ) {
				event.result = handle.apply( cur, data );
				if ( event.result === false ) {
					event.preventDefault();
				}
			}
		}
		event.type = type;

		// If nobody prevented the default action, do it now
		if ( !onlyHandlers && !event.isDefaultPrevented() ) {

			if ( (!special._default || special._default.apply( eventPath.pop(), data ) === false) &&
				jQuery.acceptData( elem ) ) {

				// Call a native DOM method on the target with the same name name as the event.
				// Don't do default actions on window, that's where global variables be (#6170)
				if ( ontype && jQuery.isFunction( elem[ type ] ) && !jQuery.isWindow( elem ) ) {

					// Don't re-trigger an onFOO event when we call its FOO() method
					tmp = elem[ ontype ];

					if ( tmp ) {
						elem[ ontype ] = null;
					}

					// Prevent re-triggering of the same event, since we already bubbled it above
					jQuery.event.triggered = type;
					elem[ type ]();
					jQuery.event.triggered = undefined;

					if ( tmp ) {
						elem[ ontype ] = tmp;
					}
				}
			}
		}

		return event.result;
	},

	dispatch: function( event ) {

		// Make a writable jQuery.Event from the native event object
		event = jQuery.event.fix( event );

		var i, j, ret, matched, handleObj,
			handlerQueue = [],
			args = slice.call( arguments ),
			handlers = ( data_priv.get( this, "events" ) || {} )[ event.type ] || [],
			special = jQuery.event.special[ event.type ] || {};

		// Use the fix-ed jQuery.Event rather than the (read-only) native event
		args[0] = event;
		event.delegateTarget = this;

		// Call the preDispatch hook for the mapped type, and let it bail if desired
		if ( special.preDispatch && special.preDispatch.call( this, event ) === false ) {
			return;
		}

		// Determine handlers
		handlerQueue = jQuery.event.handlers.call( this, event, handlers );

		// Run delegates first; they may want to stop propagation beneath us
		i = 0;
		while ( (matched = handlerQueue[ i++ ]) && !event.isPropagationStopped() ) {
			event.currentTarget = matched.elem;

			j = 0;
			while ( (handleObj = matched.handlers[ j++ ]) && !event.isImmediatePropagationStopped() ) {

				// Triggered event must either 1) have no namespace, or 2) have namespace(s)
				// a subset or equal to those in the bound event (both can have no namespace).
				if ( !event.namespace_re || event.namespace_re.test( handleObj.namespace ) ) {

					event.handleObj = handleObj;
					event.data = handleObj.data;

					ret = ( (jQuery.event.special[ handleObj.origType ] || {}).handle || handleObj.handler )
							.apply( matched.elem, args );

					if ( ret !== undefined ) {
						if ( (event.result = ret) === false ) {
							event.preventDefault();
							event.stopPropagation();
						}
					}
				}
			}
		}

		// Call the postDispatch hook for the mapped type
		if ( special.postDispatch ) {
			special.postDispatch.call( this, event );
		}

		return event.result;
	},

	handlers: function( event, handlers ) {
		var i, matches, sel, handleObj,
			handlerQueue = [],
			delegateCount = handlers.delegateCount,
			cur = event.target;

		// Find delegate handlers
		// Black-hole SVG <use> instance trees (#13180)
		// Avoid non-left-click bubbling in Firefox (#3861)
		if ( delegateCount && cur.nodeType && (!event.button || event.type !== "click") ) {

			for ( ; cur !== this; cur = cur.parentNode || this ) {

				// Don't process clicks on disabled elements (#6911, #8165, #11382, #11764)
				if ( cur.disabled !== true || event.type !== "click" ) {
					matches = [];
					for ( i = 0; i < delegateCount; i++ ) {
						handleObj = handlers[ i ];

						// Don't conflict with Object.prototype properties (#13203)
						sel = handleObj.selector + " ";

						if ( matches[ sel ] === undefined ) {
							matches[ sel ] = handleObj.needsContext ?
								jQuery( sel, this ).index( cur ) >= 0 :
								jQuery.find( sel, this, null, [ cur ] ).length;
						}
						if ( matches[ sel ] ) {
							matches.push( handleObj );
						}
					}
					if ( matches.length ) {
						handlerQueue.push({ elem: cur, handlers: matches });
					}
				}
			}
		}

		// Add the remaining (directly-bound) handlers
		if ( delegateCount < handlers.length ) {
			handlerQueue.push({ elem: this, handlers: handlers.slice( delegateCount ) });
		}

		return handlerQueue;
	},

	// Includes some event props shared by KeyEvent and MouseEvent
	props: "altKey bubbles cancelable ctrlKey currentTarget eventPhase metaKey relatedTarget shiftKey target timeStamp view which".split(" "),

	fixHooks: {},

	keyHooks: {
		props: "char charCode key keyCode".split(" "),
		filter: function( event, original ) {

			// Add which for key events
			if ( event.which == null ) {
				event.which = original.charCode != null ? original.charCode : original.keyCode;
			}

			return event;
		}
	},

	mouseHooks: {
		props: "button buttons clientX clientY offsetX offsetY pageX pageY screenX screenY toElement".split(" "),
		filter: function( event, original ) {
			var eventDoc, doc, body,
				button = original.button;

			// Calculate pageX/Y if missing and clientX/Y available
			if ( event.pageX == null && original.clientX != null ) {
				eventDoc = event.target.ownerDocument || document;
				doc = eventDoc.documentElement;
				body = eventDoc.body;

				event.pageX = original.clientX + ( doc && doc.scrollLeft || body && body.scrollLeft || 0 ) - ( doc && doc.clientLeft || body && body.clientLeft || 0 );
				event.pageY = original.clientY + ( doc && doc.scrollTop  || body && body.scrollTop  || 0 ) - ( doc && doc.clientTop  || body && body.clientTop  || 0 );
			}

			// Add which for click: 1 === left; 2 === middle; 3 === right
			// Note: button is not normalized, so don't use it
			if ( !event.which && button !== undefined ) {
				event.which = ( button & 1 ? 1 : ( button & 2 ? 3 : ( button & 4 ? 2 : 0 ) ) );
			}

			return event;
		}
	},

	fix: function( event ) {
		if ( event[ jQuery.expando ] ) {
			return event;
		}

		// Create a writable copy of the event object and normalize some properties
		var i, prop, copy,
			type = event.type,
			originalEvent = event,
			fixHook = this.fixHooks[ type ];

		if ( !fixHook ) {
			this.fixHooks[ type ] = fixHook =
				rmouseEvent.test( type ) ? this.mouseHooks :
				rkeyEvent.test( type ) ? this.keyHooks :
				{};
		}
		copy = fixHook.props ? this.props.concat( fixHook.props ) : this.props;

		event = new jQuery.Event( originalEvent );

		i = copy.length;
		while ( i-- ) {
			prop = copy[ i ];
			event[ prop ] = originalEvent[ prop ];
		}

		// Support: Cordova 2.5 (WebKit) (#13255)
		// All events should have a target; Cordova deviceready doesn't
		if ( !event.target ) {
			event.target = document;
		}

		// Support: Safari 6.0+, Chrome<28
		// Target should not be a text node (#504, #13143)
		if ( event.target.nodeType === 3 ) {
			event.target = event.target.parentNode;
		}

		return fixHook.filter ? fixHook.filter( event, originalEvent ) : event;
	},

	special: {
		load: {
			// Prevent triggered image.load events from bubbling to window.load
			noBubble: true
		},
		focus: {
			// Fire native event if possible so blur/focus sequence is correct
			trigger: function() {
				if ( this !== safeActiveElement() && this.focus ) {
					this.focus();
					return false;
				}
			},
			delegateType: "focusin"
		},
		blur: {
			trigger: function() {
				if ( this === safeActiveElement() && this.blur ) {
					this.blur();
					return false;
				}
			},
			delegateType: "focusout"
		},
		click: {
			// For checkbox, fire native event so checked state will be right
			trigger: function() {
				if ( this.type === "checkbox" && this.click && jQuery.nodeName( this, "input" ) ) {
					this.click();
					return false;
				}
			},

			// For cross-browser consistency, don't fire native .click() on links
			_default: function( event ) {
				return jQuery.nodeName( event.target, "a" );
			}
		},

		beforeunload: {
			postDispatch: function( event ) {

				// Support: Firefox 20+
				// Firefox doesn't alert if the returnValue field is not set.
				if ( event.result !== undefined && event.originalEvent ) {
					event.originalEvent.returnValue = event.result;
				}
			}
		}
	},

	simulate: function( type, elem, event, bubble ) {
		// Piggyback on a donor event to simulate a different one.
		// Fake originalEvent to avoid donor's stopPropagation, but if the
		// simulated event prevents default then we do the same on the donor.
		var e = jQuery.extend(
			new jQuery.Event(),
			event,
			{
				type: type,
				isSimulated: true,
				originalEvent: {}
			}
		);
		if ( bubble ) {
			jQuery.event.trigger( e, null, elem );
		} else {
			jQuery.event.dispatch.call( elem, e );
		}
		if ( e.isDefaultPrevented() ) {
			event.preventDefault();
		}
	}
};

jQuery.removeEvent = function( elem, type, handle ) {
	if ( elem.removeEventListener ) {
		elem.removeEventListener( type, handle, false );
	}
};

jQuery.Event = function( src, props ) {
	// Allow instantiation without the 'new' keyword
	if ( !(this instanceof jQuery.Event) ) {
		return new jQuery.Event( src, props );
	}

	// Event object
	if ( src && src.type ) {
		this.originalEvent = src;
		this.type = src.type;

		// Events bubbling up the document may have been marked as prevented
		// by a handler lower down the tree; reflect the correct value.
		this.isDefaultPrevented = src.defaultPrevented ||
				src.defaultPrevented === undefined &&
				// Support: Android<4.0
				src.returnValue === false ?
			returnTrue :
			returnFalse;

	// Event type
	} else {
		this.type = src;
	}

	// Put explicitly provided properties onto the event object
	if ( props ) {
		jQuery.extend( this, props );
	}

	// Create a timestamp if incoming event doesn't have one
	this.timeStamp = src && src.timeStamp || jQuery.now();

	// Mark it as fixed
	this[ jQuery.expando ] = true;
};

// jQuery.Event is based on DOM3 Events as specified by the ECMAScript Language Binding
// http://www.w3.org/TR/2003/WD-DOM-Level-3-Events-20030331/ecma-script-binding.html
jQuery.Event.prototype = {
	isDefaultPrevented: returnFalse,
	isPropagationStopped: returnFalse,
	isImmediatePropagationStopped: returnFalse,

	preventDefault: function() {
		var e = this.originalEvent;

		this.isDefaultPrevented = returnTrue;

		if ( e && e.preventDefault ) {
			e.preventDefault();
		}
	},
	stopPropagation: function() {
		var e = this.originalEvent;

		this.isPropagationStopped = returnTrue;

		if ( e && e.stopPropagation ) {
			e.stopPropagation();
		}
	},
	stopImmediatePropagation: function() {
		var e = this.originalEvent;

		this.isImmediatePropagationStopped = returnTrue;

		if ( e && e.stopImmediatePropagation ) {
			e.stopImmediatePropagation();
		}

		this.stopPropagation();
	}
};

// Create mouseenter/leave events using mouseover/out and event-time checks
// Support: Chrome 15+
jQuery.each({
	mouseenter: "mouseover",
	mouseleave: "mouseout",
	pointerenter: "pointerover",
	pointerleave: "pointerout"
}, function( orig, fix ) {
	jQuery.event.special[ orig ] = {
		delegateType: fix,
		bindType: fix,

		handle: function( event ) {
			var ret,
				target = this,
				related = event.relatedTarget,
				handleObj = event.handleObj;

			// For mousenter/leave call the handler if related is outside the target.
			// NB: No relatedTarget if the mouse left/entered the browser window
			if ( !related || (related !== target && !jQuery.contains( target, related )) ) {
				event.type = handleObj.origType;
				ret = handleObj.handler.apply( this, arguments );
				event.type = fix;
			}
			return ret;
		}
	};
});

// Support: Firefox, Chrome, Safari
// Create "bubbling" focus and blur events
if ( !support.focusinBubbles ) {
	jQuery.each({ focus: "focusin", blur: "focusout" }, function( orig, fix ) {

		// Attach a single capturing handler on the document while someone wants focusin/focusout
		var handler = function( event ) {
				jQuery.event.simulate( fix, event.target, jQuery.event.fix( event ), true );
			};

		jQuery.event.special[ fix ] = {
			setup: function() {
				var doc = this.ownerDocument || this,
					attaches = data_priv.access( doc, fix );

				if ( !attaches ) {
					doc.addEventListener( orig, handler, true );
				}
				data_priv.access( doc, fix, ( attaches || 0 ) + 1 );
			},
			teardown: function() {
				var doc = this.ownerDocument || this,
					attaches = data_priv.access( doc, fix ) - 1;

				if ( !attaches ) {
					doc.removeEventListener( orig, handler, true );
					data_priv.remove( doc, fix );

				} else {
					data_priv.access( doc, fix, attaches );
				}
			}
		};
	});
}

jQuery.fn.extend({

	on: function( types, selector, data, fn, /*INTERNAL*/ one ) {
		var origFn, type;

		// Types can be a map of types/handlers
		if ( typeof types === "object" ) {
			// ( types-Object, selector, data )
			if ( typeof selector !== "string" ) {
				// ( types-Object, data )
				data = data || selector;
				selector = undefined;
			}
			for ( type in types ) {
				this.on( type, selector, data, types[ type ], one );
			}
			return this;
		}

		if ( data == null && fn == null ) {
			// ( types, fn )
			fn = selector;
			data = selector = undefined;
		} else if ( fn == null ) {
			if ( typeof selector === "string" ) {
				// ( types, selector, fn )
				fn = data;
				data = undefined;
			} else {
				// ( types, data, fn )
				fn = data;
				data = selector;
				selector = undefined;
			}
		}
		if ( fn === false ) {
			fn = returnFalse;
		} else if ( !fn ) {
			return this;
		}

		if ( one === 1 ) {
			origFn = fn;
			fn = function( event ) {
				// Can use an empty set, since event contains the info
				jQuery().off( event );
				return origFn.apply( this, arguments );
			};
			// Use same guid so caller can remove using origFn
			fn.guid = origFn.guid || ( origFn.guid = jQuery.guid++ );
		}
		return this.each( function() {
			jQuery.event.add( this, types, fn, data, selector );
		});
	},
	one: function( types, selector, data, fn ) {
		return this.on( types, selector, data, fn, 1 );
	},
	off: function( types, selector, fn ) {
		var handleObj, type;
		if ( types && types.preventDefault && types.handleObj ) {
			// ( event )  dispatched jQuery.Event
			handleObj = types.handleObj;
			jQuery( types.delegateTarget ).off(
				handleObj.namespace ? handleObj.origType + "." + handleObj.namespace : handleObj.origType,
				handleObj.selector,
				handleObj.handler
			);
			return this;
		}
		if ( typeof types === "object" ) {
			// ( types-object [, selector] )
			for ( type in types ) {
				this.off( type, selector, types[ type ] );
			}
			return this;
		}
		if ( selector === false || typeof selector === "function" ) {
			// ( types [, fn] )
			fn = selector;
			selector = undefined;
		}
		if ( fn === false ) {
			fn = returnFalse;
		}
		return this.each(function() {
			jQuery.event.remove( this, types, fn, selector );
		});
	},

	trigger: function( type, data ) {
		return this.each(function() {
			jQuery.event.trigger( type, data, this );
		});
	},
	triggerHandler: function( type, data ) {
		var elem = this[0];
		if ( elem ) {
			return jQuery.event.trigger( type, data, elem, true );
		}
	}
});


var
	rxhtmlTag = /<(?!area|br|col|embed|hr|img|input|link|meta|param)(([\w:]+)[^>]*)\/>/gi,
	rtagName = /<([\w:]+)/,
	rhtml = /<|&#?\w+;/,
	rnoInnerhtml = /<(?:script|style|link)/i,
	// checked="checked" or checked
	rchecked = /checked\s*(?:[^=]|=\s*.checked.)/i,
	rscriptType = /^$|\/(?:java|ecma)script/i,
	rscriptTypeMasked = /^true\/(.*)/,
	rcleanScript = /^\s*<!(?:\[CDATA\[|--)|(?:\]\]|--)>\s*$/g,

	// We have to close these tags to support XHTML (#13200)
	wrapMap = {

		// Support: IE9
		option: [ 1, "<select multiple='multiple'>", "</select>" ],

		thead: [ 1, "<table>", "</table>" ],
		col: [ 2, "<table><colgroup>", "</colgroup></table>" ],
		tr: [ 2, "<table><tbody>", "</tbody></table>" ],
		td: [ 3, "<table><tbody><tr>", "</tr></tbody></table>" ],

		_default: [ 0, "", "" ]
	};

// Support: IE9
wrapMap.optgroup = wrapMap.option;

wrapMap.tbody = wrapMap.tfoot = wrapMap.colgroup = wrapMap.caption = wrapMap.thead;
wrapMap.th = wrapMap.td;

// Support: 1.x compatibility
// Manipulating tables requires a tbody
function manipulationTarget( elem, content ) {
	return jQuery.nodeName( elem, "table" ) &&
		jQuery.nodeName( content.nodeType !== 11 ? content : content.firstChild, "tr" ) ?

		elem.getElementsByTagName("tbody")[0] ||
			elem.appendChild( elem.ownerDocument.createElement("tbody") ) :
		elem;
}

// Replace/restore the type attribute of script elements for safe DOM manipulation
function disableScript( elem ) {
	elem.type = (elem.getAttribute("type") !== null) + "/" + elem.type;
	return elem;
}
function restoreScript( elem ) {
	var match = rscriptTypeMasked.exec( elem.type );

	if ( match ) {
		elem.type = match[ 1 ];
	} else {
		elem.removeAttribute("type");
	}

	return elem;
}

// Mark scripts as having already been evaluated
function setGlobalEval( elems, refElements ) {
	var i = 0,
		l = elems.length;

	for ( ; i < l; i++ ) {
		data_priv.set(
			elems[ i ], "globalEval", !refElements || data_priv.get( refElements[ i ], "globalEval" )
		);
	}
}

function cloneCopyEvent( src, dest ) {
	var i, l, type, pdataOld, pdataCur, udataOld, udataCur, events;

	if ( dest.nodeType !== 1 ) {
		return;
	}

	// 1. Copy private data: events, handlers, etc.
	if ( data_priv.hasData( src ) ) {
		pdataOld = data_priv.access( src );
		pdataCur = data_priv.set( dest, pdataOld );
		events = pdataOld.events;

		if ( events ) {
			delete pdataCur.handle;
			pdataCur.events = {};

			for ( type in events ) {
				for ( i = 0, l = events[ type ].length; i < l; i++ ) {
					jQuery.event.add( dest, type, events[ type ][ i ] );
				}
			}
		}
	}

	// 2. Copy user data
	if ( data_user.hasData( src ) ) {
		udataOld = data_user.access( src );
		udataCur = jQuery.extend( {}, udataOld );

		data_user.set( dest, udataCur );
	}
}

function getAll( context, tag ) {
	var ret = context.getElementsByTagName ? context.getElementsByTagName( tag || "*" ) :
			context.querySelectorAll ? context.querySelectorAll( tag || "*" ) :
			[];

	return tag === undefined || tag && jQuery.nodeName( context, tag ) ?
		jQuery.merge( [ context ], ret ) :
		ret;
}

// Fix IE bugs, see support tests
function fixInput( src, dest ) {
	var nodeName = dest.nodeName.toLowerCase();

	// Fails to persist the checked state of a cloned checkbox or radio button.
	if ( nodeName === "input" && rcheckableType.test( src.type ) ) {
		dest.checked = src.checked;

	// Fails to return the selected option to the default selected state when cloning options
	} else if ( nodeName === "input" || nodeName === "textarea" ) {
		dest.defaultValue = src.defaultValue;
	}
}

jQuery.extend({
	clone: function( elem, dataAndEvents, deepDataAndEvents ) {
		var i, l, srcElements, destElements,
			clone = elem.cloneNode( true ),
			inPage = jQuery.contains( elem.ownerDocument, elem );

		// Fix IE cloning issues
		if ( !support.noCloneChecked && ( elem.nodeType === 1 || elem.nodeType === 11 ) &&
				!jQuery.isXMLDoc( elem ) ) {

			// We eschew Sizzle here for performance reasons: http://jsperf.com/getall-vs-sizzle/2
			destElements = getAll( clone );
			srcElements = getAll( elem );

			for ( i = 0, l = srcElements.length; i < l; i++ ) {
				fixInput( srcElements[ i ], destElements[ i ] );
			}
		}

		// Copy the events from the original to the clone
		if ( dataAndEvents ) {
			if ( deepDataAndEvents ) {
				srcElements = srcElements || getAll( elem );
				destElements = destElements || getAll( clone );

				for ( i = 0, l = srcElements.length; i < l; i++ ) {
					cloneCopyEvent( srcElements[ i ], destElements[ i ] );
				}
			} else {
				cloneCopyEvent( elem, clone );
			}
		}

		// Preserve script evaluation history
		destElements = getAll( clone, "script" );
		if ( destElements.length > 0 ) {
			setGlobalEval( destElements, !inPage && getAll( elem, "script" ) );
		}

		// Return the cloned set
		return clone;
	},

	buildFragment: function( elems, context, scripts, selection ) {
		var elem, tmp, tag, wrap, contains, j,
			fragment = context.createDocumentFragment(),
			nodes = [],
			i = 0,
			l = elems.length;

		for ( ; i < l; i++ ) {
			elem = elems[ i ];

			if ( elem || elem === 0 ) {

				// Add nodes directly
				if ( jQuery.type( elem ) === "object" ) {
					// Support: QtWebKit, PhantomJS
					// push.apply(_, arraylike) throws on ancient WebKit
					jQuery.merge( nodes, elem.nodeType ? [ elem ] : elem );

				// Convert non-html into a text node
				} else if ( !rhtml.test( elem ) ) {
					nodes.push( context.createTextNode( elem ) );

				// Convert html into DOM nodes
				} else {
					tmp = tmp || fragment.appendChild( context.createElement("div") );

					// Deserialize a standard representation
					tag = ( rtagName.exec( elem ) || [ "", "" ] )[ 1 ].toLowerCase();
					wrap = wrapMap[ tag ] || wrapMap._default;
					tmp.innerHTML = wrap[ 1 ] + elem.replace( rxhtmlTag, "<$1></$2>" ) + wrap[ 2 ];

					// Descend through wrappers to the right content
					j = wrap[ 0 ];
					while ( j-- ) {
						tmp = tmp.lastChild;
					}

					// Support: QtWebKit, PhantomJS
					// push.apply(_, arraylike) throws on ancient WebKit
					jQuery.merge( nodes, tmp.childNodes );

					// Remember the top-level container
					tmp = fragment.firstChild;

					// Ensure the created nodes are orphaned (#12392)
					tmp.textContent = "";
				}
			}
		}

		// Remove wrapper from fragment
		fragment.textContent = "";

		i = 0;
		while ( (elem = nodes[ i++ ]) ) {

			// #4087 - If origin and destination elements are the same, and this is
			// that element, do not do anything
			if ( selection && jQuery.inArray( elem, selection ) !== -1 ) {
				continue;
			}

			contains = jQuery.contains( elem.ownerDocument, elem );

			// Append to fragment
			tmp = getAll( fragment.appendChild( elem ), "script" );

			// Preserve script evaluation history
			if ( contains ) {
				setGlobalEval( tmp );
			}

			// Capture executables
			if ( scripts ) {
				j = 0;
				while ( (elem = tmp[ j++ ]) ) {
					if ( rscriptType.test( elem.type || "" ) ) {
						scripts.push( elem );
					}
				}
			}
		}

		return fragment;
	},

	cleanData: function( elems ) {
		var data, elem, type, key,
			special = jQuery.event.special,
			i = 0;

		for ( ; (elem = elems[ i ]) !== undefined; i++ ) {
			if ( jQuery.acceptData( elem ) ) {
				key = elem[ data_priv.expando ];

				if ( key && (data = data_priv.cache[ key ]) ) {
					if ( data.events ) {
						for ( type in data.events ) {
							if ( special[ type ] ) {
								jQuery.event.remove( elem, type );

							// This is a shortcut to avoid jQuery.event.remove's overhead
							} else {
								jQuery.removeEvent( elem, type, data.handle );
							}
						}
					}
					if ( data_priv.cache[ key ] ) {
						// Discard any remaining `private` data
						delete data_priv.cache[ key ];
					}
				}
			}
			// Discard any remaining `user` data
			delete data_user.cache[ elem[ data_user.expando ] ];
		}
	}
});

jQuery.fn.extend({
	text: function( value ) {
		return access( this, function( value ) {
			return value === undefined ?
				jQuery.text( this ) :
				this.empty().each(function() {
					if ( this.nodeType === 1 || this.nodeType === 11 || this.nodeType === 9 ) {
						this.textContent = value;
					}
				});
		}, null, value, arguments.length );
	},

	append: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.nodeType === 1 || this.nodeType === 11 || this.nodeType === 9 ) {
				var target = manipulationTarget( this, elem );
				target.appendChild( elem );
			}
		});
	},

	prepend: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.nodeType === 1 || this.nodeType === 11 || this.nodeType === 9 ) {
				var target = manipulationTarget( this, elem );
				target.insertBefore( elem, target.firstChild );
			}
		});
	},

	before: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.parentNode ) {
				this.parentNode.insertBefore( elem, this );
			}
		});
	},

	after: function() {
		return this.domManip( arguments, function( elem ) {
			if ( this.parentNode ) {
				this.parentNode.insertBefore( elem, this.nextSibling );
			}
		});
	},

	remove: function( selector, keepData /* Internal Use Only */ ) {
		var elem,
			elems = selector ? jQuery.filter( selector, this ) : this,
			i = 0;

		for ( ; (elem = elems[i]) != null; i++ ) {
			if ( !keepData && elem.nodeType === 1 ) {
				jQuery.cleanData( getAll( elem ) );
			}

			if ( elem.parentNode ) {
				if ( keepData && jQuery.contains( elem.ownerDocument, elem ) ) {
					setGlobalEval( getAll( elem, "script" ) );
				}
				elem.parentNode.removeChild( elem );
			}
		}

		return this;
	},

	empty: function() {
		var elem,
			i = 0;

		for ( ; (elem = this[i]) != null; i++ ) {
			if ( elem.nodeType === 1 ) {

				// Prevent memory leaks
				jQuery.cleanData( getAll( elem, false ) );

				// Remove any remaining nodes
				elem.textContent = "";
			}
		}

		return this;
	},

	clone: function( dataAndEvents, deepDataAndEvents ) {
		dataAndEvents = dataAndEvents == null ? false : dataAndEvents;
		deepDataAndEvents = deepDataAndEvents == null ? dataAndEvents : deepDataAndEvents;

		return this.map(function() {
			return jQuery.clone( this, dataAndEvents, deepDataAndEvents );
		});
	},

	html: function( value ) {
		return access( this, function( value ) {
			var elem = this[ 0 ] || {},
				i = 0,
				l = this.length;

			if ( value === undefined && elem.nodeType === 1 ) {
				return elem.innerHTML;
			}

			// See if we can take a shortcut and just use innerHTML
			if ( typeof value === "string" && !rnoInnerhtml.test( value ) &&
				!wrapMap[ ( rtagName.exec( value ) || [ "", "" ] )[ 1 ].toLowerCase() ] ) {

				value = value.replace( rxhtmlTag, "<$1></$2>" );

				try {
					for ( ; i < l; i++ ) {
						elem = this[ i ] || {};

						// Remove element nodes and prevent memory leaks
						if ( elem.nodeType === 1 ) {
							jQuery.cleanData( getAll( elem, false ) );
							elem.innerHTML = value;
						}
					}

					elem = 0;

				// If using innerHTML throws an exception, use the fallback method
				} catch( e ) {}
			}

			if ( elem ) {
				this.empty().append( value );
			}
		}, null, value, arguments.length );
	},

	replaceWith: function() {
		var arg = arguments[ 0 ];

		// Make the changes, replacing each context element with the new content
		this.domManip( arguments, function( elem ) {
			arg = this.parentNode;

			jQuery.cleanData( getAll( this ) );

			if ( arg ) {
				arg.replaceChild( elem, this );
			}
		});

		// Force removal if there was no new content (e.g., from empty arguments)
		return arg && (arg.length || arg.nodeType) ? this : this.remove();
	},

	detach: function( selector ) {
		return this.remove( selector, true );
	},

	domManip: function( args, callback ) {

		// Flatten any nested arrays
		args = concat.apply( [], args );

		var fragment, first, scripts, hasScripts, node, doc,
			i = 0,
			l = this.length,
			set = this,
			iNoClone = l - 1,
			value = args[ 0 ],
			isFunction = jQuery.isFunction( value );

		// We can't cloneNode fragments that contain checked, in WebKit
		if ( isFunction ||
				( l > 1 && typeof value === "string" &&
					!support.checkClone && rchecked.test( value ) ) ) {
			return this.each(function( index ) {
				var self = set.eq( index );
				if ( isFunction ) {
					args[ 0 ] = value.call( this, index, self.html() );
				}
				self.domManip( args, callback );
			});
		}

		if ( l ) {
			fragment = jQuery.buildFragment( args, this[ 0 ].ownerDocument, false, this );
			first = fragment.firstChild;

			if ( fragment.childNodes.length === 1 ) {
				fragment = first;
			}

			if ( first ) {
				scripts = jQuery.map( getAll( fragment, "script" ), disableScript );
				hasScripts = scripts.length;

				// Use the original fragment for the last item instead of the first because it can end up
				// being emptied incorrectly in certain situations (#8070).
				for ( ; i < l; i++ ) {
					node = fragment;

					if ( i !== iNoClone ) {
						node = jQuery.clone( node, true, true );

						// Keep references to cloned scripts for later restoration
						if ( hasScripts ) {
							// Support: QtWebKit
							// jQuery.merge because push.apply(_, arraylike) throws
							jQuery.merge( scripts, getAll( node, "script" ) );
						}
					}

					callback.call( this[ i ], node, i );
				}

				if ( hasScripts ) {
					doc = scripts[ scripts.length - 1 ].ownerDocument;

					// Reenable scripts
					jQuery.map( scripts, restoreScript );

					// Evaluate executable scripts on first document insertion
					for ( i = 0; i < hasScripts; i++ ) {
						node = scripts[ i ];
						if ( rscriptType.test( node.type || "" ) &&
							!data_priv.access( node, "globalEval" ) && jQuery.contains( doc, node ) ) {

							if ( node.src ) {
								// Optional AJAX dependency, but won't run scripts if not present
								if ( jQuery._evalUrl ) {
									jQuery._evalUrl( node.src );
								}
							} else {
								jQuery.globalEval( node.textContent.replace( rcleanScript, "" ) );
							}
						}
					}
				}
			}
		}

		return this;
	}
});

jQuery.each({
	appendTo: "append",
	prependTo: "prepend",
	insertBefore: "before",
	insertAfter: "after",
	replaceAll: "replaceWith"
}, function( name, original ) {
	jQuery.fn[ name ] = function( selector ) {
		var elems,
			ret = [],
			insert = jQuery( selector ),
			last = insert.length - 1,
			i = 0;

		for ( ; i <= last; i++ ) {
			elems = i === last ? this : this.clone( true );
			jQuery( insert[ i ] )[ original ]( elems );

			// Support: QtWebKit
			// .get() because push.apply(_, arraylike) throws
			push.apply( ret, elems.get() );
		}

		return this.pushStack( ret );
	};
});


var iframe,
	elemdisplay = {};

/**
 * Retrieve the actual display of a element
 * @param {String} name nodeName of the element
 * @param {Object} doc Document object
 */
// Called only from within defaultDisplay
function actualDisplay( name, doc ) {
	var style,
		elem = jQuery( doc.createElement( name ) ).appendTo( doc.body ),

		// getDefaultComputedStyle might be reliably used only on attached element
		display = window.getDefaultComputedStyle && ( style = window.getDefaultComputedStyle( elem[ 0 ] ) ) ?

			// Use of this method is a temporary fix (more like optimization) until something better comes along,
			// since it was removed from specification and supported only in FF
			style.display : jQuery.css( elem[ 0 ], "display" );

	// We don't have any data stored on the element,
	// so use "detach" method as fast way to get rid of the element
	elem.detach();

	return display;
}

/**
 * Try to determine the default display value of an element
 * @param {String} nodeName
 */
function defaultDisplay( nodeName ) {
	var doc = document,
		display = elemdisplay[ nodeName ];

	if ( !display ) {
		display = actualDisplay( nodeName, doc );

		// If the simple way fails, read from inside an iframe
		if ( display === "none" || !display ) {

			// Use the already-created iframe if possible
			iframe = (iframe || jQuery( "<iframe frameborder='0' width='0' height='0'/>" )).appendTo( doc.documentElement );

			// Always write a new HTML skeleton so Webkit and Firefox don't choke on reuse
			doc = iframe[ 0 ].contentDocument;

			// Support: IE
			doc.write();
			doc.close();

			display = actualDisplay( nodeName, doc );
			iframe.detach();
		}

		// Store the correct default display
		elemdisplay[ nodeName ] = display;
	}

	return display;
}
var rmargin = (/^margin/);

var rnumnonpx = new RegExp( "^(" + pnum + ")(?!px)[a-z%]+$", "i" );

var getStyles = function( elem ) {
		// Support: IE<=11+, Firefox<=30+ (#15098, #14150)
		// IE throws on elements created in popups
		// FF meanwhile throws on frame elements through "defaultView.getComputedStyle"
		if ( elem.ownerDocument.defaultView.opener ) {
			return elem.ownerDocument.defaultView.getComputedStyle( elem, null );
		}

		return window.getComputedStyle( elem, null );
	};



function curCSS( elem, name, computed ) {
	var width, minWidth, maxWidth, ret,
		style = elem.style;

	computed = computed || getStyles( elem );

	// Support: IE9
	// getPropertyValue is only needed for .css('filter') (#12537)
	if ( computed ) {
		ret = computed.getPropertyValue( name ) || computed[ name ];
	}

	if ( computed ) {

		if ( ret === "" && !jQuery.contains( elem.ownerDocument, elem ) ) {
			ret = jQuery.style( elem, name );
		}

		// Support: iOS < 6
		// A tribute to the "awesome hack by Dean Edwards"
		// iOS < 6 (at least) returns percentage for a larger set of values, but width seems to be reliably pixels
		// this is against the CSSOM draft spec: http://dev.w3.org/csswg/cssom/#resolved-values
		if ( rnumnonpx.test( ret ) && rmargin.test( name ) ) {

			// Remember the original values
			width = style.width;
			minWidth = style.minWidth;
			maxWidth = style.maxWidth;

			// Put in the new values to get a computed value out
			style.minWidth = style.maxWidth = style.width = ret;
			ret = computed.width;

			// Revert the changed values
			style.width = width;
			style.minWidth = minWidth;
			style.maxWidth = maxWidth;
		}
	}

	return ret !== undefined ?
		// Support: IE
		// IE returns zIndex value as an integer.
		ret + "" :
		ret;
}


function addGetHookIf( conditionFn, hookFn ) {
	// Define the hook, we'll check on the first run if it's really needed.
	return {
		get: function() {
			if ( conditionFn() ) {
				// Hook not needed (or it's not possible to use it due
				// to missing dependency), remove it.
				delete this.get;
				return;
			}

			// Hook needed; redefine it so that the support test is not executed again.
			return (this.get = hookFn).apply( this, arguments );
		}
	};
}


(function() {
	var pixelPositionVal, boxSizingReliableVal,
		docElem = document.documentElement,
		container = document.createElement( "div" ),
		div = document.createElement( "div" );

	if ( !div.style ) {
		return;
	}

	// Support: IE9-11+
	// Style of cloned element affects source element cloned (#8908)
	div.style.backgroundClip = "content-box";
	div.cloneNode( true ).style.backgroundClip = "";
	support.clearCloneStyle = div.style.backgroundClip === "content-box";

	container.style.cssText = "border:0;width:0;height:0;top:0;left:-9999px;margin-top:1px;" +
		"position:absolute";
	container.appendChild( div );

	// Executing both pixelPosition & boxSizingReliable tests require only one layout
	// so they're executed at the same time to save the second computation.
	function computePixelPositionAndBoxSizingReliable() {
		div.style.cssText =
			// Support: Firefox<29, Android 2.3
			// Vendor-prefix box-sizing
			"-webkit-box-sizing:border-box;-moz-box-sizing:border-box;" +
			"box-sizing:border-box;display:block;margin-top:1%;top:1%;" +
			"border:1px;padding:1px;width:4px;position:absolute";
		div.innerHTML = "";
		docElem.appendChild( container );

		var divStyle = window.getComputedStyle( div, null );
		pixelPositionVal = divStyle.top !== "1%";
		boxSizingReliableVal = divStyle.width === "4px";

		docElem.removeChild( container );
	}

	// Support: node.js jsdom
	// Don't assume that getComputedStyle is a property of the global object
	if ( window.getComputedStyle ) {
		jQuery.extend( support, {
			pixelPosition: function() {

				// This test is executed only once but we still do memoizing
				// since we can use the boxSizingReliable pre-computing.
				// No need to check if the test was already performed, though.
				computePixelPositionAndBoxSizingReliable();
				return pixelPositionVal;
			},
			boxSizingReliable: function() {
				if ( boxSizingReliableVal == null ) {
					computePixelPositionAndBoxSizingReliable();
				}
				return boxSizingReliableVal;
			},
			reliableMarginRight: function() {

				// Support: Android 2.3
				// Check if div with explicit width and no margin-right incorrectly
				// gets computed margin-right based on width of container. (#3333)
				// WebKit Bug 13343 - getComputedStyle returns wrong value for margin-right
				// This support function is only executed once so no memoizing is needed.
				var ret,
					marginDiv = div.appendChild( document.createElement( "div" ) );

				// Reset CSS: box-sizing; display; margin; border; padding
				marginDiv.style.cssText = div.style.cssText =
					// Support: Firefox<29, Android 2.3
					// Vendor-prefix box-sizing
					"-webkit-box-sizing:content-box;-moz-box-sizing:content-box;" +
					"box-sizing:content-box;display:block;margin:0;border:0;padding:0";
				marginDiv.style.marginRight = marginDiv.style.width = "0";
				div.style.width = "1px";
				docElem.appendChild( container );

				ret = !parseFloat( window.getComputedStyle( marginDiv, null ).marginRight );

				docElem.removeChild( container );
				div.removeChild( marginDiv );

				return ret;
			}
		});
	}
})();


// A method for quickly swapping in/out CSS properties to get correct calculations.
jQuery.swap = function( elem, options, callback, args ) {
	var ret, name,
		old = {};

	// Remember the old values, and insert the new ones
	for ( name in options ) {
		old[ name ] = elem.style[ name ];
		elem.style[ name ] = options[ name ];
	}

	ret = callback.apply( elem, args || [] );

	// Revert the old values
	for ( name in options ) {
		elem.style[ name ] = old[ name ];
	}

	return ret;
};


var
	// Swappable if display is none or starts with table except "table", "table-cell", or "table-caption"
	// See here for display values: https://developer.mozilla.org/en-US/docs/CSS/display
	rdisplayswap = /^(none|table(?!-c[ea]).+)/,
	rnumsplit = new RegExp( "^(" + pnum + ")(.*)$", "i" ),
	rrelNum = new RegExp( "^([+-])=(" + pnum + ")", "i" ),

	cssShow = { position: "absolute", visibility: "hidden", display: "block" },
	cssNormalTransform = {
		letterSpacing: "0",
		fontWeight: "400"
	},

	cssPrefixes = [ "Webkit", "O", "Moz", "ms" ];

// Return a css property mapped to a potentially vendor prefixed property
function vendorPropName( style, name ) {

	// Shortcut for names that are not vendor prefixed
	if ( name in style ) {
		return name;
	}

	// Check for vendor prefixed names
	var capName = name[0].toUpperCase() + name.slice(1),
		origName = name,
		i = cssPrefixes.length;

	while ( i-- ) {
		name = cssPrefixes[ i ] + capName;
		if ( name in style ) {
			return name;
		}
	}

	return origName;
}

function setPositiveNumber( elem, value, subtract ) {
	var matches = rnumsplit.exec( value );
	return matches ?
		// Guard against undefined "subtract", e.g., when used as in cssHooks
		Math.max( 0, matches[ 1 ] - ( subtract || 0 ) ) + ( matches[ 2 ] || "px" ) :
		value;
}

function augmentWidthOrHeight( elem, name, extra, isBorderBox, styles ) {
	var i = extra === ( isBorderBox ? "border" : "content" ) ?
		// If we already have the right measurement, avoid augmentation
		4 :
		// Otherwise initialize for horizontal or vertical properties
		name === "width" ? 1 : 0,

		val = 0;

	for ( ; i < 4; i += 2 ) {
		// Both box models exclude margin, so add it if we want it
		if ( extra === "margin" ) {
			val += jQuery.css( elem, extra + cssExpand[ i ], true, styles );
		}

		if ( isBorderBox ) {
			// border-box includes padding, so remove it if we want content
			if ( extra === "content" ) {
				val -= jQuery.css( elem, "padding" + cssExpand[ i ], true, styles );
			}

			// At this point, extra isn't border nor margin, so remove border
			if ( extra !== "margin" ) {
				val -= jQuery.css( elem, "border" + cssExpand[ i ] + "Width", true, styles );
			}
		} else {
			// At this point, extra isn't content, so add padding
			val += jQuery.css( elem, "padding" + cssExpand[ i ], true, styles );

			// At this point, extra isn't content nor padding, so add border
			if ( extra !== "padding" ) {
				val += jQuery.css( elem, "border" + cssExpand[ i ] + "Width", true, styles );
			}
		}
	}

	return val;
}

function getWidthOrHeight( elem, name, extra ) {

	// Start with offset property, which is equivalent to the border-box value
	var valueIsBorderBox = true,
		val = name === "width" ? elem.offsetWidth : elem.offsetHeight,
		styles = getStyles( elem ),
		isBorderBox = jQuery.css( elem, "boxSizing", false, styles ) === "border-box";

	// Some non-html elements return undefined for offsetWidth, so check for null/undefined
	// svg - https://bugzilla.mozilla.org/show_bug.cgi?id=649285
	// MathML - https://bugzilla.mozilla.org/show_bug.cgi?id=491668
	if ( val <= 0 || val == null ) {
		// Fall back to computed then uncomputed css if necessary
		val = curCSS( elem, name, styles );
		if ( val < 0 || val == null ) {
			val = elem.style[ name ];
		}

		// Computed unit is not pixels. Stop here and return.
		if ( rnumnonpx.test(val) ) {
			return val;
		}

		// Check for style in case a browser which returns unreliable values
		// for getComputedStyle silently falls back to the reliable elem.style
		valueIsBorderBox = isBorderBox &&
			( support.boxSizingReliable() || val === elem.style[ name ] );

		// Normalize "", auto, and prepare for extra
		val = parseFloat( val ) || 0;
	}

	// Use the active box-sizing model to add/subtract irrelevant styles
	return ( val +
		augmentWidthOrHeight(
			elem,
			name,
			extra || ( isBorderBox ? "border" : "content" ),
			valueIsBorderBox,
			styles
		)
	) + "px";
}

function showHide( elements, show ) {
	var display, elem, hidden,
		values = [],
		index = 0,
		length = elements.length;

	for ( ; index < length; index++ ) {
		elem = elements[ index ];
		if ( !elem.style ) {
			continue;
		}

		values[ index ] = data_priv.get( elem, "olddisplay" );
		display = elem.style.display;
		if ( show ) {
			// Reset the inline display of this element to learn if it is
			// being hidden by cascaded rules or not
			if ( !values[ index ] && display === "none" ) {
				elem.style.display = "";
			}

			// Set elements which have been overridden with display: none
			// in a stylesheet to whatever the default browser style is
			// for such an element
			if ( elem.style.display === "" && isHidden( elem ) ) {
				values[ index ] = data_priv.access( elem, "olddisplay", defaultDisplay(elem.nodeName) );
			}
		} else {
			hidden = isHidden( elem );

			if ( display !== "none" || !hidden ) {
				data_priv.set( elem, "olddisplay", hidden ? display : jQuery.css( elem, "display" ) );
			}
		}
	}

	// Set the display of most of the elements in a second loop
	// to avoid the constant reflow
	for ( index = 0; index < length; index++ ) {
		elem = elements[ index ];
		if ( !elem.style ) {
			continue;
		}
		if ( !show || elem.style.display === "none" || elem.style.display === "" ) {
			elem.style.display = show ? values[ index ] || "" : "none";
		}
	}

	return elements;
}

jQuery.extend({

	// Add in style property hooks for overriding the default
	// behavior of getting and setting a style property
	cssHooks: {
		opacity: {
			get: function( elem, computed ) {
				if ( computed ) {

					// We should always get a number back from opacity
					var ret = curCSS( elem, "opacity" );
					return ret === "" ? "1" : ret;
				}
			}
		}
	},

	// Don't automatically add "px" to these possibly-unitless properties
	cssNumber: {
		"columnCount": true,
		"fillOpacity": true,
		"flexGrow": true,
		"flexShrink": true,
		"fontWeight": true,
		"lineHeight": true,
		"opacity": true,
		"order": true,
		"orphans": true,
		"widows": true,
		"zIndex": true,
		"zoom": true
	},

	// Add in properties whose names you wish to fix before
	// setting or getting the value
	cssProps: {
		"float": "cssFloat"
	},

	// Get and set the style property on a DOM Node
	style: function( elem, name, value, extra ) {

		// Don't set styles on text and comment nodes
		if ( !elem || elem.nodeType === 3 || elem.nodeType === 8 || !elem.style ) {
			return;
		}

		// Make sure that we're working with the right name
		var ret, type, hooks,
			origName = jQuery.camelCase( name ),
			style = elem.style;

		name = jQuery.cssProps[ origName ] || ( jQuery.cssProps[ origName ] = vendorPropName( style, origName ) );

		// Gets hook for the prefixed version, then unprefixed version
		hooks = jQuery.cssHooks[ name ] || jQuery.cssHooks[ origName ];

		// Check if we're setting a value
		if ( value !== undefined ) {
			type = typeof value;

			// Convert "+=" or "-=" to relative numbers (#7345)
			if ( type === "string" && (ret = rrelNum.exec( value )) ) {
				value = ( ret[1] + 1 ) * ret[2] + parseFloat( jQuery.css( elem, name ) );
				// Fixes bug #9237
				type = "number";
			}

			// Make sure that null and NaN values aren't set (#7116)
			if ( value == null || value !== value ) {
				return;
			}

			// If a number, add 'px' to the (except for certain CSS properties)
			if ( type === "number" && !jQuery.cssNumber[ origName ] ) {
				value += "px";
			}

			// Support: IE9-11+
			// background-* props affect original clone's values
			if ( !support.clearCloneStyle && value === "" && name.indexOf( "background" ) === 0 ) {
				style[ name ] = "inherit";
			}

			// If a hook was provided, use that value, otherwise just set the specified value
			if ( !hooks || !("set" in hooks) || (value = hooks.set( elem, value, extra )) !== undefined ) {
				style[ name ] = value;
			}

		} else {
			// If a hook was provided get the non-computed value from there
			if ( hooks && "get" in hooks && (ret = hooks.get( elem, false, extra )) !== undefined ) {
				return ret;
			}

			// Otherwise just get the value from the style object
			return style[ name ];
		}
	},

	css: function( elem, name, extra, styles ) {
		var val, num, hooks,
			origName = jQuery.camelCase( name );

		// Make sure that we're working with the right name
		name = jQuery.cssProps[ origName ] || ( jQuery.cssProps[ origName ] = vendorPropName( elem.style, origName ) );

		// Try prefixed name followed by the unprefixed name
		hooks = jQuery.cssHooks[ name ] || jQuery.cssHooks[ origName ];

		// If a hook was provided get the computed value from there
		if ( hooks && "get" in hooks ) {
			val = hooks.get( elem, true, extra );
		}

		// Otherwise, if a way to get the computed value exists, use that
		if ( val === undefined ) {
			val = curCSS( elem, name, styles );
		}

		// Convert "normal" to computed value
		if ( val === "normal" && name in cssNormalTransform ) {
			val = cssNormalTransform[ name ];
		}

		// Make numeric if forced or a qualifier was provided and val looks numeric
		if ( extra === "" || extra ) {
			num = parseFloat( val );
			return extra === true || jQuery.isNumeric( num ) ? num || 0 : val;
		}
		return val;
	}
});

jQuery.each([ "height", "width" ], function( i, name ) {
	jQuery.cssHooks[ name ] = {
		get: function( elem, computed, extra ) {
			if ( computed ) {

				// Certain elements can have dimension info if we invisibly show them
				// but it must have a current display style that would benefit
				return rdisplayswap.test( jQuery.css( elem, "display" ) ) && elem.offsetWidth === 0 ?
					jQuery.swap( elem, cssShow, function() {
						return getWidthOrHeight( elem, name, extra );
					}) :
					getWidthOrHeight( elem, name, extra );
			}
		},

		set: function( elem, value, extra ) {
			var styles = extra && getStyles( elem );
			return setPositiveNumber( elem, value, extra ?
				augmentWidthOrHeight(
					elem,
					name,
					extra,
					jQuery.css( elem, "boxSizing", false, styles ) === "border-box",
					styles
				) : 0
			);
		}
	};
});

// Support: Android 2.3
jQuery.cssHooks.marginRight = addGetHookIf( support.reliableMarginRight,
	function( elem, computed ) {
		if ( computed ) {
			return jQuery.swap( elem, { "display": "inline-block" },
				curCSS, [ elem, "marginRight" ] );
		}
	}
);

// These hooks are used by animate to expand properties
jQuery.each({
	margin: "",
	padding: "",
	border: "Width"
}, function( prefix, suffix ) {
	jQuery.cssHooks[ prefix + suffix ] = {
		expand: function( value ) {
			var i = 0,
				expanded = {},

				// Assumes a single number if not a string
				parts = typeof value === "string" ? value.split(" ") : [ value ];

			for ( ; i < 4; i++ ) {
				expanded[ prefix + cssExpand[ i ] + suffix ] =
					parts[ i ] || parts[ i - 2 ] || parts[ 0 ];
			}

			return expanded;
		}
	};

	if ( !rmargin.test( prefix ) ) {
		jQuery.cssHooks[ prefix + suffix ].set = setPositiveNumber;
	}
});

jQuery.fn.extend({
	css: function( name, value ) {
		return access( this, function( elem, name, value ) {
			var styles, len,
				map = {},
				i = 0;

			if ( jQuery.isArray( name ) ) {
				styles = getStyles( elem );
				len = name.length;

				for ( ; i < len; i++ ) {
					map[ name[ i ] ] = jQuery.css( elem, name[ i ], false, styles );
				}

				return map;
			}

			return value !== undefined ?
				jQuery.style( elem, name, value ) :
				jQuery.css( elem, name );
		}, name, value, arguments.length > 1 );
	},
	show: function() {
		return showHide( this, true );
	},
	hide: function() {
		return showHide( this );
	},
	toggle: function( state ) {
		if ( typeof state === "boolean" ) {
			return state ? this.show() : this.hide();
		}

		return this.each(function() {
			if ( isHidden( this ) ) {
				jQuery( this ).show();
			} else {
				jQuery( this ).hide();
			}
		});
	}
});


function Tween( elem, options, prop, end, easing ) {
	return new Tween.prototype.init( elem, options, prop, end, easing );
}
jQuery.Tween = Tween;

Tween.prototype = {
	constructor: Tween,
	init: function( elem, options, prop, end, easing, unit ) {
		this.elem = elem;
		this.prop = prop;
		this.easing = easing || "swing";
		this.options = options;
		this.start = this.now = this.cur();
		this.end = end;
		this.unit = unit || ( jQuery.cssNumber[ prop ] ? "" : "px" );
	},
	cur: function() {
		var hooks = Tween.propHooks[ this.prop ];

		return hooks && hooks.get ?
			hooks.get( this ) :
			Tween.propHooks._default.get( this );
	},
	run: function( percent ) {
		var eased,
			hooks = Tween.propHooks[ this.prop ];

		if ( this.options.duration ) {
			this.pos = eased = jQuery.easing[ this.easing ](
				percent, this.options.duration * percent, 0, 1, this.options.duration
			);
		} else {
			this.pos = eased = percent;
		}
		this.now = ( this.end - this.start ) * eased + this.start;

		if ( this.options.step ) {
			this.options.step.call( this.elem, this.now, this );
		}

		if ( hooks && hooks.set ) {
			hooks.set( this );
		} else {
			Tween.propHooks._default.set( this );
		}
		return this;
	}
};

Tween.prototype.init.prototype = Tween.prototype;

Tween.propHooks = {
	_default: {
		get: function( tween ) {
			var result;

			if ( tween.elem[ tween.prop ] != null &&
				(!tween.elem.style || tween.elem.style[ tween.prop ] == null) ) {
				return tween.elem[ tween.prop ];
			}

			// Passing an empty string as a 3rd parameter to .css will automatically
			// attempt a parseFloat and fallback to a string if the parse fails.
			// Simple values such as "10px" are parsed to Float;
			// complex values such as "rotate(1rad)" are returned as-is.
			result = jQuery.css( tween.elem, tween.prop, "" );
			// Empty strings, null, undefined and "auto" are converted to 0.
			return !result || result === "auto" ? 0 : result;
		},
		set: function( tween ) {
			// Use step hook for back compat.
			// Use cssHook if its there.
			// Use .style if available and use plain properties where available.
			if ( jQuery.fx.step[ tween.prop ] ) {
				jQuery.fx.step[ tween.prop ]( tween );
			} else if ( tween.elem.style && ( tween.elem.style[ jQuery.cssProps[ tween.prop ] ] != null || jQuery.cssHooks[ tween.prop ] ) ) {
				jQuery.style( tween.elem, tween.prop, tween.now + tween.unit );
			} else {
				tween.elem[ tween.prop ] = tween.now;
			}
		}
	}
};

// Support: IE9
// Panic based approach to setting things on disconnected nodes
Tween.propHooks.scrollTop = Tween.propHooks.scrollLeft = {
	set: function( tween ) {
		if ( tween.elem.nodeType && tween.elem.parentNode ) {
			tween.elem[ tween.prop ] = tween.now;
		}
	}
};

jQuery.easing = {
	linear: function( p ) {
		return p;
	},
	swing: function( p ) {
		return 0.5 - Math.cos( p * Math.PI ) / 2;
	}
};

jQuery.fx = Tween.prototype.init;

// Back Compat <1.8 extension point
jQuery.fx.step = {};




var
	fxNow, timerId,
	rfxtypes = /^(?:toggle|show|hide)$/,
	rfxnum = new RegExp( "^(?:([+-])=|)(" + pnum + ")([a-z%]*)$", "i" ),
	rrun = /queueHooks$/,
	animationPrefilters = [ defaultPrefilter ],
	tweeners = {
		"*": [ function( prop, value ) {
			var tween = this.createTween( prop, value ),
				target = tween.cur(),
				parts = rfxnum.exec( value ),
				unit = parts && parts[ 3 ] || ( jQuery.cssNumber[ prop ] ? "" : "px" ),

				// Starting value computation is required for potential unit mismatches
				start = ( jQuery.cssNumber[ prop ] || unit !== "px" && +target ) &&
					rfxnum.exec( jQuery.css( tween.elem, prop ) ),
				scale = 1,
				maxIterations = 20;

			if ( start && start[ 3 ] !== unit ) {
				// Trust units reported by jQuery.css
				unit = unit || start[ 3 ];

				// Make sure we update the tween properties later on
				parts = parts || [];

				// Iteratively approximate from a nonzero starting point
				start = +target || 1;

				do {
					// If previous iteration zeroed out, double until we get *something*.
					// Use string for doubling so we don't accidentally see scale as unchanged below
					scale = scale || ".5";

					// Adjust and apply
					start = start / scale;
					jQuery.style( tween.elem, prop, start + unit );

				// Update scale, tolerating zero or NaN from tween.cur(),
				// break the loop if scale is unchanged or perfect, or if we've just had enough
				} while ( scale !== (scale = tween.cur() / target) && scale !== 1 && --maxIterations );
			}

			// Update tween properties
			if ( parts ) {
				start = tween.start = +start || +target || 0;
				tween.unit = unit;
				// If a +=/-= token was provided, we're doing a relative animation
				tween.end = parts[ 1 ] ?
					start + ( parts[ 1 ] + 1 ) * parts[ 2 ] :
					+parts[ 2 ];
			}

			return tween;
		} ]
	};

// Animations created synchronously will run synchronously
function createFxNow() {
	setTimeout(function() {
		fxNow = undefined;
	});
	return ( fxNow = jQuery.now() );
}

// Generate parameters to create a standard animation
function genFx( type, includeWidth ) {
	var which,
		i = 0,
		attrs = { height: type };

	// If we include width, step value is 1 to do all cssExpand values,
	// otherwise step value is 2 to skip over Left and Right
	includeWidth = includeWidth ? 1 : 0;
	for ( ; i < 4 ; i += 2 - includeWidth ) {
		which = cssExpand[ i ];
		attrs[ "margin" + which ] = attrs[ "padding" + which ] = type;
	}

	if ( includeWidth ) {
		attrs.opacity = attrs.width = type;
	}

	return attrs;
}

function createTween( value, prop, animation ) {
	var tween,
		collection = ( tweeners[ prop ] || [] ).concat( tweeners[ "*" ] ),
		index = 0,
		length = collection.length;
	for ( ; index < length; index++ ) {
		if ( (tween = collection[ index ].call( animation, prop, value )) ) {

			// We're done with this property
			return tween;
		}
	}
}

function defaultPrefilter( elem, props, opts ) {
	/* jshint validthis: true */
	var prop, value, toggle, tween, hooks, oldfire, display, checkDisplay,
		anim = this,
		orig = {},
		style = elem.style,
		hidden = elem.nodeType && isHidden( elem ),
		dataShow = data_priv.get( elem, "fxshow" );

	// Handle queue: false promises
	if ( !opts.queue ) {
		hooks = jQuery._queueHooks( elem, "fx" );
		if ( hooks.unqueued == null ) {
			hooks.unqueued = 0;
			oldfire = hooks.empty.fire;
			hooks.empty.fire = function() {
				if ( !hooks.unqueued ) {
					oldfire();
				}
			};
		}
		hooks.unqueued++;

		anim.always(function() {
			// Ensure the complete handler is called before this completes
			anim.always(function() {
				hooks.unqueued--;
				if ( !jQuery.queue( elem, "fx" ).length ) {
					hooks.empty.fire();
				}
			});
		});
	}

	// Height/width overflow pass
	if ( elem.nodeType === 1 && ( "height" in props || "width" in props ) ) {
		// Make sure that nothing sneaks out
		// Record all 3 overflow attributes because IE9-10 do not
		// change the overflow attribute when overflowX and
		// overflowY are set to the same value
		opts.overflow = [ style.overflow, style.overflowX, style.overflowY ];

		// Set display property to inline-block for height/width
		// animations on inline elements that are having width/height animated
		display = jQuery.css( elem, "display" );

		// Test default display if display is currently "none"
		checkDisplay = display === "none" ?
			data_priv.get( elem, "olddisplay" ) || defaultDisplay( elem.nodeName ) : display;

		if ( checkDisplay === "inline" && jQuery.css( elem, "float" ) === "none" ) {
			style.display = "inline-block";
		}
	}

	if ( opts.overflow ) {
		style.overflow = "hidden";
		anim.always(function() {
			style.overflow = opts.overflow[ 0 ];
			style.overflowX = opts.overflow[ 1 ];
			style.overflowY = opts.overflow[ 2 ];
		});
	}

	// show/hide pass
	for ( prop in props ) {
		value = props[ prop ];
		if ( rfxtypes.exec( value ) ) {
			delete props[ prop ];
			toggle = toggle || value === "toggle";
			if ( value === ( hidden ? "hide" : "show" ) ) {

				// If there is dataShow left over from a stopped hide or show and we are going to proceed with show, we should pretend to be hidden
				if ( value === "show" && dataShow && dataShow[ prop ] !== undefined ) {
					hidden = true;
				} else {
					continue;
				}
			}
			orig[ prop ] = dataShow && dataShow[ prop ] || jQuery.style( elem, prop );

		// Any non-fx value stops us from restoring the original display value
		} else {
			display = undefined;
		}
	}

	if ( !jQuery.isEmptyObject( orig ) ) {
		if ( dataShow ) {
			if ( "hidden" in dataShow ) {
				hidden = dataShow.hidden;
			}
		} else {
			dataShow = data_priv.access( elem, "fxshow", {} );
		}

		// Store state if its toggle - enables .stop().toggle() to "reverse"
		if ( toggle ) {
			dataShow.hidden = !hidden;
		}
		if ( hidden ) {
			jQuery( elem ).show();
		} else {
			anim.done(function() {
				jQuery( elem ).hide();
			});
		}
		anim.done(function() {
			var prop;

			data_priv.remove( elem, "fxshow" );
			for ( prop in orig ) {
				jQuery.style( elem, prop, orig[ prop ] );
			}
		});
		for ( prop in orig ) {
			tween = createTween( hidden ? dataShow[ prop ] : 0, prop, anim );

			if ( !( prop in dataShow ) ) {
				dataShow[ prop ] = tween.start;
				if ( hidden ) {
					tween.end = tween.start;
					tween.start = prop === "width" || prop === "height" ? 1 : 0;
				}
			}
		}

	// If this is a noop like .hide().hide(), restore an overwritten display value
	} else if ( (display === "none" ? defaultDisplay( elem.nodeName ) : display) === "inline" ) {
		style.display = display;
	}
}

function propFilter( props, specialEasing ) {
	var index, name, easing, value, hooks;

	// camelCase, specialEasing and expand cssHook pass
	for ( index in props ) {
		name = jQuery.camelCase( index );
		easing = specialEasing[ name ];
		value = props[ index ];
		if ( jQuery.isArray( value ) ) {
			easing = value[ 1 ];
			value = props[ index ] = value[ 0 ];
		}

		if ( index !== name ) {
			props[ name ] = value;
			delete props[ index ];
		}

		hooks = jQuery.cssHooks[ name ];
		if ( hooks && "expand" in hooks ) {
			value = hooks.expand( value );
			delete props[ name ];

			// Not quite $.extend, this won't overwrite existing keys.
			// Reusing 'index' because we have the correct "name"
			for ( index in value ) {
				if ( !( index in props ) ) {
					props[ index ] = value[ index ];
					specialEasing[ index ] = easing;
				}
			}
		} else {
			specialEasing[ name ] = easing;
		}
	}
}

function Animation( elem, properties, options ) {
	var result,
		stopped,
		index = 0,
		length = animationPrefilters.length,
		deferred = jQuery.Deferred().always( function() {
			// Don't match elem in the :animated selector
			delete tick.elem;
		}),
		tick = function() {
			if ( stopped ) {
				return false;
			}
			var currentTime = fxNow || createFxNow(),
				remaining = Math.max( 0, animation.startTime + animation.duration - currentTime ),
				// Support: Android 2.3
				// Archaic crash bug won't allow us to use `1 - ( 0.5 || 0 )` (#12497)
				temp = remaining / animation.duration || 0,
				percent = 1 - temp,
				index = 0,
				length = animation.tweens.length;

			for ( ; index < length ; index++ ) {
				animation.tweens[ index ].run( percent );
			}

			deferred.notifyWith( elem, [ animation, percent, remaining ]);

			if ( percent < 1 && length ) {
				return remaining;
			} else {
				deferred.resolveWith( elem, [ animation ] );
				return false;
			}
		},
		animation = deferred.promise({
			elem: elem,
			props: jQuery.extend( {}, properties ),
			opts: jQuery.extend( true, { specialEasing: {} }, options ),
			originalProperties: properties,
			originalOptions: options,
			startTime: fxNow || createFxNow(),
			duration: options.duration,
			tweens: [],
			createTween: function( prop, end ) {
				var tween = jQuery.Tween( elem, animation.opts, prop, end,
						animation.opts.specialEasing[ prop ] || animation.opts.easing );
				animation.tweens.push( tween );
				return tween;
			},
			stop: function( gotoEnd ) {
				var index = 0,
					// If we are going to the end, we want to run all the tweens
					// otherwise we skip this part
					length = gotoEnd ? animation.tweens.length : 0;
				if ( stopped ) {
					return this;
				}
				stopped = true;
				for ( ; index < length ; index++ ) {
					animation.tweens[ index ].run( 1 );
				}

				// Resolve when we played the last frame; otherwise, reject
				if ( gotoEnd ) {
					deferred.resolveWith( elem, [ animation, gotoEnd ] );
				} else {
					deferred.rejectWith( elem, [ animation, gotoEnd ] );
				}
				return this;
			}
		}),
		props = animation.props;

	propFilter( props, animation.opts.specialEasing );

	for ( ; index < length ; index++ ) {
		result = animationPrefilters[ index ].call( animation, elem, props, animation.opts );
		if ( result ) {
			return result;
		}
	}

	jQuery.map( props, createTween, animation );

	if ( jQuery.isFunction( animation.opts.start ) ) {
		animation.opts.start.call( elem, animation );
	}

	jQuery.fx.timer(
		jQuery.extend( tick, {
			elem: elem,
			anim: animation,
			queue: animation.opts.queue
		})
	);

	// attach callbacks from options
	return animation.progress( animation.opts.progress )
		.done( animation.opts.done, animation.opts.complete )
		.fail( animation.opts.fail )
		.always( animation.opts.always );
}

jQuery.Animation = jQuery.extend( Animation, {

	tweener: function( props, callback ) {
		if ( jQuery.isFunction( props ) ) {
			callback = props;
			props = [ "*" ];
		} else {
			props = props.split(" ");
		}

		var prop,
			index = 0,
			length = props.length;

		for ( ; index < length ; index++ ) {
			prop = props[ index ];
			tweeners[ prop ] = tweeners[ prop ] || [];
			tweeners[ prop ].unshift( callback );
		}
	},

	prefilter: function( callback, prepend ) {
		if ( prepend ) {
			animationPrefilters.unshift( callback );
		} else {
			animationPrefilters.push( callback );
		}
	}
});

jQuery.speed = function( speed, easing, fn ) {
	var opt = speed && typeof speed === "object" ? jQuery.extend( {}, speed ) : {
		complete: fn || !fn && easing ||
			jQuery.isFunction( speed ) && speed,
		duration: speed,
		easing: fn && easing || easing && !jQuery.isFunction( easing ) && easing
	};

	opt.duration = jQuery.fx.off ? 0 : typeof opt.duration === "number" ? opt.duration :
		opt.duration in jQuery.fx.speeds ? jQuery.fx.speeds[ opt.duration ] : jQuery.fx.speeds._default;

	// Normalize opt.queue - true/undefined/null -> "fx"
	if ( opt.queue == null || opt.queue === true ) {
		opt.queue = "fx";
	}

	// Queueing
	opt.old = opt.complete;

	opt.complete = function() {
		if ( jQuery.isFunction( opt.old ) ) {
			opt.old.call( this );
		}

		if ( opt.queue ) {
			jQuery.dequeue( this, opt.queue );
		}
	};

	return opt;
};

jQuery.fn.extend({
	fadeTo: function( speed, to, easing, callback ) {

		// Show any hidden elements after setting opacity to 0
		return this.filter( isHidden ).css( "opacity", 0 ).show()

			// Animate to the value specified
			.end().animate({ opacity: to }, speed, easing, callback );
	},
	animate: function( prop, speed, easing, callback ) {
		var empty = jQuery.isEmptyObject( prop ),
			optall = jQuery.speed( speed, easing, callback ),
			doAnimation = function() {
				// Operate on a copy of prop so per-property easing won't be lost
				var anim = Animation( this, jQuery.extend( {}, prop ), optall );

				// Empty animations, or finishing resolves immediately
				if ( empty || data_priv.get( this, "finish" ) ) {
					anim.stop( true );
				}
			};
			doAnimation.finish = doAnimation;

		return empty || optall.queue === false ?
			this.each( doAnimation ) :
			this.queue( optall.queue, doAnimation );
	},
	stop: function( type, clearQueue, gotoEnd ) {
		var stopQueue = function( hooks ) {
			var stop = hooks.stop;
			delete hooks.stop;
			stop( gotoEnd );
		};

		if ( typeof type !== "string" ) {
			gotoEnd = clearQueue;
			clearQueue = type;
			type = undefined;
		}
		if ( clearQueue && type !== false ) {
			this.queue( type || "fx", [] );
		}

		return this.each(function() {
			var dequeue = true,
				index = type != null && type + "queueHooks",
				timers = jQuery.timers,
				data = data_priv.get( this );

			if ( index ) {
				if ( data[ index ] && data[ index ].stop ) {
					stopQueue( data[ index ] );
				}
			} else {
				for ( index in data ) {
					if ( data[ index ] && data[ index ].stop && rrun.test( index ) ) {
						stopQueue( data[ index ] );
					}
				}
			}

			for ( index = timers.length; index--; ) {
				if ( timers[ index ].elem === this && (type == null || timers[ index ].queue === type) ) {
					timers[ index ].anim.stop( gotoEnd );
					dequeue = false;
					timers.splice( index, 1 );
				}
			}

			// Start the next in the queue if the last step wasn't forced.
			// Timers currently will call their complete callbacks, which
			// will dequeue but only if they were gotoEnd.
			if ( dequeue || !gotoEnd ) {
				jQuery.dequeue( this, type );
			}
		});
	},
	finish: function( type ) {
		if ( type !== false ) {
			type = type || "fx";
		}
		return this.each(function() {
			var index,
				data = data_priv.get( this ),
				queue = data[ type + "queue" ],
				hooks = data[ type + "queueHooks" ],
				timers = jQuery.timers,
				length = queue ? queue.length : 0;

			// Enable finishing flag on private data
			data.finish = true;

			// Empty the queue first
			jQuery.queue( this, type, [] );

			if ( hooks && hooks.stop ) {
				hooks.stop.call( this, true );
			}

			// Look for any active animations, and finish them
			for ( index = timers.length; index--; ) {
				if ( timers[ index ].elem === this && timers[ index ].queue === type ) {
					timers[ index ].anim.stop( true );
					timers.splice( index, 1 );
				}
			}

			// Look for any animations in the old queue and finish them
			for ( index = 0; index < length; index++ ) {
				if ( queue[ index ] && queue[ index ].finish ) {
					queue[ index ].finish.call( this );
				}
			}

			// Turn off finishing flag
			delete data.finish;
		});
	}
});

jQuery.each([ "toggle", "show", "hide" ], function( i, name ) {
	var cssFn = jQuery.fn[ name ];
	jQuery.fn[ name ] = function( speed, easing, callback ) {
		return speed == null || typeof speed === "boolean" ?
			cssFn.apply( this, arguments ) :
			this.animate( genFx( name, true ), speed, easing, callback );
	};
});

// Generate shortcuts for custom animations
jQuery.each({
	slideDown: genFx("show"),
	slideUp: genFx("hide"),
	slideToggle: genFx("toggle"),
	fadeIn: { opacity: "show" },
	fadeOut: { opacity: "hide" },
	fadeToggle: { opacity: "toggle" }
}, function( name, props ) {
	jQuery.fn[ name ] = function( speed, easing, callback ) {
		return this.animate( props, speed, easing, callback );
	};
});

jQuery.timers = [];
jQuery.fx.tick = function() {
	var timer,
		i = 0,
		timers = jQuery.timers;

	fxNow = jQuery.now();

	for ( ; i < timers.length; i++ ) {
		timer = timers[ i ];
		// Checks the timer has not already been removed
		if ( !timer() && timers[ i ] === timer ) {
			timers.splice( i--, 1 );
		}
	}

	if ( !timers.length ) {
		jQuery.fx.stop();
	}
	fxNow = undefined;
};

jQuery.fx.timer = function( timer ) {
	jQuery.timers.push( timer );
	if ( timer() ) {
		jQuery.fx.start();
	} else {
		jQuery.timers.pop();
	}
};

jQuery.fx.interval = 13;

jQuery.fx.start = function() {
	if ( !timerId ) {
		timerId = setInterval( jQuery.fx.tick, jQuery.fx.interval );
	}
};

jQuery.fx.stop = function() {
	clearInterval( timerId );
	timerId = null;
};

jQuery.fx.speeds = {
	slow: 600,
	fast: 200,
	// Default speed
	_default: 400
};


// Based off of the plugin by Clint Helfers, with permission.
// http://blindsignals.com/index.php/2009/07/jquery-delay/
jQuery.fn.delay = function( time, type ) {
	time = jQuery.fx ? jQuery.fx.speeds[ time ] || time : time;
	type = type || "fx";

	return this.queue( type, function( next, hooks ) {
		var timeout = setTimeout( next, time );
		hooks.stop = function() {
			clearTimeout( timeout );
		};
	});
};


(function() {
	var input = document.createElement( "input" ),
		select = document.createElement( "select" ),
		opt = select.appendChild( document.createElement( "option" ) );

	input.type = "checkbox";

	// Support: iOS<=5.1, Android<=4.2+
	// Default value for a checkbox should be "on"
	support.checkOn = input.value !== "";

	// Support: IE<=11+
	// Must access selectedIndex to make default options select
	support.optSelected = opt.selected;

	// Support: Android<=2.3
	// Options inside disabled selects are incorrectly marked as disabled
	select.disabled = true;
	support.optDisabled = !opt.disabled;

	// Support: IE<=11+
	// An input loses its value after becoming a radio
	input = document.createElement( "input" );
	input.value = "t";
	input.type = "radio";
	support.radioValue = input.value === "t";
})();


var nodeHook, boolHook,
	attrHandle = jQuery.expr.attrHandle;

jQuery.fn.extend({
	attr: function( name, value ) {
		return access( this, jQuery.attr, name, value, arguments.length > 1 );
	},

	removeAttr: function( name ) {
		return this.each(function() {
			jQuery.removeAttr( this, name );
		});
	}
});

jQuery.extend({
	attr: function( elem, name, value ) {
		var hooks, ret,
			nType = elem.nodeType;

		// don't get/set attributes on text, comment and attribute nodes
		if ( !elem || nType === 3 || nType === 8 || nType === 2 ) {
			return;
		}

		// Fallback to prop when attributes are not supported
		if ( typeof elem.getAttribute === strundefined ) {
			return jQuery.prop( elem, name, value );
		}

		// All attributes are lowercase
		// Grab necessary hook if one is defined
		if ( nType !== 1 || !jQuery.isXMLDoc( elem ) ) {
			name = name.toLowerCase();
			hooks = jQuery.attrHooks[ name ] ||
				( jQuery.expr.match.bool.test( name ) ? boolHook : nodeHook );
		}

		if ( value !== undefined ) {

			if ( value === null ) {
				jQuery.removeAttr( elem, name );

			} else if ( hooks && "set" in hooks && (ret = hooks.set( elem, value, name )) !== undefined ) {
				return ret;

			} else {
				elem.setAttribute( name, value + "" );
				return value;
			}

		} else if ( hooks && "get" in hooks && (ret = hooks.get( elem, name )) !== null ) {
			return ret;

		} else {
			ret = jQuery.find.attr( elem, name );

			// Non-existent attributes return null, we normalize to undefined
			return ret == null ?
				undefined :
				ret;
		}
	},

	removeAttr: function( elem, value ) {
		var name, propName,
			i = 0,
			attrNames = value && value.match( rnotwhite );

		if ( attrNames && elem.nodeType === 1 ) {
			while ( (name = attrNames[i++]) ) {
				propName = jQuery.propFix[ name ] || name;

				// Boolean attributes get special treatment (#10870)
				if ( jQuery.expr.match.bool.test( name ) ) {
					// Set corresponding property to false
					elem[ propName ] = false;
				}

				elem.removeAttribute( name );
			}
		}
	},

	attrHooks: {
		type: {
			set: function( elem, value ) {
				if ( !support.radioValue && value === "radio" &&
					jQuery.nodeName( elem, "input" ) ) {
					var val = elem.value;
					elem.setAttribute( "type", value );
					if ( val ) {
						elem.value = val;
					}
					return value;
				}
			}
		}
	}
});

// Hooks for boolean attributes
boolHook = {
	set: function( elem, value, name ) {
		if ( value === false ) {
			// Remove boolean attributes when set to false
			jQuery.removeAttr( elem, name );
		} else {
			elem.setAttribute( name, name );
		}
		return name;
	}
};
jQuery.each( jQuery.expr.match.bool.source.match( /\w+/g ), function( i, name ) {
	var getter = attrHandle[ name ] || jQuery.find.attr;

	attrHandle[ name ] = function( elem, name, isXML ) {
		var ret, handle;
		if ( !isXML ) {
			// Avoid an infinite loop by temporarily removing this function from the getter
			handle = attrHandle[ name ];
			attrHandle[ name ] = ret;
			ret = getter( elem, name, isXML ) != null ?
				name.toLowerCase() :
				null;
			attrHandle[ name ] = handle;
		}
		return ret;
	};
});




var rfocusable = /^(?:input|select|textarea|button)$/i;

jQuery.fn.extend({
	prop: function( name, value ) {
		return access( this, jQuery.prop, name, value, arguments.length > 1 );
	},

	removeProp: function( name ) {
		return this.each(function() {
			delete this[ jQuery.propFix[ name ] || name ];
		});
	}
});

jQuery.extend({
	propFix: {
		"for": "htmlFor",
		"class": "className"
	},

	prop: function( elem, name, value ) {
		var ret, hooks, notxml,
			nType = elem.nodeType;

		// Don't get/set properties on text, comment and attribute nodes
		if ( !elem || nType === 3 || nType === 8 || nType === 2 ) {
			return;
		}

		notxml = nType !== 1 || !jQuery.isXMLDoc( elem );

		if ( notxml ) {
			// Fix name and attach hooks
			name = jQuery.propFix[ name ] || name;
			hooks = jQuery.propHooks[ name ];
		}

		if ( value !== undefined ) {
			return hooks && "set" in hooks && (ret = hooks.set( elem, value, name )) !== undefined ?
				ret :
				( elem[ name ] = value );

		} else {
			return hooks && "get" in hooks && (ret = hooks.get( elem, name )) !== null ?
				ret :
				elem[ name ];
		}
	},

	propHooks: {
		tabIndex: {
			get: function( elem ) {
				return elem.hasAttribute( "tabindex" ) || rfocusable.test( elem.nodeName ) || elem.href ?
					elem.tabIndex :
					-1;
			}
		}
	}
});

if ( !support.optSelected ) {
	jQuery.propHooks.selected = {
		get: function( elem ) {
			var parent = elem.parentNode;
			if ( parent && parent.parentNode ) {
				parent.parentNode.selectedIndex;
			}
			return null;
		}
	};
}

jQuery.each([
	"tabIndex",
	"readOnly",
	"maxLength",
	"cellSpacing",
	"cellPadding",
	"rowSpan",
	"colSpan",
	"useMap",
	"frameBorder",
	"contentEditable"
], function() {
	jQuery.propFix[ this.toLowerCase() ] = this;
});




var rclass = /[\t\r\n\f]/g;

jQuery.fn.extend({
	addClass: function( value ) {
		var classes, elem, cur, clazz, j, finalValue,
			proceed = typeof value === "string" && value,
			i = 0,
			len = this.length;

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( j ) {
				jQuery( this ).addClass( value.call( this, j, this.className ) );
			});
		}

		if ( proceed ) {
			// The disjunction here is for better compressibility (see removeClass)
			classes = ( value || "" ).match( rnotwhite ) || [];

			for ( ; i < len; i++ ) {
				elem = this[ i ];
				cur = elem.nodeType === 1 && ( elem.className ?
					( " " + elem.className + " " ).replace( rclass, " " ) :
					" "
				);

				if ( cur ) {
					j = 0;
					while ( (clazz = classes[j++]) ) {
						if ( cur.indexOf( " " + clazz + " " ) < 0 ) {
							cur += clazz + " ";
						}
					}

					// only assign if different to avoid unneeded rendering.
					finalValue = jQuery.trim( cur );
					if ( elem.className !== finalValue ) {
						elem.className = finalValue;
					}
				}
			}
		}

		return this;
	},

	removeClass: function( value ) {
		var classes, elem, cur, clazz, j, finalValue,
			proceed = arguments.length === 0 || typeof value === "string" && value,
			i = 0,
			len = this.length;

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( j ) {
				jQuery( this ).removeClass( value.call( this, j, this.className ) );
			});
		}
		if ( proceed ) {
			classes = ( value || "" ).match( rnotwhite ) || [];

			for ( ; i < len; i++ ) {
				elem = this[ i ];
				// This expression is here for better compressibility (see addClass)
				cur = elem.nodeType === 1 && ( elem.className ?
					( " " + elem.className + " " ).replace( rclass, " " ) :
					""
				);

				if ( cur ) {
					j = 0;
					while ( (clazz = classes[j++]) ) {
						// Remove *all* instances
						while ( cur.indexOf( " " + clazz + " " ) >= 0 ) {
							cur = cur.replace( " " + clazz + " ", " " );
						}
					}

					// Only assign if different to avoid unneeded rendering.
					finalValue = value ? jQuery.trim( cur ) : "";
					if ( elem.className !== finalValue ) {
						elem.className = finalValue;
					}
				}
			}
		}

		return this;
	},

	toggleClass: function( value, stateVal ) {
		var type = typeof value;

		if ( typeof stateVal === "boolean" && type === "string" ) {
			return stateVal ? this.addClass( value ) : this.removeClass( value );
		}

		if ( jQuery.isFunction( value ) ) {
			return this.each(function( i ) {
				jQuery( this ).toggleClass( value.call(this, i, this.className, stateVal), stateVal );
			});
		}

		return this.each(function() {
			if ( type === "string" ) {
				// Toggle individual class names
				var className,
					i = 0,
					self = jQuery( this ),
					classNames = value.match( rnotwhite ) || [];

				while ( (className = classNames[ i++ ]) ) {
					// Check each className given, space separated list
					if ( self.hasClass( className ) ) {
						self.removeClass( className );
					} else {
						self.addClass( className );
					}
				}

			// Toggle whole class name
			} else if ( type === strundefined || type === "boolean" ) {
				if ( this.className ) {
					// store className if set
					data_priv.set( this, "__className__", this.className );
				}

				// If the element has a class name or if we're passed `false`,
				// then remove the whole classname (if there was one, the above saved it).
				// Otherwise bring back whatever was previously saved (if anything),
				// falling back to the empty string if nothing was stored.
				this.className = this.className || value === false ? "" : data_priv.get( this, "__className__" ) || "";
			}
		});
	},

	hasClass: function( selector ) {
		var className = " " + selector + " ",
			i = 0,
			l = this.length;
		for ( ; i < l; i++ ) {
			if ( this[i].nodeType === 1 && (" " + this[i].className + " ").replace(rclass, " ").indexOf( className ) >= 0 ) {
				return true;
			}
		}

		return false;
	}
});




var rreturn = /\r/g;

jQuery.fn.extend({
	val: function( value ) {
		var hooks, ret, isFunction,
			elem = this[0];

		if ( !arguments.length ) {
			if ( elem ) {
				hooks = jQuery.valHooks[ elem.type ] || jQuery.valHooks[ elem.nodeName.toLowerCase() ];

				if ( hooks && "get" in hooks && (ret = hooks.get( elem, "value" )) !== undefined ) {
					return ret;
				}

				ret = elem.value;

				return typeof ret === "string" ?
					// Handle most common string cases
					ret.replace(rreturn, "") :
					// Handle cases where value is null/undef or number
					ret == null ? "" : ret;
			}

			return;
		}

		isFunction = jQuery.isFunction( value );

		return this.each(function( i ) {
			var val;

			if ( this.nodeType !== 1 ) {
				return;
			}

			if ( isFunction ) {
				val = value.call( this, i, jQuery( this ).val() );
			} else {
				val = value;
			}

			// Treat null/undefined as ""; convert numbers to string
			if ( val == null ) {
				val = "";

			} else if ( typeof val === "number" ) {
				val += "";

			} else if ( jQuery.isArray( val ) ) {
				val = jQuery.map( val, function( value ) {
					return value == null ? "" : value + "";
				});
			}

			hooks = jQuery.valHooks[ this.type ] || jQuery.valHooks[ this.nodeName.toLowerCase() ];

			// If set returns undefined, fall back to normal setting
			if ( !hooks || !("set" in hooks) || hooks.set( this, val, "value" ) === undefined ) {
				this.value = val;
			}
		});
	}
});

jQuery.extend({
	valHooks: {
		option: {
			get: function( elem ) {
				var val = jQuery.find.attr( elem, "value" );
				return val != null ?
					val :
					// Support: IE10-11+
					// option.text throws exceptions (#14686, #14858)
					jQuery.trim( jQuery.text( elem ) );
			}
		},
		select: {
			get: function( elem ) {
				var value, option,
					options = elem.options,
					index = elem.selectedIndex,
					one = elem.type === "select-one" || index < 0,
					values = one ? null : [],
					max = one ? index + 1 : options.length,
					i = index < 0 ?
						max :
						one ? index : 0;

				// Loop through all the selected options
				for ( ; i < max; i++ ) {
					option = options[ i ];

					// IE6-9 doesn't update selected after form reset (#2551)
					if ( ( option.selected || i === index ) &&
							// Don't return options that are disabled or in a disabled optgroup
							( support.optDisabled ? !option.disabled : option.getAttribute( "disabled" ) === null ) &&
							( !option.parentNode.disabled || !jQuery.nodeName( option.parentNode, "optgroup" ) ) ) {

						// Get the specific value for the option
						value = jQuery( option ).val();

						// We don't need an array for one selects
						if ( one ) {
							return value;
						}

						// Multi-Selects return an array
						values.push( value );
					}
				}

				return values;
			},

			set: function( elem, value ) {
				var optionSet, option,
					options = elem.options,
					values = jQuery.makeArray( value ),
					i = options.length;

				while ( i-- ) {
					option = options[ i ];
					if ( (option.selected = jQuery.inArray( option.value, values ) >= 0) ) {
						optionSet = true;
					}
				}

				// Force browsers to behave consistently when non-matching value is set
				if ( !optionSet ) {
					elem.selectedIndex = -1;
				}
				return values;
			}
		}
	}
});

// Radios and checkboxes getter/setter
jQuery.each([ "radio", "checkbox" ], function() {
	jQuery.valHooks[ this ] = {
		set: function( elem, value ) {
			if ( jQuery.isArray( value ) ) {
				return ( elem.checked = jQuery.inArray( jQuery(elem).val(), value ) >= 0 );
			}
		}
	};
	if ( !support.checkOn ) {
		jQuery.valHooks[ this ].get = function( elem ) {
			return elem.getAttribute("value") === null ? "on" : elem.value;
		};
	}
});




// Return jQuery for attributes-only inclusion


jQuery.each( ("blur focus focusin focusout load resize scroll unload click dblclick " +
	"mousedown mouseup mousemove mouseover mouseout mouseenter mouseleave " +
	"change select submit keydown keypress keyup error contextmenu").split(" "), function( i, name ) {

	// Handle event binding
	jQuery.fn[ name ] = function( data, fn ) {
		return arguments.length > 0 ?
			this.on( name, null, data, fn ) :
			this.trigger( name );
	};
});

jQuery.fn.extend({
	hover: function( fnOver, fnOut ) {
		return this.mouseenter( fnOver ).mouseleave( fnOut || fnOver );
	},

	bind: function( types, data, fn ) {
		return this.on( types, null, data, fn );
	},
	unbind: function( types, fn ) {
		return this.off( types, null, fn );
	},

	delegate: function( selector, types, data, fn ) {
		return this.on( types, selector, data, fn );
	},
	undelegate: function( selector, types, fn ) {
		// ( namespace ) or ( selector, types [, fn] )
		return arguments.length === 1 ? this.off( selector, "**" ) : this.off( types, selector || "**", fn );
	}
});


var nonce = jQuery.now();

var rquery = (/\?/);



// Support: Android 2.3
// Workaround failure to string-cast null input
jQuery.parseJSON = function( data ) {
	return JSON.parse( data + "" );
};


// Cross-browser xml parsing
jQuery.parseXML = function( data ) {
	var xml, tmp;
	if ( !data || typeof data !== "string" ) {
		return null;
	}

	// Support: IE9
	try {
		tmp = new DOMParser();
		xml = tmp.parseFromString( data, "text/xml" );
	} catch ( e ) {
		xml = undefined;
	}

	if ( !xml || xml.getElementsByTagName( "parsererror" ).length ) {
		jQuery.error( "Invalid XML: " + data );
	}
	return xml;
};


var
	rhash = /#.*$/,
	rts = /([?&])_=[^&]*/,
	rheaders = /^(.*?):[ \t]*([^\r\n]*)$/mg,
	// #7653, #8125, #8152: local protocol detection
	rlocalProtocol = /^(?:about|app|app-storage|.+-extension|file|res|widget):$/,
	rnoContent = /^(?:GET|HEAD)$/,
	rprotocol = /^\/\//,
	rurl = /^([\w.+-]+:)(?:\/\/(?:[^\/?#]*@|)([^\/?#:]*)(?::(\d+)|)|)/,

	/* Prefilters
	 * 1) They are useful to introduce custom dataTypes (see ajax/jsonp.js for an example)
	 * 2) These are called:
	 *    - BEFORE asking for a transport
	 *    - AFTER param serialization (s.data is a string if s.processData is true)
	 * 3) key is the dataType
	 * 4) the catchall symbol "*" can be used
	 * 5) execution will start with transport dataType and THEN continue down to "*" if needed
	 */
	prefilters = {},

	/* Transports bindings
	 * 1) key is the dataType
	 * 2) the catchall symbol "*" can be used
	 * 3) selection will start with transport dataType and THEN go to "*" if needed
	 */
	transports = {},

	// Avoid comment-prolog char sequence (#10098); must appease lint and evade compression
	allTypes = "*/".concat( "*" ),

	// Document location
	ajaxLocation = window.location.href,

	// Segment location into parts
	ajaxLocParts = rurl.exec( ajaxLocation.toLowerCase() ) || [];

// Base "constructor" for jQuery.ajaxPrefilter and jQuery.ajaxTransport
function addToPrefiltersOrTransports( structure ) {

	// dataTypeExpression is optional and defaults to "*"
	return function( dataTypeExpression, func ) {

		if ( typeof dataTypeExpression !== "string" ) {
			func = dataTypeExpression;
			dataTypeExpression = "*";
		}

		var dataType,
			i = 0,
			dataTypes = dataTypeExpression.toLowerCase().match( rnotwhite ) || [];

		if ( jQuery.isFunction( func ) ) {
			// For each dataType in the dataTypeExpression
			while ( (dataType = dataTypes[i++]) ) {
				// Prepend if requested
				if ( dataType[0] === "+" ) {
					dataType = dataType.slice( 1 ) || "*";
					(structure[ dataType ] = structure[ dataType ] || []).unshift( func );

				// Otherwise append
				} else {
					(structure[ dataType ] = structure[ dataType ] || []).push( func );
				}
			}
		}
	};
}

// Base inspection function for prefilters and transports
function inspectPrefiltersOrTransports( structure, options, originalOptions, jqXHR ) {

	var inspected = {},
		seekingTransport = ( structure === transports );

	function inspect( dataType ) {
		var selected;
		inspected[ dataType ] = true;
		jQuery.each( structure[ dataType ] || [], function( _, prefilterOrFactory ) {
			var dataTypeOrTransport = prefilterOrFactory( options, originalOptions, jqXHR );
			if ( typeof dataTypeOrTransport === "string" && !seekingTransport && !inspected[ dataTypeOrTransport ] ) {
				options.dataTypes.unshift( dataTypeOrTransport );
				inspect( dataTypeOrTransport );
				return false;
			} else if ( seekingTransport ) {
				return !( selected = dataTypeOrTransport );
			}
		});
		return selected;
	}

	return inspect( options.dataTypes[ 0 ] ) || !inspected[ "*" ] && inspect( "*" );
}

// A special extend for ajax options
// that takes "flat" options (not to be deep extended)
// Fixes #9887
function ajaxExtend( target, src ) {
	var key, deep,
		flatOptions = jQuery.ajaxSettings.flatOptions || {};

	for ( key in src ) {
		if ( src[ key ] !== undefined ) {
			( flatOptions[ key ] ? target : ( deep || (deep = {}) ) )[ key ] = src[ key ];
		}
	}
	if ( deep ) {
		jQuery.extend( true, target, deep );
	}

	return target;
}

/* Handles responses to an ajax request:
 * - finds the right dataType (mediates between content-type and expected dataType)
 * - returns the corresponding response
 */
function ajaxHandleResponses( s, jqXHR, responses ) {

	var ct, type, finalDataType, firstDataType,
		contents = s.contents,
		dataTypes = s.dataTypes;

	// Remove auto dataType and get content-type in the process
	while ( dataTypes[ 0 ] === "*" ) {
		dataTypes.shift();
		if ( ct === undefined ) {
			ct = s.mimeType || jqXHR.getResponseHeader("Content-Type");
		}
	}

	// Check if we're dealing with a known content-type
	if ( ct ) {
		for ( type in contents ) {
			if ( contents[ type ] && contents[ type ].test( ct ) ) {
				dataTypes.unshift( type );
				break;
			}
		}
	}

	// Check to see if we have a response for the expected dataType
	if ( dataTypes[ 0 ] in responses ) {
		finalDataType = dataTypes[ 0 ];
	} else {
		// Try convertible dataTypes
		for ( type in responses ) {
			if ( !dataTypes[ 0 ] || s.converters[ type + " " + dataTypes[0] ] ) {
				finalDataType = type;
				break;
			}
			if ( !firstDataType ) {
				firstDataType = type;
			}
		}
		// Or just use first one
		finalDataType = finalDataType || firstDataType;
	}

	// If we found a dataType
	// We add the dataType to the list if needed
	// and return the corresponding response
	if ( finalDataType ) {
		if ( finalDataType !== dataTypes[ 0 ] ) {
			dataTypes.unshift( finalDataType );
		}
		return responses[ finalDataType ];
	}
}

/* Chain conversions given the request and the original response
 * Also sets the responseXXX fields on the jqXHR instance
 */
function ajaxConvert( s, response, jqXHR, isSuccess ) {
	var conv2, current, conv, tmp, prev,
		converters = {},
		// Work with a copy of dataTypes in case we need to modify it for conversion
		dataTypes = s.dataTypes.slice();

	// Create converters map with lowercased keys
	if ( dataTypes[ 1 ] ) {
		for ( conv in s.converters ) {
			converters[ conv.toLowerCase() ] = s.converters[ conv ];
		}
	}

	current = dataTypes.shift();

	// Convert to each sequential dataType
	while ( current ) {

		if ( s.responseFields[ current ] ) {
			jqXHR[ s.responseFields[ current ] ] = response;
		}

		// Apply the dataFilter if provided
		if ( !prev && isSuccess && s.dataFilter ) {
			response = s.dataFilter( response, s.dataType );
		}

		prev = current;
		current = dataTypes.shift();

		if ( current ) {

		// There's only work to do if current dataType is non-auto
			if ( current === "*" ) {

				current = prev;

			// Convert response if prev dataType is non-auto and differs from current
			} else if ( prev !== "*" && prev !== current ) {

				// Seek a direct converter
				conv = converters[ prev + " " + current ] || converters[ "* " + current ];

				// If none found, seek a pair
				if ( !conv ) {
					for ( conv2 in converters ) {

						// If conv2 outputs current
						tmp = conv2.split( " " );
						if ( tmp[ 1 ] === current ) {

							// If prev can be converted to accepted input
							conv = converters[ prev + " " + tmp[ 0 ] ] ||
								converters[ "* " + tmp[ 0 ] ];
							if ( conv ) {
								// Condense equivalence converters
								if ( conv === true ) {
									conv = converters[ conv2 ];

								// Otherwise, insert the intermediate dataType
								} else if ( converters[ conv2 ] !== true ) {
									current = tmp[ 0 ];
									dataTypes.unshift( tmp[ 1 ] );
								}
								break;
							}
						}
					}
				}

				// Apply converter (if not an equivalence)
				if ( conv !== true ) {

					// Unless errors are allowed to bubble, catch and return them
					if ( conv && s[ "throws" ] ) {
						response = conv( response );
					} else {
						try {
							response = conv( response );
						} catch ( e ) {
							return { state: "parsererror", error: conv ? e : "No conversion from " + prev + " to " + current };
						}
					}
				}
			}
		}
	}

	return { state: "success", data: response };
}

jQuery.extend({

	// Counter for holding the number of active queries
	active: 0,

	// Last-Modified header cache for next request
	lastModified: {},
	etag: {},

	ajaxSettings: {
		url: ajaxLocation,
		type: "GET",
		isLocal: rlocalProtocol.test( ajaxLocParts[ 1 ] ),
		global: true,
		processData: true,
		async: true,
		contentType: "application/x-www-form-urlencoded; charset=UTF-8",
		/*
		timeout: 0,
		data: null,
		dataType: null,
		username: null,
		password: null,
		cache: null,
		throws: false,
		traditional: false,
		headers: {},
		*/

		accepts: {
			"*": allTypes,
			text: "text/plain",
			html: "text/html",
			xml: "application/xml, text/xml",
			json: "application/json, text/javascript"
		},

		contents: {
			xml: /xml/,
			html: /html/,
			json: /json/
		},

		responseFields: {
			xml: "responseXML",
			text: "responseText",
			json: "responseJSON"
		},

		// Data converters
		// Keys separate source (or catchall "*") and destination types with a single space
		converters: {

			// Convert anything to text
			"* text": String,

			// Text to html (true = no transformation)
			"text html": true,

			// Evaluate text as a json expression
			"text json": jQuery.parseJSON,

			// Parse text as xml
			"text xml": jQuery.parseXML
		},

		// For options that shouldn't be deep extended:
		// you can add your own custom options here if
		// and when you create one that shouldn't be
		// deep extended (see ajaxExtend)
		flatOptions: {
			url: true,
			context: true
		}
	},

	// Creates a full fledged settings object into target
	// with both ajaxSettings and settings fields.
	// If target is omitted, writes into ajaxSettings.
	ajaxSetup: function( target, settings ) {
		return settings ?

			// Building a settings object
			ajaxExtend( ajaxExtend( target, jQuery.ajaxSettings ), settings ) :

			// Extending ajaxSettings
			ajaxExtend( jQuery.ajaxSettings, target );
	},

	ajaxPrefilter: addToPrefiltersOrTransports( prefilters ),
	ajaxTransport: addToPrefiltersOrTransports( transports ),

	// Main method
	ajax: function( url, options ) {

		// If url is an object, simulate pre-1.5 signature
		if ( typeof url === "object" ) {
			options = url;
			url = undefined;
		}

		// Force options to be an object
		options = options || {};

		var transport,
			// URL without anti-cache param
			cacheURL,
			// Response headers
			responseHeadersString,
			responseHeaders,
			// timeout handle
			timeoutTimer,
			// Cross-domain detection vars
			parts,
			// To know if global events are to be dispatched
			fireGlobals,
			// Loop variable
			i,
			// Create the final options object
			s = jQuery.ajaxSetup( {}, options ),
			// Callbacks context
			callbackContext = s.context || s,
			// Context for global events is callbackContext if it is a DOM node or jQuery collection
			globalEventContext = s.context && ( callbackContext.nodeType || callbackContext.jquery ) ?
				jQuery( callbackContext ) :
				jQuery.event,
			// Deferreds
			deferred = jQuery.Deferred(),
			completeDeferred = jQuery.Callbacks("once memory"),
			// Status-dependent callbacks
			statusCode = s.statusCode || {},
			// Headers (they are sent all at once)
			requestHeaders = {},
			requestHeadersNames = {},
			// The jqXHR state
			state = 0,
			// Default abort message
			strAbort = "canceled",
			// Fake xhr
			jqXHR = {
				readyState: 0,

				// Builds headers hashtable if needed
				getResponseHeader: function( key ) {
					var match;
					if ( state === 2 ) {
						if ( !responseHeaders ) {
							responseHeaders = {};
							while ( (match = rheaders.exec( responseHeadersString )) ) {
								responseHeaders[ match[1].toLowerCase() ] = match[ 2 ];
							}
						}
						match = responseHeaders[ key.toLowerCase() ];
					}
					return match == null ? null : match;
				},

				// Raw string
				getAllResponseHeaders: function() {
					return state === 2 ? responseHeadersString : null;
				},

				// Caches the header
				setRequestHeader: function( name, value ) {
					var lname = name.toLowerCase();
					if ( !state ) {
						name = requestHeadersNames[ lname ] = requestHeadersNames[ lname ] || name;
						requestHeaders[ name ] = value;
					}
					return this;
				},

				// Overrides response content-type header
				overrideMimeType: function( type ) {
					if ( !state ) {
						s.mimeType = type;
					}
					return this;
				},

				// Status-dependent callbacks
				statusCode: function( map ) {
					var code;
					if ( map ) {
						if ( state < 2 ) {
							for ( code in map ) {
								// Lazy-add the new callback in a way that preserves old ones
								statusCode[ code ] = [ statusCode[ code ], map[ code ] ];
							}
						} else {
							// Execute the appropriate callbacks
							jqXHR.always( map[ jqXHR.status ] );
						}
					}
					return this;
				},

				// Cancel the request
				abort: function( statusText ) {
					var finalText = statusText || strAbort;
					if ( transport ) {
						transport.abort( finalText );
					}
					done( 0, finalText );
					return this;
				}
			};

		// Attach deferreds
		deferred.promise( jqXHR ).complete = completeDeferred.add;
		jqXHR.success = jqXHR.done;
		jqXHR.error = jqXHR.fail;

		// Remove hash character (#7531: and string promotion)
		// Add protocol if not provided (prefilters might expect it)
		// Handle falsy url in the settings object (#10093: consistency with old signature)
		// We also use the url parameter if available
		s.url = ( ( url || s.url || ajaxLocation ) + "" ).replace( rhash, "" )
			.replace( rprotocol, ajaxLocParts[ 1 ] + "//" );

		// Alias method option to type as per ticket #12004
		s.type = options.method || options.type || s.method || s.type;

		// Extract dataTypes list
		s.dataTypes = jQuery.trim( s.dataType || "*" ).toLowerCase().match( rnotwhite ) || [ "" ];

		// A cross-domain request is in order when we have a protocol:host:port mismatch
		if ( s.crossDomain == null ) {
			parts = rurl.exec( s.url.toLowerCase() );
			s.crossDomain = !!( parts &&
				( parts[ 1 ] !== ajaxLocParts[ 1 ] || parts[ 2 ] !== ajaxLocParts[ 2 ] ||
					( parts[ 3 ] || ( parts[ 1 ] === "http:" ? "80" : "443" ) ) !==
						( ajaxLocParts[ 3 ] || ( ajaxLocParts[ 1 ] === "http:" ? "80" : "443" ) ) )
			);
		}

		// Convert data if not already a string
		if ( s.data && s.processData && typeof s.data !== "string" ) {
			s.data = jQuery.param( s.data, s.traditional );
		}

		// Apply prefilters
		inspectPrefiltersOrTransports( prefilters, s, options, jqXHR );

		// If request was aborted inside a prefilter, stop there
		if ( state === 2 ) {
			return jqXHR;
		}

		// We can fire global events as of now if asked to
		// Don't fire events if jQuery.event is undefined in an AMD-usage scenario (#15118)
		fireGlobals = jQuery.event && s.global;

		// Watch for a new set of requests
		if ( fireGlobals && jQuery.active++ === 0 ) {
			jQuery.event.trigger("ajaxStart");
		}

		// Uppercase the type
		s.type = s.type.toUpperCase();

		// Determine if request has content
		s.hasContent = !rnoContent.test( s.type );

		// Save the URL in case we're toying with the If-Modified-Since
		// and/or If-None-Match header later on
		cacheURL = s.url;

		// More options handling for requests with no content
		if ( !s.hasContent ) {

			// If data is available, append data to url
			if ( s.data ) {
				cacheURL = ( s.url += ( rquery.test( cacheURL ) ? "&" : "?" ) + s.data );
				// #9682: remove data so that it's not used in an eventual retry
				delete s.data;
			}

			// Add anti-cache in url if needed
			if ( s.cache === false ) {
				s.url = rts.test( cacheURL ) ?

					// If there is already a '_' parameter, set its value
					cacheURL.replace( rts, "$1_=" + nonce++ ) :

					// Otherwise add one to the end
					cacheURL + ( rquery.test( cacheURL ) ? "&" : "?" ) + "_=" + nonce++;
			}
		}

		// Set the If-Modified-Since and/or If-None-Match header, if in ifModified mode.
		if ( s.ifModified ) {
			if ( jQuery.lastModified[ cacheURL ] ) {
				jqXHR.setRequestHeader( "If-Modified-Since", jQuery.lastModified[ cacheURL ] );
			}
			if ( jQuery.etag[ cacheURL ] ) {
				jqXHR.setRequestHeader( "If-None-Match", jQuery.etag[ cacheURL ] );
			}
		}

		// Set the correct header, if data is being sent
		if ( s.data && s.hasContent && s.contentType !== false || options.contentType ) {
			jqXHR.setRequestHeader( "Content-Type", s.contentType );
		}

		// Set the Accepts header for the server, depending on the dataType
		jqXHR.setRequestHeader(
			"Accept",
			s.dataTypes[ 0 ] && s.accepts[ s.dataTypes[0] ] ?
				s.accepts[ s.dataTypes[0] ] + ( s.dataTypes[ 0 ] !== "*" ? ", " + allTypes + "; q=0.01" : "" ) :
				s.accepts[ "*" ]
		);

		// Check for headers option
		for ( i in s.headers ) {
			jqXHR.setRequestHeader( i, s.headers[ i ] );
		}

		// Allow custom headers/mimetypes and early abort
		if ( s.beforeSend && ( s.beforeSend.call( callbackContext, jqXHR, s ) === false || state === 2 ) ) {
			// Abort if not done already and return
			return jqXHR.abort();
		}

		// Aborting is no longer a cancellation
		strAbort = "abort";

		// Install callbacks on deferreds
		for ( i in { success: 1, error: 1, complete: 1 } ) {
			jqXHR[ i ]( s[ i ] );
		}

		// Get transport
		transport = inspectPrefiltersOrTransports( transports, s, options, jqXHR );

		// If no transport, we auto-abort
		if ( !transport ) {
			done( -1, "No Transport" );
		} else {
			jqXHR.readyState = 1;

			// Send global event
			if ( fireGlobals ) {
				globalEventContext.trigger( "ajaxSend", [ jqXHR, s ] );
			}
			// Timeout
			if ( s.async && s.timeout > 0 ) {
				timeoutTimer = setTimeout(function() {
					jqXHR.abort("timeout");
				}, s.timeout );
			}

			try {
				state = 1;
				transport.send( requestHeaders, done );
			} catch ( e ) {
				// Propagate exception as error if not done
				if ( state < 2 ) {
					done( -1, e );
				// Simply rethrow otherwise
				} else {
					throw e;
				}
			}
		}

		// Callback for when everything is done
		function done( status, nativeStatusText, responses, headers ) {
			var isSuccess, success, error, response, modified,
				statusText = nativeStatusText;

			// Called once
			if ( state === 2 ) {
				return;
			}

			// State is "done" now
			state = 2;

			// Clear timeout if it exists
			if ( timeoutTimer ) {
				clearTimeout( timeoutTimer );
			}

			// Dereference transport for early garbage collection
			// (no matter how long the jqXHR object will be used)
			transport = undefined;

			// Cache response headers
			responseHeadersString = headers || "";

			// Set readyState
			jqXHR.readyState = status > 0 ? 4 : 0;

			// Determine if successful
			isSuccess = status >= 200 && status < 300 || status === 304;

			// Get response data
			if ( responses ) {
				response = ajaxHandleResponses( s, jqXHR, responses );
			}

			// Convert no matter what (that way responseXXX fields are always set)
			response = ajaxConvert( s, response, jqXHR, isSuccess );

			// If successful, handle type chaining
			if ( isSuccess ) {

				// Set the If-Modified-Since and/or If-None-Match header, if in ifModified mode.
				if ( s.ifModified ) {
					modified = jqXHR.getResponseHeader("Last-Modified");
					if ( modified ) {
						jQuery.lastModified[ cacheURL ] = modified;
					}
					modified = jqXHR.getResponseHeader("etag");
					if ( modified ) {
						jQuery.etag[ cacheURL ] = modified;
					}
				}

				// if no content
				if ( status === 204 || s.type === "HEAD" ) {
					statusText = "nocontent";

				// if not modified
				} else if ( status === 304 ) {
					statusText = "notmodified";

				// If we have data, let's convert it
				} else {
					statusText = response.state;
					success = response.data;
					error = response.error;
					isSuccess = !error;
				}
			} else {
				// Extract error from statusText and normalize for non-aborts
				error = statusText;
				if ( status || !statusText ) {
					statusText = "error";
					if ( status < 0 ) {
						status = 0;
					}
				}
			}

			// Set data for the fake xhr object
			jqXHR.status = status;
			jqXHR.statusText = ( nativeStatusText || statusText ) + "";

			// Success/Error
			if ( isSuccess ) {
				deferred.resolveWith( callbackContext, [ success, statusText, jqXHR ] );
			} else {
				deferred.rejectWith( callbackContext, [ jqXHR, statusText, error ] );
			}

			// Status-dependent callbacks
			jqXHR.statusCode( statusCode );
			statusCode = undefined;

			if ( fireGlobals ) {
				globalEventContext.trigger( isSuccess ? "ajaxSuccess" : "ajaxError",
					[ jqXHR, s, isSuccess ? success : error ] );
			}

			// Complete
			completeDeferred.fireWith( callbackContext, [ jqXHR, statusText ] );

			if ( fireGlobals ) {
				globalEventContext.trigger( "ajaxComplete", [ jqXHR, s ] );
				// Handle the global AJAX counter
				if ( !( --jQuery.active ) ) {
					jQuery.event.trigger("ajaxStop");
				}
			}
		}

		return jqXHR;
	},

	getJSON: function( url, data, callback ) {
		return jQuery.get( url, data, callback, "json" );
	},

	getScript: function( url, callback ) {
		return jQuery.get( url, undefined, callback, "script" );
	}
});

jQuery.each( [ "get", "post" ], function( i, method ) {
	jQuery[ method ] = function( url, data, callback, type ) {
		// Shift arguments if data argument was omitted
		if ( jQuery.isFunction( data ) ) {
			type = type || callback;
			callback = data;
			data = undefined;
		}

		return jQuery.ajax({
			url: url,
			type: method,
			dataType: type,
			data: data,
			success: callback
		});
	};
});


jQuery._evalUrl = function( url ) {
	return jQuery.ajax({
		url: url,
		type: "GET",
		dataType: "script",
		async: false,
		global: false,
		"throws": true
	});
};


jQuery.fn.extend({
	wrapAll: function( html ) {
		var wrap;

		if ( jQuery.isFunction( html ) ) {
			return this.each(function( i ) {
				jQuery( this ).wrapAll( html.call(this, i) );
			});
		}

		if ( this[ 0 ] ) {

			// The elements to wrap the target around
			wrap = jQuery( html, this[ 0 ].ownerDocument ).eq( 0 ).clone( true );

			if ( this[ 0 ].parentNode ) {
				wrap.insertBefore( this[ 0 ] );
			}

			wrap.map(function() {
				var elem = this;

				while ( elem.firstElementChild ) {
					elem = elem.firstElementChild;
				}

				return elem;
			}).append( this );
		}

		return this;
	},

	wrapInner: function( html ) {
		if ( jQuery.isFunction( html ) ) {
			return this.each(function( i ) {
				jQuery( this ).wrapInner( html.call(this, i) );
			});
		}

		return this.each(function() {
			var self = jQuery( this ),
				contents = self.contents();

			if ( contents.length ) {
				contents.wrapAll( html );

			} else {
				self.append( html );
			}
		});
	},

	wrap: function( html ) {
		var isFunction = jQuery.isFunction( html );

		return this.each(function( i ) {
			jQuery( this ).wrapAll( isFunction ? html.call(this, i) : html );
		});
	},

	unwrap: function() {
		return this.parent().each(function() {
			if ( !jQuery.nodeName( this, "body" ) ) {
				jQuery( this ).replaceWith( this.childNodes );
			}
		}).end();
	}
});


jQuery.expr.filters.hidden = function( elem ) {
	// Support: Opera <= 12.12
	// Opera reports offsetWidths and offsetHeights less than zero on some elements
	return elem.offsetWidth <= 0 && elem.offsetHeight <= 0;
};
jQuery.expr.filters.visible = function( elem ) {
	return !jQuery.expr.filters.hidden( elem );
};




var r20 = /%20/g,
	rbracket = /\[\]$/,
	rCRLF = /\r?\n/g,
	rsubmitterTypes = /^(?:submit|button|image|reset|file)$/i,
	rsubmittable = /^(?:input|select|textarea|keygen)/i;

function buildParams( prefix, obj, traditional, add ) {
	var name;

	if ( jQuery.isArray( obj ) ) {
		// Serialize array item.
		jQuery.each( obj, function( i, v ) {
			if ( traditional || rbracket.test( prefix ) ) {
				// Treat each array item as a scalar.
				add( prefix, v );

			} else {
				// Item is non-scalar (array or object), encode its numeric index.
				buildParams( prefix + "[" + ( typeof v === "object" ? i : "" ) + "]", v, traditional, add );
			}
		});

	} else if ( !traditional && jQuery.type( obj ) === "object" ) {
		// Serialize object item.
		for ( name in obj ) {
			buildParams( prefix + "[" + name + "]", obj[ name ], traditional, add );
		}

	} else {
		// Serialize scalar item.
		add( prefix, obj );
	}
}

// Serialize an array of form elements or a set of
// key/values into a query string
jQuery.param = function( a, traditional ) {
	var prefix,
		s = [],
		add = function( key, value ) {
			// If value is a function, invoke it and return its value
			value = jQuery.isFunction( value ) ? value() : ( value == null ? "" : value );
			s[ s.length ] = encodeURIComponent( key ) + "=" + encodeURIComponent( value );
		};

	// Set traditional to true for jQuery <= 1.3.2 behavior.
	if ( traditional === undefined ) {
		traditional = jQuery.ajaxSettings && jQuery.ajaxSettings.traditional;
	}

	// If an array was passed in, assume that it is an array of form elements.
	if ( jQuery.isArray( a ) || ( a.jquery && !jQuery.isPlainObject( a ) ) ) {
		// Serialize the form elements
		jQuery.each( a, function() {
			add( this.name, this.value );
		});

	} else {
		// If traditional, encode the "old" way (the way 1.3.2 or older
		// did it), otherwise encode params recursively.
		for ( prefix in a ) {
			buildParams( prefix, a[ prefix ], traditional, add );
		}
	}

	// Return the resulting serialization
	return s.join( "&" ).replace( r20, "+" );
};

jQuery.fn.extend({
	serialize: function() {
		return jQuery.param( this.serializeArray() );
	},
	serializeArray: function() {
		return this.map(function() {
			// Can add propHook for "elements" to filter or add form elements
			var elements = jQuery.prop( this, "elements" );
			return elements ? jQuery.makeArray( elements ) : this;
		})
		.filter(function() {
			var type = this.type;

			// Use .is( ":disabled" ) so that fieldset[disabled] works
			return this.name && !jQuery( this ).is( ":disabled" ) &&
				rsubmittable.test( this.nodeName ) && !rsubmitterTypes.test( type ) &&
				( this.checked || !rcheckableType.test( type ) );
		})
		.map(function( i, elem ) {
			var val = jQuery( this ).val();

			return val == null ?
				null :
				jQuery.isArray( val ) ?
					jQuery.map( val, function( val ) {
						return { name: elem.name, value: val.replace( rCRLF, "\r\n" ) };
					}) :
					{ name: elem.name, value: val.replace( rCRLF, "\r\n" ) };
		}).get();
	}
});


jQuery.ajaxSettings.xhr = function() {
	try {
		return new XMLHttpRequest();
	} catch( e ) {}
};

var xhrId = 0,
	xhrCallbacks = {},
	xhrSuccessStatus = {
		// file protocol always yields status code 0, assume 200
		0: 200,
		// Support: IE9
		// #1450: sometimes IE returns 1223 when it should be 204
		1223: 204
	},
	xhrSupported = jQuery.ajaxSettings.xhr();

// Support: IE9
// Open requests must be manually aborted on unload (#5280)
// See https://support.microsoft.com/kb/2856746 for more info
if ( window.attachEvent ) {
	window.attachEvent( "onunload", function() {
		for ( var key in xhrCallbacks ) {
			xhrCallbacks[ key ]();
		}
	});
}

support.cors = !!xhrSupported && ( "withCredentials" in xhrSupported );
support.ajax = xhrSupported = !!xhrSupported;

jQuery.ajaxTransport(function( options ) {
	var callback;

	// Cross domain only allowed if supported through XMLHttpRequest
	if ( support.cors || xhrSupported && !options.crossDomain ) {
		return {
			send: function( headers, complete ) {
				var i,
					xhr = options.xhr(),
					id = ++xhrId;

				xhr.open( options.type, options.url, options.async, options.username, options.password );

				// Apply custom fields if provided
				if ( options.xhrFields ) {
					for ( i in options.xhrFields ) {
						xhr[ i ] = options.xhrFields[ i ];
					}
				}

				// Override mime type if needed
				if ( options.mimeType && xhr.overrideMimeType ) {
					xhr.overrideMimeType( options.mimeType );
				}

				// X-Requested-With header
				// For cross-domain requests, seeing as conditions for a preflight are
				// akin to a jigsaw puzzle, we simply never set it to be sure.
				// (it can always be set on a per-request basis or even using ajaxSetup)
				// For same-domain requests, won't change header if already provided.
				if ( !options.crossDomain && !headers["X-Requested-With"] ) {
					headers["X-Requested-With"] = "XMLHttpRequest";
				}

				// Set headers
				for ( i in headers ) {
					xhr.setRequestHeader( i, headers[ i ] );
				}

				// Callback
				callback = function( type ) {
					return function() {
						if ( callback ) {
							delete xhrCallbacks[ id ];
							callback = xhr.onload = xhr.onerror = null;

							if ( type === "abort" ) {
								xhr.abort();
							} else if ( type === "error" ) {
								complete(
									// file: protocol always yields status 0; see #8605, #14207
									xhr.status,
									xhr.statusText
								);
							} else {
								complete(
									xhrSuccessStatus[ xhr.status ] || xhr.status,
									xhr.statusText,
									// Support: IE9
									// Accessing binary-data responseText throws an exception
									// (#11426)
									typeof xhr.responseText === "string" ? {
										text: xhr.responseText
									} : undefined,
									xhr.getAllResponseHeaders()
								);
							}
						}
					};
				};

				// Listen to events
				xhr.onload = callback();
				xhr.onerror = callback("error");

				// Create the abort callback
				callback = xhrCallbacks[ id ] = callback("abort");

				try {
					// Do send the request (this may raise an exception)
					xhr.send( options.hasContent && options.data || null );
				} catch ( e ) {
					// #14683: Only rethrow if this hasn't been notified as an error yet
					if ( callback ) {
						throw e;
					}
				}
			},

			abort: function() {
				if ( callback ) {
					callback();
				}
			}
		};
	}
});




// Install script dataType
jQuery.ajaxSetup({
	accepts: {
		script: "text/javascript, application/javascript, application/ecmascript, application/x-ecmascript"
	},
	contents: {
		script: /(?:java|ecma)script/
	},
	converters: {
		"text script": function( text ) {
			jQuery.globalEval( text );
			return text;
		}
	}
});

// Handle cache's special case and crossDomain
jQuery.ajaxPrefilter( "script", function( s ) {
	if ( s.cache === undefined ) {
		s.cache = false;
	}
	if ( s.crossDomain ) {
		s.type = "GET";
	}
});

// Bind script tag hack transport
jQuery.ajaxTransport( "script", function( s ) {
	// This transport only deals with cross domain requests
	if ( s.crossDomain ) {
		var script, callback;
		return {
			send: function( _, complete ) {
				script = jQuery("<script>").prop({
					async: true,
					charset: s.scriptCharset,
					src: s.url
				}).on(
					"load error",
					callback = function( evt ) {
						script.remove();
						callback = null;
						if ( evt ) {
							complete( evt.type === "error" ? 404 : 200, evt.type );
						}
					}
				);
				document.head.appendChild( script[ 0 ] );
			},
			abort: function() {
				if ( callback ) {
					callback();
				}
			}
		};
	}
});




var oldCallbacks = [],
	rjsonp = /(=)\?(?=&|$)|\?\?/;

// Default jsonp settings
jQuery.ajaxSetup({
	jsonp: "callback",
	jsonpCallback: function() {
		var callback = oldCallbacks.pop() || ( jQuery.expando + "_" + ( nonce++ ) );
		this[ callback ] = true;
		return callback;
	}
});

// Detect, normalize options and install callbacks for jsonp requests
jQuery.ajaxPrefilter( "json jsonp", function( s, originalSettings, jqXHR ) {

	var callbackName, overwritten, responseContainer,
		jsonProp = s.jsonp !== false && ( rjsonp.test( s.url ) ?
			"url" :
			typeof s.data === "string" && !( s.contentType || "" ).indexOf("application/x-www-form-urlencoded") && rjsonp.test( s.data ) && "data"
		);

	// Handle iff the expected data type is "jsonp" or we have a parameter to set
	if ( jsonProp || s.dataTypes[ 0 ] === "jsonp" ) {

		// Get callback name, remembering preexisting value associated with it
		callbackName = s.jsonpCallback = jQuery.isFunction( s.jsonpCallback ) ?
			s.jsonpCallback() :
			s.jsonpCallback;

		// Insert callback into url or form data
		if ( jsonProp ) {
			s[ jsonProp ] = s[ jsonProp ].replace( rjsonp, "$1" + callbackName );
		} else if ( s.jsonp !== false ) {
			s.url += ( rquery.test( s.url ) ? "&" : "?" ) + s.jsonp + "=" + callbackName;
		}

		// Use data converter to retrieve json after script execution
		s.converters["script json"] = function() {
			if ( !responseContainer ) {
				jQuery.error( callbackName + " was not called" );
			}
			return responseContainer[ 0 ];
		};

		// force json dataType
		s.dataTypes[ 0 ] = "json";

		// Install callback
		overwritten = window[ callbackName ];
		window[ callbackName ] = function() {
			responseContainer = arguments;
		};

		// Clean-up function (fires after converters)
		jqXHR.always(function() {
			// Restore preexisting value
			window[ callbackName ] = overwritten;

			// Save back as free
			if ( s[ callbackName ] ) {
				// make sure that re-using the options doesn't screw things around
				s.jsonpCallback = originalSettings.jsonpCallback;

				// save the callback name for future use
				oldCallbacks.push( callbackName );
			}

			// Call if it was a function and we have a response
			if ( responseContainer && jQuery.isFunction( overwritten ) ) {
				overwritten( responseContainer[ 0 ] );
			}

			responseContainer = overwritten = undefined;
		});

		// Delegate to script
		return "script";
	}
});




// data: string of html
// context (optional): If specified, the fragment will be created in this context, defaults to document
// keepScripts (optional): If true, will include scripts passed in the html string
jQuery.parseHTML = function( data, context, keepScripts ) {
	if ( !data || typeof data !== "string" ) {
		return null;
	}
	if ( typeof context === "boolean" ) {
		keepScripts = context;
		context = false;
	}
	context = context || document;

	var parsed = rsingleTag.exec( data ),
		scripts = !keepScripts && [];

	// Single tag
	if ( parsed ) {
		return [ context.createElement( parsed[1] ) ];
	}

	parsed = jQuery.buildFragment( [ data ], context, scripts );

	if ( scripts && scripts.length ) {
		jQuery( scripts ).remove();
	}

	return jQuery.merge( [], parsed.childNodes );
};


// Keep a copy of the old load method
var _load = jQuery.fn.load;

/**
 * Load a url into a page
 */
jQuery.fn.load = function( url, params, callback ) {
	if ( typeof url !== "string" && _load ) {
		return _load.apply( this, arguments );
	}

	var selector, type, response,
		self = this,
		off = url.indexOf(" ");

	if ( off >= 0 ) {
		selector = jQuery.trim( url.slice( off ) );
		url = url.slice( 0, off );
	}

	// If it's a function
	if ( jQuery.isFunction( params ) ) {

		// We assume that it's the callback
		callback = params;
		params = undefined;

	// Otherwise, build a param string
	} else if ( params && typeof params === "object" ) {
		type = "POST";
	}

	// If we have elements to modify, make the request
	if ( self.length > 0 ) {
		jQuery.ajax({
			url: url,

			// if "type" variable is undefined, then "GET" method will be used
			type: type,
			dataType: "html",
			data: params
		}).done(function( responseText ) {

			// Save response for use in complete callback
			response = arguments;

			self.html( selector ?

				// If a selector was specified, locate the right elements in a dummy div
				// Exclude scripts to avoid IE 'Permission Denied' errors
				jQuery("<div>").append( jQuery.parseHTML( responseText ) ).find( selector ) :

				// Otherwise use the full result
				responseText );

		}).complete( callback && function( jqXHR, status ) {
			self.each( callback, response || [ jqXHR.responseText, status, jqXHR ] );
		});
	}

	return this;
};




// Attach a bunch of functions for handling common AJAX events
jQuery.each( [ "ajaxStart", "ajaxStop", "ajaxComplete", "ajaxError", "ajaxSuccess", "ajaxSend" ], function( i, type ) {
	jQuery.fn[ type ] = function( fn ) {
		return this.on( type, fn );
	};
});




jQuery.expr.filters.animated = function( elem ) {
	return jQuery.grep(jQuery.timers, function( fn ) {
		return elem === fn.elem;
	}).length;
};




var docElem = window.document.documentElement;

/**
 * Gets a window from an element
 */
function getWindow( elem ) {
	return jQuery.isWindow( elem ) ? elem : elem.nodeType === 9 && elem.defaultView;
}

jQuery.offset = {
	setOffset: function( elem, options, i ) {
		var curPosition, curLeft, curCSSTop, curTop, curOffset, curCSSLeft, calculatePosition,
			position = jQuery.css( elem, "position" ),
			curElem = jQuery( elem ),
			props = {};

		// Set position first, in-case top/left are set even on static elem
		if ( position === "static" ) {
			elem.style.position = "relative";
		}

		curOffset = curElem.offset();
		curCSSTop = jQuery.css( elem, "top" );
		curCSSLeft = jQuery.css( elem, "left" );
		calculatePosition = ( position === "absolute" || position === "fixed" ) &&
			( curCSSTop + curCSSLeft ).indexOf("auto") > -1;

		// Need to be able to calculate position if either
		// top or left is auto and position is either absolute or fixed
		if ( calculatePosition ) {
			curPosition = curElem.position();
			curTop = curPosition.top;
			curLeft = curPosition.left;

		} else {
			curTop = parseFloat( curCSSTop ) || 0;
			curLeft = parseFloat( curCSSLeft ) || 0;
		}

		if ( jQuery.isFunction( options ) ) {
			options = options.call( elem, i, curOffset );
		}

		if ( options.top != null ) {
			props.top = ( options.top - curOffset.top ) + curTop;
		}
		if ( options.left != null ) {
			props.left = ( options.left - curOffset.left ) + curLeft;
		}

		if ( "using" in options ) {
			options.using.call( elem, props );

		} else {
			curElem.css( props );
		}
	}
};

jQuery.fn.extend({
	offset: function( options ) {
		if ( arguments.length ) {
			return options === undefined ?
				this :
				this.each(function( i ) {
					jQuery.offset.setOffset( this, options, i );
				});
		}

		var docElem, win,
			elem = this[ 0 ],
			box = { top: 0, left: 0 },
			doc = elem && elem.ownerDocument;

		if ( !doc ) {
			return;
		}

		docElem = doc.documentElement;

		// Make sure it's not a disconnected DOM node
		if ( !jQuery.contains( docElem, elem ) ) {
			return box;
		}

		// Support: BlackBerry 5, iOS 3 (original iPhone)
		// If we don't have gBCR, just use 0,0 rather than error
		if ( typeof elem.getBoundingClientRect !== strundefined ) {
			box = elem.getBoundingClientRect();
		}
		win = getWindow( doc );
		return {
			top: box.top + win.pageYOffset - docElem.clientTop,
			left: box.left + win.pageXOffset - docElem.clientLeft
		};
	},

	position: function() {
		if ( !this[ 0 ] ) {
			return;
		}

		var offsetParent, offset,
			elem = this[ 0 ],
			parentOffset = { top: 0, left: 0 };

		// Fixed elements are offset from window (parentOffset = {top:0, left: 0}, because it is its only offset parent
		if ( jQuery.css( elem, "position" ) === "fixed" ) {
			// Assume getBoundingClientRect is there when computed position is fixed
			offset = elem.getBoundingClientRect();

		} else {
			// Get *real* offsetParent
			offsetParent = this.offsetParent();

			// Get correct offsets
			offset = this.offset();
			if ( !jQuery.nodeName( offsetParent[ 0 ], "html" ) ) {
				parentOffset = offsetParent.offset();
			}

			// Add offsetParent borders
			parentOffset.top += jQuery.css( offsetParent[ 0 ], "borderTopWidth", true );
			parentOffset.left += jQuery.css( offsetParent[ 0 ], "borderLeftWidth", true );
		}

		// Subtract parent offsets and element margins
		return {
			top: offset.top - parentOffset.top - jQuery.css( elem, "marginTop", true ),
			left: offset.left - parentOffset.left - jQuery.css( elem, "marginLeft", true )
		};
	},

	offsetParent: function() {
		return this.map(function() {
			var offsetParent = this.offsetParent || docElem;

			while ( offsetParent && ( !jQuery.nodeName( offsetParent, "html" ) && jQuery.css( offsetParent, "position" ) === "static" ) ) {
				offsetParent = offsetParent.offsetParent;
			}

			return offsetParent || docElem;
		});
	}
});

// Create scrollLeft and scrollTop methods
jQuery.each( { scrollLeft: "pageXOffset", scrollTop: "pageYOffset" }, function( method, prop ) {
	var top = "pageYOffset" === prop;

	jQuery.fn[ method ] = function( val ) {
		return access( this, function( elem, method, val ) {
			var win = getWindow( elem );

			if ( val === undefined ) {
				return win ? win[ prop ] : elem[ method ];
			}

			if ( win ) {
				win.scrollTo(
					!top ? val : window.pageXOffset,
					top ? val : window.pageYOffset
				);

			} else {
				elem[ method ] = val;
			}
		}, method, val, arguments.length, null );
	};
});

// Support: Safari<7+, Chrome<37+
// Add the top/left cssHooks using jQuery.fn.position
// Webkit bug: https://bugs.webkit.org/show_bug.cgi?id=29084
// Blink bug: https://code.google.com/p/chromium/issues/detail?id=229280
// getComputedStyle returns percent when specified for top/left/bottom/right;
// rather than make the css module depend on the offset module, just check for it here
jQuery.each( [ "top", "left" ], function( i, prop ) {
	jQuery.cssHooks[ prop ] = addGetHookIf( support.pixelPosition,
		function( elem, computed ) {
			if ( computed ) {
				computed = curCSS( elem, prop );
				// If curCSS returns percentage, fallback to offset
				return rnumnonpx.test( computed ) ?
					jQuery( elem ).position()[ prop ] + "px" :
					computed;
			}
		}
	);
});


// Create innerHeight, innerWidth, height, width, outerHeight and outerWidth methods
jQuery.each( { Height: "height", Width: "width" }, function( name, type ) {
	jQuery.each( { padding: "inner" + name, content: type, "": "outer" + name }, function( defaultExtra, funcName ) {
		// Margin is only for outerHeight, outerWidth
		jQuery.fn[ funcName ] = function( margin, value ) {
			var chainable = arguments.length && ( defaultExtra || typeof margin !== "boolean" ),
				extra = defaultExtra || ( margin === true || value === true ? "margin" : "border" );

			return access( this, function( elem, type, value ) {
				var doc;

				if ( jQuery.isWindow( elem ) ) {
					// As of 5/8/2012 this will yield incorrect results for Mobile Safari, but there
					// isn't a whole lot we can do. See pull request at this URL for discussion:
					// https://github.com/jquery/jquery/pull/764
					return elem.document.documentElement[ "client" + name ];
				}

				// Get document width or height
				if ( elem.nodeType === 9 ) {
					doc = elem.documentElement;

					// Either scroll[Width/Height] or offset[Width/Height] or client[Width/Height],
					// whichever is greatest
					return Math.max(
						elem.body[ "scroll" + name ], doc[ "scroll" + name ],
						elem.body[ "offset" + name ], doc[ "offset" + name ],
						doc[ "client" + name ]
					);
				}

				return value === undefined ?
					// Get width or height on the element, requesting but not forcing parseFloat
					jQuery.css( elem, type, extra ) :

					// Set width or height on the element
					jQuery.style( elem, type, value, extra );
			}, type, chainable ? margin : undefined, chainable, null );
		};
	});
});


// The number of elements contained in the matched element set
jQuery.fn.size = function() {
	return this.length;
};

jQuery.fn.andSelf = jQuery.fn.addBack;




// Register as a named AMD module, since jQuery can be concatenated with other
// files that may use define, but not via a proper concatenation script that
// understands anonymous AMD modules. A named AMD is safest and most robust
// way to register. Lowercase jquery is used because AMD module names are
// derived from file names, and jQuery is normally delivered in a lowercase
// file name. Do this after creating the global so that if an AMD module wants
// to call noConflict to hide this version of jQuery, it will work.

// Note that for maximum portability, libraries that are not jQuery should
// declare themselves as anonymous modules, and avoid setting a global if an
// AMD loader is present. jQuery is a special case. For more information, see
// https://github.com/jrburke/requirejs/wiki/Updating-existing-libraries#wiki-anon

if ( typeof define === "function" && define.amd ) {
	define( "jquery", [], function() {
		return jQuery;
	});
}




var
	// Map over jQuery in case of overwrite
	_jQuery = window.jQuery,

	// Map over the $ in case of overwrite
	_$ = window.$;

jQuery.noConflict = function( deep ) {
	if ( window.$ === jQuery ) {
		window.$ = _$;
	}

	if ( deep && window.jQuery === jQuery ) {
		window.jQuery = _jQuery;
	}

	return jQuery;
};

// Expose jQuery and $ identifiers, even in AMD
// (#7102#comment:10, https://github.com/jquery/jquery/pull/557)
// and CommonJS for browser emulators (#13566)
if ( typeof noGlobal === strundefined ) {
	window.jQuery = window.$ = jQuery;
}




return jQuery;

}));

/*! VelocityJS.org (1.0.0). (C) 2014 Julian Shapiro. MIT @license: en.wikipedia.org/wiki/MIT_License */

/*************************
   Velocity jQuery Shim
*************************/

/*! VelocityJS.org jQuery Shim (1.0.1). (C) 2014 The jQuery Foundation. MIT @license: en.wikipedia.org/wiki/MIT_License. */

/* This file contains the jQuery functions that Velocity relies on, thereby removing Velocity's dependency on a full copy of jQuery, and allowing it to work in any environment. */
/* These shimmed functions are only used if jQuery isn't present. If both this shim and jQuery are loaded, Velocity defaults to jQuery proper. */
/* Browser support: Using this shim instead of jQuery proper removes support for IE8. */

;(function (window) {
    /***************
         Setup
    ***************/

    /* If jQuery is already loaded, there's no point in loading this shim. */
    if (window.jQuery) {
        return;
    }

    /* jQuery base. */
    var $ = function (selector, context) {
        return new $.fn.init(selector, context);
    };

    /********************
       Private Methods
    ********************/

    /* jQuery */
    $.isWindow = function (obj) {
        /* jshint eqeqeq: false */
        return obj != null && obj == obj.window;
    };

    /* jQuery */
    $.type = function (obj) {
        if (obj == null) {
            return obj + "";
        }

        return typeof obj === "object" || typeof obj === "function" ?
            class2type[toString.call(obj)] || "object" :
            typeof obj;
    };

    /* jQuery */
    $.isArray = Array.isArray || function (obj) {
        return $.type(obj) === "array";
    };

    /* jQuery */
    function isArraylike (obj) {
        var length = obj.length,
            type = $.type(obj);

        if (type === "function" || $.isWindow(obj)) {
            return false;
        }

        if (obj.nodeType === 1 && length) {
            return true;
        }

        return type === "array" || length === 0 || typeof length === "number" && length > 0 && (length - 1) in obj;
    }

    /***************
       $ Methods
    ***************/

    /* jQuery: Support removed for IE<9. */
    $.isPlainObject = function (obj) {
        var key;

        if (!obj || $.type(obj) !== "object" || obj.nodeType || $.isWindow(obj)) {
            return false;
        }

        try {
            if (obj.constructor &&
                !hasOwn.call(obj, "constructor") &&
                !hasOwn.call(obj.constructor.prototype, "isPrototypeOf")) {
                return false;
            }
        } catch (e) {
            return false;
        }

        for (key in obj) {}

        return key === undefined || hasOwn.call(obj, key);
    };

    /* jQuery */
    $.each = function(obj, callback, args) {
        var value,
            i = 0,
            length = obj.length,
            isArray = isArraylike(obj);

        if (args) {
            if (isArray) {
                for (; i < length; i++) {
                    value = callback.apply(obj[i], args);

                    if (value === false) {
                        break;
                    }
                }
            } else {
                for (i in obj) {
                    value = callback.apply(obj[i], args);

                    if (value === false) {
                        break;
                    }
                }
            }

        } else {
            if (isArray) {
                for (; i < length; i++) {
                    value = callback.call(obj[i], i, obj[i]);

                    if (value === false) {
                        break;
                    }
                }
            } else {
                for (i in obj) {
                    value = callback.call(obj[i], i, obj[i]);

                    if (value === false) {
                        break;
                    }
                }
            }
        }

        return obj;
    };

    /* Custom */
    $.data = function (node, key, value) {
        /* $.getData() */
        if (value === undefined) {
            var id = node[$.expando],
                store = id && cache[id];

            if (key === undefined) {
                return store;
            } else if (store) {
                if (key in store) {
                    return store[key];
                }
            }
        /* $.setData() */
        } else if (key !== undefined) {
            var id = node[$.expando] || (node[$.expando] = ++$.uuid);

            cache[id] = cache[id] || {};
            cache[id][key] = value;

            return value;
        }
    };

    /* Custom */
    $.removeData = function (node, keys) {
        var id = node[$.expando],
            store = id && cache[id];

        if (store) {
            $.each(keys, function(_, key) {
                delete store[key];
            });
        }
    };

    /* jQuery */
    $.extend = function () {
        var src, copyIsArray, copy, name, options, clone,
            target = arguments[0] || {},
            i = 1,
            length = arguments.length,
            deep = false;

        if (typeof target === "boolean") {
            deep = target;

            target = arguments[i] || {};
            i++;
        }

        if (typeof target !== "object" && $.type(target) !== "function") {
            target = {};
        }

        if (i === length) {
            target = this;
            i--;
        }

        for (; i < length; i++) {
            if ((options = arguments[i]) != null) {
                for (name in options) {
                    src = target[name];
                    copy = options[name];

                    if (target === copy) {
                        continue;
                    }

                    if (deep && copy && ($.isPlainObject(copy) || (copyIsArray = $.isArray(copy)))) {
                        if (copyIsArray) {
                            copyIsArray = false;
                            clone = src && $.isArray(src) ? src : [];

                        } else {
                            clone = src && $.isPlainObject(src) ? src : {};
                        }

                        target[name] = $.extend(deep, clone, copy);

                    } else if (copy !== undefined) {
                        target[name] = copy;
                    }
                }
            }
        }

        return target;
    };

    /* jQuery 1.4.3 */
    $.queue = function (elem, type, data) {
        function $makeArray (arr, results) {
            var ret = results || [];

            if (arr != null) {
                if (isArraylike(Object(arr))) {
                    /* $.merge */
                    (function(first, second) {
                        var len = +second.length,
                            j = 0,
                            i = first.length;

                        while (j < len) {
                            first[i++] = second[j++];
                        }

                        if (len !== len) {
                            while (second[j] !== undefined) {
                                first[i++] = second[j++];
                            }
                        }

                        first.length = i;

                        return first;
                    })(ret, typeof arr === "string" ? [arr] : arr);
                } else {
                    [].push.call(ret, arr);
                }
            }

            return ret;
        }

        if (!elem) {
            return;
        }

        type = (type || "fx") + "queue";

        var q = $.data(elem, type);

        if (!data) {
            return q || [];
        }

        if (!q || $.isArray(data)) {
            q = $.data(elem, type, $makeArray(data));
        } else {
            q.push(data);
        }

        return q;
    };

    /* jQuery 1.4.3 */
    $.dequeue = function (elems, type) {
        /* Custom: Embed element iteration. */
        $.each(elems.nodeType ? [ elems ] : elems, function(i, elem) {
            type = type || "fx";

            var queue = $.queue(elem, type),
                fn = queue.shift();

            if (fn === "inprogress") {
                fn = queue.shift();
            }

            if (fn) {
                if (type === "fx") {
                    queue.unshift("inprogress");
                }

                fn.call(elem, function() {
                    $.dequeue(elem, type);
                });
            }
        });
    };

    /******************
       $.fn Methods
    ******************/

    /* jQuery */
    $.fn = $.prototype = {
        init: function (selector) {
            /* Just return the element wrapped inside an array; don't proceed with the actual jQuery node wrapping process. */
            if (selector.nodeType) {
                this[0] = selector;

                return this;
            } else {
                throw new Error("Not a DOM node.");
            }
        },

        offset: function () {
            /* jQuery altered code: Dropped disconnected DOM node checking. */
            var box = this[0].getBoundingClientRect ? this[0].getBoundingClientRect() : { top: 0, left: 0 };

            return {
                top: box.top + (window.pageYOffset || document.scrollTop  || 0)  - (document.clientTop  || 0),
                left: box.left + (window.pageXOffset || document.scrollLeft  || 0) - (document.clientLeft || 0)
            };
        },

        position: function () {
            /* jQuery */
            function offsetParent() {
                var offsetParent = this.offsetParent || document;

                while (offsetParent && (!offsetParent.nodeType.toLowerCase === "html" && offsetParent.style.position === "static")) {
                    offsetParent = offsetParent.offsetParent;
                }

                return offsetParent || document;
            }

            /* Zepto */
            var elem = this[0],
                offsetParent = offsetParent.apply(elem),
                offset = this.offset(),
                parentOffset = /^(?:body|html)$/i.test(offsetParent.nodeName) ? { top: 0, left: 0 } : $(offsetParent).offset()

            offset.top -= parseFloat(elem.style.marginTop) || 0;
            offset.left -= parseFloat(elem.style.marginLeft) || 0;

            if (offsetParent.style) {
                parentOffset.top += parseFloat(offsetParent.style.borderTopWidth) || 0
                parentOffset.left += parseFloat(offsetParent.style.borderLeftWidth) || 0
            }

            return {
                top: offset.top - parentOffset.top,
                left: offset.left - parentOffset.left
            };
        }
    };

    /**********************
       Private Variables
    **********************/

    /* For $.data() */
    var cache = {};
    $.expando = "velocity" + (new Date().getTime());
    $.uuid = 0;

    /* For $.queue() */
    var class2type = {},
        hasOwn = class2type.hasOwnProperty,
        toString = class2type.toString;

    var types = "Boolean Number String Function Array Date RegExp Object Error".split(" ");
    for (var i = 0; i < types.length; i++) {
        class2type["[object " + types[i] + "]"] = types[i].toLowerCase();
    }

    /* Makes $(node) possible, without having to call init. */
    $.fn.init.prototype = $.fn;

    /* Globalize Velocity onto the window, and assign its Utilities property. */
    window.Velocity = { Utilities: $ };
})(window);

/******************
    Velocity.js
******************/

;(function (factory) {
    /* CommonJS module. */
    if (typeof module === "object" && typeof module.exports === "object") {
        module.exports = factory();
    /* AMD module. */
    } else if (typeof define === "function" && define.amd) {
        define(factory);
    /* Browser globals. */
    } else {
        factory();
    }
}(function() {
return function (global, window, document, undefined) {

    /***************
        Summary
    ***************/

    /*
    - CSS: CSS stack that works independently from the rest of Velocity.
    - animate(): Core animation method that iterates over the targeted elements and queues the incoming call onto each element individually.
      - Pre-Queueing: Prepare the element for animation by instantiating its data cache and processing the call's options.
      - Queueing: The logic that runs once the call has reached its point of execution in the element's $.queue() stack.
                  Most logic is placed here to avoid risking it becoming stale (if the element's properties have changed).
      - Pushing: Consolidation of the tween data followed by its push onto the global in-progress calls container.
    - tick(): The single requestAnimationFrame loop responsible for tweening all in-progress calls.
    - completeCall(): Handles the cleanup process for each Velocity call.
    */

    /*********************
       Helper Functions
    *********************/

    /* IE detection. Gist: https://gist.github.com/julianshapiro/9098609 */
    var IE = (function() {
        if (document.documentMode) {
            return document.documentMode;
        } else {
            for (var i = 7; i > 4; i--) {
                var div = document.createElement("div");

                div.innerHTML = "<!--[if IE " + i + "]><span></span><![endif]-->";

                if (div.getElementsByTagName("span").length) {
                    div = null;

                    return i;
                }
            }
        }

        return undefined;
    })();

    /* rAF shim. Gist: https://gist.github.com/julianshapiro/9497513 */
    var rAFShim = (function() {
        var timeLast = 0;

        return window.webkitRequestAnimationFrame || window.mozRequestAnimationFrame || function(callback) {
            var timeCurrent = (new Date()).getTime(),
                timeDelta;

            /* Dynamically set delay on a per-tick basis to match 60fps. */
            /* Technique by Erik Moller. MIT license: https://gist.github.com/paulirish/1579671 */
            timeDelta = Math.max(0, 16 - (timeCurrent - timeLast));
            timeLast = timeCurrent + timeDelta;

            return setTimeout(function() { callback(timeCurrent + timeDelta); }, timeDelta);
        };
    })();

    /* Array compacting. Copyright Lo-Dash. MIT License: https://github.com/lodash/lodash/blob/master/LICENSE.txt */
    function compactSparseArray (array) {
        var index = -1,
            length = array ? array.length : 0,
            result = [];

        while (++index < length) {
            var value = array[index];

            if (value) {
                result.push(value);
            }
        }

        return result;
    }

    function sanitizeElements (elements) {
        /* Unwrap jQuery/Zepto objects. */
        if (Type.isWrapped(elements)) {
            elements = [].slice.call(elements);
        /* Wrap a single element in an array so that $.each() can iterate with the element instead of its node's children. */
        } else if (Type.isNode(elements)) {
            elements = [ elements ];
        }

        return elements;
    }

    var Type = {
        isString: function (variable) {
            return (typeof variable === "string");
        },
        isArray: Array.isArray || function (variable) {
            return Object.prototype.toString.call(variable) === "[object Array]";
        },
        isFunction: function (variable) {
            return Object.prototype.toString.call(variable) === "[object Function]";
        },
        isNode: function (variable) {
            return variable && variable.nodeType;
        },
        /* Copyright Martin Bohm. MIT License: https://gist.github.com/Tomalak/818a78a226a0738eaade */
        isNodeList: function (variable) {
            return typeof variable === "object" &&
                /^\[object (HTMLCollection|NodeList|Object)\]$/.test(Object.prototype.toString.call(variable)) &&
                variable.length !== undefined &&
                (variable.length === 0 || (typeof variable[0] === "object" && variable[0].nodeType > 0));
        },
        /* Determine if variable is a wrapped jQuery or Zepto element. */
        isWrapped: function (variable) {
            return variable && (variable.jquery || (window.Zepto && window.Zepto.zepto.isZ(variable)));
        },
        isSVG: function (variable) {
            return window.SVGElement && (variable instanceof window.SVGElement);
        },
        isEmptyObject: function (variable) {
            for (var name in variable) {
                return false;
            }

            return true;
        }
    };

    /*****************
       Dependencies
    *****************/

    var $,
        isJQuery = false;

    if (global.fn && global.fn.jquery) {
        $ = global;
        isJQuery = true;
    } else {
        $ = window.Velocity.Utilities;
    }

    if (IE <= 8 && !isJQuery) {
        throw new Error("Velocity: IE8 and below require jQuery to be loaded before Velocity.");
    } else if (IE <= 7) {
        /* Revert to jQuery's $.animate(), and lose Velocity's extra features. */
        jQuery.fn.velocity = jQuery.fn.animate;

        /* Now that $.fn.velocity is aliased, abort this Velocity declaration. */
        return;
    }

    /*****************
        Constants
    *****************/

    var DURATION_DEFAULT = 400,
        EASING_DEFAULT = "swing";

    /*************
        State
    *************/

    /* Note: The global object also doubles as a publicly-accessible data store for the purposes of unit testing. */
    /* Note: Alias the lowercase and uppercase variants of "velocity" to minimize user confusion due to the lowercase nature of the $.fn extension. */
    var Velocity = {
        /* Container for page-wide Velocity state data. */
        State: {
            /* Detect mobile devices to determine if mobileHA should be turned on. */
            isMobile: /Android|webOS|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i.test(navigator.userAgent),
            /* The mobileHA option's behavior changes on older Android devices (Gingerbread, versions 2.3.3-2.3.7). */
            isAndroid: /Android/i.test(navigator.userAgent),
            isGingerbread: /Android 2\.3\.[3-7]/i.test(navigator.userAgent),
            isChrome: window.chrome,
            isFirefox: /Firefox/i.test(navigator.userAgent),
            /* Create a cached element for re-use when checking for CSS property prefixes. */
            prefixElement: document.createElement("div"),
            /* Cache every prefix match to avoid repeating lookups. */
            prefixMatches: {},
            /* Cache the anchor used for animating window scrolling. */
            scrollAnchor: null,
            /* Cache the property names associated with the scroll anchor. */
            scrollPropertyLeft: null,
            scrollPropertyTop: null,
            /* Keep track of whether our RAF tick is running. */
            isTicking: false,
            /* Container for every in-progress call to Velocity. */
            calls: []
        },
        /* Velocity's custom CSS stack. Made global for unit testing. */
        CSS: { /* Defined below. */ },
        /* Defined by Velocity's optional jQuery shim. */
        Utilities: $,
        /* Container for the user's custom animation redirects that are referenced by name in place of a properties map object. */
        Redirects: { /* Manually registered by the user. */ },
        Easings: { /* Defined below. */ },
        /* Attempt to use ES6 Promises by default. Users can override this with a third-party promises library. */
        Promise: window.Promise,
        /* Page-wide option defaults, which can be overriden by the user. */
        defaults: {
            queue: "",
            duration: DURATION_DEFAULT,
            easing: EASING_DEFAULT,
            begin: undefined,
            complete: undefined,
            progress: undefined,
            display: undefined,
            visibility: undefined,
            loop: false,
            delay: false,
            mobileHA: true,
            /* Set to false to prevent property values from being cached between consecutive Velocity-initiated chain calls. */
            _cacheValues: true
        },
        /* A design goal of Velocity is to cache data wherever possible in order to avoid DOM requerying.
           Accordingly, each element has a data cache instantiated on it. */
        init: function (element) {
            $.data(element, "velocity", {
                /* Store whether this is an SVG element, since its properties are retrieved and updated differently than standard HTML elements. */
                isSVG: Type.isSVG(element),
                /* Keep track of whether the element is currently being animated by Velocity.
                   This is used to ensure that property values are not transferred between non-consecutive (stale) calls. */
                isAnimating: false,
                /* A reference to the element's live computedStyle object. Learn more here: https://developer.mozilla.org/en/docs/Web/API/window.getComputedStyle */
                computedStyle: null,
                /* Tween data is cached for each animation on the element so that data can be passed across calls --
                   in particular, end values are used as subsequent start values in consecutive Velocity calls. */
                tweensContainer: null,
                /* The full root property values of each CSS hook being animated on this element are cached so that:
                   1) Concurrently-animating hooks sharing the same root can have their root values' merged into one while tweening.
                   2) Post-hook-injection root values can be transferred over to consecutively chained Velocity calls as starting root values. */
                rootPropertyValueCache: {},
                /* A cache for transform updates, which must be manually flushed via CSS.flushTransformCache(). */
                transformCache: {}
            });
        },
        /* A parallel to jQuery's $.css(), used for getting/setting Velocity's hooked CSS properties. */
        hook: null, /* Defined below. */
        /* Velocity-wide animation time remapping for testing purposes. */
        mock: false,
        version: { major: 1, minor: 1, patch: 0 },
        /* Set to 1 or 2 (most verbose) to output debug info to console. */
        debug: false
    };

    /* Retrieve the appropriate scroll anchor and property name for the browser: https://developer.mozilla.org/en-US/docs/Web/API/Window.scrollY */
    if (window.pageYOffset !== undefined) {
        Velocity.State.scrollAnchor = window;
        Velocity.State.scrollPropertyLeft = "pageXOffset";
        Velocity.State.scrollPropertyTop = "pageYOffset";
    } else {
        Velocity.State.scrollAnchor = document.documentElement || document.body.parentNode || document.body;
        Velocity.State.scrollPropertyLeft = "scrollLeft";
        Velocity.State.scrollPropertyTop = "scrollTop";
    }

    /* Shorthand alias for jQuery's $.data() utility. */
    function Data (element) {
        /* Hardcode a reference to the plugin name. */
        var response = $.data(element, "velocity");

        /* jQuery <=1.4.2 returns null instead of undefined when no match is found. We normalize this behavior. */
        return response === null ? undefined : response;
    };

    /**************
        Easing
    **************/

    /* Step easing generator. */
    function generateStep (steps) {
        return function (p) {
            return Math.round(p * steps) * (1 / steps);
        };
    }

    /* Bezier curve function generator. Copyright Gaetan Renaudeau. MIT License: http://en.wikipedia.org/wiki/MIT_License */
    function generateBezier (mX1, mY1, mX2, mY2) {
        var NEWTON_ITERATIONS = 4,
            NEWTON_MIN_SLOPE = 0.001,
            SUBDIVISION_PRECISION = 0.0000001,
            SUBDIVISION_MAX_ITERATIONS = 10,
            kSplineTableSize = 11,
            kSampleStepSize = 1.0 / (kSplineTableSize - 1.0),
            float32ArraySupported = "Float32Array" in window;

        /* Must contain four arguments. */
        if (arguments.length !== 4) {
            return false;
        }

        /* Arguments must be numbers. */
        for (var i = 0; i < 4; ++i) {
            if (typeof arguments[i] !== "number" || isNaN(arguments[i]) || !isFinite(arguments[i])) {
                return false;
            }
        }

        /* X values must be in the [0, 1] range. */
        mX1 = Math.min(mX1, 1);
        mX2 = Math.min(mX2, 1);
        mX1 = Math.max(mX1, 0);
        mX2 = Math.max(mX2, 0);

        var mSampleValues = float32ArraySupported ? new Float32Array(kSplineTableSize) : new Array(kSplineTableSize);

        function A (aA1, aA2) { return 1.0 - 3.0 * aA2 + 3.0 * aA1; }
        function B (aA1, aA2) { return 3.0 * aA2 - 6.0 * aA1; }
        function C (aA1)      { return 3.0 * aA1; }

        function calcBezier (aT, aA1, aA2) {
            return ((A(aA1, aA2)*aT + B(aA1, aA2))*aT + C(aA1))*aT;
        }

        function getSlope (aT, aA1, aA2) {
            return 3.0 * A(aA1, aA2)*aT*aT + 2.0 * B(aA1, aA2) * aT + C(aA1);
        }

        function newtonRaphsonIterate (aX, aGuessT) {
            for (var i = 0; i < NEWTON_ITERATIONS; ++i) {
                var currentSlope = getSlope(aGuessT, mX1, mX2);

                if (currentSlope === 0.0) return aGuessT;

                var currentX = calcBezier(aGuessT, mX1, mX2) - aX;
                aGuessT -= currentX / currentSlope;
            }

            return aGuessT;
        }

        function calcSampleValues () {
            for (var i = 0; i < kSplineTableSize; ++i) {
                mSampleValues[i] = calcBezier(i * kSampleStepSize, mX1, mX2);
            }
        }

        function binarySubdivide (aX, aA, aB) {
            var currentX, currentT, i = 0;

            do {
                currentT = aA + (aB - aA) / 2.0;
                currentX = calcBezier(currentT, mX1, mX2) - aX;
                if (currentX > 0.0) {
                  aB = currentT;
                } else {
                  aA = currentT;
                }
            } while (Math.abs(currentX) > SUBDIVISION_PRECISION && ++i < SUBDIVISION_MAX_ITERATIONS);

            return currentT;
        }

        function getTForX (aX) {
            var intervalStart = 0.0,
                currentSample = 1,
                lastSample = kSplineTableSize - 1;

            for (; currentSample != lastSample && mSampleValues[currentSample] <= aX; ++currentSample) {
                intervalStart += kSampleStepSize;
            }

            --currentSample;

            var dist = (aX - mSampleValues[currentSample]) / (mSampleValues[currentSample+1] - mSampleValues[currentSample]),
                guessForT = intervalStart + dist * kSampleStepSize,
                initialSlope = getSlope(guessForT, mX1, mX2);

            if (initialSlope >= NEWTON_MIN_SLOPE) {
                return newtonRaphsonIterate(aX, guessForT);
            } else if (initialSlope == 0.0) {
                return guessForT;
            } else {
                return binarySubdivide(aX, intervalStart, intervalStart + kSampleStepSize);
            }
        }

        var _precomputed = false;

        function precompute() {
            _precomputed = true;
            if (mX1 != mY1 || mX2 != mY2) calcSampleValues();
        }

        var f = function (aX) {
            if (!_precomputed) precompute();
            if (mX1 === mY1 && mX2 === mY2) return aX;
            if (aX === 0) return 0;
            if (aX === 1) return 1;

            return calcBezier(getTForX(aX), mY1, mY2);
        };

        f.getControlPoints = function() { return [{ x: mX1, y: mY1 }, { x: mX2, y: mY2 }]; };

        var str = "generateBezier(" + [mX1, mY1, mX2, mY2] + ")";
        f.toString = function () { return str; };

        return f;
    }

    /* Runge-Kutta spring physics function generator. Adapted from Framer.js, copyright Koen Bok. MIT License: http://en.wikipedia.org/wiki/MIT_License */
    /* Given a tension, friction, and duration, a simulation at 60FPS will first run without a defined duration in order to calculate the full path. A second pass
       then adjusts the time delta -- using the relation between actual time and duration -- to calculate the path for the duration-constrained animation. */
    var generateSpringRK4 = (function () {
        function springAccelerationForState (state) {
            return (-state.tension * state.x) - (state.friction * state.v);
        }

        function springEvaluateStateWithDerivative (initialState, dt, derivative) {
            var state = {
                x: initialState.x + derivative.dx * dt,
                v: initialState.v + derivative.dv * dt,
                tension: initialState.tension,
                friction: initialState.friction
            };

            return { dx: state.v, dv: springAccelerationForState(state) };
        }

        function springIntegrateState (state, dt) {
            var a = {
                    dx: state.v,
                    dv: springAccelerationForState(state)
                },
                b = springEvaluateStateWithDerivative(state, dt * 0.5, a),
                c = springEvaluateStateWithDerivative(state, dt * 0.5, b),
                d = springEvaluateStateWithDerivative(state, dt, c),
                dxdt = 1.0 / 6.0 * (a.dx + 2.0 * (b.dx + c.dx) + d.dx),
                dvdt = 1.0 / 6.0 * (a.dv + 2.0 * (b.dv + c.dv) + d.dv);

            state.x = state.x + dxdt * dt;
            state.v = state.v + dvdt * dt;

            return state;
        }

        return function springRK4Factory (tension, friction, duration) {

            var initState = {
                    x: -1,
                    v: 0,
                    tension: null,
                    friction: null
                },
                path = [0],
                time_lapsed = 0,
                tolerance = 1 / 10000,
                DT = 16 / 1000,
                have_duration, dt, last_state;

            tension = parseFloat(tension) || 500;
            friction = parseFloat(friction) || 20;
            duration = duration || null;

            initState.tension = tension;
            initState.friction = friction;

            have_duration = duration !== null;

            /* Calculate the actual time it takes for this animation to complete with the provided conditions. */
            if (have_duration) {
                /* Run the simulation without a duration. */
                time_lapsed = springRK4Factory(tension, friction);
                /* Compute the adjusted time delta. */
                dt = time_lapsed / duration * DT;
            } else {
                dt = DT;
            }

            while (true) {
                /* Next/step function .*/
                last_state = springIntegrateState(last_state || initState, dt);
                /* Store the position. */
                path.push(1 + last_state.x);
                time_lapsed += 16;
                /* If the change threshold is reached, break. */
                if (!(Math.abs(last_state.x) > tolerance && Math.abs(last_state.v) > tolerance)) {
                    break;
                }
            }

            /* If duration is not defined, return the actual time required for completing this animation. Otherwise, return a closure that holds the
               computed path and returns a snapshot of the position according to a given percentComplete. */
            return !have_duration ? time_lapsed : function(percentComplete) { return path[ (percentComplete * (path.length - 1)) | 0 ]; };
        };
    }());

    /* jQuery easings. */
    Velocity.Easings = {
        linear: function(p) { return p; },
        swing: function(p) { return 0.5 - Math.cos( p * Math.PI ) / 2 },
        /* Bonus "spring" easing, which is a less exaggerated version of easeInOutElastic. */
        spring: function(p) { return 1 - (Math.cos(p * 4.5 * Math.PI) * Math.exp(-p * 6)); }
    };

    /* CSS3 and Robert Penner easings. */
    $.each(
        [
            [ "ease", [ 0.25, 0.1, 0.25, 1.0 ] ],
            [ "ease-in", [ 0.42, 0.0, 1.00, 1.0 ] ],
            [ "ease-out", [ 0.00, 0.0, 0.58, 1.0 ] ],
            [ "ease-in-out", [ 0.42, 0.0, 0.58, 1.0 ] ],
            [ "easeInSine", [ 0.47, 0, 0.745, 0.715 ] ],
            [ "easeOutSine", [ 0.39, 0.575, 0.565, 1 ] ],
            [ "easeInOutSine", [ 0.445, 0.05, 0.55, 0.95 ] ],
            [ "easeInQuad", [ 0.55, 0.085, 0.68, 0.53 ] ],
            [ "easeOutQuad", [ 0.25, 0.46, 0.45, 0.94 ] ],
            [ "easeInOutQuad", [ 0.455, 0.03, 0.515, 0.955 ] ],
            [ "easeInCubic", [ 0.55, 0.055, 0.675, 0.19 ] ],
            [ "easeOutCubic", [ 0.215, 0.61, 0.355, 1 ] ],
            [ "easeInOutCubic", [ 0.645, 0.045, 0.355, 1 ] ],
            [ "easeInQuart", [ 0.895, 0.03, 0.685, 0.22 ] ],
            [ "easeOutQuart", [ 0.165, 0.84, 0.44, 1 ] ],
            [ "easeInOutQuart", [ 0.77, 0, 0.175, 1 ] ],
            [ "easeInQuint", [ 0.755, 0.05, 0.855, 0.06 ] ],
            [ "easeOutQuint", [ 0.23, 1, 0.32, 1 ] ],
            [ "easeInOutQuint", [ 0.86, 0, 0.07, 1 ] ],
            [ "easeInExpo", [ 0.95, 0.05, 0.795, 0.035 ] ],
            [ "easeOutExpo", [ 0.19, 1, 0.22, 1 ] ],
            [ "easeInOutExpo", [ 1, 0, 0, 1 ] ],
            [ "easeInCirc", [ 0.6, 0.04, 0.98, 0.335 ] ],
            [ "easeOutCirc", [ 0.075, 0.82, 0.165, 1 ] ],
            [ "easeInOutCirc", [ 0.785, 0.135, 0.15, 0.86 ] ]
        ], function(i, easingArray) {
            Velocity.Easings[easingArray[0]] = generateBezier.apply(null, easingArray[1]);
        });

    /* Determine the appropriate easing type given an easing input. */
    function getEasing(value, duration) {
        var easing = value;

        /* The easing option can either be a string that references a pre-registered easing,
           or it can be a two-/four-item array of integers to be converted into a bezier/spring function. */
        if (Type.isString(value)) {
            /* Ensure that the easing has been assigned to jQuery's Velocity.Easings object. */
            if (!Velocity.Easings[value]) {
                easing = false;
            }
        } else if (Type.isArray(value) && value.length === 1) {
            easing = generateStep.apply(null, value);
        } else if (Type.isArray(value) && value.length === 2) {
            /* springRK4 must be passed the animation's duration. */
            /* Note: If the springRK4 array contains non-numbers, generateSpringRK4() returns an easing
               function generated with default tension and friction values. */
            easing = generateSpringRK4.apply(null, value.concat([ duration ]));
        } else if (Type.isArray(value) && value.length === 4) {
            /* Note: If the bezier array contains non-numbers, generateBezier() returns false. */
            easing = generateBezier.apply(null, value);
        } else {
            easing = false;
        }

        /* Revert to the Velocity-wide default easing type, or fall back to "swing" (which is also jQuery's default)
           if the Velocity-wide default has been incorrectly modified. */
        if (easing === false) {
            if (Velocity.Easings[Velocity.defaults.easing]) {
                easing = Velocity.defaults.easing;
            } else {
                easing = EASING_DEFAULT;
            }
        }

        return easing;
    }

    /*****************
        CSS Stack
    *****************/

    /* The CSS object is a highly condensed and performant CSS stack that fully replaces jQuery's.
       It handles the validation, getting, and setting of both standard CSS properties and CSS property hooks. */
    /* Note: A "CSS" shorthand is aliased so that our code is easier to read. */
    var CSS = Velocity.CSS = {

        /*************
            RegEx
        *************/

        RegEx: {
            isHex: /^#([A-f\d]{3}){1,2}$/i,
            /* Unwrap a property value's surrounding text, e.g. "rgba(4, 3, 2, 1)" ==> "4, 3, 2, 1" and "rect(4px 3px 2px 1px)" ==> "4px 3px 2px 1px". */
            valueUnwrap: /^[A-z]+\((.*)\)$/i,
            wrappedValueAlreadyExtracted: /[0-9.]+ [0-9.]+ [0-9.]+( [0-9.]+)?/,
            /* Split a multi-value property into an array of subvalues, e.g. "rgba(4, 3, 2, 1) 4px 3px 2px 1px" ==> [ "rgba(4, 3, 2, 1)", "4px", "3px", "2px", "1px" ]. */
            valueSplit: /([A-z]+\(.+\))|(([A-z0-9#-.]+?)(?=\s|$))/ig
        },

        /************
            Lists
        ************/

        Lists: {
            colors: [ "fill", "stroke", "stopColor", "color", "backgroundColor", "borderColor", "borderTopColor", "borderRightColor", "borderBottomColor", "borderLeftColor", "outlineColor" ],
            transformsBase: [ "translateX", "translateY", "scale", "scaleX", "scaleY", "skewX", "skewY", "rotateZ" ],
            transforms3D: [ "transformPerspective", "translateZ", "scaleZ", "rotateX", "rotateY" ]
        },

        /************
            Hooks
        ************/

        /* Hooks allow a subproperty (e.g. "boxShadowBlur") of a compound-value CSS property
           (e.g. "boxShadow: X Y Blur Spread Color") to be animated as if it were a discrete property. */
        /* Note: Beyond enabling fine-grained property animation, hooking is necessary since Velocity only
           tweens properties with single numeric values; unlike CSS transitions, Velocity does not interpolate compound-values. */
        Hooks: {
            /********************
                Registration
            ********************/

            /* Templates are a concise way of indicating which subproperties must be individually registered for each compound-value CSS property. */
            /* Each template consists of the compound-value's base name, its constituent subproperty names, and those subproperties' default values. */
            templates: {
                "textShadow": [ "Color X Y Blur", "black 0px 0px 0px" ],
                /* Todo: Add support for inset boxShadows. (webkit places it last whereas IE places it first.) */
                "boxShadow": [ "Color X Y Blur Spread", "black 0px 0px 0px 0px" ],
                "clip": [ "Top Right Bottom Left", "0px 0px 0px 0px" ],
                "backgroundPosition": [ "X Y", "0% 0%" ],
                "transformOrigin": [ "X Y Z", "50% 50% 0px" ],
                "perspectiveOrigin": [ "X Y", "50% 50%" ]
            },

            /* A "registered" hook is one that has been converted from its template form into a live,
               tweenable property. It contains data to associate it with its root property. */
            registered: {
                /* Note: A registered hook looks like this ==> textShadowBlur: [ "textShadow", 3 ],
                   which consists of the subproperty's name, the associated root property's name,
                   and the subproperty's position in the root's value. */
            },
            /* Convert the templates into individual hooks then append them to the registered object above. */
            register: function () {
                /* Color hooks registration: Colors are defaulted to white -- as opposed to black -- since colors that are
                   currently set to "transparent" default to their respective template below when color-animated,
                   and white is typically a closer match to transparent than black is. An exception is made for text ("color"),
                   which is almost always set closer to black than white. */
                for (var i = 0; i < CSS.Lists.colors.length; i++) {
                    var rgbComponents = (CSS.Lists.colors[i] === "color") ? "0 0 0 1" : "255 255 255 1";
                    CSS.Hooks.templates[CSS.Lists.colors[i]] = [ "Red Green Blue Alpha", rgbComponents ];
                }

                var rootProperty,
                    hookTemplate,
                    hookNames;

                /* In IE, color values inside compound-value properties are positioned at the end the value instead of at the beginning.
                   Thus, we re-arrange the templates accordingly. */
                if (IE) {
                    for (rootProperty in CSS.Hooks.templates) {
                        hookTemplate = CSS.Hooks.templates[rootProperty];
                        hookNames = hookTemplate[0].split(" ");

                        var defaultValues = hookTemplate[1].match(CSS.RegEx.valueSplit);

                        if (hookNames[0] === "Color") {
                            /* Reposition both the hook's name and its default value to the end of their respective strings. */
                            hookNames.push(hookNames.shift());
                            defaultValues.push(defaultValues.shift());

                            /* Replace the existing template for the hook's root property. */
                            CSS.Hooks.templates[rootProperty] = [ hookNames.join(" "), defaultValues.join(" ") ];
                        }
                    }
                }

                /* Hook registration. */
                for (rootProperty in CSS.Hooks.templates) {
                    hookTemplate = CSS.Hooks.templates[rootProperty];
                    hookNames = hookTemplate[0].split(" ");

                    for (var i in hookNames) {
                        var fullHookName = rootProperty + hookNames[i],
                            hookPosition = i;

                        /* For each hook, register its full name (e.g. textShadowBlur) with its root property (e.g. textShadow)
                           and the hook's position in its template's default value string. */
                        CSS.Hooks.registered[fullHookName] = [ rootProperty, hookPosition ];
                    }
                }
            },

            /*****************************
               Injection and Extraction
            *****************************/

            /* Look up the root property associated with the hook (e.g. return "textShadow" for "textShadowBlur"). */
            /* Since a hook cannot be set directly (the browser won't recognize it), style updating for hooks is routed through the hook's root property. */
            getRoot: function (property) {
                var hookData = CSS.Hooks.registered[property];

                if (hookData) {
                    return hookData[0];
                } else {
                    /* If there was no hook match, return the property name untouched. */
                    return property;
                }
            },
            /* Convert any rootPropertyValue, null or otherwise, into a space-delimited list of hook values so that
               the targeted hook can be injected or extracted at its standard position. */
            cleanRootPropertyValue: function(rootProperty, rootPropertyValue) {
                /* If the rootPropertyValue is wrapped with "rgb()", "clip()", etc., remove the wrapping to normalize the value before manipulation. */
                if (CSS.RegEx.valueUnwrap.test(rootPropertyValue)) {
                    rootPropertyValue = rootPropertyValue.match(CSS.RegEx.valueUnwrap)[1];
                }

                /* If rootPropertyValue is a CSS null-value (from which there's inherently no hook value to extract),
                   default to the root's default value as defined in CSS.Hooks.templates. */
                /* Note: CSS null-values include "none", "auto", and "transparent". They must be converted into their
                   zero-values (e.g. textShadow: "none" ==> textShadow: "0px 0px 0px black") for hook manipulation to proceed. */
                if (CSS.Values.isCSSNullValue(rootPropertyValue)) {
                    rootPropertyValue = CSS.Hooks.templates[rootProperty][1];
                }

                return rootPropertyValue;
            },
            /* Extracted the hook's value from its root property's value. This is used to get the starting value of an animating hook. */
            extractValue: function (fullHookName, rootPropertyValue) {
                var hookData = CSS.Hooks.registered[fullHookName];

                if (hookData) {
                    var hookRoot = hookData[0],
                        hookPosition = hookData[1];

                    rootPropertyValue = CSS.Hooks.cleanRootPropertyValue(hookRoot, rootPropertyValue);

                    /* Split rootPropertyValue into its constituent hook values then grab the desired hook at its standard position. */
                    return rootPropertyValue.toString().match(CSS.RegEx.valueSplit)[hookPosition];
                } else {
                    /* If the provided fullHookName isn't a registered hook, return the rootPropertyValue that was passed in. */
                    return rootPropertyValue;
                }
            },
            /* Inject the hook's value into its root property's value. This is used to piece back together the root property
               once Velocity has updated one of its individually hooked values through tweening. */
            injectValue: function (fullHookName, hookValue, rootPropertyValue) {
                var hookData = CSS.Hooks.registered[fullHookName];

                if (hookData) {
                    var hookRoot = hookData[0],
                        hookPosition = hookData[1],
                        rootPropertyValueParts,
                        rootPropertyValueUpdated;

                    rootPropertyValue = CSS.Hooks.cleanRootPropertyValue(hookRoot, rootPropertyValue);

                    /* Split rootPropertyValue into its individual hook values, replace the targeted value with hookValue,
                       then reconstruct the rootPropertyValue string. */
                    rootPropertyValueParts = rootPropertyValue.toString().match(CSS.RegEx.valueSplit);
                    rootPropertyValueParts[hookPosition] = hookValue;
                    rootPropertyValueUpdated = rootPropertyValueParts.join(" ");

                    return rootPropertyValueUpdated;
                } else {
                    /* If the provided fullHookName isn't a registered hook, return the rootPropertyValue that was passed in. */
                    return rootPropertyValue;
                }
            }
        },

        /*******************
           Normalizations
        *******************/

        /* Normalizations standardize CSS property manipulation by pollyfilling browser-specific implementations (e.g. opacity)
           and reformatting special properties (e.g. clip, rgba) to look like standard ones. */
        Normalizations: {
            /* Normalizations are passed a normalization target (either the property's name, its extracted value, or its injected value),
               the targeted element (which may need to be queried), and the targeted property value. */
            registered: {
                clip: function (type, element, propertyValue) {
                    switch (type) {
                        case "name":
                            return "clip";
                        /* Clip needs to be unwrapped and stripped of its commas during extraction. */
                        case "extract":
                            var extracted;

                            /* If Velocity also extracted this value, skip extraction. */
                            if (CSS.RegEx.wrappedValueAlreadyExtracted.test(propertyValue)) {
                                extracted = propertyValue;
                            } else {
                                /* Remove the "rect()" wrapper. */
                                extracted = propertyValue.toString().match(CSS.RegEx.valueUnwrap);

                                /* Strip off commas. */
                                extracted = extracted ? extracted[1].replace(/,(\s+)?/g, " ") : propertyValue;
                            }

                            return extracted;
                        /* Clip needs to be re-wrapped during injection. */
                        case "inject":
                            return "rect(" + propertyValue + ")";
                    }
                },

                blur: function(type, element, propertyValue) {
                    switch (type) {
                        case "name":
                            return "-webkit-filter";
                        case "extract":
                            var extracted = parseFloat(propertyValue);

                            /* If extracted is NaN, meaning the value isn't already extracted. */
                            if (!(extracted || extracted === 0)) {
                                var blurComponent = propertyValue.toString().match(/blur\(([0-9]+[A-z]+)\)/i);

                                /* If the filter string had a blur component, return just the blur value and unit type. */
                                if (blurComponent) {
                                    extracted = blurComponent[1];
                                /* If the component doesn't exist, default blur to 0. */
                                } else {
                                    extracted = 0;
                                }
                            }

                            return extracted;
                        /* Blur needs to be re-wrapped during injection. */
                        case "inject":
                            /* For the blur effect to be fully de-applied, it needs to be set to "none" instead of 0. */
                            if (!parseFloat(propertyValue)) {
                                return "none";
                            } else {
                                return "blur(" + propertyValue + ")";
                            }
                    }
                },

                /* <=IE8 do not support the standard opacity property. They use filter:alpha(opacity=INT) instead. */
                opacity: function (type, element, propertyValue) {
                    if (IE <= 8) {
                        switch (type) {
                            case "name":
                                return "filter";
                            case "extract":
                                /* <=IE8 return a "filter" value of "alpha(opacity=\d{1,3})".
                                   Extract the value and convert it to a decimal value to match the standard CSS opacity property's formatting. */
                                var extracted = propertyValue.toString().match(/alpha\(opacity=(.*)\)/i);

                                if (extracted) {
                                    /* Convert to decimal value. */
                                    propertyValue = extracted[1] / 100;
                                } else {
                                    /* When extracting opacity, default to 1 since a null value means opacity hasn't been set. */
                                    propertyValue = 1;
                                }

                                return propertyValue;
                            case "inject":
                                /* Opacified elements are required to have their zoom property set to a non-zero value. */
                                element.style.zoom = 1;

                                /* Setting the filter property on elements with certain font property combinations can result in a
                                   highly unappealing ultra-bolding effect. There's no way to remedy this throughout a tween, but dropping the
                                   value altogether (when opacity hits 1) at leasts ensures that the glitch is gone post-tweening. */
                                if (parseFloat(propertyValue) >= 1) {
                                    return "";
                                } else {
                                  /* As per the filter property's spec, convert the decimal value to a whole number and wrap the value. */
                                  return "alpha(opacity=" + parseInt(parseFloat(propertyValue) * 100, 10) + ")";
                                }
                        }
                    /* With all other browsers, normalization is not required; return the same values that were passed in. */
                    } else {
                        switch (type) {
                            case "name":
                                return "opacity";
                            case "extract":
                                return propertyValue;
                            case "inject":
                                return propertyValue;
                        }
                    }
                }
            },

            /*****************************
                Batched Registrations
            *****************************/

            /* Note: Batched normalizations extend the CSS.Normalizations.registered object. */
            register: function () {

                /*****************
                    Transforms
                *****************/

                /* Transforms are the subproperties contained by the CSS "transform" property. Transforms must undergo normalization
                   so that they can be referenced in a properties map by their individual names. */
                /* Note: When transforms are "set", they are actually assigned to a per-element transformCache. When all transform
                   setting is complete complete, CSS.flushTransformCache() must be manually called to flush the values to the DOM.
                   Transform setting is batched in this way to improve performance: the transform style only needs to be updated
                   once when multiple transform subproperties are being animated simultaneously. */
                /* Note: IE9 and Android Gingerbread have support for 2D -- but not 3D -- transforms. Since animating unsupported
                   transform properties results in the browser ignoring the *entire* transform string, we prevent these 3D values
                   from being normalized for these browsers so that tweening skips these properties altogether
                   (since it will ignore them as being unsupported by the browser.) */
                if (!(IE <= 9) && !Velocity.State.isGingerbread) {
                    /* Note: Since the standalone CSS "perspective" property and the CSS transform "perspective" subproperty
                    share the same name, the latter is given a unique token within Velocity: "transformPerspective". */
                    CSS.Lists.transformsBase = CSS.Lists.transformsBase.concat(CSS.Lists.transforms3D);
                }

                for (var i = 0; i < CSS.Lists.transformsBase.length; i++) {
                    /* Wrap the dynamically generated normalization function in a new scope so that transformName's value is
                    paired with its respective function. (Otherwise, all functions would take the final for loop's transformName.) */
                    (function() {
                        var transformName = CSS.Lists.transformsBase[i];

                        CSS.Normalizations.registered[transformName] = function (type, element, propertyValue) {
                            switch (type) {
                                /* The normalized property name is the parent "transform" property -- the property that is actually set in CSS. */
                                case "name":
                                    return "transform";
                                /* Transform values are cached onto a per-element transformCache object. */
                                case "extract":
                                    /* If this transform has yet to be assigned a value, return its null value. */
                                    if (Data(element) === undefined || Data(element).transformCache[transformName] === undefined) {
                                        /* Scale CSS.Lists.transformsBase default to 1 whereas all other transform properties default to 0. */
                                        return /^scale/i.test(transformName) ? 1 : 0;
                                    /* When transform values are set, they are wrapped in parentheses as per the CSS spec.
                                       Thus, when extracting their values (for tween calculations), we strip off the parentheses. */
                                    } else {
                                        return Data(element).transformCache[transformName].replace(/[()]/g, "");
                                    }
                                case "inject":
                                    var invalid = false;

                                    /* If an individual transform property contains an unsupported unit type, the browser ignores the *entire* transform property.
                                       Thus, protect users from themselves by skipping setting for transform values supplied with invalid unit types. */
                                    /* Switch on the base transform type; ignore the axis by removing the last letter from the transform's name. */
                                    switch (transformName.substr(0, transformName.length - 1)) {
                                        /* Whitelist unit types for each transform. */
                                        case "translate":
                                            invalid = !/(%|px|em|rem|vw|vh|\d)$/i.test(propertyValue);
                                            break;
                                        /* Since an axis-free "scale" property is supported as well, a little hack is used here to detect it by chopping off its last letter. */
                                        case "scal":
                                        case "scale":
                                            /* Chrome on Android has a bug in which scaled elements blur if their initial scale
                                               value is below 1 (which can happen with forcefeeding). Thus, we detect a yet-unset scale property
                                               and ensure that its first value is always 1. More info: http://stackoverflow.com/questions/10417890/css3-animations-with-transform-causes-blurred-elements-on-webkit/10417962#10417962 */
                                            if (Velocity.State.isAndroid && Data(element).transformCache[transformName] === undefined && propertyValue < 1) {
                                                propertyValue = 1;
                                            }

                                            invalid = !/(\d)$/i.test(propertyValue);
                                            break;
                                        case "skew":
                                            invalid = !/(deg|\d)$/i.test(propertyValue);
                                            break;
                                        case "rotate":
                                            invalid = !/(deg|\d)$/i.test(propertyValue);
                                            break;
                                    }

                                    if (!invalid) {
                                        /* As per the CSS spec, wrap the value in parentheses. */
                                        Data(element).transformCache[transformName] = "(" + propertyValue + ")";
                                    }

                                    /* Although the value is set on the transformCache object, return the newly-updated value for the calling code to process as normal. */
                                    return Data(element).transformCache[transformName];
                            }
                        };
                    })();
                }

                /*************
                    Colors
                *************/

                /* Since Velocity only animates a single numeric value per property, color animation is achieved by hooking the individual RGBA components of CSS color properties.
                   Accordingly, color values must be normalized (e.g. "#ff0000", "red", and "rgb(255, 0, 0)" ==> "255 0 0 1") so that their components can be injected/extracted by CSS.Hooks logic. */
                for (var i = 0; i < CSS.Lists.colors.length; i++) {
                    /* Wrap the dynamically generated normalization function in a new scope so that colorName's value is paired with its respective function.
                       (Otherwise, all functions would take the final for loop's colorName.) */
                    (function () {
                        var colorName = CSS.Lists.colors[i];

                        /* Note: In IE<=8, which support rgb but not rgba, color properties are reverted to rgb by stripping off the alpha component. */
                        CSS.Normalizations.registered[colorName] = function(type, element, propertyValue) {
                            switch (type) {
                                case "name":
                                    return colorName;
                                /* Convert all color values into the rgb format. (Old IE can return hex values and color names instead of rgb/rgba.) */
                                case "extract":
                                    var extracted;

                                    /* If the color is already in its hookable form (e.g. "255 255 255 1") due to having been previously extracted, skip extraction. */
                                    if (CSS.RegEx.wrappedValueAlreadyExtracted.test(propertyValue)) {
                                        extracted = propertyValue;
                                    } else {
                                        var converted,
                                            colorNames = {
                                                black: "rgb(0, 0, 0)",
                                                blue: "rgb(0, 0, 255)",
                                                gray: "rgb(128, 128, 128)",
                                                green: "rgb(0, 128, 0)",
                                                red: "rgb(255, 0, 0)",
                                                white: "rgb(255, 255, 255)"
                                            };

                                        /* Convert color names to rgb. */
                                        if (/^[A-z]+$/i.test(propertyValue)) {
                                            if (colorNames[propertyValue] !== undefined) {
                                                converted = colorNames[propertyValue]
                                            } else {
                                                /* If an unmatched color name is provided, default to black. */
                                                converted = colorNames.black;
                                            }
                                        /* Convert hex values to rgb. */
                                        } else if (CSS.RegEx.isHex.test(propertyValue)) {
                                            converted = "rgb(" + CSS.Values.hexToRgb(propertyValue).join(" ") + ")";
                                        /* If the provided color doesn't match any of the accepted color formats, default to black. */
                                        } else if (!(/^rgba?\(/i.test(propertyValue))) {
                                            converted = colorNames.black;
                                        }

                                        /* Remove the surrounding "rgb/rgba()" string then replace commas with spaces and strip
                                           repeated spaces (in case the value included spaces to begin with). */
                                        extracted = (converted || propertyValue).toString().match(CSS.RegEx.valueUnwrap)[1].replace(/,(\s+)?/g, " ");
                                    }

                                    /* So long as this isn't <=IE8, add a fourth (alpha) component if it's missing and default it to 1 (visible). */
                                    if (!(IE <= 8) && extracted.split(" ").length === 3) {
                                        extracted += " 1";
                                    }

                                    return extracted;
                                case "inject":
                                    /* If this is IE<=8 and an alpha component exists, strip it off. */
                                    if (IE <= 8) {
                                        if (propertyValue.split(" ").length === 4) {
                                            propertyValue = propertyValue.split(/\s+/).slice(0, 3).join(" ");
                                        }
                                    /* Otherwise, add a fourth (alpha) component if it's missing and default it to 1 (visible). */
                                    } else if (propertyValue.split(" ").length === 3) {
                                        propertyValue += " 1";
                                    }

                                    /* Re-insert the browser-appropriate wrapper("rgb/rgba()"), insert commas, and strip off decimal units
                                       on all values but the fourth (R, G, and B only accept whole numbers). */
                                    return (IE <= 8 ? "rgb" : "rgba") + "(" + propertyValue.replace(/\s+/g, ",").replace(/\.(\d)+(?=,)/g, "") + ")";
                            }
                        };
                    })();
                }
            }
        },

        /************************
           CSS Property Names
        ************************/

        Names: {
            /* Camelcase a property name into its JavaScript notation (e.g. "background-color" ==> "backgroundColor").
               Camelcasing is used to normalize property names between and across calls. */
            camelCase: function (property) {
                return property.replace(/-(\w)/g, function (match, subMatch) {
                    return subMatch.toUpperCase();
                });
            },

            /* For SVG elements, some properties (namely, dimensional ones) are GET/SET via the element's HTML attributes (instead of via CSS styles). */
            SVGAttribute: function (property) {
                var SVGAttributes = "width|height|x|y|cx|cy|r|rx|ry|x1|x2|y1|y2";

                /* Certain browsers require an SVG transform to be applied as an attribute. (Otherwise, application via CSS is preferable due to 3D support.) */
                if (IE || (Velocity.State.isAndroid && !Velocity.State.isChrome)) {
                    SVGAttributes += "|transform";
                }

                return new RegExp("^(" + SVGAttributes + ")$", "i").test(property);
            },

            /* Determine whether a property should be set with a vendor prefix. */
            /* If a prefixed version of the property exists, return it. Otherwise, return the original property name.
               If the property is not at all supported by the browser, return a false flag. */
            prefixCheck: function (property) {
                /* If this property has already been checked, return the cached value. */
                if (Velocity.State.prefixMatches[property]) {
                    return [ Velocity.State.prefixMatches[property], true ];
                } else {
                    var vendors = [ "", "Webkit", "Moz", "ms", "O" ];

                    for (var i = 0, vendorsLength = vendors.length; i < vendorsLength; i++) {
                        var propertyPrefixed;

                        if (i === 0) {
                            propertyPrefixed = property;
                        } else {
                            /* Capitalize the first letter of the property to conform to JavaScript vendor prefix notation (e.g. webkitFilter). */
                            propertyPrefixed = vendors[i] + property.replace(/^\w/, function(match) { return match.toUpperCase(); });
                        }

                        /* Check if the browser supports this property as prefixed. */
                        if (Type.isString(Velocity.State.prefixElement.style[propertyPrefixed])) {
                            /* Cache the match. */
                            Velocity.State.prefixMatches[property] = propertyPrefixed;

                            return [ propertyPrefixed, true ];
                        }
                    }

                    /* If the browser doesn't support this property in any form, include a false flag so that the caller can decide how to proceed. */
                    return [ property, false ];
                }
            }
        },

        /************************
           CSS Property Values
        ************************/

        Values: {
            /* Hex to RGB conversion. Copyright Tim Down: http://stackoverflow.com/questions/5623838/rgb-to-hex-and-hex-to-rgb */
            hexToRgb: function (hex) {
                var shortformRegex = /^#?([a-f\d])([a-f\d])([a-f\d])$/i,
                    longformRegex = /^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i,
                    rgbParts;

                hex = hex.replace(shortformRegex, function (m, r, g, b) {
                    return r + r + g + g + b + b;
                });

                rgbParts = longformRegex.exec(hex);

                return rgbParts ? [ parseInt(rgbParts[1], 16), parseInt(rgbParts[2], 16), parseInt(rgbParts[3], 16) ] : [ 0, 0, 0 ];
            },

            isCSSNullValue: function (value) {
                /* The browser defaults CSS values that have not been set to either 0 or one of several possible null-value strings.
                   Thus, we check for both falsiness and these special strings. */
                /* Null-value checking is performed to default the special strings to 0 (for the sake of tweening) or their hook
                   templates as defined as CSS.Hooks (for the sake of hook injection/extraction). */
                /* Note: Chrome returns "rgba(0, 0, 0, 0)" for an undefined color whereas IE returns "transparent". */
                return (value == 0 || /^(none|auto|transparent|(rgba\(0, ?0, ?0, ?0\)))$/i.test(value));
            },

            /* Retrieve a property's default unit type. Used for assigning a unit type when one is not supplied by the user. */
            getUnitType: function (property) {
                if (/^(rotate|skew)/i.test(property)) {
                    return "deg";
                } else if (/(^(scale|scaleX|scaleY|scaleZ|alpha|flexGrow|flexHeight|zIndex|fontWeight)$)|((opacity|red|green|blue|alpha)$)/i.test(property)) {
                    /* The above properties are unitless. */
                    return "";
                } else {
                    /* Default to px for all other properties. */
                    return "px";
                }
            },

            /* HTML elements default to an associated display type when they're not set to display:none. */
            /* Note: This function is used for correctly setting the non-"none" display value in certain Velocity redirects, such as fadeIn/Out. */
            getDisplayType: function (element) {
                var tagName = element && element.tagName.toString().toLowerCase();

                if (/^(b|big|i|small|tt|abbr|acronym|cite|code|dfn|em|kbd|strong|samp|var|a|bdo|br|img|map|object|q|script|span|sub|sup|button|input|label|select|textarea)$/i.test(tagName)) {
                    return "inline";
                } else if (/^(li)$/i.test(tagName)) {
                    return "list-item";
                } else if (/^(tr)$/i.test(tagName)) {
                    return "table-row";
                /* Default to "block" when no match is found. */
                } else {
                    return "block";
                }
            },

            /* The class add/remove functions are used to temporarily apply a "velocity-animating" class to elements while they're animating. */
            addClass: function (element, className) {
                if (element.classList) {
                    element.classList.add(className);
                } else {
                    element.className += (element.className.length ? " " : "") + className;
                }
            },

            removeClass: function (element, className) {
                if (element.classList) {
                    element.classList.remove(className);
                } else {
                    element.className = element.className.toString().replace(new RegExp("(^|\\s)" + className.split(" ").join("|") + "(\\s|$)", "gi"), " ");
                }
            }
        },

        /****************************
           Style Getting & Setting
        ****************************/

        /* The singular getPropertyValue, which routes the logic for all normalizations, hooks, and standard CSS properties. */
        getPropertyValue: function (element, property, rootPropertyValue, forceStyleLookup) {
            /* Get an element's computed property value. */
            /* Note: Retrieving the value of a CSS property cannot simply be performed by checking an element's
               style attribute (which only reflects user-defined values). Instead, the browser must be queried for a property's
               *computed* value. You can read more about getComputedStyle here: https://developer.mozilla.org/en/docs/Web/API/window.getComputedStyle */
            function computePropertyValue (element, property) {
                /* When box-sizing isn't set to border-box, height and width style values are incorrectly computed when an
                   element's scrollbars are visible (which expands the element's dimensions). Thus, we defer to the more accurate
                   offsetHeight/Width property, which includes the total dimensions for interior, border, padding, and scrollbar.
                   We subtract border and padding to get the sum of interior + scrollbar. */
                var computedValue = 0;

                /* IE<=8 doesn't support window.getComputedStyle, thus we defer to jQuery, which has an extensive array
                   of hacks to accurately retrieve IE8 property values. Re-implementing that logic here is not worth bloating the
                   codebase for a dying browser. The performance repercussions of using jQuery here are minimal since
                   Velocity is optimized to rarely (and sometimes never) query the DOM. Further, the $.css() codepath isn't that slow. */
                if (IE <= 8) {
                    computedValue = $.css(element, property); /* GET */
                /* All other browsers support getComputedStyle. The returned live object reference is cached onto its
                   associated element so that it does not need to be refetched upon every GET. */
                } else {
                    /* Browsers do not return height and width values for elements that are set to display:"none". Thus, we temporarily
                       toggle display to the element type's default value. */
                    var toggleDisplay = false;

                    if (/^(width|height)$/.test(property) && CSS.getPropertyValue(element, "display") === 0) {
                        toggleDisplay = true;
                        CSS.setPropertyValue(element, "display", CSS.Values.getDisplayType(element));
                    }

                    function revertDisplay () {
                        if (toggleDisplay) {
                            CSS.setPropertyValue(element, "display", "none");
                        }
                    }

                    if (!forceStyleLookup) {
                        if (property === "height" && CSS.getPropertyValue(element, "boxSizing").toString().toLowerCase() !== "border-box") {
                            var contentBoxHeight = element.offsetHeight - (parseFloat(CSS.getPropertyValue(element, "borderTopWidth")) || 0) - (parseFloat(CSS.getPropertyValue(element, "borderBottomWidth")) || 0) - (parseFloat(CSS.getPropertyValue(element, "paddingTop")) || 0) - (parseFloat(CSS.getPropertyValue(element, "paddingBottom")) || 0);
                            revertDisplay();

                            return contentBoxHeight;
                        } else if (property === "width" && CSS.getPropertyValue(element, "boxSizing").toString().toLowerCase() !== "border-box") {
                            var contentBoxWidth = element.offsetWidth - (parseFloat(CSS.getPropertyValue(element, "borderLeftWidth")) || 0) - (parseFloat(CSS.getPropertyValue(element, "borderRightWidth")) || 0) - (parseFloat(CSS.getPropertyValue(element, "paddingLeft")) || 0) - (parseFloat(CSS.getPropertyValue(element, "paddingRight")) || 0);
                            revertDisplay();

                            return contentBoxWidth;
                        }
                    }

                    var computedStyle;

                    /* For elements that Velocity hasn't been called on directly (e.g. when Velocity queries the DOM on behalf
                       of a parent of an element its animating), perform a direct getComputedStyle lookup since the object isn't cached. */
                    if (Data(element) === undefined) {
                        computedStyle = window.getComputedStyle(element, null); /* GET */
                    /* If the computedStyle object has yet to be cached, do so now. */
                    } else if (!Data(element).computedStyle) {
                        computedStyle = Data(element).computedStyle = window.getComputedStyle(element, null); /* GET */
                    /* If computedStyle is cached, use it. */
                    } else {
                        computedStyle = Data(element).computedStyle;
                    }

                    /* IE and Firefox do not return a value for the generic borderColor -- they only return individual values for each border side's color.
                       As a polyfill for querying individual border side colors, just return the top border's color. */
                    if ((IE || Velocity.State.isFirefox) && property === "borderColor") {
                        property = "borderTopColor";
                    }

                    /* IE9 has a bug in which the "filter" property must be accessed from computedStyle using the getPropertyValue method
                       instead of a direct property lookup. The getPropertyValue method is slower than a direct lookup, which is why we avoid it by default. */
                    if (IE === 9 && property === "filter") {
                        computedValue = computedStyle.getPropertyValue(property); /* GET */
                    } else {
                        computedValue = computedStyle[property];
                    }

                    /* Fall back to the property's style value (if defined) when computedValue returns nothing,
                       which can happen when the element hasn't been painted. */
                    if (computedValue === "" || computedValue === null) {
                        computedValue = element.style[property];
                    }

                    revertDisplay();
                }

                /* For top, right, bottom, and left (TRBL) values that are set to "auto" on elements of "fixed" or "absolute" position,
                   defer to jQuery for converting "auto" to a numeric value. (For elements with a "static" or "relative" position, "auto" has the same
                   effect as being set to 0, so no conversion is necessary.) */
                /* An example of why numeric conversion is necessary: When an element with "position:absolute" has an untouched "left"
                   property, which reverts to "auto", left's value is 0 relative to its parent element, but is often non-zero relative
                   to its *containing* (not parent) element, which is the nearest "position:relative" ancestor or the viewport (and always the viewport in the case of "position:fixed"). */
                if (computedValue === "auto" && /^(top|right|bottom|left)$/i.test(property)) {
                    var position = computePropertyValue(element, "position"); /* GET */

                    /* For absolute positioning, jQuery's $.position() only returns values for top and left;
                       right and bottom will have their "auto" value reverted to 0. */
                    /* Note: A jQuery object must be created here since jQuery doesn't have a low-level alias for $.position().
                       Not a big deal since we're currently in a GET batch anyway. */
                    if (position === "fixed" || (position === "absolute" && /top|left/i.test(property))) {
                        /* Note: jQuery strips the pixel unit from its returned values; we re-add it here to conform with computePropertyValue's behavior. */
                        computedValue = $(element).position()[property] + "px"; /* GET */
                    }
                }

                return computedValue;
            }

            var propertyValue;

            /* If this is a hooked property (e.g. "clipLeft" instead of the root property of "clip"),
               extract the hook's value from a normalized rootPropertyValue using CSS.Hooks.extractValue(). */
            if (CSS.Hooks.registered[property]) {
                var hook = property,
                    hookRoot = CSS.Hooks.getRoot(hook);

                /* If a cached rootPropertyValue wasn't passed in (which Velocity always attempts to do in order to avoid requerying the DOM),
                   query the DOM for the root property's value. */
                if (rootPropertyValue === undefined) {
                    /* Since the browser is now being directly queried, use the official post-prefixing property name for this lookup. */
                    rootPropertyValue = CSS.getPropertyValue(element, CSS.Names.prefixCheck(hookRoot)[0]); /* GET */
                }

                /* If this root has a normalization registered, peform the associated normalization extraction. */
                if (CSS.Normalizations.registered[hookRoot]) {
                    rootPropertyValue = CSS.Normalizations.registered[hookRoot]("extract", element, rootPropertyValue);
                }

                /* Extract the hook's value. */
                propertyValue = CSS.Hooks.extractValue(hook, rootPropertyValue);

            /* If this is a normalized property (e.g. "opacity" becomes "filter" in <=IE8) or "translateX" becomes "transform"),
               normalize the property's name and value, and handle the special case of transforms. */
            /* Note: Normalizing a property is mutually exclusive from hooking a property since hook-extracted values are strictly
               numerical and therefore do not require normalization extraction. */
            } else if (CSS.Normalizations.registered[property]) {
                var normalizedPropertyName,
                    normalizedPropertyValue;

                normalizedPropertyName = CSS.Normalizations.registered[property]("name", element);

                /* Transform values are calculated via normalization extraction (see below), which checks against the element's transformCache.
                   At no point do transform GETs ever actually query the DOM; initial stylesheet values are never processed.
                   This is because parsing 3D transform matrices is not always accurate and would bloat our codebase;
                   thus, normalization extraction defaults initial transform values to their zero-values (e.g. 1 for scaleX and 0 for translateX). */
                if (normalizedPropertyName !== "transform") {
                    normalizedPropertyValue = computePropertyValue(element, CSS.Names.prefixCheck(normalizedPropertyName)[0]); /* GET */

                    /* If the value is a CSS null-value and this property has a hook template, use that zero-value template so that hooks can be extracted from it. */
                    if (CSS.Values.isCSSNullValue(normalizedPropertyValue) && CSS.Hooks.templates[property]) {
                        normalizedPropertyValue = CSS.Hooks.templates[property][1];
                    }
                }

                propertyValue = CSS.Normalizations.registered[property]("extract", element, normalizedPropertyValue);
            }

            /* If a (numeric) value wasn't produced via hook extraction or normalization, query the DOM. */
            if (!/^[\d-]/.test(propertyValue)) {
                /* For SVG elements, dimensional properties (which SVGAttribute() detects) are tweened via
                   their HTML attribute values instead of their CSS style values. */
                if (Data(element) && Data(element).isSVG && CSS.Names.SVGAttribute(property)) {
                    /* Since the height/width attribute values must be set manually, they don't reflect computed values.
                       Thus, we use use getBBox() to ensure we always get values for elements with undefined height/width attributes. */
                    if (/^(height|width)$/i.test(property)) {
                        propertyValue = element.getBBox()[property];
                    /* Otherwise, access the attribute value directly. */
                    } else {
                        propertyValue = element.getAttribute(property);
                    }
                } else {
                    propertyValue = computePropertyValue(element, CSS.Names.prefixCheck(property)[0]); /* GET */
                }
            }

            /* Since property lookups are for animation purposes (which entails computing the numeric delta between start and end values),
               convert CSS null-values to an integer of value 0. */
            if (CSS.Values.isCSSNullValue(propertyValue)) {
                propertyValue = 0;
            }

            if (Velocity.debug >= 2) console.log("Get " + property + ": " + propertyValue);

            return propertyValue;
        },

        /* The singular setPropertyValue, which routes the logic for all normalizations, hooks, and standard CSS properties. */
        setPropertyValue: function(element, property, propertyValue, rootPropertyValue, scrollData) {
            var propertyName = property;

            /* In order to be subjected to call options and element queueing, scroll animation is routed through Velocity as if it were a standard CSS property. */
            if (property === "scroll") {
                /* If a container option is present, scroll the container instead of the browser window. */
                if (scrollData.container) {
                    scrollData.container["scroll" + scrollData.direction] = propertyValue;
                /* Otherwise, Velocity defaults to scrolling the browser window. */
                } else {
                    if (scrollData.direction === "Left") {
                        window.scrollTo(propertyValue, scrollData.alternateValue);
                    } else {
                        window.scrollTo(scrollData.alternateValue, propertyValue);
                    }
                }
            } else {
                /* Transforms (translateX, rotateZ, etc.) are applied to a per-element transformCache object, which is manually flushed via flushTransformCache().
                   Thus, for now, we merely cache transforms being SET. */
                if (CSS.Normalizations.registered[property] && CSS.Normalizations.registered[property]("name", element) === "transform") {
                    /* Perform a normalization injection. */
                    /* Note: The normalization logic handles the transformCache updating. */
                    CSS.Normalizations.registered[property]("inject", element, propertyValue);

                    propertyName = "transform";
                    propertyValue = Data(element).transformCache[property];
                } else {
                    /* Inject hooks. */
                    if (CSS.Hooks.registered[property]) {
                        var hookName = property,
                            hookRoot = CSS.Hooks.getRoot(property);

                        /* If a cached rootPropertyValue was not provided, query the DOM for the hookRoot's current value. */
                        rootPropertyValue = rootPropertyValue || CSS.getPropertyValue(element, hookRoot); /* GET */

                        propertyValue = CSS.Hooks.injectValue(hookName, propertyValue, rootPropertyValue);
                        property = hookRoot;
                    }

                    /* Normalize names and values. */
                    if (CSS.Normalizations.registered[property]) {
                        propertyValue = CSS.Normalizations.registered[property]("inject", element, propertyValue);
                        property = CSS.Normalizations.registered[property]("name", element);
                    }

                    /* Assign the appropriate vendor prefix before performing an official style update. */
                    propertyName = CSS.Names.prefixCheck(property)[0];

                    /* A try/catch is used for IE<=8, which throws an error when "invalid" CSS values are set, e.g. a negative width.
                       Try/catch is avoided for other browsers since it incurs a performance overhead. */
                    if (IE <= 8) {
                        try {
                            element.style[propertyName] = propertyValue;
                        } catch (error) { if (Velocity.debug) console.log("Browser does not support [" + propertyValue + "] for [" + propertyName + "]"); }
                    /* SVG elements have their dimensional properties (width, height, x, y, cx, etc.) applied directly as attributes instead of as styles. */
                    /* Note: IE8 does not support SVG elements, so it's okay that we skip it for SVG animation. */
                    } else if (Data(element) && Data(element).isSVG && CSS.Names.SVGAttribute(property)) {
                        /* Note: For SVG attributes, vendor-prefixed property names are never used. */
                        /* Note: Not all CSS properties can be animated via attributes, but the browser won't throw an error for unsupported properties. */
                        element.setAttribute(property, propertyValue);
                    } else {
                        element.style[propertyName] = propertyValue;
                    }

                    if (Velocity.debug >= 2) console.log("Set " + property + " (" + propertyName + "): " + propertyValue);
                }
            }

            /* Return the normalized property name and value in case the caller wants to know how these values were modified before being applied to the DOM. */
            return [ propertyName, propertyValue ];
        },

        /* To increase performance by batching transform updates into a single SET, transforms are not directly applied to an element until flushTransformCache() is called. */
        /* Note: Velocity applies transform properties in the same order that they are chronogically introduced to the element's CSS styles. */
        flushTransformCache: function(element) {
            var transformString = "";

            /* Certain browsers require that SVG transforms be applied as an attribute. However, the SVG transform attribute takes a modified version of CSS's transform string
               (units are dropped and, except for skewX/Y, subproperties are merged into their master property -- e.g. scaleX and scaleY are merged into scale(X Y). */
            if ((IE || (Velocity.State.isAndroid && !Velocity.State.isChrome)) && Data(element).isSVG) {
                /* Since transform values are stored in their parentheses-wrapped form, we use a helper function to strip out their numeric values.
                   Further, SVG transform properties only take unitless (representing pixels) values, so it's okay that parseFloat() strips the unit suffixed to the float value. */
                function getTransformFloat (transformProperty) {
                    return parseFloat(CSS.getPropertyValue(element, transformProperty));
                }

                /* Create an object to organize all the transforms that we'll apply to the SVG element. To keep the logic simple,
                   we process *all* transform properties -- even those that may not be explicitly applied (since they default to their zero-values anyway). */
                var SVGTransforms = {
                    translate: [ getTransformFloat("translateX"), getTransformFloat("translateY") ],
                    skewX: [ getTransformFloat("skewX") ], skewY: [ getTransformFloat("skewY") ],
                    /* If the scale property is set (non-1), use that value for the scaleX and scaleY values
                       (this behavior mimics the result of animating all these properties at once on HTML elements). */
                    scale: getTransformFloat("scale") !== 1 ? [ getTransformFloat("scale"), getTransformFloat("scale") ] : [ getTransformFloat("scaleX"), getTransformFloat("scaleY") ],
                    /* Note: SVG's rotate transform takes three values: rotation degrees followed by the X and Y values
                       defining the rotation's origin point. We ignore the origin values (default them to 0). */
                    rotate: [ getTransformFloat("rotateZ"), 0, 0 ]
                };

                /* Iterate through the transform properties in the user-defined property map order.
                   (This mimics the behavior of non-SVG transform animation.) */
                $.each(Data(element).transformCache, function(transformName) {
                    /* Except for with skewX/Y, revert the axis-specific transform subproperties to their axis-free master
                       properties so that they match up with SVG's accepted transform properties. */
                    if (/^translate/i.test(transformName)) {
                        transformName = "translate";
                    } else if (/^scale/i.test(transformName)) {
                        transformName = "scale";
                    } else if (/^rotate/i.test(transformName)) {
                        transformName = "rotate";
                    }

                    /* Check that we haven't yet deleted the property from the SVGTransforms container. */
                    if (SVGTransforms[transformName]) {
                        /* Append the transform property in the SVG-supported transform format. As per the spec, surround the space-delimited values in parentheses. */
                        transformString += transformName + "(" + SVGTransforms[transformName].join(" ") + ")" + " ";

                        /* After processing an SVG transform property, delete it from the SVGTransforms container so we don't
                           re-insert the same master property if we encounter another one of its axis-specific properties. */
                        delete SVGTransforms[transformName];
                    }
                });
            } else {
                var transformValue,
                    perspective;

                /* Transform properties are stored as members of the transformCache object. Concatenate all the members into a string. */
                $.each(Data(element).transformCache, function(transformName) {
                    transformValue = Data(element).transformCache[transformName];

                    /* Transform's perspective subproperty must be set first in order to take effect. Store it temporarily. */
                    if (transformName === "transformPerspective") {
                        perspective = transformValue;
                        return true;
                    }

                    /* IE9 only supports one rotation type, rotateZ, which it refers to as "rotate". */
                    if (IE === 9 && transformName === "rotateZ") {
                        transformName = "rotate";
                    }

                    transformString += transformName + transformValue + " ";
                });

                /* If present, set the perspective subproperty first. */
                if (perspective) {
                    transformString = "perspective" + perspective + " " + transformString;
                }
            }

            CSS.setPropertyValue(element, "transform", transformString);
        }
    };

    /* Register hooks and normalizations. */
    CSS.Hooks.register();
    CSS.Normalizations.register();

    /* Allow hook setting in the same fashion as jQuery's $.css(). */
    Velocity.hook = function (elements, arg2, arg3) {
        var value = undefined;

        elements = sanitizeElements(elements);

        $.each(elements, function(i, element) {
            /* Initialize Velocity's per-element data cache if this element hasn't previously been animated. */
            if (Data(element) === undefined) {
                Velocity.init(element);
            }

            /* Get property value. If an element set was passed in, only return the value for the first element. */
            if (arg3 === undefined) {
                if (value === undefined) {
                    value = Velocity.CSS.getPropertyValue(element, arg2);
                }
            /* Set property value. */
            } else {
                /* sPV returns an array of the normalized propertyName/propertyValue pair used to update the DOM. */
                var adjustedSet = Velocity.CSS.setPropertyValue(element, arg2, arg3);

                /* Transform properties don't automatically set. They have to be flushed to the DOM. */
                if (adjustedSet[0] === "transform") {
                    Velocity.CSS.flushTransformCache(element);
                }

                value = adjustedSet;
            }
        });

        return value;
    };

    /*****************
        Animation
    *****************/

    var animate = function() {

        /******************
            Call Chain
        ******************/

        /* Logic for determining what to return to the call stack when exiting out of Velocity. */
        function getChain () {
            /* If we are using the utility function, attempt to return this call's promise. If no promise library was detected,
               default to null instead of returning the targeted elements so that utility function's return value is standardized. */
            if (isUtility) {
                return promiseData.promise || null;
            /* Otherwise, if we're using $.fn, return the jQuery-/Zepto-wrapped element set. */
            } else {
                return elementsWrapped;
            }
        }

        /*************************
           Arguments Assignment
        *************************/

        /* To allow for expressive CoffeeScript code, Velocity supports an alternative syntax in which "properties" and "options"
           objects are defined on a container object that's passed in as Velocity's sole argument. */
        /* Note: Some browsers automatically populate arguments with a "properties" object. We detect it by checking for its default "names" property. */
        var syntacticSugar = (arguments[0] && (($.isPlainObject(arguments[0].properties) && !arguments[0].properties.names) || Type.isString(arguments[0].properties))),
            /* Whether Velocity was called via the utility function (as opposed to on a jQuery/Zepto object). */
            isUtility,
            /* When Velocity is called via the utility function ($.Velocity()/Velocity()), elements are explicitly
               passed in as the first parameter. Thus, argument positioning varies. We normalize them here. */
            elementsWrapped,
            argumentIndex;

        var elements,
            propertiesMap,
            options;

        /* Detect jQuery/Zepto elements being animated via the $.fn method. */
        if (Type.isWrapped(this)) {
            isUtility = false;

            argumentIndex = 0;
            elements = this;
            elementsWrapped = this;
        /* Otherwise, raw elements are being animated via the utility function. */
        } else {
            isUtility = true;

            argumentIndex = 1;
            elements = syntacticSugar ? arguments[0].elements : arguments[0];
        }

        elements = sanitizeElements(elements);

        if (!elements) {
            return;
        }

        if (syntacticSugar) {
            propertiesMap = arguments[0].properties;
            options = arguments[0].options;
        } else {
            propertiesMap = arguments[argumentIndex];
            options = arguments[argumentIndex + 1];
        }

        /* The length of the element set (in the form of a nodeList or an array of elements) is defaulted to 1 in case a
           single raw DOM element is passed in (which doesn't contain a length property). */
        var elementsLength = elements.length,
            elementsIndex = 0;

        /***************************
            Argument Overloading
        ***************************/

        /* Support is included for jQuery's argument overloading: $.animate(propertyMap [, duration] [, easing] [, complete]).
           Overloading is detected by checking for the absence of an object being passed into options. */
        /* Note: The stop action does not accept animation options, and is therefore excluded from this check. */
        if (propertiesMap !== "stop" && !$.isPlainObject(options)) {
            /* The utility function shifts all arguments one position to the right, so we adjust for that offset. */
            var startingArgumentPosition = argumentIndex + 1;

            options = {};

            /* Iterate through all options arguments */
            for (var i = startingArgumentPosition; i < arguments.length; i++) {
                /* Treat a number as a duration. Parse it out. */
                /* Note: The following RegEx will return true if passed an array with a number as its first item.
                   Thus, arrays are skipped from this check. */
                if (!Type.isArray(arguments[i]) && (/^(fast|normal|slow)$/i.test(arguments[i]) || /^\d/.test(arguments[i]))) {
                    options.duration = arguments[i];
                /* Treat strings and arrays as easings. */
                } else if (Type.isString(arguments[i]) || Type.isArray(arguments[i])) {
                    options.easing = arguments[i];
                /* Treat a function as a complete callback. */
                } else if (Type.isFunction(arguments[i])) {
                    options.complete = arguments[i];
                }
            }
        }

        /***************
            Promises
        ***************/

        var promiseData = {
                promise: null,
                resolver: null,
                rejecter: null
            };

        /* If this call was made via the utility function (which is the default method of invocation when jQuery/Zepto are not being used), and if
           promise support was detected, create a promise object for this call and store references to its resolver and rejecter methods. The resolve
           method is used when a call completes naturally or is prematurely stopped by the user. In both cases, completeCall() handles the associated
           call cleanup and promise resolving logic. The reject method is used when an invalid set of arguments is passed into a Velocity call. */
        /* Note: Velocity employs a call-based queueing architecture, which means that stopping an animating element actually stops the full call that
           triggered it -- not that one element exclusively. Similarly, there is one promise per call, and all elements targeted by a Velocity call are
           grouped together for the purposes of resolving and rejecting a promise. */
        if (isUtility && Velocity.Promise) {
            promiseData.promise = new Velocity.Promise(function (resolve, reject) {
                promiseData.resolver = resolve;
                promiseData.rejecter = reject;
            });
        }

        /*********************
           Action Detection
        *********************/

        /* Velocity's behavior is categorized into "actions": Elements can either be specially scrolled into view,
           or they can be started, stopped, or reversed. If a literal or referenced properties map is passed in as Velocity's
           first argument, the associated action is "start". Alternatively, "scroll", "reverse", or "stop" can be passed in instead of a properties map. */
        var action;

        switch (propertiesMap) {
            case "scroll":
                action = "scroll";
                break;

            case "reverse":
                action = "reverse";
                break;

            case "stop":
                /*******************
                    Action: Stop
                *******************/

                /* Clear the currently-active delay on each targeted element. */
                $.each(elements, function(i, element) {
                    if (Data(element) && Data(element).delayTimer) {
                        /* Stop the timer from triggering its cached next() function. */
                        clearTimeout(Data(element).delayTimer.setTimeout);

                        /* Manually call the next() function so that the subsequent queue items can progress. */
                        if (Data(element).delayTimer.next) {
                            Data(element).delayTimer.next();
                        }

                        delete Data(element).delayTimer;
                    }
                });

                var callsToStop = [];

                /* When the stop action is triggered, the elements' currently active call is immediately stopped. The active call might have
                   been applied to multiple elements, in which case all of the call's elements will be subjected to stopping. When an element
                   is stopped, the next item in its animation queue is immediately triggered. */
                /* An additional argument may be passed in to clear an element's remaining queued calls. Either true (which defaults to the "fx" queue)
                   or a custom queue string can be passed in. */
                /* Note: The stop command runs prior to Queueing since its behavior is intended to take effect *immediately*,
                   regardless of the element's current queue state. */

                /* Iterate through every active call. */
                $.each(Velocity.State.calls, function(i, activeCall) {
                    /* Inactive calls are set to false by the logic inside completeCall(). Skip them. */
                    if (activeCall) {
                        /* Iterate through the active call's targeted elements. */
                        $.each(activeCall[1], function(k, activeElement) {
                            var queueName = Type.isString(options) ? options : "";

                            if (options !== undefined && activeCall[2].queue !== queueName) {
                                return true;
                            }

                            /* Iterate through the calls targeted by the stop command. */
                            $.each(elements, function(l, element) {
                                /* Check that this call was applied to the target element. */
                                if (element === activeElement) {
                                    /* Optionally clear the remaining queued calls. */
                                    if (options !== undefined) {
                                        /* Iterate through the items in the element's queue. */
                                        $.each($.queue(element, queueName), function(_, item) {
                                            /* The queue array can contain an "inprogress" string, which we skip. */
                                            if (Type.isFunction(item)) {
                                                /* Pass the item's callback a flag indicating that we want to abort from the queue call.
                                                   (Specifically, the queue will resolve the call's associated promise then abort.)  */
                                                item(null, true);
                                            }
                                        });

                                        /* Clearing the $.queue() array is achieved by resetting it to []. */
                                        $.queue(element, queueName, []);
                                    }

                                    if (Data(element) && queueName === "") {
                                        /* Since "reverse" uses cached start values (the previous call's endValues),
                                           these values must be changed to reflect the final value that the elements were actually tweened to. */
                                        $.each(Data(element).tweensContainer, function(m, activeTween) {
                                            activeTween.endValue = activeTween.currentValue;
                                        });
                                    }

                                    callsToStop.push(i);
                                }
                            });
                        });
                    }
                });

                /* Prematurely call completeCall() on each matched active call, passing an additional flag to indicate
                   that the complete callback and display:none setting should be skipped since we're completing prematurely. */
                $.each(callsToStop, function(i, j) {
                    completeCall(j, true);
                });

                if (promiseData.promise) {
                    /* Immediately resolve the promise associated with this stop call since stop runs synchronously. */
                    promiseData.resolver(elements);
                }

                /* Since we're stopping, and not proceeding with queueing, exit out of Velocity. */
                return getChain();

            default:
                /* Treat a non-empty plain object as a literal properties map. */
                if ($.isPlainObject(propertiesMap) && !Type.isEmptyObject(propertiesMap)) {
                    action = "start";

                /****************
                    Redirects
                ****************/

                /* Check if a string matches a registered redirect (see Redirects above). */
                } else if (Type.isString(propertiesMap) && Velocity.Redirects[propertiesMap]) {
                    var opts = $.extend({}, options),
                        durationOriginal = opts.duration,
                        delayOriginal = opts.delay || 0;

                    /* If the backwards option was passed in, reverse the element set so that elements animate from the last to the first. */
                    if (opts.backwards === true) {
                        elements = $.extend(true, [], elements).reverse();
                    }

                    /* Individually trigger the redirect for each element in the set to prevent users from having to handle iteration logic in their redirect. */
                    $.each(elements, function(elementIndex, element) {
                        /* If the stagger option was passed in, successively delay each element by the stagger value (in ms). Retain the original delay value. */
                        if (parseFloat(opts.stagger)) {
                            opts.delay = delayOriginal + (parseFloat(opts.stagger) * elementIndex);
                        } else if (Type.isFunction(opts.stagger)) {
                            opts.delay = delayOriginal + opts.stagger.call(element, elementIndex, elementsLength);
                        }

                        /* If the drag option was passed in, successively increase/decrease (depending on the presense of opts.backwards)
                           the duration of each element's animation, using floors to prevent producing very short durations. */
                        if (opts.drag) {
                            /* Default the duration of UI pack effects (callouts and transitions) to 1000ms instead of the usual default duration of 400ms. */
                            opts.duration = parseFloat(durationOriginal) || (/^(callout|transition)/.test(propertiesMap) ? 1000 : DURATION_DEFAULT);

                            /* For each element, take the greater duration of: A) animation completion percentage relative to the original duration,
                               B) 75% of the original duration, or C) a 200ms fallback (in case duration is already set to a low value).
                               The end result is a baseline of 75% of the redirect's duration that increases/decreases as the end of the element set is approached. */
                            opts.duration = Math.max(opts.duration * (opts.backwards ? 1 - elementIndex/elementsLength : (elementIndex + 1) / elementsLength), opts.duration * 0.75, 200);
                        }

                        /* Pass in the call's opts object so that the redirect can optionally extend it. It defaults to an empty object instead of null to
                           reduce the opts checking logic required inside the redirect. */
                        Velocity.Redirects[propertiesMap].call(element, element, opts || {}, elementIndex, elementsLength, elements, promiseData.promise ? promiseData : undefined);
                    });

                    /* Since the animation logic resides within the redirect's own code, abort the remainder of this call.
                       (The performance overhead up to this point is virtually non-existant.) */
                    /* Note: The jQuery call chain is kept intact by returning the complete element set. */
                    return getChain();
                } else {
                    var abortError = "Velocity: First argument (" + propertiesMap + ") was not a property map, a known action, or a registered redirect. Aborting.";

                    if (promiseData.promise) {
                        promiseData.rejecter(new Error(abortError));
                    } else {
                        console.log(abortError);
                    }

                    return getChain();
                }
        }

        /**************************
            Call-Wide Variables
        **************************/

        /* A container for CSS unit conversion ratios (e.g. %, rem, and em ==> px) that is used to cache ratios across all elements
           being animated in a single Velocity call. Calculating unit ratios necessitates DOM querying and updating, and is therefore
           avoided (via caching) wherever possible. This container is call-wide instead of page-wide to avoid the risk of using stale
           conversion metrics across Velocity animations that are not immediately consecutively chained. */
        var callUnitConversionData = {
                lastParent: null,
                lastPosition: null,
                lastFontSize: null,
                lastPercentToPxWidth: null,
                lastPercentToPxHeight: null,
                lastEmToPx: null,
                remToPx: null,
                vwToPx: null,
                vhToPx: null
            };

        /* A container for all the ensuing tween data and metadata associated with this call. This container gets pushed to the page-wide
           Velocity.State.calls array that is processed during animation ticking. */
        var call = [];

        /************************
           Element Processing
        ************************/

        /* Element processing consists of three parts -- data processing that cannot go stale and data processing that *can* go stale (i.e. third-party style modifications):
           1) Pre-Queueing: Element-wide variables, including the element's data storage, are instantiated. Call options are prepared. If triggered, the Stop action is executed.
           2) Queueing: The logic that runs once this call has reached its point of execution in the element's $.queue() stack. Most logic is placed here to avoid risking it becoming stale.
           3) Pushing: Consolidation of the tween data followed by its push onto the global in-progress calls container.
        */

        function processElement () {

            /*************************
               Part I: Pre-Queueing
            *************************/

            /***************************
               Element-Wide Variables
            ***************************/

            var element = this,
                /* The runtime opts object is the extension of the current call's options and Velocity's page-wide option defaults. */
                opts = $.extend({}, Velocity.defaults, options),
                /* A container for the processed data associated with each property in the propertyMap.
                   (Each property in the map produces its own "tween".) */
                tweensContainer = {},
                elementUnitConversionData;

            /******************
               Element Init
            ******************/

            if (Data(element) === undefined) {
                Velocity.init(element);
            }

            /******************
               Option: Delay
            ******************/

            /* Since queue:false doesn't respect the item's existing queue, we avoid injecting its delay here (it's set later on). */
            /* Note: Velocity rolls its own delay function since jQuery doesn't have a utility alias for $.fn.delay()
               (and thus requires jQuery element creation, which we avoid since its overhead includes DOM querying). */
            if (parseFloat(opts.delay) && opts.queue !== false) {
                $.queue(element, opts.queue, function(next) {
                    /* This is a flag used to indicate to the upcoming completeCall() function that this queue entry was initiated by Velocity. See completeCall() for further details. */
                    Velocity.velocityQueueEntryFlag = true;

                    /* The ensuing queue item (which is assigned to the "next" argument that $.queue() automatically passes in) will be triggered after a setTimeout delay.
                       The setTimeout is stored so that it can be subjected to clearTimeout() if this animation is prematurely stopped via Velocity's "stop" command. */
                    Data(element).delayTimer = {
                        setTimeout: setTimeout(next, parseFloat(opts.delay)),
                        next: next
                    };
                });
            }

            /*********************
               Option: Duration
            *********************/

            /* Support for jQuery's named durations. */
            switch (opts.duration.toString().toLowerCase()) {
                case "fast":
                    opts.duration = 200;
                    break;

                case "normal":
                    opts.duration = DURATION_DEFAULT;
                    break;

                case "slow":
                    opts.duration = 600;
                    break;

                default:
                    /* Remove the potential "ms" suffix and default to 1 if the user is attempting to set a duration of 0 (in order to produce an immediate style change). */
                    opts.duration = parseFloat(opts.duration) || 1;
            }

            /************************
               Global Option: Mock
            ************************/

            if (Velocity.mock !== false) {
                /* In mock mode, all animations are forced to 1ms so that they occur immediately upon the next rAF tick.
                   Alternatively, a multiplier can be passed in to time remap all delays and durations. */
                if (Velocity.mock === true) {
                    opts.duration = opts.delay = 1;
                } else {
                    opts.duration *= parseFloat(Velocity.mock) || 1;
                    opts.delay *= parseFloat(Velocity.mock) || 1;
                }
            }

            /*******************
               Option: Easing
            *******************/

            opts.easing = getEasing(opts.easing, opts.duration);

            /**********************
               Option: Callbacks
            **********************/

            /* Callbacks must functions. Otherwise, default to null. */
            if (opts.begin && !Type.isFunction(opts.begin)) {
                opts.begin = null;
            }

            if (opts.progress && !Type.isFunction(opts.progress)) {
                opts.progress = null;
            }

            if (opts.complete && !Type.isFunction(opts.complete)) {
                opts.complete = null;
            }

            /*********************************
               Option: Display & Visibility
            *********************************/

            /* Refer to Velocity's documentation (VelocityJS.org/#displayAndVisibility) for a description of the display and visibility options' behavior. */
            /* Note: We strictly check for undefined instead of falsiness because display accepts an empty string value. */
            if (opts.display !== undefined && opts.display !== null) {
                opts.display = opts.display.toString().toLowerCase();

                /* Users can pass in a special "auto" value to instruct Velocity to set the element to its default display value. */
                if (opts.display === "auto") {
                    opts.display = Velocity.CSS.Values.getDisplayType(element);
                }
            }

            if (opts.visibility !== undefined && opts.visibility !== null) {
                opts.visibility = opts.visibility.toString().toLowerCase();
            }

            /**********************
               Option: mobileHA
            **********************/

            /* When set to true, and if this is a mobile device, mobileHA automatically enables hardware acceleration (via a null transform hack)
               on animating elements. HA is removed from the element at the completion of its animation. */
            /* Note: Android Gingerbread doesn't support HA. If a null transform hack (mobileHA) is in fact set, it will prevent other tranform subproperties from taking effect. */
            /* Note: You can read more about the use of mobileHA in Velocity's documentation: VelocityJS.org/#mobileHA. */
            opts.mobileHA = (opts.mobileHA && Velocity.State.isMobile && !Velocity.State.isGingerbread);

            /***********************
               Part II: Queueing
            ***********************/

            /* When a set of elements is targeted by a Velocity call, the set is broken up and each element has the current Velocity call individually queued onto it.
               In this way, each element's existing queue is respected; some elements may already be animating and accordingly should not have this current Velocity call triggered immediately. */
            /* In each queue, tween data is processed for each animating property then pushed onto the call-wide calls array. When the last element in the set has had its tweens processed,
               the call array is pushed to Velocity.State.calls for live processing by the requestAnimationFrame tick. */
            function buildQueue (next) {

                /*******************
                   Option: Begin
                *******************/

                /* The begin callback is fired once per call -- not once per elemenet -- and is passed the full raw DOM element set as both its context and its first argument. */
                if (opts.begin && elementsIndex === 0) {
                    /* We throw callbacks in a setTimeout so that thrown errors don't halt the execution of Velocity itself. */
                    try {
                        opts.begin.call(elements, elements);
                    } catch (error) {
                        setTimeout(function() { throw error; }, 1);
                    }
                }

                /*****************************************
                   Tween Data Construction (for Scroll)
                *****************************************/

                /* Note: In order to be subjected to chaining and animation options, scroll's tweening is routed through Velocity as if it were a standard CSS property animation. */
                if (action === "scroll") {
                    /* The scroll action uniquely takes an optional "offset" option -- specified in pixels -- that offsets the targeted scroll position. */
                    var scrollDirection = (/^x$/i.test(opts.axis) ? "Left" : "Top"),
                        scrollOffset = parseFloat(opts.offset) || 0,
                        scrollPositionCurrent,
                        scrollPositionCurrentAlternate,
                        scrollPositionEnd;

                    /* Scroll also uniquely takes an optional "container" option, which indicates the parent element that should be scrolled --
                       as opposed to the browser window itself. This is useful for scrolling toward an element that's inside an overflowing parent element. */
                    if (opts.container) {
                        /* Ensure that either a jQuery object or a raw DOM element was passed in. */
                        if (Type.isWrapped(opts.container) || Type.isNode(opts.container)) {
                            /* Extract the raw DOM element from the jQuery wrapper. */
                            opts.container = opts.container[0] || opts.container;
                            /* Note: Unlike other properties in Velocity, the browser's scroll position is never cached since it so frequently changes
                               (due to the user's natural interaction with the page). */
                            scrollPositionCurrent = opts.container["scroll" + scrollDirection]; /* GET */

                            /* $.position() values are relative to the container's currently viewable area (without taking into account the container's true dimensions
                               -- say, for example, if the container was not overflowing). Thus, the scroll end value is the sum of the child element's position *and*
                               the scroll container's current scroll position. */
                            /* Note: jQuery does not offer a utility alias for $.position(), so we have to incur jQuery object conversion here.
                               This syncs up with an ensuing batch of GETs, so it fortunately does not trigger layout thrashing. */
                            scrollPositionEnd = (scrollPositionCurrent + $(element).position()[scrollDirection.toLowerCase()]) + scrollOffset; /* GET */
                        /* If a value other than a jQuery object or a raw DOM element was passed in, default to null so that this option is ignored. */
                        } else {
                            opts.container = null;
                        }
                    } else {
                        /* If the window itself is being scrolled -- not a containing element -- perform a live scroll position lookup using
                           the appropriate cached property names (which differ based on browser type). */
                        scrollPositionCurrent = Velocity.State.scrollAnchor[Velocity.State["scrollProperty" + scrollDirection]]; /* GET */
                        /* When scrolling the browser window, cache the alternate axis's current value since window.scrollTo() doesn't let us change only one value at a time. */
                        scrollPositionCurrentAlternate = Velocity.State.scrollAnchor[Velocity.State["scrollProperty" + (scrollDirection === "Left" ? "Top" : "Left")]]; /* GET */

                        /* Unlike $.position(), $.offset() values are relative to the browser window's true dimensions -- not merely its currently viewable area --
                           and therefore end values do not need to be compounded onto current values. */
                        scrollPositionEnd = $(element).offset()[scrollDirection.toLowerCase()] + scrollOffset; /* GET */
                    }

                    /* Since there's only one format that scroll's associated tweensContainer can take, we create it manually. */
                    tweensContainer = {
                        scroll: {
                            rootPropertyValue: false,
                            startValue: scrollPositionCurrent,
                            currentValue: scrollPositionCurrent,
                            endValue: scrollPositionEnd,
                            unitType: "",
                            easing: opts.easing,
                            scrollData: {
                                container: opts.container,
                                direction: scrollDirection,
                                alternateValue: scrollPositionCurrentAlternate
                            }
                        },
                        element: element
                    };

                    if (Velocity.debug) console.log("tweensContainer (scroll): ", tweensContainer.scroll, element);

                /******************************************
                   Tween Data Construction (for Reverse)
                ******************************************/

                /* Reverse acts like a "start" action in that a property map is animated toward. The only difference is
                   that the property map used for reverse is the inverse of the map used in the previous call. Thus, we manipulate
                   the previous call to construct our new map: use the previous map's end values as our new map's start values. Copy over all other data. */
                /* Note: Reverse can be directly called via the "reverse" parameter, or it can be indirectly triggered via the loop option. (Loops are composed of multiple reverses.) */
                /* Note: Reverse calls do not need to be consecutively chained onto a currently-animating element in order to operate on cached values;
                   there is no harm to reverse being called on a potentially stale data cache since reverse's behavior is simply defined
                   as reverting to the element's values as they were prior to the previous *Velocity* call. */
                } else if (action === "reverse") {
                    /* Abort if there is no prior animation data to reverse to. */
                    if (!Data(element).tweensContainer) {
                        /* Dequeue the element so that this queue entry releases itself immediately, allowing subsequent queue entries to run. */
                        $.dequeue(element, opts.queue);

                        return;
                    } else {
                        /*********************
                           Options Parsing
                        *********************/

                        /* If the element was hidden via the display option in the previous call,
                           revert display to "auto" prior to reversal so that the element is visible again. */
                        if (Data(element).opts.display === "none") {
                            Data(element).opts.display = "auto";
                        }

                        if (Data(element).opts.visibility === "hidden") {
                            Data(element).opts.visibility = "visible";
                        }

                        /* If the loop option was set in the previous call, disable it so that "reverse" calls aren't recursively generated.
                           Further, remove the previous call's callback options; typically, users do not want these to be refired. */
                        Data(element).opts.loop = false;
                        Data(element).opts.begin = null;
                        Data(element).opts.complete = null;

                        /* Since we're extending an opts object that has already been extended with the defaults options object,
                           we remove non-explicitly-defined properties that are auto-assigned values. */
                        if (!options.easing) {
                            delete opts.easing;
                        }

                        if (!options.duration) {
                            delete opts.duration;
                        }

                        /* The opts object used for reversal is an extension of the options object optionally passed into this
                           reverse call plus the options used in the previous Velocity call. */
                        opts = $.extend({}, Data(element).opts, opts);

                        /*************************************
                           Tweens Container Reconstruction
                        *************************************/

                        /* Create a deepy copy (indicated via the true flag) of the previous call's tweensContainer. */
                        var lastTweensContainer = $.extend(true, {}, Data(element).tweensContainer);

                        /* Manipulate the previous tweensContainer by replacing its end values and currentValues with its start values. */
                        for (var lastTween in lastTweensContainer) {
                            /* In addition to tween data, tweensContainers contain an element property that we ignore here. */
                            if (lastTween !== "element") {
                                var lastStartValue = lastTweensContainer[lastTween].startValue;

                                lastTweensContainer[lastTween].startValue = lastTweensContainer[lastTween].currentValue = lastTweensContainer[lastTween].endValue;
                                lastTweensContainer[lastTween].endValue = lastStartValue;

                                /* Easing is the only option that embeds into the individual tween data (since it can be defined on a per-property basis).
                                   Accordingly, every property's easing value must be updated when an options object is passed in with a reverse call.
                                   The side effect of this extensibility is that all per-property easing values are forcefully reset to the new value. */
                                if (!Type.isEmptyObject(options)) {
                                    lastTweensContainer[lastTween].easing = opts.easing;
                                }

                                if (Velocity.debug) console.log("reverse tweensContainer (" + lastTween + "): " + JSON.stringify(lastTweensContainer[lastTween]), element);
                            }
                        }

                        tweensContainer = lastTweensContainer;
                    }

                /*****************************************
                   Tween Data Construction (for Start)
                *****************************************/

                } else if (action === "start") {

                    /*************************
                        Value Transferring
                    *************************/

                    /* If this queue entry follows a previous Velocity-initiated queue entry *and* if this entry was created
                       while the element was in the process of being animated by Velocity, then this current call is safe to use
                       the end values from the prior call as its start values. Velocity attempts to perform this value transfer
                       process whenever possible in order to avoid requerying the DOM. */
                    /* If values aren't transferred from a prior call and start values were not forcefed by the user (more on this below),
                       then the DOM is queried for the element's current values as a last resort. */
                    /* Note: Conversely, animation reversal (and looping) *always* perform inter-call value transfers; they never requery the DOM. */
                    var lastTweensContainer;

                    /* The per-element isAnimating flag is used to indicate whether it's safe (i.e. the data isn't stale)
                       to transfer over end values to use as start values. If it's set to true and there is a previous
                       Velocity call to pull values from, do so. */
                    if (Data(element).tweensContainer && Data(element).isAnimating === true) {
                        lastTweensContainer = Data(element).tweensContainer;
                    }

                    /***************************
                       Tween Data Calculation
                    ***************************/

                    /* This function parses property data and defaults endValue, easing, and startValue as appropriate. */
                    /* Property map values can either take the form of 1) a single value representing the end value,
                       or 2) an array in the form of [ endValue, [, easing] [, startValue] ].
                       The optional third parameter is a forcefed startValue to be used instead of querying the DOM for
                       the element's current value. Read Velocity's docmentation to learn more about forcefeeding: VelocityJS.org/#forcefeeding */
                    function parsePropertyValue (valueData, skipResolvingEasing) {
                        var endValue = undefined,
                            easing = undefined,
                            startValue = undefined;

                        /* Handle the array format, which can be structured as one of three potential overloads:
                           A) [ endValue, easing, startValue ], B) [ endValue, easing ], or C) [ endValue, startValue ] */
                        if (Type.isArray(valueData)) {
                            /* endValue is always the first item in the array. Don't bother validating endValue's value now
                               since the ensuing property cycling logic does that. */
                            endValue = valueData[0];

                            /* Two-item array format: If the second item is a number, function, or hex string, treat it as a
                               start value since easings can only be non-hex strings or arrays. */
                            if ((!Type.isArray(valueData[1]) && /^[\d-]/.test(valueData[1])) || Type.isFunction(valueData[1]) || CSS.RegEx.isHex.test(valueData[1])) {
                                startValue = valueData[1];
                            /* Two or three-item array: If the second item is a non-hex string or an array, treat it as an easing. */
                            } else if ((Type.isString(valueData[1]) && !CSS.RegEx.isHex.test(valueData[1])) || Type.isArray(valueData[1])) {
                                easing = skipResolvingEasing ? valueData[1] : getEasing(valueData[1], opts.duration);

                                /* Don't bother validating startValue's value now since the ensuing property cycling logic inherently does that. */
                                if (valueData[2] !== undefined) {
                                    startValue = valueData[2];
                                }
                            }
                        /* Handle the single-value format. */
                        } else {
                            endValue = valueData;
                        }

                        /* Default to the call's easing if a per-property easing type was not defined. */
                        if (!skipResolvingEasing) {
                            easing = easing || opts.easing;
                        }

                        /* If functions were passed in as values, pass the function the current element as its context,
                           plus the element's index and the element set's size as arguments. Then, assign the returned value. */
                        if (Type.isFunction(endValue)) {
                            endValue = endValue.call(element, elementsIndex, elementsLength);
                        }

                        if (Type.isFunction(startValue)) {
                            startValue = startValue.call(element, elementsIndex, elementsLength);
                        }

                        /* Allow startValue to be left as undefined to indicate to the ensuing code that its value was not forcefed. */
                        return [ endValue || 0, easing, startValue ];
                    }

                    /* Cycle through each property in the map, looking for shorthand color properties (e.g. "color" as opposed to "colorRed"). Inject the corresponding
                       colorRed, colorGreen, and colorBlue RGB component tweens into the propertiesMap (which Velocity understands) and remove the shorthand property. */
                    $.each(propertiesMap, function(property, value) {
                        /* Find shorthand color properties that have been passed a hex string. */
                        if (RegExp("^" + CSS.Lists.colors.join("$|^") + "$").test(property)) {
                            /* Parse the value data for each shorthand. */
                            var valueData = parsePropertyValue(value, true),
                                endValue = valueData[0],
                                easing = valueData[1],
                                startValue = valueData[2];

                            if (CSS.RegEx.isHex.test(endValue)) {
                                /* Convert the hex strings into their RGB component arrays. */
                                var colorComponents = [ "Red", "Green", "Blue" ],
                                    endValueRGB = CSS.Values.hexToRgb(endValue),
                                    startValueRGB = startValue ? CSS.Values.hexToRgb(startValue) : undefined;

                                /* Inject the RGB component tweens into propertiesMap. */
                                for (var i = 0; i < colorComponents.length; i++) {
                                    var dataArray = [ endValueRGB[i] ];

                                    if (easing) {
                                        dataArray.push(easing);
                                    }

                                    if (startValueRGB !== undefined) {
                                        dataArray.push(startValueRGB[i]);
                                    }

                                    propertiesMap[property + colorComponents[i]] = dataArray;
                                }

                                /* Remove the intermediary shorthand property entry now that we've processed it. */
                                delete propertiesMap[property];
                            }
                        }
                    });

                    /* Create a tween out of each property, and append its associated data to tweensContainer. */
                    for (var property in propertiesMap) {

                        /**************************
                           Start Value Sourcing
                        **************************/

                        /* Parse out endValue, easing, and startValue from the property's data. */
                        var valueData = parsePropertyValue(propertiesMap[property]),
                            endValue = valueData[0],
                            easing = valueData[1],
                            startValue = valueData[2];

                        /* Now that the original property name's format has been used for the parsePropertyValue() lookup above,
                           we force the property to its camelCase styling to normalize it for manipulation. */
                        property = CSS.Names.camelCase(property);

                        /* In case this property is a hook, there are circumstances where we will intend to work on the hook's root property and not the hooked subproperty. */
                        var rootProperty = CSS.Hooks.getRoot(property),
                            rootPropertyValue = false;

                        /* Properties that are not supported by the browser (and do not have an associated normalization) will
                           inherently produce no style changes when set, so they are skipped in order to decrease animation tick overhead.
                           Property support is determined via prefixCheck(), which returns a false flag when no supported is detected. */
                        /* Note: Since SVG elements have some of their properties directly applied as HTML attributes,
                           there is no way to check for their explicit browser support, and so we skip skip this check for them. */
                        if (!Data(element).isSVG && CSS.Names.prefixCheck(rootProperty)[1] === false && CSS.Normalizations.registered[rootProperty] === undefined) {
                            if (Velocity.debug) console.log("Skipping [" + rootProperty + "] due to a lack of browser support.");

                            continue;
                        }

                        /* If the display option is being set to a non-"none" (e.g. "block") and opacity (filter on IE<=8) is being
                           animated to an endValue of non-zero, the user's intention is to fade in from invisible, thus we forcefeed opacity
                           a startValue of 0 if its startValue hasn't already been sourced by value transferring or prior forcefeeding. */
                        if (((opts.display !== undefined && opts.display !== null && opts.display !== "none") || (opts.visibility !== undefined && opts.visibility !== "hidden")) && /opacity|filter/.test(property) && !startValue && endValue !== 0) {
                            startValue = 0;
                        }

                        /* If values have been transferred from the previous Velocity call, extract the endValue and rootPropertyValue
                           for all of the current call's properties that were *also* animated in the previous call. */
                        /* Note: Value transferring can optionally be disabled by the user via the _cacheValues option. */
                        if (opts._cacheValues && lastTweensContainer && lastTweensContainer[property]) {
                            if (startValue === undefined) {
                                startValue = lastTweensContainer[property].endValue + lastTweensContainer[property].unitType;
                            }

                            /* The previous call's rootPropertyValue is extracted from the element's data cache since that's the
                               instance of rootPropertyValue that gets freshly updated by the tweening process, whereas the rootPropertyValue
                               attached to the incoming lastTweensContainer is equal to the root property's value prior to any tweening. */
                            rootPropertyValue = Data(element).rootPropertyValueCache[rootProperty];
                        /* If values were not transferred from a previous Velocity call, query the DOM as needed. */
                        } else {
                            /* Handle hooked properties. */
                            if (CSS.Hooks.registered[property]) {
                               if (startValue === undefined) {
                                    rootPropertyValue = CSS.getPropertyValue(element, rootProperty); /* GET */
                                    /* Note: The following getPropertyValue() call does not actually trigger a DOM query;
                                       getPropertyValue() will extract the hook from rootPropertyValue. */
                                    startValue = CSS.getPropertyValue(element, property, rootPropertyValue);
                                /* If startValue is already defined via forcefeeding, do not query the DOM for the root property's value;
                                   just grab rootProperty's zero-value template from CSS.Hooks. This overwrites the element's actual
                                   root property value (if one is set), but this is acceptable since the primary reason users forcefeed is
                                   to avoid DOM queries, and thus we likewise avoid querying the DOM for the root property's value. */
                                } else {
                                    /* Grab this hook's zero-value template, e.g. "0px 0px 0px black". */
                                    rootPropertyValue = CSS.Hooks.templates[rootProperty][1];
                                }
                            /* Handle non-hooked properties that haven't already been defined via forcefeeding. */
                            } else if (startValue === undefined) {
                                startValue = CSS.getPropertyValue(element, property); /* GET */
                            }
                        }

                        /**************************
                           Value Data Extraction
                        **************************/

                        var separatedValue,
                            endValueUnitType,
                            startValueUnitType,
                            operator = false;

                        /* Separates a property value into its numeric value and its unit type. */
                        function separateValue (property, value) {
                            var unitType,
                                numericValue;

                            numericValue = (value || "0")
                                .toString()
                                .toLowerCase()
                                /* Match the unit type at the end of the value. */
                                .replace(/[%A-z]+$/, function(match) {
                                    /* Grab the unit type. */
                                    unitType = match;

                                    /* Strip the unit type off of value. */
                                    return "";
                                });

                            /* If no unit type was supplied, assign one that is appropriate for this property (e.g. "deg" for rotateZ or "px" for width). */
                            if (!unitType) {
                                unitType = CSS.Values.getUnitType(property);
                            }

                            return [ numericValue, unitType ];
                        }

                        /* Separate startValue. */
                        separatedValue = separateValue(property, startValue);
                        startValue = separatedValue[0];
                        startValueUnitType = separatedValue[1];

                        /* Separate endValue, and extract a value operator (e.g. "+=", "-=") if one exists. */
                        separatedValue = separateValue(property, endValue);
                        endValue = separatedValue[0].replace(/^([+-\/*])=/, function(match, subMatch) {
                            operator = subMatch;

                            /* Strip the operator off of the value. */
                            return "";
                        });
                        endValueUnitType = separatedValue[1];

                        /* Parse float values from endValue and startValue. Default to 0 if NaN is returned. */
                        startValue = parseFloat(startValue) || 0;
                        endValue = parseFloat(endValue) || 0;

                        /***************************************
                           Property-Specific Value Conversion
                        ***************************************/

                        /* Custom support for properties that don't actually accept the % unit type, but where pollyfilling is trivial and relatively foolproof. */
                        if (endValueUnitType === "%") {
                            /* A %-value fontSize/lineHeight is relative to the parent's fontSize (as opposed to the parent's dimensions),
                               which is identical to the em unit's behavior, so we piggyback off of that. */
                            if (/^(fontSize|lineHeight)$/.test(property)) {
                                /* Convert % into an em decimal value. */
                                endValue = endValue / 100;
                                endValueUnitType = "em";
                            /* For scaleX and scaleY, convert the value into its decimal format and strip off the unit type. */
                            } else if (/^scale/.test(property)) {
                                endValue = endValue / 100;
                                endValueUnitType = "";
                            /* For RGB components, take the defined percentage of 255 and strip off the unit type. */
                            } else if (/(Red|Green|Blue)$/i.test(property)) {
                                endValue = (endValue / 100) * 255;
                                endValueUnitType = "";
                            }
                        }

                        /***************************
                           Unit Ratio Calculation
                        ***************************/

                        /* When queried, the browser returns (most) CSS property values in pixels. Therefore, if an endValue with a unit type of
                           %, em, or rem is animated toward, startValue must be converted from pixels into the same unit type as endValue in order
                           for value manipulation logic (increment/decrement) to proceed. Further, if the startValue was forcefed or transferred
                           from a previous call, startValue may also not be in pixels. Unit conversion logic therefore consists of two steps:
                           1) Calculating the ratio of %/em/rem/vh/vw relative to pixels
                           2) Converting startValue into the same unit of measurement as endValue based on these ratios. */
                        /* Unit conversion ratios are calculated by inserting a sibling node next to the target node, copying over its position property,
                           setting values with the target unit type then comparing the returned pixel value. */
                        /* Note: Even if only one of these unit types is being animated, all unit ratios are calculated at once since the overhead
                           of batching the SETs and GETs together upfront outweights the potential overhead
                           of layout thrashing caused by re-querying for uncalculated ratios for subsequently-processed properties. */
                        /* Todo: Shift this logic into the calls' first tick instance so that it's synced with RAF. */
                        function calculateUnitRatios () {

                            /************************
                                Same Ratio Checks
                            ************************/

                            /* The properties below are used to determine whether the element differs sufficiently from this call's
                               previously iterated element to also differ in its unit conversion ratios. If the properties match up with those
                               of the prior element, the prior element's conversion ratios are used. Like most optimizations in Velocity,
                               this is done to minimize DOM querying. */
                            var sameRatioIndicators = {
                                    myParent: element.parentNode || document.body, /* GET */
                                    position: CSS.getPropertyValue(element, "position"), /* GET */
                                    fontSize: CSS.getPropertyValue(element, "fontSize") /* GET */
                                },
                                /* Determine if the same % ratio can be used. % is based on the element's position value and its parent's width and height dimensions. */
                                samePercentRatio = ((sameRatioIndicators.position === callUnitConversionData.lastPosition) && (sameRatioIndicators.myParent === callUnitConversionData.lastParent)),
                                /* Determine if the same em ratio can be used. em is relative to the element's fontSize. */
                                sameEmRatio = (sameRatioIndicators.fontSize === callUnitConversionData.lastFontSize);

                            /* Store these ratio indicators call-wide for the next element to compare against. */
                            callUnitConversionData.lastParent = sameRatioIndicators.myParent;
                            callUnitConversionData.lastPosition = sameRatioIndicators.position;
                            callUnitConversionData.lastFontSize = sameRatioIndicators.fontSize;

                            /***************************
                               Element-Specific Units
                            ***************************/

                            /* Note: IE8 rounds to the nearest pixel when returning CSS values, thus we perform conversions using a measurement
                               of 100 (instead of 1) to give our ratios a precision of at least 2 decimal values. */
                            var measurement = 100,
                                unitRatios = {};

                            if (!sameEmRatio || !samePercentRatio) {
                                var dummy = Data(element).isSVG ? document.createElementNS("http://www.w3.org/2000/svg", "rect") : document.createElement("div");

                                Velocity.init(dummy);
                                sameRatioIndicators.myParent.appendChild(dummy);

                                /* To accurately and consistently calculate conversion ratios, the element's cascaded overflow and box-sizing are stripped.
                                   Similarly, since width/height can be artificially constrained by their min-/max- equivalents, these are controlled for as well. */
                                /* Note: Overflow must be also be controlled for per-axis since the overflow property overwrites its per-axis values. */
                                $.each([ "overflow", "overflowX", "overflowY" ], function(i, property) {
                                    Velocity.CSS.setPropertyValue(dummy, property, "hidden");
                                });
                                Velocity.CSS.setPropertyValue(dummy, "position", sameRatioIndicators.position);
                                Velocity.CSS.setPropertyValue(dummy, "fontSize", sameRatioIndicators.fontSize);
                                Velocity.CSS.setPropertyValue(dummy, "boxSizing", "content-box");

                                /* width and height act as our proxy properties for measuring the horizontal and vertical % ratios. */
                                $.each([ "minWidth", "maxWidth", "width", "minHeight", "maxHeight", "height" ], function(i, property) {
                                    Velocity.CSS.setPropertyValue(dummy, property, measurement + "%");
                                });
                                /* paddingLeft arbitrarily acts as our proxy property for the em ratio. */
                                Velocity.CSS.setPropertyValue(dummy, "paddingLeft", measurement + "em");

                                /* Divide the returned value by the measurement to get the ratio between 1% and 1px. Default to 1 since working with 0 can produce Infinite. */
                                unitRatios.percentToPxWidth = callUnitConversionData.lastPercentToPxWidth = (parseFloat(CSS.getPropertyValue(dummy, "width", null, true)) || 1) / measurement; /* GET */
                                unitRatios.percentToPxHeight = callUnitConversionData.lastPercentToPxHeight = (parseFloat(CSS.getPropertyValue(dummy, "height", null, true)) || 1) / measurement; /* GET */
                                unitRatios.emToPx = callUnitConversionData.lastEmToPx = (parseFloat(CSS.getPropertyValue(dummy, "paddingLeft")) || 1) / measurement; /* GET */

                                sameRatioIndicators.myParent.removeChild(dummy);
                            } else {
                                unitRatios.emToPx = callUnitConversionData.lastEmToPx;
                                unitRatios.percentToPxWidth = callUnitConversionData.lastPercentToPxWidth;
                                unitRatios.percentToPxHeight = callUnitConversionData.lastPercentToPxHeight;
                            }

                            /***************************
                               Element-Agnostic Units
                            ***************************/

                            /* Whereas % and em ratios are determined on a per-element basis, the rem unit only needs to be checked
                               once per call since it's exclusively dependant upon document.body's fontSize. If this is the first time
                               that calculateUnitRatios() is being run during this call, remToPx will still be set to its default value of null,
                               so we calculate it now. */
                            if (callUnitConversionData.remToPx === null) {
                                /* Default to browsers' default fontSize of 16px in the case of 0. */
                                callUnitConversionData.remToPx = parseFloat(CSS.getPropertyValue(document.body, "fontSize")) || 16; /* GET */
                            }

                            /* Similarly, viewport units are %-relative to the window's inner dimensions. */
                            if (callUnitConversionData.vwToPx === null) {
                                callUnitConversionData.vwToPx = parseFloat(window.innerWidth) / 100; /* GET */
                                callUnitConversionData.vhToPx = parseFloat(window.innerHeight) / 100; /* GET */
                            }

                            unitRatios.remToPx = callUnitConversionData.remToPx;
                            unitRatios.vwToPx = callUnitConversionData.vwToPx;
                            unitRatios.vhToPx = callUnitConversionData.vhToPx;

                            if (Velocity.debug >= 1) console.log("Unit ratios: " + JSON.stringify(unitRatios), element);

                            return unitRatios;
                        }

                        /********************
                           Unit Conversion
                        ********************/

                        /* The * and / operators, which are not passed in with an associated unit, inherently use startValue's unit. Skip value and unit conversion. */
                        if (/[\/*]/.test(operator)) {
                            endValueUnitType = startValueUnitType;
                        /* If startValue and endValue differ in unit type, convert startValue into the same unit type as endValue so that if endValueUnitType
                           is a relative unit (%, em, rem), the values set during tweening will continue to be accurately relative even if the metrics they depend
                           on are dynamically changing during the course of the animation. Conversely, if we always normalized into px and used px for setting values, the px ratio
                           would become stale if the original unit being animated toward was relative and the underlying metrics change during the animation. */
                        /* Since 0 is 0 in any unit type, no conversion is necessary when startValue is 0 -- we just start at 0 with endValueUnitType. */
                        } else if ((startValueUnitType !== endValueUnitType) && startValue !== 0) {
                            /* Unit conversion is also skipped when endValue is 0, but *startValueUnitType* must be used for tween values to remain accurate. */
                            /* Note: Skipping unit conversion here means that if endValueUnitType was originally a relative unit, the animation won't relatively
                               match the underlying metrics if they change, but this is acceptable since we're animating toward invisibility instead of toward visibility,
                               which remains past the point of the animation's completion. */
                            if (endValue === 0) {
                                endValueUnitType = startValueUnitType;
                            } else {
                                /* By this point, we cannot avoid unit conversion (it's undesirable since it causes layout thrashing).
                                   If we haven't already, we trigger calculateUnitRatios(), which runs once per element per call. */
                                elementUnitConversionData = elementUnitConversionData || calculateUnitRatios();

                                /* The following RegEx matches CSS properties that have their % values measured relative to the x-axis. */
                                /* Note: W3C spec mandates that all of margin and padding's properties (even top and bottom) are %-relative to the *width* of the parent element. */
                                var axis = (/margin|padding|left|right|width|text|word|letter/i.test(property) || /X$/.test(property) || property === "x") ? "x" : "y";

                                /* In order to avoid generating n^2 bespoke conversion functions, unit conversion is a two-step process:
                                   1) Convert startValue into pixels. 2) Convert this new pixel value into endValue's unit type. */
                                switch (startValueUnitType) {
                                    case "%":
                                        /* Note: translateX and translateY are the only properties that are %-relative to an element's own dimensions -- not its parent's dimensions.
                                           Velocity does not include a special conversion process to account for this behavior. Therefore, animating translateX/Y from a % value
                                           to a non-% value will produce an incorrect start value. Fortunately, this sort of cross-unit conversion is rarely done by users in practice. */
                                        startValue *= (axis === "x" ? elementUnitConversionData.percentToPxWidth : elementUnitConversionData.percentToPxHeight);
                                        break;

                                    case "px":
                                        /* px acts as our midpoint in the unit conversion process; do nothing. */
                                        break;

                                    default:
                                        startValue *= elementUnitConversionData[startValueUnitType + "ToPx"];
                                }

                                /* Invert the px ratios to convert into to the target unit. */
                                switch (endValueUnitType) {
                                    case "%":
                                        startValue *= 1 / (axis === "x" ? elementUnitConversionData.percentToPxWidth : elementUnitConversionData.percentToPxHeight);
                                        break;

                                    case "px":
                                        /* startValue is already in px, do nothing; we're done. */
                                        break;

                                    default:
                                        startValue *= 1 / elementUnitConversionData[endValueUnitType + "ToPx"];
                                }
                            }
                        }

                        /*********************
                           Relative Values
                        *********************/

                        /* Operator logic must be performed last since it requires unit-normalized start and end values. */
                        /* Note: Relative *percent values* do not behave how most people think; while one would expect "+=50%"
                           to increase the property 1.5x its current value, it in fact increases the percent units in absolute terms:
                           50 points is added on top of the current % value. */
                        switch (operator) {
                            case "+":
                                endValue = startValue + endValue;
                                break;

                            case "-":
                                endValue = startValue - endValue;
                                break;

                            case "*":
                                endValue = startValue * endValue;
                                break;

                            case "/":
                                endValue = startValue / endValue;
                                break;
                        }

                        /**************************
                           tweensContainer Push
                        **************************/

                        /* Construct the per-property tween object, and push it to the element's tweensContainer. */
                        tweensContainer[property] = {
                            rootPropertyValue: rootPropertyValue,
                            startValue: startValue,
                            currentValue: startValue,
                            endValue: endValue,
                            unitType: endValueUnitType,
                            easing: easing
                        };

                        if (Velocity.debug) console.log("tweensContainer (" + property + "): " + JSON.stringify(tweensContainer[property]), element);
                    }

                    /* Along with its property data, store a reference to the element itself onto tweensContainer. */
                    tweensContainer.element = element;
                }

                /*****************
                    Call Push
                *****************/

                /* Note: tweensContainer can be empty if all of the properties in this call's property map were skipped due to not
                   being supported by the browser. The element property is used for checking that the tweensContainer has been appended to. */
                if (tweensContainer.element) {
                    /* Apply the "velocity-animating" indicator class. */
                    CSS.Values.addClass(element, "velocity-animating");

                    /* The call array houses the tweensContainers for each element being animated in the current call. */
                    call.push(tweensContainer);

                    /* Store the tweensContainer and options if we're working on the default effects queue, so that they can be used by the reverse command. */
                    if (opts.queue === "") {
                        Data(element).tweensContainer = tweensContainer;
                        Data(element).opts = opts;
                    }

                    /* Switch on the element's animating flag. */
                    Data(element).isAnimating = true;

                    /* Once the final element in this call's element set has been processed, push the call array onto
                       Velocity.State.calls for the animation tick to immediately begin processing. */
                    if (elementsIndex === elementsLength - 1) {
                        /* To speed up iterating over this array, it is compacted (falsey items -- calls that have completed -- are removed)
                           when its length has ballooned to a point that can impact tick performance. This only becomes necessary when animation
                           has been continuous with many elements over a long period of time; whenever all active calls are completed, completeCall() clears Velocity.State.calls. */
                        if (Velocity.State.calls.length > 10000) {
                            Velocity.State.calls = compactSparseArray(Velocity.State.calls);
                        }

                        /* Add the current call plus its associated metadata (the element set and the call's options) onto the global call container.
                           Anything on this call container is subjected to tick() processing. */
                        Velocity.State.calls.push([ call, elements, opts, null, promiseData.resolver ]);

                        /* If the animation tick isn't running, start it. (Velocity shuts it off when there are no active calls to process.) */
                        if (Velocity.State.isTicking === false) {
                            Velocity.State.isTicking = true;

                            /* Start the tick loop. */
                            tick();
                        }
                    } else {
                        elementsIndex++;
                    }
                }
            }

            /* When the queue option is set to false, the call skips the element's queue and fires immediately. */
            if (opts.queue === false) {
                /* Since this buildQueue call doesn't respect the element's existing queue (which is where a delay option would have been appended),
                   we manually inject the delay property here with an explicit setTimeout. */
                if (opts.delay) {
                    setTimeout(buildQueue, opts.delay);
                } else {
                    buildQueue();
                }
            /* Otherwise, the call undergoes element queueing as normal. */
            /* Note: To interoperate with jQuery, Velocity uses jQuery's own $.queue() stack for queuing logic. */
            } else {
                $.queue(element, opts.queue, function(next, clearQueue) {
                    /* If the clearQueue flag was passed in by the stop command, resolve this call's promise. (Promises can only be resolved once,
                       so it's fine if this is repeatedly triggered for each element in the associated call.) */
                    if (clearQueue === true) {
                        if (promiseData.promise) {
                            promiseData.resolver(elements);
                        }

                        /* Do not continue with animation queueing. */
                        return true;
                    }

                    /* This flag indicates to the upcoming completeCall() function that this queue entry was initiated by Velocity.
                       See completeCall() for further details. */
                    Velocity.velocityQueueEntryFlag = true;

                    buildQueue(next);
                });
            }

            /*********************
                Auto-Dequeuing
            *********************/

            /* As per jQuery's $.queue() behavior, to fire the first non-custom-queue entry on an element, the element
               must be dequeued if its queue stack consists *solely* of the current call. (This can be determined by checking
               for the "inprogress" item that jQuery prepends to active queue stack arrays.) Regardless, whenever the element's
               queue is further appended with additional items -- including $.delay()'s or even $.animate() calls, the queue's
               first entry is automatically fired. This behavior contrasts that of custom queues, which never auto-fire. */
            /* Note: When an element set is being subjected to a non-parallel Velocity call, the animation will not begin until
               each one of the elements in the set has reached the end of its individually pre-existing queue chain. */
            /* Note: Unfortunately, most people don't fully grasp jQuery's powerful, yet quirky, $.queue() function.
               Lean more here: http://stackoverflow.com/questions/1058158/can-somebody-explain-jquery-queue-to-me */
            if ((opts.queue === "" || opts.queue === "fx") && $.queue(element)[0] !== "inprogress") {
                $.dequeue(element);
            }
        }

        /**************************
           Element Set Iteration
        **************************/

        /* If the "nodeType" property exists on the elements variable, we're animating a single element.
           Place it in an array so that $.each() can iterate over it. */
        $.each(elements, function(i, element) {
            /* Ensure each element in a set has a nodeType (is a real element) to avoid throwing errors. */
            if (Type.isNode(element)) {
                processElement.call(element);
            }
        });

        /******************
           Option: Loop
        ******************/

        /* The loop option accepts an integer indicating how many times the element should loop between the values in the
           current call's properties map and the element's property values prior to this call. */
        /* Note: The loop option's logic is performed here -- after element processing -- because the current call needs
           to undergo its queue insertion prior to the loop option generating its series of constituent "reverse" calls,
           which chain after the current call. Two reverse calls (two "alternations") constitute one loop. */
        var opts = $.extend({}, Velocity.defaults, options),
            reverseCallsCount;

        opts.loop = parseInt(opts.loop);
        reverseCallsCount = (opts.loop * 2) - 1;

        if (opts.loop) {
            /* Double the loop count to convert it into its appropriate number of "reverse" calls.
               Subtract 1 from the resulting value since the current call is included in the total alternation count. */
            for (var x = 0; x < reverseCallsCount; x++) {
                /* Since the logic for the reverse action occurs inside Queueing and therefore this call's options object
                   isn't parsed until then as well, the current call's delay option must be explicitly passed into the reverse
                   call so that the delay logic that occurs inside *Pre-Queueing* can process it. */
                var reverseOptions = {
                    delay: opts.delay,
                    progress: opts.progress
                };

                /* If a complete callback was passed into this call, transfer it to the loop redirect's final "reverse" call
                   so that it's triggered when the entire redirect is complete (and not when the very first animation is complete). */
                if (x === reverseCallsCount - 1) {
                    reverseOptions.display = opts.display;
                    reverseOptions.visibility = opts.visibility;
                    reverseOptions.complete = opts.complete;
                }

                animate(elements, "reverse", reverseOptions);
            }
        }

        /***************
            Chaining
        ***************/

        /* Return the elements back to the call chain, with wrapped elements taking precedence in case Velocity was called via the $.fn. extension. */
        return getChain();
    };

    /* Turn Velocity into the animation function, extended with the pre-existing Velocity object. */
    Velocity = $.extend(animate, Velocity);
    /* For legacy support, also expose the literal animate method. */
    Velocity.animate = animate;

    /**************
        Timing
    **************/

    /* Ticker function. */
    var ticker = window.requestAnimationFrame || rAFShim;

    /* Inactive browser tabs pause rAF, which results in all active animations immediately sprinting to their completion states when the tab refocuses.
       To get around this, we dynamically switch rAF to setTimeout (which the browser *doesn't* pause) when the tab loses focus. We skip this for mobile
       devices to avoid wasting battery power on inactive tabs. */
    /* Note: Tab focus detection doesn't work on older versions of IE, but that's okay since they don't support rAF to begin with. */
    if (!Velocity.State.isMobile && document.hidden !== undefined) {
        document.addEventListener("visibilitychange", function() {
            /* Reassign the rAF function (which the global tick() function uses) based on the tab's focus state. */
            if (document.hidden) {
                ticker = function(callback) {
                    /* The tick function needs a truthy first argument in order to pass its internal timestamp check. */
                    return setTimeout(function() { callback(true) }, 16);
                };

                /* The rAF loop has been paused by the browser, so we manually restart the tick. */
                tick();
            } else {
                ticker = window.requestAnimationFrame || rAFShim;
            }
        });
    }

    /************
        Tick
    ************/

    /* Note: All calls to Velocity are pushed to the Velocity.State.calls array, which is fully iterated through upon each tick. */
    function tick (timestamp) {
        /* An empty timestamp argument indicates that this is the first tick occurence since ticking was turned on.
           We leverage this metadata to fully ignore the first tick pass since RAF's initial pass is fired whenever
           the browser's next tick sync time occurs, which results in the first elements subjected to Velocity
           calls being animated out of sync with any elements animated immediately thereafter. In short, we ignore
           the first RAF tick pass so that elements being immediately consecutively animated -- instead of simultaneously animated
           by the same Velocity call -- are properly batched into the same initial RAF tick and consequently remain in sync thereafter. */
        if (timestamp) {
            /* We ignore RAF's high resolution timestamp since it can be significantly offset when the browser is
               under high stress; we opt for choppiness over allowing the browser to drop huge chunks of frames. */
            var timeCurrent = (new Date).getTime();

            /********************
               Call Iteration
            ********************/

            /* Iterate through each active call. */
            for (var i = 0, callsLength = Velocity.State.calls.length; i < callsLength; i++) {
                /* When a Velocity call is completed, its Velocity.State.calls entry is set to false. Continue on to the next call. */
                if (!Velocity.State.calls[i]) {
                    continue;
                }

                /************************
                   Call-Wide Variables
                ************************/

                var callContainer = Velocity.State.calls[i],
                    call = callContainer[0],
                    opts = callContainer[2],
                    timeStart = callContainer[3],
                    firstTick = !!timeStart;

                /* If timeStart is undefined, then this is the first time that this call has been processed by tick().
                   We assign timeStart now so that its value is as close to the real animation start time as possible.
                   (Conversely, had timeStart been defined when this call was added to Velocity.State.calls, the delay
                   between that time and now would cause the first few frames of the tween to be skipped since
                   percentComplete is calculated relative to timeStart.) */
                /* Further, subtract 16ms (the approximate resolution of RAF) from the current time value so that the
                   first tick iteration isn't wasted by animating at 0% tween completion, which would produce the
                   same style value as the element's current value. */
                if (!timeStart) {
                    timeStart = Velocity.State.calls[i][3] = timeCurrent - 16;
                }

                /* The tween's completion percentage is relative to the tween's start time, not the tween's start value
                   (which would result in unpredictable tween durations since JavaScript's timers are not particularly accurate).
                   Accordingly, we ensure that percentComplete does not exceed 1. */
                var percentComplete = Math.min((timeCurrent - timeStart) / opts.duration, 1);

                /**********************
                   Element Iteration
                **********************/

                /* For every call, iterate through each of the elements in its set. */
                for (var j = 0, callLength = call.length; j < callLength; j++) {
                    var tweensContainer = call[j],
                        element = tweensContainer.element;

                    /* Check to see if this element has been deleted midway through the animation by checking for the
                       continued existence of its data cache. If it's gone, skip animating this element. */
                    if (!Data(element)) {
                        continue;
                    }

                    var transformPropertyExists = false;

                    /**********************************
                       Display & Visibility Toggling
                    **********************************/

                    /* If the display option is set to non-"none", set it upfront so that the element can become visible before tweening begins.
                       (Otherwise, display's "none" value is set in completeCall() once the animation has completed.) */
                    if (opts.display !== undefined && opts.display !== null && opts.display !== "none") {
                        if (opts.display === "flex") {
                            var flexValues = [ "-webkit-box", "-moz-box", "-ms-flexbox", "-webkit-flex" ];

                            $.each(flexValues, function(i, flexValue) {
                                CSS.setPropertyValue(element, "display", flexValue);
                            });
                        }

                        CSS.setPropertyValue(element, "display", opts.display);
                    }

                    /* Same goes with the visibility option, but its "none" equivalent is "hidden". */
                    if (opts.visibility !== undefined && opts.visibility !== "hidden") {
                        CSS.setPropertyValue(element, "visibility", opts.visibility);
                    }

                    /************************
                       Property Iteration
                    ************************/

                    /* For every element, iterate through each property. */
                    for (var property in tweensContainer) {
                        /* Note: In addition to property tween data, tweensContainer contains a reference to its associated element. */
                        if (property !== "element") {
                            var tween = tweensContainer[property],
                                currentValue,
                                /* Easing can either be a pre-genereated function or a string that references a pre-registered easing
                                   on the Velocity.Easings object. In either case, return the appropriate easing *function*. */
                                easing = Type.isString(tween.easing) ? Velocity.Easings[tween.easing] : tween.easing;

                            /******************************
                               Current Value Calculation
                            ******************************/

                            /* If this is the last tick pass (if we've reached 100% completion for this tween),
                               ensure that currentValue is explicitly set to its target endValue so that it's not subjected to any rounding. */
                            if (percentComplete === 1) {
                                currentValue = tween.endValue;
                            /* Otherwise, calculate currentValue based on the current delta from startValue. */
                            } else {
                                currentValue = tween.startValue + ((tween.endValue - tween.startValue) * easing(percentComplete));

                                /* If no value change is occurring, don't proceed with DOM updating. */
                                if (!firstTick && (currentValue === tween.currentValue)) {
                                    continue;
                                }
                            }

                            tween.currentValue = currentValue;

                            /******************
                               Hooks: Part I
                            ******************/

                            /* For hooked properties, the newly-updated rootPropertyValueCache is cached onto the element so that it can be used
                               for subsequent hooks in this call that are associated with the same root property. If we didn't cache the updated
                               rootPropertyValue, each subsequent update to the root property in this tick pass would reset the previous hook's
                               updates to rootPropertyValue prior to injection. A nice performance byproduct of rootPropertyValue caching is that
                               subsequently chained animations using the same hookRoot but a different hook can use this cached rootPropertyValue. */
                            if (CSS.Hooks.registered[property]) {
                                var hookRoot = CSS.Hooks.getRoot(property),
                                    rootPropertyValueCache = Data(element).rootPropertyValueCache[hookRoot];

                                if (rootPropertyValueCache) {
                                    tween.rootPropertyValue = rootPropertyValueCache;
                                }
                            }

                            /*****************
                                DOM Update
                            *****************/

                            /* setPropertyValue() returns an array of the property name and property value post any normalization that may have been performed. */
                            /* Note: To solve an IE<=8 positioning bug, the unit type is dropped when setting a property value of 0. */
                            var adjustedSetData = CSS.setPropertyValue(element, /* SET */
                                                                       property,
                                                                       tween.currentValue + (parseFloat(currentValue) === 0 ? "" : tween.unitType),
                                                                       tween.rootPropertyValue,
                                                                       tween.scrollData);

                            /*******************
                               Hooks: Part II
                            *******************/

                            /* Now that we have the hook's updated rootPropertyValue (the post-processed value provided by adjustedSetData), cache it onto the element. */
                            if (CSS.Hooks.registered[property]) {
                                /* Since adjustedSetData contains normalized data ready for DOM updating, the rootPropertyValue needs to be re-extracted from its normalized form. ?? */
                                if (CSS.Normalizations.registered[hookRoot]) {
                                    Data(element).rootPropertyValueCache[hookRoot] = CSS.Normalizations.registered[hookRoot]("extract", null, adjustedSetData[1]);
                                } else {
                                    Data(element).rootPropertyValueCache[hookRoot] = adjustedSetData[1];
                                }
                            }

                            /***************
                               Transforms
                            ***************/

                            /* Flag whether a transform property is being animated so that flushTransformCache() can be triggered once this tick pass is complete. */
                            if (adjustedSetData[0] === "transform") {
                                transformPropertyExists = true;
                            }
                        }
                    }

                    /****************
                        mobileHA
                    ****************/

                    /* If mobileHA is enabled, set the translate3d transform to null to force hardware acceleration.
                       It's safe to override this property since Velocity doesn't actually support its animation (hooks are used in its place). */
                    if (opts.mobileHA) {
                        /* Don't set the null transform hack if we've already done so. */
                        if (Data(element).transformCache.translate3d === undefined) {
                            /* All entries on the transformCache object are later concatenated into a single transform string via flushTransformCache(). */
                            Data(element).transformCache.translate3d = "(0px, 0px, 0px)";

                            transformPropertyExists = true;
                        }
                    }

                    if (transformPropertyExists) {
                        CSS.flushTransformCache(element);
                    }
                }

                /* The non-"none" display value is only applied to an element once -- when its associated call is first ticked through.
                   Accordingly, it's set to false so that it isn't re-processed by this call in the next tick. */
                if (opts.display !== undefined && opts.display !== "none") {
                    Velocity.State.calls[i][2].display = false;
                }
                if (opts.visibility !== undefined && opts.visibility !== "hidden") {
                    Velocity.State.calls[i][2].visibility = false;
                }


                /* Pass the elements and the timing data (percentComplete, msRemaining, and timeStart) into the progress callback. */
                if (opts.progress) {
                    opts.progress.call(callContainer[1],
                                       callContainer[1],
                                       percentComplete,
                                       Math.max(0, (timeStart + opts.duration) - timeCurrent),
                                       timeStart);
                }

                /* If this call has finished tweening, pass its index to completeCall() to handle call cleanup. */
                if (percentComplete === 1) {
                    completeCall(i);
                }
            }
        }

        /* Note: completeCall() sets the isTicking flag to false when the last call on Velocity.State.calls has completed. */
        if (Velocity.State.isTicking) {
            ticker(tick);
        }
    }

    /**********************
        Call Completion
    **********************/

    /* Note: Unlike tick(), which processes all active calls at once, call completion is handled on a per-call basis. */
    function completeCall (callIndex, isStopped) {
        /* Ensure the call exists. */
        if (!Velocity.State.calls[callIndex]) {
            return false;
        }

        /* Pull the metadata from the call. */
        var call = Velocity.State.calls[callIndex][0],
            elements = Velocity.State.calls[callIndex][1],
            opts = Velocity.State.calls[callIndex][2],
            resolver = Velocity.State.calls[callIndex][4];

        var remainingCallsExist = false;

        /*************************
           Element Finalization
        *************************/

        for (var i = 0, callLength = call.length; i < callLength; i++) {
            var element = call[i].element;

            /* If the user set display to "none" (intending to hide the element), set it now that the animation has completed. */
            /* Note: display:none isn't set when calls are manually stopped (via Velocity("stop"). */
            /* Note: Display gets ignored with "reverse" calls and infinite loops, since this behavior would be undesirable. */
            if (!isStopped && !opts.loop) {
                if (opts.display === "none") {
                    CSS.setPropertyValue(element, "display", opts.display);
                }

                if (opts.visibility === "hidden") {
                    CSS.setPropertyValue(element, "visibility", opts.visibility);
                }
            }

            /* If the element's queue is empty (if only the "inprogress" item is left at position 0) or if its queue is about to run
               a non-Velocity-initiated entry, turn off the isAnimating flag. A non-Velocity-initiatied queue entry's logic might alter
               an element's CSS values and thereby cause Velocity's cached value data to go stale. To detect if a queue entry was initiated by Velocity,
               we check for the existence of our special Velocity.queueEntryFlag declaration, which minifiers won't rename since the flag
               is assigned to jQuery's global $ object and thus exists out of Velocity's own scope. */
            if (opts.loop !== true && ($.queue(element)[1] === undefined || !/\.velocityQueueEntryFlag/i.test($.queue(element)[1]))) {
                /* The element may have been deleted. Ensure that its data cache still exists before acting on it. */
                if (Data(element)) {
                    Data(element).isAnimating = false;
                    /* Clear the element's rootPropertyValueCache, which will become stale. */
                    Data(element).rootPropertyValueCache = {};

                    var transformHAPropertyExists = false;
                    /* If any 3D transform subproperty is at its default value (regardless of unit type), remove it. */
                    $.each(CSS.Lists.transforms3D, function(i, transformName) {
                        var defaultValue = /^scale/.test(transformName) ? 1 : 0,
                            currentValue = Data(element).transformCache[transformName];

                        if (Data(element).transformCache[transformName] !== undefined && new RegExp("^\\(" + defaultValue + "[^.]").test(currentValue)) {
                            transformHAPropertyExists = true;

                            delete Data(element).transformCache[transformName];
                        }
                    });

                    /* Mobile devices have hardware acceleration removed at the end of the animation in order to avoid hogging the GPU's memory. */
                    if (opts.mobileHA) {
                        transformHAPropertyExists = true;
                        delete Data(element).transformCache.translate3d;
                    }

                    /* Flush the subproperty removals to the DOM. */
                    if (transformHAPropertyExists) {
                        CSS.flushTransformCache(element);
                    }

                    /* Remove the "velocity-animating" indicator class. */
                    CSS.Values.removeClass(element, "velocity-animating");
                }
            }

            /*********************
               Option: Complete
            *********************/

            /* Complete is fired once per call (not once per element) and is passed the full raw DOM element set as both its context and its first argument. */
            /* Note: Callbacks aren't fired when calls are manually stopped (via Velocity("stop"). */
            if (!isStopped && opts.complete && !opts.loop && (i === callLength - 1)) {
                /* We throw callbacks in a setTimeout so that thrown errors don't halt the execution of Velocity itself. */
                try {
                    opts.complete.call(elements, elements);
                } catch (error) {
                    setTimeout(function() { throw error; }, 1);
                }
            }

            /**********************
               Promise Resolving
            **********************/

            /* Note: Infinite loops don't return promises. */
            if (resolver && opts.loop !== true) {
                resolver(elements);
            }

            /****************************
               Option: Loop (Infinite)
            ****************************/

            if (opts.loop === true && !isStopped) {
                /* If a rotateX/Y/Z property is being animated to 360 deg with loop:true, swap tween start/end values to enable
                   continuous iterative rotation looping. (Otherise, the element would just rotate back and forth.) */
                $.each(Data(element).tweensContainer, function(propertyName, tweenContainer) {
                    if (/^rotate/.test(propertyName) && parseFloat(tweenContainer.endValue) === 360) {
                        tweenContainer.endValue = 0;
                        tweenContainer.startValue = 360;
                    }
                });

                Velocity(element, "reverse", { loop: true, delay: opts.delay });
            }

            /***************
               Dequeueing
            ***************/

            /* Fire the next call in the queue so long as this call's queue wasn't set to false (to trigger a parallel animation),
               which would have already caused the next call to fire. Note: Even if the end of the animation queue has been reached,
               $.dequeue() must still be called in order to completely clear jQuery's animation queue. */
            if (opts.queue !== false) {
                $.dequeue(element, opts.queue);
            }
        }

        /************************
           Calls Array Cleanup
        ************************/

        /* Since this call is complete, set it to false so that the rAF tick skips it. This array is later compacted via compactSparseArray().
          (For performance reasons, the call is set to false instead of being deleted from the array: http://www.html5rocks.com/en/tutorials/speed/v8/) */
        Velocity.State.calls[callIndex] = false;

        /* Iterate through the calls array to determine if this was the final in-progress animation.
           If so, set a flag to end ticking and clear the calls array. */
        for (var j = 0, callsLength = Velocity.State.calls.length; j < callsLength; j++) {
            if (Velocity.State.calls[j] !== false) {
                remainingCallsExist = true;

                break;
            }
        }

        if (remainingCallsExist === false) {
            /* tick() will detect this flag upon its next iteration and subsequently turn itself off. */
            Velocity.State.isTicking = false;

            /* Clear the calls array so that its length is reset. */
            delete Velocity.State.calls;
            Velocity.State.calls = [];
        }
    }

    /******************
        Frameworks
    ******************/

    /* Both jQuery and Zepto allow their $.fn object to be extended to allow wrapped elements to be subjected to plugin calls.
       If either framework is loaded, register a "velocity" extension pointing to Velocity's core animate() method.  Velocity
       also registers itself onto a global container (window.jQuery || window.Zepto || window) so that certain features are
       accessible beyond just a per-element scope. This master object contains an .animate() method, which is later assigned to $.fn
       (if jQuery or Zepto are present). Accordingly, Velocity can both act on wrapped DOM elements and stand alone for targeting raw DOM elements. */
    global.Velocity = Velocity;

    if (global !== window) {
        /* Assign the element function to Velocity's core animate() method. */
        global.fn.velocity = animate;
        /* Assign the object function's defaults to Velocity's global defaults object. */
        global.fn.velocity.defaults = Velocity.defaults;
    }

    /***********************
       Packaged Redirects
    ***********************/

    /* slideUp, slideDown */
    $.each([ "Down", "Up" ], function(i, direction) {
        Velocity.Redirects["slide" + direction] = function (element, options, elementsIndex, elementsSize, elements, promiseData) {
            var opts = $.extend({}, options),
                begin = opts.begin,
                complete = opts.complete,
                computedValues = { height: "", marginTop: "", marginBottom: "", paddingTop: "", paddingBottom: "" },
                inlineValues = {};

            if (opts.display === undefined) {
                /* Show the element before slideDown begins and hide the element after slideUp completes. */
                /* Note: Inline elements cannot have dimensions animated, so they're reverted to inline-block. */
                opts.display = (direction === "Down" ? (Velocity.CSS.Values.getDisplayType(element) === "inline" ? "inline-block" : "block") : "none");
            }

            opts.begin = function() {
                /* If the user passed in a begin callback, fire it now. */
                begin && begin.call(elements, elements);

                /* Cache the elements' original vertical dimensional property values so that we can animate back to them. */
                for (var property in computedValues) {
                    /* Cache all inline values, we reset to upon animation completion. */
                    inlineValues[property] = element.style[property];

                    /* For slideDown, use forcefeeding to animate all vertical properties from 0. For slideUp,
                       use forcefeeding to start from computed values and animate down to 0. */
                    var propertyValue = Velocity.CSS.getPropertyValue(element, property);
                    computedValues[property] = (direction === "Down") ? [ propertyValue, 0 ] : [ 0, propertyValue ];
                }

                /* Force vertical overflow content to clip so that sliding works as expected. */
                inlineValues.overflow = element.style.overflow;
                element.style.overflow = "hidden";
            }

            opts.complete = function() {
                /* Reset element to its pre-slide inline values once its slide animation is complete. */
                for (var property in inlineValues) {
                    element.style[property] = inlineValues[property];
                }

                /* If the user passed in a complete callback, fire it now. */
                complete && complete.call(elements, elements);
                promiseData && promiseData.resolver(elements);
            };

            Velocity(element, computedValues, opts);
        };
    });

    /* fadeIn, fadeOut */
    $.each([ "In", "Out" ], function(i, direction) {
        Velocity.Redirects["fade" + direction] = function (element, options, elementsIndex, elementsSize, elements, promiseData) {
            var opts = $.extend({}, options),
                propertiesMap = { opacity: (direction === "In") ? 1 : 0 },
                originalComplete = opts.complete;

            /* Since redirects are triggered individually for each element in the animated set, avoid repeatedly triggering
               callbacks by firing them only when the final element has been reached. */
            if (elementsIndex !== elementsSize - 1) {
                opts.complete = opts.begin = null;
            } else {
                opts.complete = function() {
                    if (originalComplete) {
                        originalComplete.call(elements, elements);
                    }

                    promiseData && promiseData.resolver(elements);
                }
            }

            /* If a display was passed in, use it. Otherwise, default to "none" for fadeOut or the element-specific default for fadeIn. */
            /* Note: We allow users to pass in "null" to skip display setting altogether. */
            if (opts.display === undefined) {
                opts.display = (direction === "In" ? "auto" : "none");
            }

            Velocity(this, propertiesMap, opts);
        };
    });

    return Velocity;
}((window.jQuery || window.Zepto || window), window, document);
}));

/******************
   Known Issues
******************/

/* The CSS spec mandates that the translateX/Y/Z transforms are %-relative to the element itself -- not its parent.
Velocity, however, doesn't make this distinction. Thus, converting to or from the % unit with these subproperties
will produce an inaccurate conversion value. The same issue exists with the cx/cy attributes of SVG circles and ellipses. */
/**
 * @license AngularJS v1.3.20
 * (c) 2010-2014 Google, Inc. http://angularjs.org
 * License: MIT
 */
(function(window, document, undefined) {'use strict';

/**
 * @description
 *
 * This object provides a utility for producing rich Error messages within
 * Angular. It can be called as follows:
 *
 * var exampleMinErr = minErr('example');
 * throw exampleMinErr('one', 'This {0} is {1}', foo, bar);
 *
 * The above creates an instance of minErr in the example namespace. The
 * resulting error will have a namespaced error code of example.one.  The
 * resulting error will replace {0} with the value of foo, and {1} with the
 * value of bar. The object is not restricted in the number of arguments it can
 * take.
 *
 * If fewer arguments are specified than necessary for interpolation, the extra
 * interpolation markers will be preserved in the final string.
 *
 * Since data will be parsed statically during a build step, some restrictions
 * are applied with respect to how minErr instances are created and called.
 * Instances should have names of the form namespaceMinErr for a minErr created
 * using minErr('namespace') . Error codes, namespaces and template strings
 * should all be static strings, not variables or general expressions.
 *
 * @param {string} module The namespace to use for the new minErr instance.
 * @param {function} ErrorConstructor Custom error constructor to be instantiated when returning
 *   error from returned function, for cases when a particular type of error is useful.
 * @returns {function(code:string, template:string, ...templateArgs): Error} minErr instance
 */

function minErr(module, ErrorConstructor) {
  ErrorConstructor = ErrorConstructor || Error;
  return function() {
    var code = arguments[0],
      prefix = '[' + (module ? module + ':' : '') + code + '] ',
      template = arguments[1],
      templateArgs = arguments,

      message, i;

    message = prefix + template.replace(/\{\d+\}/g, function(match) {
      var index = +match.slice(1, -1), arg;

      if (index + 2 < templateArgs.length) {
        return toDebugString(templateArgs[index + 2]);
      }
      return match;
    });

    message = message + '\nhttp://errors.angularjs.org/1.3.20/' +
      (module ? module + '/' : '') + code;
    for (i = 2; i < arguments.length; i++) {
      message = message + (i == 2 ? '?' : '&') + 'p' + (i - 2) + '=' +
        encodeURIComponent(toDebugString(arguments[i]));
    }
    return new ErrorConstructor(message);
  };
}

/* We need to tell jshint what variables are being exported */
/* global angular: true,
  msie: true,
  jqLite: true,
  jQuery: true,
  slice: true,
  splice: true,
  push: true,
  toString: true,
  ngMinErr: true,
  angularModule: true,
  uid: true,
  REGEX_STRING_REGEXP: true,
  VALIDITY_STATE_PROPERTY: true,

  lowercase: true,
  uppercase: true,
  manualLowercase: true,
  manualUppercase: true,
  nodeName_: true,
  isArrayLike: true,
  forEach: true,
  sortedKeys: true,
  forEachSorted: true,
  reverseParams: true,
  nextUid: true,
  setHashKey: true,
  extend: true,
  int: true,
  inherit: true,
  noop: true,
  identity: true,
  valueFn: true,
  isUndefined: true,
  isDefined: true,
  isObject: true,
  isString: true,
  isNumber: true,
  isDate: true,
  isArray: true,
  isFunction: true,
  isRegExp: true,
  isWindow: true,
  isScope: true,
  isFile: true,
  isFormData: true,
  isBlob: true,
  isBoolean: true,
  isPromiseLike: true,
  trim: true,
  escapeForRegexp: true,
  isElement: true,
  makeMap: true,
  includes: true,
  arrayRemove: true,
  copy: true,
  shallowCopy: true,
  equals: true,
  csp: true,
  concat: true,
  sliceArgs: true,
  bind: true,
  toJsonReplacer: true,
  toJson: true,
  fromJson: true,
  startingTag: true,
  tryDecodeURIComponent: true,
  parseKeyValue: true,
  toKeyValue: true,
  encodeUriSegment: true,
  encodeUriQuery: true,
  angularInit: true,
  bootstrap: true,
  getTestability: true,
  snake_case: true,
  bindJQuery: true,
  assertArg: true,
  assertArgFn: true,
  assertNotHasOwnProperty: true,
  getter: true,
  getBlockNodes: true,
  hasOwnProperty: true,
  createMap: true,

  NODE_TYPE_ELEMENT: true,
  NODE_TYPE_ATTRIBUTE: true,
  NODE_TYPE_TEXT: true,
  NODE_TYPE_COMMENT: true,
  NODE_TYPE_DOCUMENT: true,
  NODE_TYPE_DOCUMENT_FRAGMENT: true,
*/

////////////////////////////////////

/**
 * @ngdoc module
 * @name ng
 * @module ng
 * @description
 *
 * # ng (core module)
 * The ng module is loaded by default when an AngularJS application is started. The module itself
 * contains the essential components for an AngularJS application to function. The table below
 * lists a high level breakdown of each of the services/factories, filters, directives and testing
 * components available within this core module.
 *
 * <div doc-module-components="ng"></div>
 */

var REGEX_STRING_REGEXP = /^\/(.+)\/([a-z]*)$/;

// The name of a form control's ValidityState property.
// This is used so that it's possible for internal tests to create mock ValidityStates.
var VALIDITY_STATE_PROPERTY = 'validity';

/**
 * @ngdoc function
 * @name angular.lowercase
 * @module ng
 * @kind function
 *
 * @description Converts the specified string to lowercase.
 * @param {string} string String to be converted to lowercase.
 * @returns {string} Lowercased string.
 */
var lowercase = function(string) {return isString(string) ? string.toLowerCase() : string;};
var hasOwnProperty = Object.prototype.hasOwnProperty;

/**
 * @ngdoc function
 * @name angular.uppercase
 * @module ng
 * @kind function
 *
 * @description Converts the specified string to uppercase.
 * @param {string} string String to be converted to uppercase.
 * @returns {string} Uppercased string.
 */
var uppercase = function(string) {return isString(string) ? string.toUpperCase() : string;};


var manualLowercase = function(s) {
  /* jshint bitwise: false */
  return isString(s)
      ? s.replace(/[A-Z]/g, function(ch) {return String.fromCharCode(ch.charCodeAt(0) | 32);})
      : s;
};
var manualUppercase = function(s) {
  /* jshint bitwise: false */
  return isString(s)
      ? s.replace(/[a-z]/g, function(ch) {return String.fromCharCode(ch.charCodeAt(0) & ~32);})
      : s;
};


// String#toLowerCase and String#toUpperCase don't produce correct results in browsers with Turkish
// locale, for this reason we need to detect this case and redefine lowercase/uppercase methods
// with correct but slower alternatives.
if ('i' !== 'I'.toLowerCase()) {
  lowercase = manualLowercase;
  uppercase = manualUppercase;
}


var
    msie,             // holds major version number for IE, or NaN if UA is not IE.
    jqLite,           // delay binding since jQuery could be loaded after us.
    jQuery,           // delay binding
    slice             = [].slice,
    splice            = [].splice,
    push              = [].push,
    toString          = Object.prototype.toString,
    ngMinErr          = minErr('ng'),

    /** @name angular */
    angular           = window.angular || (window.angular = {}),
    angularModule,
    uid               = 0;

/**
 * documentMode is an IE-only property
 * http://msdn.microsoft.com/en-us/library/ie/cc196988(v=vs.85).aspx
 */
msie = document.documentMode;


/**
 * @private
 * @param {*} obj
 * @return {boolean} Returns true if `obj` is an array or array-like object (NodeList, Arguments,
 *                   String ...)
 */
function isArrayLike(obj) {
  if (obj == null || isWindow(obj)) {
    return false;
  }

  // Support: iOS 8.2 (not reproducible in simulator)
  // "length" in obj used to prevent JIT error (gh-11508)
  var length = "length" in Object(obj) && obj.length;

  if (obj.nodeType === NODE_TYPE_ELEMENT && length) {
    return true;
  }

  return isString(obj) || isArray(obj) || length === 0 ||
         typeof length === 'number' && length > 0 && (length - 1) in obj;
}

/**
 * @ngdoc function
 * @name angular.forEach
 * @module ng
 * @kind function
 *
 * @description
 * Invokes the `iterator` function once for each item in `obj` collection, which can be either an
 * object or an array. The `iterator` function is invoked with `iterator(value, key, obj)`, where `value`
 * is the value of an object property or an array element, `key` is the object property key or
 * array element index and obj is the `obj` itself. Specifying a `context` for the function is optional.
 *
 * It is worth noting that `.forEach` does not iterate over inherited properties because it filters
 * using the `hasOwnProperty` method.
 *
 * Unlike ES262's
 * [Array.prototype.forEach](http://www.ecma-international.org/ecma-262/5.1/#sec-15.4.4.18),
 * Providing 'undefined' or 'null' values for `obj` will not throw a TypeError, but rather just
 * return the value provided.
 *
   ```js
     var values = {name: 'misko', gender: 'male'};
     var log = [];
     angular.forEach(values, function(value, key) {
       this.push(key + ': ' + value);
     }, log);
     expect(log).toEqual(['name: misko', 'gender: male']);
   ```
 *
 * @param {Object|Array} obj Object to iterate over.
 * @param {Function} iterator Iterator function.
 * @param {Object=} context Object to become context (`this`) for the iterator function.
 * @returns {Object|Array} Reference to `obj`.
 */

function forEach(obj, iterator, context) {
  var key, length;
  if (obj) {
    if (isFunction(obj)) {
      for (key in obj) {
        // Need to check if hasOwnProperty exists,
        // as on IE8 the result of querySelectorAll is an object without a hasOwnProperty function
        if (key != 'prototype' && key != 'length' && key != 'name' && (!obj.hasOwnProperty || obj.hasOwnProperty(key))) {
          iterator.call(context, obj[key], key, obj);
        }
      }
    } else if (isArray(obj) || isArrayLike(obj)) {
      var isPrimitive = typeof obj !== 'object';
      for (key = 0, length = obj.length; key < length; key++) {
        if (isPrimitive || key in obj) {
          iterator.call(context, obj[key], key, obj);
        }
      }
    } else if (obj.forEach && obj.forEach !== forEach) {
        obj.forEach(iterator, context, obj);
    } else {
      for (key in obj) {
        if (obj.hasOwnProperty(key)) {
          iterator.call(context, obj[key], key, obj);
        }
      }
    }
  }
  return obj;
}

function sortedKeys(obj) {
  return Object.keys(obj).sort();
}

function forEachSorted(obj, iterator, context) {
  var keys = sortedKeys(obj);
  for (var i = 0; i < keys.length; i++) {
    iterator.call(context, obj[keys[i]], keys[i]);
  }
  return keys;
}


/**
 * when using forEach the params are value, key, but it is often useful to have key, value.
 * @param {function(string, *)} iteratorFn
 * @returns {function(*, string)}
 */
function reverseParams(iteratorFn) {
  return function(value, key) { iteratorFn(key, value); };
}

/**
 * A consistent way of creating unique IDs in angular.
 *
 * Using simple numbers allows us to generate 28.6 million unique ids per second for 10 years before
 * we hit number precision issues in JavaScript.
 *
 * Math.pow(2,53) / 60 / 60 / 24 / 365 / 10 = 28.6M
 *
 * @returns {number} an unique alpha-numeric string
 */
function nextUid() {
  return ++uid;
}


/**
 * Set or clear the hashkey for an object.
 * @param obj object
 * @param h the hashkey (!truthy to delete the hashkey)
 */
function setHashKey(obj, h) {
  if (h) {
    obj.$$hashKey = h;
  } else {
    delete obj.$$hashKey;
  }
}

/**
 * @ngdoc function
 * @name angular.extend
 * @module ng
 * @kind function
 *
 * @description
 * Extends the destination object `dst` by copying own enumerable properties from the `src` object(s)
 * to `dst`. You can specify multiple `src` objects. If you want to preserve original objects, you can do so
 * by passing an empty object as the target: `var object = angular.extend({}, object1, object2)`.
 * Note: Keep in mind that `angular.extend` does not support recursive merge (deep copy).
 *
 * @param {Object} dst Destination object.
 * @param {...Object} src Source object(s).
 * @returns {Object} Reference to `dst`.
 */
function extend(dst) {
  var h = dst.$$hashKey;

  for (var i = 1, ii = arguments.length; i < ii; i++) {
    var obj = arguments[i];
    if (obj) {
      var keys = Object.keys(obj);
      for (var j = 0, jj = keys.length; j < jj; j++) {
        var key = keys[j];
        dst[key] = obj[key];
      }
    }
  }

  setHashKey(dst, h);
  return dst;
}

function int(str) {
  return parseInt(str, 10);
}


function inherit(parent, extra) {
  return extend(Object.create(parent), extra);
}

/**
 * @ngdoc function
 * @name angular.noop
 * @module ng
 * @kind function
 *
 * @description
 * A function that performs no operations. This function can be useful when writing code in the
 * functional style.
   ```js
     function foo(callback) {
       var result = calculateResult();
       (callback || angular.noop)(result);
     }
   ```
 */
function noop() {}
noop.$inject = [];


/**
 * @ngdoc function
 * @name angular.identity
 * @module ng
 * @kind function
 *
 * @description
 * A function that returns its first argument. This function is useful when writing code in the
 * functional style.
 *
   ```js
     function transformer(transformationFn, value) {
       return (transformationFn || angular.identity)(value);
     };
   ```
  * @param {*} value to be returned.
  * @returns {*} the value passed in.
 */
function identity($) {return $;}
identity.$inject = [];


function valueFn(value) {return function() {return value;};}

/**
 * @ngdoc function
 * @name angular.isUndefined
 * @module ng
 * @kind function
 *
 * @description
 * Determines if a reference is undefined.
 *
 * @param {*} value Reference to check.
 * @returns {boolean} True if `value` is undefined.
 */
function isUndefined(value) {return typeof value === 'undefined';}


/**
 * @ngdoc function
 * @name angular.isDefined
 * @module ng
 * @kind function
 *
 * @description
 * Determines if a reference is defined.
 *
 * @param {*} value Reference to check.
 * @returns {boolean} True if `value` is defined.
 */
function isDefined(value) {return typeof value !== 'undefined';}


/**
 * @ngdoc function
 * @name angular.isObject
 * @module ng
 * @kind function
 *
 * @description
 * Determines if a reference is an `Object`. Unlike `typeof` in JavaScript, `null`s are not
 * considered to be objects. Note that JavaScript arrays are objects.
 *
 * @param {*} value Reference to check.
 * @returns {boolean} True if `value` is an `Object` but not `null`.
 */
function isObject(value) {
  // http://jsperf.com/isobject4
  return value !== null && typeof value === 'object';
}


/**
 * @ngdoc function
 * @name angular.isString
 * @module ng
 * @kind function
 *
 * @description
 * Determines if a reference is a `String`.
 *
 * @param {*} value Reference to check.
 * @returns {boolean} True if `value` is a `String`.
 */
function isString(value) {return typeof value === 'string';}


/**
 * @ngdoc function
 * @name angular.isNumber
 * @module ng
 * @kind function
 *
 * @description
 * Determines if a reference is a `Number`.
 *
 * This includes the "special" numbers `NaN`, `+Infinity` and `-Infinity`.
 *
 * If you wish to exclude these then you can use the native
 * [`isFinite'](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/isFinite)
 * method.
 *
 * @param {*} value Reference to check.
 * @returns {boolean} True if `value` is a `Number`.
 */
function isNumber(value) {return typeof value === 'number';}


/**
 * @ngdoc function
 * @name angular.isDate
 * @module ng
 * @kind function
 *
 * @description
 * Determines if a value is a date.
 *
 * @param {*} value Reference to check.
 * @returns {boolean} True if `value` is a `Date`.
 */
function isDate(value) {
  return toString.call(value) === '[object Date]';
}


/**
 * @ngdoc function
 * @name angular.isArray
 * @module ng
 * @kind function
 *
 * @description
 * Determines if a reference is an `Array`.
 *
 * @param {*} value Reference to check.
 * @returns {boolean} True if `value` is an `Array`.
 */
var isArray = Array.isArray;

/**
 * @ngdoc function
 * @name angular.isFunction
 * @module ng
 * @kind function
 *
 * @description
 * Determines if a reference is a `Function`.
 *
 * @param {*} value Reference to check.
 * @returns {boolean} True if `value` is a `Function`.
 */
function isFunction(value) {return typeof value === 'function';}


/**
 * Determines if a value is a regular expression object.
 *
 * @private
 * @param {*} value Reference to check.
 * @returns {boolean} True if `value` is a `RegExp`.
 */
function isRegExp(value) {
  return toString.call(value) === '[object RegExp]';
}


/**
 * Checks if `obj` is a window object.
 *
 * @private
 * @param {*} obj Object to check
 * @returns {boolean} True if `obj` is a window obj.
 */
function isWindow(obj) {
  return obj && obj.window === obj;
}


function isScope(obj) {
  return obj && obj.$evalAsync && obj.$watch;
}


function isFile(obj) {
  return toString.call(obj) === '[object File]';
}


function isFormData(obj) {
  return toString.call(obj) === '[object FormData]';
}


function isBlob(obj) {
  return toString.call(obj) === '[object Blob]';
}


function isBoolean(value) {
  return typeof value === 'boolean';
}


function isPromiseLike(obj) {
  return obj && isFunction(obj.then);
}


var trim = function(value) {
  return isString(value) ? value.trim() : value;
};

// Copied from:
// http://docs.closure-library.googlecode.com/git/local_closure_goog_string_string.js.source.html#line1021
// Prereq: s is a string.
var escapeForRegexp = function(s) {
  return s.replace(/([-()\[\]{}+?*.$\^|,:#<!\\])/g, '\\$1').
           replace(/\x08/g, '\\x08');
};


/**
 * @ngdoc function
 * @name angular.isElement
 * @module ng
 * @kind function
 *
 * @description
 * Determines if a reference is a DOM element (or wrapped jQuery element).
 *
 * @param {*} value Reference to check.
 * @returns {boolean} True if `value` is a DOM element (or wrapped jQuery element).
 */
function isElement(node) {
  return !!(node &&
    (node.nodeName  // we are a direct element
    || (node.prop && node.attr && node.find)));  // we have an on and find method part of jQuery API
}

/**
 * @param str 'key1,key2,...'
 * @returns {object} in the form of {key1:true, key2:true, ...}
 */
function makeMap(str) {
  var obj = {}, items = str.split(","), i;
  for (i = 0; i < items.length; i++)
    obj[items[i]] = true;
  return obj;
}


function nodeName_(element) {
  return lowercase(element.nodeName || (element[0] && element[0].nodeName));
}

function includes(array, obj) {
  return Array.prototype.indexOf.call(array, obj) != -1;
}

function arrayRemove(array, value) {
  var index = array.indexOf(value);
  if (index >= 0)
    array.splice(index, 1);
  return value;
}

/**
 * @ngdoc function
 * @name angular.copy
 * @module ng
 * @kind function
 *
 * @description
 * Creates a deep copy of `source`, which should be an object or an array.
 *
 * * If no destination is supplied, a copy of the object or array is created.
 * * If a destination is provided, all of its elements (for arrays) or properties (for objects)
 *   are deleted and then all elements/properties from the source are copied to it.
 * * If `source` is not an object or array (inc. `null` and `undefined`), `source` is returned.
 * * If `source` is identical to 'destination' an exception will be thrown.
 *
 * @param {*} source The source that will be used to make a copy.
 *                   Can be any type, including primitives, `null`, and `undefined`.
 * @param {(Object|Array)=} destination Destination into which the source is copied. If
 *     provided, must be of the same type as `source`.
 * @returns {*} The copy or updated `destination`, if `destination` was specified.
 *
 * @example
 <example module="copyExample">
 <file name="index.html">
 <div ng-controller="ExampleController">
 <form novalidate class="simple-form">
 Name: <input type="text" ng-model="user.name" /><br />
 E-mail: <input type="email" ng-model="user.email" /><br />
 Gender: <input type="radio" ng-model="user.gender" value="male" />male
 <input type="radio" ng-model="user.gender" value="female" />female<br />
 <button ng-click="reset()">RESET</button>
 <button ng-click="update(user)">SAVE</button>
 </form>
 <pre>form = {{user | json}}</pre>
 <pre>master = {{master | json}}</pre>
 </div>

 <script>
  angular.module('copyExample', [])
    .controller('ExampleController', ['$scope', function($scope) {
      $scope.master= {};

      $scope.update = function(user) {
        // Example with 1 argument
        $scope.master= angular.copy(user);
      };

      $scope.reset = function() {
        // Example with 2 arguments
        angular.copy($scope.master, $scope.user);
      };

      $scope.reset();
    }]);
 </script>
 </file>
 </example>
 */
function copy(source, destination, stackSource, stackDest) {
  if (isWindow(source) || isScope(source)) {
    throw ngMinErr('cpws',
      "Can't copy! Making copies of Window or Scope instances is not supported.");
  }

  if (!destination) {
    destination = source;
    if (source) {
      if (isArray(source)) {
        destination = copy(source, [], stackSource, stackDest);
      } else if (isDate(source)) {
        destination = new Date(source.getTime());
      } else if (isRegExp(source)) {
        destination = new RegExp(source.source, source.toString().match(/[^\/]*$/)[0]);
        destination.lastIndex = source.lastIndex;
      } else if (isObject(source)) {
        var emptyObject = Object.create(Object.getPrototypeOf(source));
        destination = copy(source, emptyObject, stackSource, stackDest);
      }
    }
  } else {
    if (source === destination) throw ngMinErr('cpi',
      "Can't copy! Source and destination are identical.");

    stackSource = stackSource || [];
    stackDest = stackDest || [];

    if (isObject(source)) {
      var index = stackSource.indexOf(source);
      if (index !== -1) return stackDest[index];

      stackSource.push(source);
      stackDest.push(destination);
    }

    var result;
    if (isArray(source)) {
      destination.length = 0;
      for (var i = 0; i < source.length; i++) {
        result = copy(source[i], null, stackSource, stackDest);
        if (isObject(source[i])) {
          stackSource.push(source[i]);
          stackDest.push(result);
        }
        destination.push(result);
      }
    } else {
      var h = destination.$$hashKey;
      if (isArray(destination)) {
        destination.length = 0;
      } else {
        forEach(destination, function(value, key) {
          delete destination[key];
        });
      }
      for (var key in source) {
        if (source.hasOwnProperty(key)) {
          result = copy(source[key], null, stackSource, stackDest);
          if (isObject(source[key])) {
            stackSource.push(source[key]);
            stackDest.push(result);
          }
          destination[key] = result;
        }
      }
      setHashKey(destination,h);
    }

  }
  return destination;
}

/**
 * Creates a shallow copy of an object, an array or a primitive.
 *
 * Assumes that there are no proto properties for objects.
 */
function shallowCopy(src, dst) {
  if (isArray(src)) {
    dst = dst || [];

    for (var i = 0, ii = src.length; i < ii; i++) {
      dst[i] = src[i];
    }
  } else if (isObject(src)) {
    dst = dst || {};

    for (var key in src) {
      if (!(key.charAt(0) === '$' && key.charAt(1) === '$')) {
        dst[key] = src[key];
      }
    }
  }

  return dst || src;
}


/**
 * @ngdoc function
 * @name angular.equals
 * @module ng
 * @kind function
 *
 * @description
 * Determines if two objects or two values are equivalent. Supports value types, regular
 * expressions, arrays and objects.
 *
 * Two objects or values are considered equivalent if at least one of the following is true:
 *
 * * Both objects or values pass `===` comparison.
 * * Both objects or values are of the same type and all of their properties are equal by
 *   comparing them with `angular.equals`.
 * * Both values are NaN. (In JavaScript, NaN == NaN => false. But we consider two NaN as equal)
 * * Both values represent the same regular expression (In JavaScript,
 *   /abc/ == /abc/ => false. But we consider two regular expressions as equal when their textual
 *   representation matches).
 *
 * During a property comparison, properties of `function` type and properties with names
 * that begin with `$` are ignored.
 *
 * Scope and DOMWindow objects are being compared only by identify (`===`).
 *
 * @param {*} o1 Object or value to compare.
 * @param {*} o2 Object or value to compare.
 * @returns {boolean} True if arguments are equal.
 */
function equals(o1, o2) {
  if (o1 === o2) return true;
  if (o1 === null || o2 === null) return false;
  if (o1 !== o1 && o2 !== o2) return true; // NaN === NaN
  var t1 = typeof o1, t2 = typeof o2, length, key, keySet;
  if (t1 == t2) {
    if (t1 == 'object') {
      if (isArray(o1)) {
        if (!isArray(o2)) return false;
        if ((length = o1.length) == o2.length) {
          for (key = 0; key < length; key++) {
            if (!equals(o1[key], o2[key])) return false;
          }
          return true;
        }
      } else if (isDate(o1)) {
        if (!isDate(o2)) return false;
        return equals(o1.getTime(), o2.getTime());
      } else if (isRegExp(o1)) {
        return isRegExp(o2) ? o1.toString() == o2.toString() : false;
      } else {
        if (isScope(o1) || isScope(o2) || isWindow(o1) || isWindow(o2) ||
          isArray(o2) || isDate(o2) || isRegExp(o2)) return false;
        keySet = {};
        for (key in o1) {
          if (key.charAt(0) === '$' || isFunction(o1[key])) continue;
          if (!equals(o1[key], o2[key])) return false;
          keySet[key] = true;
        }
        for (key in o2) {
          if (!keySet.hasOwnProperty(key) &&
              key.charAt(0) !== '$' &&
              o2[key] !== undefined &&
              !isFunction(o2[key])) return false;
        }
        return true;
      }
    }
  }
  return false;
}

var csp = function() {
  if (isDefined(csp.isActive_)) return csp.isActive_;

  var active = !!(document.querySelector('[ng-csp]') ||
                  document.querySelector('[data-ng-csp]'));

  if (!active) {
    try {
      /* jshint -W031, -W054 */
      new Function('');
      /* jshint +W031, +W054 */
    } catch (e) {
      active = true;
    }
  }

  return (csp.isActive_ = active);
};



function concat(array1, array2, index) {
  return array1.concat(slice.call(array2, index));
}

function sliceArgs(args, startIndex) {
  return slice.call(args, startIndex || 0);
}


/* jshint -W101 */
/**
 * @ngdoc function
 * @name angular.bind
 * @module ng
 * @kind function
 *
 * @description
 * Returns a function which calls function `fn` bound to `self` (`self` becomes the `this` for
 * `fn`). You can supply optional `args` that are prebound to the function. This feature is also
 * known as [partial application](http://en.wikipedia.org/wiki/Partial_application), as
 * distinguished from [function currying](http://en.wikipedia.org/wiki/Currying#Contrast_with_partial_function_application).
 *
 * @param {Object} self Context which `fn` should be evaluated in.
 * @param {function()} fn Function to be bound.
 * @param {...*} args Optional arguments to be prebound to the `fn` function call.
 * @returns {function()} Function that wraps the `fn` with all the specified bindings.
 */
/* jshint +W101 */
function bind(self, fn) {
  var curryArgs = arguments.length > 2 ? sliceArgs(arguments, 2) : [];
  if (isFunction(fn) && !(fn instanceof RegExp)) {
    return curryArgs.length
      ? function() {
          return arguments.length
            ? fn.apply(self, concat(curryArgs, arguments, 0))
            : fn.apply(self, curryArgs);
        }
      : function() {
          return arguments.length
            ? fn.apply(self, arguments)
            : fn.call(self);
        };
  } else {
    // in IE, native methods are not functions so they cannot be bound (note: they don't need to be)
    return fn;
  }
}


function toJsonReplacer(key, value) {
  var val = value;

  if (typeof key === 'string' && key.charAt(0) === '$' && key.charAt(1) === '$') {
    val = undefined;
  } else if (isWindow(value)) {
    val = '$WINDOW';
  } else if (value &&  document === value) {
    val = '$DOCUMENT';
  } else if (isScope(value)) {
    val = '$SCOPE';
  }

  return val;
}


/**
 * @ngdoc function
 * @name angular.toJson
 * @module ng
 * @kind function
 *
 * @description
 * Serializes input into a JSON-formatted string. Properties with leading $$ characters will be
 * stripped since angular uses this notation internally.
 *
 * @param {Object|Array|Date|string|number} obj Input to be serialized into JSON.
 * @param {boolean|number} [pretty=2] If set to true, the JSON output will contain newlines and whitespace.
 *    If set to an integer, the JSON output will contain that many spaces per indentation.
 * @returns {string|undefined} JSON-ified string representing `obj`.
 */
function toJson(obj, pretty) {
  if (typeof obj === 'undefined') return undefined;
  if (!isNumber(pretty)) {
    pretty = pretty ? 2 : null;
  }
  return JSON.stringify(obj, toJsonReplacer, pretty);
}


/**
 * @ngdoc function
 * @name angular.fromJson
 * @module ng
 * @kind function
 *
 * @description
 * Deserializes a JSON string.
 *
 * @param {string} json JSON string to deserialize.
 * @returns {Object|Array|string|number} Deserialized JSON string.
 */
function fromJson(json) {
  return isString(json)
      ? JSON.parse(json)
      : json;
}


/**
 * @returns {string} Returns the string representation of the element.
 */
function startingTag(element) {
  element = jqLite(element).clone();
  try {
    // turns out IE does not let you set .html() on elements which
    // are not allowed to have children. So we just ignore it.
    element.empty();
  } catch (e) {}
  var elemHtml = jqLite('<div>').append(element).html();
  try {
    return element[0].nodeType === NODE_TYPE_TEXT ? lowercase(elemHtml) :
        elemHtml.
          match(/^(<[^>]+>)/)[1].
          replace(/^<([\w\-]+)/, function(match, nodeName) { return '<' + lowercase(nodeName); });
  } catch (e) {
    return lowercase(elemHtml);
  }

}


/////////////////////////////////////////////////

/**
 * Tries to decode the URI component without throwing an exception.
 *
 * @private
 * @param str value potential URI component to check.
 * @returns {boolean} True if `value` can be decoded
 * with the decodeURIComponent function.
 */
function tryDecodeURIComponent(value) {
  try {
    return decodeURIComponent(value);
  } catch (e) {
    // Ignore any invalid uri component
  }
}


/**
 * Parses an escaped url query string into key-value pairs.
 * @returns {Object.<string,boolean|Array>}
 */
function parseKeyValue(/**string*/keyValue) {
  var obj = {}, key_value, key;
  forEach((keyValue || "").split('&'), function(keyValue) {
    if (keyValue) {
      key_value = keyValue.replace(/\+/g,'%20').split('=');
      key = tryDecodeURIComponent(key_value[0]);
      if (isDefined(key)) {
        var val = isDefined(key_value[1]) ? tryDecodeURIComponent(key_value[1]) : true;
        if (!hasOwnProperty.call(obj, key)) {
          obj[key] = val;
        } else if (isArray(obj[key])) {
          obj[key].push(val);
        } else {
          obj[key] = [obj[key],val];
        }
      }
    }
  });
  return obj;
}

function toKeyValue(obj) {
  var parts = [];
  forEach(obj, function(value, key) {
    if (isArray(value)) {
      forEach(value, function(arrayValue) {
        parts.push(encodeUriQuery(key, true) +
                   (arrayValue === true ? '' : '=' + encodeUriQuery(arrayValue, true)));
      });
    } else {
    parts.push(encodeUriQuery(key, true) +
               (value === true ? '' : '=' + encodeUriQuery(value, true)));
    }
  });
  return parts.length ? parts.join('&') : '';
}


/**
 * We need our custom method because encodeURIComponent is too aggressive and doesn't follow
 * http://www.ietf.org/rfc/rfc3986.txt with regards to the character set (pchar) allowed in path
 * segments:
 *    segment       = *pchar
 *    pchar         = unreserved / pct-encoded / sub-delims / ":" / "@"
 *    pct-encoded   = "%" HEXDIG HEXDIG
 *    unreserved    = ALPHA / DIGIT / "-" / "." / "_" / "~"
 *    sub-delims    = "!" / "$" / "&" / "'" / "(" / ")"
 *                     / "*" / "+" / "," / ";" / "="
 */
function encodeUriSegment(val) {
  return encodeUriQuery(val, true).
             replace(/%26/gi, '&').
             replace(/%3D/gi, '=').
             replace(/%2B/gi, '+');
}


/**
 * This method is intended for encoding *key* or *value* parts of query component. We need a custom
 * method because encodeURIComponent is too aggressive and encodes stuff that doesn't have to be
 * encoded per http://tools.ietf.org/html/rfc3986:
 *    query       = *( pchar / "/" / "?" )
 *    pchar         = unreserved / pct-encoded / sub-delims / ":" / "@"
 *    unreserved    = ALPHA / DIGIT / "-" / "." / "_" / "~"
 *    pct-encoded   = "%" HEXDIG HEXDIG
 *    sub-delims    = "!" / "$" / "&" / "'" / "(" / ")"
 *                     / "*" / "+" / "," / ";" / "="
 */
function encodeUriQuery(val, pctEncodeSpaces) {
  return encodeURIComponent(val).
             replace(/%40/gi, '@').
             replace(/%3A/gi, ':').
             replace(/%24/g, '$').
             replace(/%2C/gi, ',').
             replace(/%3B/gi, ';').
             replace(/%20/g, (pctEncodeSpaces ? '%20' : '+'));
}

var ngAttrPrefixes = ['ng-', 'data-ng-', 'ng:', 'x-ng-'];

function getNgAttribute(element, ngAttr) {
  var attr, i, ii = ngAttrPrefixes.length;
  element = jqLite(element);
  for (i = 0; i < ii; ++i) {
    attr = ngAttrPrefixes[i] + ngAttr;
    if (isString(attr = element.attr(attr))) {
      return attr;
    }
  }
  return null;
}

/**
 * @ngdoc directive
 * @name ngApp
 * @module ng
 *
 * @element ANY
 * @param {angular.Module} ngApp an optional application
 *   {@link angular.module module} name to load.
 * @param {boolean=} ngStrictDi if this attribute is present on the app element, the injector will be
 *   created in "strict-di" mode. This means that the application will fail to invoke functions which
 *   do not use explicit function annotation (and are thus unsuitable for minification), as described
 *   in {@link guide/di the Dependency Injection guide}, and useful debugging info will assist in
 *   tracking down the root of these bugs.
 *
 * @description
 *
 * Use this directive to **auto-bootstrap** an AngularJS application. The `ngApp` directive
 * designates the **root element** of the application and is typically placed near the root element
 * of the page - e.g. on the `<body>` or `<html>` tags.
 *
 * Only one AngularJS application can be auto-bootstrapped per HTML document. The first `ngApp`
 * found in the document will be used to define the root element to auto-bootstrap as an
 * application. To run multiple applications in an HTML document you must manually bootstrap them using
 * {@link angular.bootstrap} instead. AngularJS applications cannot be nested within each other.
 *
 * You can specify an **AngularJS module** to be used as the root module for the application.  This
 * module will be loaded into the {@link auto.$injector} when the application is bootstrapped. It
 * should contain the application code needed or have dependencies on other modules that will
 * contain the code. See {@link angular.module} for more information.
 *
 * In the example below if the `ngApp` directive were not placed on the `html` element then the
 * document would not be compiled, the `AppController` would not be instantiated and the `{{ a+b }}`
 * would not be resolved to `3`.
 *
 * `ngApp` is the easiest, and most common way to bootstrap an application.
 *
 <example module="ngAppDemo">
   <file name="index.html">
   <div ng-controller="ngAppDemoController">
     I can add: {{a}} + {{b}} =  {{ a+b }}
   </div>
   </file>
   <file name="script.js">
   angular.module('ngAppDemo', []).controller('ngAppDemoController', function($scope) {
     $scope.a = 1;
     $scope.b = 2;
   });
   </file>
 </example>
 *
 * Using `ngStrictDi`, you would see something like this:
 *
 <example ng-app-included="true">
   <file name="index.html">
   <div ng-app="ngAppStrictDemo" ng-strict-di>
       <div ng-controller="GoodController1">
           I can add: {{a}} + {{b}} =  {{ a+b }}

           <p>This renders because the controller does not fail to
              instantiate, by using explicit annotation style (see
              script.js for details)
           </p>
       </div>

       <div ng-controller="GoodController2">
           Name: <input ng-model="name"><br />
           Hello, {{name}}!

           <p>This renders because the controller does not fail to
              instantiate, by using explicit annotation style
              (see script.js for details)
           </p>
       </div>

       <div ng-controller="BadController">
           I can add: {{a}} + {{b}} =  {{ a+b }}

           <p>The controller could not be instantiated, due to relying
              on automatic function annotations (which are disabled in
              strict mode). As such, the content of this section is not
              interpolated, and there should be an error in your web console.
           </p>
       </div>
   </div>
   </file>
   <file name="script.js">
   angular.module('ngAppStrictDemo', [])
     // BadController will fail to instantiate, due to relying on automatic function annotation,
     // rather than an explicit annotation
     .controller('BadController', function($scope) {
       $scope.a = 1;
       $scope.b = 2;
     })
     // Unlike BadController, GoodController1 and GoodController2 will not fail to be instantiated,
     // due to using explicit annotations using the array style and $inject property, respectively.
     .controller('GoodController1', ['$scope', function($scope) {
       $scope.a = 1;
       $scope.b = 2;
     }])
     .controller('GoodController2', GoodController2);
     function GoodController2($scope) {
       $scope.name = "World";
     }
     GoodController2.$inject = ['$scope'];
   </file>
   <file name="style.css">
   div[ng-controller] {
       margin-bottom: 1em;
       -webkit-border-radius: 4px;
       border-radius: 4px;
       border: 1px solid;
       padding: .5em;
   }
   div[ng-controller^=Good] {
       border-color: #d6e9c6;
       background-color: #dff0d8;
       color: #3c763d;
   }
   div[ng-controller^=Bad] {
       border-color: #ebccd1;
       background-color: #f2dede;
       color: #a94442;
       margin-bottom: 0;
   }
   </file>
 </example>
 */
function angularInit(element, bootstrap) {
  var appElement,
      module,
      config = {};

  // The element `element` has priority over any other element
  forEach(ngAttrPrefixes, function(prefix) {
    var name = prefix + 'app';

    if (!appElement && element.hasAttribute && element.hasAttribute(name)) {
      appElement = element;
      module = element.getAttribute(name);
    }
  });
  forEach(ngAttrPrefixes, function(prefix) {
    var name = prefix + 'app';
    var candidate;

    if (!appElement && (candidate = element.querySelector('[' + name.replace(':', '\\:') + ']'))) {
      appElement = candidate;
      module = candidate.getAttribute(name);
    }
  });
  if (appElement) {
    config.strictDi = getNgAttribute(appElement, "strict-di") !== null;
    bootstrap(appElement, module ? [module] : [], config);
  }
}

/**
 * @ngdoc function
 * @name angular.bootstrap
 * @module ng
 * @description
 * Use this function to manually start up angular application.
 *
 * See: {@link guide/bootstrap Bootstrap}
 *
 * Note that Protractor based end-to-end tests cannot use this function to bootstrap manually.
 * They must use {@link ng.directive:ngApp ngApp}.
 *
 * Angular will detect if it has been loaded into the browser more than once and only allow the
 * first loaded script to be bootstrapped and will report a warning to the browser console for
 * each of the subsequent scripts. This prevents strange results in applications, where otherwise
 * multiple instances of Angular try to work on the DOM.
 *
 * ```html
 * <!doctype html>
 * <html>
 * <body>
 * <div ng-controller="WelcomeController">
 *   {{greeting}}
 * </div>
 *
 * <script src="angular.js"></script>
 * <script>
 *   var app = angular.module('demo', [])
 *   .controller('WelcomeController', function($scope) {
 *       $scope.greeting = 'Welcome!';
 *   });
 *   angular.bootstrap(document, ['demo']);
 * </script>
 * </body>
 * </html>
 * ```
 *
 * @param {DOMElement} element DOM element which is the root of angular application.
 * @param {Array<String|Function|Array>=} modules an array of modules to load into the application.
 *     Each item in the array should be the name of a predefined module or a (DI annotated)
 *     function that will be invoked by the injector as a `config` block.
 *     See: {@link angular.module modules}
 * @param {Object=} config an object for defining configuration options for the application. The
 *     following keys are supported:
 *
 * * `strictDi` - disable automatic function annotation for the application. This is meant to
 *   assist in finding bugs which break minified code. Defaults to `false`.
 *
 * @returns {auto.$injector} Returns the newly created injector for this app.
 */
function bootstrap(element, modules, config) {
  if (!isObject(config)) config = {};
  var defaultConfig = {
    strictDi: false
  };
  config = extend(defaultConfig, config);
  var doBootstrap = function() {
    element = jqLite(element);

    if (element.injector()) {
      var tag = (element[0] === document) ? 'document' : startingTag(element);
      //Encode angle brackets to prevent input from being sanitized to empty string #8683
      throw ngMinErr(
          'btstrpd',
          "App Already Bootstrapped with this Element '{0}'",
          tag.replace(/</,'&lt;').replace(/>/,'&gt;'));
    }

    modules = modules || [];
    modules.unshift(['$provide', function($provide) {
      $provide.value('$rootElement', element);
    }]);

    if (config.debugInfoEnabled) {
      // Pushing so that this overrides `debugInfoEnabled` setting defined in user's `modules`.
      modules.push(['$compileProvider', function($compileProvider) {
        $compileProvider.debugInfoEnabled(true);
      }]);
    }

    modules.unshift('ng');
    var injector = createInjector(modules, config.strictDi);
    injector.invoke(['$rootScope', '$rootElement', '$compile', '$injector',
       function bootstrapApply(scope, element, compile, injector) {
        scope.$apply(function() {
          element.data('$injector', injector);
          compile(element)(scope);
        });
      }]
    );
    return injector;
  };

  var NG_ENABLE_DEBUG_INFO = /^NG_ENABLE_DEBUG_INFO!/;
  var NG_DEFER_BOOTSTRAP = /^NG_DEFER_BOOTSTRAP!/;

  if (window && NG_ENABLE_DEBUG_INFO.test(window.name)) {
    config.debugInfoEnabled = true;
    window.name = window.name.replace(NG_ENABLE_DEBUG_INFO, '');
  }

  if (window && !NG_DEFER_BOOTSTRAP.test(window.name)) {
    return doBootstrap();
  }

  window.name = window.name.replace(NG_DEFER_BOOTSTRAP, '');
  angular.resumeBootstrap = function(extraModules) {
    forEach(extraModules, function(module) {
      modules.push(module);
    });
    return doBootstrap();
  };

  if (isFunction(angular.resumeDeferredBootstrap)) {
    angular.resumeDeferredBootstrap();
  }
}

/**
 * @ngdoc function
 * @name angular.reloadWithDebugInfo
 * @module ng
 * @description
 * Use this function to reload the current application with debug information turned on.
 * This takes precedence over a call to `$compileProvider.debugInfoEnabled(false)`.
 *
 * See {@link ng.$compileProvider#debugInfoEnabled} for more.
 */
function reloadWithDebugInfo() {
  window.name = 'NG_ENABLE_DEBUG_INFO!' + window.name;
  window.location.reload();
}

/**
 * @name angular.getTestability
 * @module ng
 * @description
 * Get the testability service for the instance of Angular on the given
 * element.
 * @param {DOMElement} element DOM element which is the root of angular application.
 */
function getTestability(rootElement) {
  var injector = angular.element(rootElement).injector();
  if (!injector) {
    throw ngMinErr('test',
      'no injector found for element argument to getTestability');
  }
  return injector.get('$$testability');
}

var SNAKE_CASE_REGEXP = /[A-Z]/g;
function snake_case(name, separator) {
  separator = separator || '_';
  return name.replace(SNAKE_CASE_REGEXP, function(letter, pos) {
    return (pos ? separator : '') + letter.toLowerCase();
  });
}

var bindJQueryFired = false;
var skipDestroyOnNextJQueryCleanData;
function bindJQuery() {
  var originalCleanData;

  if (bindJQueryFired) {
    return;
  }

  // bind to jQuery if present;
  jQuery = window.jQuery;
  // Use jQuery if it exists with proper functionality, otherwise default to us.
  // Angular 1.2+ requires jQuery 1.7+ for on()/off() support.
  // Angular 1.3+ technically requires at least jQuery 2.1+ but it may work with older
  // versions. It will not work for sure with jQuery <1.7, though.
  if (jQuery && jQuery.fn.on) {
    jqLite = jQuery;
    extend(jQuery.fn, {
      scope: JQLitePrototype.scope,
      isolateScope: JQLitePrototype.isolateScope,
      controller: JQLitePrototype.controller,
      injector: JQLitePrototype.injector,
      inheritedData: JQLitePrototype.inheritedData
    });

    // All nodes removed from the DOM via various jQuery APIs like .remove()
    // are passed through jQuery.cleanData. Monkey-patch this method to fire
    // the $destroy event on all removed nodes.
    originalCleanData = jQuery.cleanData;
    jQuery.cleanData = function(elems) {
      var events;
      if (!skipDestroyOnNextJQueryCleanData) {
        for (var i = 0, elem; (elem = elems[i]) != null; i++) {
          events = jQuery._data(elem, "events");
          if (events && events.$destroy) {
            jQuery(elem).triggerHandler('$destroy');
          }
        }
      } else {
        skipDestroyOnNextJQueryCleanData = false;
      }
      originalCleanData(elems);
    };
  } else {
    jqLite = JQLite;
  }

  angular.element = jqLite;

  // Prevent double-proxying.
  bindJQueryFired = true;
}

/**
 * throw error if the argument is falsy.
 */
function assertArg(arg, name, reason) {
  if (!arg) {
    throw ngMinErr('areq', "Argument '{0}' is {1}", (name || '?'), (reason || "required"));
  }
  return arg;
}

function assertArgFn(arg, name, acceptArrayAnnotation) {
  if (acceptArrayAnnotation && isArray(arg)) {
      arg = arg[arg.length - 1];
  }

  assertArg(isFunction(arg), name, 'not a function, got ' +
      (arg && typeof arg === 'object' ? arg.constructor.name || 'Object' : typeof arg));
  return arg;
}

/**
 * throw error if the name given is hasOwnProperty
 * @param  {String} name    the name to test
 * @param  {String} context the context in which the name is used, such as module or directive
 */
function assertNotHasOwnProperty(name, context) {
  if (name === 'hasOwnProperty') {
    throw ngMinErr('badname', "hasOwnProperty is not a valid {0} name", context);
  }
}

/**
 * Return the value accessible from the object by path. Any undefined traversals are ignored
 * @param {Object} obj starting object
 * @param {String} path path to traverse
 * @param {boolean} [bindFnToScope=true]
 * @returns {Object} value as accessible by path
 */
//TODO(misko): this function needs to be removed
function getter(obj, path, bindFnToScope) {
  if (!path) return obj;
  var keys = path.split('.');
  var key;
  var lastInstance = obj;
  var len = keys.length;

  for (var i = 0; i < len; i++) {
    key = keys[i];
    if (obj) {
      obj = (lastInstance = obj)[key];
    }
  }
  if (!bindFnToScope && isFunction(obj)) {
    return bind(lastInstance, obj);
  }
  return obj;
}

/**
 * Return the DOM siblings between the first and last node in the given array.
 * @param {Array} array like object
 * @returns {jqLite} jqLite collection containing the nodes
 */
function getBlockNodes(nodes) {
  // TODO(perf): just check if all items in `nodes` are siblings and if they are return the original
  //             collection, otherwise update the original collection.
  var node = nodes[0];
  var endNode = nodes[nodes.length - 1];
  var blockNodes = [node];

  do {
    node = node.nextSibling;
    if (!node) break;
    blockNodes.push(node);
  } while (node !== endNode);

  return jqLite(blockNodes);
}


/**
 * Creates a new object without a prototype. This object is useful for lookup without having to
 * guard against prototypically inherited properties via hasOwnProperty.
 *
 * Related micro-benchmarks:
 * - http://jsperf.com/object-create2
 * - http://jsperf.com/proto-map-lookup/2
 * - http://jsperf.com/for-in-vs-object-keys2
 *
 * @returns {Object}
 */
function createMap() {
  return Object.create(null);
}

var NODE_TYPE_ELEMENT = 1;
var NODE_TYPE_ATTRIBUTE = 2;
var NODE_TYPE_TEXT = 3;
var NODE_TYPE_COMMENT = 8;
var NODE_TYPE_DOCUMENT = 9;
var NODE_TYPE_DOCUMENT_FRAGMENT = 11;

/**
 * @ngdoc type
 * @name angular.Module
 * @module ng
 * @description
 *
 * Interface for configuring angular {@link angular.module modules}.
 */

function setupModuleLoader(window) {

  var $injectorMinErr = minErr('$injector');
  var ngMinErr = minErr('ng');

  function ensure(obj, name, factory) {
    return obj[name] || (obj[name] = factory());
  }

  var angular = ensure(window, 'angular', Object);

  // We need to expose `angular.$$minErr` to modules such as `ngResource` that reference it during bootstrap
  angular.$$minErr = angular.$$minErr || minErr;

  return ensure(angular, 'module', function() {
    /** @type {Object.<string, angular.Module>} */
    var modules = {};

    /**
     * @ngdoc function
     * @name angular.module
     * @module ng
     * @description
     *
     * The `angular.module` is a global place for creating, registering and retrieving Angular
     * modules.
     * All modules (angular core or 3rd party) that should be available to an application must be
     * registered using this mechanism.
     *
     * When passed two or more arguments, a new module is created.  If passed only one argument, an
     * existing module (the name passed as the first argument to `module`) is retrieved.
     *
     *
     * # Module
     *
     * A module is a collection of services, directives, controllers, filters, and configuration information.
     * `angular.module` is used to configure the {@link auto.$injector $injector}.
     *
     * ```js
     * // Create a new module
     * var myModule = angular.module('myModule', []);
     *
     * // register a new service
     * myModule.value('appName', 'MyCoolApp');
     *
     * // configure existing services inside initialization blocks.
     * myModule.config(['$locationProvider', function($locationProvider) {
     *   // Configure existing providers
     *   $locationProvider.hashPrefix('!');
     * }]);
     * ```
     *
     * Then you can create an injector and load your modules like this:
     *
     * ```js
     * var injector = angular.injector(['ng', 'myModule'])
     * ```
     *
     * However it's more likely that you'll just use
     * {@link ng.directive:ngApp ngApp} or
     * {@link angular.bootstrap} to simplify this process for you.
     *
     * @param {!string} name The name of the module to create or retrieve.
     * @param {!Array.<string>=} requires If specified then new module is being created. If
     *        unspecified then the module is being retrieved for further configuration.
     * @param {Function=} configFn Optional configuration function for the module. Same as
     *        {@link angular.Module#config Module#config()}.
     * @returns {module} new module with the {@link angular.Module} api.
     */
    return function module(name, requires, configFn) {
      var assertNotHasOwnProperty = function(name, context) {
        if (name === 'hasOwnProperty') {
          throw ngMinErr('badname', 'hasOwnProperty is not a valid {0} name', context);
        }
      };

      assertNotHasOwnProperty(name, 'module');
      if (requires && modules.hasOwnProperty(name)) {
        modules[name] = null;
      }
      return ensure(modules, name, function() {
        if (!requires) {
          throw $injectorMinErr('nomod', "Module '{0}' is not available! You either misspelled " +
             "the module name or forgot to load it. If registering a module ensure that you " +
             "specify the dependencies as the second argument.", name);
        }

        /** @type {!Array.<Array.<*>>} */
        var invokeQueue = [];

        /** @type {!Array.<Function>} */
        var configBlocks = [];

        /** @type {!Array.<Function>} */
        var runBlocks = [];

        var config = invokeLater('$injector', 'invoke', 'push', configBlocks);

        /** @type {angular.Module} */
        var moduleInstance = {
          // Private state
          _invokeQueue: invokeQueue,
          _configBlocks: configBlocks,
          _runBlocks: runBlocks,

          /**
           * @ngdoc property
           * @name angular.Module#requires
           * @module ng
           *
           * @description
           * Holds the list of modules which the injector will load before the current module is
           * loaded.
           */
          requires: requires,

          /**
           * @ngdoc property
           * @name angular.Module#name
           * @module ng
           *
           * @description
           * Name of the module.
           */
          name: name,


          /**
           * @ngdoc method
           * @name angular.Module#provider
           * @module ng
           * @param {string} name service name
           * @param {Function} providerType Construction function for creating new instance of the
           *                                service.
           * @description
           * See {@link auto.$provide#provider $provide.provider()}.
           */
          provider: invokeLater('$provide', 'provider'),

          /**
           * @ngdoc method
           * @name angular.Module#factory
           * @module ng
           * @param {string} name service name
           * @param {Function} providerFunction Function for creating new instance of the service.
           * @description
           * See {@link auto.$provide#factory $provide.factory()}.
           */
          factory: invokeLater('$provide', 'factory'),

          /**
           * @ngdoc method
           * @name angular.Module#service
           * @module ng
           * @param {string} name service name
           * @param {Function} constructor A constructor function that will be instantiated.
           * @description
           * See {@link auto.$provide#service $provide.service()}.
           */
          service: invokeLater('$provide', 'service'),

          /**
           * @ngdoc method
           * @name angular.Module#value
           * @module ng
           * @param {string} name service name
           * @param {*} object Service instance object.
           * @description
           * See {@link auto.$provide#value $provide.value()}.
           */
          value: invokeLater('$provide', 'value'),

          /**
           * @ngdoc method
           * @name angular.Module#constant
           * @module ng
           * @param {string} name constant name
           * @param {*} object Constant value.
           * @description
           * Because the constant are fixed, they get applied before other provide methods.
           * See {@link auto.$provide#constant $provide.constant()}.
           */
          constant: invokeLater('$provide', 'constant', 'unshift'),

          /**
           * @ngdoc method
           * @name angular.Module#animation
           * @module ng
           * @param {string} name animation name
           * @param {Function} animationFactory Factory function for creating new instance of an
           *                                    animation.
           * @description
           *
           * **NOTE**: animations take effect only if the **ngAnimate** module is loaded.
           *
           *
           * Defines an animation hook that can be later used with
           * {@link ngAnimate.$animate $animate} service and directives that use this service.
           *
           * ```js
           * module.animation('.animation-name', function($inject1, $inject2) {
           *   return {
           *     eventName : function(element, done) {
           *       //code to run the animation
           *       //once complete, then run done()
           *       return function cancellationFunction(element) {
           *         //code to cancel the animation
           *       }
           *     }
           *   }
           * })
           * ```
           *
           * See {@link ng.$animateProvider#register $animateProvider.register()} and
           * {@link ngAnimate ngAnimate module} for more information.
           */
          animation: invokeLater('$animateProvider', 'register'),

          /**
           * @ngdoc method
           * @name angular.Module#filter
           * @module ng
           * @param {string} name Filter name - this must be a valid angular expression identifier
           * @param {Function} filterFactory Factory function for creating new instance of filter.
           * @description
           * See {@link ng.$filterProvider#register $filterProvider.register()}.
           *
           * <div class="alert alert-warning">
           * **Note:** Filter names must be valid angular {@link expression} identifiers, such as `uppercase` or `orderBy`.
           * Names with special characters, such as hyphens and dots, are not allowed. If you wish to namespace
           * your filters, then you can use capitalization (`myappSubsectionFilterx`) or underscores
           * (`myapp_subsection_filterx`).
           * </div>
           */
          filter: invokeLater('$filterProvider', 'register'),

          /**
           * @ngdoc method
           * @name angular.Module#controller
           * @module ng
           * @param {string|Object} name Controller name, or an object map of controllers where the
           *    keys are the names and the values are the constructors.
           * @param {Function} constructor Controller constructor function.
           * @description
           * See {@link ng.$controllerProvider#register $controllerProvider.register()}.
           */
          controller: invokeLater('$controllerProvider', 'register'),

          /**
           * @ngdoc method
           * @name angular.Module#directive
           * @module ng
           * @param {string|Object} name Directive name, or an object map of directives where the
           *    keys are the names and the values are the factories.
           * @param {Function} directiveFactory Factory function for creating new instance of
           * directives.
           * @description
           * See {@link ng.$compileProvider#directive $compileProvider.directive()}.
           */
          directive: invokeLater('$compileProvider', 'directive'),

          /**
           * @ngdoc method
           * @name angular.Module#config
           * @module ng
           * @param {Function} configFn Execute this function on module load. Useful for service
           *    configuration.
           * @description
           * Use this method to register work which needs to be performed on module loading.
           * For more about how to configure services, see
           * {@link providers#provider-recipe Provider Recipe}.
           */
          config: config,

          /**
           * @ngdoc method
           * @name angular.Module#run
           * @module ng
           * @param {Function} initializationFn Execute this function after injector creation.
           *    Useful for application initialization.
           * @description
           * Use this method to register work which should be performed when the injector is done
           * loading all modules.
           */
          run: function(block) {
            runBlocks.push(block);
            return this;
          }
        };

        if (configFn) {
          config(configFn);
        }

        return moduleInstance;

        /**
         * @param {string} provider
         * @param {string} method
         * @param {String=} insertMethod
         * @returns {angular.Module}
         */
        function invokeLater(provider, method, insertMethod, queue) {
          if (!queue) queue = invokeQueue;
          return function() {
            queue[insertMethod || 'push']([provider, method, arguments]);
            return moduleInstance;
          };
        }
      });
    };
  });

}

/* global: toDebugString: true */

function serializeObject(obj) {
  var seen = [];

  return JSON.stringify(obj, function(key, val) {
    val = toJsonReplacer(key, val);
    if (isObject(val)) {

      if (seen.indexOf(val) >= 0) return '<<already seen>>';

      seen.push(val);
    }
    return val;
  });
}

function toDebugString(obj) {
  if (typeof obj === 'function') {
    return obj.toString().replace(/ \{[\s\S]*$/, '');
  } else if (typeof obj === 'undefined') {
    return 'undefined';
  } else if (typeof obj !== 'string') {
    return serializeObject(obj);
  }
  return obj;
}

/* global angularModule: true,
  version: true,

  $LocaleProvider,
  $CompileProvider,

  htmlAnchorDirective,
  inputDirective,
  inputDirective,
  formDirective,
  scriptDirective,
  selectDirective,
  styleDirective,
  optionDirective,
  ngBindDirective,
  ngBindHtmlDirective,
  ngBindTemplateDirective,
  ngClassDirective,
  ngClassEvenDirective,
  ngClassOddDirective,
  ngCspDirective,
  ngCloakDirective,
  ngControllerDirective,
  ngFormDirective,
  ngHideDirective,
  ngIfDirective,
  ngIncludeDirective,
  ngIncludeFillContentDirective,
  ngInitDirective,
  ngNonBindableDirective,
  ngPluralizeDirective,
  ngRepeatDirective,
  ngShowDirective,
  ngStyleDirective,
  ngSwitchDirective,
  ngSwitchWhenDirective,
  ngSwitchDefaultDirective,
  ngOptionsDirective,
  ngTranscludeDirective,
  ngModelDirective,
  ngListDirective,
  ngChangeDirective,
  patternDirective,
  patternDirective,
  requiredDirective,
  requiredDirective,
  minlengthDirective,
  minlengthDirective,
  maxlengthDirective,
  maxlengthDirective,
  ngValueDirective,
  ngModelOptionsDirective,
  ngAttributeAliasDirectives,
  ngEventDirectives,

  $AnchorScrollProvider,
  $AnimateProvider,
  $BrowserProvider,
  $CacheFactoryProvider,
  $ControllerProvider,
  $DocumentProvider,
  $ExceptionHandlerProvider,
  $FilterProvider,
  $InterpolateProvider,
  $IntervalProvider,
  $HttpProvider,
  $HttpBackendProvider,
  $LocationProvider,
  $LogProvider,
  $ParseProvider,
  $RootScopeProvider,
  $QProvider,
  $$QProvider,
  $$SanitizeUriProvider,
  $SceProvider,
  $SceDelegateProvider,
  $SnifferProvider,
  $TemplateCacheProvider,
  $TemplateRequestProvider,
  $$TestabilityProvider,
  $TimeoutProvider,
  $$RAFProvider,
  $$AsyncCallbackProvider,
  $WindowProvider,
  $$jqLiteProvider
*/


/**
 * @ngdoc object
 * @name angular.version
 * @module ng
 * @description
 * An object that contains information about the current AngularJS version. This object has the
 * following properties:
 *
 * - `full` – `{string}` – Full version string, such as "0.9.18".
 * - `major` – `{number}` – Major version number, such as "0".
 * - `minor` – `{number}` – Minor version number, such as "9".
 * - `dot` – `{number}` – Dot version number, such as "18".
 * - `codeName` – `{string}` – Code name of the release, such as "jiggling-armfat".
 */
var version = {
  full: '1.3.20',    // all of these placeholder strings will be replaced by grunt's
  major: 1,    // package task
  minor: 3,
  dot: 20,
  codeName: 'shallow-translucence'
};


function publishExternalAPI(angular) {
  extend(angular, {
    'bootstrap': bootstrap,
    'copy': copy,
    'extend': extend,
    'equals': equals,
    'element': jqLite,
    'forEach': forEach,
    'injector': createInjector,
    'noop': noop,
    'bind': bind,
    'toJson': toJson,
    'fromJson': fromJson,
    'identity': identity,
    'isUndefined': isUndefined,
    'isDefined': isDefined,
    'isString': isString,
    'isFunction': isFunction,
    'isObject': isObject,
    'isNumber': isNumber,
    'isElement': isElement,
    'isArray': isArray,
    'version': version,
    'isDate': isDate,
    'lowercase': lowercase,
    'uppercase': uppercase,
    'callbacks': {counter: 0},
    'getTestability': getTestability,
    '$$minErr': minErr,
    '$$csp': csp,
    'reloadWithDebugInfo': reloadWithDebugInfo
  });

  angularModule = setupModuleLoader(window);
  try {
    angularModule('ngLocale');
  } catch (e) {
    angularModule('ngLocale', []).provider('$locale', $LocaleProvider);
  }

  angularModule('ng', ['ngLocale'], ['$provide',
    function ngModule($provide) {
      // $$sanitizeUriProvider needs to be before $compileProvider as it is used by it.
      $provide.provider({
        $$sanitizeUri: $$SanitizeUriProvider
      });
      $provide.provider('$compile', $CompileProvider).
        directive({
            a: htmlAnchorDirective,
            input: inputDirective,
            textarea: inputDirective,
            form: formDirective,
            script: scriptDirective,
            select: selectDirective,
            style: styleDirective,
            option: optionDirective,
            ngBind: ngBindDirective,
            ngBindHtml: ngBindHtmlDirective,
            ngBindTemplate: ngBindTemplateDirective,
            ngClass: ngClassDirective,
            ngClassEven: ngClassEvenDirective,
            ngClassOdd: ngClassOddDirective,
            ngCloak: ngCloakDirective,
            ngController: ngControllerDirective,
            ngForm: ngFormDirective,
            ngHide: ngHideDirective,
            ngIf: ngIfDirective,
            ngInclude: ngIncludeDirective,
            ngInit: ngInitDirective,
            ngNonBindable: ngNonBindableDirective,
            ngPluralize: ngPluralizeDirective,
            ngRepeat: ngRepeatDirective,
            ngShow: ngShowDirective,
            ngStyle: ngStyleDirective,
            ngSwitch: ngSwitchDirective,
            ngSwitchWhen: ngSwitchWhenDirective,
            ngSwitchDefault: ngSwitchDefaultDirective,
            ngOptions: ngOptionsDirective,
            ngTransclude: ngTranscludeDirective,
            ngModel: ngModelDirective,
            ngList: ngListDirective,
            ngChange: ngChangeDirective,
            pattern: patternDirective,
            ngPattern: patternDirective,
            required: requiredDirective,
            ngRequired: requiredDirective,
            minlength: minlengthDirective,
            ngMinlength: minlengthDirective,
            maxlength: maxlengthDirective,
            ngMaxlength: maxlengthDirective,
            ngValue: ngValueDirective,
            ngModelOptions: ngModelOptionsDirective
        }).
        directive({
          ngInclude: ngIncludeFillContentDirective
        }).
        directive(ngAttributeAliasDirectives).
        directive(ngEventDirectives);
      $provide.provider({
        $anchorScroll: $AnchorScrollProvider,
        $animate: $AnimateProvider,
        $browser: $BrowserProvider,
        $cacheFactory: $CacheFactoryProvider,
        $controller: $ControllerProvider,
        $document: $DocumentProvider,
        $exceptionHandler: $ExceptionHandlerProvider,
        $filter: $FilterProvider,
        $interpolate: $InterpolateProvider,
        $interval: $IntervalProvider,
        $http: $HttpProvider,
        $httpBackend: $HttpBackendProvider,
        $location: $LocationProvider,
        $log: $LogProvider,
        $parse: $ParseProvider,
        $rootScope: $RootScopeProvider,
        $q: $QProvider,
        $$q: $$QProvider,
        $sce: $SceProvider,
        $sceDelegate: $SceDelegateProvider,
        $sniffer: $SnifferProvider,
        $templateCache: $TemplateCacheProvider,
        $templateRequest: $TemplateRequestProvider,
        $$testability: $$TestabilityProvider,
        $timeout: $TimeoutProvider,
        $window: $WindowProvider,
        $$rAF: $$RAFProvider,
        $$asyncCallback: $$AsyncCallbackProvider,
        $$jqLite: $$jqLiteProvider
      });
    }
  ]);
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 *     Any commits to this file should be reviewed with security in mind.  *
 *   Changes to this file can potentially create security vulnerabilities. *
 *          An approval from 2 Core members with history of modifying      *
 *                         this file is required.                          *
 *                                                                         *
 *  Does the change somehow allow for arbitrary javascript to be executed? *
 *    Or allows for someone to change the prototype of built-in objects?   *
 *     Or gives undesired access to variables likes document or window?    *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

/* global JQLitePrototype: true,
  addEventListenerFn: true,
  removeEventListenerFn: true,
  BOOLEAN_ATTR: true,
  ALIASED_ATTR: true,
*/

//////////////////////////////////
//JQLite
//////////////////////////////////

/**
 * @ngdoc function
 * @name angular.element
 * @module ng
 * @kind function
 *
 * @description
 * Wraps a raw DOM element or HTML string as a [jQuery](http://jquery.com) element.
 *
 * If jQuery is available, `angular.element` is an alias for the
 * [jQuery](http://api.jquery.com/jQuery/) function. If jQuery is not available, `angular.element`
 * delegates to Angular's built-in subset of jQuery, called "jQuery lite" or "jqLite."
 *
 * <div class="alert alert-success">jqLite is a tiny, API-compatible subset of jQuery that allows
 * Angular to manipulate the DOM in a cross-browser compatible way. **jqLite** implements only the most
 * commonly needed functionality with the goal of having a very small footprint.</div>
 *
 * To use `jQuery`, simply ensure it is loaded before the `angular.js` file.
 *
 * <div class="alert">**Note:** all element references in Angular are always wrapped with jQuery or
 * jqLite; they are never raw DOM references.</div>
 *
 * ## Angular's jqLite
 * jqLite provides only the following jQuery methods:
 *
 * - [`addClass()`](http://api.jquery.com/addClass/)
 * - [`after()`](http://api.jquery.com/after/)
 * - [`append()`](http://api.jquery.com/append/)
 * - [`attr()`](http://api.jquery.com/attr/) - Does not support functions as parameters
 * - [`bind()`](http://api.jquery.com/bind/) - Does not support namespaces, selectors or eventData
 * - [`children()`](http://api.jquery.com/children/) - Does not support selectors
 * - [`clone()`](http://api.jquery.com/clone/)
 * - [`contents()`](http://api.jquery.com/contents/)
 * - [`css()`](http://api.jquery.com/css/) - Only retrieves inline-styles, does not call `getComputedStyle()`. As a setter, does not convert numbers to strings or append 'px'.
 * - [`data()`](http://api.jquery.com/data/)
 * - [`detach()`](http://api.jquery.com/detach/)
 * - [`empty()`](http://api.jquery.com/empty/)
 * - [`eq()`](http://api.jquery.com/eq/)
 * - [`find()`](http://api.jquery.com/find/) - Limited to lookups by tag name
 * - [`hasClass()`](http://api.jquery.com/hasClass/)
 * - [`html()`](http://api.jquery.com/html/)
 * - [`next()`](http://api.jquery.com/next/) - Does not support selectors
 * - [`on()`](http://api.jquery.com/on/) - Does not support namespaces, selectors or eventData
 * - [`off()`](http://api.jquery.com/off/) - Does not support namespaces or selectors
 * - [`one()`](http://api.jquery.com/one/) - Does not support namespaces or selectors
 * - [`parent()`](http://api.jquery.com/parent/) - Does not support selectors
 * - [`prepend()`](http://api.jquery.com/prepend/)
 * - [`prop()`](http://api.jquery.com/prop/)
 * - [`ready()`](http://api.jquery.com/ready/)
 * - [`remove()`](http://api.jquery.com/remove/)
 * - [`removeAttr()`](http://api.jquery.com/removeAttr/)
 * - [`removeClass()`](http://api.jquery.com/removeClass/)
 * - [`removeData()`](http://api.jquery.com/removeData/)
 * - [`replaceWith()`](http://api.jquery.com/replaceWith/)
 * - [`text()`](http://api.jquery.com/text/)
 * - [`toggleClass()`](http://api.jquery.com/toggleClass/)
 * - [`triggerHandler()`](http://api.jquery.com/triggerHandler/) - Passes a dummy event object to handlers.
 * - [`unbind()`](http://api.jquery.com/unbind/) - Does not support namespaces
 * - [`val()`](http://api.jquery.com/val/)
 * - [`wrap()`](http://api.jquery.com/wrap/)
 *
 * ## jQuery/jqLite Extras
 * Angular also provides the following additional methods and events to both jQuery and jqLite:
 *
 * ### Events
 * - `$destroy` - AngularJS intercepts all jqLite/jQuery's DOM destruction apis and fires this event
 *    on all DOM nodes being removed.  This can be used to clean up any 3rd party bindings to the DOM
 *    element before it is removed.
 *
 * ### Methods
 * - `controller(name)` - retrieves the controller of the current element or its parent. By default
 *   retrieves controller associated with the `ngController` directive. If `name` is provided as
 *   camelCase directive name, then the controller for this directive will be retrieved (e.g.
 *   `'ngModel'`).
 * - `injector()` - retrieves the injector of the current element or its parent.
 * - `scope()` - retrieves the {@link ng.$rootScope.Scope scope} of the current
 *   element or its parent. Requires {@link guide/production#disabling-debug-data Debug Data} to
 *   be enabled.
 * - `isolateScope()` - retrieves an isolate {@link ng.$rootScope.Scope scope} if one is attached directly to the
 *   current element. This getter should be used only on elements that contain a directive which starts a new isolate
 *   scope. Calling `scope()` on this element always returns the original non-isolate scope.
 *   Requires {@link guide/production#disabling-debug-data Debug Data} to be enabled.
 * - `inheritedData()` - same as `data()`, but walks up the DOM until a value is found or the top
 *   parent element is reached.
 *
 * @param {string|DOMElement} element HTML string or DOMElement to be wrapped into jQuery.
 * @returns {Object} jQuery object.
 */

JQLite.expando = 'ng339';

var jqCache = JQLite.cache = {},
    jqId = 1,
    addEventListenerFn = function(element, type, fn) {
      element.addEventListener(type, fn, false);
    },
    removeEventListenerFn = function(element, type, fn) {
      element.removeEventListener(type, fn, false);
    };

/*
 * !!! This is an undocumented "private" function !!!
 */
JQLite._data = function(node) {
  //jQuery always returns an object on cache miss
  return this.cache[node[this.expando]] || {};
};

function jqNextId() { return ++jqId; }


var SPECIAL_CHARS_REGEXP = /([\:\-\_]+(.))/g;
var MOZ_HACK_REGEXP = /^moz([A-Z])/;
var MOUSE_EVENT_MAP= { mouseleave: "mouseout", mouseenter: "mouseover"};
var jqLiteMinErr = minErr('jqLite');

/**
 * Converts snake_case to camelCase.
 * Also there is special case for Moz prefix starting with upper case letter.
 * @param name Name to normalize
 */
function camelCase(name) {
  return name.
    replace(SPECIAL_CHARS_REGEXP, function(_, separator, letter, offset) {
      return offset ? letter.toUpperCase() : letter;
    }).
    replace(MOZ_HACK_REGEXP, 'Moz$1');
}

var SINGLE_TAG_REGEXP = /^<(\w+)\s*\/?>(?:<\/\1>|)$/;
var HTML_REGEXP = /<|&#?\w+;/;
var TAG_NAME_REGEXP = /<([\w:]+)/;
var XHTML_TAG_REGEXP = /<(?!area|br|col|embed|hr|img|input|link|meta|param)(([\w:]+)[^>]*)\/>/gi;

var wrapMap = {
  'option': [1, '<select multiple="multiple">', '</select>'],

  'thead': [1, '<table>', '</table>'],
  'col': [2, '<table><colgroup>', '</colgroup></table>'],
  'tr': [2, '<table><tbody>', '</tbody></table>'],
  'td': [3, '<table><tbody><tr>', '</tr></tbody></table>'],
  '_default': [0, "", ""]
};

wrapMap.optgroup = wrapMap.option;
wrapMap.tbody = wrapMap.tfoot = wrapMap.colgroup = wrapMap.caption = wrapMap.thead;
wrapMap.th = wrapMap.td;


function jqLiteIsTextNode(html) {
  return !HTML_REGEXP.test(html);
}

function jqLiteAcceptsData(node) {
  // The window object can accept data but has no nodeType
  // Otherwise we are only interested in elements (1) and documents (9)
  var nodeType = node.nodeType;
  return nodeType === NODE_TYPE_ELEMENT || !nodeType || nodeType === NODE_TYPE_DOCUMENT;
}

function jqLiteBuildFragment(html, context) {
  var tmp, tag, wrap,
      fragment = context.createDocumentFragment(),
      nodes = [], i;

  if (jqLiteIsTextNode(html)) {
    // Convert non-html into a text node
    nodes.push(context.createTextNode(html));
  } else {
    // Convert html into DOM nodes
    tmp = tmp || fragment.appendChild(context.createElement("div"));
    tag = (TAG_NAME_REGEXP.exec(html) || ["", ""])[1].toLowerCase();
    wrap = wrapMap[tag] || wrapMap._default;
    tmp.innerHTML = wrap[1] + html.replace(XHTML_TAG_REGEXP, "<$1></$2>") + wrap[2];

    // Descend through wrappers to the right content
    i = wrap[0];
    while (i--) {
      tmp = tmp.lastChild;
    }

    nodes = concat(nodes, tmp.childNodes);

    tmp = fragment.firstChild;
    tmp.textContent = "";
  }

  // Remove wrapper from fragment
  fragment.textContent = "";
  fragment.innerHTML = ""; // Clear inner HTML
  forEach(nodes, function(node) {
    fragment.appendChild(node);
  });

  return fragment;
}

function jqLiteParseHTML(html, context) {
  context = context || document;
  var parsed;

  if ((parsed = SINGLE_TAG_REGEXP.exec(html))) {
    return [context.createElement(parsed[1])];
  }

  if ((parsed = jqLiteBuildFragment(html, context))) {
    return parsed.childNodes;
  }

  return [];
}

/////////////////////////////////////////////
function JQLite(element) {
  if (element instanceof JQLite) {
    return element;
  }

  var argIsString;

  if (isString(element)) {
    element = trim(element);
    argIsString = true;
  }
  if (!(this instanceof JQLite)) {
    if (argIsString && element.charAt(0) != '<') {
      throw jqLiteMinErr('nosel', 'Looking up elements via selectors is not supported by jqLite! See: http://docs.angularjs.org/api/angular.element');
    }
    return new JQLite(element);
  }

  if (argIsString) {
    jqLiteAddNodes(this, jqLiteParseHTML(element));
  } else {
    jqLiteAddNodes(this, element);
  }
}

function jqLiteClone(element) {
  return element.cloneNode(true);
}

function jqLiteDealoc(element, onlyDescendants) {
  if (!onlyDescendants) jqLiteRemoveData(element);

  if (element.querySelectorAll) {
    var descendants = element.querySelectorAll('*');
    for (var i = 0, l = descendants.length; i < l; i++) {
      jqLiteRemoveData(descendants[i]);
    }
  }
}

function jqLiteOff(element, type, fn, unsupported) {
  if (isDefined(unsupported)) throw jqLiteMinErr('offargs', 'jqLite#off() does not support the `selector` argument');

  var expandoStore = jqLiteExpandoStore(element);
  var events = expandoStore && expandoStore.events;
  var handle = expandoStore && expandoStore.handle;

  if (!handle) return; //no listeners registered

  if (!type) {
    for (type in events) {
      if (type !== '$destroy') {
        removeEventListenerFn(element, type, handle);
      }
      delete events[type];
    }
  } else {
    forEach(type.split(' '), function(type) {
      if (isDefined(fn)) {
        var listenerFns = events[type];
        arrayRemove(listenerFns || [], fn);
        if (listenerFns && listenerFns.length > 0) {
          return;
        }
      }

      removeEventListenerFn(element, type, handle);
      delete events[type];
    });
  }
}

function jqLiteRemoveData(element, name) {
  var expandoId = element.ng339;
  var expandoStore = expandoId && jqCache[expandoId];

  if (expandoStore) {
    if (name) {
      delete expandoStore.data[name];
      return;
    }

    if (expandoStore.handle) {
      if (expandoStore.events.$destroy) {
        expandoStore.handle({}, '$destroy');
      }
      jqLiteOff(element);
    }
    delete jqCache[expandoId];
    element.ng339 = undefined; // don't delete DOM expandos. IE and Chrome don't like it
  }
}


function jqLiteExpandoStore(element, createIfNecessary) {
  var expandoId = element.ng339,
      expandoStore = expandoId && jqCache[expandoId];

  if (createIfNecessary && !expandoStore) {
    element.ng339 = expandoId = jqNextId();
    expandoStore = jqCache[expandoId] = {events: {}, data: {}, handle: undefined};
  }

  return expandoStore;
}


function jqLiteData(element, key, value) {
  if (jqLiteAcceptsData(element)) {

    var isSimpleSetter = isDefined(value);
    var isSimpleGetter = !isSimpleSetter && key && !isObject(key);
    var massGetter = !key;
    var expandoStore = jqLiteExpandoStore(element, !isSimpleGetter);
    var data = expandoStore && expandoStore.data;

    if (isSimpleSetter) { // data('key', value)
      data[key] = value;
    } else {
      if (massGetter) {  // data()
        return data;
      } else {
        if (isSimpleGetter) { // data('key')
          // don't force creation of expandoStore if it doesn't exist yet
          return data && data[key];
        } else { // mass-setter: data({key1: val1, key2: val2})
          extend(data, key);
        }
      }
    }
  }
}

function jqLiteHasClass(element, selector) {
  if (!element.getAttribute) return false;
  return ((" " + (element.getAttribute('class') || '') + " ").replace(/[\n\t]/g, " ").
      indexOf(" " + selector + " ") > -1);
}

function jqLiteRemoveClass(element, cssClasses) {
  if (cssClasses && element.setAttribute) {
    forEach(cssClasses.split(' '), function(cssClass) {
      element.setAttribute('class', trim(
          (" " + (element.getAttribute('class') || '') + " ")
          .replace(/[\n\t]/g, " ")
          .replace(" " + trim(cssClass) + " ", " "))
      );
    });
  }
}

function jqLiteAddClass(element, cssClasses) {
  if (cssClasses && element.setAttribute) {
    var existingClasses = (' ' + (element.getAttribute('class') || '') + ' ')
                            .replace(/[\n\t]/g, " ");

    forEach(cssClasses.split(' '), function(cssClass) {
      cssClass = trim(cssClass);
      if (existingClasses.indexOf(' ' + cssClass + ' ') === -1) {
        existingClasses += cssClass + ' ';
      }
    });

    element.setAttribute('class', trim(existingClasses));
  }
}


function jqLiteAddNodes(root, elements) {
  // THIS CODE IS VERY HOT. Don't make changes without benchmarking.

  if (elements) {

    // if a Node (the most common case)
    if (elements.nodeType) {
      root[root.length++] = elements;
    } else {
      var length = elements.length;

      // if an Array or NodeList and not a Window
      if (typeof length === 'number' && elements.window !== elements) {
        if (length) {
          for (var i = 0; i < length; i++) {
            root[root.length++] = elements[i];
          }
        }
      } else {
        root[root.length++] = elements;
      }
    }
  }
}


function jqLiteController(element, name) {
  return jqLiteInheritedData(element, '$' + (name || 'ngController') + 'Controller');
}

function jqLiteInheritedData(element, name, value) {
  // if element is the document object work with the html element instead
  // this makes $(document).scope() possible
  if (element.nodeType == NODE_TYPE_DOCUMENT) {
    element = element.documentElement;
  }
  var names = isArray(name) ? name : [name];

  while (element) {
    for (var i = 0, ii = names.length; i < ii; i++) {
      if ((value = jqLite.data(element, names[i])) !== undefined) return value;
    }

    // If dealing with a document fragment node with a host element, and no parent, use the host
    // element as the parent. This enables directives within a Shadow DOM or polyfilled Shadow DOM
    // to lookup parent controllers.
    element = element.parentNode || (element.nodeType === NODE_TYPE_DOCUMENT_FRAGMENT && element.host);
  }
}

function jqLiteEmpty(element) {
  jqLiteDealoc(element, true);
  while (element.firstChild) {
    element.removeChild(element.firstChild);
  }
}

function jqLiteRemove(element, keepData) {
  if (!keepData) jqLiteDealoc(element);
  var parent = element.parentNode;
  if (parent) parent.removeChild(element);
}


function jqLiteDocumentLoaded(action, win) {
  win = win || window;
  if (win.document.readyState === 'complete') {
    // Force the action to be run async for consistent behaviour
    // from the action's point of view
    // i.e. it will definitely not be in a $apply
    win.setTimeout(action);
  } else {
    // No need to unbind this handler as load is only ever called once
    jqLite(win).on('load', action);
  }
}

//////////////////////////////////////////
// Functions which are declared directly.
//////////////////////////////////////////
var JQLitePrototype = JQLite.prototype = {
  ready: function(fn) {
    var fired = false;

    function trigger() {
      if (fired) return;
      fired = true;
      fn();
    }

    // check if document is already loaded
    if (document.readyState === 'complete') {
      setTimeout(trigger);
    } else {
      this.on('DOMContentLoaded', trigger); // works for modern browsers and IE9
      // we can not use jqLite since we are not done loading and jQuery could be loaded later.
      // jshint -W064
      JQLite(window).on('load', trigger); // fallback to window.onload for others
      // jshint +W064
    }
  },
  toString: function() {
    var value = [];
    forEach(this, function(e) { value.push('' + e);});
    return '[' + value.join(', ') + ']';
  },

  eq: function(index) {
      return (index >= 0) ? jqLite(this[index]) : jqLite(this[this.length + index]);
  },

  length: 0,
  push: push,
  sort: [].sort,
  splice: [].splice
};

//////////////////////////////////////////
// Functions iterating getter/setters.
// these functions return self on setter and
// value on get.
//////////////////////////////////////////
var BOOLEAN_ATTR = {};
forEach('multiple,selected,checked,disabled,readOnly,required,open'.split(','), function(value) {
  BOOLEAN_ATTR[lowercase(value)] = value;
});
var BOOLEAN_ELEMENTS = {};
forEach('input,select,option,textarea,button,form,details'.split(','), function(value) {
  BOOLEAN_ELEMENTS[value] = true;
});
var ALIASED_ATTR = {
  'ngMinlength': 'minlength',
  'ngMaxlength': 'maxlength',
  'ngMin': 'min',
  'ngMax': 'max',
  'ngPattern': 'pattern'
};

function getBooleanAttrName(element, name) {
  // check dom last since we will most likely fail on name
  var booleanAttr = BOOLEAN_ATTR[name.toLowerCase()];

  // booleanAttr is here twice to minimize DOM access
  return booleanAttr && BOOLEAN_ELEMENTS[nodeName_(element)] && booleanAttr;
}

function getAliasedAttrName(element, name) {
  var nodeName = element.nodeName;
  return (nodeName === 'INPUT' || nodeName === 'TEXTAREA') && ALIASED_ATTR[name];
}

forEach({
  data: jqLiteData,
  removeData: jqLiteRemoveData
}, function(fn, name) {
  JQLite[name] = fn;
});

forEach({
  data: jqLiteData,
  inheritedData: jqLiteInheritedData,

  scope: function(element) {
    // Can't use jqLiteData here directly so we stay compatible with jQuery!
    return jqLite.data(element, '$scope') || jqLiteInheritedData(element.parentNode || element, ['$isolateScope', '$scope']);
  },

  isolateScope: function(element) {
    // Can't use jqLiteData here directly so we stay compatible with jQuery!
    return jqLite.data(element, '$isolateScope') || jqLite.data(element, '$isolateScopeNoTemplate');
  },

  controller: jqLiteController,

  injector: function(element) {
    return jqLiteInheritedData(element, '$injector');
  },

  removeAttr: function(element, name) {
    element.removeAttribute(name);
  },

  hasClass: jqLiteHasClass,

  css: function(element, name, value) {
    name = camelCase(name);

    if (isDefined(value)) {
      element.style[name] = value;
    } else {
      return element.style[name];
    }
  },

  attr: function(element, name, value) {
    var nodeType = element.nodeType;
    if (nodeType === NODE_TYPE_TEXT || nodeType === NODE_TYPE_ATTRIBUTE || nodeType === NODE_TYPE_COMMENT) {
      return;
    }
    var lowercasedName = lowercase(name);
    if (BOOLEAN_ATTR[lowercasedName]) {
      if (isDefined(value)) {
        if (!!value) {
          element[name] = true;
          element.setAttribute(name, lowercasedName);
        } else {
          element[name] = false;
          element.removeAttribute(lowercasedName);
        }
      } else {
        return (element[name] ||
                 (element.attributes.getNamedItem(name) || noop).specified)
               ? lowercasedName
               : undefined;
      }
    } else if (isDefined(value)) {
      element.setAttribute(name, value);
    } else if (element.getAttribute) {
      // the extra argument "2" is to get the right thing for a.href in IE, see jQuery code
      // some elements (e.g. Document) don't have get attribute, so return undefined
      var ret = element.getAttribute(name, 2);
      // normalize non-existing attributes to undefined (as jQuery)
      return ret === null ? undefined : ret;
    }
  },

  prop: function(element, name, value) {
    if (isDefined(value)) {
      element[name] = value;
    } else {
      return element[name];
    }
  },

  text: (function() {
    getText.$dv = '';
    return getText;

    function getText(element, value) {
      if (isUndefined(value)) {
        var nodeType = element.nodeType;
        return (nodeType === NODE_TYPE_ELEMENT || nodeType === NODE_TYPE_TEXT) ? element.textContent : '';
      }
      element.textContent = value;
    }
  })(),

  val: function(element, value) {
    if (isUndefined(value)) {
      if (element.multiple && nodeName_(element) === 'select') {
        var result = [];
        forEach(element.options, function(option) {
          if (option.selected) {
            result.push(option.value || option.text);
          }
        });
        return result.length === 0 ? null : result;
      }
      return element.value;
    }
    element.value = value;
  },

  html: function(element, value) {
    if (isUndefined(value)) {
      return element.innerHTML;
    }
    jqLiteDealoc(element, true);
    element.innerHTML = value;
  },

  empty: jqLiteEmpty
}, function(fn, name) {
  /**
   * Properties: writes return selection, reads return first value
   */
  JQLite.prototype[name] = function(arg1, arg2) {
    var i, key;
    var nodeCount = this.length;

    // jqLiteHasClass has only two arguments, but is a getter-only fn, so we need to special-case it
    // in a way that survives minification.
    // jqLiteEmpty takes no arguments but is a setter.
    if (fn !== jqLiteEmpty &&
        (((fn.length == 2 && (fn !== jqLiteHasClass && fn !== jqLiteController)) ? arg1 : arg2) === undefined)) {
      if (isObject(arg1)) {

        // we are a write, but the object properties are the key/values
        for (i = 0; i < nodeCount; i++) {
          if (fn === jqLiteData) {
            // data() takes the whole object in jQuery
            fn(this[i], arg1);
          } else {
            for (key in arg1) {
              fn(this[i], key, arg1[key]);
            }
          }
        }
        // return self for chaining
        return this;
      } else {
        // we are a read, so read the first child.
        // TODO: do we still need this?
        var value = fn.$dv;
        // Only if we have $dv do we iterate over all, otherwise it is just the first element.
        var jj = (value === undefined) ? Math.min(nodeCount, 1) : nodeCount;
        for (var j = 0; j < jj; j++) {
          var nodeValue = fn(this[j], arg1, arg2);
          value = value ? value + nodeValue : nodeValue;
        }
        return value;
      }
    } else {
      // we are a write, so apply to all children
      for (i = 0; i < nodeCount; i++) {
        fn(this[i], arg1, arg2);
      }
      // return self for chaining
      return this;
    }
  };
});

function createEventHandler(element, events) {
  var eventHandler = function(event, type) {
    // jQuery specific api
    event.isDefaultPrevented = function() {
      return event.defaultPrevented;
    };

    var eventFns = events[type || event.type];
    var eventFnsLength = eventFns ? eventFns.length : 0;

    if (!eventFnsLength) return;

    if (isUndefined(event.immediatePropagationStopped)) {
      var originalStopImmediatePropagation = event.stopImmediatePropagation;
      event.stopImmediatePropagation = function() {
        event.immediatePropagationStopped = true;

        if (event.stopPropagation) {
          event.stopPropagation();
        }

        if (originalStopImmediatePropagation) {
          originalStopImmediatePropagation.call(event);
        }
      };
    }

    event.isImmediatePropagationStopped = function() {
      return event.immediatePropagationStopped === true;
    };

    // Copy event handlers in case event handlers array is modified during execution.
    if ((eventFnsLength > 1)) {
      eventFns = shallowCopy(eventFns);
    }

    for (var i = 0; i < eventFnsLength; i++) {
      if (!event.isImmediatePropagationStopped()) {
        eventFns[i].call(element, event);
      }
    }
  };

  // TODO: this is a hack for angularMocks/clearDataCache that makes it possible to deregister all
  //       events on `element`
  eventHandler.elem = element;
  return eventHandler;
}

//////////////////////////////////////////
// Functions iterating traversal.
// These functions chain results into a single
// selector.
//////////////////////////////////////////
forEach({
  removeData: jqLiteRemoveData,

  on: function jqLiteOn(element, type, fn, unsupported) {
    if (isDefined(unsupported)) throw jqLiteMinErr('onargs', 'jqLite#on() does not support the `selector` or `eventData` parameters');

    // Do not add event handlers to non-elements because they will not be cleaned up.
    if (!jqLiteAcceptsData(element)) {
      return;
    }

    var expandoStore = jqLiteExpandoStore(element, true);
    var events = expandoStore.events;
    var handle = expandoStore.handle;

    if (!handle) {
      handle = expandoStore.handle = createEventHandler(element, events);
    }

    // http://jsperf.com/string-indexof-vs-split
    var types = type.indexOf(' ') >= 0 ? type.split(' ') : [type];
    var i = types.length;

    while (i--) {
      type = types[i];
      var eventFns = events[type];

      if (!eventFns) {
        events[type] = [];

        if (type === 'mouseenter' || type === 'mouseleave') {
          // Refer to jQuery's implementation of mouseenter & mouseleave
          // Read about mouseenter and mouseleave:
          // http://www.quirksmode.org/js/events_mouse.html#link8

          jqLiteOn(element, MOUSE_EVENT_MAP[type], function(event) {
            var target = this, related = event.relatedTarget;
            // For mousenter/leave call the handler if related is outside the target.
            // NB: No relatedTarget if the mouse left/entered the browser window
            if (!related || (related !== target && !target.contains(related))) {
              handle(event, type);
            }
          });

        } else {
          if (type !== '$destroy') {
            addEventListenerFn(element, type, handle);
          }
        }
        eventFns = events[type];
      }
      eventFns.push(fn);
    }
  },

  off: jqLiteOff,

  one: function(element, type, fn) {
    element = jqLite(element);

    //add the listener twice so that when it is called
    //you can remove the original function and still be
    //able to call element.off(ev, fn) normally
    element.on(type, function onFn() {
      element.off(type, fn);
      element.off(type, onFn);
    });
    element.on(type, fn);
  },

  replaceWith: function(element, replaceNode) {
    var index, parent = element.parentNode;
    jqLiteDealoc(element);
    forEach(new JQLite(replaceNode), function(node) {
      if (index) {
        parent.insertBefore(node, index.nextSibling);
      } else {
        parent.replaceChild(node, element);
      }
      index = node;
    });
  },

  children: function(element) {
    var children = [];
    forEach(element.childNodes, function(element) {
      if (element.nodeType === NODE_TYPE_ELEMENT)
        children.push(element);
    });
    return children;
  },

  contents: function(element) {
    return element.contentDocument || element.childNodes || [];
  },

  append: function(element, node) {
    var nodeType = element.nodeType;
    if (nodeType !== NODE_TYPE_ELEMENT && nodeType !== NODE_TYPE_DOCUMENT_FRAGMENT) return;

    node = new JQLite(node);

    for (var i = 0, ii = node.length; i < ii; i++) {
      var child = node[i];
      element.appendChild(child);
    }
  },

  prepend: function(element, node) {
    if (element.nodeType === NODE_TYPE_ELEMENT) {
      var index = element.firstChild;
      forEach(new JQLite(node), function(child) {
        element.insertBefore(child, index);
      });
    }
  },

  wrap: function(element, wrapNode) {
    wrapNode = jqLite(wrapNode).eq(0).clone()[0];
    var parent = element.parentNode;
    if (parent) {
      parent.replaceChild(wrapNode, element);
    }
    wrapNode.appendChild(element);
  },

  remove: jqLiteRemove,

  detach: function(element) {
    jqLiteRemove(element, true);
  },

  after: function(element, newElement) {
    var index = element, parent = element.parentNode;
    newElement = new JQLite(newElement);

    for (var i = 0, ii = newElement.length; i < ii; i++) {
      var node = newElement[i];
      parent.insertBefore(node, index.nextSibling);
      index = node;
    }
  },

  addClass: jqLiteAddClass,
  removeClass: jqLiteRemoveClass,

  toggleClass: function(element, selector, condition) {
    if (selector) {
      forEach(selector.split(' '), function(className) {
        var classCondition = condition;
        if (isUndefined(classCondition)) {
          classCondition = !jqLiteHasClass(element, className);
        }
        (classCondition ? jqLiteAddClass : jqLiteRemoveClass)(element, className);
      });
    }
  },

  parent: function(element) {
    var parent = element.parentNode;
    return parent && parent.nodeType !== NODE_TYPE_DOCUMENT_FRAGMENT ? parent : null;
  },

  next: function(element) {
    return element.nextElementSibling;
  },

  find: function(element, selector) {
    if (element.getElementsByTagName) {
      return element.getElementsByTagName(selector);
    } else {
      return [];
    }
  },

  clone: jqLiteClone,

  triggerHandler: function(element, event, extraParameters) {

    var dummyEvent, eventFnsCopy, handlerArgs;
    var eventName = event.type || event;
    var expandoStore = jqLiteExpandoStore(element);
    var events = expandoStore && expandoStore.events;
    var eventFns = events && events[eventName];

    if (eventFns) {
      // Create a dummy event to pass to the handlers
      dummyEvent = {
        preventDefault: function() { this.defaultPrevented = true; },
        isDefaultPrevented: function() { return this.defaultPrevented === true; },
        stopImmediatePropagation: function() { this.immediatePropagationStopped = true; },
        isImmediatePropagationStopped: function() { return this.immediatePropagationStopped === true; },
        stopPropagation: noop,
        type: eventName,
        target: element
      };

      // If a custom event was provided then extend our dummy event with it
      if (event.type) {
        dummyEvent = extend(dummyEvent, event);
      }

      // Copy event handlers in case event handlers array is modified during execution.
      eventFnsCopy = shallowCopy(eventFns);
      handlerArgs = extraParameters ? [dummyEvent].concat(extraParameters) : [dummyEvent];

      forEach(eventFnsCopy, function(fn) {
        if (!dummyEvent.isImmediatePropagationStopped()) {
          fn.apply(element, handlerArgs);
        }
      });
    }
  }
}, function(fn, name) {
  /**
   * chaining functions
   */
  JQLite.prototype[name] = function(arg1, arg2, arg3) {
    var value;

    for (var i = 0, ii = this.length; i < ii; i++) {
      if (isUndefined(value)) {
        value = fn(this[i], arg1, arg2, arg3);
        if (isDefined(value)) {
          // any function which returns a value needs to be wrapped
          value = jqLite(value);
        }
      } else {
        jqLiteAddNodes(value, fn(this[i], arg1, arg2, arg3));
      }
    }
    return isDefined(value) ? value : this;
  };

  // bind legacy bind/unbind to on/off
  JQLite.prototype.bind = JQLite.prototype.on;
  JQLite.prototype.unbind = JQLite.prototype.off;
});


// Provider for private $$jqLite service
function $$jqLiteProvider() {
  this.$get = function $$jqLite() {
    return extend(JQLite, {
      hasClass: function(node, classes) {
        if (node.attr) node = node[0];
        return jqLiteHasClass(node, classes);
      },
      addClass: function(node, classes) {
        if (node.attr) node = node[0];
        return jqLiteAddClass(node, classes);
      },
      removeClass: function(node, classes) {
        if (node.attr) node = node[0];
        return jqLiteRemoveClass(node, classes);
      }
    });
  };
}

/**
 * Computes a hash of an 'obj'.
 * Hash of a:
 *  string is string
 *  number is number as string
 *  object is either result of calling $$hashKey function on the object or uniquely generated id,
 *         that is also assigned to the $$hashKey property of the object.
 *
 * @param obj
 * @returns {string} hash string such that the same input will have the same hash string.
 *         The resulting string key is in 'type:hashKey' format.
 */
function hashKey(obj, nextUidFn) {
  var key = obj && obj.$$hashKey;

  if (key) {
    if (typeof key === 'function') {
      key = obj.$$hashKey();
    }
    return key;
  }

  var objType = typeof obj;
  if (objType == 'function' || (objType == 'object' && obj !== null)) {
    key = obj.$$hashKey = objType + ':' + (nextUidFn || nextUid)();
  } else {
    key = objType + ':' + obj;
  }

  return key;
}

/**
 * HashMap which can use objects as keys
 */
function HashMap(array, isolatedUid) {
  if (isolatedUid) {
    var uid = 0;
    this.nextUid = function() {
      return ++uid;
    };
  }
  forEach(array, this.put, this);
}
HashMap.prototype = {
  /**
   * Store key value pair
   * @param key key to store can be any type
   * @param value value to store can be any type
   */
  put: function(key, value) {
    this[hashKey(key, this.nextUid)] = value;
  },

  /**
   * @param key
   * @returns {Object} the value for the key
   */
  get: function(key) {
    return this[hashKey(key, this.nextUid)];
  },

  /**
   * Remove the key/value pair
   * @param key
   */
  remove: function(key) {
    var value = this[key = hashKey(key, this.nextUid)];
    delete this[key];
    return value;
  }
};

/**
 * @ngdoc function
 * @module ng
 * @name angular.injector
 * @kind function
 *
 * @description
 * Creates an injector object that can be used for retrieving services as well as for
 * dependency injection (see {@link guide/di dependency injection}).
 *
 * @param {Array.<string|Function>} modules A list of module functions or their aliases. See
 *     {@link angular.module}. The `ng` module must be explicitly added.
 * @param {boolean=} [strictDi=false] Whether the injector should be in strict mode, which
 *     disallows argument name annotation inference.
 * @returns {injector} Injector object. See {@link auto.$injector $injector}.
 *
 * @example
 * Typical usage
 * ```js
 *   // create an injector
 *   var $injector = angular.injector(['ng']);
 *
 *   // use the injector to kick off your application
 *   // use the type inference to auto inject arguments, or use implicit injection
 *   $injector.invoke(function($rootScope, $compile, $document) {
 *     $compile($document)($rootScope);
 *     $rootScope.$digest();
 *   });
 * ```
 *
 * Sometimes you want to get access to the injector of a currently running Angular app
 * from outside Angular. Perhaps, you want to inject and compile some markup after the
 * application has been bootstrapped. You can do this using the extra `injector()` added
 * to JQuery/jqLite elements. See {@link angular.element}.
 *
 * *This is fairly rare but could be the case if a third party library is injecting the
 * markup.*
 *
 * In the following example a new block of HTML containing a `ng-controller`
 * directive is added to the end of the document body by JQuery. We then compile and link
 * it into the current AngularJS scope.
 *
 * ```js
 * var $div = $('<div ng-controller="MyCtrl">{{content.label}}</div>');
 * $(document.body).append($div);
 *
 * angular.element(document).injector().invoke(function($compile) {
 *   var scope = angular.element($div).scope();
 *   $compile($div)(scope);
 * });
 * ```
 */


/**
 * @ngdoc module
 * @name auto
 * @description
 *
 * Implicit module which gets automatically added to each {@link auto.$injector $injector}.
 */

var FN_ARGS = /^function\s*[^\(]*\(\s*([^\)]*)\)/m;
var FN_ARG_SPLIT = /,/;
var FN_ARG = /^\s*(_?)(\S+?)\1\s*$/;
var STRIP_COMMENTS = /((\/\/.*$)|(\/\*[\s\S]*?\*\/))/mg;
var $injectorMinErr = minErr('$injector');

function anonFn(fn) {
  // For anonymous functions, showing at the very least the function signature can help in
  // debugging.
  var fnText = fn.toString().replace(STRIP_COMMENTS, ''),
      args = fnText.match(FN_ARGS);
  if (args) {
    return 'function(' + (args[1] || '').replace(/[\s\r\n]+/, ' ') + ')';
  }
  return 'fn';
}

function annotate(fn, strictDi, name) {
  var $inject,
      fnText,
      argDecl,
      last;

  if (typeof fn === 'function') {
    if (!($inject = fn.$inject)) {
      $inject = [];
      if (fn.length) {
        if (strictDi) {
          if (!isString(name) || !name) {
            name = fn.name || anonFn(fn);
          }
          throw $injectorMinErr('strictdi',
            '{0} is not using explicit annotation and cannot be invoked in strict mode', name);
        }
        fnText = fn.toString().replace(STRIP_COMMENTS, '');
        argDecl = fnText.match(FN_ARGS);
        forEach(argDecl[1].split(FN_ARG_SPLIT), function(arg) {
          arg.replace(FN_ARG, function(all, underscore, name) {
            $inject.push(name);
          });
        });
      }
      fn.$inject = $inject;
    }
  } else if (isArray(fn)) {
    last = fn.length - 1;
    assertArgFn(fn[last], 'fn');
    $inject = fn.slice(0, last);
  } else {
    assertArgFn(fn, 'fn', true);
  }
  return $inject;
}

///////////////////////////////////////

/**
 * @ngdoc service
 * @name $injector
 *
 * @description
 *
 * `$injector` is used to retrieve object instances as defined by
 * {@link auto.$provide provider}, instantiate types, invoke methods,
 * and load modules.
 *
 * The following always holds true:
 *
 * ```js
 *   var $injector = angular.injector();
 *   expect($injector.get('$injector')).toBe($injector);
 *   expect($injector.invoke(function($injector) {
 *     return $injector;
 *   })).toBe($injector);
 * ```
 *
 * # Injection Function Annotation
 *
 * JavaScript does not have annotations, and annotations are needed for dependency injection. The
 * following are all valid ways of annotating function with injection arguments and are equivalent.
 *
 * ```js
 *   // inferred (only works if code not minified/obfuscated)
 *   $injector.invoke(function(serviceA){});
 *
 *   // annotated
 *   function explicit(serviceA) {};
 *   explicit.$inject = ['serviceA'];
 *   $injector.invoke(explicit);
 *
 *   // inline
 *   $injector.invoke(['serviceA', function(serviceA){}]);
 * ```
 *
 * ## Inference
 *
 * In JavaScript calling `toString()` on a function returns the function definition. The definition
 * can then be parsed and the function arguments can be extracted. This method of discovering
 * annotations is disallowed when the injector is in strict mode.
 * *NOTE:* This does not work with minification, and obfuscation tools since these tools change the
 * argument names.
 *
 * ## `$inject` Annotation
 * By adding an `$inject` property onto a function the injection parameters can be specified.
 *
 * ## Inline
 * As an array of injection names, where the last item in the array is the function to call.
 */

/**
 * @ngdoc method
 * @name $injector#get
 *
 * @description
 * Return an instance of the service.
 *
 * @param {string} name The name of the instance to retrieve.
 * @param {string=} caller An optional string to provide the origin of the function call for error messages.
 * @return {*} The instance.
 */

/**
 * @ngdoc method
 * @name $injector#invoke
 *
 * @description
 * Invoke the method and supply the method arguments from the `$injector`.
 *
 * @param {Function|Array.<string|Function>} fn The injectable function to invoke. Function parameters are
 *   injected according to the {@link guide/di $inject Annotation} rules.
 * @param {Object=} self The `this` for the invoked method.
 * @param {Object=} locals Optional object. If preset then any argument names are read from this
 *                         object first, before the `$injector` is consulted.
 * @returns {*} the value returned by the invoked `fn` function.
 */

/**
 * @ngdoc method
 * @name $injector#has
 *
 * @description
 * Allows the user to query if the particular service exists.
 *
 * @param {string} name Name of the service to query.
 * @returns {boolean} `true` if injector has given service.
 */

/**
 * @ngdoc method
 * @name $injector#instantiate
 * @description
 * Create a new instance of JS type. The method takes a constructor function, invokes the new
 * operator, and supplies all of the arguments to the constructor function as specified by the
 * constructor annotation.
 *
 * @param {Function} Type Annotated constructor function.
 * @param {Object=} locals Optional object. If preset then any argument names are read from this
 * object first, before the `$injector` is consulted.
 * @returns {Object} new instance of `Type`.
 */

/**
 * @ngdoc method
 * @name $injector#annotate
 *
 * @description
 * Returns an array of service names which the function is requesting for injection. This API is
 * used by the injector to determine which services need to be injected into the function when the
 * function is invoked. There are three ways in which the function can be annotated with the needed
 * dependencies.
 *
 * # Argument names
 *
 * The simplest form is to extract the dependencies from the arguments of the function. This is done
 * by converting the function into a string using `toString()` method and extracting the argument
 * names.
 * ```js
 *   // Given
 *   function MyController($scope, $route) {
 *     // ...
 *   }
 *
 *   // Then
 *   expect(injector.annotate(MyController)).toEqual(['$scope', '$route']);
 * ```
 *
 * You can disallow this method by using strict injection mode.
 *
 * This method does not work with code minification / obfuscation. For this reason the following
 * annotation strategies are supported.
 *
 * # The `$inject` property
 *
 * If a function has an `$inject` property and its value is an array of strings, then the strings
 * represent names of services to be injected into the function.
 * ```js
 *   // Given
 *   var MyController = function(obfuscatedScope, obfuscatedRoute) {
 *     // ...
 *   }
 *   // Define function dependencies
 *   MyController['$inject'] = ['$scope', '$route'];
 *
 *   // Then
 *   expect(injector.annotate(MyController)).toEqual(['$scope', '$route']);
 * ```
 *
 * # The array notation
 *
 * It is often desirable to inline Injected functions and that's when setting the `$inject` property
 * is very inconvenient. In these situations using the array notation to specify the dependencies in
 * a way that survives minification is a better choice:
 *
 * ```js
 *   // We wish to write this (not minification / obfuscation safe)
 *   injector.invoke(function($compile, $rootScope) {
 *     // ...
 *   });
 *
 *   // We are forced to write break inlining
 *   var tmpFn = function(obfuscatedCompile, obfuscatedRootScope) {
 *     // ...
 *   };
 *   tmpFn.$inject = ['$compile', '$rootScope'];
 *   injector.invoke(tmpFn);
 *
 *   // To better support inline function the inline annotation is supported
 *   injector.invoke(['$compile', '$rootScope', function(obfCompile, obfRootScope) {
 *     // ...
 *   }]);
 *
 *   // Therefore
 *   expect(injector.annotate(
 *      ['$compile', '$rootScope', function(obfus_$compile, obfus_$rootScope) {}])
 *    ).toEqual(['$compile', '$rootScope']);
 * ```
 *
 * @param {Function|Array.<string|Function>} fn Function for which dependent service names need to
 * be retrieved as described above.
 *
 * @param {boolean=} [strictDi=false] Disallow argument name annotation inference.
 *
 * @returns {Array.<string>} The names of the services which the function requires.
 */




/**
 * @ngdoc service
 * @name $provide
 *
 * @description
 *
 * The {@link auto.$provide $provide} service has a number of methods for registering components
 * with the {@link auto.$injector $injector}. Many of these functions are also exposed on
 * {@link angular.Module}.
 *
 * An Angular **service** is a singleton object created by a **service factory**.  These **service
 * factories** are functions which, in turn, are created by a **service provider**.
 * The **service providers** are constructor functions. When instantiated they must contain a
 * property called `$get`, which holds the **service factory** function.
 *
 * When you request a service, the {@link auto.$injector $injector} is responsible for finding the
 * correct **service provider**, instantiating it and then calling its `$get` **service factory**
 * function to get the instance of the **service**.
 *
 * Often services have no configuration options and there is no need to add methods to the service
 * provider.  The provider will be no more than a constructor function with a `$get` property. For
 * these cases the {@link auto.$provide $provide} service has additional helper methods to register
 * services without specifying a provider.
 *
 * * {@link auto.$provide#provider provider(provider)} - registers a **service provider** with the
 *     {@link auto.$injector $injector}
 * * {@link auto.$provide#constant constant(obj)} - registers a value/object that can be accessed by
 *     providers and services.
 * * {@link auto.$provide#value value(obj)} - registers a value/object that can only be accessed by
 *     services, not providers.
 * * {@link auto.$provide#factory factory(fn)} - registers a service **factory function**, `fn`,
 *     that will be wrapped in a **service provider** object, whose `$get` property will contain the
 *     given factory function.
 * * {@link auto.$provide#service service(class)} - registers a **constructor function**, `class`
 *     that will be wrapped in a **service provider** object, whose `$get` property will instantiate
 *      a new object using the given constructor function.
 *
 * See the individual methods for more information and examples.
 */

/**
 * @ngdoc method
 * @name $provide#provider
 * @description
 *
 * Register a **provider function** with the {@link auto.$injector $injector}. Provider functions
 * are constructor functions, whose instances are responsible for "providing" a factory for a
 * service.
 *
 * Service provider names start with the name of the service they provide followed by `Provider`.
 * For example, the {@link ng.$log $log} service has a provider called
 * {@link ng.$logProvider $logProvider}.
 *
 * Service provider objects can have additional methods which allow configuration of the provider
 * and its service. Importantly, you can configure what kind of service is created by the `$get`
 * method, or how that service will act. For example, the {@link ng.$logProvider $logProvider} has a
 * method {@link ng.$logProvider#debugEnabled debugEnabled}
 * which lets you specify whether the {@link ng.$log $log} service will log debug messages to the
 * console or not.
 *
 * @param {string} name The name of the instance. NOTE: the provider will be available under `name +
                        'Provider'` key.
 * @param {(Object|function())} provider If the provider is:
 *
 *   - `Object`: then it should have a `$get` method. The `$get` method will be invoked using
 *     {@link auto.$injector#invoke $injector.invoke()} when an instance needs to be created.
 *   - `Constructor`: a new instance of the provider will be created using
 *     {@link auto.$injector#instantiate $injector.instantiate()}, then treated as `object`.
 *
 * @returns {Object} registered provider instance

 * @example
 *
 * The following example shows how to create a simple event tracking service and register it using
 * {@link auto.$provide#provider $provide.provider()}.
 *
 * ```js
 *  // Define the eventTracker provider
 *  function EventTrackerProvider() {
 *    var trackingUrl = '/track';
 *
 *    // A provider method for configuring where the tracked events should been saved
 *    this.setTrackingUrl = function(url) {
 *      trackingUrl = url;
 *    };
 *
 *    // The service factory function
 *    this.$get = ['$http', function($http) {
 *      var trackedEvents = {};
 *      return {
 *        // Call this to track an event
 *        event: function(event) {
 *          var count = trackedEvents[event] || 0;
 *          count += 1;
 *          trackedEvents[event] = count;
 *          return count;
 *        },
 *        // Call this to save the tracked events to the trackingUrl
 *        save: function() {
 *          $http.post(trackingUrl, trackedEvents);
 *        }
 *      };
 *    }];
 *  }
 *
 *  describe('eventTracker', function() {
 *    var postSpy;
 *
 *    beforeEach(module(function($provide) {
 *      // Register the eventTracker provider
 *      $provide.provider('eventTracker', EventTrackerProvider);
 *    }));
 *
 *    beforeEach(module(function(eventTrackerProvider) {
 *      // Configure eventTracker provider
 *      eventTrackerProvider.setTrackingUrl('/custom-track');
 *    }));
 *
 *    it('tracks events', inject(function(eventTracker) {
 *      expect(eventTracker.event('login')).toEqual(1);
 *      expect(eventTracker.event('login')).toEqual(2);
 *    }));
 *
 *    it('saves to the tracking url', inject(function(eventTracker, $http) {
 *      postSpy = spyOn($http, 'post');
 *      eventTracker.event('login');
 *      eventTracker.save();
 *      expect(postSpy).toHaveBeenCalled();
 *      expect(postSpy.mostRecentCall.args[0]).not.toEqual('/track');
 *      expect(postSpy.mostRecentCall.args[0]).toEqual('/custom-track');
 *      expect(postSpy.mostRecentCall.args[1]).toEqual({ 'login': 1 });
 *    }));
 *  });
 * ```
 */

/**
 * @ngdoc method
 * @name $provide#factory
 * @description
 *
 * Register a **service factory**, which will be called to return the service instance.
 * This is short for registering a service where its provider consists of only a `$get` property,
 * which is the given service factory function.
 * You should use {@link auto.$provide#factory $provide.factory(getFn)} if you do not need to
 * configure your service in a provider.
 *
 * @param {string} name The name of the instance.
 * @param {Function|Array.<string|Function>} $getFn The injectable $getFn for the instance creation.
 *                      Internally this is a short hand for `$provide.provider(name, {$get: $getFn})`.
 * @returns {Object} registered provider instance
 *
 * @example
 * Here is an example of registering a service
 * ```js
 *   $provide.factory('ping', ['$http', function($http) {
 *     return function ping() {
 *       return $http.send('/ping');
 *     };
 *   }]);
 * ```
 * You would then inject and use this service like this:
 * ```js
 *   someModule.controller('Ctrl', ['ping', function(ping) {
 *     ping();
 *   }]);
 * ```
 */


/**
 * @ngdoc method
 * @name $provide#service
 * @description
 *
 * Register a **service constructor**, which will be invoked with `new` to create the service
 * instance.
 * This is short for registering a service where its provider's `$get` property is the service
 * constructor function that will be used to instantiate the service instance.
 *
 * You should use {@link auto.$provide#service $provide.service(class)} if you define your service
 * as a type/class.
 *
 * @param {string} name The name of the instance.
 * @param {Function|Array.<string|Function>} constructor An injectable class (constructor function)
 *     that will be instantiated.
 * @returns {Object} registered provider instance
 *
 * @example
 * Here is an example of registering a service using
 * {@link auto.$provide#service $provide.service(class)}.
 * ```js
 *   var Ping = function($http) {
 *     this.$http = $http;
 *   };
 *
 *   Ping.$inject = ['$http'];
 *
 *   Ping.prototype.send = function() {
 *     return this.$http.get('/ping');
 *   };
 *   $provide.service('ping', Ping);
 * ```
 * You would then inject and use this service like this:
 * ```js
 *   someModule.controller('Ctrl', ['ping', function(ping) {
 *     ping.send();
 *   }]);
 * ```
 */


/**
 * @ngdoc method
 * @name $provide#value
 * @description
 *
 * Register a **value service** with the {@link auto.$injector $injector}, such as a string, a
 * number, an array, an object or a function.  This is short for registering a service where its
 * provider's `$get` property is a factory function that takes no arguments and returns the **value
 * service**.
 *
 * Value services are similar to constant services, except that they cannot be injected into a
 * module configuration function (see {@link angular.Module#config}) but they can be overridden by
 * an Angular
 * {@link auto.$provide#decorator decorator}.
 *
 * @param {string} name The name of the instance.
 * @param {*} value The value.
 * @returns {Object} registered provider instance
 *
 * @example
 * Here are some examples of creating value services.
 * ```js
 *   $provide.value('ADMIN_USER', 'admin');
 *
 *   $provide.value('RoleLookup', { admin: 0, writer: 1, reader: 2 });
 *
 *   $provide.value('halfOf', function(value) {
 *     return value / 2;
 *   });
 * ```
 */


/**
 * @ngdoc method
 * @name $provide#constant
 * @description
 *
 * Register a **constant service**, such as a string, a number, an array, an object or a function,
 * with the {@link auto.$injector $injector}. Unlike {@link auto.$provide#value value} it can be
 * injected into a module configuration function (see {@link angular.Module#config}) and it cannot
 * be overridden by an Angular {@link auto.$provide#decorator decorator}.
 *
 * @param {string} name The name of the constant.
 * @param {*} value The constant value.
 * @returns {Object} registered instance
 *
 * @example
 * Here a some examples of creating constants:
 * ```js
 *   $provide.constant('SHARD_HEIGHT', 306);
 *
 *   $provide.constant('MY_COLOURS', ['red', 'blue', 'grey']);
 *
 *   $provide.constant('double', function(value) {
 *     return value * 2;
 *   });
 * ```
 */


/**
 * @ngdoc method
 * @name $provide#decorator
 * @description
 *
 * Register a **service decorator** with the {@link auto.$injector $injector}. A service decorator
 * intercepts the creation of a service, allowing it to override or modify the behaviour of the
 * service. The object returned by the decorator may be the original service, or a new service
 * object which replaces or wraps and delegates to the original service.
 *
 * @param {string} name The name of the service to decorate.
 * @param {Function|Array.<string|Function>} decorator This function will be invoked when the service needs to be
 *    instantiated and should return the decorated service instance. The function is called using
 *    the {@link auto.$injector#invoke injector.invoke} method and is therefore fully injectable.
 *    Local injection arguments:
 *
 *    * `$delegate` - The original service instance, which can be monkey patched, configured,
 *      decorated or delegated to.
 *
 * @example
 * Here we decorate the {@link ng.$log $log} service to convert warnings to errors by intercepting
 * calls to {@link ng.$log#error $log.warn()}.
 * ```js
 *   $provide.decorator('$log', ['$delegate', function($delegate) {
 *     $delegate.warn = $delegate.error;
 *     return $delegate;
 *   }]);
 * ```
 */


function createInjector(modulesToLoad, strictDi) {
  strictDi = (strictDi === true);
  var INSTANTIATING = {},
      providerSuffix = 'Provider',
      path = [],
      loadedModules = new HashMap([], true),
      providerCache = {
        $provide: {
            provider: supportObject(provider),
            factory: supportObject(factory),
            service: supportObject(service),
            value: supportObject(value),
            constant: supportObject(constant),
            decorator: decorator
          }
      },
      providerInjector = (providerCache.$injector =
          createInternalInjector(providerCache, function(serviceName, caller) {
            if (angular.isString(caller)) {
              path.push(caller);
            }
            throw $injectorMinErr('unpr', "Unknown provider: {0}", path.join(' <- '));
          })),
      instanceCache = {},
      instanceInjector = (instanceCache.$injector =
          createInternalInjector(instanceCache, function(serviceName, caller) {
            var provider = providerInjector.get(serviceName + providerSuffix, caller);
            return instanceInjector.invoke(provider.$get, provider, undefined, serviceName);
          }));


  forEach(loadModules(modulesToLoad), function(fn) { instanceInjector.invoke(fn || noop); });

  return instanceInjector;

  ////////////////////////////////////
  // $provider
  ////////////////////////////////////

  function supportObject(delegate) {
    return function(key, value) {
      if (isObject(key)) {
        forEach(key, reverseParams(delegate));
      } else {
        return delegate(key, value);
      }
    };
  }

  function provider(name, provider_) {
    assertNotHasOwnProperty(name, 'service');
    if (isFunction(provider_) || isArray(provider_)) {
      provider_ = providerInjector.instantiate(provider_);
    }
    if (!provider_.$get) {
      throw $injectorMinErr('pget', "Provider '{0}' must define $get factory method.", name);
    }
    return providerCache[name + providerSuffix] = provider_;
  }

  function enforceReturnValue(name, factory) {
    return function enforcedReturnValue() {
      var result = instanceInjector.invoke(factory, this);
      if (isUndefined(result)) {
        throw $injectorMinErr('undef', "Provider '{0}' must return a value from $get factory method.", name);
      }
      return result;
    };
  }

  function factory(name, factoryFn, enforce) {
    return provider(name, {
      $get: enforce !== false ? enforceReturnValue(name, factoryFn) : factoryFn
    });
  }

  function service(name, constructor) {
    return factory(name, ['$injector', function($injector) {
      return $injector.instantiate(constructor);
    }]);
  }

  function value(name, val) { return factory(name, valueFn(val), false); }

  function constant(name, value) {
    assertNotHasOwnProperty(name, 'constant');
    providerCache[name] = value;
    instanceCache[name] = value;
  }

  function decorator(serviceName, decorFn) {
    var origProvider = providerInjector.get(serviceName + providerSuffix),
        orig$get = origProvider.$get;

    origProvider.$get = function() {
      var origInstance = instanceInjector.invoke(orig$get, origProvider);
      return instanceInjector.invoke(decorFn, null, {$delegate: origInstance});
    };
  }

  ////////////////////////////////////
  // Module Loading
  ////////////////////////////////////
  function loadModules(modulesToLoad) {
    var runBlocks = [], moduleFn;
    forEach(modulesToLoad, function(module) {
      if (loadedModules.get(module)) return;
      loadedModules.put(module, true);

      function runInvokeQueue(queue) {
        var i, ii;
        for (i = 0, ii = queue.length; i < ii; i++) {
          var invokeArgs = queue[i],
              provider = providerInjector.get(invokeArgs[0]);

          provider[invokeArgs[1]].apply(provider, invokeArgs[2]);
        }
      }

      try {
        if (isString(module)) {
          moduleFn = angularModule(module);
          runBlocks = runBlocks.concat(loadModules(moduleFn.requires)).concat(moduleFn._runBlocks);
          runInvokeQueue(moduleFn._invokeQueue);
          runInvokeQueue(moduleFn._configBlocks);
        } else if (isFunction(module)) {
            runBlocks.push(providerInjector.invoke(module));
        } else if (isArray(module)) {
            runBlocks.push(providerInjector.invoke(module));
        } else {
          assertArgFn(module, 'module');
        }
      } catch (e) {
        if (isArray(module)) {
          module = module[module.length - 1];
        }
        if (e.message && e.stack && e.stack.indexOf(e.message) == -1) {
          // Safari & FF's stack traces don't contain error.message content
          // unlike those of Chrome and IE
          // So if stack doesn't contain message, we create a new string that contains both.
          // Since error.stack is read-only in Safari, I'm overriding e and not e.stack here.
          /* jshint -W022 */
          e = e.message + '\n' + e.stack;
        }
        throw $injectorMinErr('modulerr', "Failed to instantiate module {0} due to:\n{1}",
                  module, e.stack || e.message || e);
      }
    });
    return runBlocks;
  }

  ////////////////////////////////////
  // internal Injector
  ////////////////////////////////////

  function createInternalInjector(cache, factory) {

    function getService(serviceName, caller) {
      if (cache.hasOwnProperty(serviceName)) {
        if (cache[serviceName] === INSTANTIATING) {
          throw $injectorMinErr('cdep', 'Circular dependency found: {0}',
                    serviceName + ' <- ' + path.join(' <- '));
        }
        return cache[serviceName];
      } else {
        try {
          path.unshift(serviceName);
          cache[serviceName] = INSTANTIATING;
          return cache[serviceName] = factory(serviceName, caller);
        } catch (err) {
          if (cache[serviceName] === INSTANTIATING) {
            delete cache[serviceName];
          }
          throw err;
        } finally {
          path.shift();
        }
      }
    }

    function invoke(fn, self, locals, serviceName) {
      if (typeof locals === 'string') {
        serviceName = locals;
        locals = null;
      }

      var args = [],
          $inject = createInjector.$$annotate(fn, strictDi, serviceName),
          length, i,
          key;

      for (i = 0, length = $inject.length; i < length; i++) {
        key = $inject[i];
        if (typeof key !== 'string') {
          throw $injectorMinErr('itkn',
                  'Incorrect injection token! Expected service name as string, got {0}', key);
        }
        args.push(
          locals && locals.hasOwnProperty(key)
          ? locals[key]
          : getService(key, serviceName)
        );
      }
      if (isArray(fn)) {
        fn = fn[length];
      }

      // http://jsperf.com/angularjs-invoke-apply-vs-switch
      // #5388
      return fn.apply(self, args);
    }

    function instantiate(Type, locals, serviceName) {
      // Check if Type is annotated and use just the given function at n-1 as parameter
      // e.g. someModule.factory('greeter', ['$window', function(renamed$window) {}]);
      // Object creation: http://jsperf.com/create-constructor/2
      var instance = Object.create((isArray(Type) ? Type[Type.length - 1] : Type).prototype || null);
      var returnedValue = invoke(Type, instance, locals, serviceName);

      return isObject(returnedValue) || isFunction(returnedValue) ? returnedValue : instance;
    }

    return {
      invoke: invoke,
      instantiate: instantiate,
      get: getService,
      annotate: createInjector.$$annotate,
      has: function(name) {
        return providerCache.hasOwnProperty(name + providerSuffix) || cache.hasOwnProperty(name);
      }
    };
  }
}

createInjector.$$annotate = annotate;

/**
 * @ngdoc provider
 * @name $anchorScrollProvider
 *
 * @description
 * Use `$anchorScrollProvider` to disable automatic scrolling whenever
 * {@link ng.$location#hash $location.hash()} changes.
 */
function $AnchorScrollProvider() {

  var autoScrollingEnabled = true;

  /**
   * @ngdoc method
   * @name $anchorScrollProvider#disableAutoScrolling
   *
   * @description
   * By default, {@link ng.$anchorScroll $anchorScroll()} will automatically detect changes to
   * {@link ng.$location#hash $location.hash()} and scroll to the element matching the new hash.<br />
   * Use this method to disable automatic scrolling.
   *
   * If automatic scrolling is disabled, one must explicitly call
   * {@link ng.$anchorScroll $anchorScroll()} in order to scroll to the element related to the
   * current hash.
   */
  this.disableAutoScrolling = function() {
    autoScrollingEnabled = false;
  };

  /**
   * @ngdoc service
   * @name $anchorScroll
   * @kind function
   * @requires $window
   * @requires $location
   * @requires $rootScope
   *
   * @description
   * When called, it checks the current value of {@link ng.$location#hash $location.hash()} and
   * scrolls to the related element, according to the rules specified in the
   * [Html5 spec](http://dev.w3.org/html5/spec/Overview.html#the-indicated-part-of-the-document).
   *
   * It also watches the {@link ng.$location#hash $location.hash()} and automatically scrolls to
   * match any anchor whenever it changes. This can be disabled by calling
   * {@link ng.$anchorScrollProvider#disableAutoScrolling $anchorScrollProvider.disableAutoScrolling()}.
   *
   * Additionally, you can use its {@link ng.$anchorScroll#yOffset yOffset} property to specify a
   * vertical scroll-offset (either fixed or dynamic).
   *
   * @property {(number|function|jqLite)} yOffset
   * If set, specifies a vertical scroll-offset. This is often useful when there are fixed
   * positioned elements at the top of the page, such as navbars, headers etc.
   *
   * `yOffset` can be specified in various ways:
   * - **number**: A fixed number of pixels to be used as offset.<br /><br />
   * - **function**: A getter function called everytime `$anchorScroll()` is executed. Must return
   *   a number representing the offset (in pixels).<br /><br />
   * - **jqLite**: A jqLite/jQuery element to be used for specifying the offset. The distance from
   *   the top of the page to the element's bottom will be used as offset.<br />
   *   **Note**: The element will be taken into account only as long as its `position` is set to
   *   `fixed`. This option is useful, when dealing with responsive navbars/headers that adjust
   *   their height and/or positioning according to the viewport's size.
   *
   * <br />
   * <div class="alert alert-warning">
   * In order for `yOffset` to work properly, scrolling should take place on the document's root and
   * not some child element.
   * </div>
   *
   * @example
     <example module="anchorScrollExample">
       <file name="index.html">
         <div id="scrollArea" ng-controller="ScrollController">
           <a ng-click="gotoBottom()">Go to bottom</a>
           <a id="bottom"></a> You're at the bottom!
         </div>
       </file>
       <file name="script.js">
         angular.module('anchorScrollExample', [])
           .controller('ScrollController', ['$scope', '$location', '$anchorScroll',
             function ($scope, $location, $anchorScroll) {
               $scope.gotoBottom = function() {
                 // set the location.hash to the id of
                 // the element you wish to scroll to.
                 $location.hash('bottom');

                 // call $anchorScroll()
                 $anchorScroll();
               };
             }]);
       </file>
       <file name="style.css">
         #scrollArea {
           height: 280px;
           overflow: auto;
         }

         #bottom {
           display: block;
           margin-top: 2000px;
         }
       </file>
     </example>
   *
   * <hr />
   * The example below illustrates the use of a vertical scroll-offset (specified as a fixed value).
   * See {@link ng.$anchorScroll#yOffset $anchorScroll.yOffset} for more details.
   *
   * @example
     <example module="anchorScrollOffsetExample">
       <file name="index.html">
         <div class="fixed-header" ng-controller="headerCtrl">
           <a href="" ng-click="gotoAnchor(x)" ng-repeat="x in [1,2,3,4,5]">
             Go to anchor {{x}}
           </a>
         </div>
         <div id="anchor{{x}}" class="anchor" ng-repeat="x in [1,2,3,4,5]">
           Anchor {{x}} of 5
         </div>
       </file>
       <file name="script.js">
         angular.module('anchorScrollOffsetExample', [])
           .run(['$anchorScroll', function($anchorScroll) {
             $anchorScroll.yOffset = 50;   // always scroll by 50 extra pixels
           }])
           .controller('headerCtrl', ['$anchorScroll', '$location', '$scope',
             function ($anchorScroll, $location, $scope) {
               $scope.gotoAnchor = function(x) {
                 var newHash = 'anchor' + x;
                 if ($location.hash() !== newHash) {
                   // set the $location.hash to `newHash` and
                   // $anchorScroll will automatically scroll to it
                   $location.hash('anchor' + x);
                 } else {
                   // call $anchorScroll() explicitly,
                   // since $location.hash hasn't changed
                   $anchorScroll();
                 }
               };
             }
           ]);
       </file>
       <file name="style.css">
         body {
           padding-top: 50px;
         }

         .anchor {
           border: 2px dashed DarkOrchid;
           padding: 10px 10px 200px 10px;
         }

         .fixed-header {
           background-color: rgba(0, 0, 0, 0.2);
           height: 50px;
           position: fixed;
           top: 0; left: 0; right: 0;
         }

         .fixed-header > a {
           display: inline-block;
           margin: 5px 15px;
         }
       </file>
     </example>
   */
  this.$get = ['$window', '$location', '$rootScope', function($window, $location, $rootScope) {
    var document = $window.document;

    // Helper function to get first anchor from a NodeList
    // (using `Array#some()` instead of `angular#forEach()` since it's more performant
    //  and working in all supported browsers.)
    function getFirstAnchor(list) {
      var result = null;
      Array.prototype.some.call(list, function(element) {
        if (nodeName_(element) === 'a') {
          result = element;
          return true;
        }
      });
      return result;
    }

    function getYOffset() {

      var offset = scroll.yOffset;

      if (isFunction(offset)) {
        offset = offset();
      } else if (isElement(offset)) {
        var elem = offset[0];
        var style = $window.getComputedStyle(elem);
        if (style.position !== 'fixed') {
          offset = 0;
        } else {
          offset = elem.getBoundingClientRect().bottom;
        }
      } else if (!isNumber(offset)) {
        offset = 0;
      }

      return offset;
    }

    function scrollTo(elem) {
      if (elem) {
        elem.scrollIntoView();

        var offset = getYOffset();

        if (offset) {
          // `offset` is the number of pixels we should scroll UP in order to align `elem` properly.
          // This is true ONLY if the call to `elem.scrollIntoView()` initially aligns `elem` at the
          // top of the viewport.
          //
          // IF the number of pixels from the top of `elem` to the end of the page's content is less
          // than the height of the viewport, then `elem.scrollIntoView()` will align the `elem` some
          // way down the page.
          //
          // This is often the case for elements near the bottom of the page.
          //
          // In such cases we do not need to scroll the whole `offset` up, just the difference between
          // the top of the element and the offset, which is enough to align the top of `elem` at the
          // desired position.
          var elemTop = elem.getBoundingClientRect().top;
          $window.scrollBy(0, elemTop - offset);
        }
      } else {
        $window.scrollTo(0, 0);
      }
    }

    function scroll() {
      var hash = $location.hash(), elm;

      // empty hash, scroll to the top of the page
      if (!hash) scrollTo(null);

      // element with given id
      else if ((elm = document.getElementById(hash))) scrollTo(elm);

      // first anchor with given name :-D
      else if ((elm = getFirstAnchor(document.getElementsByName(hash)))) scrollTo(elm);

      // no element and hash == 'top', scroll to the top of the page
      else if (hash === 'top') scrollTo(null);
    }

    // does not scroll when user clicks on anchor link that is currently on
    // (no url change, no $location.hash() change), browser native does scroll
    if (autoScrollingEnabled) {
      $rootScope.$watch(function autoScrollWatch() {return $location.hash();},
        function autoScrollWatchAction(newVal, oldVal) {
          // skip the initial scroll if $location.hash is empty
          if (newVal === oldVal && newVal === '') return;

          jqLiteDocumentLoaded(function() {
            $rootScope.$evalAsync(scroll);
          });
        });
    }

    return scroll;
  }];
}

var $animateMinErr = minErr('$animate');

/**
 * @ngdoc provider
 * @name $animateProvider
 *
 * @description
 * Default implementation of $animate that doesn't perform any animations, instead just
 * synchronously performs DOM
 * updates and calls done() callbacks.
 *
 * In order to enable animations the ngAnimate module has to be loaded.
 *
 * To see the functional implementation check out src/ngAnimate/animate.js
 */
var $AnimateProvider = ['$provide', function($provide) {


  this.$$selectors = {};


  /**
   * @ngdoc method
   * @name $animateProvider#register
   *
   * @description
   * Registers a new injectable animation factory function. The factory function produces the
   * animation object which contains callback functions for each event that is expected to be
   * animated.
   *
   *   * `eventFn`: `function(Element, doneFunction)` The element to animate, the `doneFunction`
   *   must be called once the element animation is complete. If a function is returned then the
   *   animation service will use this function to cancel the animation whenever a cancel event is
   *   triggered.
   *
   *
   * ```js
   *   return {
     *     eventFn : function(element, done) {
     *       //code to run the animation
     *       //once complete, then run done()
     *       return function cancellationFunction() {
     *         //code to cancel the animation
     *       }
     *     }
     *   }
   * ```
   *
   * @param {string} name The name of the animation.
   * @param {Function} factory The factory function that will be executed to return the animation
   *                           object.
   */
  this.register = function(name, factory) {
    var key = name + '-animation';
    if (name && name.charAt(0) != '.') throw $animateMinErr('notcsel',
        "Expecting class selector starting with '.' got '{0}'.", name);
    this.$$selectors[name.substr(1)] = key;
    $provide.factory(key, factory);
  };

  /**
   * @ngdoc method
   * @name $animateProvider#classNameFilter
   *
   * @description
   * Sets and/or returns the CSS class regular expression that is checked when performing
   * an animation. Upon bootstrap the classNameFilter value is not set at all and will
   * therefore enable $animate to attempt to perform an animation on any element.
   * When setting the classNameFilter value, animations will only be performed on elements
   * that successfully match the filter expression. This in turn can boost performance
   * for low-powered devices as well as applications containing a lot of structural operations.
   * @param {RegExp=} expression The className expression which will be checked against all animations
   * @return {RegExp} The current CSS className expression value. If null then there is no expression value
   */
  this.classNameFilter = function(expression) {
    if (arguments.length === 1) {
      this.$$classNameFilter = (expression instanceof RegExp) ? expression : null;
    }
    return this.$$classNameFilter;
  };

  this.$get = ['$$q', '$$asyncCallback', '$rootScope', function($$q, $$asyncCallback, $rootScope) {

    var currentDefer;

    function runAnimationPostDigest(fn) {
      var cancelFn, defer = $$q.defer();
      defer.promise.$$cancelFn = function ngAnimateMaybeCancel() {
        cancelFn && cancelFn();
      };

      $rootScope.$$postDigest(function ngAnimatePostDigest() {
        cancelFn = fn(function ngAnimateNotifyComplete() {
          defer.resolve();
        });
      });

      return defer.promise;
    }

    function resolveElementClasses(element, classes) {
      var toAdd = [], toRemove = [];

      var hasClasses = createMap();
      forEach((element.attr('class') || '').split(/\s+/), function(className) {
        hasClasses[className] = true;
      });

      forEach(classes, function(status, className) {
        var hasClass = hasClasses[className];

        // If the most recent class manipulation (via $animate) was to remove the class, and the
        // element currently has the class, the class is scheduled for removal. Otherwise, if
        // the most recent class manipulation (via $animate) was to add the class, and the
        // element does not currently have the class, the class is scheduled to be added.
        if (status === false && hasClass) {
          toRemove.push(className);
        } else if (status === true && !hasClass) {
          toAdd.push(className);
        }
      });

      return (toAdd.length + toRemove.length) > 0 &&
        [toAdd.length ? toAdd : null, toRemove.length ? toRemove : null];
    }

    function cachedClassManipulation(cache, classes, op) {
      for (var i=0, ii = classes.length; i < ii; ++i) {
        var className = classes[i];
        cache[className] = op;
      }
    }

    function asyncPromise() {
      // only serve one instance of a promise in order to save CPU cycles
      if (!currentDefer) {
        currentDefer = $$q.defer();
        $$asyncCallback(function() {
          currentDefer.resolve();
          currentDefer = null;
        });
      }
      return currentDefer.promise;
    }

    function applyStyles(element, options) {
      if (angular.isObject(options)) {
        var styles = extend(options.from || {}, options.to || {});
        element.css(styles);
      }
    }

    /**
     *
     * @ngdoc service
     * @name $animate
     * @description The $animate service provides rudimentary DOM manipulation functions to
     * insert, remove and move elements within the DOM, as well as adding and removing classes.
     * This service is the core service used by the ngAnimate $animator service which provides
     * high-level animation hooks for CSS and JavaScript.
     *
     * $animate is available in the AngularJS core, however, the ngAnimate module must be included
     * to enable full out animation support. Otherwise, $animate will only perform simple DOM
     * manipulation operations.
     *
     * To learn more about enabling animation support, click here to visit the {@link ngAnimate
     * ngAnimate module page} as well as the {@link ngAnimate.$animate ngAnimate $animate service
     * page}.
     */
    return {
      animate: function(element, from, to) {
        applyStyles(element, { from: from, to: to });
        return asyncPromise();
      },

      /**
       *
       * @ngdoc method
       * @name $animate#enter
       * @kind function
       * @description Inserts the element into the DOM either after the `after` element or
       * as the first child within the `parent` element. When the function is called a promise
       * is returned that will be resolved at a later time.
       * @param {DOMElement} element the element which will be inserted into the DOM
       * @param {DOMElement} parent the parent element which will append the element as
       *   a child (if the after element is not present)
       * @param {DOMElement} after the sibling element which will append the element
       *   after itself
       * @param {object=} options an optional collection of styles that will be applied to the element.
       * @return {Promise} the animation callback promise
       */
      enter: function(element, parent, after, options) {
        applyStyles(element, options);
        after ? after.after(element)
              : parent.prepend(element);
        return asyncPromise();
      },

      /**
       *
       * @ngdoc method
       * @name $animate#leave
       * @kind function
       * @description Removes the element from the DOM. When the function is called a promise
       * is returned that will be resolved at a later time.
       * @param {DOMElement} element the element which will be removed from the DOM
       * @param {object=} options an optional collection of options that will be applied to the element.
       * @return {Promise} the animation callback promise
       */
      leave: function(element, options) {
        applyStyles(element, options);
        element.remove();
        return asyncPromise();
      },

      /**
       *
       * @ngdoc method
       * @name $animate#move
       * @kind function
       * @description Moves the position of the provided element within the DOM to be placed
       * either after the `after` element or inside of the `parent` element. When the function
       * is called a promise is returned that will be resolved at a later time.
       *
       * @param {DOMElement} element the element which will be moved around within the
       *   DOM
       * @param {DOMElement} parent the parent element where the element will be
       *   inserted into (if the after element is not present)
       * @param {DOMElement} after the sibling element where the element will be
       *   positioned next to
       * @param {object=} options an optional collection of options that will be applied to the element.
       * @return {Promise} the animation callback promise
       */
      move: function(element, parent, after, options) {
        // Do not remove element before insert. Removing will cause data associated with the
        // element to be dropped. Insert will implicitly do the remove.
        return this.enter(element, parent, after, options);
      },

      /**
       *
       * @ngdoc method
       * @name $animate#addClass
       * @kind function
       * @description Adds the provided className CSS class value to the provided element.
       * When the function is called a promise is returned that will be resolved at a later time.
       * @param {DOMElement} element the element which will have the className value
       *   added to it
       * @param {string} className the CSS class which will be added to the element
       * @param {object=} options an optional collection of options that will be applied to the element.
       * @return {Promise} the animation callback promise
       */
      addClass: function(element, className, options) {
        return this.setClass(element, className, [], options);
      },

      $$addClassImmediately: function(element, className, options) {
        element = jqLite(element);
        className = !isString(className)
                        ? (isArray(className) ? className.join(' ') : '')
                        : className;
        forEach(element, function(element) {
          jqLiteAddClass(element, className);
        });
        applyStyles(element, options);
        return asyncPromise();
      },

      /**
       *
       * @ngdoc method
       * @name $animate#removeClass
       * @kind function
       * @description Removes the provided className CSS class value from the provided element.
       * When the function is called a promise is returned that will be resolved at a later time.
       * @param {DOMElement} element the element which will have the className value
       *   removed from it
       * @param {string} className the CSS class which will be removed from the element
       * @param {object=} options an optional collection of options that will be applied to the element.
       * @return {Promise} the animation callback promise
       */
      removeClass: function(element, className, options) {
        return this.setClass(element, [], className, options);
      },

      $$removeClassImmediately: function(element, className, options) {
        element = jqLite(element);
        className = !isString(className)
                        ? (isArray(className) ? className.join(' ') : '')
                        : className;
        forEach(element, function(element) {
          jqLiteRemoveClass(element, className);
        });
        applyStyles(element, options);
        return asyncPromise();
      },

      /**
       *
       * @ngdoc method
       * @name $animate#setClass
       * @kind function
       * @description Adds and/or removes the given CSS classes to and from the element.
       * When the function is called a promise is returned that will be resolved at a later time.
       * @param {DOMElement} element the element which will have its CSS classes changed
       *   removed from it
       * @param {string} add the CSS classes which will be added to the element
       * @param {string} remove the CSS class which will be removed from the element
       * @param {object=} options an optional collection of options that will be applied to the element.
       * @return {Promise} the animation callback promise
       */
      setClass: function(element, add, remove, options) {
        var self = this;
        var STORAGE_KEY = '$$animateClasses';
        var createdCache = false;
        element = jqLite(element);

        var cache = element.data(STORAGE_KEY);
        if (!cache) {
          cache = {
            classes: {},
            options: options
          };
          createdCache = true;
        } else if (options && cache.options) {
          cache.options = angular.extend(cache.options || {}, options);
        }

        var classes = cache.classes;

        add = isArray(add) ? add : add.split(' ');
        remove = isArray(remove) ? remove : remove.split(' ');
        cachedClassManipulation(classes, add, true);
        cachedClassManipulation(classes, remove, false);

        if (createdCache) {
          cache.promise = runAnimationPostDigest(function(done) {
            var cache = element.data(STORAGE_KEY);
            element.removeData(STORAGE_KEY);

            // in the event that the element is removed before postDigest
            // is run then the cache will be undefined and there will be
            // no need anymore to add or remove and of the element classes
            if (cache) {
              var classes = resolveElementClasses(element, cache.classes);
              if (classes) {
                self.$$setClassImmediately(element, classes[0], classes[1], cache.options);
              }
            }

            done();
          });
          element.data(STORAGE_KEY, cache);
        }

        return cache.promise;
      },

      $$setClassImmediately: function(element, add, remove, options) {
        add && this.$$addClassImmediately(element, add);
        remove && this.$$removeClassImmediately(element, remove);
        applyStyles(element, options);
        return asyncPromise();
      },

      enabled: noop,
      cancel: noop
    };
  }];
}];

function $$AsyncCallbackProvider() {
  this.$get = ['$$rAF', '$timeout', function($$rAF, $timeout) {
    return $$rAF.supported
      ? function(fn) { return $$rAF(fn); }
      : function(fn) {
        return $timeout(fn, 0, false);
      };
  }];
}

/* global stripHash: true */

/**
 * ! This is a private undocumented service !
 *
 * @name $browser
 * @requires $log
 * @description
 * This object has two goals:
 *
 * - hide all the global state in the browser caused by the window object
 * - abstract away all the browser specific features and inconsistencies
 *
 * For tests we provide {@link ngMock.$browser mock implementation} of the `$browser`
 * service, which can be used for convenient testing of the application without the interaction with
 * the real browser apis.
 */
/**
 * @param {object} window The global window object.
 * @param {object} document jQuery wrapped document.
 * @param {object} $log window.console or an object with the same interface.
 * @param {object} $sniffer $sniffer service
 */
function Browser(window, document, $log, $sniffer) {
  var self = this,
      rawDocument = document[0],
      location = window.location,
      history = window.history,
      setTimeout = window.setTimeout,
      clearTimeout = window.clearTimeout,
      pendingDeferIds = {};

  self.isMock = false;

  var outstandingRequestCount = 0;
  var outstandingRequestCallbacks = [];

  // TODO(vojta): remove this temporary api
  self.$$completeOutstandingRequest = completeOutstandingRequest;
  self.$$incOutstandingRequestCount = function() { outstandingRequestCount++; };

  /**
   * Executes the `fn` function(supports currying) and decrements the `outstandingRequestCallbacks`
   * counter. If the counter reaches 0, all the `outstandingRequestCallbacks` are executed.
   */
  function completeOutstandingRequest(fn) {
    try {
      fn.apply(null, sliceArgs(arguments, 1));
    } finally {
      outstandingRequestCount--;
      if (outstandingRequestCount === 0) {
        while (outstandingRequestCallbacks.length) {
          try {
            outstandingRequestCallbacks.pop()();
          } catch (e) {
            $log.error(e);
          }
        }
      }
    }
  }

  function getHash(url) {
    var index = url.indexOf('#');
    return index === -1 ? '' : url.substr(index);
  }

  /**
   * @private
   * Note: this method is used only by scenario runner
   * TODO(vojta): prefix this method with $$ ?
   * @param {function()} callback Function that will be called when no outstanding request
   */
  self.notifyWhenNoOutstandingRequests = function(callback) {
    // force browser to execute all pollFns - this is needed so that cookies and other pollers fire
    // at some deterministic time in respect to the test runner's actions. Leaving things up to the
    // regular poller would result in flaky tests.
    forEach(pollFns, function(pollFn) { pollFn(); });

    if (outstandingRequestCount === 0) {
      callback();
    } else {
      outstandingRequestCallbacks.push(callback);
    }
  };

  //////////////////////////////////////////////////////////////
  // Poll Watcher API
  //////////////////////////////////////////////////////////////
  var pollFns = [],
      pollTimeout;

  /**
   * @name $browser#addPollFn
   *
   * @param {function()} fn Poll function to add
   *
   * @description
   * Adds a function to the list of functions that poller periodically executes,
   * and starts polling if not started yet.
   *
   * @returns {function()} the added function
   */
  self.addPollFn = function(fn) {
    if (isUndefined(pollTimeout)) startPoller(100, setTimeout);
    pollFns.push(fn);
    return fn;
  };

  /**
   * @param {number} interval How often should browser call poll functions (ms)
   * @param {function()} setTimeout Reference to a real or fake `setTimeout` function.
   *
   * @description
   * Configures the poller to run in the specified intervals, using the specified
   * setTimeout fn and kicks it off.
   */
  function startPoller(interval, setTimeout) {
    (function check() {
      forEach(pollFns, function(pollFn) { pollFn(); });
      pollTimeout = setTimeout(check, interval);
    })();
  }

  //////////////////////////////////////////////////////////////
  // URL API
  //////////////////////////////////////////////////////////////

  var cachedState, lastHistoryState,
      lastBrowserUrl = location.href,
      baseElement = document.find('base'),
      reloadLocation = null;

  cacheState();
  lastHistoryState = cachedState;

  /**
   * @name $browser#url
   *
   * @description
   * GETTER:
   * Without any argument, this method just returns current value of location.href.
   *
   * SETTER:
   * With at least one argument, this method sets url to new value.
   * If html5 history api supported, pushState/replaceState is used, otherwise
   * location.href/location.replace is used.
   * Returns its own instance to allow chaining
   *
   * NOTE: this api is intended for use only by the $location service. Please use the
   * {@link ng.$location $location service} to change url.
   *
   * @param {string} url New url (when used as setter)
   * @param {boolean=} replace Should new url replace current history record?
   * @param {object=} state object to use with pushState/replaceState
   */
  self.url = function(url, replace, state) {
    // In modern browsers `history.state` is `null` by default; treating it separately
    // from `undefined` would cause `$browser.url('/foo')` to change `history.state`
    // to undefined via `pushState`. Instead, let's change `undefined` to `null` here.
    if (isUndefined(state)) {
      state = null;
    }

    // Android Browser BFCache causes location, history reference to become stale.
    if (location !== window.location) location = window.location;
    if (history !== window.history) history = window.history;

    // setter
    if (url) {
      var sameState = lastHistoryState === state;

      // Don't change anything if previous and current URLs and states match. This also prevents
      // IE<10 from getting into redirect loop when in LocationHashbangInHtml5Url mode.
      // See https://github.com/angular/angular.js/commit/ffb2701
      if (lastBrowserUrl === url && (!$sniffer.history || sameState)) {
        return self;
      }
      var sameBase = lastBrowserUrl && stripHash(lastBrowserUrl) === stripHash(url);
      lastBrowserUrl = url;
      lastHistoryState = state;
      // Don't use history API if only the hash changed
      // due to a bug in IE10/IE11 which leads
      // to not firing a `hashchange` nor `popstate` event
      // in some cases (see #9143).
      if ($sniffer.history && (!sameBase || !sameState)) {
        history[replace ? 'replaceState' : 'pushState'](state, '', url);
        cacheState();
        // Do the assignment again so that those two variables are referentially identical.
        lastHistoryState = cachedState;
      } else {
        if (!sameBase || reloadLocation) {
          reloadLocation = url;
        }
        if (replace) {
          location.replace(url);
        } else if (!sameBase) {
          location.href = url;
        } else {
          location.hash = getHash(url);
        }
      }
      return self;
    // getter
    } else {
      // - reloadLocation is needed as browsers don't allow to read out
      //   the new location.href if a reload happened.
      // - the replacement is a workaround for https://bugzilla.mozilla.org/show_bug.cgi?id=407172
      return reloadLocation || location.href.replace(/%27/g,"'");
    }
  };

  /**
   * @name $browser#state
   *
   * @description
   * This method is a getter.
   *
   * Return history.state or null if history.state is undefined.
   *
   * @returns {object} state
   */
  self.state = function() {
    return cachedState;
  };

  var urlChangeListeners = [],
      urlChangeInit = false;

  function cacheStateAndFireUrlChange() {
    cacheState();
    fireUrlChange();
  }

  function getCurrentState() {
    try {
      return history.state;
    } catch (e) {
      // MSIE can reportedly throw when there is no state (UNCONFIRMED).
    }
  }

  // This variable should be used *only* inside the cacheState function.
  var lastCachedState = null;
  function cacheState() {
    // This should be the only place in $browser where `history.state` is read.
    cachedState = getCurrentState();
    cachedState = isUndefined(cachedState) ? null : cachedState;

    // Prevent callbacks fo fire twice if both hashchange & popstate were fired.
    if (equals(cachedState, lastCachedState)) {
      cachedState = lastCachedState;
    }
    lastCachedState = cachedState;
  }

  function fireUrlChange() {
    if (lastBrowserUrl === self.url() && lastHistoryState === cachedState) {
      return;
    }

    lastBrowserUrl = self.url();
    lastHistoryState = cachedState;
    forEach(urlChangeListeners, function(listener) {
      listener(self.url(), cachedState);
    });
  }

  /**
   * @name $browser#onUrlChange
   *
   * @description
   * Register callback function that will be called, when url changes.
   *
   * It's only called when the url is changed from outside of angular:
   * - user types different url into address bar
   * - user clicks on history (forward/back) button
   * - user clicks on a link
   *
   * It's not called when url is changed by $browser.url() method
   *
   * The listener gets called with new url as parameter.
   *
   * NOTE: this api is intended for use only by the $location service. Please use the
   * {@link ng.$location $location service} to monitor url changes in angular apps.
   *
   * @param {function(string)} listener Listener function to be called when url changes.
   * @return {function(string)} Returns the registered listener fn - handy if the fn is anonymous.
   */
  self.onUrlChange = function(callback) {
    // TODO(vojta): refactor to use node's syntax for events
    if (!urlChangeInit) {
      // We listen on both (hashchange/popstate) when available, as some browsers (e.g. Opera)
      // don't fire popstate when user change the address bar and don't fire hashchange when url
      // changed by push/replaceState

      // html5 history api - popstate event
      if ($sniffer.history) jqLite(window).on('popstate', cacheStateAndFireUrlChange);
      // hashchange event
      jqLite(window).on('hashchange', cacheStateAndFireUrlChange);

      urlChangeInit = true;
    }

    urlChangeListeners.push(callback);
    return callback;
  };

  /**
   * Checks whether the url has changed outside of Angular.
   * Needs to be exported to be able to check for changes that have been done in sync,
   * as hashchange/popstate events fire in async.
   */
  self.$$checkUrlChange = fireUrlChange;

  //////////////////////////////////////////////////////////////
  // Misc API
  //////////////////////////////////////////////////////////////

  /**
   * @name $browser#baseHref
   *
   * @description
   * Returns current <base href>
   * (always relative - without domain)
   *
   * @returns {string} The current base href
   */
  self.baseHref = function() {
    var href = baseElement.attr('href');
    return href ? href.replace(/^(https?\:)?\/\/[^\/]*/, '') : '';
  };

  //////////////////////////////////////////////////////////////
  // Cookies API
  //////////////////////////////////////////////////////////////
  var lastCookies = {};
  var lastCookieString = '';
  var cookiePath = self.baseHref();

  function safeDecodeURIComponent(str) {
    try {
      return decodeURIComponent(str);
    } catch (e) {
      return str;
    }
  }

  /**
   * @name $browser#cookies
   *
   * @param {string=} name Cookie name
   * @param {string=} value Cookie value
   *
   * @description
   * The cookies method provides a 'private' low level access to browser cookies.
   * It is not meant to be used directly, use the $cookie service instead.
   *
   * The return values vary depending on the arguments that the method was called with as follows:
   *
   * - cookies() -> hash of all cookies, this is NOT a copy of the internal state, so do not modify
   *   it
   * - cookies(name, value) -> set name to value, if value is undefined delete the cookie
   * - cookies(name) -> the same as (name, undefined) == DELETES (no one calls it right now that
   *   way)
   *
   * @returns {Object} Hash of all cookies (if called without any parameter)
   */
  self.cookies = function(name, value) {
    var cookieLength, cookieArray, cookie, i, index;

    if (name) {
      if (value === undefined) {
        rawDocument.cookie = encodeURIComponent(name) + "=;path=" + cookiePath +
                                ";expires=Thu, 01 Jan 1970 00:00:00 GMT";
      } else {
        if (isString(value)) {
          cookieLength = (rawDocument.cookie = encodeURIComponent(name) + '=' + encodeURIComponent(value) +
                                ';path=' + cookiePath).length + 1;

          // per http://www.ietf.org/rfc/rfc2109.txt browser must allow at minimum:
          // - 300 cookies
          // - 20 cookies per unique domain
          // - 4096 bytes per cookie
          if (cookieLength > 4096) {
            $log.warn("Cookie '" + name +
              "' possibly not set or overflowed because it was too large (" +
              cookieLength + " > 4096 bytes)!");
          }
        }
      }
    } else {
      if (rawDocument.cookie !== lastCookieString) {
        lastCookieString = rawDocument.cookie;
        cookieArray = lastCookieString.split("; ");
        lastCookies = {};

        for (i = 0; i < cookieArray.length; i++) {
          cookie = cookieArray[i];
          index = cookie.indexOf('=');
          if (index > 0) { //ignore nameless cookies
            name = safeDecodeURIComponent(cookie.substring(0, index));
            // the first value that is seen for a cookie is the most
            // specific one.  values for the same cookie name that
            // follow are for less specific paths.
            if (lastCookies[name] === undefined) {
              lastCookies[name] = safeDecodeURIComponent(cookie.substring(index + 1));
            }
          }
        }
      }
      return lastCookies;
    }
  };


  /**
   * @name $browser#defer
   * @param {function()} fn A function, who's execution should be deferred.
   * @param {number=} [delay=0] of milliseconds to defer the function execution.
   * @returns {*} DeferId that can be used to cancel the task via `$browser.defer.cancel()`.
   *
   * @description
   * Executes a fn asynchronously via `setTimeout(fn, delay)`.
   *
   * Unlike when calling `setTimeout` directly, in test this function is mocked and instead of using
   * `setTimeout` in tests, the fns are queued in an array, which can be programmatically flushed
   * via `$browser.defer.flush()`.
   *
   */
  self.defer = function(fn, delay) {
    var timeoutId;
    outstandingRequestCount++;
    timeoutId = setTimeout(function() {
      delete pendingDeferIds[timeoutId];
      completeOutstandingRequest(fn);
    }, delay || 0);
    pendingDeferIds[timeoutId] = true;
    return timeoutId;
  };


  /**
   * @name $browser#defer.cancel
   *
   * @description
   * Cancels a deferred task identified with `deferId`.
   *
   * @param {*} deferId Token returned by the `$browser.defer` function.
   * @returns {boolean} Returns `true` if the task hasn't executed yet and was successfully
   *                    canceled.
   */
  self.defer.cancel = function(deferId) {
    if (pendingDeferIds[deferId]) {
      delete pendingDeferIds[deferId];
      clearTimeout(deferId);
      completeOutstandingRequest(noop);
      return true;
    }
    return false;
  };

}

function $BrowserProvider() {
  this.$get = ['$window', '$log', '$sniffer', '$document',
      function($window, $log, $sniffer, $document) {
        return new Browser($window, $document, $log, $sniffer);
      }];
}

/**
 * @ngdoc service
 * @name $cacheFactory
 *
 * @description
 * Factory that constructs {@link $cacheFactory.Cache Cache} objects and gives access to
 * them.
 *
 * ```js
 *
 *  var cache = $cacheFactory('cacheId');
 *  expect($cacheFactory.get('cacheId')).toBe(cache);
 *  expect($cacheFactory.get('noSuchCacheId')).not.toBeDefined();
 *
 *  cache.put("key", "value");
 *  cache.put("another key", "another value");
 *
 *  // We've specified no options on creation
 *  expect(cache.info()).toEqual({id: 'cacheId', size: 2});
 *
 * ```
 *
 *
 * @param {string} cacheId Name or id of the newly created cache.
 * @param {object=} options Options object that specifies the cache behavior. Properties:
 *
 *   - `{number=}` `capacity` — turns the cache into LRU cache.
 *
 * @returns {object} Newly created cache object with the following set of methods:
 *
 * - `{object}` `info()` — Returns id, size, and options of cache.
 * - `{{*}}` `put({string} key, {*} value)` — Puts a new key-value pair into the cache and returns
 *   it.
 * - `{{*}}` `get({string} key)` — Returns cached value for `key` or undefined for cache miss.
 * - `{void}` `remove({string} key)` — Removes a key-value pair from the cache.
 * - `{void}` `removeAll()` — Removes all cached values.
 * - `{void}` `destroy()` — Removes references to this cache from $cacheFactory.
 *
 * @example
   <example module="cacheExampleApp">
     <file name="index.html">
       <div ng-controller="CacheController">
         <input ng-model="newCacheKey" placeholder="Key">
         <input ng-model="newCacheValue" placeholder="Value">
         <button ng-click="put(newCacheKey, newCacheValue)">Cache</button>

         <p ng-if="keys.length">Cached Values</p>
         <div ng-repeat="key in keys">
           <span ng-bind="key"></span>
           <span>: </span>
           <b ng-bind="cache.get(key)"></b>
         </div>

         <p>Cache Info</p>
         <div ng-repeat="(key, value) in cache.info()">
           <span ng-bind="key"></span>
           <span>: </span>
           <b ng-bind="value"></b>
         </div>
       </div>
     </file>
     <file name="script.js">
       angular.module('cacheExampleApp', []).
         controller('CacheController', ['$scope', '$cacheFactory', function($scope, $cacheFactory) {
           $scope.keys = [];
           $scope.cache = $cacheFactory('cacheId');
           $scope.put = function(key, value) {
             if ($scope.cache.get(key) === undefined) {
               $scope.keys.push(key);
             }
             $scope.cache.put(key, value === undefined ? null : value);
           };
         }]);
     </file>
     <file name="style.css">
       p {
         margin: 10px 0 3px;
       }
     </file>
   </example>
 */
function $CacheFactoryProvider() {

  this.$get = function() {
    var caches = {};

    function cacheFactory(cacheId, options) {
      if (cacheId in caches) {
        throw minErr('$cacheFactory')('iid', "CacheId '{0}' is already taken!", cacheId);
      }

      var size = 0,
          stats = extend({}, options, {id: cacheId}),
          data = {},
          capacity = (options && options.capacity) || Number.MAX_VALUE,
          lruHash = {},
          freshEnd = null,
          staleEnd = null;

      /**
       * @ngdoc type
       * @name $cacheFactory.Cache
       *
       * @description
       * A cache object used to store and retrieve data, primarily used by
       * {@link $http $http} and the {@link ng.directive:script script} directive to cache
       * templates and other data.
       *
       * ```js
       *  angular.module('superCache')
       *    .factory('superCache', ['$cacheFactory', function($cacheFactory) {
       *      return $cacheFactory('super-cache');
       *    }]);
       * ```
       *
       * Example test:
       *
       * ```js
       *  it('should behave like a cache', inject(function(superCache) {
       *    superCache.put('key', 'value');
       *    superCache.put('another key', 'another value');
       *
       *    expect(superCache.info()).toEqual({
       *      id: 'super-cache',
       *      size: 2
       *    });
       *
       *    superCache.remove('another key');
       *    expect(superCache.get('another key')).toBeUndefined();
       *
       *    superCache.removeAll();
       *    expect(superCache.info()).toEqual({
       *      id: 'super-cache',
       *      size: 0
       *    });
       *  }));
       * ```
       */
      return caches[cacheId] = {

        /**
         * @ngdoc method
         * @name $cacheFactory.Cache#put
         * @kind function
         *
         * @description
         * Inserts a named entry into the {@link $cacheFactory.Cache Cache} object to be
         * retrieved later, and incrementing the size of the cache if the key was not already
         * present in the cache. If behaving like an LRU cache, it will also remove stale
         * entries from the set.
         *
         * It will not insert undefined values into the cache.
         *
         * @param {string} key the key under which the cached data is stored.
         * @param {*} value the value to store alongside the key. If it is undefined, the key
         *    will not be stored.
         * @returns {*} the value stored.
         */
        put: function(key, value) {
          if (capacity < Number.MAX_VALUE) {
            var lruEntry = lruHash[key] || (lruHash[key] = {key: key});

            refresh(lruEntry);
          }

          if (isUndefined(value)) return;
          if (!(key in data)) size++;
          data[key] = value;

          if (size > capacity) {
            this.remove(staleEnd.key);
          }

          return value;
        },

        /**
         * @ngdoc method
         * @name $cacheFactory.Cache#get
         * @kind function
         *
         * @description
         * Retrieves named data stored in the {@link $cacheFactory.Cache Cache} object.
         *
         * @param {string} key the key of the data to be retrieved
         * @returns {*} the value stored.
         */
        get: function(key) {
          if (capacity < Number.MAX_VALUE) {
            var lruEntry = lruHash[key];

            if (!lruEntry) return;

            refresh(lruEntry);
          }

          return data[key];
        },


        /**
         * @ngdoc method
         * @name $cacheFactory.Cache#remove
         * @kind function
         *
         * @description
         * Removes an entry from the {@link $cacheFactory.Cache Cache} object.
         *
         * @param {string} key the key of the entry to be removed
         */
        remove: function(key) {
          if (capacity < Number.MAX_VALUE) {
            var lruEntry = lruHash[key];

            if (!lruEntry) return;

            if (lruEntry == freshEnd) freshEnd = lruEntry.p;
            if (lruEntry == staleEnd) staleEnd = lruEntry.n;
            link(lruEntry.n,lruEntry.p);

            delete lruHash[key];
          }

          delete data[key];
          size--;
        },


        /**
         * @ngdoc method
         * @name $cacheFactory.Cache#removeAll
         * @kind function
         *
         * @description
         * Clears the cache object of any entries.
         */
        removeAll: function() {
          data = {};
          size = 0;
          lruHash = {};
          freshEnd = staleEnd = null;
        },


        /**
         * @ngdoc method
         * @name $cacheFactory.Cache#destroy
         * @kind function
         *
         * @description
         * Destroys the {@link $cacheFactory.Cache Cache} object entirely,
         * removing it from the {@link $cacheFactory $cacheFactory} set.
         */
        destroy: function() {
          data = null;
          stats = null;
          lruHash = null;
          delete caches[cacheId];
        },


        /**
         * @ngdoc method
         * @name $cacheFactory.Cache#info
         * @kind function
         *
         * @description
         * Retrieve information regarding a particular {@link $cacheFactory.Cache Cache}.
         *
         * @returns {object} an object with the following properties:
         *   <ul>
         *     <li>**id**: the id of the cache instance</li>
         *     <li>**size**: the number of entries kept in the cache instance</li>
         *     <li>**...**: any additional properties from the options object when creating the
         *       cache.</li>
         *   </ul>
         */
        info: function() {
          return extend({}, stats, {size: size});
        }
      };


      /**
       * makes the `entry` the freshEnd of the LRU linked list
       */
      function refresh(entry) {
        if (entry != freshEnd) {
          if (!staleEnd) {
            staleEnd = entry;
          } else if (staleEnd == entry) {
            staleEnd = entry.n;
          }

          link(entry.n, entry.p);
          link(entry, freshEnd);
          freshEnd = entry;
          freshEnd.n = null;
        }
      }


      /**
       * bidirectionally links two entries of the LRU linked list
       */
      function link(nextEntry, prevEntry) {
        if (nextEntry != prevEntry) {
          if (nextEntry) nextEntry.p = prevEntry; //p stands for previous, 'prev' didn't minify
          if (prevEntry) prevEntry.n = nextEntry; //n stands for next, 'next' didn't minify
        }
      }
    }


  /**
   * @ngdoc method
   * @name $cacheFactory#info
   *
   * @description
   * Get information about all the caches that have been created
   *
   * @returns {Object} - key-value map of `cacheId` to the result of calling `cache#info`
   */
    cacheFactory.info = function() {
      var info = {};
      forEach(caches, function(cache, cacheId) {
        info[cacheId] = cache.info();
      });
      return info;
    };


  /**
   * @ngdoc method
   * @name $cacheFactory#get
   *
   * @description
   * Get access to a cache object by the `cacheId` used when it was created.
   *
   * @param {string} cacheId Name or id of a cache to access.
   * @returns {object} Cache object identified by the cacheId or undefined if no such cache.
   */
    cacheFactory.get = function(cacheId) {
      return caches[cacheId];
    };


    return cacheFactory;
  };
}

/**
 * @ngdoc service
 * @name $templateCache
 *
 * @description
 * The first time a template is used, it is loaded in the template cache for quick retrieval. You
 * can load templates directly into the cache in a `script` tag, or by consuming the
 * `$templateCache` service directly.
 *
 * Adding via the `script` tag:
 *
 * ```html
 *   <script type="text/ng-template" id="templateId.html">
 *     <p>This is the content of the template</p>
 *   </script>
 * ```
 *
 * **Note:** the `script` tag containing the template does not need to be included in the `head` of
 * the document, but it must be a descendent of the {@link ng.$rootElement $rootElement} (IE,
 * element with ng-app attribute), otherwise the template will be ignored.
 *
 * Adding via the `$templateCache` service:
 *
 * ```js
 * var myApp = angular.module('myApp', []);
 * myApp.run(function($templateCache) {
 *   $templateCache.put('templateId.html', 'This is the content of the template');
 * });
 * ```
 *
 * To retrieve the template later, simply use it in your HTML:
 * ```html
 * <div ng-include=" 'templateId.html' "></div>
 * ```
 *
 * or get it via Javascript:
 * ```js
 * $templateCache.get('templateId.html')
 * ```
 *
 * See {@link ng.$cacheFactory $cacheFactory}.
 *
 */
function $TemplateCacheProvider() {
  this.$get = ['$cacheFactory', function($cacheFactory) {
    return $cacheFactory('templates');
  }];
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 *     Any commits to this file should be reviewed with security in mind.  *
 *   Changes to this file can potentially create security vulnerabilities. *
 *          An approval from 2 Core members with history of modifying      *
 *                         this file is required.                          *
 *                                                                         *
 *  Does the change somehow allow for arbitrary javascript to be executed? *
 *    Or allows for someone to change the prototype of built-in objects?   *
 *     Or gives undesired access to variables likes document or window?    *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

/* ! VARIABLE/FUNCTION NAMING CONVENTIONS THAT APPLY TO THIS FILE!
 *
 * DOM-related variables:
 *
 * - "node" - DOM Node
 * - "element" - DOM Element or Node
 * - "$node" or "$element" - jqLite-wrapped node or element
 *
 *
 * Compiler related stuff:
 *
 * - "linkFn" - linking fn of a single directive
 * - "nodeLinkFn" - function that aggregates all linking fns for a particular node
 * - "childLinkFn" -  function that aggregates all linking fns for child nodes of a particular node
 * - "compositeLinkFn" - function that aggregates all linking fns for a compilation root (nodeList)
 */


/**
 * @ngdoc service
 * @name $compile
 * @kind function
 *
 * @description
 * Compiles an HTML string or DOM into a template and produces a template function, which
 * can then be used to link {@link ng.$rootScope.Scope `scope`} and the template together.
 *
 * The compilation is a process of walking the DOM tree and matching DOM elements to
 * {@link ng.$compileProvider#directive directives}.
 *
 * <div class="alert alert-warning">
 * **Note:** This document is an in-depth reference of all directive options.
 * For a gentle introduction to directives with examples of common use cases,
 * see the {@link guide/directive directive guide}.
 * </div>
 *
 * ## Comprehensive Directive API
 *
 * There are many different options for a directive.
 *
 * The difference resides in the return value of the factory function.
 * You can either return a "Directive Definition Object" (see below) that defines the directive properties,
 * or just the `postLink` function (all other properties will have the default values).
 *
 * <div class="alert alert-success">
 * **Best Practice:** It's recommended to use the "directive definition object" form.
 * </div>
 *
 * Here's an example directive declared with a Directive Definition Object:
 *
 * ```js
 *   var myModule = angular.module(...);
 *
 *   myModule.directive('directiveName', function factory(injectables) {
 *     var directiveDefinitionObject = {
 *       priority: 0,
 *       template: '<div></div>', // or // function(tElement, tAttrs) { ... },
 *       // or
 *       // templateUrl: 'directive.html', // or // function(tElement, tAttrs) { ... },
 *       transclude: false,
 *       restrict: 'A',
 *       templateNamespace: 'html',
 *       scope: false,
 *       controller: function($scope, $element, $attrs, $transclude, otherInjectables) { ... },
 *       controllerAs: 'stringIdentifier',
 *       bindToController: false,
 *       require: 'siblingDirectiveName', // or // ['^parentDirectiveName', '?optionalDirectiveName', '?^optionalParent'],
 *       compile: function compile(tElement, tAttrs, transclude) {
 *         return {
 *           pre: function preLink(scope, iElement, iAttrs, controller) { ... },
 *           post: function postLink(scope, iElement, iAttrs, controller) { ... }
 *         }
 *         // or
 *         // return function postLink( ... ) { ... }
 *       },
 *       // or
 *       // link: {
 *       //  pre: function preLink(scope, iElement, iAttrs, controller) { ... },
 *       //  post: function postLink(scope, iElement, iAttrs, controller) { ... }
 *       // }
 *       // or
 *       // link: function postLink( ... ) { ... }
 *     };
 *     return directiveDefinitionObject;
 *   });
 * ```
 *
 * <div class="alert alert-warning">
 * **Note:** Any unspecified options will use the default value. You can see the default values below.
 * </div>
 *
 * Therefore the above can be simplified as:
 *
 * ```js
 *   var myModule = angular.module(...);
 *
 *   myModule.directive('directiveName', function factory(injectables) {
 *     var directiveDefinitionObject = {
 *       link: function postLink(scope, iElement, iAttrs) { ... }
 *     };
 *     return directiveDefinitionObject;
 *     // or
 *     // return function postLink(scope, iElement, iAttrs) { ... }
 *   });
 * ```
 *
 *
 *
 * ### Directive Definition Object
 *
 * The directive definition object provides instructions to the {@link ng.$compile
 * compiler}. The attributes are:
 *
 * #### `multiElement`
 * When this property is set to true, the HTML compiler will collect DOM nodes between
 * nodes with the attributes `directive-name-start` and `directive-name-end`, and group them
 * together as the directive elements. It is recommended that this feature be used on directives
 * which are not strictly behavioural (such as {@link ngClick}), and which
 * do not manipulate or replace child nodes (such as {@link ngInclude}).
 *
 * #### `priority`
 * When there are multiple directives defined on a single DOM element, sometimes it
 * is necessary to specify the order in which the directives are applied. The `priority` is used
 * to sort the directives before their `compile` functions get called. Priority is defined as a
 * number. Directives with greater numerical `priority` are compiled first. Pre-link functions
 * are also run in priority order, but post-link functions are run in reverse order. The order
 * of directives with the same priority is undefined. The default priority is `0`.
 *
 * #### `terminal`
 * If set to true then the current `priority` will be the last set of directives
 * which will execute (any directives at the current priority will still execute
 * as the order of execution on same `priority` is undefined). Note that expressions
 * and other directives used in the directive's template will also be excluded from execution.
 *
 * #### `scope`
 * **If set to `true`,** then a new scope will be created for this directive. If multiple directives on the
 * same element request a new scope, only one new scope is created. The new scope rule does not
 * apply for the root of the template since the root of the template always gets a new scope.
 *
 * **If set to `{}` (object hash),** then a new "isolate" scope is created. The 'isolate' scope differs from
 * normal scope in that it does not prototypically inherit from the parent scope. This is useful
 * when creating reusable components, which should not accidentally read or modify data in the
 * parent scope.
 *
 * The 'isolate' scope takes an object hash which defines a set of local scope properties
 * derived from the parent scope. These local properties are useful for aliasing values for
 * templates. Locals definition is a hash of local scope property to its source:
 *
 * * `@` or `@attr` - bind a local scope property to the value of DOM attribute. The result is
 *   always a string since DOM attributes are strings. If no `attr` name is specified  then the
 *   attribute name is assumed to be the same as the local name.
 *   Given `<widget my-attr="hello {{name}}">` and widget definition
 *   of `scope: { localName:'@myAttr' }`, then widget scope property `localName` will reflect
 *   the interpolated value of `hello {{name}}`. As the `name` attribute changes so will the
 *   `localName` property on the widget scope. The `name` is read from the parent scope (not
 *   component scope).
 *
 * * `=` or `=attr` - set up bi-directional binding between a local scope property and the
 *   parent scope property of name defined via the value of the `attr` attribute. If no `attr`
 *   name is specified then the attribute name is assumed to be the same as the local name.
 *   Given `<widget my-attr="parentModel">` and widget definition of
 *   `scope: { localModel:'=myAttr' }`, then widget scope property `localModel` will reflect the
 *   value of `parentModel` on the parent scope. Any changes to `parentModel` will be reflected
 *   in `localModel` and any changes in `localModel` will reflect in `parentModel`. If the parent
 *   scope property doesn't exist, it will throw a NON_ASSIGNABLE_MODEL_EXPRESSION exception. You
 *   can avoid this behavior using `=?` or `=?attr` in order to flag the property as optional. If
 *   you want to shallow watch for changes (i.e. $watchCollection instead of $watch) you can use
 *   `=*` or `=*attr` (`=*?` or `=*?attr` if the property is optional).
 *
 * * `&` or `&attr` - provides a way to execute an expression in the context of the parent scope.
 *   If no `attr` name is specified then the attribute name is assumed to be the same as the
 *   local name. Given `<widget my-attr="count = count + value">` and widget definition of
 *   `scope: { localFn:'&myAttr' }`, then isolate scope property `localFn` will point to
 *   a function wrapper for the `count = count + value` expression. Often it's desirable to
 *   pass data from the isolated scope via an expression to the parent scope, this can be
 *   done by passing a map of local variable names and values into the expression wrapper fn.
 *   For example, if the expression is `increment(amount)` then we can specify the amount value
 *   by calling the `localFn` as `localFn({amount: 22})`.
 *
 *
 * #### `bindToController`
 * When an isolate scope is used for a component (see above), and `controllerAs` is used, `bindToController: true` will
 * allow a component to have its properties bound to the controller, rather than to scope. When the controller
 * is instantiated, the initial values of the isolate scope bindings are already available.
 *
 * #### `controller`
 * Controller constructor function. The controller is instantiated before the
 * pre-linking phase and it is shared with other directives (see
 * `require` attribute). This allows the directives to communicate with each other and augment
 * each other's behavior. The controller is injectable (and supports bracket notation) with the following locals:
 *
 * * `$scope` - Current scope associated with the element
 * * `$element` - Current element
 * * `$attrs` - Current attributes object for the element
 * * `$transclude` - A transclude linking function pre-bound to the correct transclusion scope:
 *   `function([scope], cloneLinkingFn, futureParentElement)`.
 *    * `scope`: optional argument to override the scope.
 *    * `cloneLinkingFn`: optional argument to create clones of the original transcluded content.
 *    * `futureParentElement`:
 *        * defines the parent to which the `cloneLinkingFn` will add the cloned elements.
 *        * default: `$element.parent()` resp. `$element` for `transclude:'element'` resp. `transclude:true`.
 *        * only needed for transcludes that are allowed to contain non html elements (e.g. SVG elements)
 *          and when the `cloneLinkinFn` is passed,
 *          as those elements need to created and cloned in a special way when they are defined outside their
 *          usual containers (e.g. like `<svg>`).
 *        * See also the `directive.templateNamespace` property.
 *
 *
 * #### `require`
 * Require another directive and inject its controller as the fourth argument to the linking function. The
 * `require` takes a string name (or array of strings) of the directive(s) to pass in. If an array is used, the
 * injected argument will be an array in corresponding order. If no such directive can be
 * found, or if the directive does not have a controller, then an error is raised (unless no link function
 * is specified, in which case error checking is skipped). The name can be prefixed with:
 *
 * * (no prefix) - Locate the required controller on the current element. Throw an error if not found.
 * * `?` - Attempt to locate the required controller or pass `null` to the `link` fn if not found.
 * * `^` - Locate the required controller by searching the element and its parents. Throw an error if not found.
 * * `^^` - Locate the required controller by searching the element's parents. Throw an error if not found.
 * * `?^` - Attempt to locate the required controller by searching the element and its parents or pass
 *   `null` to the `link` fn if not found.
 * * `?^^` - Attempt to locate the required controller by searching the element's parents, or pass
 *   `null` to the `link` fn if not found.
 *
 *
 * #### `controllerAs`
 * Controller alias at the directive scope. An alias for the controller so it
 * can be referenced at the directive template. The directive needs to define a scope for this
 * configuration to be used. Useful in the case when directive is used as component.
 *
 *
 * #### `restrict`
 * String of subset of `EACM` which restricts the directive to a specific directive
 * declaration style. If omitted, the defaults (elements and attributes) are used.
 *
 * * `E` - Element name (default): `<my-directive></my-directive>`
 * * `A` - Attribute (default): `<div my-directive="exp"></div>`
 * * `C` - Class: `<div class="my-directive: exp;"></div>`
 * * `M` - Comment: `<!-- directive: my-directive exp -->`
 *
 *
 * #### `templateNamespace`
 * String representing the document type used by the markup in the template.
 * AngularJS needs this information as those elements need to be created and cloned
 * in a special way when they are defined outside their usual containers like `<svg>` and `<math>`.
 *
 * * `html` - All root nodes in the template are HTML. Root nodes may also be
 *   top-level elements such as `<svg>` or `<math>`.
 * * `svg` - The root nodes in the template are SVG elements (excluding `<math>`).
 * * `math` - The root nodes in the template are MathML elements (excluding `<svg>`).
 *
 * If no `templateNamespace` is specified, then the namespace is considered to be `html`.
 *
 * #### `template`
 * HTML markup that may:
 * * Replace the contents of the directive's element (default).
 * * Replace the directive's element itself (if `replace` is true - DEPRECATED).
 * * Wrap the contents of the directive's element (if `transclude` is true).
 *
 * Value may be:
 *
 * * A string. For example `<div red-on-hover>{{delete_str}}</div>`.
 * * A function which takes two arguments `tElement` and `tAttrs` (described in the `compile`
 *   function api below) and returns a string value.
 *
 *
 * #### `templateUrl`
 * This is similar to `template` but the template is loaded from the specified URL, asynchronously.
 *
 * Because template loading is asynchronous the compiler will suspend compilation of directives on that element
 * for later when the template has been resolved.  In the meantime it will continue to compile and link
 * sibling and parent elements as though this element had not contained any directives.
 *
 * The compiler does not suspend the entire compilation to wait for templates to be loaded because this
 * would result in the whole app "stalling" until all templates are loaded asynchronously - even in the
 * case when only one deeply nested directive has `templateUrl`.
 *
 * Template loading is asynchronous even if the template has been preloaded into the {@link $templateCache}
 *
 * You can specify `templateUrl` as a string representing the URL or as a function which takes two
 * arguments `tElement` and `tAttrs` (described in the `compile` function api below) and returns
 * a string value representing the url.  In either case, the template URL is passed through {@link
 * $sce#getTrustedResourceUrl $sce.getTrustedResourceUrl}.
 *
 *
 * #### `replace` ([*DEPRECATED*!], will be removed in next major release - i.e. v2.0)
 * specify what the template should replace. Defaults to `false`.
 *
 * * `true` - the template will replace the directive's element.
 * * `false` - the template will replace the contents of the directive's element.
 *
 * The replacement process migrates all of the attributes / classes from the old element to the new
 * one. See the {@link guide/directive#template-expanding-directive
 * Directives Guide} for an example.
 *
 * There are very few scenarios where element replacement is required for the application function,
 * the main one being reusable custom components that are used within SVG contexts
 * (because SVG doesn't work with custom elements in the DOM tree).
 *
 * #### `transclude`
 * Extract the contents of the element where the directive appears and make it available to the directive.
 * The contents are compiled and provided to the directive as a **transclusion function**. See the
 * {@link $compile#transclusion Transclusion} section below.
 *
 * There are two kinds of transclusion depending upon whether you want to transclude just the contents of the
 * directive's element or the entire element:
 *
 * * `true` - transclude the content (i.e. the child nodes) of the directive's element.
 * * `'element'` - transclude the whole of the directive's element including any directives on this
 *   element that defined at a lower priority than this directive. When used, the `template`
 *   property is ignored.
 *
 *
 * #### `compile`
 *
 * ```js
 *   function compile(tElement, tAttrs, transclude) { ... }
 * ```
 *
 * The compile function deals with transforming the template DOM. Since most directives do not do
 * template transformation, it is not used often. The compile function takes the following arguments:
 *
 *   * `tElement` - template element - The element where the directive has been declared. It is
 *     safe to do template transformation on the element and child elements only.
 *
 *   * `tAttrs` - template attributes - Normalized list of attributes declared on this element shared
 *     between all directive compile functions.
 *
 *   * `transclude` -  [*DEPRECATED*!] A transclude linking function: `function(scope, cloneLinkingFn)`
 *
 * <div class="alert alert-warning">
 * **Note:** The template instance and the link instance may be different objects if the template has
 * been cloned. For this reason it is **not** safe to do anything other than DOM transformations that
 * apply to all cloned DOM nodes within the compile function. Specifically, DOM listener registration
 * should be done in a linking function rather than in a compile function.
 * </div>

 * <div class="alert alert-warning">
 * **Note:** The compile function cannot handle directives that recursively use themselves in their
 * own templates or compile functions. Compiling these directives results in an infinite loop and a
 * stack overflow errors.
 *
 * This can be avoided by manually using $compile in the postLink function to imperatively compile
 * a directive's template instead of relying on automatic template compilation via `template` or
 * `templateUrl` declaration or manual compilation inside the compile function.
 * </div>
 *
 * <div class="alert alert-error">
 * **Note:** The `transclude` function that is passed to the compile function is deprecated, as it
 *   e.g. does not know about the right outer scope. Please use the transclude function that is passed
 *   to the link function instead.
 * </div>

 * A compile function can have a return value which can be either a function or an object.
 *
 * * returning a (post-link) function - is equivalent to registering the linking function via the
 *   `link` property of the config object when the compile function is empty.
 *
 * * returning an object with function(s) registered via `pre` and `post` properties - allows you to
 *   control when a linking function should be called during the linking phase. See info about
 *   pre-linking and post-linking functions below.
 *
 *
 * #### `link`
 * This property is used only if the `compile` property is not defined.
 *
 * ```js
 *   function link(scope, iElement, iAttrs, controller, transcludeFn) { ... }
 * ```
 *
 * The link function is responsible for registering DOM listeners as well as updating the DOM. It is
 * executed after the template has been cloned. This is where most of the directive logic will be
 * put.
 *
 *   * `scope` - {@link ng.$rootScope.Scope Scope} - The scope to be used by the
 *     directive for registering {@link ng.$rootScope.Scope#$watch watches}.
 *
 *   * `iElement` - instance element - The element where the directive is to be used. It is safe to
 *     manipulate the children of the element only in `postLink` function since the children have
 *     already been linked.
 *
 *   * `iAttrs` - instance attributes - Normalized list of attributes declared on this element shared
 *     between all directive linking functions.
 *
 *   * `controller` - the directive's required controller instance(s) - Instances are shared
 *     among all directives, which allows the directives to use the controllers as a communication
 *     channel. The exact value depends on the directive's `require` property:
 *       * `string`: the controller instance
 *       * `array`: array of controller instances
 *       * no controller(s) required: `undefined`
 *
 *     If a required controller cannot be found, and it is optional, the instance is `null`,
 *     otherwise the {@link error:$compile:ctreq Missing Required Controller} error is thrown.
 *
 *   * `transcludeFn` - A transclude linking function pre-bound to the correct transclusion scope.
 *     This is the same as the `$transclude`
 *     parameter of directive controllers, see there for details.
 *     `function([scope], cloneLinkingFn, futureParentElement)`.
 *
 * #### Pre-linking function
 *
 * Executed before the child elements are linked. Not safe to do DOM transformation since the
 * compiler linking function will fail to locate the correct elements for linking.
 *
 * #### Post-linking function
 *
 * Executed after the child elements are linked.
 *
 * Note that child elements that contain `templateUrl` directives will not have been compiled
 * and linked since they are waiting for their template to load asynchronously and their own
 * compilation and linking has been suspended until that occurs.
 *
 * It is safe to do DOM transformation in the post-linking function on elements that are not waiting
 * for their async templates to be resolved.
 *
 *
 * ### Transclusion
 *
 * Transclusion is the process of extracting a collection of DOM elements from one part of the DOM and
 * copying them to another part of the DOM, while maintaining their connection to the original AngularJS
 * scope from where they were taken.
 *
 * Transclusion is used (often with {@link ngTransclude}) to insert the
 * original contents of a directive's element into a specified place in the template of the directive.
 * The benefit of transclusion, over simply moving the DOM elements manually, is that the transcluded
 * content has access to the properties on the scope from which it was taken, even if the directive
 * has isolated scope.
 * See the {@link guide/directive#creating-a-directive-that-wraps-other-elements Directives Guide}.
 *
 * This makes it possible for the widget to have private state for its template, while the transcluded
 * content has access to its originating scope.
 *
 * <div class="alert alert-warning">
 * **Note:** When testing an element transclude directive you must not place the directive at the root of the
 * DOM fragment that is being compiled. See {@link guide/unit-testing#testing-transclusion-directives
 * Testing Transclusion Directives}.
 * </div>
 *
 * #### Transclusion Functions
 *
 * When a directive requests transclusion, the compiler extracts its contents and provides a **transclusion
 * function** to the directive's `link` function and `controller`. This transclusion function is a special
 * **linking function** that will return the compiled contents linked to a new transclusion scope.
 *
 * <div class="alert alert-info">
 * If you are just using {@link ngTransclude} then you don't need to worry about this function, since
 * ngTransclude will deal with it for us.
 * </div>
 *
 * If you want to manually control the insertion and removal of the transcluded content in your directive
 * then you must use this transclude function. When you call a transclude function it returns a a jqLite/JQuery
 * object that contains the compiled DOM, which is linked to the correct transclusion scope.
 *
 * When you call a transclusion function you can pass in a **clone attach function**. This function accepts
 * two parameters, `function(clone, scope) { ... }`, where the `clone` is a fresh compiled copy of your transcluded
 * content and the `scope` is the newly created transclusion scope, to which the clone is bound.
 *
 * <div class="alert alert-info">
 * **Best Practice**: Always provide a `cloneFn` (clone attach function) when you call a translude function
 * since you then get a fresh clone of the original DOM and also have access to the new transclusion scope.
 * </div>
 *
 * It is normal practice to attach your transcluded content (`clone`) to the DOM inside your **clone
 * attach function**:
 *
 * ```js
 * var transcludedContent, transclusionScope;
 *
 * $transclude(function(clone, scope) {
 *   element.append(clone);
 *   transcludedContent = clone;
 *   transclusionScope = scope;
 * });
 * ```
 *
 * Later, if you want to remove the transcluded content from your DOM then you should also destroy the
 * associated transclusion scope:
 *
 * ```js
 * transcludedContent.remove();
 * transclusionScope.$destroy();
 * ```
 *
 * <div class="alert alert-info">
 * **Best Practice**: if you intend to add and remove transcluded content manually in your directive
 * (by calling the transclude function to get the DOM and and calling `element.remove()` to remove it),
 * then you are also responsible for calling `$destroy` on the transclusion scope.
 * </div>
 *
 * The built-in DOM manipulation directives, such as {@link ngIf}, {@link ngSwitch} and {@link ngRepeat}
 * automatically destroy their transluded clones as necessary so you do not need to worry about this if
 * you are simply using {@link ngTransclude} to inject the transclusion into your directive.
 *
 *
 * #### Transclusion Scopes
 *
 * When you call a transclude function it returns a DOM fragment that is pre-bound to a **transclusion
 * scope**. This scope is special, in that it is a child of the directive's scope (and so gets destroyed
 * when the directive's scope gets destroyed) but it inherits the properties of the scope from which it
 * was taken.
 *
 * For example consider a directive that uses transclusion and isolated scope. The DOM hierarchy might look
 * like this:
 *
 * ```html
 * <div ng-app>
 *   <div isolate>
 *     <div transclusion>
 *     </div>
 *   </div>
 * </div>
 * ```
 *
 * The `$parent` scope hierarchy will look like this:
 *
 * ```
 * - $rootScope
 *   - isolate
 *     - transclusion
 * ```
 *
 * but the scopes will inherit prototypically from different scopes to their `$parent`.
 *
 * ```
 * - $rootScope
 *   - transclusion
 * - isolate
 * ```
 *
 *
 * ### Attributes
 *
 * The {@link ng.$compile.directive.Attributes Attributes} object - passed as a parameter in the
 * `link()` or `compile()` functions. It has a variety of uses.
 *
 * accessing *Normalized attribute names:*
 * Directives like 'ngBind' can be expressed in many ways: 'ng:bind', `data-ng-bind`, or 'x-ng-bind'.
 * the attributes object allows for normalized access to
 *   the attributes.
 *
 * * *Directive inter-communication:* All directives share the same instance of the attributes
 *   object which allows the directives to use the attributes object as inter directive
 *   communication.
 *
 * * *Supports interpolation:* Interpolation attributes are assigned to the attribute object
 *   allowing other directives to read the interpolated value.
 *
 * * *Observing interpolated attributes:* Use `$observe` to observe the value changes of attributes
 *   that contain interpolation (e.g. `src="{{bar}}"`). Not only is this very efficient but it's also
 *   the only way to easily get the actual value because during the linking phase the interpolation
 *   hasn't been evaluated yet and so the value is at this time set to `undefined`.
 *
 * ```js
 * function linkingFn(scope, elm, attrs, ctrl) {
 *   // get the attribute value
 *   console.log(attrs.ngModel);
 *
 *   // change the attribute
 *   attrs.$set('ngModel', 'new value');
 *
 *   // observe changes to interpolated attribute
 *   attrs.$observe('ngModel', function(value) {
 *     console.log('ngModel has changed value to ' + value);
 *   });
 * }
 * ```
 *
 * ## Example
 *
 * <div class="alert alert-warning">
 * **Note**: Typically directives are registered with `module.directive`. The example below is
 * to illustrate how `$compile` works.
 * </div>
 *
 <example module="compileExample">
   <file name="index.html">
    <script>
      angular.module('compileExample', [], function($compileProvider) {
        // configure new 'compile' directive by passing a directive
        // factory function. The factory function injects the '$compile'
        $compileProvider.directive('compile', function($compile) {
          // directive factory creates a link function
          return function(scope, element, attrs) {
            scope.$watch(
              function(scope) {
                 // watch the 'compile' expression for changes
                return scope.$eval(attrs.compile);
              },
              function(value) {
                // when the 'compile' expression changes
                // assign it into the current DOM
                element.html(value);

                // compile the new DOM and link it to the current
                // scope.
                // NOTE: we only compile .childNodes so that
                // we don't get into infinite loop compiling ourselves
                $compile(element.contents())(scope);
              }
            );
          };
        });
      })
      .controller('GreeterController', ['$scope', function($scope) {
        $scope.name = 'Angular';
        $scope.html = 'Hello {{name}}';
      }]);
    </script>
    <div ng-controller="GreeterController">
      <input ng-model="name"> <br>
      <textarea ng-model="html"></textarea> <br>
      <div compile="html"></div>
    </div>
   </file>
   <file name="protractor.js" type="protractor">
     it('should auto compile', function() {
       var textarea = $('textarea');
       var output = $('div[compile]');
       // The initial state reads 'Hello Angular'.
       expect(output.getText()).toBe('Hello Angular');
       textarea.clear();
       textarea.sendKeys('{{name}}!');
       expect(output.getText()).toBe('Angular!');
     });
   </file>
 </example>

 *
 *
 * @param {string|DOMElement} element Element or HTML string to compile into a template function.
 * @param {function(angular.Scope, cloneAttachFn=)} transclude function available to directives - DEPRECATED.
 *
 * <div class="alert alert-error">
 * **Note:** Passing a `transclude` function to the $compile function is deprecated, as it
 *   e.g. will not use the right outer scope. Please pass the transclude function as a
 *   `parentBoundTranscludeFn` to the link function instead.
 * </div>
 *
 * @param {number} maxPriority only apply directives lower than given priority (Only effects the
 *                 root element(s), not their children)
 * @returns {function(scope, cloneAttachFn=, options=)} a link function which is used to bind template
 * (a DOM element/tree) to a scope. Where:
 *
 *  * `scope` - A {@link ng.$rootScope.Scope Scope} to bind to.
 *  * `cloneAttachFn` - If `cloneAttachFn` is provided, then the link function will clone the
 *  `template` and call the `cloneAttachFn` function allowing the caller to attach the
 *  cloned elements to the DOM document at the appropriate place. The `cloneAttachFn` is
 *  called as: <br> `cloneAttachFn(clonedElement, scope)` where:
 *
 *      * `clonedElement` - is a clone of the original `element` passed into the compiler.
 *      * `scope` - is the current scope with which the linking function is working with.
 *
 *  * `options` - An optional object hash with linking options. If `options` is provided, then the following
 *  keys may be used to control linking behavior:
 *
 *      * `parentBoundTranscludeFn` - the transclude function made available to
 *        directives; if given, it will be passed through to the link functions of
 *        directives found in `element` during compilation.
 *      * `transcludeControllers` - an object hash with keys that map controller names
 *        to controller instances; if given, it will make the controllers
 *        available to directives.
 *      * `futureParentElement` - defines the parent to which the `cloneAttachFn` will add
 *        the cloned elements; only needed for transcludes that are allowed to contain non html
 *        elements (e.g. SVG elements). See also the directive.controller property.
 *
 * Calling the linking function returns the element of the template. It is either the original
 * element passed in, or the clone of the element if the `cloneAttachFn` is provided.
 *
 * After linking the view is not updated until after a call to $digest which typically is done by
 * Angular automatically.
 *
 * If you need access to the bound view, there are two ways to do it:
 *
 * - If you are not asking the linking function to clone the template, create the DOM element(s)
 *   before you send them to the compiler and keep this reference around.
 *   ```js
 *     var element = $compile('<p>{{total}}</p>')(scope);
 *   ```
 *
 * - if on the other hand, you need the element to be cloned, the view reference from the original
 *   example would not point to the clone, but rather to the original template that was cloned. In
 *   this case, you can access the clone via the cloneAttachFn:
 *   ```js
 *     var templateElement = angular.element('<p>{{total}}</p>'),
 *         scope = ....;
 *
 *     var clonedElement = $compile(templateElement)(scope, function(clonedElement, scope) {
 *       //attach the clone to DOM document at the right place
 *     });
 *
 *     //now we have reference to the cloned DOM via `clonedElement`
 *   ```
 *
 *
 * For information on how the compiler works, see the
 * {@link guide/compiler Angular HTML Compiler} section of the Developer Guide.
 */

var $compileMinErr = minErr('$compile');

/**
 * @ngdoc provider
 * @name $compileProvider
 *
 * @description
 */
$CompileProvider.$inject = ['$provide', '$$sanitizeUriProvider'];
function $CompileProvider($provide, $$sanitizeUriProvider) {
  var hasDirectives = {},
      Suffix = 'Directive',
      COMMENT_DIRECTIVE_REGEXP = /^\s*directive\:\s*([\w\-]+)\s+(.*)$/,
      CLASS_DIRECTIVE_REGEXP = /(([\w\-]+)(?:\:([^;]+))?;?)/,
      ALL_OR_NOTHING_ATTRS = makeMap('ngSrc,ngSrcset,src,srcset'),
      REQUIRE_PREFIX_REGEXP = /^(?:(\^\^?)?(\?)?(\^\^?)?)?/;

  // Ref: http://developers.whatwg.org/webappapis.html#event-handler-idl-attributes
  // The assumption is that future DOM event attribute names will begin with
  // 'on' and be composed of only English letters.
  var EVENT_HANDLER_ATTR_REGEXP = /^(on[a-z]+|formaction)$/;

  function parseIsolateBindings(scope, directiveName) {
    var LOCAL_REGEXP = /^\s*([@&]|=(\*?))(\??)\s*(\w*)\s*$/;

    var bindings = {};

    forEach(scope, function(definition, scopeName) {
      var match = definition.match(LOCAL_REGEXP);

      if (!match) {
        throw $compileMinErr('iscp',
            "Invalid isolate scope definition for directive '{0}'." +
            " Definition: {... {1}: '{2}' ...}",
            directiveName, scopeName, definition);
      }

      bindings[scopeName] = {
        mode: match[1][0],
        collection: match[2] === '*',
        optional: match[3] === '?',
        attrName: match[4] || scopeName
      };
    });

    return bindings;
  }

  /**
   * @ngdoc method
   * @name $compileProvider#directive
   * @kind function
   *
   * @description
   * Register a new directive with the compiler.
   *
   * @param {string|Object} name Name of the directive in camel-case (i.e. <code>ngBind</code> which
   *    will match as <code>ng-bind</code>), or an object map of directives where the keys are the
   *    names and the values are the factories.
   * @param {Function|Array} directiveFactory An injectable directive factory function. See
   *    {@link guide/directive} for more info.
   * @returns {ng.$compileProvider} Self for chaining.
   */
   this.directive = function registerDirective(name, directiveFactory) {
    assertNotHasOwnProperty(name, 'directive');
    if (isString(name)) {
      assertArg(directiveFactory, 'directiveFactory');
      if (!hasDirectives.hasOwnProperty(name)) {
        hasDirectives[name] = [];
        $provide.factory(name + Suffix, ['$injector', '$exceptionHandler',
          function($injector, $exceptionHandler) {
            var directives = [];
            forEach(hasDirectives[name], function(directiveFactory, index) {
              try {
                var directive = $injector.invoke(directiveFactory);
                if (isFunction(directive)) {
                  directive = { compile: valueFn(directive) };
                } else if (!directive.compile && directive.link) {
                  directive.compile = valueFn(directive.link);
                }
                directive.priority = directive.priority || 0;
                directive.index = index;
                directive.name = directive.name || name;
                directive.require = directive.require || (directive.controller && directive.name);
                directive.restrict = directive.restrict || 'EA';
                if (isObject(directive.scope)) {
                  directive.$$isolateBindings = parseIsolateBindings(directive.scope, directive.name);
                }
                directives.push(directive);
              } catch (e) {
                $exceptionHandler(e);
              }
            });
            return directives;
          }]);
      }
      hasDirectives[name].push(directiveFactory);
    } else {
      forEach(name, reverseParams(registerDirective));
    }
    return this;
  };


  /**
   * @ngdoc method
   * @name $compileProvider#aHrefSanitizationWhitelist
   * @kind function
   *
   * @description
   * Retrieves or overrides the default regular expression that is used for whitelisting of safe
   * urls during a[href] sanitization.
   *
   * The sanitization is a security measure aimed at preventing XSS attacks via html links.
   *
   * Any url about to be assigned to a[href] via data-binding is first normalized and turned into
   * an absolute url. Afterwards, the url is matched against the `aHrefSanitizationWhitelist`
   * regular expression. If a match is found, the original url is written into the dom. Otherwise,
   * the absolute url is prefixed with `'unsafe:'` string and only then is it written into the DOM.
   *
   * @param {RegExp=} regexp New regexp to whitelist urls with.
   * @returns {RegExp|ng.$compileProvider} Current RegExp if called without value or self for
   *    chaining otherwise.
   */
  this.aHrefSanitizationWhitelist = function(regexp) {
    if (isDefined(regexp)) {
      $$sanitizeUriProvider.aHrefSanitizationWhitelist(regexp);
      return this;
    } else {
      return $$sanitizeUriProvider.aHrefSanitizationWhitelist();
    }
  };


  /**
   * @ngdoc method
   * @name $compileProvider#imgSrcSanitizationWhitelist
   * @kind function
   *
   * @description
   * Retrieves or overrides the default regular expression that is used for whitelisting of safe
   * urls during img[src] sanitization.
   *
   * The sanitization is a security measure aimed at prevent XSS attacks via html links.
   *
   * Any url about to be assigned to img[src] via data-binding is first normalized and turned into
   * an absolute url. Afterwards, the url is matched against the `imgSrcSanitizationWhitelist`
   * regular expression. If a match is found, the original url is written into the dom. Otherwise,
   * the absolute url is prefixed with `'unsafe:'` string and only then is it written into the DOM.
   *
   * @param {RegExp=} regexp New regexp to whitelist urls with.
   * @returns {RegExp|ng.$compileProvider} Current RegExp if called without value or self for
   *    chaining otherwise.
   */
  this.imgSrcSanitizationWhitelist = function(regexp) {
    if (isDefined(regexp)) {
      $$sanitizeUriProvider.imgSrcSanitizationWhitelist(regexp);
      return this;
    } else {
      return $$sanitizeUriProvider.imgSrcSanitizationWhitelist();
    }
  };

  /**
   * @ngdoc method
   * @name  $compileProvider#debugInfoEnabled
   *
   * @param {boolean=} enabled update the debugInfoEnabled state if provided, otherwise just return the
   * current debugInfoEnabled state
   * @returns {*} current value if used as getter or itself (chaining) if used as setter
   *
   * @kind function
   *
   * @description
   * Call this method to enable/disable various debug runtime information in the compiler such as adding
   * binding information and a reference to the current scope on to DOM elements.
   * If enabled, the compiler will add the following to DOM elements that have been bound to the scope
   * * `ng-binding` CSS class
   * * `$binding` data property containing an array of the binding expressions
   *
   * You may want to disable this in production for a significant performance boost. See
   * {@link guide/production#disabling-debug-data Disabling Debug Data} for more.
   *
   * The default value is true.
   */
  var debugInfoEnabled = true;
  this.debugInfoEnabled = function(enabled) {
    if (isDefined(enabled)) {
      debugInfoEnabled = enabled;
      return this;
    }
    return debugInfoEnabled;
  };

  this.$get = [
            '$injector', '$interpolate', '$exceptionHandler', '$templateRequest', '$parse',
            '$controller', '$rootScope', '$document', '$sce', '$animate', '$$sanitizeUri',
    function($injector,   $interpolate,   $exceptionHandler,   $templateRequest,   $parse,
             $controller,   $rootScope,   $document,   $sce,   $animate,   $$sanitizeUri) {

    var Attributes = function(element, attributesToCopy) {
      if (attributesToCopy) {
        var keys = Object.keys(attributesToCopy);
        var i, l, key;

        for (i = 0, l = keys.length; i < l; i++) {
          key = keys[i];
          this[key] = attributesToCopy[key];
        }
      } else {
        this.$attr = {};
      }

      this.$$element = element;
    };

    Attributes.prototype = {
      /**
       * @ngdoc method
       * @name $compile.directive.Attributes#$normalize
       * @kind function
       *
       * @description
       * Converts an attribute name (e.g. dash/colon/underscore-delimited string, optionally prefixed with `x-` or
       * `data-`) to its normalized, camelCase form.
       *
       * Also there is special case for Moz prefix starting with upper case letter.
       *
       * For further information check out the guide on {@link guide/directive#matching-directives Matching Directives}
       *
       * @param {string} name Name to normalize
       */
      $normalize: directiveNormalize,


      /**
       * @ngdoc method
       * @name $compile.directive.Attributes#$addClass
       * @kind function
       *
       * @description
       * Adds the CSS class value specified by the classVal parameter to the element. If animations
       * are enabled then an animation will be triggered for the class addition.
       *
       * @param {string} classVal The className value that will be added to the element
       */
      $addClass: function(classVal) {
        if (classVal && classVal.length > 0) {
          $animate.addClass(this.$$element, classVal);
        }
      },

      /**
       * @ngdoc method
       * @name $compile.directive.Attributes#$removeClass
       * @kind function
       *
       * @description
       * Removes the CSS class value specified by the classVal parameter from the element. If
       * animations are enabled then an animation will be triggered for the class removal.
       *
       * @param {string} classVal The className value that will be removed from the element
       */
      $removeClass: function(classVal) {
        if (classVal && classVal.length > 0) {
          $animate.removeClass(this.$$element, classVal);
        }
      },

      /**
       * @ngdoc method
       * @name $compile.directive.Attributes#$updateClass
       * @kind function
       *
       * @description
       * Adds and removes the appropriate CSS class values to the element based on the difference
       * between the new and old CSS class values (specified as newClasses and oldClasses).
       *
       * @param {string} newClasses The current CSS className value
       * @param {string} oldClasses The former CSS className value
       */
      $updateClass: function(newClasses, oldClasses) {
        var toAdd = tokenDifference(newClasses, oldClasses);
        if (toAdd && toAdd.length) {
          $animate.addClass(this.$$element, toAdd);
        }

        var toRemove = tokenDifference(oldClasses, newClasses);
        if (toRemove && toRemove.length) {
          $animate.removeClass(this.$$element, toRemove);
        }
      },

      /**
       * Set a normalized attribute on the element in a way such that all directives
       * can share the attribute. This function properly handles boolean attributes.
       * @param {string} key Normalized key. (ie ngAttribute)
       * @param {string|boolean} value The value to set. If `null` attribute will be deleted.
       * @param {boolean=} writeAttr If false, does not write the value to DOM element attribute.
       *     Defaults to true.
       * @param {string=} attrName Optional none normalized name. Defaults to key.
       */
      $set: function(key, value, writeAttr, attrName) {
        // TODO: decide whether or not to throw an error if "class"
        //is set through this function since it may cause $updateClass to
        //become unstable.

        var node = this.$$element[0],
            booleanKey = getBooleanAttrName(node, key),
            aliasedKey = getAliasedAttrName(node, key),
            observer = key,
            nodeName;

        if (booleanKey) {
          this.$$element.prop(key, value);
          attrName = booleanKey;
        } else if (aliasedKey) {
          this[aliasedKey] = value;
          observer = aliasedKey;
        }

        this[key] = value;

        // translate normalized key to actual key
        if (attrName) {
          this.$attr[key] = attrName;
        } else {
          attrName = this.$attr[key];
          if (!attrName) {
            this.$attr[key] = attrName = snake_case(key, '-');
          }
        }

        nodeName = nodeName_(this.$$element);

        if ((nodeName === 'a' && key === 'href') ||
            (nodeName === 'img' && key === 'src')) {
          // sanitize a[href] and img[src] values
          this[key] = value = $$sanitizeUri(value, key === 'src');
        } else if (nodeName === 'img' && key === 'srcset') {
          // sanitize img[srcset] values
          var result = "";

          // first check if there are spaces because it's not the same pattern
          var trimmedSrcset = trim(value);
          //                (   999x   ,|   999w   ,|   ,|,   )
          var srcPattern = /(\s+\d+x\s*,|\s+\d+w\s*,|\s+,|,\s+)/;
          var pattern = /\s/.test(trimmedSrcset) ? srcPattern : /(,)/;

          // split srcset into tuple of uri and descriptor except for the last item
          var rawUris = trimmedSrcset.split(pattern);

          // for each tuples
          var nbrUrisWith2parts = Math.floor(rawUris.length / 2);
          for (var i = 0; i < nbrUrisWith2parts; i++) {
            var innerIdx = i * 2;
            // sanitize the uri
            result += $$sanitizeUri(trim(rawUris[innerIdx]), true);
            // add the descriptor
            result += (" " + trim(rawUris[innerIdx + 1]));
          }

          // split the last item into uri and descriptor
          var lastTuple = trim(rawUris[i * 2]).split(/\s/);

          // sanitize the last uri
          result += $$sanitizeUri(trim(lastTuple[0]), true);

          // and add the last descriptor if any
          if (lastTuple.length === 2) {
            result += (" " + trim(lastTuple[1]));
          }
          this[key] = value = result;
        }

        if (writeAttr !== false) {
          if (value === null || value === undefined) {
            this.$$element.removeAttr(attrName);
          } else {
            this.$$element.attr(attrName, value);
          }
        }

        // fire observers
        var $$observers = this.$$observers;
        $$observers && forEach($$observers[observer], function(fn) {
          try {
            fn(value);
          } catch (e) {
            $exceptionHandler(e);
          }
        });
      },


      /**
       * @ngdoc method
       * @name $compile.directive.Attributes#$observe
       * @kind function
       *
       * @description
       * Observes an interpolated attribute.
       *
       * The observer function will be invoked once during the next `$digest` following
       * compilation. The observer is then invoked whenever the interpolated value
       * changes.
       *
       * @param {string} key Normalized key. (ie ngAttribute) .
       * @param {function(interpolatedValue)} fn Function that will be called whenever
                the interpolated value of the attribute changes.
       *        See the {@link guide/directive#text-and-attribute-bindings Directives} guide for more info.
       * @returns {function()} Returns a deregistration function for this observer.
       */
      $observe: function(key, fn) {
        var attrs = this,
            $$observers = (attrs.$$observers || (attrs.$$observers = createMap())),
            listeners = ($$observers[key] || ($$observers[key] = []));

        listeners.push(fn);
        $rootScope.$evalAsync(function() {
          if (!listeners.$$inter && attrs.hasOwnProperty(key)) {
            // no one registered attribute interpolation function, so lets call it manually
            fn(attrs[key]);
          }
        });

        return function() {
          arrayRemove(listeners, fn);
        };
      }
    };


    function safeAddClass($element, className) {
      try {
        $element.addClass(className);
      } catch (e) {
        // ignore, since it means that we are trying to set class on
        // SVG element, where class name is read-only.
      }
    }


    var startSymbol = $interpolate.startSymbol(),
        endSymbol = $interpolate.endSymbol(),
        denormalizeTemplate = (startSymbol == '{{' || endSymbol  == '}}')
            ? identity
            : function denormalizeTemplate(template) {
              return template.replace(/\{\{/g, startSymbol).replace(/}}/g, endSymbol);
        },
        NG_ATTR_BINDING = /^ngAttr[A-Z]/;

    compile.$$addBindingInfo = debugInfoEnabled ? function $$addBindingInfo($element, binding) {
      var bindings = $element.data('$binding') || [];

      if (isArray(binding)) {
        bindings = bindings.concat(binding);
      } else {
        bindings.push(binding);
      }

      $element.data('$binding', bindings);
    } : noop;

    compile.$$addBindingClass = debugInfoEnabled ? function $$addBindingClass($element) {
      safeAddClass($element, 'ng-binding');
    } : noop;

    compile.$$addScopeInfo = debugInfoEnabled ? function $$addScopeInfo($element, scope, isolated, noTemplate) {
      var dataName = isolated ? (noTemplate ? '$isolateScopeNoTemplate' : '$isolateScope') : '$scope';
      $element.data(dataName, scope);
    } : noop;

    compile.$$addScopeClass = debugInfoEnabled ? function $$addScopeClass($element, isolated) {
      safeAddClass($element, isolated ? 'ng-isolate-scope' : 'ng-scope');
    } : noop;

    return compile;

    //================================

    function compile($compileNodes, transcludeFn, maxPriority, ignoreDirective,
                        previousCompileContext) {
      if (!($compileNodes instanceof jqLite)) {
        // jquery always rewraps, whereas we need to preserve the original selector so that we can
        // modify it.
        $compileNodes = jqLite($compileNodes);
      }
      // We can not compile top level text elements since text nodes can be merged and we will
      // not be able to attach scope data to them, so we will wrap them in <span>
      forEach($compileNodes, function(node, index) {
        if (node.nodeType == NODE_TYPE_TEXT && node.nodeValue.match(/\S+/) /* non-empty */ ) {
          $compileNodes[index] = jqLite(node).wrap('<span></span>').parent()[0];
        }
      });
      var compositeLinkFn =
              compileNodes($compileNodes, transcludeFn, $compileNodes,
                           maxPriority, ignoreDirective, previousCompileContext);
      compile.$$addScopeClass($compileNodes);
      var namespace = null;
      return function publicLinkFn(scope, cloneConnectFn, options) {
        assertArg(scope, 'scope');

        options = options || {};
        var parentBoundTranscludeFn = options.parentBoundTranscludeFn,
          transcludeControllers = options.transcludeControllers,
          futureParentElement = options.futureParentElement;

        // When `parentBoundTranscludeFn` is passed, it is a
        // `controllersBoundTransclude` function (it was previously passed
        // as `transclude` to directive.link) so we must unwrap it to get
        // its `boundTranscludeFn`
        if (parentBoundTranscludeFn && parentBoundTranscludeFn.$$boundTransclude) {
          parentBoundTranscludeFn = parentBoundTranscludeFn.$$boundTransclude;
        }

        if (!namespace) {
          namespace = detectNamespaceForChildElements(futureParentElement);
        }
        var $linkNode;
        if (namespace !== 'html') {
          // When using a directive with replace:true and templateUrl the $compileNodes
          // (or a child element inside of them)
          // might change, so we need to recreate the namespace adapted compileNodes
          // for call to the link function.
          // Note: This will already clone the nodes...
          $linkNode = jqLite(
            wrapTemplate(namespace, jqLite('<div>').append($compileNodes).html())
          );
        } else if (cloneConnectFn) {
          // important!!: we must call our jqLite.clone() since the jQuery one is trying to be smart
          // and sometimes changes the structure of the DOM.
          $linkNode = JQLitePrototype.clone.call($compileNodes);
        } else {
          $linkNode = $compileNodes;
        }

        if (transcludeControllers) {
          for (var controllerName in transcludeControllers) {
            $linkNode.data('$' + controllerName + 'Controller', transcludeControllers[controllerName].instance);
          }
        }

        compile.$$addScopeInfo($linkNode, scope);

        if (cloneConnectFn) cloneConnectFn($linkNode, scope);
        if (compositeLinkFn) compositeLinkFn(scope, $linkNode, $linkNode, parentBoundTranscludeFn);
        return $linkNode;
      };
    }

    function detectNamespaceForChildElements(parentElement) {
      // TODO: Make this detect MathML as well...
      var node = parentElement && parentElement[0];
      if (!node) {
        return 'html';
      } else {
        return nodeName_(node) !== 'foreignobject' && node.toString().match(/SVG/) ? 'svg' : 'html';
      }
    }

    /**
     * Compile function matches each node in nodeList against the directives. Once all directives
     * for a particular node are collected their compile functions are executed. The compile
     * functions return values - the linking functions - are combined into a composite linking
     * function, which is the a linking function for the node.
     *
     * @param {NodeList} nodeList an array of nodes or NodeList to compile
     * @param {function(angular.Scope, cloneAttachFn=)} transcludeFn A linking function, where the
     *        scope argument is auto-generated to the new child of the transcluded parent scope.
     * @param {DOMElement=} $rootElement If the nodeList is the root of the compilation tree then
     *        the rootElement must be set the jqLite collection of the compile root. This is
     *        needed so that the jqLite collection items can be replaced with widgets.
     * @param {number=} maxPriority Max directive priority.
     * @returns {Function} A composite linking function of all of the matched directives or null.
     */
    function compileNodes(nodeList, transcludeFn, $rootElement, maxPriority, ignoreDirective,
                            previousCompileContext) {
      var linkFns = [],
          attrs, directives, nodeLinkFn, childNodes, childLinkFn, linkFnFound, nodeLinkFnFound;

      for (var i = 0; i < nodeList.length; i++) {
        attrs = new Attributes();

        // we must always refer to nodeList[i] since the nodes can be replaced underneath us.
        directives = collectDirectives(nodeList[i], [], attrs, i === 0 ? maxPriority : undefined,
                                        ignoreDirective);

        nodeLinkFn = (directives.length)
            ? applyDirectivesToNode(directives, nodeList[i], attrs, transcludeFn, $rootElement,
                                      null, [], [], previousCompileContext)
            : null;

        if (nodeLinkFn && nodeLinkFn.scope) {
          compile.$$addScopeClass(attrs.$$element);
        }

        childLinkFn = (nodeLinkFn && nodeLinkFn.terminal ||
                      !(childNodes = nodeList[i].childNodes) ||
                      !childNodes.length)
            ? null
            : compileNodes(childNodes,
                 nodeLinkFn ? (
                  (nodeLinkFn.transcludeOnThisElement || !nodeLinkFn.templateOnThisElement)
                     && nodeLinkFn.transclude) : transcludeFn);

        if (nodeLinkFn || childLinkFn) {
          linkFns.push(i, nodeLinkFn, childLinkFn);
          linkFnFound = true;
          nodeLinkFnFound = nodeLinkFnFound || nodeLinkFn;
        }

        //use the previous context only for the first element in the virtual group
        previousCompileContext = null;
      }

      // return a linking function if we have found anything, null otherwise
      return linkFnFound ? compositeLinkFn : null;

      function compositeLinkFn(scope, nodeList, $rootElement, parentBoundTranscludeFn) {
        var nodeLinkFn, childLinkFn, node, childScope, i, ii, idx, childBoundTranscludeFn;
        var stableNodeList;


        if (nodeLinkFnFound) {
          // copy nodeList so that if a nodeLinkFn removes or adds an element at this DOM level our
          // offsets don't get screwed up
          var nodeListLength = nodeList.length;
          stableNodeList = new Array(nodeListLength);

          // create a sparse array by only copying the elements which have a linkFn
          for (i = 0; i < linkFns.length; i+=3) {
            idx = linkFns[i];
            stableNodeList[idx] = nodeList[idx];
          }
        } else {
          stableNodeList = nodeList;
        }

        for (i = 0, ii = linkFns.length; i < ii;) {
          node = stableNodeList[linkFns[i++]];
          nodeLinkFn = linkFns[i++];
          childLinkFn = linkFns[i++];

          if (nodeLinkFn) {
            if (nodeLinkFn.scope) {
              childScope = scope.$new();
              compile.$$addScopeInfo(jqLite(node), childScope);
            } else {
              childScope = scope;
            }

            if (nodeLinkFn.transcludeOnThisElement) {
              childBoundTranscludeFn = createBoundTranscludeFn(
                  scope, nodeLinkFn.transclude, parentBoundTranscludeFn,
                  nodeLinkFn.elementTranscludeOnThisElement);

            } else if (!nodeLinkFn.templateOnThisElement && parentBoundTranscludeFn) {
              childBoundTranscludeFn = parentBoundTranscludeFn;

            } else if (!parentBoundTranscludeFn && transcludeFn) {
              childBoundTranscludeFn = createBoundTranscludeFn(scope, transcludeFn);

            } else {
              childBoundTranscludeFn = null;
            }

            nodeLinkFn(childLinkFn, childScope, node, $rootElement, childBoundTranscludeFn);

          } else if (childLinkFn) {
            childLinkFn(scope, node.childNodes, undefined, parentBoundTranscludeFn);
          }
        }
      }
    }

    function createBoundTranscludeFn(scope, transcludeFn, previousBoundTranscludeFn, elementTransclusion) {

      var boundTranscludeFn = function(transcludedScope, cloneFn, controllers, futureParentElement, containingScope) {

        if (!transcludedScope) {
          transcludedScope = scope.$new(false, containingScope);
          transcludedScope.$$transcluded = true;
        }

        return transcludeFn(transcludedScope, cloneFn, {
          parentBoundTranscludeFn: previousBoundTranscludeFn,
          transcludeControllers: controllers,
          futureParentElement: futureParentElement
        });
      };

      return boundTranscludeFn;
    }

    /**
     * Looks for directives on the given node and adds them to the directive collection which is
     * sorted.
     *
     * @param node Node to search.
     * @param directives An array to which the directives are added to. This array is sorted before
     *        the function returns.
     * @param attrs The shared attrs object which is used to populate the normalized attributes.
     * @param {number=} maxPriority Max directive priority.
     */
    function collectDirectives(node, directives, attrs, maxPriority, ignoreDirective) {
      var nodeType = node.nodeType,
          attrsMap = attrs.$attr,
          match,
          className;

      switch (nodeType) {
        case NODE_TYPE_ELEMENT: /* Element */
          // use the node name: <directive>
          addDirective(directives,
              directiveNormalize(nodeName_(node)), 'E', maxPriority, ignoreDirective);

          // iterate over the attributes
          for (var attr, name, nName, ngAttrName, value, isNgAttr, nAttrs = node.attributes,
                   j = 0, jj = nAttrs && nAttrs.length; j < jj; j++) {
            var attrStartName = false;
            var attrEndName = false;

            attr = nAttrs[j];
            name = attr.name;
            value = trim(attr.value);

            // support ngAttr attribute binding
            ngAttrName = directiveNormalize(name);
            if (isNgAttr = NG_ATTR_BINDING.test(ngAttrName)) {
              name = name.replace(PREFIX_REGEXP, '')
                .substr(8).replace(/_(.)/g, function(match, letter) {
                  return letter.toUpperCase();
                });
            }

            var directiveNName = ngAttrName.replace(/(Start|End)$/, '');
            if (directiveIsMultiElement(directiveNName)) {
              if (ngAttrName === directiveNName + 'Start') {
                attrStartName = name;
                attrEndName = name.substr(0, name.length - 5) + 'end';
                name = name.substr(0, name.length - 6);
              }
            }

            nName = directiveNormalize(name.toLowerCase());
            attrsMap[nName] = name;
            if (isNgAttr || !attrs.hasOwnProperty(nName)) {
                attrs[nName] = value;
                if (getBooleanAttrName(node, nName)) {
                  attrs[nName] = true; // presence means true
                }
            }
            addAttrInterpolateDirective(node, directives, value, nName, isNgAttr);
            addDirective(directives, nName, 'A', maxPriority, ignoreDirective, attrStartName,
                          attrEndName);
          }

          // use class as directive
          className = node.className;
          if (isObject(className)) {
              // Maybe SVGAnimatedString
              className = className.animVal;
          }
          if (isString(className) && className !== '') {
            while (match = CLASS_DIRECTIVE_REGEXP.exec(className)) {
              nName = directiveNormalize(match[2]);
              if (addDirective(directives, nName, 'C', maxPriority, ignoreDirective)) {
                attrs[nName] = trim(match[3]);
              }
              className = className.substr(match.index + match[0].length);
            }
          }
          break;
        case NODE_TYPE_TEXT: /* Text Node */
          addTextInterpolateDirective(directives, node.nodeValue);
          break;
        case NODE_TYPE_COMMENT: /* Comment */
          try {
            match = COMMENT_DIRECTIVE_REGEXP.exec(node.nodeValue);
            if (match) {
              nName = directiveNormalize(match[1]);
              if (addDirective(directives, nName, 'M', maxPriority, ignoreDirective)) {
                attrs[nName] = trim(match[2]);
              }
            }
          } catch (e) {
            // turns out that under some circumstances IE9 throws errors when one attempts to read
            // comment's node value.
            // Just ignore it and continue. (Can't seem to reproduce in test case.)
          }
          break;
      }

      directives.sort(byPriority);
      return directives;
    }

    /**
     * Given a node with an directive-start it collects all of the siblings until it finds
     * directive-end.
     * @param node
     * @param attrStart
     * @param attrEnd
     * @returns {*}
     */
    function groupScan(node, attrStart, attrEnd) {
      var nodes = [];
      var depth = 0;
      if (attrStart && node.hasAttribute && node.hasAttribute(attrStart)) {
        do {
          if (!node) {
            throw $compileMinErr('uterdir',
                      "Unterminated attribute, found '{0}' but no matching '{1}' found.",
                      attrStart, attrEnd);
          }
          if (node.nodeType == NODE_TYPE_ELEMENT) {
            if (node.hasAttribute(attrStart)) depth++;
            if (node.hasAttribute(attrEnd)) depth--;
          }
          nodes.push(node);
          node = node.nextSibling;
        } while (depth > 0);
      } else {
        nodes.push(node);
      }

      return jqLite(nodes);
    }

    /**
     * Wrapper for linking function which converts normal linking function into a grouped
     * linking function.
     * @param linkFn
     * @param attrStart
     * @param attrEnd
     * @returns {Function}
     */
    function groupElementsLinkFnWrapper(linkFn, attrStart, attrEnd) {
      return function(scope, element, attrs, controllers, transcludeFn) {
        element = groupScan(element[0], attrStart, attrEnd);
        return linkFn(scope, element, attrs, controllers, transcludeFn);
      };
    }

    /**
     * Once the directives have been collected, their compile functions are executed. This method
     * is responsible for inlining directive templates as well as terminating the application
     * of the directives if the terminal directive has been reached.
     *
     * @param {Array} directives Array of collected directives to execute their compile function.
     *        this needs to be pre-sorted by priority order.
     * @param {Node} compileNode The raw DOM node to apply the compile functions to
     * @param {Object} templateAttrs The shared attribute function
     * @param {function(angular.Scope, cloneAttachFn=)} transcludeFn A linking function, where the
     *                                                  scope argument is auto-generated to the new
     *                                                  child of the transcluded parent scope.
     * @param {JQLite} jqCollection If we are working on the root of the compile tree then this
     *                              argument has the root jqLite array so that we can replace nodes
     *                              on it.
     * @param {Object=} originalReplaceDirective An optional directive that will be ignored when
     *                                           compiling the transclusion.
     * @param {Array.<Function>} preLinkFns
     * @param {Array.<Function>} postLinkFns
     * @param {Object} previousCompileContext Context used for previous compilation of the current
     *                                        node
     * @returns {Function} linkFn
     */
    function applyDirectivesToNode(directives, compileNode, templateAttrs, transcludeFn,
                                   jqCollection, originalReplaceDirective, preLinkFns, postLinkFns,
                                   previousCompileContext) {
      previousCompileContext = previousCompileContext || {};

      var terminalPriority = -Number.MAX_VALUE,
          newScopeDirective,
          controllerDirectives = previousCompileContext.controllerDirectives,
          controllers,
          newIsolateScopeDirective = previousCompileContext.newIsolateScopeDirective,
          templateDirective = previousCompileContext.templateDirective,
          nonTlbTranscludeDirective = previousCompileContext.nonTlbTranscludeDirective,
          hasTranscludeDirective = false,
          hasTemplate = false,
          hasElementTranscludeDirective = previousCompileContext.hasElementTranscludeDirective,
          $compileNode = templateAttrs.$$element = jqLite(compileNode),
          directive,
          directiveName,
          $template,
          replaceDirective = originalReplaceDirective,
          childTranscludeFn = transcludeFn,
          linkFn,
          directiveValue;

      // executes all directives on the current element
      for (var i = 0, ii = directives.length; i < ii; i++) {
        directive = directives[i];
        var attrStart = directive.$$start;
        var attrEnd = directive.$$end;

        // collect multiblock sections
        if (attrStart) {
          $compileNode = groupScan(compileNode, attrStart, attrEnd);
        }
        $template = undefined;

        if (terminalPriority > directive.priority) {
          break; // prevent further processing of directives
        }

        if (directiveValue = directive.scope) {

          // skip the check for directives with async templates, we'll check the derived sync
          // directive when the template arrives
          if (!directive.templateUrl) {
            if (isObject(directiveValue)) {
              // This directive is trying to add an isolated scope.
              // Check that there is no scope of any kind already
              assertNoDuplicate('new/isolated scope', newIsolateScopeDirective || newScopeDirective,
                                directive, $compileNode);
              newIsolateScopeDirective = directive;
            } else {
              // This directive is trying to add a child scope.
              // Check that there is no isolated scope already
              assertNoDuplicate('new/isolated scope', newIsolateScopeDirective, directive,
                                $compileNode);
            }
          }

          newScopeDirective = newScopeDirective || directive;
        }

        directiveName = directive.name;

        if (!directive.templateUrl && directive.controller) {
          directiveValue = directive.controller;
          controllerDirectives = controllerDirectives || {};
          assertNoDuplicate("'" + directiveName + "' controller",
              controllerDirectives[directiveName], directive, $compileNode);
          controllerDirectives[directiveName] = directive;
        }

        if (directiveValue = directive.transclude) {
          hasTranscludeDirective = true;

          // Special case ngIf and ngRepeat so that we don't complain about duplicate transclusion.
          // This option should only be used by directives that know how to safely handle element transclusion,
          // where the transcluded nodes are added or replaced after linking.
          if (!directive.$$tlb) {
            assertNoDuplicate('transclusion', nonTlbTranscludeDirective, directive, $compileNode);
            nonTlbTranscludeDirective = directive;
          }

          if (directiveValue == 'element') {
            hasElementTranscludeDirective = true;
            terminalPriority = directive.priority;
            $template = $compileNode;
            $compileNode = templateAttrs.$$element =
                jqLite(document.createComment(' ' + directiveName + ': ' +
                                              templateAttrs[directiveName] + ' '));
            compileNode = $compileNode[0];
            replaceWith(jqCollection, sliceArgs($template), compileNode);

            childTranscludeFn = compile($template, transcludeFn, terminalPriority,
                                        replaceDirective && replaceDirective.name, {
                                          // Don't pass in:
                                          // - controllerDirectives - otherwise we'll create duplicates controllers
                                          // - newIsolateScopeDirective or templateDirective - combining templates with
                                          //   element transclusion doesn't make sense.
                                          //
                                          // We need only nonTlbTranscludeDirective so that we prevent putting transclusion
                                          // on the same element more than once.
                                          nonTlbTranscludeDirective: nonTlbTranscludeDirective
                                        });
          } else {
            $template = jqLite(jqLiteClone(compileNode)).contents();
            $compileNode.empty(); // clear contents
            childTranscludeFn = compile($template, transcludeFn);
          }
        }

        if (directive.template) {
          hasTemplate = true;
          assertNoDuplicate('template', templateDirective, directive, $compileNode);
          templateDirective = directive;

          directiveValue = (isFunction(directive.template))
              ? directive.template($compileNode, templateAttrs)
              : directive.template;

          directiveValue = denormalizeTemplate(directiveValue);

          if (directive.replace) {
            replaceDirective = directive;
            if (jqLiteIsTextNode(directiveValue)) {
              $template = [];
            } else {
              $template = removeComments(wrapTemplate(directive.templateNamespace, trim(directiveValue)));
            }
            compileNode = $template[0];

            if ($template.length != 1 || compileNode.nodeType !== NODE_TYPE_ELEMENT) {
              throw $compileMinErr('tplrt',
                  "Template for directive '{0}' must have exactly one root element. {1}",
                  directiveName, '');
            }

            replaceWith(jqCollection, $compileNode, compileNode);

            var newTemplateAttrs = {$attr: {}};

            // combine directives from the original node and from the template:
            // - take the array of directives for this element
            // - split it into two parts, those that already applied (processed) and those that weren't (unprocessed)
            // - collect directives from the template and sort them by priority
            // - combine directives as: processed + template + unprocessed
            var templateDirectives = collectDirectives(compileNode, [], newTemplateAttrs);
            var unprocessedDirectives = directives.splice(i + 1, directives.length - (i + 1));

            if (newIsolateScopeDirective) {
              markDirectivesAsIsolate(templateDirectives);
            }
            directives = directives.concat(templateDirectives).concat(unprocessedDirectives);
            mergeTemplateAttributes(templateAttrs, newTemplateAttrs);

            ii = directives.length;
          } else {
            $compileNode.html(directiveValue);
          }
        }

        if (directive.templateUrl) {
          hasTemplate = true;
          assertNoDuplicate('template', templateDirective, directive, $compileNode);
          templateDirective = directive;

          if (directive.replace) {
            replaceDirective = directive;
          }

          nodeLinkFn = compileTemplateUrl(directives.splice(i, directives.length - i), $compileNode,
              templateAttrs, jqCollection, hasTranscludeDirective && childTranscludeFn, preLinkFns, postLinkFns, {
                controllerDirectives: controllerDirectives,
                newIsolateScopeDirective: newIsolateScopeDirective,
                templateDirective: templateDirective,
                nonTlbTranscludeDirective: nonTlbTranscludeDirective
              });
          ii = directives.length;
        } else if (directive.compile) {
          try {
            linkFn = directive.compile($compileNode, templateAttrs, childTranscludeFn);
            if (isFunction(linkFn)) {
              addLinkFns(null, linkFn, attrStart, attrEnd);
            } else if (linkFn) {
              addLinkFns(linkFn.pre, linkFn.post, attrStart, attrEnd);
            }
          } catch (e) {
            $exceptionHandler(e, startingTag($compileNode));
          }
        }

        if (directive.terminal) {
          nodeLinkFn.terminal = true;
          terminalPriority = Math.max(terminalPriority, directive.priority);
        }

      }

      nodeLinkFn.scope = newScopeDirective && newScopeDirective.scope === true;
      nodeLinkFn.transcludeOnThisElement = hasTranscludeDirective;
      nodeLinkFn.elementTranscludeOnThisElement = hasElementTranscludeDirective;
      nodeLinkFn.templateOnThisElement = hasTemplate;
      nodeLinkFn.transclude = childTranscludeFn;

      previousCompileContext.hasElementTranscludeDirective = hasElementTranscludeDirective;

      // might be normal or delayed nodeLinkFn depending on if templateUrl is present
      return nodeLinkFn;

      ////////////////////

      function addLinkFns(pre, post, attrStart, attrEnd) {
        if (pre) {
          if (attrStart) pre = groupElementsLinkFnWrapper(pre, attrStart, attrEnd);
          pre.require = directive.require;
          pre.directiveName = directiveName;
          if (newIsolateScopeDirective === directive || directive.$$isolateScope) {
            pre = cloneAndAnnotateFn(pre, {isolateScope: true});
          }
          preLinkFns.push(pre);
        }
        if (post) {
          if (attrStart) post = groupElementsLinkFnWrapper(post, attrStart, attrEnd);
          post.require = directive.require;
          post.directiveName = directiveName;
          if (newIsolateScopeDirective === directive || directive.$$isolateScope) {
            post = cloneAndAnnotateFn(post, {isolateScope: true});
          }
          postLinkFns.push(post);
        }
      }


      function getControllers(directiveName, require, $element, elementControllers) {
        var value, retrievalMethod = 'data', optional = false;
        var $searchElement = $element;
        var match;
        if (isString(require)) {
          match = require.match(REQUIRE_PREFIX_REGEXP);
          require = require.substring(match[0].length);

          if (match[3]) {
            if (match[1]) match[3] = null;
            else match[1] = match[3];
          }
          if (match[1] === '^') {
            retrievalMethod = 'inheritedData';
          } else if (match[1] === '^^') {
            retrievalMethod = 'inheritedData';
            $searchElement = $element.parent();
          }
          if (match[2] === '?') {
            optional = true;
          }

          value = null;

          if (elementControllers && retrievalMethod === 'data') {
            if (value = elementControllers[require]) {
              value = value.instance;
            }
          }
          value = value || $searchElement[retrievalMethod]('$' + require + 'Controller');

          if (!value && !optional) {
            throw $compileMinErr('ctreq',
                "Controller '{0}', required by directive '{1}', can't be found!",
                require, directiveName);
          }
          return value || null;
        } else if (isArray(require)) {
          value = [];
          forEach(require, function(require) {
            value.push(getControllers(directiveName, require, $element, elementControllers));
          });
        }
        return value;
      }


      function nodeLinkFn(childLinkFn, scope, linkNode, $rootElement, boundTranscludeFn) {
        var i, ii, linkFn, controller, isolateScope, elementControllers, transcludeFn, $element,
            attrs;

        if (compileNode === linkNode) {
          attrs = templateAttrs;
          $element = templateAttrs.$$element;
        } else {
          $element = jqLite(linkNode);
          attrs = new Attributes($element, templateAttrs);
        }

        if (newIsolateScopeDirective) {
          isolateScope = scope.$new(true);
        }

        if (boundTranscludeFn) {
          // track `boundTranscludeFn` so it can be unwrapped if `transcludeFn`
          // is later passed as `parentBoundTranscludeFn` to `publicLinkFn`
          transcludeFn = controllersBoundTransclude;
          transcludeFn.$$boundTransclude = boundTranscludeFn;
        }

        if (controllerDirectives) {
          // TODO: merge `controllers` and `elementControllers` into single object.
          controllers = {};
          elementControllers = {};
          forEach(controllerDirectives, function(directive) {
            var locals = {
              $scope: directive === newIsolateScopeDirective || directive.$$isolateScope ? isolateScope : scope,
              $element: $element,
              $attrs: attrs,
              $transclude: transcludeFn
            }, controllerInstance;

            controller = directive.controller;
            if (controller == '@') {
              controller = attrs[directive.name];
            }

            controllerInstance = $controller(controller, locals, true, directive.controllerAs);

            // For directives with element transclusion the element is a comment,
            // but jQuery .data doesn't support attaching data to comment nodes as it's hard to
            // clean up (http://bugs.jquery.com/ticket/8335).
            // Instead, we save the controllers for the element in a local hash and attach to .data
            // later, once we have the actual element.
            elementControllers[directive.name] = controllerInstance;
            if (!hasElementTranscludeDirective) {
              $element.data('$' + directive.name + 'Controller', controllerInstance.instance);
            }

            controllers[directive.name] = controllerInstance;
          });
        }

        if (newIsolateScopeDirective) {
          compile.$$addScopeInfo($element, isolateScope, true, !(templateDirective && (templateDirective === newIsolateScopeDirective ||
              templateDirective === newIsolateScopeDirective.$$originalDirective)));
          compile.$$addScopeClass($element, true);

          var isolateScopeController = controllers && controllers[newIsolateScopeDirective.name];
          var isolateBindingContext = isolateScope;
          if (isolateScopeController && isolateScopeController.identifier &&
              newIsolateScopeDirective.bindToController === true) {
            isolateBindingContext = isolateScopeController.instance;
          }

          forEach(isolateScope.$$isolateBindings = newIsolateScopeDirective.$$isolateBindings, function(definition, scopeName) {
            var attrName = definition.attrName,
                optional = definition.optional,
                mode = definition.mode, // @, =, or &
                lastValue,
                parentGet, parentSet, compare;

            switch (mode) {

              case '@':
                attrs.$observe(attrName, function(value) {
                  isolateBindingContext[scopeName] = value;
                });
                attrs.$$observers[attrName].$$scope = scope;
                if (attrs[attrName]) {
                  // If the attribute has been provided then we trigger an interpolation to ensure
                  // the value is there for use in the link fn
                  isolateBindingContext[scopeName] = $interpolate(attrs[attrName])(scope);
                }
                break;

              case '=':
                if (optional && !attrs[attrName]) {
                  return;
                }
                parentGet = $parse(attrs[attrName]);
                if (parentGet.literal) {
                  compare = equals;
                } else {
                  compare = function(a, b) { return a === b || (a !== a && b !== b); };
                }
                parentSet = parentGet.assign || function() {
                  // reset the change, or we will throw this exception on every $digest
                  lastValue = isolateBindingContext[scopeName] = parentGet(scope);
                  throw $compileMinErr('nonassign',
                      "Expression '{0}' used with directive '{1}' is non-assignable!",
                      attrs[attrName], newIsolateScopeDirective.name);
                };
                lastValue = isolateBindingContext[scopeName] = parentGet(scope);
                var parentValueWatch = function parentValueWatch(parentValue) {
                  if (!compare(parentValue, isolateBindingContext[scopeName])) {
                    // we are out of sync and need to copy
                    if (!compare(parentValue, lastValue)) {
                      // parent changed and it has precedence
                      isolateBindingContext[scopeName] = parentValue;
                    } else {
                      // if the parent can be assigned then do so
                      parentSet(scope, parentValue = isolateBindingContext[scopeName]);
                    }
                  }
                  return lastValue = parentValue;
                };
                parentValueWatch.$stateful = true;
                var unwatch;
                if (definition.collection) {
                  unwatch = scope.$watchCollection(attrs[attrName], parentValueWatch);
                } else {
                  unwatch = scope.$watch($parse(attrs[attrName], parentValueWatch), null, parentGet.literal);
                }
                isolateScope.$on('$destroy', unwatch);
                break;

              case '&':
                parentGet = $parse(attrs[attrName]);
                isolateBindingContext[scopeName] = function(locals) {
                  return parentGet(scope, locals);
                };
                break;
            }
          });
        }
        if (controllers) {
          forEach(controllers, function(controller) {
            controller();
          });
          controllers = null;
        }

        // PRELINKING
        for (i = 0, ii = preLinkFns.length; i < ii; i++) {
          linkFn = preLinkFns[i];
          invokeLinkFn(linkFn,
              linkFn.isolateScope ? isolateScope : scope,
              $element,
              attrs,
              linkFn.require && getControllers(linkFn.directiveName, linkFn.require, $element, elementControllers),
              transcludeFn
          );
        }

        // RECURSION
        // We only pass the isolate scope, if the isolate directive has a template,
        // otherwise the child elements do not belong to the isolate directive.
        var scopeToChild = scope;
        if (newIsolateScopeDirective && (newIsolateScopeDirective.template || newIsolateScopeDirective.templateUrl === null)) {
          scopeToChild = isolateScope;
        }
        childLinkFn && childLinkFn(scopeToChild, linkNode.childNodes, undefined, boundTranscludeFn);

        // POSTLINKING
        for (i = postLinkFns.length - 1; i >= 0; i--) {
          linkFn = postLinkFns[i];
          invokeLinkFn(linkFn,
              linkFn.isolateScope ? isolateScope : scope,
              $element,
              attrs,
              linkFn.require && getControllers(linkFn.directiveName, linkFn.require, $element, elementControllers),
              transcludeFn
          );
        }

        // This is the function that is injected as `$transclude`.
        // Note: all arguments are optional!
        function controllersBoundTransclude(scope, cloneAttachFn, futureParentElement) {
          var transcludeControllers;

          // No scope passed in:
          if (!isScope(scope)) {
            futureParentElement = cloneAttachFn;
            cloneAttachFn = scope;
            scope = undefined;
          }

          if (hasElementTranscludeDirective) {
            transcludeControllers = elementControllers;
          }
          if (!futureParentElement) {
            futureParentElement = hasElementTranscludeDirective ? $element.parent() : $element;
          }
          return boundTranscludeFn(scope, cloneAttachFn, transcludeControllers, futureParentElement, scopeToChild);
        }
      }
    }

    function markDirectivesAsIsolate(directives) {
      // mark all directives as needing isolate scope.
      for (var j = 0, jj = directives.length; j < jj; j++) {
        directives[j] = inherit(directives[j], {$$isolateScope: true});
      }
    }

    /**
     * looks up the directive and decorates it with exception handling and proper parameters. We
     * call this the boundDirective.
     *
     * @param {string} name name of the directive to look up.
     * @param {string} location The directive must be found in specific format.
     *   String containing any of theses characters:
     *
     *   * `E`: element name
     *   * `A': attribute
     *   * `C`: class
     *   * `M`: comment
     * @returns {boolean} true if directive was added.
     */
    function addDirective(tDirectives, name, location, maxPriority, ignoreDirective, startAttrName,
                          endAttrName) {
      if (name === ignoreDirective) return null;
      var match = null;
      if (hasDirectives.hasOwnProperty(name)) {
        for (var directive, directives = $injector.get(name + Suffix),
            i = 0, ii = directives.length; i < ii; i++) {
          try {
            directive = directives[i];
            if ((maxPriority === undefined || maxPriority > directive.priority) &&
                 directive.restrict.indexOf(location) != -1) {
              if (startAttrName) {
                directive = inherit(directive, {$$start: startAttrName, $$end: endAttrName});
              }
              tDirectives.push(directive);
              match = directive;
            }
          } catch (e) { $exceptionHandler(e); }
        }
      }
      return match;
    }


    /**
     * looks up the directive and returns true if it is a multi-element directive,
     * and therefore requires DOM nodes between -start and -end markers to be grouped
     * together.
     *
     * @param {string} name name of the directive to look up.
     * @returns true if directive was registered as multi-element.
     */
    function directiveIsMultiElement(name) {
      if (hasDirectives.hasOwnProperty(name)) {
        for (var directive, directives = $injector.get(name + Suffix),
            i = 0, ii = directives.length; i < ii; i++) {
          directive = directives[i];
          if (directive.multiElement) {
            return true;
          }
        }
      }
      return false;
    }

    /**
     * When the element is replaced with HTML template then the new attributes
     * on the template need to be merged with the existing attributes in the DOM.
     * The desired effect is to have both of the attributes present.
     *
     * @param {object} dst destination attributes (original DOM)
     * @param {object} src source attributes (from the directive template)
     */
    function mergeTemplateAttributes(dst, src) {
      var srcAttr = src.$attr,
          dstAttr = dst.$attr,
          $element = dst.$$element;

      // reapply the old attributes to the new element
      forEach(dst, function(value, key) {
        if (key.charAt(0) != '$') {
          if (src[key] && src[key] !== value) {
            value += (key === 'style' ? ';' : ' ') + src[key];
          }
          dst.$set(key, value, true, srcAttr[key]);
        }
      });

      // copy the new attributes on the old attrs object
      forEach(src, function(value, key) {
        if (key == 'class') {
          safeAddClass($element, value);
          dst['class'] = (dst['class'] ? dst['class'] + ' ' : '') + value;
        } else if (key == 'style') {
          $element.attr('style', $element.attr('style') + ';' + value);
          dst['style'] = (dst['style'] ? dst['style'] + ';' : '') + value;
          // `dst` will never contain hasOwnProperty as DOM parser won't let it.
          // You will get an "InvalidCharacterError: DOM Exception 5" error if you
          // have an attribute like "has-own-property" or "data-has-own-property", etc.
        } else if (key.charAt(0) != '$' && !dst.hasOwnProperty(key)) {
          dst[key] = value;
          dstAttr[key] = srcAttr[key];
        }
      });
    }


    function compileTemplateUrl(directives, $compileNode, tAttrs,
        $rootElement, childTranscludeFn, preLinkFns, postLinkFns, previousCompileContext) {
      var linkQueue = [],
          afterTemplateNodeLinkFn,
          afterTemplateChildLinkFn,
          beforeTemplateCompileNode = $compileNode[0],
          origAsyncDirective = directives.shift(),
          derivedSyncDirective = inherit(origAsyncDirective, {
            templateUrl: null, transclude: null, replace: null, $$originalDirective: origAsyncDirective
          }),
          templateUrl = (isFunction(origAsyncDirective.templateUrl))
              ? origAsyncDirective.templateUrl($compileNode, tAttrs)
              : origAsyncDirective.templateUrl,
          templateNamespace = origAsyncDirective.templateNamespace;

      $compileNode.empty();

      $templateRequest(templateUrl)
        .then(function(content) {
          var compileNode, tempTemplateAttrs, $template, childBoundTranscludeFn;

          content = denormalizeTemplate(content);

          if (origAsyncDirective.replace) {
            if (jqLiteIsTextNode(content)) {
              $template = [];
            } else {
              $template = removeComments(wrapTemplate(templateNamespace, trim(content)));
            }
            compileNode = $template[0];

            if ($template.length != 1 || compileNode.nodeType !== NODE_TYPE_ELEMENT) {
              throw $compileMinErr('tplrt',
                  "Template for directive '{0}' must have exactly one root element. {1}",
                  origAsyncDirective.name, templateUrl);
            }

            tempTemplateAttrs = {$attr: {}};
            replaceWith($rootElement, $compileNode, compileNode);
            var templateDirectives = collectDirectives(compileNode, [], tempTemplateAttrs);

            if (isObject(origAsyncDirective.scope)) {
              markDirectivesAsIsolate(templateDirectives);
            }
            directives = templateDirectives.concat(directives);
            mergeTemplateAttributes(tAttrs, tempTemplateAttrs);
          } else {
            compileNode = beforeTemplateCompileNode;
            $compileNode.html(content);
          }

          directives.unshift(derivedSyncDirective);

          afterTemplateNodeLinkFn = applyDirectivesToNode(directives, compileNode, tAttrs,
              childTranscludeFn, $compileNode, origAsyncDirective, preLinkFns, postLinkFns,
              previousCompileContext);
          forEach($rootElement, function(node, i) {
            if (node == compileNode) {
              $rootElement[i] = $compileNode[0];
            }
          });
          afterTemplateChildLinkFn = compileNodes($compileNode[0].childNodes, childTranscludeFn);

          while (linkQueue.length) {
            var scope = linkQueue.shift(),
                beforeTemplateLinkNode = linkQueue.shift(),
                linkRootElement = linkQueue.shift(),
                boundTranscludeFn = linkQueue.shift(),
                linkNode = $compileNode[0];

            if (scope.$$destroyed) continue;

            if (beforeTemplateLinkNode !== beforeTemplateCompileNode) {
              var oldClasses = beforeTemplateLinkNode.className;

              if (!(previousCompileContext.hasElementTranscludeDirective &&
                  origAsyncDirective.replace)) {
                // it was cloned therefore we have to clone as well.
                linkNode = jqLiteClone(compileNode);
              }
              replaceWith(linkRootElement, jqLite(beforeTemplateLinkNode), linkNode);

              // Copy in CSS classes from original node
              safeAddClass(jqLite(linkNode), oldClasses);
            }
            if (afterTemplateNodeLinkFn.transcludeOnThisElement) {
              childBoundTranscludeFn = createBoundTranscludeFn(scope, afterTemplateNodeLinkFn.transclude, boundTranscludeFn);
            } else {
              childBoundTranscludeFn = boundTranscludeFn;
            }
            afterTemplateNodeLinkFn(afterTemplateChildLinkFn, scope, linkNode, $rootElement,
              childBoundTranscludeFn);
          }
          linkQueue = null;
        });

      return function delayedNodeLinkFn(ignoreChildLinkFn, scope, node, rootElement, boundTranscludeFn) {
        var childBoundTranscludeFn = boundTranscludeFn;
        if (scope.$$destroyed) return;
        if (linkQueue) {
          linkQueue.push(scope,
                         node,
                         rootElement,
                         childBoundTranscludeFn);
        } else {
          if (afterTemplateNodeLinkFn.transcludeOnThisElement) {
            childBoundTranscludeFn = createBoundTranscludeFn(scope, afterTemplateNodeLinkFn.transclude, boundTranscludeFn);
          }
          afterTemplateNodeLinkFn(afterTemplateChildLinkFn, scope, node, rootElement, childBoundTranscludeFn);
        }
      };
    }


    /**
     * Sorting function for bound directives.
     */
    function byPriority(a, b) {
      var diff = b.priority - a.priority;
      if (diff !== 0) return diff;
      if (a.name !== b.name) return (a.name < b.name) ? -1 : 1;
      return a.index - b.index;
    }


    function assertNoDuplicate(what, previousDirective, directive, element) {
      if (previousDirective) {
        throw $compileMinErr('multidir', 'Multiple directives [{0}, {1}] asking for {2} on: {3}',
            previousDirective.name, directive.name, what, startingTag(element));
      }
    }


    function addTextInterpolateDirective(directives, text) {
      var interpolateFn = $interpolate(text, true);
      if (interpolateFn) {
        directives.push({
          priority: 0,
          compile: function textInterpolateCompileFn(templateNode) {
            var templateNodeParent = templateNode.parent(),
                hasCompileParent = !!templateNodeParent.length;

            // When transcluding a template that has bindings in the root
            // we don't have a parent and thus need to add the class during linking fn.
            if (hasCompileParent) compile.$$addBindingClass(templateNodeParent);

            return function textInterpolateLinkFn(scope, node) {
              var parent = node.parent();
              if (!hasCompileParent) compile.$$addBindingClass(parent);
              compile.$$addBindingInfo(parent, interpolateFn.expressions);
              scope.$watch(interpolateFn, function interpolateFnWatchAction(value) {
                node[0].nodeValue = value;
              });
            };
          }
        });
      }
    }


    function wrapTemplate(type, template) {
      type = lowercase(type || 'html');
      switch (type) {
      case 'svg':
      case 'math':
        var wrapper = document.createElement('div');
        wrapper.innerHTML = '<' + type + '>' + template + '</' + type + '>';
        return wrapper.childNodes[0].childNodes;
      default:
        return template;
      }
    }


    function getTrustedContext(node, attrNormalizedName) {
      if (attrNormalizedName == "srcdoc") {
        return $sce.HTML;
      }
      var tag = nodeName_(node);
      // maction[xlink:href] can source SVG.  It's not limited to <maction>.
      if (attrNormalizedName == "xlinkHref" ||
          (tag == "form" && attrNormalizedName == "action") ||
          (tag != "img" && (attrNormalizedName == "src" ||
                            attrNormalizedName == "ngSrc"))) {
        return $sce.RESOURCE_URL;
      }
    }


    function addAttrInterpolateDirective(node, directives, value, name, allOrNothing) {
      var trustedContext = getTrustedContext(node, name);
      allOrNothing = ALL_OR_NOTHING_ATTRS[name] || allOrNothing;

      var interpolateFn = $interpolate(value, true, trustedContext, allOrNothing);

      // no interpolation found -> ignore
      if (!interpolateFn) return;


      if (name === "multiple" && nodeName_(node) === "select") {
        throw $compileMinErr("selmulti",
            "Binding to the 'multiple' attribute is not supported. Element: {0}",
            startingTag(node));
      }

      directives.push({
        priority: 100,
        compile: function() {
            return {
              pre: function attrInterpolatePreLinkFn(scope, element, attr) {
                var $$observers = (attr.$$observers || (attr.$$observers = {}));

                if (EVENT_HANDLER_ATTR_REGEXP.test(name)) {
                  throw $compileMinErr('nodomevents',
                      "Interpolations for HTML DOM event attributes are disallowed.  Please use the " +
                          "ng- versions (such as ng-click instead of onclick) instead.");
                }

                // If the attribute has changed since last $interpolate()ed
                var newValue = attr[name];
                if (newValue !== value) {
                  // we need to interpolate again since the attribute value has been updated
                  // (e.g. by another directive's compile function)
                  // ensure unset/empty values make interpolateFn falsy
                  interpolateFn = newValue && $interpolate(newValue, true, trustedContext, allOrNothing);
                  value = newValue;
                }

                // if attribute was updated so that there is no interpolation going on we don't want to
                // register any observers
                if (!interpolateFn) return;

                // initialize attr object so that it's ready in case we need the value for isolate
                // scope initialization, otherwise the value would not be available from isolate
                // directive's linking fn during linking phase
                attr[name] = interpolateFn(scope);

                ($$observers[name] || ($$observers[name] = [])).$$inter = true;
                (attr.$$observers && attr.$$observers[name].$$scope || scope).
                  $watch(interpolateFn, function interpolateFnWatchAction(newValue, oldValue) {
                    //special case for class attribute addition + removal
                    //so that class changes can tap into the animation
                    //hooks provided by the $animate service. Be sure to
                    //skip animations when the first digest occurs (when
                    //both the new and the old values are the same) since
                    //the CSS classes are the non-interpolated values
                    if (name === 'class' && newValue != oldValue) {
                      attr.$updateClass(newValue, oldValue);
                    } else {
                      attr.$set(name, newValue);
                    }
                  });
              }
            };
          }
      });
    }


    /**
     * This is a special jqLite.replaceWith, which can replace items which
     * have no parents, provided that the containing jqLite collection is provided.
     *
     * @param {JqLite=} $rootElement The root of the compile tree. Used so that we can replace nodes
     *                               in the root of the tree.
     * @param {JqLite} elementsToRemove The jqLite element which we are going to replace. We keep
     *                                  the shell, but replace its DOM node reference.
     * @param {Node} newNode The new DOM node.
     */
    function replaceWith($rootElement, elementsToRemove, newNode) {
      var firstElementToRemove = elementsToRemove[0],
          removeCount = elementsToRemove.length,
          parent = firstElementToRemove.parentNode,
          i, ii;

      if ($rootElement) {
        for (i = 0, ii = $rootElement.length; i < ii; i++) {
          if ($rootElement[i] == firstElementToRemove) {
            $rootElement[i++] = newNode;
            for (var j = i, j2 = j + removeCount - 1,
                     jj = $rootElement.length;
                 j < jj; j++, j2++) {
              if (j2 < jj) {
                $rootElement[j] = $rootElement[j2];
              } else {
                delete $rootElement[j];
              }
            }
            $rootElement.length -= removeCount - 1;

            // If the replaced element is also the jQuery .context then replace it
            // .context is a deprecated jQuery api, so we should set it only when jQuery set it
            // http://api.jquery.com/context/
            if ($rootElement.context === firstElementToRemove) {
              $rootElement.context = newNode;
            }
            break;
          }
        }
      }

      if (parent) {
        parent.replaceChild(newNode, firstElementToRemove);
      }

      // TODO(perf): what's this document fragment for? is it needed? can we at least reuse it?
      var fragment = document.createDocumentFragment();
      fragment.appendChild(firstElementToRemove);

      // Copy over user data (that includes Angular's $scope etc.). Don't copy private
      // data here because there's no public interface in jQuery to do that and copying over
      // event listeners (which is the main use of private data) wouldn't work anyway.
      jqLite(newNode).data(jqLite(firstElementToRemove).data());

      // Remove data of the replaced element. We cannot just call .remove()
      // on the element it since that would deallocate scope that is needed
      // for the new node. Instead, remove the data "manually".
      if (!jQuery) {
        delete jqLite.cache[firstElementToRemove[jqLite.expando]];
      } else {
        // jQuery 2.x doesn't expose the data storage. Use jQuery.cleanData to clean up after
        // the replaced element. The cleanData version monkey-patched by Angular would cause
        // the scope to be trashed and we do need the very same scope to work with the new
        // element. However, we cannot just cache the non-patched version and use it here as
        // that would break if another library patches the method after Angular does (one
        // example is jQuery UI). Instead, set a flag indicating scope destroying should be
        // skipped this one time.
        skipDestroyOnNextJQueryCleanData = true;
        jQuery.cleanData([firstElementToRemove]);
      }

      for (var k = 1, kk = elementsToRemove.length; k < kk; k++) {
        var element = elementsToRemove[k];
        jqLite(element).remove(); // must do this way to clean up expando
        fragment.appendChild(element);
        delete elementsToRemove[k];
      }

      elementsToRemove[0] = newNode;
      elementsToRemove.length = 1;
    }


    function cloneAndAnnotateFn(fn, annotation) {
      return extend(function() { return fn.apply(null, arguments); }, fn, annotation);
    }


    function invokeLinkFn(linkFn, scope, $element, attrs, controllers, transcludeFn) {
      try {
        linkFn(scope, $element, attrs, controllers, transcludeFn);
      } catch (e) {
        $exceptionHandler(e, startingTag($element));
      }
    }
  }];
}

var PREFIX_REGEXP = /^((?:x|data)[\:\-_])/i;
/**
 * Converts all accepted directives format into proper directive name.
 * @param name Name to normalize
 */
function directiveNormalize(name) {
  return camelCase(name.replace(PREFIX_REGEXP, ''));
}

/**
 * @ngdoc type
 * @name $compile.directive.Attributes
 *
 * @description
 * A shared object between directive compile / linking functions which contains normalized DOM
 * element attributes. The values reflect current binding state `{{ }}`. The normalization is
 * needed since all of these are treated as equivalent in Angular:
 *
 * ```
 *    <span ng:bind="a" ng-bind="a" data-ng-bind="a" x-ng-bind="a">
 * ```
 */

/**
 * @ngdoc property
 * @name $compile.directive.Attributes#$attr
 *
 * @description
 * A map of DOM element attribute names to the normalized name. This is
 * needed to do reverse lookup from normalized name back to actual name.
 */


/**
 * @ngdoc method
 * @name $compile.directive.Attributes#$set
 * @kind function
 *
 * @description
 * Set DOM element attribute value.
 *
 *
 * @param {string} name Normalized element attribute name of the property to modify. The name is
 *          reverse-translated using the {@link ng.$compile.directive.Attributes#$attr $attr}
 *          property to the original name.
 * @param {string} value Value to set the attribute to. The value can be an interpolated string.
 */



/**
 * Closure compiler type information
 */

function nodesetLinkingFn(
  /* angular.Scope */ scope,
  /* NodeList */ nodeList,
  /* Element */ rootElement,
  /* function(Function) */ boundTranscludeFn
) {}

function directiveLinkingFn(
  /* nodesetLinkingFn */ nodesetLinkingFn,
  /* angular.Scope */ scope,
  /* Node */ node,
  /* Element */ rootElement,
  /* function(Function) */ boundTranscludeFn
) {}

function tokenDifference(str1, str2) {
  var values = '',
      tokens1 = str1.split(/\s+/),
      tokens2 = str2.split(/\s+/);

  outer:
  for (var i = 0; i < tokens1.length; i++) {
    var token = tokens1[i];
    for (var j = 0; j < tokens2.length; j++) {
      if (token == tokens2[j]) continue outer;
    }
    values += (values.length > 0 ? ' ' : '') + token;
  }
  return values;
}

function removeComments(jqNodes) {
  jqNodes = jqLite(jqNodes);
  var i = jqNodes.length;

  if (i <= 1) {
    return jqNodes;
  }

  while (i--) {
    var node = jqNodes[i];
    if (node.nodeType === NODE_TYPE_COMMENT) {
      splice.call(jqNodes, i, 1);
    }
  }
  return jqNodes;
}

var $controllerMinErr = minErr('$controller');

/**
 * @ngdoc provider
 * @name $controllerProvider
 * @description
 * The {@link ng.$controller $controller service} is used by Angular to create new
 * controllers.
 *
 * This provider allows controller registration via the
 * {@link ng.$controllerProvider#register register} method.
 */
function $ControllerProvider() {
  var controllers = {},
      globals = false,
      CNTRL_REG = /^(\S+)(\s+as\s+(\w+))?$/;


  /**
   * @ngdoc method
   * @name $controllerProvider#register
   * @param {string|Object} name Controller name, or an object map of controllers where the keys are
   *    the names and the values are the constructors.
   * @param {Function|Array} constructor Controller constructor fn (optionally decorated with DI
   *    annotations in the array notation).
   */
  this.register = function(name, constructor) {
    assertNotHasOwnProperty(name, 'controller');
    if (isObject(name)) {
      extend(controllers, name);
    } else {
      controllers[name] = constructor;
    }
  };

  /**
   * @ngdoc method
   * @name $controllerProvider#allowGlobals
   * @description If called, allows `$controller` to find controller constructors on `window`
   */
  this.allowGlobals = function() {
    globals = true;
  };


  this.$get = ['$injector', '$window', function($injector, $window) {

    /**
     * @ngdoc service
     * @name $controller
     * @requires $injector
     *
     * @param {Function|string} constructor If called with a function then it's considered to be the
     *    controller constructor function. Otherwise it's considered to be a string which is used
     *    to retrieve the controller constructor using the following steps:
     *
     *    * check if a controller with given name is registered via `$controllerProvider`
     *    * check if evaluating the string on the current scope returns a constructor
     *    * if $controllerProvider#allowGlobals, check `window[constructor]` on the global
     *      `window` object (not recommended)
     *
     *    The string can use the `controller as property` syntax, where the controller instance is published
     *    as the specified property on the `scope`; the `scope` must be injected into `locals` param for this
     *    to work correctly.
     *
     * @param {Object} locals Injection locals for Controller.
     * @return {Object} Instance of given controller.
     *
     * @description
     * `$controller` service is responsible for instantiating controllers.
     *
     * It's just a simple call to {@link auto.$injector $injector}, but extracted into
     * a service, so that one can override this service with [BC version](https://gist.github.com/1649788).
     */
    return function(expression, locals, later, ident) {
      // PRIVATE API:
      //   param `later` --- indicates that the controller's constructor is invoked at a later time.
      //                     If true, $controller will allocate the object with the correct
      //                     prototype chain, but will not invoke the controller until a returned
      //                     callback is invoked.
      //   param `ident` --- An optional label which overrides the label parsed from the controller
      //                     expression, if any.
      var instance, match, constructor, identifier;
      later = later === true;
      if (ident && isString(ident)) {
        identifier = ident;
      }

      if (isString(expression)) {
        match = expression.match(CNTRL_REG);
        if (!match) {
          throw $controllerMinErr('ctrlfmt',
            "Badly formed controller string '{0}'. " +
            "Must match `__name__ as __id__` or `__name__`.", expression);
        }
        constructor = match[1],
        identifier = identifier || match[3];
        expression = controllers.hasOwnProperty(constructor)
            ? controllers[constructor]
            : getter(locals.$scope, constructor, true) ||
                (globals ? getter($window, constructor, true) : undefined);

        assertArgFn(expression, constructor, true);
      }

      if (later) {
        // Instantiate controller later:
        // This machinery is used to create an instance of the object before calling the
        // controller's constructor itself.
        //
        // This allows properties to be added to the controller before the constructor is
        // invoked. Primarily, this is used for isolate scope bindings in $compile.
        //
        // This feature is not intended for use by applications, and is thus not documented
        // publicly.
        // Object creation: http://jsperf.com/create-constructor/2
        var controllerPrototype = (isArray(expression) ?
          expression[expression.length - 1] : expression).prototype;
        instance = Object.create(controllerPrototype || null);

        if (identifier) {
          addIdentifier(locals, identifier, instance, constructor || expression.name);
        }

        return extend(function() {
          $injector.invoke(expression, instance, locals, constructor);
          return instance;
        }, {
          instance: instance,
          identifier: identifier
        });
      }

      instance = $injector.instantiate(expression, locals, constructor);

      if (identifier) {
        addIdentifier(locals, identifier, instance, constructor || expression.name);
      }

      return instance;
    };

    function addIdentifier(locals, identifier, instance, name) {
      if (!(locals && isObject(locals.$scope))) {
        throw minErr('$controller')('noscp',
          "Cannot export controller '{0}' as '{1}'! No $scope object provided via `locals`.",
          name, identifier);
      }

      locals.$scope[identifier] = instance;
    }
  }];
}

/**
 * @ngdoc service
 * @name $document
 * @requires $window
 *
 * @description
 * A {@link angular.element jQuery or jqLite} wrapper for the browser's `window.document` object.
 *
 * @example
   <example module="documentExample">
     <file name="index.html">
       <div ng-controller="ExampleController">
         <p>$document title: <b ng-bind="title"></b></p>
         <p>window.document title: <b ng-bind="windowTitle"></b></p>
       </div>
     </file>
     <file name="script.js">
       angular.module('documentExample', [])
         .controller('ExampleController', ['$scope', '$document', function($scope, $document) {
           $scope.title = $document[0].title;
           $scope.windowTitle = angular.element(window.document)[0].title;
         }]);
     </file>
   </example>
 */
function $DocumentProvider() {
  this.$get = ['$window', function(window) {
    return jqLite(window.document);
  }];
}

/**
 * @ngdoc service
 * @name $exceptionHandler
 * @requires ng.$log
 *
 * @description
 * Any uncaught exception in angular expressions is delegated to this service.
 * The default implementation simply delegates to `$log.error` which logs it into
 * the browser console.
 *
 * In unit tests, if `angular-mocks.js` is loaded, this service is overridden by
 * {@link ngMock.$exceptionHandler mock $exceptionHandler} which aids in testing.
 *
 * ## Example:
 *
 * ```js
 *   angular.module('exceptionOverride', []).factory('$exceptionHandler', function() {
 *     return function(exception, cause) {
 *       exception.message += ' (caused by "' + cause + '")';
 *       throw exception;
 *     };
 *   });
 * ```
 *
 * This example will override the normal action of `$exceptionHandler`, to make angular
 * exceptions fail hard when they happen, instead of just logging to the console.
 *
 * <hr />
 * Note, that code executed in event-listeners (even those registered using jqLite's `on`/`bind`
 * methods) does not delegate exceptions to the {@link ng.$exceptionHandler $exceptionHandler}
 * (unless executed during a digest).
 *
 * If you wish, you can manually delegate exceptions, e.g.
 * `try { ... } catch(e) { $exceptionHandler(e); }`
 *
 * @param {Error} exception Exception associated with the error.
 * @param {string=} cause optional information about the context in which
 *       the error was thrown.
 *
 */
function $ExceptionHandlerProvider() {
  this.$get = ['$log', function($log) {
    return function(exception, cause) {
      $log.error.apply($log, arguments);
    };
  }];
}

var APPLICATION_JSON = 'application/json';
var CONTENT_TYPE_APPLICATION_JSON = {'Content-Type': APPLICATION_JSON + ';charset=utf-8'};
var JSON_START = /^\[|^\{(?!\{)/;
var JSON_ENDS = {
  '[': /]$/,
  '{': /}$/
};
var JSON_PROTECTION_PREFIX = /^\)\]\}',?\n/;

function defaultHttpResponseTransform(data, headers) {
  if (isString(data)) {
    // Strip json vulnerability protection prefix and trim whitespace
    var tempData = data.replace(JSON_PROTECTION_PREFIX, '').trim();

    if (tempData) {
      var contentType = headers('Content-Type');
      if ((contentType && (contentType.indexOf(APPLICATION_JSON) === 0)) || isJsonLike(tempData)) {
        data = fromJson(tempData);
      }
    }
  }

  return data;
}

function isJsonLike(str) {
    var jsonStart = str.match(JSON_START);
    return jsonStart && JSON_ENDS[jsonStart[0]].test(str);
}

/**
 * Parse headers into key value object
 *
 * @param {string} headers Raw headers as a string
 * @returns {Object} Parsed headers as key value object
 */
function parseHeaders(headers) {
  var parsed = createMap(), key, val, i;

  if (!headers) return parsed;

  forEach(headers.split('\n'), function(line) {
    i = line.indexOf(':');
    key = lowercase(trim(line.substr(0, i)));
    val = trim(line.substr(i + 1));

    if (key) {
      parsed[key] = parsed[key] ? parsed[key] + ', ' + val : val;
    }
  });

  return parsed;
}


/**
 * Returns a function that provides access to parsed headers.
 *
 * Headers are lazy parsed when first requested.
 * @see parseHeaders
 *
 * @param {(string|Object)} headers Headers to provide access to.
 * @returns {function(string=)} Returns a getter function which if called with:
 *
 *   - if called with single an argument returns a single header value or null
 *   - if called with no arguments returns an object containing all headers.
 */
function headersGetter(headers) {
  var headersObj = isObject(headers) ? headers : undefined;

  return function(name) {
    if (!headersObj) headersObj =  parseHeaders(headers);

    if (name) {
      var value = headersObj[lowercase(name)];
      if (value === void 0) {
        value = null;
      }
      return value;
    }

    return headersObj;
  };
}


/**
 * Chain all given functions
 *
 * This function is used for both request and response transforming
 *
 * @param {*} data Data to transform.
 * @param {function(string=)} headers HTTP headers getter fn.
 * @param {number} status HTTP status code of the response.
 * @param {(Function|Array.<Function>)} fns Function or an array of functions.
 * @returns {*} Transformed data.
 */
function transformData(data, headers, status, fns) {
  if (isFunction(fns))
    return fns(data, headers, status);

  forEach(fns, function(fn) {
    data = fn(data, headers, status);
  });

  return data;
}


function isSuccess(status) {
  return 200 <= status && status < 300;
}


/**
 * @ngdoc provider
 * @name $httpProvider
 * @description
 * Use `$httpProvider` to change the default behavior of the {@link ng.$http $http} service.
 * */
function $HttpProvider() {
  /**
   * @ngdoc property
   * @name $httpProvider#defaults
   * @description
   *
   * Object containing default values for all {@link ng.$http $http} requests.
   *
   * - **`defaults.cache`** - {Object} - an object built with {@link ng.$cacheFactory `$cacheFactory`}
   * that will provide the cache for all requests who set their `cache` property to `true`.
   * If you set the `default.cache = false` then only requests that specify their own custom
   * cache object will be cached. See {@link $http#caching $http Caching} for more information.
   *
   * - **`defaults.xsrfCookieName`** - {string} - Name of cookie containing the XSRF token.
   * Defaults value is `'XSRF-TOKEN'`.
   *
   * - **`defaults.xsrfHeaderName`** - {string} - Name of HTTP header to populate with the
   * XSRF token. Defaults value is `'X-XSRF-TOKEN'`.
   *
   * - **`defaults.headers`** - {Object} - Default headers for all $http requests.
   * Refer to {@link ng.$http#setting-http-headers $http} for documentation on
   * setting default headers.
   *     - **`defaults.headers.common`**
   *     - **`defaults.headers.post`**
   *     - **`defaults.headers.put`**
   *     - **`defaults.headers.patch`**
   *
   **/
  var defaults = this.defaults = {
    // transform incoming response data
    transformResponse: [defaultHttpResponseTransform],

    // transform outgoing request data
    transformRequest: [function(d) {
      return isObject(d) && !isFile(d) && !isBlob(d) && !isFormData(d) ? toJson(d) : d;
    }],

    // default headers
    headers: {
      common: {
        'Accept': 'application/json, text/plain, */*'
      },
      post:   shallowCopy(CONTENT_TYPE_APPLICATION_JSON),
      put:    shallowCopy(CONTENT_TYPE_APPLICATION_JSON),
      patch:  shallowCopy(CONTENT_TYPE_APPLICATION_JSON)
    },

    xsrfCookieName: 'XSRF-TOKEN',
    xsrfHeaderName: 'X-XSRF-TOKEN'
  };

  var useApplyAsync = false;
  /**
   * @ngdoc method
   * @name $httpProvider#useApplyAsync
   * @description
   *
   * Configure $http service to combine processing of multiple http responses received at around
   * the same time via {@link ng.$rootScope.Scope#$applyAsync $rootScope.$applyAsync}. This can result in
   * significant performance improvement for bigger applications that make many HTTP requests
   * concurrently (common during application bootstrap).
   *
   * Defaults to false. If no value is specifed, returns the current configured value.
   *
   * @param {boolean=} value If true, when requests are loaded, they will schedule a deferred
   *    "apply" on the next tick, giving time for subsequent requests in a roughly ~10ms window
   *    to load and share the same digest cycle.
   *
   * @returns {boolean|Object} If a value is specified, returns the $httpProvider for chaining.
   *    otherwise, returns the current configured value.
   **/
  this.useApplyAsync = function(value) {
    if (isDefined(value)) {
      useApplyAsync = !!value;
      return this;
    }
    return useApplyAsync;
  };

  /**
   * @ngdoc property
   * @name $httpProvider#interceptors
   * @description
   *
   * Array containing service factories for all synchronous or asynchronous {@link ng.$http $http}
   * pre-processing of request or postprocessing of responses.
   *
   * These service factories are ordered by request, i.e. they are applied in the same order as the
   * array, on request, but reverse order, on response.
   *
   * {@link ng.$http#interceptors Interceptors detailed info}
   **/
  var interceptorFactories = this.interceptors = [];

  this.$get = ['$httpBackend', '$browser', '$cacheFactory', '$rootScope', '$q', '$injector',
      function($httpBackend, $browser, $cacheFactory, $rootScope, $q, $injector) {

    var defaultCache = $cacheFactory('$http');

    /**
     * Interceptors stored in reverse order. Inner interceptors before outer interceptors.
     * The reversal is needed so that we can build up the interception chain around the
     * server request.
     */
    var reversedInterceptors = [];

    forEach(interceptorFactories, function(interceptorFactory) {
      reversedInterceptors.unshift(isString(interceptorFactory)
          ? $injector.get(interceptorFactory) : $injector.invoke(interceptorFactory));
    });

    /**
     * @ngdoc service
     * @kind function
     * @name $http
     * @requires ng.$httpBackend
     * @requires $cacheFactory
     * @requires $rootScope
     * @requires $q
     * @requires $injector
     *
     * @description
     * The `$http` service is a core Angular service that facilitates communication with the remote
     * HTTP servers via the browser's [XMLHttpRequest](https://developer.mozilla.org/en/xmlhttprequest)
     * object or via [JSONP](http://en.wikipedia.org/wiki/JSONP).
     *
     * For unit testing applications that use `$http` service, see
     * {@link ngMock.$httpBackend $httpBackend mock}.
     *
     * For a higher level of abstraction, please check out the {@link ngResource.$resource
     * $resource} service.
     *
     * The $http API is based on the {@link ng.$q deferred/promise APIs} exposed by
     * the $q service. While for simple usage patterns this doesn't matter much, for advanced usage
     * it is important to familiarize yourself with these APIs and the guarantees they provide.
     *
     *
     * ## General usage
     * The `$http` service is a function which takes a single argument — a configuration object —
     * that is used to generate an HTTP request and returns  a {@link ng.$q promise}
     * with two $http specific methods: `success` and `error`.
     *
     * ```js
     *   // Simple GET request example :
     *   $http.get('/someUrl').
     *     success(function(data, status, headers, config) {
     *       // this callback will be called asynchronously
     *       // when the response is available
     *     }).
     *     error(function(data, status, headers, config) {
     *       // called asynchronously if an error occurs
     *       // or server returns response with an error status.
     *     });
     * ```
     *
     * ```js
     *   // Simple POST request example (passing data) :
     *   $http.post('/someUrl', {msg:'hello word!'}).
     *     success(function(data, status, headers, config) {
     *       // this callback will be called asynchronously
     *       // when the response is available
     *     }).
     *     error(function(data, status, headers, config) {
     *       // called asynchronously if an error occurs
     *       // or server returns response with an error status.
     *     });
     * ```
     *
     *
     * Since the returned value of calling the $http function is a `promise`, you can also use
     * the `then` method to register callbacks, and these callbacks will receive a single argument –
     * an object representing the response. See the API signature and type info below for more
     * details.
     *
     * A response status code between 200 and 299 is considered a success status and
     * will result in the success callback being called. Note that if the response is a redirect,
     * XMLHttpRequest will transparently follow it, meaning that the error callback will not be
     * called for such responses.
     *
     * ## Writing Unit Tests that use $http
     * When unit testing (using {@link ngMock ngMock}), it is necessary to call
     * {@link ngMock.$httpBackend#flush $httpBackend.flush()} to flush each pending
     * request using trained responses.
     *
     * ```
     * $httpBackend.expectGET(...);
     * $http.get(...);
     * $httpBackend.flush();
     * ```
     *
     * ## Shortcut methods
     *
     * Shortcut methods are also available. All shortcut methods require passing in the URL, and
     * request data must be passed in for POST/PUT requests.
     *
     * ```js
     *   $http.get('/someUrl').success(successCallback);
     *   $http.post('/someUrl', data).success(successCallback);
     * ```
     *
     * Complete list of shortcut methods:
     *
     * - {@link ng.$http#get $http.get}
     * - {@link ng.$http#head $http.head}
     * - {@link ng.$http#post $http.post}
     * - {@link ng.$http#put $http.put}
     * - {@link ng.$http#delete $http.delete}
     * - {@link ng.$http#jsonp $http.jsonp}
     * - {@link ng.$http#patch $http.patch}
     *
     *
     * ## Setting HTTP Headers
     *
     * The $http service will automatically add certain HTTP headers to all requests. These defaults
     * can be fully configured by accessing the `$httpProvider.defaults.headers` configuration
     * object, which currently contains this default configuration:
     *
     * - `$httpProvider.defaults.headers.common` (headers that are common for all requests):
     *   - `Accept: application/json, text/plain, * / *`
     * - `$httpProvider.defaults.headers.post`: (header defaults for POST requests)
     *   - `Content-Type: application/json`
     * - `$httpProvider.defaults.headers.put` (header defaults for PUT requests)
     *   - `Content-Type: application/json`
     *
     * To add or overwrite these defaults, simply add or remove a property from these configuration
     * objects. To add headers for an HTTP method other than POST or PUT, simply add a new object
     * with the lowercased HTTP method name as the key, e.g.
     * `$httpProvider.defaults.headers.get = { 'My-Header' : 'value' }.
     *
     * The defaults can also be set at runtime via the `$http.defaults` object in the same
     * fashion. For example:
     *
     * ```
     * module.run(function($http) {
     *   $http.defaults.headers.common.Authorization = 'Basic YmVlcDpib29w'
     * });
     * ```
     *
     * In addition, you can supply a `headers` property in the config object passed when
     * calling `$http(config)`, which overrides the defaults without changing them globally.
     *
     * To explicitly remove a header automatically added via $httpProvider.defaults.headers on a per request basis,
     * Use the `headers` property, setting the desired header to `undefined`. For example:
     *
     * ```js
     * var req = {
     *  method: 'POST',
     *  url: 'http://example.com',
     *  headers: {
     *    'Content-Type': undefined
     *  },
     *  data: { test: 'test' }
     * }
     *
     * $http(req).success(function(){...}).error(function(){...});
     * ```
     *
     * ## Transforming Requests and Responses
     *
     * Both requests and responses can be transformed using transformation functions: `transformRequest`
     * and `transformResponse`. These properties can be a single function that returns
     * the transformed value (`function(data, headersGetter, status)`) or an array of such transformation functions,
     * which allows you to `push` or `unshift` a new transformation function into the transformation chain.
     *
     * ### Default Transformations
     *
     * The `$httpProvider` provider and `$http` service expose `defaults.transformRequest` and
     * `defaults.transformResponse` properties. If a request does not provide its own transformations
     * then these will be applied.
     *
     * You can augment or replace the default transformations by modifying these properties by adding to or
     * replacing the array.
     *
     * Angular provides the following default transformations:
     *
     * Request transformations (`$httpProvider.defaults.transformRequest` and `$http.defaults.transformRequest`):
     *
     * - If the `data` property of the request configuration object contains an object, serialize it
     *   into JSON format.
     *
     * Response transformations (`$httpProvider.defaults.transformResponse` and `$http.defaults.transformResponse`):
     *
     *  - If XSRF prefix is detected, strip it (see Security Considerations section below).
     *  - If JSON response is detected, deserialize it using a JSON parser.
     *
     *
     * ### Overriding the Default Transformations Per Request
     *
     * If you wish override the request/response transformations only for a single request then provide
     * `transformRequest` and/or `transformResponse` properties on the configuration object passed
     * into `$http`.
     *
     * Note that if you provide these properties on the config object the default transformations will be
     * overwritten. If you wish to augment the default transformations then you must include them in your
     * local transformation array.
     *
     * The following code demonstrates adding a new response transformation to be run after the default response
     * transformations have been run.
     *
     * ```js
     * function appendTransform(defaults, transform) {
     *
     *   // We can't guarantee that the default transformation is an array
     *   defaults = angular.isArray(defaults) ? defaults : [defaults];
     *
     *   // Append the new transformation to the defaults
     *   return defaults.concat(transform);
     * }
     *
     * $http({
     *   url: '...',
     *   method: 'GET',
     *   transformResponse: appendTransform($http.defaults.transformResponse, function(value) {
     *     return doTransform(value);
     *   })
     * });
     * ```
     *
     *
     * ## Caching
     *
     * To enable caching, set the request configuration `cache` property to `true` (to use default
     * cache) or to a custom cache object (built with {@link ng.$cacheFactory `$cacheFactory`}).
     * When the cache is enabled, `$http` stores the response from the server in the specified
     * cache. The next time the same request is made, the response is served from the cache without
     * sending a request to the server.
     *
     * Note that even if the response is served from cache, delivery of the data is asynchronous in
     * the same way that real requests are.
     *
     * If there are multiple GET requests for the same URL that should be cached using the same
     * cache, but the cache is not populated yet, only one request to the server will be made and
     * the remaining requests will be fulfilled using the response from the first request.
     *
     * You can change the default cache to a new object (built with
     * {@link ng.$cacheFactory `$cacheFactory`}) by updating the
     * {@link ng.$http#defaults `$http.defaults.cache`} property. All requests who set
     * their `cache` property to `true` will now use this cache object.
     *
     * If you set the default cache to `false` then only requests that specify their own custom
     * cache object will be cached.
     *
     * ## Interceptors
     *
     * Before you start creating interceptors, be sure to understand the
     * {@link ng.$q $q and deferred/promise APIs}.
     *
     * For purposes of global error handling, authentication, or any kind of synchronous or
     * asynchronous pre-processing of request or postprocessing of responses, it is desirable to be
     * able to intercept requests before they are handed to the server and
     * responses before they are handed over to the application code that
     * initiated these requests. The interceptors leverage the {@link ng.$q
     * promise APIs} to fulfill this need for both synchronous and asynchronous pre-processing.
     *
     * The interceptors are service factories that are registered with the `$httpProvider` by
     * adding them to the `$httpProvider.interceptors` array. The factory is called and
     * injected with dependencies (if specified) and returns the interceptor.
     *
     * There are two kinds of interceptors (and two kinds of rejection interceptors):
     *
     *   * `request`: interceptors get called with a http `config` object. The function is free to
     *     modify the `config` object or create a new one. The function needs to return the `config`
     *     object directly, or a promise containing the `config` or a new `config` object.
     *   * `requestError`: interceptor gets called when a previous interceptor threw an error or
     *     resolved with a rejection.
     *   * `response`: interceptors get called with http `response` object. The function is free to
     *     modify the `response` object or create a new one. The function needs to return the `response`
     *     object directly, or as a promise containing the `response` or a new `response` object.
     *   * `responseError`: interceptor gets called when a previous interceptor threw an error or
     *     resolved with a rejection.
     *
     *
     * ```js
     *   // register the interceptor as a service
     *   $provide.factory('myHttpInterceptor', function($q, dependency1, dependency2) {
     *     return {
     *       // optional method
     *       'request': function(config) {
     *         // do something on success
     *         return config;
     *       },
     *
     *       // optional method
     *      'requestError': function(rejection) {
     *         // do something on error
     *         if (canRecover(rejection)) {
     *           return responseOrNewPromise
     *         }
     *         return $q.reject(rejection);
     *       },
     *
     *
     *
     *       // optional method
     *       'response': function(response) {
     *         // do something on success
     *         return response;
     *       },
     *
     *       // optional method
     *      'responseError': function(rejection) {
     *         // do something on error
     *         if (canRecover(rejection)) {
     *           return responseOrNewPromise
     *         }
     *         return $q.reject(rejection);
     *       }
     *     };
     *   });
     *
     *   $httpProvider.interceptors.push('myHttpInterceptor');
     *
     *
     *   // alternatively, register the interceptor via an anonymous factory
     *   $httpProvider.interceptors.push(function($q, dependency1, dependency2) {
     *     return {
     *      'request': function(config) {
     *          // same as above
     *       },
     *
     *       'response': function(response) {
     *          // same as above
     *       }
     *     };
     *   });
     * ```
     *
     * ## Security Considerations
     *
     * When designing web applications, consider security threats from:
     *
     * - [JSON vulnerability](http://haacked.com/archive/2008/11/20/anatomy-of-a-subtle-json-vulnerability.aspx)
     * - [XSRF](http://en.wikipedia.org/wiki/Cross-site_request_forgery)
     *
     * Both server and the client must cooperate in order to eliminate these threats. Angular comes
     * pre-configured with strategies that address these issues, but for this to work backend server
     * cooperation is required.
     *
     * ### JSON Vulnerability Protection
     *
     * A [JSON vulnerability](http://haacked.com/archive/2008/11/20/anatomy-of-a-subtle-json-vulnerability.aspx)
     * allows third party website to turn your JSON resource URL into
     * [JSONP](http://en.wikipedia.org/wiki/JSONP) request under some conditions. To
     * counter this your server can prefix all JSON requests with following string `")]}',\n"`.
     * Angular will automatically strip the prefix before processing it as JSON.
     *
     * For example if your server needs to return:
     * ```js
     * ['one','two']
     * ```
     *
     * which is vulnerable to attack, your server can return:
     * ```js
     * )]}',
     * ['one','two']
     * ```
     *
     * Angular will strip the prefix, before processing the JSON.
     *
     *
     * ### Cross Site Request Forgery (XSRF) Protection
     *
     * [XSRF](http://en.wikipedia.org/wiki/Cross-site_request_forgery) is a technique by which
     * an unauthorized site can gain your user's private data. Angular provides a mechanism
     * to counter XSRF. When performing XHR requests, the $http service reads a token from a cookie
     * (by default, `XSRF-TOKEN`) and sets it as an HTTP header (`X-XSRF-TOKEN`). Since only
     * JavaScript that runs on your domain could read the cookie, your server can be assured that
     * the XHR came from JavaScript running on your domain. The header will not be set for
     * cross-domain requests.
     *
     * To take advantage of this, your server needs to set a token in a JavaScript readable session
     * cookie called `XSRF-TOKEN` on the first HTTP GET request. On subsequent XHR requests the
     * server can verify that the cookie matches `X-XSRF-TOKEN` HTTP header, and therefore be sure
     * that only JavaScript running on your domain could have sent the request. The token must be
     * unique for each user and must be verifiable by the server (to prevent the JavaScript from
     * making up its own tokens). We recommend that the token is a digest of your site's
     * authentication cookie with a [salt](https://en.wikipedia.org/wiki/Salt_(cryptography&#41;)
     * for added security.
     *
     * The name of the headers can be specified using the xsrfHeaderName and xsrfCookieName
     * properties of either $httpProvider.defaults at config-time, $http.defaults at run-time,
     * or the per-request config object.
     *
     *
     * @param {object} config Object describing the request to be made and how it should be
     *    processed. The object has following properties:
     *
     *    - **method** – `{string}` – HTTP method (e.g. 'GET', 'POST', etc)
     *    - **url** – `{string}` – Absolute or relative URL of the resource that is being requested.
     *    - **params** – `{Object.<string|Object>}` – Map of strings or objects which will be turned
     *      to `?key1=value1&key2=value2` after the url. If the value is not a string, it will be
     *      JSONified.
     *    - **data** – `{string|Object}` – Data to be sent as the request message data.
     *    - **headers** – `{Object}` – Map of strings or functions which return strings representing
     *      HTTP headers to send to the server. If the return value of a function is null, the
     *      header will not be sent.
     *    - **xsrfHeaderName** – `{string}` – Name of HTTP header to populate with the XSRF token.
     *    - **xsrfCookieName** – `{string}` – Name of cookie containing the XSRF token.
     *    - **transformRequest** –
     *      `{function(data, headersGetter)|Array.<function(data, headersGetter)>}` –
     *      transform function or an array of such functions. The transform function takes the http
     *      request body and headers and returns its transformed (typically serialized) version.
     *      See {@link ng.$http#overriding-the-default-transformations-per-request
     *      Overriding the Default Transformations}
     *    - **transformResponse** –
     *      `{function(data, headersGetter, status)|Array.<function(data, headersGetter, status)>}` –
     *      transform function or an array of such functions. The transform function takes the http
     *      response body, headers and status and returns its transformed (typically deserialized) version.
     *      See {@link ng.$http#overriding-the-default-transformations-per-request
     *      Overriding the Default Transformations}
     *    - **cache** – `{boolean|Cache}` – If true, a default $http cache will be used to cache the
     *      GET request, otherwise if a cache instance built with
     *      {@link ng.$cacheFactory $cacheFactory}, this cache will be used for
     *      caching.
     *    - **timeout** – `{number|Promise}` – timeout in milliseconds, or {@link ng.$q promise}
     *      that should abort the request when resolved.
     *    - **withCredentials** - `{boolean}` - whether to set the `withCredentials` flag on the
     *      XHR object. See [requests with credentials](https://developer.mozilla.org/docs/Web/HTTP/Access_control_CORS#Requests_with_credentials)
     *      for more information.
     *    - **responseType** - `{string}` - see
     *      [requestType](https://developer.mozilla.org/en-US/docs/DOM/XMLHttpRequest#responseType).
     *
     * @returns {HttpPromise} Returns a {@link ng.$q promise} object with the
     *   standard `then` method and two http specific methods: `success` and `error`. The `then`
     *   method takes two arguments a success and an error callback which will be called with a
     *   response object. The `success` and `error` methods take a single argument - a function that
     *   will be called when the request succeeds or fails respectively. The arguments passed into
     *   these functions are destructured representation of the response object passed into the
     *   `then` method. The response object has these properties:
     *
     *   - **data** – `{string|Object}` – The response body transformed with the transform
     *     functions.
     *   - **status** – `{number}` – HTTP status code of the response.
     *   - **headers** – `{function([headerName])}` – Header getter function.
     *   - **config** – `{Object}` – The configuration object that was used to generate the request.
     *   - **statusText** – `{string}` – HTTP status text of the response.
     *
     * @property {Array.<Object>} pendingRequests Array of config objects for currently pending
     *   requests. This is primarily meant to be used for debugging purposes.
     *
     *
     * @example
<example module="httpExample">
<file name="index.html">
  <div ng-controller="FetchController">
    <select ng-model="method">
      <option>GET</option>
      <option>JSONP</option>
    </select>
    <input type="text" ng-model="url" size="80"/>
    <button id="fetchbtn" ng-click="fetch()">fetch</button><br>
    <button id="samplegetbtn" ng-click="updateModel('GET', 'http-hello.html')">Sample GET</button>
    <button id="samplejsonpbtn"
      ng-click="updateModel('JSONP',
                    'https://angularjs.org/greet.php?callback=JSON_CALLBACK&name=Super%20Hero')">
      Sample JSONP
    </button>
    <button id="invalidjsonpbtn"
      ng-click="updateModel('JSONP', 'https://angularjs.org/doesntexist&callback=JSON_CALLBACK')">
        Invalid JSONP
      </button>
    <pre>http status code: {{status}}</pre>
    <pre>http response data: {{data}}</pre>
  </div>
</file>
<file name="script.js">
  angular.module('httpExample', [])
    .controller('FetchController', ['$scope', '$http', '$templateCache',
      function($scope, $http, $templateCache) {
        $scope.method = 'GET';
        $scope.url = 'http-hello.html';

        $scope.fetch = function() {
          $scope.code = null;
          $scope.response = null;

          $http({method: $scope.method, url: $scope.url, cache: $templateCache}).
            success(function(data, status) {
              $scope.status = status;
              $scope.data = data;
            }).
            error(function(data, status) {
              $scope.data = data || "Request failed";
              $scope.status = status;
          });
        };

        $scope.updateModel = function(method, url) {
          $scope.method = method;
          $scope.url = url;
        };
      }]);
</file>
<file name="http-hello.html">
  Hello, $http!
</file>
<file name="protractor.js" type="protractor">
  var status = element(by.binding('status'));
  var data = element(by.binding('data'));
  var fetchBtn = element(by.id('fetchbtn'));
  var sampleGetBtn = element(by.id('samplegetbtn'));
  var sampleJsonpBtn = element(by.id('samplejsonpbtn'));
  var invalidJsonpBtn = element(by.id('invalidjsonpbtn'));

  it('should make an xhr GET request', function() {
    sampleGetBtn.click();
    fetchBtn.click();
    expect(status.getText()).toMatch('200');
    expect(data.getText()).toMatch(/Hello, \$http!/);
  });

// Commented out due to flakes. See https://github.com/angular/angular.js/issues/9185
// it('should make a JSONP request to angularjs.org', function() {
//   sampleJsonpBtn.click();
//   fetchBtn.click();
//   expect(status.getText()).toMatch('200');
//   expect(data.getText()).toMatch(/Super Hero!/);
// });

  it('should make JSONP request to invalid URL and invoke the error handler',
      function() {
    invalidJsonpBtn.click();
    fetchBtn.click();
    expect(status.getText()).toMatch('0');
    expect(data.getText()).toMatch('Request failed');
  });
</file>
</example>
     */
    function $http(requestConfig) {

      if (!angular.isObject(requestConfig)) {
        throw minErr('$http')('badreq', 'Http request configuration must be an object.  Received: {0}', requestConfig);
      }

      var config = extend({
        method: 'get',
        transformRequest: defaults.transformRequest,
        transformResponse: defaults.transformResponse
      }, requestConfig);

      config.headers = mergeHeaders(requestConfig);
      config.method = uppercase(config.method);

      var serverRequest = function(config) {
        var headers = config.headers;
        var reqData = transformData(config.data, headersGetter(headers), undefined, config.transformRequest);

        // strip content-type if data is undefined
        if (isUndefined(reqData)) {
          forEach(headers, function(value, header) {
            if (lowercase(header) === 'content-type') {
                delete headers[header];
            }
          });
        }

        if (isUndefined(config.withCredentials) && !isUndefined(defaults.withCredentials)) {
          config.withCredentials = defaults.withCredentials;
        }

        // send request
        return sendReq(config, reqData).then(transformResponse, transformResponse);
      };

      var chain = [serverRequest, undefined];
      var promise = $q.when(config);

      // apply interceptors
      forEach(reversedInterceptors, function(interceptor) {
        if (interceptor.request || interceptor.requestError) {
          chain.unshift(interceptor.request, interceptor.requestError);
        }
        if (interceptor.response || interceptor.responseError) {
          chain.push(interceptor.response, interceptor.responseError);
        }
      });

      while (chain.length) {
        var thenFn = chain.shift();
        var rejectFn = chain.shift();

        promise = promise.then(thenFn, rejectFn);
      }

      promise.success = function(fn) {
        assertArgFn(fn, 'fn');

        promise.then(function(response) {
          fn(response.data, response.status, response.headers, config);
        });
        return promise;
      };

      promise.error = function(fn) {
        assertArgFn(fn, 'fn');

        promise.then(null, function(response) {
          fn(response.data, response.status, response.headers, config);
        });
        return promise;
      };

      return promise;

      function transformResponse(response) {
        // make a copy since the response must be cacheable
        var resp = extend({}, response);
        if (!response.data) {
          resp.data = response.data;
        } else {
          resp.data = transformData(response.data, response.headers, response.status, config.transformResponse);
        }
        return (isSuccess(response.status))
          ? resp
          : $q.reject(resp);
      }

      function executeHeaderFns(headers) {
        var headerContent, processedHeaders = {};

        forEach(headers, function(headerFn, header) {
          if (isFunction(headerFn)) {
            headerContent = headerFn();
            if (headerContent != null) {
              processedHeaders[header] = headerContent;
            }
          } else {
            processedHeaders[header] = headerFn;
          }
        });

        return processedHeaders;
      }

      function mergeHeaders(config) {
        var defHeaders = defaults.headers,
            reqHeaders = extend({}, config.headers),
            defHeaderName, lowercaseDefHeaderName, reqHeaderName;

        defHeaders = extend({}, defHeaders.common, defHeaders[lowercase(config.method)]);

        // using for-in instead of forEach to avoid unecessary iteration after header has been found
        defaultHeadersIteration:
        for (defHeaderName in defHeaders) {
          lowercaseDefHeaderName = lowercase(defHeaderName);

          for (reqHeaderName in reqHeaders) {
            if (lowercase(reqHeaderName) === lowercaseDefHeaderName) {
              continue defaultHeadersIteration;
            }
          }

          reqHeaders[defHeaderName] = defHeaders[defHeaderName];
        }

        // execute if header value is a function for merged headers
        return executeHeaderFns(reqHeaders);
      }
    }

    $http.pendingRequests = [];

    /**
     * @ngdoc method
     * @name $http#get
     *
     * @description
     * Shortcut method to perform `GET` request.
     *
     * @param {string} url Relative or absolute URL specifying the destination of the request
     * @param {Object=} config Optional configuration object
     * @returns {HttpPromise} Future object
     */

    /**
     * @ngdoc method
     * @name $http#delete
     *
     * @description
     * Shortcut method to perform `DELETE` request.
     *
     * @param {string} url Relative or absolute URL specifying the destination of the request
     * @param {Object=} config Optional configuration object
     * @returns {HttpPromise} Future object
     */

    /**
     * @ngdoc method
     * @name $http#head
     *
     * @description
     * Shortcut method to perform `HEAD` request.
     *
     * @param {string} url Relative or absolute URL specifying the destination of the request
     * @param {Object=} config Optional configuration object
     * @returns {HttpPromise} Future object
     */

    /**
     * @ngdoc method
     * @name $http#jsonp
     *
     * @description
     * Shortcut method to perform `JSONP` request.
     *
     * @param {string} url Relative or absolute URL specifying the destination of the request.
     *                     The name of the callback should be the string `JSON_CALLBACK`.
     * @param {Object=} config Optional configuration object
     * @returns {HttpPromise} Future object
     */
    createShortMethods('get', 'delete', 'head', 'jsonp');

    /**
     * @ngdoc method
     * @name $http#post
     *
     * @description
     * Shortcut method to perform `POST` request.
     *
     * @param {string} url Relative or absolute URL specifying the destination of the request
     * @param {*} data Request content
     * @param {Object=} config Optional configuration object
     * @returns {HttpPromise} Future object
     */

    /**
     * @ngdoc method
     * @name $http#put
     *
     * @description
     * Shortcut method to perform `PUT` request.
     *
     * @param {string} url Relative or absolute URL specifying the destination of the request
     * @param {*} data Request content
     * @param {Object=} config Optional configuration object
     * @returns {HttpPromise} Future object
     */

     /**
      * @ngdoc method
      * @name $http#patch
      *
      * @description
      * Shortcut method to perform `PATCH` request.
      *
      * @param {string} url Relative or absolute URL specifying the destination of the request
      * @param {*} data Request content
      * @param {Object=} config Optional configuration object
      * @returns {HttpPromise} Future object
      */
    createShortMethodsWithData('post', 'put', 'patch');

        /**
         * @ngdoc property
         * @name $http#defaults
         *
         * @description
         * Runtime equivalent of the `$httpProvider.defaults` property. Allows configuration of
         * default headers, withCredentials as well as request and response transformations.
         *
         * See "Setting HTTP Headers" and "Transforming Requests and Responses" sections above.
         */
    $http.defaults = defaults;


    return $http;


    function createShortMethods(names) {
      forEach(arguments, function(name) {
        $http[name] = function(url, config) {
          return $http(extend(config || {}, {
            method: name,
            url: url
          }));
        };
      });
    }


    function createShortMethodsWithData(name) {
      forEach(arguments, function(name) {
        $http[name] = function(url, data, config) {
          return $http(extend(config || {}, {
            method: name,
            url: url,
            data: data
          }));
        };
      });
    }


    /**
     * Makes the request.
     *
     * !!! ACCESSES CLOSURE VARS:
     * $httpBackend, defaults, $log, $rootScope, defaultCache, $http.pendingRequests
     */
    function sendReq(config, reqData) {
      var deferred = $q.defer(),
          promise = deferred.promise,
          cache,
          cachedResp,
          reqHeaders = config.headers,
          url = buildUrl(config.url, config.params);

      $http.pendingRequests.push(config);
      promise.then(removePendingReq, removePendingReq);


      if ((config.cache || defaults.cache) && config.cache !== false &&
          (config.method === 'GET' || config.method === 'JSONP')) {
        cache = isObject(config.cache) ? config.cache
              : isObject(defaults.cache) ? defaults.cache
              : defaultCache;
      }

      if (cache) {
        cachedResp = cache.get(url);
        if (isDefined(cachedResp)) {
          if (isPromiseLike(cachedResp)) {
            // cached request has already been sent, but there is no response yet
            cachedResp.then(resolvePromiseWithResult, resolvePromiseWithResult);
          } else {
            // serving from cache
            if (isArray(cachedResp)) {
              resolvePromise(cachedResp[1], cachedResp[0], shallowCopy(cachedResp[2]), cachedResp[3]);
            } else {
              resolvePromise(cachedResp, 200, {}, 'OK');
            }
          }
        } else {
          // put the promise for the non-transformed response into cache as a placeholder
          cache.put(url, promise);
        }
      }


      // if we won't have the response in cache, set the xsrf headers and
      // send the request to the backend
      if (isUndefined(cachedResp)) {
        var xsrfValue = urlIsSameOrigin(config.url)
            ? $browser.cookies()[config.xsrfCookieName || defaults.xsrfCookieName]
            : undefined;
        if (xsrfValue) {
          reqHeaders[(config.xsrfHeaderName || defaults.xsrfHeaderName)] = xsrfValue;
        }

        $httpBackend(config.method, url, reqData, done, reqHeaders, config.timeout,
            config.withCredentials, config.responseType);
      }

      return promise;


      /**
       * Callback registered to $httpBackend():
       *  - caches the response if desired
       *  - resolves the raw $http promise
       *  - calls $apply
       */
      function done(status, response, headersString, statusText) {
        if (cache) {
          if (isSuccess(status)) {
            cache.put(url, [status, response, parseHeaders(headersString), statusText]);
          } else {
            // remove promise from the cache
            cache.remove(url);
          }
        }

        function resolveHttpPromise() {
          resolvePromise(response, status, headersString, statusText);
        }

        if (useApplyAsync) {
          $rootScope.$applyAsync(resolveHttpPromise);
        } else {
          resolveHttpPromise();
          if (!$rootScope.$$phase) $rootScope.$apply();
        }
      }


      /**
       * Resolves the raw $http promise.
       */
      function resolvePromise(response, status, headers, statusText) {
        //status: HTTP response status code, 0, -1 (aborted by timeout / promise)
        status = status >= -1 ? status : 0;

        (isSuccess(status) ? deferred.resolve : deferred.reject)({
          data: response,
          status: status,
          headers: headersGetter(headers),
          config: config,
          statusText: statusText
        });
      }

      function resolvePromiseWithResult(result) {
        resolvePromise(result.data, result.status, shallowCopy(result.headers()), result.statusText);
      }

      function removePendingReq() {
        var idx = $http.pendingRequests.indexOf(config);
        if (idx !== -1) $http.pendingRequests.splice(idx, 1);
      }
    }


    function buildUrl(url, params) {
      if (!params) return url;
      var parts = [];
      forEachSorted(params, function(value, key) {
        if (value === null || isUndefined(value)) return;
        if (!isArray(value)) value = [value];

        forEach(value, function(v) {
          if (isObject(v)) {
            if (isDate(v)) {
              v = v.toISOString();
            } else {
              v = toJson(v);
            }
          }
          parts.push(encodeUriQuery(key) + '=' +
                     encodeUriQuery(v));
        });
      });
      if (parts.length > 0) {
        url += ((url.indexOf('?') == -1) ? '?' : '&') + parts.join('&');
      }
      return url;
    }
  }];
}

function createXhr() {
    return new window.XMLHttpRequest();
}

/**
 * @ngdoc service
 * @name $httpBackend
 * @requires $window
 * @requires $document
 *
 * @description
 * HTTP backend used by the {@link ng.$http service} that delegates to
 * XMLHttpRequest object or JSONP and deals with browser incompatibilities.
 *
 * You should never need to use this service directly, instead use the higher-level abstractions:
 * {@link ng.$http $http} or {@link ngResource.$resource $resource}.
 *
 * During testing this implementation is swapped with {@link ngMock.$httpBackend mock
 * $httpBackend} which can be trained with responses.
 */
function $HttpBackendProvider() {
  this.$get = ['$browser', '$window', '$document', function($browser, $window, $document) {
    return createHttpBackend($browser, createXhr, $browser.defer, $window.angular.callbacks, $document[0]);
  }];
}

function createHttpBackend($browser, createXhr, $browserDefer, callbacks, rawDocument) {
  // TODO(vojta): fix the signature
  return function(method, url, post, callback, headers, timeout, withCredentials, responseType) {
    $browser.$$incOutstandingRequestCount();
    url = url || $browser.url();

    if (lowercase(method) == 'jsonp') {
      var callbackId = '_' + (callbacks.counter++).toString(36);
      callbacks[callbackId] = function(data) {
        callbacks[callbackId].data = data;
        callbacks[callbackId].called = true;
      };

      var jsonpDone = jsonpReq(url.replace('JSON_CALLBACK', 'angular.callbacks.' + callbackId),
          callbackId, function(status, text) {
        completeRequest(callback, status, callbacks[callbackId].data, "", text);
        callbacks[callbackId] = noop;
      });
    } else {

      var xhr = createXhr();

      xhr.open(method, url, true);
      forEach(headers, function(value, key) {
        if (isDefined(value)) {
            xhr.setRequestHeader(key, value);
        }
      });

      xhr.onload = function requestLoaded() {
        var statusText = xhr.statusText || '';

        // responseText is the old-school way of retrieving response (supported by IE9)
        // response/responseType properties were introduced in XHR Level2 spec (supported by IE10)
        var response = ('response' in xhr) ? xhr.response : xhr.responseText;

        // normalize IE9 bug (http://bugs.jquery.com/ticket/1450)
        var status = xhr.status === 1223 ? 204 : xhr.status;

        // fix status code when it is 0 (0 status is undocumented).
        // Occurs when accessing file resources or on Android 4.1 stock browser
        // while retrieving files from application cache.
        if (status === 0) {
          status = response ? 200 : urlResolve(url).protocol == 'file' ? 404 : 0;
        }

        completeRequest(callback,
            status,
            response,
            xhr.getAllResponseHeaders(),
            statusText);
      };

      var requestError = function() {
        // The response is always empty
        // See https://xhr.spec.whatwg.org/#request-error-steps and https://fetch.spec.whatwg.org/#concept-network-error
        completeRequest(callback, -1, null, null, '');
      };

      xhr.onerror = requestError;
      xhr.onabort = requestError;

      if (withCredentials) {
        xhr.withCredentials = true;
      }

      if (responseType) {
        try {
          xhr.responseType = responseType;
        } catch (e) {
          // WebKit added support for the json responseType value on 09/03/2013
          // https://bugs.webkit.org/show_bug.cgi?id=73648. Versions of Safari prior to 7 are
          // known to throw when setting the value "json" as the response type. Other older
          // browsers implementing the responseType
          //
          // The json response type can be ignored if not supported, because JSON payloads are
          // parsed on the client-side regardless.
          if (responseType !== 'json') {
            throw e;
          }
        }
      }

      xhr.send(post || null);
    }

    if (timeout > 0) {
      var timeoutId = $browserDefer(timeoutRequest, timeout);
    } else if (isPromiseLike(timeout)) {
      timeout.then(timeoutRequest);
    }


    function timeoutRequest() {
      jsonpDone && jsonpDone();
      xhr && xhr.abort();
    }

    function completeRequest(callback, status, response, headersString, statusText) {
      // cancel timeout and subsequent timeout promise resolution
      if (timeoutId !== undefined) {
        $browserDefer.cancel(timeoutId);
      }
      jsonpDone = xhr = null;

      callback(status, response, headersString, statusText);
      $browser.$$completeOutstandingRequest(noop);
    }
  };

  function jsonpReq(url, callbackId, done) {
    // we can't use jQuery/jqLite here because jQuery does crazy stuff with script elements, e.g.:
    // - fetches local scripts via XHR and evals them
    // - adds and immediately removes script elements from the document
    var script = rawDocument.createElement('script'), callback = null;
    script.type = "text/javascript";
    script.src = url;
    script.async = true;

    callback = function(event) {
      removeEventListenerFn(script, "load", callback);
      removeEventListenerFn(script, "error", callback);
      rawDocument.body.removeChild(script);
      script = null;
      var status = -1;
      var text = "unknown";

      if (event) {
        if (event.type === "load" && !callbacks[callbackId].called) {
          event = { type: "error" };
        }
        text = event.type;
        status = event.type === "error" ? 404 : 200;
      }

      if (done) {
        done(status, text);
      }
    };

    addEventListenerFn(script, "load", callback);
    addEventListenerFn(script, "error", callback);
    rawDocument.body.appendChild(script);
    return callback;
  }
}

var $interpolateMinErr = minErr('$interpolate');

/**
 * @ngdoc provider
 * @name $interpolateProvider
 *
 * @description
 *
 * Used for configuring the interpolation markup. Defaults to `{{` and `}}`.
 *
 * @example
<example module="customInterpolationApp">
<file name="index.html">
<script>
  var customInterpolationApp = angular.module('customInterpolationApp', []);

  customInterpolationApp.config(function($interpolateProvider) {
    $interpolateProvider.startSymbol('//');
    $interpolateProvider.endSymbol('//');
  });


  customInterpolationApp.controller('DemoController', function() {
      this.label = "This binding is brought you by // interpolation symbols.";
  });
</script>
<div ng-app="App" ng-controller="DemoController as demo">
    //demo.label//
</div>
</file>
<file name="protractor.js" type="protractor">
  it('should interpolate binding with custom symbols', function() {
    expect(element(by.binding('demo.label')).getText()).toBe('This binding is brought you by // interpolation symbols.');
  });
</file>
</example>
 */
function $InterpolateProvider() {
  var startSymbol = '{{';
  var endSymbol = '}}';

  /**
   * @ngdoc method
   * @name $interpolateProvider#startSymbol
   * @description
   * Symbol to denote start of expression in the interpolated string. Defaults to `{{`.
   *
   * @param {string=} value new value to set the starting symbol to.
   * @returns {string|self} Returns the symbol when used as getter and self if used as setter.
   */
  this.startSymbol = function(value) {
    if (value) {
      startSymbol = value;
      return this;
    } else {
      return startSymbol;
    }
  };

  /**
   * @ngdoc method
   * @name $interpolateProvider#endSymbol
   * @description
   * Symbol to denote the end of expression in the interpolated string. Defaults to `}}`.
   *
   * @param {string=} value new value to set the ending symbol to.
   * @returns {string|self} Returns the symbol when used as getter and self if used as setter.
   */
  this.endSymbol = function(value) {
    if (value) {
      endSymbol = value;
      return this;
    } else {
      return endSymbol;
    }
  };


  this.$get = ['$parse', '$exceptionHandler', '$sce', function($parse, $exceptionHandler, $sce) {
    var startSymbolLength = startSymbol.length,
        endSymbolLength = endSymbol.length,
        escapedStartRegexp = new RegExp(startSymbol.replace(/./g, escape), 'g'),
        escapedEndRegexp = new RegExp(endSymbol.replace(/./g, escape), 'g');

    function escape(ch) {
      return '\\\\\\' + ch;
    }

    /**
     * @ngdoc service
     * @name $interpolate
     * @kind function
     *
     * @requires $parse
     * @requires $sce
     *
     * @description
     *
     * Compiles a string with markup into an interpolation function. This service is used by the
     * HTML {@link ng.$compile $compile} service for data binding. See
     * {@link ng.$interpolateProvider $interpolateProvider} for configuring the
     * interpolation markup.
     *
     *
     * ```js
     *   var $interpolate = ...; // injected
     *   var exp = $interpolate('Hello {{name | uppercase}}!');
     *   expect(exp({name:'Angular'}).toEqual('Hello ANGULAR!');
     * ```
     *
     * `$interpolate` takes an optional fourth argument, `allOrNothing`. If `allOrNothing` is
     * `true`, the interpolation function will return `undefined` unless all embedded expressions
     * evaluate to a value other than `undefined`.
     *
     * ```js
     *   var $interpolate = ...; // injected
     *   var context = {greeting: 'Hello', name: undefined };
     *
     *   // default "forgiving" mode
     *   var exp = $interpolate('{{greeting}} {{name}}!');
     *   expect(exp(context)).toEqual('Hello !');
     *
     *   // "allOrNothing" mode
     *   exp = $interpolate('{{greeting}} {{name}}!', false, null, true);
     *   expect(exp(context)).toBeUndefined();
     *   context.name = 'Angular';
     *   expect(exp(context)).toEqual('Hello Angular!');
     * ```
     *
     * `allOrNothing` is useful for interpolating URLs. `ngSrc` and `ngSrcset` use this behavior.
     *
     * ####Escaped Interpolation
     * $interpolate provides a mechanism for escaping interpolation markers. Start and end markers
     * can be escaped by preceding each of their characters with a REVERSE SOLIDUS U+005C (backslash).
     * It will be rendered as a regular start/end marker, and will not be interpreted as an expression
     * or binding.
     *
     * This enables web-servers to prevent script injection attacks and defacing attacks, to some
     * degree, while also enabling code examples to work without relying on the
     * {@link ng.directive:ngNonBindable ngNonBindable} directive.
     *
     * **For security purposes, it is strongly encouraged that web servers escape user-supplied data,
     * replacing angle brackets (&lt;, &gt;) with &amp;lt; and &amp;gt; respectively, and replacing all
     * interpolation start/end markers with their escaped counterparts.**
     *
     * Escaped interpolation markers are only replaced with the actual interpolation markers in rendered
     * output when the $interpolate service processes the text. So, for HTML elements interpolated
     * by {@link ng.$compile $compile}, or otherwise interpolated with the `mustHaveExpression` parameter
     * set to `true`, the interpolated text must contain an unescaped interpolation expression. As such,
     * this is typically useful only when user-data is used in rendering a template from the server, or
     * when otherwise untrusted data is used by a directive.
     *
     * <example>
     *  <file name="index.html">
     *    <div ng-init="username='A user'">
     *      <p ng-init="apptitle='Escaping demo'">{{apptitle}}: \{\{ username = "defaced value"; \}\}
     *        </p>
     *      <p><strong>{{username}}</strong> attempts to inject code which will deface the
     *        application, but fails to accomplish their task, because the server has correctly
     *        escaped the interpolation start/end markers with REVERSE SOLIDUS U+005C (backslash)
     *        characters.</p>
     *      <p>Instead, the result of the attempted script injection is visible, and can be removed
     *        from the database by an administrator.</p>
     *    </div>
     *  </file>
     * </example>
     *
     * @param {string} text The text with markup to interpolate.
     * @param {boolean=} mustHaveExpression if set to true then the interpolation string must have
     *    embedded expression in order to return an interpolation function. Strings with no
     *    embedded expression will return null for the interpolation function.
     * @param {string=} trustedContext when provided, the returned function passes the interpolated
     *    result through {@link ng.$sce#getTrusted $sce.getTrusted(interpolatedResult,
     *    trustedContext)} before returning it.  Refer to the {@link ng.$sce $sce} service that
     *    provides Strict Contextual Escaping for details.
     * @param {boolean=} allOrNothing if `true`, then the returned function returns undefined
     *    unless all embedded expressions evaluate to a value other than `undefined`.
     * @returns {function(context)} an interpolation function which is used to compute the
     *    interpolated string. The function has these parameters:
     *
     * - `context`: evaluation context for all expressions embedded in the interpolated text
     */
    function $interpolate(text, mustHaveExpression, trustedContext, allOrNothing) {
      allOrNothing = !!allOrNothing;
      var startIndex,
          endIndex,
          index = 0,
          expressions = [],
          parseFns = [],
          textLength = text.length,
          exp,
          concat = [],
          expressionPositions = [];

      while (index < textLength) {
        if (((startIndex = text.indexOf(startSymbol, index)) != -1) &&
             ((endIndex = text.indexOf(endSymbol, startIndex + startSymbolLength)) != -1)) {
          if (index !== startIndex) {
            concat.push(unescapeText(text.substring(index, startIndex)));
          }
          exp = text.substring(startIndex + startSymbolLength, endIndex);
          expressions.push(exp);
          parseFns.push($parse(exp, parseStringifyInterceptor));
          index = endIndex + endSymbolLength;
          expressionPositions.push(concat.length);
          concat.push('');
        } else {
          // we did not find an interpolation, so we have to add the remainder to the separators array
          if (index !== textLength) {
            concat.push(unescapeText(text.substring(index)));
          }
          break;
        }
      }

      // Concatenating expressions makes it hard to reason about whether some combination of
      // concatenated values are unsafe to use and could easily lead to XSS.  By requiring that a
      // single expression be used for iframe[src], object[src], etc., we ensure that the value
      // that's used is assigned or constructed by some JS code somewhere that is more testable or
      // make it obvious that you bound the value to some user controlled value.  This helps reduce
      // the load when auditing for XSS issues.
      if (trustedContext && concat.length > 1) {
          throw $interpolateMinErr('noconcat',
              "Error while interpolating: {0}\nStrict Contextual Escaping disallows " +
              "interpolations that concatenate multiple expressions when a trusted value is " +
              "required.  See http://docs.angularjs.org/api/ng.$sce", text);
      }

      if (!mustHaveExpression || expressions.length) {
        var compute = function(values) {
          for (var i = 0, ii = expressions.length; i < ii; i++) {
            if (allOrNothing && isUndefined(values[i])) return;
            concat[expressionPositions[i]] = values[i];
          }
          return concat.join('');
        };

        var getValue = function(value) {
          return trustedContext ?
            $sce.getTrusted(trustedContext, value) :
            $sce.valueOf(value);
        };

        var stringify = function(value) {
          if (value == null) { // null || undefined
            return '';
          }
          switch (typeof value) {
            case 'string':
              break;
            case 'number':
              value = '' + value;
              break;
            default:
              value = toJson(value);
          }

          return value;
        };

        return extend(function interpolationFn(context) {
            var i = 0;
            var ii = expressions.length;
            var values = new Array(ii);

            try {
              for (; i < ii; i++) {
                values[i] = parseFns[i](context);
              }

              return compute(values);
            } catch (err) {
              var newErr = $interpolateMinErr('interr', "Can't interpolate: {0}\n{1}", text,
                  err.toString());
              $exceptionHandler(newErr);
            }

          }, {
          // all of these properties are undocumented for now
          exp: text, //just for compatibility with regular watchers created via $watch
          expressions: expressions,
          $$watchDelegate: function(scope, listener, objectEquality) {
            var lastValue;
            return scope.$watchGroup(parseFns, function interpolateFnWatcher(values, oldValues) {
              var currValue = compute(values);
              if (isFunction(listener)) {
                listener.call(this, currValue, values !== oldValues ? lastValue : currValue, scope);
              }
              lastValue = currValue;
            }, objectEquality);
          }
        });
      }

      function unescapeText(text) {
        return text.replace(escapedStartRegexp, startSymbol).
          replace(escapedEndRegexp, endSymbol);
      }

      function parseStringifyInterceptor(value) {
        try {
          value = getValue(value);
          return allOrNothing && !isDefined(value) ? value : stringify(value);
        } catch (err) {
          var newErr = $interpolateMinErr('interr', "Can't interpolate: {0}\n{1}", text,
            err.toString());
          $exceptionHandler(newErr);
        }
      }
    }


    /**
     * @ngdoc method
     * @name $interpolate#startSymbol
     * @description
     * Symbol to denote the start of expression in the interpolated string. Defaults to `{{`.
     *
     * Use {@link ng.$interpolateProvider#startSymbol `$interpolateProvider.startSymbol`} to change
     * the symbol.
     *
     * @returns {string} start symbol.
     */
    $interpolate.startSymbol = function() {
      return startSymbol;
    };


    /**
     * @ngdoc method
     * @name $interpolate#endSymbol
     * @description
     * Symbol to denote the end of expression in the interpolated string. Defaults to `}}`.
     *
     * Use {@link ng.$interpolateProvider#endSymbol `$interpolateProvider.endSymbol`} to change
     * the symbol.
     *
     * @returns {string} end symbol.
     */
    $interpolate.endSymbol = function() {
      return endSymbol;
    };

    return $interpolate;
  }];
}

function $IntervalProvider() {
  this.$get = ['$rootScope', '$window', '$q', '$$q',
       function($rootScope,   $window,   $q,   $$q) {
    var intervals = {};


     /**
      * @ngdoc service
      * @name $interval
      *
      * @description
      * Angular's wrapper for `window.setInterval`. The `fn` function is executed every `delay`
      * milliseconds.
      *
      * The return value of registering an interval function is a promise. This promise will be
      * notified upon each tick of the interval, and will be resolved after `count` iterations, or
      * run indefinitely if `count` is not defined. The value of the notification will be the
      * number of iterations that have run.
      * To cancel an interval, call `$interval.cancel(promise)`.
      *
      * In tests you can use {@link ngMock.$interval#flush `$interval.flush(millis)`} to
      * move forward by `millis` milliseconds and trigger any functions scheduled to run in that
      * time.
      *
      * <div class="alert alert-warning">
      * **Note**: Intervals created by this service must be explicitly destroyed when you are finished
      * with them.  In particular they are not automatically destroyed when a controller's scope or a
      * directive's element are destroyed.
      * You should take this into consideration and make sure to always cancel the interval at the
      * appropriate moment.  See the example below for more details on how and when to do this.
      * </div>
      *
      * @param {function()} fn A function that should be called repeatedly.
      * @param {number} delay Number of milliseconds between each function call.
      * @param {number=} [count=0] Number of times to repeat. If not set, or 0, will repeat
      *   indefinitely.
      * @param {boolean=} [invokeApply=true] If set to `false` skips model dirty checking, otherwise
      *   will invoke `fn` within the {@link ng.$rootScope.Scope#$apply $apply} block.
      * @returns {promise} A promise which will be notified on each iteration.
      *
      * @example
      * <example module="intervalExample">
      * <file name="index.html">
      *   <script>
      *     angular.module('intervalExample', [])
      *       .controller('ExampleController', ['$scope', '$interval',
      *         function($scope, $interval) {
      *           $scope.format = 'M/d/yy h:mm:ss a';
      *           $scope.blood_1 = 100;
      *           $scope.blood_2 = 120;
      *
      *           var stop;
      *           $scope.fight = function() {
      *             // Don't start a new fight if we are already fighting
      *             if ( angular.isDefined(stop) ) return;
      *
      *             stop = $interval(function() {
      *               if ($scope.blood_1 > 0 && $scope.blood_2 > 0) {
      *                 $scope.blood_1 = $scope.blood_1 - 3;
      *                 $scope.blood_2 = $scope.blood_2 - 4;
      *               } else {
      *                 $scope.stopFight();
      *               }
      *             }, 100);
      *           };
      *
      *           $scope.stopFight = function() {
      *             if (angular.isDefined(stop)) {
      *               $interval.cancel(stop);
      *               stop = undefined;
      *             }
      *           };
      *
      *           $scope.resetFight = function() {
      *             $scope.blood_1 = 100;
      *             $scope.blood_2 = 120;
      *           };
      *
      *           $scope.$on('$destroy', function() {
      *             // Make sure that the interval is destroyed too
      *             $scope.stopFight();
      *           });
      *         }])
      *       // Register the 'myCurrentTime' directive factory method.
      *       // We inject $interval and dateFilter service since the factory method is DI.
      *       .directive('myCurrentTime', ['$interval', 'dateFilter',
      *         function($interval, dateFilter) {
      *           // return the directive link function. (compile function not needed)
      *           return function(scope, element, attrs) {
      *             var format,  // date format
      *                 stopTime; // so that we can cancel the time updates
      *
      *             // used to update the UI
      *             function updateTime() {
      *               element.text(dateFilter(new Date(), format));
      *             }
      *
      *             // watch the expression, and update the UI on change.
      *             scope.$watch(attrs.myCurrentTime, function(value) {
      *               format = value;
      *               updateTime();
      *             });
      *
      *             stopTime = $interval(updateTime, 1000);
      *
      *             // listen on DOM destroy (removal) event, and cancel the next UI update
      *             // to prevent updating time after the DOM element was removed.
      *             element.on('$destroy', function() {
      *               $interval.cancel(stopTime);
      *             });
      *           }
      *         }]);
      *   </script>
      *
      *   <div>
      *     <div ng-controller="ExampleController">
      *       Date format: <input ng-model="format"> <hr/>
      *       Current time is: <span my-current-time="format"></span>
      *       <hr/>
      *       Blood 1 : <font color='red'>{{blood_1}}</font>
      *       Blood 2 : <font color='red'>{{blood_2}}</font>
      *       <button type="button" data-ng-click="fight()">Fight</button>
      *       <button type="button" data-ng-click="stopFight()">StopFight</button>
      *       <button type="button" data-ng-click="resetFight()">resetFight</button>
      *     </div>
      *   </div>
      *
      * </file>
      * </example>
      */
    function interval(fn, delay, count, invokeApply) {
      var setInterval = $window.setInterval,
          clearInterval = $window.clearInterval,
          iteration = 0,
          skipApply = (isDefined(invokeApply) && !invokeApply),
          deferred = (skipApply ? $$q : $q).defer(),
          promise = deferred.promise;

      count = isDefined(count) ? count : 0;

      promise.then(null, null, fn);

      promise.$$intervalId = setInterval(function tick() {
        deferred.notify(iteration++);

        if (count > 0 && iteration >= count) {
          deferred.resolve(iteration);
          clearInterval(promise.$$intervalId);
          delete intervals[promise.$$intervalId];
        }

        if (!skipApply) $rootScope.$apply();

      }, delay);

      intervals[promise.$$intervalId] = deferred;

      return promise;
    }


     /**
      * @ngdoc method
      * @name $interval#cancel
      *
      * @description
      * Cancels a task associated with the `promise`.
      *
      * @param {promise} promise returned by the `$interval` function.
      * @returns {boolean} Returns `true` if the task was successfully canceled.
      */
    interval.cancel = function(promise) {
      if (promise && promise.$$intervalId in intervals) {
        intervals[promise.$$intervalId].reject('canceled');
        $window.clearInterval(promise.$$intervalId);
        delete intervals[promise.$$intervalId];
        return true;
      }
      return false;
    };

    return interval;
  }];
}

/**
 * @ngdoc service
 * @name $locale
 *
 * @description
 * $locale service provides localization rules for various Angular components. As of right now the
 * only public api is:
 *
 * * `id` – `{string}` – locale id formatted as `languageId-countryId` (e.g. `en-us`)
 */
function $LocaleProvider() {
  this.$get = function() {
    return {
      id: 'en-us',

      NUMBER_FORMATS: {
        DECIMAL_SEP: '.',
        GROUP_SEP: ',',
        PATTERNS: [
          { // Decimal Pattern
            minInt: 1,
            minFrac: 0,
            maxFrac: 3,
            posPre: '',
            posSuf: '',
            negPre: '-',
            negSuf: '',
            gSize: 3,
            lgSize: 3
          },{ //Currency Pattern
            minInt: 1,
            minFrac: 2,
            maxFrac: 2,
            posPre: '\u00A4',
            posSuf: '',
            negPre: '(\u00A4',
            negSuf: ')',
            gSize: 3,
            lgSize: 3
          }
        ],
        CURRENCY_SYM: '$'
      },

      DATETIME_FORMATS: {
        MONTH:
            'January,February,March,April,May,June,July,August,September,October,November,December'
            .split(','),
        SHORTMONTH:  'Jan,Feb,Mar,Apr,May,Jun,Jul,Aug,Sep,Oct,Nov,Dec'.split(','),
        DAY: 'Sunday,Monday,Tuesday,Wednesday,Thursday,Friday,Saturday'.split(','),
        SHORTDAY: 'Sun,Mon,Tue,Wed,Thu,Fri,Sat'.split(','),
        AMPMS: ['AM','PM'],
        medium: 'MMM d, y h:mm:ss a',
        'short': 'M/d/yy h:mm a',
        fullDate: 'EEEE, MMMM d, y',
        longDate: 'MMMM d, y',
        mediumDate: 'MMM d, y',
        shortDate: 'M/d/yy',
        mediumTime: 'h:mm:ss a',
        shortTime: 'h:mm a',
        ERANAMES: [
          "Before Christ",
          "Anno Domini"
        ],
        ERAS: [
          "BC",
          "AD"
        ]
      },

      pluralCat: function(num) {
        if (num === 1) {
          return 'one';
        }
        return 'other';
      }
    };
  };
}

var PATH_MATCH = /^([^\?#]*)(\?([^#]*))?(#(.*))?$/,
    DEFAULT_PORTS = {'http': 80, 'https': 443, 'ftp': 21};
var $locationMinErr = minErr('$location');


/**
 * Encode path using encodeUriSegment, ignoring forward slashes
 *
 * @param {string} path Path to encode
 * @returns {string}
 */
function encodePath(path) {
  var segments = path.split('/'),
      i = segments.length;

  while (i--) {
    segments[i] = encodeUriSegment(segments[i]);
  }

  return segments.join('/');
}

function parseAbsoluteUrl(absoluteUrl, locationObj) {
  var parsedUrl = urlResolve(absoluteUrl);

  locationObj.$$protocol = parsedUrl.protocol;
  locationObj.$$host = parsedUrl.hostname;
  locationObj.$$port = int(parsedUrl.port) || DEFAULT_PORTS[parsedUrl.protocol] || null;
}


function parseAppUrl(relativeUrl, locationObj) {
  var prefixed = (relativeUrl.charAt(0) !== '/');
  if (prefixed) {
    relativeUrl = '/' + relativeUrl;
  }
  var match = urlResolve(relativeUrl);
  locationObj.$$path = decodeURIComponent(prefixed && match.pathname.charAt(0) === '/' ?
      match.pathname.substring(1) : match.pathname);
  locationObj.$$search = parseKeyValue(match.search);
  locationObj.$$hash = decodeURIComponent(match.hash);

  // make sure path starts with '/';
  if (locationObj.$$path && locationObj.$$path.charAt(0) != '/') {
    locationObj.$$path = '/' + locationObj.$$path;
  }
}


/**
 *
 * @param {string} begin
 * @param {string} whole
 * @returns {string} returns text from whole after begin or undefined if it does not begin with
 *                   expected string.
 */
function beginsWith(begin, whole) {
  if (whole.indexOf(begin) === 0) {
    return whole.substr(begin.length);
  }
}


function stripHash(url) {
  var index = url.indexOf('#');
  return index == -1 ? url : url.substr(0, index);
}

function trimEmptyHash(url) {
  return url.replace(/(#.+)|#$/, '$1');
}


function stripFile(url) {
  return url.substr(0, stripHash(url).lastIndexOf('/') + 1);
}

/* return the server only (scheme://host:port) */
function serverBase(url) {
  return url.substring(0, url.indexOf('/', url.indexOf('//') + 2));
}


/**
 * LocationHtml5Url represents an url
 * This object is exposed as $location service when HTML5 mode is enabled and supported
 *
 * @constructor
 * @param {string} appBase application base URL
 * @param {string} appBaseNoFile application base URL stripped of any filename
 * @param {string} basePrefix url path prefix
 */
function LocationHtml5Url(appBase, appBaseNoFile, basePrefix) {
  this.$$html5 = true;
  basePrefix = basePrefix || '';
  parseAbsoluteUrl(appBase, this);


  /**
   * Parse given html5 (regular) url string into properties
   * @param {string} url HTML5 url
   * @private
   */
  this.$$parse = function(url) {
    var pathUrl = beginsWith(appBaseNoFile, url);
    if (!isString(pathUrl)) {
      throw $locationMinErr('ipthprfx', 'Invalid url "{0}", missing path prefix "{1}".', url,
          appBaseNoFile);
    }

    parseAppUrl(pathUrl, this);

    if (!this.$$path) {
      this.$$path = '/';
    }

    this.$$compose();
  };

  /**
   * Compose url and update `absUrl` property
   * @private
   */
  this.$$compose = function() {
    var search = toKeyValue(this.$$search),
        hash = this.$$hash ? '#' + encodeUriSegment(this.$$hash) : '';

    this.$$url = encodePath(this.$$path) + (search ? '?' + search : '') + hash;
    this.$$absUrl = appBaseNoFile + this.$$url.substr(1); // first char is always '/'
  };

  this.$$parseLinkUrl = function(url, relHref) {
    if (relHref && relHref[0] === '#') {
      // special case for links to hash fragments:
      // keep the old url and only replace the hash fragment
      this.hash(relHref.slice(1));
      return true;
    }
    var appUrl, prevAppUrl;
    var rewrittenUrl;

    if ((appUrl = beginsWith(appBase, url)) !== undefined) {
      prevAppUrl = appUrl;
      if ((appUrl = beginsWith(basePrefix, appUrl)) !== undefined) {
        rewrittenUrl = appBaseNoFile + (beginsWith('/', appUrl) || appUrl);
      } else {
        rewrittenUrl = appBase + prevAppUrl;
      }
    } else if ((appUrl = beginsWith(appBaseNoFile, url)) !== undefined) {
      rewrittenUrl = appBaseNoFile + appUrl;
    } else if (appBaseNoFile == url + '/') {
      rewrittenUrl = appBaseNoFile;
    }
    if (rewrittenUrl) {
      this.$$parse(rewrittenUrl);
    }
    return !!rewrittenUrl;
  };
}


/**
 * LocationHashbangUrl represents url
 * This object is exposed as $location service when developer doesn't opt into html5 mode.
 * It also serves as the base class for html5 mode fallback on legacy browsers.
 *
 * @constructor
 * @param {string} appBase application base URL
 * @param {string} appBaseNoFile application base URL stripped of any filename
 * @param {string} hashPrefix hashbang prefix
 */
function LocationHashbangUrl(appBase, appBaseNoFile, hashPrefix) {

  parseAbsoluteUrl(appBase, this);


  /**
   * Parse given hashbang url into properties
   * @param {string} url Hashbang url
   * @private
   */
  this.$$parse = function(url) {
    var withoutBaseUrl = beginsWith(appBase, url) || beginsWith(appBaseNoFile, url);
    var withoutHashUrl;

    if (!isUndefined(withoutBaseUrl) && withoutBaseUrl.charAt(0) === '#') {

      // The rest of the url starts with a hash so we have
      // got either a hashbang path or a plain hash fragment
      withoutHashUrl = beginsWith(hashPrefix, withoutBaseUrl);
      if (isUndefined(withoutHashUrl)) {
        // There was no hashbang prefix so we just have a hash fragment
        withoutHashUrl = withoutBaseUrl;
      }

    } else {
      // There was no hashbang path nor hash fragment:
      // If we are in HTML5 mode we use what is left as the path;
      // Otherwise we ignore what is left
      if (this.$$html5) {
        withoutHashUrl = withoutBaseUrl;
      } else {
        withoutHashUrl = '';
        if (isUndefined(withoutBaseUrl)) {
          appBase = url;
          this.replace();
        }
      }
    }

    parseAppUrl(withoutHashUrl, this);

    this.$$path = removeWindowsDriveName(this.$$path, withoutHashUrl, appBase);

    this.$$compose();

    /*
     * In Windows, on an anchor node on documents loaded from
     * the filesystem, the browser will return a pathname
     * prefixed with the drive name ('/C:/path') when a
     * pathname without a drive is set:
     *  * a.setAttribute('href', '/foo')
     *   * a.pathname === '/C:/foo' //true
     *
     * Inside of Angular, we're always using pathnames that
     * do not include drive names for routing.
     */
    function removeWindowsDriveName(path, url, base) {
      /*
      Matches paths for file protocol on windows,
      such as /C:/foo/bar, and captures only /foo/bar.
      */
      var windowsFilePathExp = /^\/[A-Z]:(\/.*)/;

      var firstPathSegmentMatch;

      //Get the relative path from the input URL.
      if (url.indexOf(base) === 0) {
        url = url.replace(base, '');
      }

      // The input URL intentionally contains a first path segment that ends with a colon.
      if (windowsFilePathExp.exec(url)) {
        return path;
      }

      firstPathSegmentMatch = windowsFilePathExp.exec(path);
      return firstPathSegmentMatch ? firstPathSegmentMatch[1] : path;
    }
  };

  /**
   * Compose hashbang url and update `absUrl` property
   * @private
   */
  this.$$compose = function() {
    var search = toKeyValue(this.$$search),
        hash = this.$$hash ? '#' + encodeUriSegment(this.$$hash) : '';

    this.$$url = encodePath(this.$$path) + (search ? '?' + search : '') + hash;
    this.$$absUrl = appBase + (this.$$url ? hashPrefix + this.$$url : '');
  };

  this.$$parseLinkUrl = function(url, relHref) {
    if (stripHash(appBase) == stripHash(url)) {
      this.$$parse(url);
      return true;
    }
    return false;
  };
}


/**
 * LocationHashbangUrl represents url
 * This object is exposed as $location service when html5 history api is enabled but the browser
 * does not support it.
 *
 * @constructor
 * @param {string} appBase application base URL
 * @param {string} appBaseNoFile application base URL stripped of any filename
 * @param {string} hashPrefix hashbang prefix
 */
function LocationHashbangInHtml5Url(appBase, appBaseNoFile, hashPrefix) {
  this.$$html5 = true;
  LocationHashbangUrl.apply(this, arguments);

  this.$$parseLinkUrl = function(url, relHref) {
    if (relHref && relHref[0] === '#') {
      // special case for links to hash fragments:
      // keep the old url and only replace the hash fragment
      this.hash(relHref.slice(1));
      return true;
    }

    var rewrittenUrl;
    var appUrl;

    if (appBase == stripHash(url)) {
      rewrittenUrl = url;
    } else if ((appUrl = beginsWith(appBaseNoFile, url))) {
      rewrittenUrl = appBase + hashPrefix + appUrl;
    } else if (appBaseNoFile === url + '/') {
      rewrittenUrl = appBaseNoFile;
    }
    if (rewrittenUrl) {
      this.$$parse(rewrittenUrl);
    }
    return !!rewrittenUrl;
  };

  this.$$compose = function() {
    var search = toKeyValue(this.$$search),
        hash = this.$$hash ? '#' + encodeUriSegment(this.$$hash) : '';

    this.$$url = encodePath(this.$$path) + (search ? '?' + search : '') + hash;
    // include hashPrefix in $$absUrl when $$url is empty so IE9 does not reload page because of removal of '#'
    this.$$absUrl = appBase + hashPrefix + this.$$url;
  };

}


var locationPrototype = {

  /**
   * Are we in html5 mode?
   * @private
   */
  $$html5: false,

  /**
   * Has any change been replacing?
   * @private
   */
  $$replace: false,

  /**
   * @ngdoc method
   * @name $location#absUrl
   *
   * @description
   * This method is getter only.
   *
   * Return full url representation with all segments encoded according to rules specified in
   * [RFC 3986](http://www.ietf.org/rfc/rfc3986.txt).
   *
   *
   * ```js
   * // given url http://example.com/#/some/path?foo=bar&baz=xoxo
   * var absUrl = $location.absUrl();
   * // => "http://example.com/#/some/path?foo=bar&baz=xoxo"
   * ```
   *
   * @return {string} full url
   */
  absUrl: locationGetter('$$absUrl'),

  /**
   * @ngdoc method
   * @name $location#url
   *
   * @description
   * This method is getter / setter.
   *
   * Return url (e.g. `/path?a=b#hash`) when called without any parameter.
   *
   * Change path, search and hash, when called with parameter and return `$location`.
   *
   *
   * ```js
   * // given url http://example.com/#/some/path?foo=bar&baz=xoxo
   * var url = $location.url();
   * // => "/some/path?foo=bar&baz=xoxo"
   * ```
   *
   * @param {string=} url New url without base prefix (e.g. `/path?a=b#hash`)
   * @return {string} url
   */
  url: function(url) {
    if (isUndefined(url))
      return this.$$url;

    var match = PATH_MATCH.exec(url);
    if (match[1] || url === '') this.path(decodeURIComponent(match[1]));
    if (match[2] || match[1] || url === '') this.search(match[3] || '');
    this.hash(match[5] || '');

    return this;
  },

  /**
   * @ngdoc method
   * @name $location#protocol
   *
   * @description
   * This method is getter only.
   *
   * Return protocol of current url.
   *
   *
   * ```js
   * // given url http://example.com/#/some/path?foo=bar&baz=xoxo
   * var protocol = $location.protocol();
   * // => "http"
   * ```
   *
   * @return {string} protocol of current url
   */
  protocol: locationGetter('$$protocol'),

  /**
   * @ngdoc method
   * @name $location#host
   *
   * @description
   * This method is getter only.
   *
   * Return host of current url.
   *
   * Note: compared to the non-angular version `location.host` which returns `hostname:port`, this returns the `hostname` portion only.
   *
   *
   * ```js
   * // given url http://example.com/#/some/path?foo=bar&baz=xoxo
   * var host = $location.host();
   * // => "example.com"
   *
   * // given url http://user:password@example.com:8080/#/some/path?foo=bar&baz=xoxo
   * host = $location.host();
   * // => "example.com"
   * host = location.host;
   * // => "example.com:8080"
   * ```
   *
   * @return {string} host of current url.
   */
  host: locationGetter('$$host'),

  /**
   * @ngdoc method
   * @name $location#port
   *
   * @description
   * This method is getter only.
   *
   * Return port of current url.
   *
   *
   * ```js
   * // given url http://example.com/#/some/path?foo=bar&baz=xoxo
   * var port = $location.port();
   * // => 80
   * ```
   *
   * @return {Number} port
   */
  port: locationGetter('$$port'),

  /**
   * @ngdoc method
   * @name $location#path
   *
   * @description
   * This method is getter / setter.
   *
   * Return path of current url when called without any parameter.
   *
   * Change path when called with parameter and return `$location`.
   *
   * Note: Path should always begin with forward slash (/), this method will add the forward slash
   * if it is missing.
   *
   *
   * ```js
   * // given url http://example.com/#/some/path?foo=bar&baz=xoxo
   * var path = $location.path();
   * // => "/some/path"
   * ```
   *
   * @param {(string|number)=} path New path
   * @return {string} path
   */
  path: locationGetterSetter('$$path', function(path) {
    path = path !== null ? path.toString() : '';
    return path.charAt(0) == '/' ? path : '/' + path;
  }),

  /**
   * @ngdoc method
   * @name $location#search
   *
   * @description
   * This method is getter / setter.
   *
   * Return search part (as object) of current url when called without any parameter.
   *
   * Change search part when called with parameter and return `$location`.
   *
   *
   * ```js
   * // given url http://example.com/#/some/path?foo=bar&baz=xoxo
   * var searchObject = $location.search();
   * // => {foo: 'bar', baz: 'xoxo'}
   *
   * // set foo to 'yipee'
   * $location.search('foo', 'yipee');
   * // $location.search() => {foo: 'yipee', baz: 'xoxo'}
   * ```
   *
   * @param {string|Object.<string>|Object.<Array.<string>>} search New search params - string or
   * hash object.
   *
   * When called with a single argument the method acts as a setter, setting the `search` component
   * of `$location` to the specified value.
   *
   * If the argument is a hash object containing an array of values, these values will be encoded
   * as duplicate search parameters in the url.
   *
   * @param {(string|Number|Array<string>|boolean)=} paramValue If `search` is a string or number, then `paramValue`
   * will override only a single search property.
   *
   * If `paramValue` is an array, it will override the property of the `search` component of
   * `$location` specified via the first argument.
   *
   * If `paramValue` is `null`, the property specified via the first argument will be deleted.
   *
   * If `paramValue` is `true`, the property specified via the first argument will be added with no
   * value nor trailing equal sign.
   *
   * @return {Object} If called with no arguments returns the parsed `search` object. If called with
   * one or more arguments returns `$location` object itself.
   */
  search: function(search, paramValue) {
    switch (arguments.length) {
      case 0:
        return this.$$search;
      case 1:
        if (isString(search) || isNumber(search)) {
          search = search.toString();
          this.$$search = parseKeyValue(search);
        } else if (isObject(search)) {
          search = copy(search, {});
          // remove object undefined or null properties
          forEach(search, function(value, key) {
            if (value == null) delete search[key];
          });

          this.$$search = search;
        } else {
          throw $locationMinErr('isrcharg',
              'The first argument of the `$location#search()` call must be a string or an object.');
        }
        break;
      default:
        if (isUndefined(paramValue) || paramValue === null) {
          delete this.$$search[search];
        } else {
          this.$$search[search] = paramValue;
        }
    }

    this.$$compose();
    return this;
  },

  /**
   * @ngdoc method
   * @name $location#hash
   *
   * @description
   * This method is getter / setter.
   *
   * Return hash fragment when called without any parameter.
   *
   * Change hash fragment when called with parameter and return `$location`.
   *
   *
   * ```js
   * // given url http://example.com/#/some/path?foo=bar&baz=xoxo#hashValue
   * var hash = $location.hash();
   * // => "hashValue"
   * ```
   *
   * @param {(string|number)=} hash New hash fragment
   * @return {string} hash
   */
  hash: locationGetterSetter('$$hash', function(hash) {
    return hash !== null ? hash.toString() : '';
  }),

  /**
   * @ngdoc method
   * @name $location#replace
   *
   * @description
   * If called, all changes to $location during current `$digest` will be replacing current history
   * record, instead of adding new one.
   */
  replace: function() {
    this.$$replace = true;
    return this;
  }
};

forEach([LocationHashbangInHtml5Url, LocationHashbangUrl, LocationHtml5Url], function(Location) {
  Location.prototype = Object.create(locationPrototype);

  /**
   * @ngdoc method
   * @name $location#state
   *
   * @description
   * This method is getter / setter.
   *
   * Return the history state object when called without any parameter.
   *
   * Change the history state object when called with one parameter and return `$location`.
   * The state object is later passed to `pushState` or `replaceState`.
   *
   * NOTE: This method is supported only in HTML5 mode and only in browsers supporting
   * the HTML5 History API (i.e. methods `pushState` and `replaceState`). If you need to support
   * older browsers (like IE9 or Android < 4.0), don't use this method.
   *
   * @param {object=} state State object for pushState or replaceState
   * @return {object} state
   */
  Location.prototype.state = function(state) {
    if (!arguments.length)
      return this.$$state;

    if (Location !== LocationHtml5Url || !this.$$html5) {
      throw $locationMinErr('nostate', 'History API state support is available only ' +
        'in HTML5 mode and only in browsers supporting HTML5 History API');
    }
    // The user might modify `stateObject` after invoking `$location.state(stateObject)`
    // but we're changing the $$state reference to $browser.state() during the $digest
    // so the modification window is narrow.
    this.$$state = isUndefined(state) ? null : state;

    return this;
  };
});


function locationGetter(property) {
  return function() {
    return this[property];
  };
}


function locationGetterSetter(property, preprocess) {
  return function(value) {
    if (isUndefined(value))
      return this[property];

    this[property] = preprocess(value);
    this.$$compose();

    return this;
  };
}


/**
 * @ngdoc service
 * @name $location
 *
 * @requires $rootElement
 *
 * @description
 * The $location service parses the URL in the browser address bar (based on the
 * [window.location](https://developer.mozilla.org/en/window.location)) and makes the URL
 * available to your application. Changes to the URL in the address bar are reflected into
 * $location service and changes to $location are reflected into the browser address bar.
 *
 * **The $location service:**
 *
 * - Exposes the current URL in the browser address bar, so you can
 *   - Watch and observe the URL.
 *   - Change the URL.
 * - Synchronizes the URL with the browser when the user
 *   - Changes the address bar.
 *   - Clicks the back or forward button (or clicks a History link).
 *   - Clicks on a link.
 * - Represents the URL object as a set of methods (protocol, host, port, path, search, hash).
 *
 * For more information see {@link guide/$location Developer Guide: Using $location}
 */

/**
 * @ngdoc provider
 * @name $locationProvider
 * @description
 * Use the `$locationProvider` to configure how the application deep linking paths are stored.
 */
function $LocationProvider() {
  var hashPrefix = '',
      html5Mode = {
        enabled: false,
        requireBase: true,
        rewriteLinks: true
      };

  /**
   * @ngdoc method
   * @name $locationProvider#hashPrefix
   * @description
   * @param {string=} prefix Prefix for hash part (containing path and search)
   * @returns {*} current value if used as getter or itself (chaining) if used as setter
   */
  this.hashPrefix = function(prefix) {
    if (isDefined(prefix)) {
      hashPrefix = prefix;
      return this;
    } else {
      return hashPrefix;
    }
  };

  /**
   * @ngdoc method
   * @name $locationProvider#html5Mode
   * @description
   * @param {(boolean|Object)=} mode If boolean, sets `html5Mode.enabled` to value.
   *   If object, sets `enabled`, `requireBase` and `rewriteLinks` to respective values. Supported
   *   properties:
   *   - **enabled** – `{boolean}` – (default: false) If true, will rely on `history.pushState` to
   *     change urls where supported. Will fall back to hash-prefixed paths in browsers that do not
   *     support `pushState`.
   *   - **requireBase** - `{boolean}` - (default: `true`) When html5Mode is enabled, specifies
   *     whether or not a <base> tag is required to be present. If `enabled` and `requireBase` are
   *     true, and a base tag is not present, an error will be thrown when `$location` is injected.
   *     See the {@link guide/$location $location guide for more information}
   *   - **rewriteLinks** - `{boolean}` - (default: `true`) When html5Mode is enabled,
   *     enables/disables url rewriting for relative links.
   *
   * @returns {Object} html5Mode object if used as getter or itself (chaining) if used as setter
   */
  this.html5Mode = function(mode) {
    if (isBoolean(mode)) {
      html5Mode.enabled = mode;
      return this;
    } else if (isObject(mode)) {

      if (isBoolean(mode.enabled)) {
        html5Mode.enabled = mode.enabled;
      }

      if (isBoolean(mode.requireBase)) {
        html5Mode.requireBase = mode.requireBase;
      }

      if (isBoolean(mode.rewriteLinks)) {
        html5Mode.rewriteLinks = mode.rewriteLinks;
      }

      return this;
    } else {
      return html5Mode;
    }
  };

  /**
   * @ngdoc event
   * @name $location#$locationChangeStart
   * @eventType broadcast on root scope
   * @description
   * Broadcasted before a URL will change.
   *
   * This change can be prevented by calling
   * `preventDefault` method of the event. See {@link ng.$rootScope.Scope#$on} for more
   * details about event object. Upon successful change
   * {@link ng.$location#$locationChangeSuccess $locationChangeSuccess} is fired.
   *
   * The `newState` and `oldState` parameters may be defined only in HTML5 mode and when
   * the browser supports the HTML5 History API.
   *
   * @param {Object} angularEvent Synthetic event object.
   * @param {string} newUrl New URL
   * @param {string=} oldUrl URL that was before it was changed.
   * @param {string=} newState New history state object
   * @param {string=} oldState History state object that was before it was changed.
   */

  /**
   * @ngdoc event
   * @name $location#$locationChangeSuccess
   * @eventType broadcast on root scope
   * @description
   * Broadcasted after a URL was changed.
   *
   * The `newState` and `oldState` parameters may be defined only in HTML5 mode and when
   * the browser supports the HTML5 History API.
   *
   * @param {Object} angularEvent Synthetic event object.
   * @param {string} newUrl New URL
   * @param {string=} oldUrl URL that was before it was changed.
   * @param {string=} newState New history state object
   * @param {string=} oldState History state object that was before it was changed.
   */

  this.$get = ['$rootScope', '$browser', '$sniffer', '$rootElement', '$window',
      function($rootScope, $browser, $sniffer, $rootElement, $window) {
    var $location,
        LocationMode,
        baseHref = $browser.baseHref(), // if base[href] is undefined, it defaults to ''
        initialUrl = $browser.url(),
        appBase;

    if (html5Mode.enabled) {
      if (!baseHref && html5Mode.requireBase) {
        throw $locationMinErr('nobase',
          "$location in HTML5 mode requires a <base> tag to be present!");
      }
      appBase = serverBase(initialUrl) + (baseHref || '/');
      LocationMode = $sniffer.history ? LocationHtml5Url : LocationHashbangInHtml5Url;
    } else {
      appBase = stripHash(initialUrl);
      LocationMode = LocationHashbangUrl;
    }
    var appBaseNoFile = stripFile(appBase);

    $location = new LocationMode(appBase, appBaseNoFile, '#' + hashPrefix);
    $location.$$parseLinkUrl(initialUrl, initialUrl);

    $location.$$state = $browser.state();

    var IGNORE_URI_REGEXP = /^\s*(javascript|mailto):/i;

    function setBrowserUrlWithFallback(url, replace, state) {
      var oldUrl = $location.url();
      var oldState = $location.$$state;
      try {
        $browser.url(url, replace, state);

        // Make sure $location.state() returns referentially identical (not just deeply equal)
        // state object; this makes possible quick checking if the state changed in the digest
        // loop. Checking deep equality would be too expensive.
        $location.$$state = $browser.state();
      } catch (e) {
        // Restore old values if pushState fails
        $location.url(oldUrl);
        $location.$$state = oldState;

        throw e;
      }
    }

    $rootElement.on('click', function(event) {
      // TODO(vojta): rewrite link when opening in new tab/window (in legacy browser)
      // currently we open nice url link and redirect then

      if (!html5Mode.rewriteLinks || event.ctrlKey || event.metaKey || event.shiftKey || event.which == 2 || event.button == 2) return;

      var elm = jqLite(event.target);

      // traverse the DOM up to find first A tag
      while (nodeName_(elm[0]) !== 'a') {
        // ignore rewriting if no A tag (reached root element, or no parent - removed from document)
        if (elm[0] === $rootElement[0] || !(elm = elm.parent())[0]) return;
      }

      var absHref = elm.prop('href');
      // get the actual href attribute - see
      // http://msdn.microsoft.com/en-us/library/ie/dd347148(v=vs.85).aspx
      var relHref = elm.attr('href') || elm.attr('xlink:href');

      if (isObject(absHref) && absHref.toString() === '[object SVGAnimatedString]') {
        // SVGAnimatedString.animVal should be identical to SVGAnimatedString.baseVal, unless during
        // an animation.
        absHref = urlResolve(absHref.animVal).href;
      }

      // Ignore when url is started with javascript: or mailto:
      if (IGNORE_URI_REGEXP.test(absHref)) return;

      if (absHref && !elm.attr('target') && !event.isDefaultPrevented()) {
        if ($location.$$parseLinkUrl(absHref, relHref)) {
          // We do a preventDefault for all urls that are part of the angular application,
          // in html5mode and also without, so that we are able to abort navigation without
          // getting double entries in the location history.
          event.preventDefault();
          // update location manually
          if ($location.absUrl() != $browser.url()) {
            $rootScope.$apply();
            // hack to work around FF6 bug 684208 when scenario runner clicks on links
            $window.angular['ff-684208-preventDefault'] = true;
          }
        }
      }
    });


    // rewrite hashbang url <> html5 url
    if (trimEmptyHash($location.absUrl()) != trimEmptyHash(initialUrl)) {
      $browser.url($location.absUrl(), true);
    }

    var initializing = true;

    // update $location when $browser url changes
    $browser.onUrlChange(function(newUrl, newState) {

      if (isUndefined(beginsWith(appBaseNoFile, newUrl))) {
        // If we are navigating outside of the app then force a reload
        $window.location.href = newUrl;
        return;
      }

      $rootScope.$evalAsync(function() {
        var oldUrl = $location.absUrl();
        var oldState = $location.$$state;
        var defaultPrevented;

        $location.$$parse(newUrl);
        $location.$$state = newState;

        defaultPrevented = $rootScope.$broadcast('$locationChangeStart', newUrl, oldUrl,
            newState, oldState).defaultPrevented;

        // if the location was changed by a `$locationChangeStart` handler then stop
        // processing this location change
        if ($location.absUrl() !== newUrl) return;

        if (defaultPrevented) {
          $location.$$parse(oldUrl);
          $location.$$state = oldState;
          setBrowserUrlWithFallback(oldUrl, false, oldState);
        } else {
          initializing = false;
          afterLocationChange(oldUrl, oldState);
        }
      });
      if (!$rootScope.$$phase) $rootScope.$digest();
    });

    // update browser
    $rootScope.$watch(function $locationWatch() {
      var oldUrl = trimEmptyHash($browser.url());
      var newUrl = trimEmptyHash($location.absUrl());
      var oldState = $browser.state();
      var currentReplace = $location.$$replace;
      var urlOrStateChanged = oldUrl !== newUrl ||
        ($location.$$html5 && $sniffer.history && oldState !== $location.$$state);

      if (initializing || urlOrStateChanged) {
        initializing = false;

        $rootScope.$evalAsync(function() {
          var newUrl = $location.absUrl();
          var defaultPrevented = $rootScope.$broadcast('$locationChangeStart', newUrl, oldUrl,
              $location.$$state, oldState).defaultPrevented;

          // if the location was changed by a `$locationChangeStart` handler then stop
          // processing this location change
          if ($location.absUrl() !== newUrl) return;

          if (defaultPrevented) {
            $location.$$parse(oldUrl);
            $location.$$state = oldState;
          } else {
            if (urlOrStateChanged) {
              setBrowserUrlWithFallback(newUrl, currentReplace,
                                        oldState === $location.$$state ? null : $location.$$state);
            }
            afterLocationChange(oldUrl, oldState);
          }
        });
      }

      $location.$$replace = false;

      // we don't need to return anything because $evalAsync will make the digest loop dirty when
      // there is a change
    });

    return $location;

    function afterLocationChange(oldUrl, oldState) {
      $rootScope.$broadcast('$locationChangeSuccess', $location.absUrl(), oldUrl,
        $location.$$state, oldState);
    }
}];
}

/**
 * @ngdoc service
 * @name $log
 * @requires $window
 *
 * @description
 * Simple service for logging. Default implementation safely writes the message
 * into the browser's console (if present).
 *
 * The main purpose of this service is to simplify debugging and troubleshooting.
 *
 * The default is to log `debug` messages. You can use
 * {@link ng.$logProvider ng.$logProvider#debugEnabled} to change this.
 *
 * @example
   <example module="logExample">
     <file name="script.js">
       angular.module('logExample', [])
         .controller('LogController', ['$scope', '$log', function($scope, $log) {
           $scope.$log = $log;
           $scope.message = 'Hello World!';
         }]);
     </file>
     <file name="index.html">
       <div ng-controller="LogController">
         <p>Reload this page with open console, enter text and hit the log button...</p>
         Message:
         <input type="text" ng-model="message"/>
         <button ng-click="$log.log(message)">log</button>
         <button ng-click="$log.warn(message)">warn</button>
         <button ng-click="$log.info(message)">info</button>
         <button ng-click="$log.error(message)">error</button>
         <button ng-click="$log.debug(message)">debug</button>
       </div>
     </file>
   </example>
 */

/**
 * @ngdoc provider
 * @name $logProvider
 * @description
 * Use the `$logProvider` to configure how the application logs messages
 */
function $LogProvider() {
  var debug = true,
      self = this;

  /**
   * @ngdoc method
   * @name $logProvider#debugEnabled
   * @description
   * @param {boolean=} flag enable or disable debug level messages
   * @returns {*} current value if used as getter or itself (chaining) if used as setter
   */
  this.debugEnabled = function(flag) {
    if (isDefined(flag)) {
      debug = flag;
    return this;
    } else {
      return debug;
    }
  };

  this.$get = ['$window', function($window) {
    return {
      /**
       * @ngdoc method
       * @name $log#log
       *
       * @description
       * Write a log message
       */
      log: consoleLog('log'),

      /**
       * @ngdoc method
       * @name $log#info
       *
       * @description
       * Write an information message
       */
      info: consoleLog('info'),

      /**
       * @ngdoc method
       * @name $log#warn
       *
       * @description
       * Write a warning message
       */
      warn: consoleLog('warn'),

      /**
       * @ngdoc method
       * @name $log#error
       *
       * @description
       * Write an error message
       */
      error: consoleLog('error'),

      /**
       * @ngdoc method
       * @name $log#debug
       *
       * @description
       * Write a debug message
       */
      debug: (function() {
        var fn = consoleLog('debug');

        return function() {
          if (debug) {
            fn.apply(self, arguments);
          }
        };
      }())
    };

    function formatError(arg) {
      if (arg instanceof Error) {
        if (arg.stack) {
          arg = (arg.message && arg.stack.indexOf(arg.message) === -1)
              ? 'Error: ' + arg.message + '\n' + arg.stack
              : arg.stack;
        } else if (arg.sourceURL) {
          arg = arg.message + '\n' + arg.sourceURL + ':' + arg.line;
        }
      }
      return arg;
    }

    function consoleLog(type) {
      var console = $window.console || {},
          logFn = console[type] || console.log || noop,
          hasApply = false;

      // Note: reading logFn.apply throws an error in IE11 in IE8 document mode.
      // The reason behind this is that console.log has type "object" in IE8...
      try {
        hasApply = !!logFn.apply;
      } catch (e) {}

      if (hasApply) {
        return function() {
          var args = [];
          forEach(arguments, function(arg) {
            args.push(formatError(arg));
          });
          return logFn.apply(console, args);
        };
      }

      // we are IE which either doesn't have window.console => this is noop and we do nothing,
      // or we are IE where console.log doesn't have apply so we log at least first 2 args
      return function(arg1, arg2) {
        logFn(arg1, arg2 == null ? '' : arg2);
      };
    }
  }];
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 *     Any commits to this file should be reviewed with security in mind.  *
 *   Changes to this file can potentially create security vulnerabilities. *
 *          An approval from 2 Core members with history of modifying      *
 *                         this file is required.                          *
 *                                                                         *
 *  Does the change somehow allow for arbitrary javascript to be executed? *
 *    Or allows for someone to change the prototype of built-in objects?   *
 *     Or gives undesired access to variables likes document or window?    *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

var $parseMinErr = minErr('$parse');

// Sandboxing Angular Expressions
// ------------------------------
// Angular expressions are generally considered safe because these expressions only have direct
// access to `$scope` and locals. However, one can obtain the ability to execute arbitrary JS code by
// obtaining a reference to native JS functions such as the Function constructor.
//
// As an example, consider the following Angular expression:
//
//   {}.toString.constructor('alert("evil JS code")')
//
// This sandboxing technique is not perfect and doesn't aim to be. The goal is to prevent exploits
// against the expression language, but not to prevent exploits that were enabled by exposing
// sensitive JavaScript or browser APIs on Scope. Exposing such objects on a Scope is never a good
// practice and therefore we are not even trying to protect against interaction with an object
// explicitly exposed in this way.
//
// In general, it is not possible to access a Window object from an angular expression unless a
// window or some DOM object that has a reference to window is published onto a Scope.
// Similarly we prevent invocations of function known to be dangerous, as well as assignments to
// native objects.
//
// See https://docs.angularjs.org/guide/security


function ensureSafeMemberName(name, fullExpression) {
  if (name === "__defineGetter__" || name === "__defineSetter__"
      || name === "__lookupGetter__" || name === "__lookupSetter__"
      || name === "__proto__") {
    throw $parseMinErr('isecfld',
        'Attempting to access a disallowed field in Angular expressions! '
        + 'Expression: {0}', fullExpression);
  }
  return name;
}

function getStringValue(name, fullExpression) {
  // From the JavaScript docs:
  // Property names must be strings. This means that non-string objects cannot be used
  // as keys in an object. Any non-string object, including a number, is typecasted
  // into a string via the toString method.
  //
  // So, to ensure that we are checking the same `name` that JavaScript would use,
  // we cast it to a string, if possible.
  // Doing `name + ''` can cause a repl error if the result to `toString` is not a string,
  // this is, this will handle objects that misbehave.
  name = name + '';
  if (!isString(name)) {
    throw $parseMinErr('iseccst',
        'Cannot convert object to primitive value! '
        + 'Expression: {0}', fullExpression);
  }
  return name;
}

function ensureSafeObject(obj, fullExpression) {
  // nifty check if obj is Function that is fast and works across iframes and other contexts
  if (obj) {
    if (obj.constructor === obj) {
      throw $parseMinErr('isecfn',
          'Referencing Function in Angular expressions is disallowed! Expression: {0}',
          fullExpression);
    } else if (// isWindow(obj)
        obj.window === obj) {
      throw $parseMinErr('isecwindow',
          'Referencing the Window in Angular expressions is disallowed! Expression: {0}',
          fullExpression);
    } else if (// isElement(obj)
        obj.children && (obj.nodeName || (obj.prop && obj.attr && obj.find))) {
      throw $parseMinErr('isecdom',
          'Referencing DOM nodes in Angular expressions is disallowed! Expression: {0}',
          fullExpression);
    } else if (// block Object so that we can't get hold of dangerous Object.* methods
        obj === Object) {
      throw $parseMinErr('isecobj',
          'Referencing Object in Angular expressions is disallowed! Expression: {0}',
          fullExpression);
    }
  }
  return obj;
}

var CALL = Function.prototype.call;
var APPLY = Function.prototype.apply;
var BIND = Function.prototype.bind;

function ensureSafeFunction(obj, fullExpression) {
  if (obj) {
    if (obj.constructor === obj) {
      throw $parseMinErr('isecfn',
        'Referencing Function in Angular expressions is disallowed! Expression: {0}',
        fullExpression);
    } else if (obj === CALL || obj === APPLY || obj === BIND) {
      throw $parseMinErr('isecff',
        'Referencing call, apply or bind in Angular expressions is disallowed! Expression: {0}',
        fullExpression);
    }
  }
}

//Keyword constants
var CONSTANTS = createMap();
forEach({
  'null': function() { return null; },
  'true': function() { return true; },
  'false': function() { return false; },
  'undefined': function() {}
}, function(constantGetter, name) {
  constantGetter.constant = constantGetter.literal = constantGetter.sharedGetter = true;
  CONSTANTS[name] = constantGetter;
});

//Not quite a constant, but can be lex/parsed the same
CONSTANTS['this'] = function(self) { return self; };
CONSTANTS['this'].sharedGetter = true;


//Operators - will be wrapped by binaryFn/unaryFn/assignment/filter
var OPERATORS = extend(createMap(), {
    '+':function(self, locals, a, b) {
      a=a(self, locals); b=b(self, locals);
      if (isDefined(a)) {
        if (isDefined(b)) {
          return a + b;
        }
        return a;
      }
      return isDefined(b) ? b : undefined;},
    '-':function(self, locals, a, b) {
          a=a(self, locals); b=b(self, locals);
          return (isDefined(a) ? a : 0) - (isDefined(b) ? b : 0);
        },
    '*':function(self, locals, a, b) {return a(self, locals) * b(self, locals);},
    '/':function(self, locals, a, b) {return a(self, locals) / b(self, locals);},
    '%':function(self, locals, a, b) {return a(self, locals) % b(self, locals);},
    '===':function(self, locals, a, b) {return a(self, locals) === b(self, locals);},
    '!==':function(self, locals, a, b) {return a(self, locals) !== b(self, locals);},
    '==':function(self, locals, a, b) {return a(self, locals) == b(self, locals);},
    '!=':function(self, locals, a, b) {return a(self, locals) != b(self, locals);},
    '<':function(self, locals, a, b) {return a(self, locals) < b(self, locals);},
    '>':function(self, locals, a, b) {return a(self, locals) > b(self, locals);},
    '<=':function(self, locals, a, b) {return a(self, locals) <= b(self, locals);},
    '>=':function(self, locals, a, b) {return a(self, locals) >= b(self, locals);},
    '&&':function(self, locals, a, b) {return a(self, locals) && b(self, locals);},
    '||':function(self, locals, a, b) {return a(self, locals) || b(self, locals);},
    '!':function(self, locals, a) {return !a(self, locals);},

    //Tokenized as operators but parsed as assignment/filters
    '=':true,
    '|':true
});
var ESCAPE = {"n":"\n", "f":"\f", "r":"\r", "t":"\t", "v":"\v", "'":"'", '"':'"'};


/////////////////////////////////////////


/**
 * @constructor
 */
var Lexer = function(options) {
  this.options = options;
};

Lexer.prototype = {
  constructor: Lexer,

  lex: function(text) {
    this.text = text;
    this.index = 0;
    this.tokens = [];

    while (this.index < this.text.length) {
      var ch = this.text.charAt(this.index);
      if (ch === '"' || ch === "'") {
        this.readString(ch);
      } else if (this.isNumber(ch) || ch === '.' && this.isNumber(this.peek())) {
        this.readNumber();
      } else if (this.isIdent(ch)) {
        this.readIdent();
      } else if (this.is(ch, '(){}[].,;:?')) {
        this.tokens.push({index: this.index, text: ch});
        this.index++;
      } else if (this.isWhitespace(ch)) {
        this.index++;
      } else {
        var ch2 = ch + this.peek();
        var ch3 = ch2 + this.peek(2);
        var op1 = OPERATORS[ch];
        var op2 = OPERATORS[ch2];
        var op3 = OPERATORS[ch3];
        if (op1 || op2 || op3) {
          var token = op3 ? ch3 : (op2 ? ch2 : ch);
          this.tokens.push({index: this.index, text: token, operator: true});
          this.index += token.length;
        } else {
          this.throwError('Unexpected next character ', this.index, this.index + 1);
        }
      }
    }
    return this.tokens;
  },

  is: function(ch, chars) {
    return chars.indexOf(ch) !== -1;
  },

  peek: function(i) {
    var num = i || 1;
    return (this.index + num < this.text.length) ? this.text.charAt(this.index + num) : false;
  },

  isNumber: function(ch) {
    return ('0' <= ch && ch <= '9') && typeof ch === "string";
  },

  isWhitespace: function(ch) {
    // IE treats non-breaking space as \u00A0
    return (ch === ' ' || ch === '\r' || ch === '\t' ||
            ch === '\n' || ch === '\v' || ch === '\u00A0');
  },

  isIdent: function(ch) {
    return ('a' <= ch && ch <= 'z' ||
            'A' <= ch && ch <= 'Z' ||
            '_' === ch || ch === '$');
  },

  isExpOperator: function(ch) {
    return (ch === '-' || ch === '+' || this.isNumber(ch));
  },

  throwError: function(error, start, end) {
    end = end || this.index;
    var colStr = (isDefined(start)
            ? 's ' + start +  '-' + this.index + ' [' + this.text.substring(start, end) + ']'
            : ' ' + end);
    throw $parseMinErr('lexerr', 'Lexer Error: {0} at column{1} in expression [{2}].',
        error, colStr, this.text);
  },

  readNumber: function() {
    var number = '';
    var start = this.index;
    while (this.index < this.text.length) {
      var ch = lowercase(this.text.charAt(this.index));
      if (ch == '.' || this.isNumber(ch)) {
        number += ch;
      } else {
        var peekCh = this.peek();
        if (ch == 'e' && this.isExpOperator(peekCh)) {
          number += ch;
        } else if (this.isExpOperator(ch) &&
            peekCh && this.isNumber(peekCh) &&
            number.charAt(number.length - 1) == 'e') {
          number += ch;
        } else if (this.isExpOperator(ch) &&
            (!peekCh || !this.isNumber(peekCh)) &&
            number.charAt(number.length - 1) == 'e') {
          this.throwError('Invalid exponent');
        } else {
          break;
        }
      }
      this.index++;
    }
    this.tokens.push({
      index: start,
      text: number,
      constant: true,
      value: Number(number)
    });
  },

  readIdent: function() {
    var start = this.index;
    while (this.index < this.text.length) {
      var ch = this.text.charAt(this.index);
      if (!(this.isIdent(ch) || this.isNumber(ch))) {
        break;
      }
      this.index++;
    }
    this.tokens.push({
      index: start,
      text: this.text.slice(start, this.index),
      identifier: true
    });
  },

  readString: function(quote) {
    var start = this.index;
    this.index++;
    var string = '';
    var rawString = quote;
    var escape = false;
    while (this.index < this.text.length) {
      var ch = this.text.charAt(this.index);
      rawString += ch;
      if (escape) {
        if (ch === 'u') {
          var hex = this.text.substring(this.index + 1, this.index + 5);
          if (!hex.match(/[\da-f]{4}/i))
            this.throwError('Invalid unicode escape [\\u' + hex + ']');
          this.index += 4;
          string += String.fromCharCode(parseInt(hex, 16));
        } else {
          var rep = ESCAPE[ch];
          string = string + (rep || ch);
        }
        escape = false;
      } else if (ch === '\\') {
        escape = true;
      } else if (ch === quote) {
        this.index++;
        this.tokens.push({
          index: start,
          text: rawString,
          constant: true,
          value: string
        });
        return;
      } else {
        string += ch;
      }
      this.index++;
    }
    this.throwError('Unterminated quote', start);
  }
};


function isConstant(exp) {
  return exp.constant;
}

/**
 * @constructor
 */
var Parser = function(lexer, $filter, options) {
  this.lexer = lexer;
  this.$filter = $filter;
  this.options = options;
};

Parser.ZERO = extend(function() {
  return 0;
}, {
  sharedGetter: true,
  constant: true
});

Parser.prototype = {
  constructor: Parser,

  parse: function(text) {
    this.text = text;
    this.tokens = this.lexer.lex(text);

    var value = this.statements();

    if (this.tokens.length !== 0) {
      this.throwError('is an unexpected token', this.tokens[0]);
    }

    value.literal = !!value.literal;
    value.constant = !!value.constant;

    return value;
  },

  primary: function() {
    var primary;
    if (this.expect('(')) {
      primary = this.filterChain();
      this.consume(')');
    } else if (this.expect('[')) {
      primary = this.arrayDeclaration();
    } else if (this.expect('{')) {
      primary = this.object();
    } else if (this.peek().identifier && this.peek().text in CONSTANTS) {
      primary = CONSTANTS[this.consume().text];
    } else if (this.peek().identifier) {
      primary = this.identifier();
    } else if (this.peek().constant) {
      primary = this.constant();
    } else {
      this.throwError('not a primary expression', this.peek());
    }

    var next, context;
    while ((next = this.expect('(', '[', '.'))) {
      if (next.text === '(') {
        primary = this.functionCall(primary, context);
        context = null;
      } else if (next.text === '[') {
        context = primary;
        primary = this.objectIndex(primary);
      } else if (next.text === '.') {
        context = primary;
        primary = this.fieldAccess(primary);
      } else {
        this.throwError('IMPOSSIBLE');
      }
    }
    return primary;
  },

  throwError: function(msg, token) {
    throw $parseMinErr('syntax',
        'Syntax Error: Token \'{0}\' {1} at column {2} of the expression [{3}] starting at [{4}].',
          token.text, msg, (token.index + 1), this.text, this.text.substring(token.index));
  },

  peekToken: function() {
    if (this.tokens.length === 0)
      throw $parseMinErr('ueoe', 'Unexpected end of expression: {0}', this.text);
    return this.tokens[0];
  },

  peek: function(e1, e2, e3, e4) {
    return this.peekAhead(0, e1, e2, e3, e4);
  },
  peekAhead: function(i, e1, e2, e3, e4) {
    if (this.tokens.length > i) {
      var token = this.tokens[i];
      var t = token.text;
      if (t === e1 || t === e2 || t === e3 || t === e4 ||
          (!e1 && !e2 && !e3 && !e4)) {
        return token;
      }
    }
    return false;
  },

  expect: function(e1, e2, e3, e4) {
    var token = this.peek(e1, e2, e3, e4);
    if (token) {
      this.tokens.shift();
      return token;
    }
    return false;
  },

  consume: function(e1) {
    if (this.tokens.length === 0) {
      throw $parseMinErr('ueoe', 'Unexpected end of expression: {0}', this.text);
    }

    var token = this.expect(e1);
    if (!token) {
      this.throwError('is unexpected, expecting [' + e1 + ']', this.peek());
    }
    return token;
  },

  unaryFn: function(op, right) {
    var fn = OPERATORS[op];
    return extend(function $parseUnaryFn(self, locals) {
      return fn(self, locals, right);
    }, {
      constant:right.constant,
      inputs: [right]
    });
  },

  binaryFn: function(left, op, right, isBranching) {
    var fn = OPERATORS[op];
    return extend(function $parseBinaryFn(self, locals) {
      return fn(self, locals, left, right);
    }, {
      constant: left.constant && right.constant,
      inputs: !isBranching && [left, right]
    });
  },

  identifier: function() {
    var id = this.consume().text;

    //Continue reading each `.identifier` unless it is a method invocation
    while (this.peek('.') && this.peekAhead(1).identifier && !this.peekAhead(2, '(')) {
      id += this.consume().text + this.consume().text;
    }

    return getterFn(id, this.options, this.text);
  },

  constant: function() {
    var value = this.consume().value;

    return extend(function $parseConstant() {
      return value;
    }, {
      constant: true,
      literal: true
    });
  },

  statements: function() {
    var statements = [];
    while (true) {
      if (this.tokens.length > 0 && !this.peek('}', ')', ';', ']'))
        statements.push(this.filterChain());
      if (!this.expect(';')) {
        // optimize for the common case where there is only one statement.
        // TODO(size): maybe we should not support multiple statements?
        return (statements.length === 1)
            ? statements[0]
            : function $parseStatements(self, locals) {
                var value;
                for (var i = 0, ii = statements.length; i < ii; i++) {
                  value = statements[i](self, locals);
                }
                return value;
              };
      }
    }
  },

  filterChain: function() {
    var left = this.expression();
    var token;
    while ((token = this.expect('|'))) {
      left = this.filter(left);
    }
    return left;
  },

  filter: function(inputFn) {
    var fn = this.$filter(this.consume().text);
    var argsFn;
    var args;

    if (this.peek(':')) {
      argsFn = [];
      args = []; // we can safely reuse the array
      while (this.expect(':')) {
        argsFn.push(this.expression());
      }
    }

    var inputs = [inputFn].concat(argsFn || []);

    return extend(function $parseFilter(self, locals) {
      var input = inputFn(self, locals);
      if (args) {
        args[0] = input;

        var i = argsFn.length;
        while (i--) {
          args[i + 1] = argsFn[i](self, locals);
        }

        return fn.apply(undefined, args);
      }

      return fn(input);
    }, {
      constant: !fn.$stateful && inputs.every(isConstant),
      inputs: !fn.$stateful && inputs
    });
  },

  expression: function() {
    return this.assignment();
  },

  assignment: function() {
    var left = this.ternary();
    var right;
    var token;
    if ((token = this.expect('='))) {
      if (!left.assign) {
        this.throwError('implies assignment but [' +
            this.text.substring(0, token.index) + '] can not be assigned to', token);
      }
      right = this.ternary();
      return extend(function $parseAssignment(scope, locals) {
        return left.assign(scope, right(scope, locals), locals);
      }, {
        inputs: [left, right]
      });
    }
    return left;
  },

  ternary: function() {
    var left = this.logicalOR();
    var middle;
    var token;
    if ((token = this.expect('?'))) {
      middle = this.assignment();
      if (this.consume(':')) {
        var right = this.assignment();

        return extend(function $parseTernary(self, locals) {
          return left(self, locals) ? middle(self, locals) : right(self, locals);
        }, {
          constant: left.constant && middle.constant && right.constant
        });
      }
    }

    return left;
  },

  logicalOR: function() {
    var left = this.logicalAND();
    var token;
    while ((token = this.expect('||'))) {
      left = this.binaryFn(left, token.text, this.logicalAND(), true);
    }
    return left;
  },

  logicalAND: function() {
    var left = this.equality();
    var token;
    while ((token = this.expect('&&'))) {
      left = this.binaryFn(left, token.text, this.equality(), true);
    }
    return left;
  },

  equality: function() {
    var left = this.relational();
    var token;
    while ((token = this.expect('==','!=','===','!=='))) {
      left = this.binaryFn(left, token.text, this.relational());
    }
    return left;
  },

  relational: function() {
    var left = this.additive();
    var token;
    while ((token = this.expect('<', '>', '<=', '>='))) {
      left = this.binaryFn(left, token.text, this.additive());
    }
    return left;
  },

  additive: function() {
    var left = this.multiplicative();
    var token;
    while ((token = this.expect('+','-'))) {
      left = this.binaryFn(left, token.text, this.multiplicative());
    }
    return left;
  },

  multiplicative: function() {
    var left = this.unary();
    var token;
    while ((token = this.expect('*','/','%'))) {
      left = this.binaryFn(left, token.text, this.unary());
    }
    return left;
  },

  unary: function() {
    var token;
    if (this.expect('+')) {
      return this.primary();
    } else if ((token = this.expect('-'))) {
      return this.binaryFn(Parser.ZERO, token.text, this.unary());
    } else if ((token = this.expect('!'))) {
      return this.unaryFn(token.text, this.unary());
    } else {
      return this.primary();
    }
  },

  fieldAccess: function(object) {
    var getter = this.identifier();

    return extend(function $parseFieldAccess(scope, locals, self) {
      var o = self || object(scope, locals);
      return (o == null) ? undefined : getter(o);
    }, {
      assign: function(scope, value, locals) {
        var o = object(scope, locals);
        if (!o) object.assign(scope, o = {}, locals);
        return getter.assign(o, value);
      }
    });
  },

  objectIndex: function(obj) {
    var expression = this.text;

    var indexFn = this.expression();
    this.consume(']');

    return extend(function $parseObjectIndex(self, locals) {
      var o = obj(self, locals),
          i = getStringValue(indexFn(self, locals), expression),
          v;

      ensureSafeMemberName(i, expression);
      if (!o) return undefined;
      v = ensureSafeObject(o[i], expression);
      return v;
    }, {
      assign: function(self, value, locals) {
        var key = ensureSafeMemberName(getStringValue(indexFn(self, locals), expression), expression);
        // prevent overwriting of Function.constructor which would break ensureSafeObject check
        var o = ensureSafeObject(obj(self, locals), expression);
        if (!o) obj.assign(self, o = {}, locals);
        return o[key] = value;
      }
    });
  },

  functionCall: function(fnGetter, contextGetter) {
    var argsFn = [];
    if (this.peekToken().text !== ')') {
      do {
        argsFn.push(this.expression());
      } while (this.expect(','));
    }
    this.consume(')');

    var expressionText = this.text;
    // we can safely reuse the array across invocations
    var args = argsFn.length ? [] : null;

    return function $parseFunctionCall(scope, locals) {
      var context = contextGetter ? contextGetter(scope, locals) : isDefined(contextGetter) ? undefined : scope;
      var fn = fnGetter(scope, locals, context) || noop;

      if (args) {
        var i = argsFn.length;
        while (i--) {
          args[i] = ensureSafeObject(argsFn[i](scope, locals), expressionText);
        }
      }

      ensureSafeObject(context, expressionText);
      ensureSafeFunction(fn, expressionText);

      // IE doesn't have apply for some native functions
      var v = fn.apply
            ? fn.apply(context, args)
            : fn(args[0], args[1], args[2], args[3], args[4]);

      if (args) {
        // Free-up the memory (arguments of the last function call).
        args.length = 0;
      }

      return ensureSafeObject(v, expressionText);
      };
  },

  // This is used with json array declaration
  arrayDeclaration: function() {
    var elementFns = [];
    if (this.peekToken().text !== ']') {
      do {
        if (this.peek(']')) {
          // Support trailing commas per ES5.1.
          break;
        }
        elementFns.push(this.expression());
      } while (this.expect(','));
    }
    this.consume(']');

    return extend(function $parseArrayLiteral(self, locals) {
      var array = [];
      for (var i = 0, ii = elementFns.length; i < ii; i++) {
        array.push(elementFns[i](self, locals));
      }
      return array;
    }, {
      literal: true,
      constant: elementFns.every(isConstant),
      inputs: elementFns
    });
  },

  object: function() {
    var keys = [], valueFns = [];
    if (this.peekToken().text !== '}') {
      do {
        if (this.peek('}')) {
          // Support trailing commas per ES5.1.
          break;
        }
        var token = this.consume();
        if (token.constant) {
          keys.push(token.value);
        } else if (token.identifier) {
          keys.push(token.text);
        } else {
          this.throwError("invalid key", token);
        }
        this.consume(':');
        valueFns.push(this.expression());
      } while (this.expect(','));
    }
    this.consume('}');

    return extend(function $parseObjectLiteral(self, locals) {
      var object = {};
      for (var i = 0, ii = valueFns.length; i < ii; i++) {
        object[keys[i]] = valueFns[i](self, locals);
      }
      return object;
    }, {
      literal: true,
      constant: valueFns.every(isConstant),
      inputs: valueFns
    });
  }
};


//////////////////////////////////////////////////
// Parser helper functions
//////////////////////////////////////////////////

function setter(obj, locals, path, setValue, fullExp) {
  ensureSafeObject(obj, fullExp);
  ensureSafeObject(locals, fullExp);

  var element = path.split('.'), key;
  for (var i = 0; element.length > 1; i++) {
    key = ensureSafeMemberName(element.shift(), fullExp);
    var propertyObj = (i === 0 && locals && locals[key]) || obj[key];
    if (!propertyObj) {
      propertyObj = {};
      obj[key] = propertyObj;
    }
    obj = ensureSafeObject(propertyObj, fullExp);
  }
  key = ensureSafeMemberName(element.shift(), fullExp);
  ensureSafeObject(obj[key], fullExp);
  obj[key] = setValue;
  return setValue;
}

var getterFnCacheDefault = createMap();
var getterFnCacheExpensive = createMap();

function isPossiblyDangerousMemberName(name) {
  return name == 'constructor';
}

/**
 * Implementation of the "Black Hole" variant from:
 * - http://jsperf.com/angularjs-parse-getter/4
 * - http://jsperf.com/path-evaluation-simplified/7
 */
function cspSafeGetterFn(key0, key1, key2, key3, key4, fullExp, expensiveChecks) {
  ensureSafeMemberName(key0, fullExp);
  ensureSafeMemberName(key1, fullExp);
  ensureSafeMemberName(key2, fullExp);
  ensureSafeMemberName(key3, fullExp);
  ensureSafeMemberName(key4, fullExp);
  var eso = function(o) {
    return ensureSafeObject(o, fullExp);
  };
  var eso0 = (expensiveChecks || isPossiblyDangerousMemberName(key0)) ? eso : identity;
  var eso1 = (expensiveChecks || isPossiblyDangerousMemberName(key1)) ? eso : identity;
  var eso2 = (expensiveChecks || isPossiblyDangerousMemberName(key2)) ? eso : identity;
  var eso3 = (expensiveChecks || isPossiblyDangerousMemberName(key3)) ? eso : identity;
  var eso4 = (expensiveChecks || isPossiblyDangerousMemberName(key4)) ? eso : identity;

  return function cspSafeGetter(scope, locals) {
    var pathVal = (locals && locals.hasOwnProperty(key0)) ? locals : scope;

    if (pathVal == null) return pathVal;
    pathVal = eso0(pathVal[key0]);

    if (!key1) return pathVal;
    if (pathVal == null) return undefined;
    pathVal = eso1(pathVal[key1]);

    if (!key2) return pathVal;
    if (pathVal == null) return undefined;
    pathVal = eso2(pathVal[key2]);

    if (!key3) return pathVal;
    if (pathVal == null) return undefined;
    pathVal = eso3(pathVal[key3]);

    if (!key4) return pathVal;
    if (pathVal == null) return undefined;
    pathVal = eso4(pathVal[key4]);

    return pathVal;
  };
}

function getterFnWithEnsureSafeObject(fn, fullExpression) {
  return function(s, l) {
    return fn(s, l, ensureSafeObject, fullExpression);
  };
}

function getterFn(path, options, fullExp) {
  var expensiveChecks = options.expensiveChecks;
  var getterFnCache = (expensiveChecks ? getterFnCacheExpensive : getterFnCacheDefault);
  var fn = getterFnCache[path];
  if (fn) return fn;


  var pathKeys = path.split('.'),
      pathKeysLength = pathKeys.length;

  // http://jsperf.com/angularjs-parse-getter/6
  if (options.csp) {
    if (pathKeysLength < 6) {
      fn = cspSafeGetterFn(pathKeys[0], pathKeys[1], pathKeys[2], pathKeys[3], pathKeys[4], fullExp, expensiveChecks);
    } else {
      fn = function cspSafeGetter(scope, locals) {
        var i = 0, val;
        do {
          val = cspSafeGetterFn(pathKeys[i++], pathKeys[i++], pathKeys[i++], pathKeys[i++],
                                pathKeys[i++], fullExp, expensiveChecks)(scope, locals);

          locals = undefined; // clear after first iteration
          scope = val;
        } while (i < pathKeysLength);
        return val;
      };
    }
  } else {
    var code = '';
    if (expensiveChecks) {
      code += 's = eso(s, fe);\nl = eso(l, fe);\n';
    }
    var needsEnsureSafeObject = expensiveChecks;
    forEach(pathKeys, function(key, index) {
      ensureSafeMemberName(key, fullExp);
      var lookupJs = (index
                      // we simply dereference 's' on any .dot notation
                      ? 's'
                      // but if we are first then we check locals first, and if so read it first
                      : '((l&&l.hasOwnProperty("' + key + '"))?l:s)') + '.' + key;
      if (expensiveChecks || isPossiblyDangerousMemberName(key)) {
        lookupJs = 'eso(' + lookupJs + ', fe)';
        needsEnsureSafeObject = true;
      }
      code += 'if(s == null) return undefined;\n' +
              's=' + lookupJs + ';\n';
    });
    code += 'return s;';

    /* jshint -W054 */
    var evaledFnGetter = new Function('s', 'l', 'eso', 'fe', code); // s=scope, l=locals, eso=ensureSafeObject
    /* jshint +W054 */
    evaledFnGetter.toString = valueFn(code);
    if (needsEnsureSafeObject) {
      evaledFnGetter = getterFnWithEnsureSafeObject(evaledFnGetter, fullExp);
    }
    fn = evaledFnGetter;
  }

  fn.sharedGetter = true;
  fn.assign = function(self, value, locals) {
    return setter(self, locals, path, value, path);
  };
  getterFnCache[path] = fn;
  return fn;
}

var objectValueOf = Object.prototype.valueOf;

function getValueOf(value) {
  return isFunction(value.valueOf) ? value.valueOf() : objectValueOf.call(value);
}

///////////////////////////////////

/**
 * @ngdoc service
 * @name $parse
 * @kind function
 *
 * @description
 *
 * Converts Angular {@link guide/expression expression} into a function.
 *
 * ```js
 *   var getter = $parse('user.name');
 *   var setter = getter.assign;
 *   var context = {user:{name:'angular'}};
 *   var locals = {user:{name:'local'}};
 *
 *   expect(getter(context)).toEqual('angular');
 *   setter(context, 'newValue');
 *   expect(context.user.name).toEqual('newValue');
 *   expect(getter(context, locals)).toEqual('local');
 * ```
 *
 *
 * @param {string} expression String expression to compile.
 * @returns {function(context, locals)} a function which represents the compiled expression:
 *
 *    * `context` – `{object}` – an object against which any expressions embedded in the strings
 *      are evaluated against (typically a scope object).
 *    * `locals` – `{object=}` – local variables context object, useful for overriding values in
 *      `context`.
 *
 *    The returned function also has the following properties:
 *      * `literal` – `{boolean}` – whether the expression's top-level node is a JavaScript
 *        literal.
 *      * `constant` – `{boolean}` – whether the expression is made entirely of JavaScript
 *        constant literals.
 *      * `assign` – `{?function(context, value)}` – if the expression is assignable, this will be
 *        set to a function to change its value on the given context.
 *
 */


/**
 * @ngdoc provider
 * @name $parseProvider
 *
 * @description
 * `$parseProvider` can be used for configuring the default behavior of the {@link ng.$parse $parse}
 *  service.
 */
function $ParseProvider() {
  var cacheDefault = createMap();
  var cacheExpensive = createMap();



  this.$get = ['$filter', '$sniffer', function($filter, $sniffer) {
    var $parseOptions = {
          csp: $sniffer.csp,
          expensiveChecks: false
        },
        $parseOptionsExpensive = {
          csp: $sniffer.csp,
          expensiveChecks: true
        };

    function wrapSharedExpression(exp) {
      var wrapped = exp;

      if (exp.sharedGetter) {
        wrapped = function $parseWrapper(self, locals) {
          return exp(self, locals);
        };
        wrapped.literal = exp.literal;
        wrapped.constant = exp.constant;
        wrapped.assign = exp.assign;
      }

      return wrapped;
    }

    return function $parse(exp, interceptorFn, expensiveChecks) {
      var parsedExpression, oneTime, cacheKey;

      switch (typeof exp) {
        case 'string':
          cacheKey = exp = exp.trim();

          var cache = (expensiveChecks ? cacheExpensive : cacheDefault);
          parsedExpression = cache[cacheKey];

          if (!parsedExpression) {
            if (exp.charAt(0) === ':' && exp.charAt(1) === ':') {
              oneTime = true;
              exp = exp.substring(2);
            }

            var parseOptions = expensiveChecks ? $parseOptionsExpensive : $parseOptions;
            var lexer = new Lexer(parseOptions);
            var parser = new Parser(lexer, $filter, parseOptions);
            parsedExpression = parser.parse(exp);

            if (parsedExpression.constant) {
              parsedExpression.$$watchDelegate = constantWatchDelegate;
            } else if (oneTime) {
              //oneTime is not part of the exp passed to the Parser so we may have to
              //wrap the parsedExpression before adding a $$watchDelegate
              parsedExpression = wrapSharedExpression(parsedExpression);
              parsedExpression.$$watchDelegate = parsedExpression.literal ?
                oneTimeLiteralWatchDelegate : oneTimeWatchDelegate;
            } else if (parsedExpression.inputs) {
              parsedExpression.$$watchDelegate = inputsWatchDelegate;
            }

            cache[cacheKey] = parsedExpression;
          }
          return addInterceptor(parsedExpression, interceptorFn);

        case 'function':
          return addInterceptor(exp, interceptorFn);

        default:
          return addInterceptor(noop, interceptorFn);
      }
    };

    function collectExpressionInputs(inputs, list) {
      for (var i = 0, ii = inputs.length; i < ii; i++) {
        var input = inputs[i];
        if (!input.constant) {
          if (input.inputs) {
            collectExpressionInputs(input.inputs, list);
          } else if (list.indexOf(input) === -1) { // TODO(perf) can we do better?
            list.push(input);
          }
        }
      }

      return list;
    }

    function expressionInputDirtyCheck(newValue, oldValueOfValue) {

      if (newValue == null || oldValueOfValue == null) { // null/undefined
        return newValue === oldValueOfValue;
      }

      if (typeof newValue === 'object') {

        // attempt to convert the value to a primitive type
        // TODO(docs): add a note to docs that by implementing valueOf even objects and arrays can
        //             be cheaply dirty-checked
        newValue = getValueOf(newValue);

        if (typeof newValue === 'object') {
          // objects/arrays are not supported - deep-watching them would be too expensive
          return false;
        }

        // fall-through to the primitive equality check
      }

      //Primitive or NaN
      return newValue === oldValueOfValue || (newValue !== newValue && oldValueOfValue !== oldValueOfValue);
    }

    function inputsWatchDelegate(scope, listener, objectEquality, parsedExpression) {
      var inputExpressions = parsedExpression.$$inputs ||
                    (parsedExpression.$$inputs = collectExpressionInputs(parsedExpression.inputs, []));

      var lastResult;

      if (inputExpressions.length === 1) {
        var oldInputValue = expressionInputDirtyCheck; // init to something unique so that equals check fails
        inputExpressions = inputExpressions[0];
        return scope.$watch(function expressionInputWatch(scope) {
          var newInputValue = inputExpressions(scope);
          if (!expressionInputDirtyCheck(newInputValue, oldInputValue)) {
            lastResult = parsedExpression(scope);
            oldInputValue = newInputValue && getValueOf(newInputValue);
          }
          return lastResult;
        }, listener, objectEquality);
      }

      var oldInputValueOfValues = [];
      for (var i = 0, ii = inputExpressions.length; i < ii; i++) {
        oldInputValueOfValues[i] = expressionInputDirtyCheck; // init to something unique so that equals check fails
      }

      return scope.$watch(function expressionInputsWatch(scope) {
        var changed = false;

        for (var i = 0, ii = inputExpressions.length; i < ii; i++) {
          var newInputValue = inputExpressions[i](scope);
          if (changed || (changed = !expressionInputDirtyCheck(newInputValue, oldInputValueOfValues[i]))) {
            oldInputValueOfValues[i] = newInputValue && getValueOf(newInputValue);
          }
        }

        if (changed) {
          lastResult = parsedExpression(scope);
        }

        return lastResult;
      }, listener, objectEquality);
    }

    function oneTimeWatchDelegate(scope, listener, objectEquality, parsedExpression) {
      var unwatch, lastValue;
      return unwatch = scope.$watch(function oneTimeWatch(scope) {
        return parsedExpression(scope);
      }, function oneTimeListener(value, old, scope) {
        lastValue = value;
        if (isFunction(listener)) {
          listener.apply(this, arguments);
        }
        if (isDefined(value)) {
          scope.$$postDigest(function() {
            if (isDefined(lastValue)) {
              unwatch();
            }
          });
        }
      }, objectEquality);
    }

    function oneTimeLiteralWatchDelegate(scope, listener, objectEquality, parsedExpression) {
      var unwatch, lastValue;
      return unwatch = scope.$watch(function oneTimeWatch(scope) {
        return parsedExpression(scope);
      }, function oneTimeListener(value, old, scope) {
        lastValue = value;
        if (isFunction(listener)) {
          listener.call(this, value, old, scope);
        }
        if (isAllDefined(value)) {
          scope.$$postDigest(function() {
            if (isAllDefined(lastValue)) unwatch();
          });
        }
      }, objectEquality);

      function isAllDefined(value) {
        var allDefined = true;
        forEach(value, function(val) {
          if (!isDefined(val)) allDefined = false;
        });
        return allDefined;
      }
    }

    function constantWatchDelegate(scope, listener, objectEquality, parsedExpression) {
      var unwatch;
      return unwatch = scope.$watch(function constantWatch(scope) {
        return parsedExpression(scope);
      }, function constantListener(value, old, scope) {
        if (isFunction(listener)) {
          listener.apply(this, arguments);
        }
        unwatch();
      }, objectEquality);
    }

    function addInterceptor(parsedExpression, interceptorFn) {
      if (!interceptorFn) return parsedExpression;
      var watchDelegate = parsedExpression.$$watchDelegate;

      var regularWatch =
          watchDelegate !== oneTimeLiteralWatchDelegate &&
          watchDelegate !== oneTimeWatchDelegate;

      var fn = regularWatch ? function regularInterceptedExpression(scope, locals) {
        var value = parsedExpression(scope, locals);
        return interceptorFn(value, scope, locals);
      } : function oneTimeInterceptedExpression(scope, locals) {
        var value = parsedExpression(scope, locals);
        var result = interceptorFn(value, scope, locals);
        // we only return the interceptor's result if the
        // initial value is defined (for bind-once)
        return isDefined(value) ? result : value;
      };

      // Propagate $$watchDelegates other then inputsWatchDelegate
      if (parsedExpression.$$watchDelegate &&
          parsedExpression.$$watchDelegate !== inputsWatchDelegate) {
        fn.$$watchDelegate = parsedExpression.$$watchDelegate;
      } else if (!interceptorFn.$stateful) {
        // If there is an interceptor, but no watchDelegate then treat the interceptor like
        // we treat filters - it is assumed to be a pure function unless flagged with $stateful
        fn.$$watchDelegate = inputsWatchDelegate;
        fn.inputs = [parsedExpression];
      }

      return fn;
    }
  }];
}

/**
 * @ngdoc service
 * @name $q
 * @requires $rootScope
 *
 * @description
 * A service that helps you run functions asynchronously, and use their return values (or exceptions)
 * when they are done processing.
 *
 * This is an implementation of promises/deferred objects inspired by
 * [Kris Kowal's Q](https://github.com/kriskowal/q).
 *
 * $q can be used in two fashions --- one which is more similar to Kris Kowal's Q or jQuery's Deferred
 * implementations, and the other which resembles ES6 promises to some degree.
 *
 * # $q constructor
 *
 * The streamlined ES6 style promise is essentially just using $q as a constructor which takes a `resolver`
 * function as the first argument. This is similar to the native Promise implementation from ES6 Harmony,
 * see [MDN](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Promise).
 *
 * While the constructor-style use is supported, not all of the supporting methods from ES6 Harmony promises are
 * available yet.
 *
 * It can be used like so:
 *
 * ```js
 *   // for the purpose of this example let's assume that variables `$q` and `okToGreet`
 *   // are available in the current lexical scope (they could have been injected or passed in).
 *
 *   function asyncGreet(name) {
 *     // perform some asynchronous operation, resolve or reject the promise when appropriate.
 *     return $q(function(resolve, reject) {
 *       setTimeout(function() {
 *         if (okToGreet(name)) {
 *           resolve('Hello, ' + name + '!');
 *         } else {
 *           reject('Greeting ' + name + ' is not allowed.');
 *         }
 *       }, 1000);
 *     });
 *   }
 *
 *   var promise = asyncGreet('Robin Hood');
 *   promise.then(function(greeting) {
 *     alert('Success: ' + greeting);
 *   }, function(reason) {
 *     alert('Failed: ' + reason);
 *   });
 * ```
 *
 * Note: progress/notify callbacks are not currently supported via the ES6-style interface.
 *
 * However, the more traditional CommonJS-style usage is still available, and documented below.
 *
 * [The CommonJS Promise proposal](http://wiki.commonjs.org/wiki/Promises) describes a promise as an
 * interface for interacting with an object that represents the result of an action that is
 * performed asynchronously, and may or may not be finished at any given point in time.
 *
 * From the perspective of dealing with error handling, deferred and promise APIs are to
 * asynchronous programming what `try`, `catch` and `throw` keywords are to synchronous programming.
 *
 * ```js
 *   // for the purpose of this example let's assume that variables `$q` and `okToGreet`
 *   // are available in the current lexical scope (they could have been injected or passed in).
 *
 *   function asyncGreet(name) {
 *     var deferred = $q.defer();
 *
 *     setTimeout(function() {
 *       deferred.notify('About to greet ' + name + '.');
 *
 *       if (okToGreet(name)) {
 *         deferred.resolve('Hello, ' + name + '!');
 *       } else {
 *         deferred.reject('Greeting ' + name + ' is not allowed.');
 *       }
 *     }, 1000);
 *
 *     return deferred.promise;
 *   }
 *
 *   var promise = asyncGreet('Robin Hood');
 *   promise.then(function(greeting) {
 *     alert('Success: ' + greeting);
 *   }, function(reason) {
 *     alert('Failed: ' + reason);
 *   }, function(update) {
 *     alert('Got notification: ' + update);
 *   });
 * ```
 *
 * At first it might not be obvious why this extra complexity is worth the trouble. The payoff
 * comes in the way of guarantees that promise and deferred APIs make, see
 * https://github.com/kriskowal/uncommonjs/blob/master/promises/specification.md.
 *
 * Additionally the promise api allows for composition that is very hard to do with the
 * traditional callback ([CPS](http://en.wikipedia.org/wiki/Continuation-passing_style)) approach.
 * For more on this please see the [Q documentation](https://github.com/kriskowal/q) especially the
 * section on serial or parallel joining of promises.
 *
 * # The Deferred API
 *
 * A new instance of deferred is constructed by calling `$q.defer()`.
 *
 * The purpose of the deferred object is to expose the associated Promise instance as well as APIs
 * that can be used for signaling the successful or unsuccessful completion, as well as the status
 * of the task.
 *
 * **Methods**
 *
 * - `resolve(value)` – resolves the derived promise with the `value`. If the value is a rejection
 *   constructed via `$q.reject`, the promise will be rejected instead.
 * - `reject(reason)` – rejects the derived promise with the `reason`. This is equivalent to
 *   resolving it with a rejection constructed via `$q.reject`.
 * - `notify(value)` - provides updates on the status of the promise's execution. This may be called
 *   multiple times before the promise is either resolved or rejected.
 *
 * **Properties**
 *
 * - promise – `{Promise}` – promise object associated with this deferred.
 *
 *
 * # The Promise API
 *
 * A new promise instance is created when a deferred instance is created and can be retrieved by
 * calling `deferred.promise`.
 *
 * The purpose of the promise object is to allow for interested parties to get access to the result
 * of the deferred task when it completes.
 *
 * **Methods**
 *
 * - `then(successCallback, errorCallback, notifyCallback)` – regardless of when the promise was or
 *   will be resolved or rejected, `then` calls one of the success or error callbacks asynchronously
 *   as soon as the result is available. The callbacks are called with a single argument: the result
 *   or rejection reason. Additionally, the notify callback may be called zero or more times to
 *   provide a progress indication, before the promise is resolved or rejected.
 *
 *   This method *returns a new promise* which is resolved or rejected via the return value of the
 *   `successCallback`, `errorCallback`. It also notifies via the return value of the
 *   `notifyCallback` method. The promise cannot be resolved or rejected from the notifyCallback
 *   method.
 *
 * - `catch(errorCallback)` – shorthand for `promise.then(null, errorCallback)`
 *
 * - `finally(callback, notifyCallback)` – allows you to observe either the fulfillment or rejection of a promise,
 *   but to do so without modifying the final value. This is useful to release resources or do some
 *   clean-up that needs to be done whether the promise was rejected or resolved. See the [full
 *   specification](https://github.com/kriskowal/q/wiki/API-Reference#promisefinallycallback) for
 *   more information.
 *
 * # Chaining promises
 *
 * Because calling the `then` method of a promise returns a new derived promise, it is easily
 * possible to create a chain of promises:
 *
 * ```js
 *   promiseB = promiseA.then(function(result) {
 *     return result + 1;
 *   });
 *
 *   // promiseB will be resolved immediately after promiseA is resolved and its value
 *   // will be the result of promiseA incremented by 1
 * ```
 *
 * It is possible to create chains of any length and since a promise can be resolved with another
 * promise (which will defer its resolution further), it is possible to pause/defer resolution of
 * the promises at any point in the chain. This makes it possible to implement powerful APIs like
 * $http's response interceptors.
 *
 *
 * # Differences between Kris Kowal's Q and $q
 *
 *  There are two main differences:
 *
 * - $q is integrated with the {@link ng.$rootScope.Scope} Scope model observation
 *   mechanism in angular, which means faster propagation of resolution or rejection into your
 *   models and avoiding unnecessary browser repaints, which would result in flickering UI.
 * - Q has many more features than $q, but that comes at a cost of bytes. $q is tiny, but contains
 *   all the important functionality needed for common async tasks.
 *
 *  # Testing
 *
 *  ```js
 *    it('should simulate promise', inject(function($q, $rootScope) {
 *      var deferred = $q.defer();
 *      var promise = deferred.promise;
 *      var resolvedValue;
 *
 *      promise.then(function(value) { resolvedValue = value; });
 *      expect(resolvedValue).toBeUndefined();
 *
 *      // Simulate resolving of promise
 *      deferred.resolve(123);
 *      // Note that the 'then' function does not get called synchronously.
 *      // This is because we want the promise API to always be async, whether or not
 *      // it got called synchronously or asynchronously.
 *      expect(resolvedValue).toBeUndefined();
 *
 *      // Propagate promise resolution to 'then' functions using $apply().
 *      $rootScope.$apply();
 *      expect(resolvedValue).toEqual(123);
 *    }));
 *  ```
 *
 * @param {function(function, function)} resolver Function which is responsible for resolving or
 *   rejecting the newly created promise. The first parameter is a function which resolves the
 *   promise, the second parameter is a function which rejects the promise.
 *
 * @returns {Promise} The newly created promise.
 */
function $QProvider() {

  this.$get = ['$rootScope', '$exceptionHandler', function($rootScope, $exceptionHandler) {
    return qFactory(function(callback) {
      $rootScope.$evalAsync(callback);
    }, $exceptionHandler);
  }];
}

function $$QProvider() {
  this.$get = ['$browser', '$exceptionHandler', function($browser, $exceptionHandler) {
    return qFactory(function(callback) {
      $browser.defer(callback);
    }, $exceptionHandler);
  }];
}

/**
 * Constructs a promise manager.
 *
 * @param {function(function)} nextTick Function for executing functions in the next turn.
 * @param {function(...*)} exceptionHandler Function into which unexpected exceptions are passed for
 *     debugging purposes.
 * @returns {object} Promise manager.
 */
function qFactory(nextTick, exceptionHandler) {
  var $qMinErr = minErr('$q', TypeError);
  function callOnce(self, resolveFn, rejectFn) {
    var called = false;
    function wrap(fn) {
      return function(value) {
        if (called) return;
        called = true;
        fn.call(self, value);
      };
    }

    return [wrap(resolveFn), wrap(rejectFn)];
  }

  /**
   * @ngdoc method
   * @name ng.$q#defer
   * @kind function
   *
   * @description
   * Creates a `Deferred` object which represents a task which will finish in the future.
   *
   * @returns {Deferred} Returns a new instance of deferred.
   */
  var defer = function() {
    return new Deferred();
  };

  function Promise() {
    this.$$state = { status: 0 };
  }

  Promise.prototype = {
    then: function(onFulfilled, onRejected, progressBack) {
      var result = new Deferred();

      this.$$state.pending = this.$$state.pending || [];
      this.$$state.pending.push([result, onFulfilled, onRejected, progressBack]);
      if (this.$$state.status > 0) scheduleProcessQueue(this.$$state);

      return result.promise;
    },

    "catch": function(callback) {
      return this.then(null, callback);
    },

    "finally": function(callback, progressBack) {
      return this.then(function(value) {
        return handleCallback(value, true, callback);
      }, function(error) {
        return handleCallback(error, false, callback);
      }, progressBack);
    }
  };

  //Faster, more basic than angular.bind http://jsperf.com/angular-bind-vs-custom-vs-native
  function simpleBind(context, fn) {
    return function(value) {
      fn.call(context, value);
    };
  }

  function processQueue(state) {
    var fn, promise, pending;

    pending = state.pending;
    state.processScheduled = false;
    state.pending = undefined;
    for (var i = 0, ii = pending.length; i < ii; ++i) {
      promise = pending[i][0];
      fn = pending[i][state.status];
      try {
        if (isFunction(fn)) {
          promise.resolve(fn(state.value));
        } else if (state.status === 1) {
          promise.resolve(state.value);
        } else {
          promise.reject(state.value);
        }
      } catch (e) {
        promise.reject(e);
        exceptionHandler(e);
      }
    }
  }

  function scheduleProcessQueue(state) {
    if (state.processScheduled || !state.pending) return;
    state.processScheduled = true;
    nextTick(function() { processQueue(state); });
  }

  function Deferred() {
    this.promise = new Promise();
    //Necessary to support unbound execution :/
    this.resolve = simpleBind(this, this.resolve);
    this.reject = simpleBind(this, this.reject);
    this.notify = simpleBind(this, this.notify);
  }

  Deferred.prototype = {
    resolve: function(val) {
      if (this.promise.$$state.status) return;
      if (val === this.promise) {
        this.$$reject($qMinErr(
          'qcycle',
          "Expected promise to be resolved with value other than itself '{0}'",
          val));
      } else {
        this.$$resolve(val);
      }

    },

    $$resolve: function(val) {
      var then, fns;

      fns = callOnce(this, this.$$resolve, this.$$reject);
      try {
        if ((isObject(val) || isFunction(val))) then = val && val.then;
        if (isFunction(then)) {
          this.promise.$$state.status = -1;
          then.call(val, fns[0], fns[1], this.notify);
        } else {
          this.promise.$$state.value = val;
          this.promise.$$state.status = 1;
          scheduleProcessQueue(this.promise.$$state);
        }
      } catch (e) {
        fns[1](e);
        exceptionHandler(e);
      }
    },

    reject: function(reason) {
      if (this.promise.$$state.status) return;
      this.$$reject(reason);
    },

    $$reject: function(reason) {
      this.promise.$$state.value = reason;
      this.promise.$$state.status = 2;
      scheduleProcessQueue(this.promise.$$state);
    },

    notify: function(progress) {
      var callbacks = this.promise.$$state.pending;

      if ((this.promise.$$state.status <= 0) && callbacks && callbacks.length) {
        nextTick(function() {
          var callback, result;
          for (var i = 0, ii = callbacks.length; i < ii; i++) {
            result = callbacks[i][0];
            callback = callbacks[i][3];
            try {
              result.notify(isFunction(callback) ? callback(progress) : progress);
            } catch (e) {
              exceptionHandler(e);
            }
          }
        });
      }
    }
  };

  /**
   * @ngdoc method
   * @name $q#reject
   * @kind function
   *
   * @description
   * Creates a promise that is resolved as rejected with the specified `reason`. This api should be
   * used to forward rejection in a chain of promises. If you are dealing with the last promise in
   * a promise chain, you don't need to worry about it.
   *
   * When comparing deferreds/promises to the familiar behavior of try/catch/throw, think of
   * `reject` as the `throw` keyword in JavaScript. This also means that if you "catch" an error via
   * a promise error callback and you want to forward the error to the promise derived from the
   * current promise, you have to "rethrow" the error by returning a rejection constructed via
   * `reject`.
   *
   * ```js
   *   promiseB = promiseA.then(function(result) {
   *     // success: do something and resolve promiseB
   *     //          with the old or a new result
   *     return result;
   *   }, function(reason) {
   *     // error: handle the error if possible and
   *     //        resolve promiseB with newPromiseOrValue,
   *     //        otherwise forward the rejection to promiseB
   *     if (canHandle(reason)) {
   *      // handle the error and recover
   *      return newPromiseOrValue;
   *     }
   *     return $q.reject(reason);
   *   });
   * ```
   *
   * @param {*} reason Constant, message, exception or an object representing the rejection reason.
   * @returns {Promise} Returns a promise that was already resolved as rejected with the `reason`.
   */
  var reject = function(reason) {
    var result = new Deferred();
    result.reject(reason);
    return result.promise;
  };

  var makePromise = function makePromise(value, resolved) {
    var result = new Deferred();
    if (resolved) {
      result.resolve(value);
    } else {
      result.reject(value);
    }
    return result.promise;
  };

  var handleCallback = function handleCallback(value, isResolved, callback) {
    var callbackOutput = null;
    try {
      if (isFunction(callback)) callbackOutput = callback();
    } catch (e) {
      return makePromise(e, false);
    }
    if (isPromiseLike(callbackOutput)) {
      return callbackOutput.then(function() {
        return makePromise(value, isResolved);
      }, function(error) {
        return makePromise(error, false);
      });
    } else {
      return makePromise(value, isResolved);
    }
  };

  /**
   * @ngdoc method
   * @name $q#when
   * @kind function
   *
   * @description
   * Wraps an object that might be a value or a (3rd party) then-able promise into a $q promise.
   * This is useful when you are dealing with an object that might or might not be a promise, or if
   * the promise comes from a source that can't be trusted.
   *
   * @param {*} value Value or a promise
   * @returns {Promise} Returns a promise of the passed value or promise
   */


  var when = function(value, callback, errback, progressBack) {
    var result = new Deferred();
    result.resolve(value);
    return result.promise.then(callback, errback, progressBack);
  };

  /**
   * @ngdoc method
   * @name $q#all
   * @kind function
   *
   * @description
   * Combines multiple promises into a single promise that is resolved when all of the input
   * promises are resolved.
   *
   * @param {Array.<Promise>|Object.<Promise>} promises An array or hash of promises.
   * @returns {Promise} Returns a single promise that will be resolved with an array/hash of values,
   *   each value corresponding to the promise at the same index/key in the `promises` array/hash.
   *   If any of the promises is resolved with a rejection, this resulting promise will be rejected
   *   with the same rejection value.
   */

  function all(promises) {
    var deferred = new Deferred(),
        counter = 0,
        results = isArray(promises) ? [] : {};

    forEach(promises, function(promise, key) {
      counter++;
      when(promise).then(function(value) {
        if (results.hasOwnProperty(key)) return;
        results[key] = value;
        if (!(--counter)) deferred.resolve(results);
      }, function(reason) {
        if (results.hasOwnProperty(key)) return;
        deferred.reject(reason);
      });
    });

    if (counter === 0) {
      deferred.resolve(results);
    }

    return deferred.promise;
  }

  var $Q = function Q(resolver) {
    if (!isFunction(resolver)) {
      throw $qMinErr('norslvr', "Expected resolverFn, got '{0}'", resolver);
    }

    if (!(this instanceof Q)) {
      // More useful when $Q is the Promise itself.
      return new Q(resolver);
    }

    var deferred = new Deferred();

    function resolveFn(value) {
      deferred.resolve(value);
    }

    function rejectFn(reason) {
      deferred.reject(reason);
    }

    resolver(resolveFn, rejectFn);

    return deferred.promise;
  };

  $Q.defer = defer;
  $Q.reject = reject;
  $Q.when = when;
  $Q.all = all;

  return $Q;
}

function $$RAFProvider() { //rAF
  this.$get = ['$window', '$timeout', function($window, $timeout) {
    var requestAnimationFrame = $window.requestAnimationFrame ||
                                $window.webkitRequestAnimationFrame;

    var cancelAnimationFrame = $window.cancelAnimationFrame ||
                               $window.webkitCancelAnimationFrame ||
                               $window.webkitCancelRequestAnimationFrame;

    var rafSupported = !!requestAnimationFrame;
    var rafFn = rafSupported
      ? function(fn) {
          var id = requestAnimationFrame(fn);
          return function() {
            cancelAnimationFrame(id);
          };
        }
      : function(fn) {
          var timer = $timeout(fn, 16.66, false); // 1000 / 60 = 16.666
          return function() {
            $timeout.cancel(timer);
          };
        };

    queueFn.supported = rafSupported;

    var cancelLastRAF;
    var taskCount = 0;
    var taskQueue = [];
    return queueFn;

    function flush() {
      for (var i = 0; i < taskQueue.length; i++) {
        var task = taskQueue[i];
        if (task) {
          taskQueue[i] = null;
          task();
        }
      }
      taskCount = taskQueue.length = 0;
    }

    function queueFn(asyncFn) {
      var index = taskQueue.length;

      taskCount++;
      taskQueue.push(asyncFn);

      if (index === 0) {
        cancelLastRAF = rafFn(flush);
      }

      return function cancelQueueFn() {
        if (index >= 0) {
          taskQueue[index] = null;
          index = null;

          if (--taskCount === 0 && cancelLastRAF) {
            cancelLastRAF();
            cancelLastRAF = null;
            taskQueue.length = 0;
          }
        }
      };
    }
  }];
}

/**
 * DESIGN NOTES
 *
 * The design decisions behind the scope are heavily favored for speed and memory consumption.
 *
 * The typical use of scope is to watch the expressions, which most of the time return the same
 * value as last time so we optimize the operation.
 *
 * Closures construction is expensive in terms of speed as well as memory:
 *   - No closures, instead use prototypical inheritance for API
 *   - Internal state needs to be stored on scope directly, which means that private state is
 *     exposed as $$____ properties
 *
 * Loop operations are optimized by using while(count--) { ... }
 *   - this means that in order to keep the same order of execution as addition we have to add
 *     items to the array at the beginning (unshift) instead of at the end (push)
 *
 * Child scopes are created and removed often
 *   - Using an array would be slow since inserts in middle are expensive so we use linked list
 *
 * There are few watches then a lot of observers. This is why you don't want the observer to be
 * implemented in the same way as watch. Watch requires return of initialization function which
 * are expensive to construct.
 */


/**
 * @ngdoc provider
 * @name $rootScopeProvider
 * @description
 *
 * Provider for the $rootScope service.
 */

/**
 * @ngdoc method
 * @name $rootScopeProvider#digestTtl
 * @description
 *
 * Sets the number of `$digest` iterations the scope should attempt to execute before giving up and
 * assuming that the model is unstable.
 *
 * The current default is 10 iterations.
 *
 * In complex applications it's possible that the dependencies between `$watch`s will result in
 * several digest iterations. However if an application needs more than the default 10 digest
 * iterations for its model to stabilize then you should investigate what is causing the model to
 * continuously change during the digest.
 *
 * Increasing the TTL could have performance implications, so you should not change it without
 * proper justification.
 *
 * @param {number} limit The number of digest iterations.
 */


/**
 * @ngdoc service
 * @name $rootScope
 * @description
 *
 * Every application has a single root {@link ng.$rootScope.Scope scope}.
 * All other scopes are descendant scopes of the root scope. Scopes provide separation
 * between the model and the view, via a mechanism for watching the model for changes.
 * They also provide an event emission/broadcast and subscription facility. See the
 * {@link guide/scope developer guide on scopes}.
 */
function $RootScopeProvider() {
  var TTL = 10;
  var $rootScopeMinErr = minErr('$rootScope');
  var lastDirtyWatch = null;
  var applyAsyncId = null;

  this.digestTtl = function(value) {
    if (arguments.length) {
      TTL = value;
    }
    return TTL;
  };

  function createChildScopeClass(parent) {
    function ChildScope() {
      this.$$watchers = this.$$nextSibling =
          this.$$childHead = this.$$childTail = null;
      this.$$listeners = {};
      this.$$listenerCount = {};
      this.$id = nextUid();
      this.$$ChildScope = null;
    }
    ChildScope.prototype = parent;
    return ChildScope;
  }

  this.$get = ['$injector', '$exceptionHandler', '$parse', '$browser',
      function($injector, $exceptionHandler, $parse, $browser) {

    function destroyChildScope($event) {
        $event.currentScope.$$destroyed = true;
    }

    /**
     * @ngdoc type
     * @name $rootScope.Scope
     *
     * @description
     * A root scope can be retrieved using the {@link ng.$rootScope $rootScope} key from the
     * {@link auto.$injector $injector}. Child scopes are created using the
     * {@link ng.$rootScope.Scope#$new $new()} method. (Most scopes are created automatically when
     * compiled HTML template is executed.) See also the {@link guide/scope Scopes guide} for
     * an in-depth introduction and usage examples.
     *
     *
     * # Inheritance
     * A scope can inherit from a parent scope, as in this example:
     * ```js
         var parent = $rootScope;
         var child = parent.$new();

         parent.salutation = "Hello";
         expect(child.salutation).toEqual('Hello');

         child.salutation = "Welcome";
         expect(child.salutation).toEqual('Welcome');
         expect(parent.salutation).toEqual('Hello');
     * ```
     *
     * When interacting with `Scope` in tests, additional helper methods are available on the
     * instances of `Scope` type. See {@link ngMock.$rootScope.Scope ngMock Scope} for additional
     * details.
     *
     *
     * @param {Object.<string, function()>=} providers Map of service factory which need to be
     *                                       provided for the current scope. Defaults to {@link ng}.
     * @param {Object.<string, *>=} instanceCache Provides pre-instantiated services which should
     *                              append/override services provided by `providers`. This is handy
     *                              when unit-testing and having the need to override a default
     *                              service.
     * @returns {Object} Newly created scope.
     *
     */
    function Scope() {
      this.$id = nextUid();
      this.$$phase = this.$parent = this.$$watchers =
                     this.$$nextSibling = this.$$prevSibling =
                     this.$$childHead = this.$$childTail = null;
      this.$root = this;
      this.$$destroyed = false;
      this.$$listeners = {};
      this.$$listenerCount = {};
      this.$$isolateBindings = null;
    }

    /**
     * @ngdoc property
     * @name $rootScope.Scope#$id
     *
     * @description
     * Unique scope ID (monotonically increasing) useful for debugging.
     */

     /**
      * @ngdoc property
      * @name $rootScope.Scope#$parent
      *
      * @description
      * Reference to the parent scope.
      */

      /**
       * @ngdoc property
       * @name $rootScope.Scope#$root
       *
       * @description
       * Reference to the root scope.
       */

    Scope.prototype = {
      constructor: Scope,
      /**
       * @ngdoc method
       * @name $rootScope.Scope#$new
       * @kind function
       *
       * @description
       * Creates a new child {@link ng.$rootScope.Scope scope}.
       *
       * The parent scope will propagate the {@link ng.$rootScope.Scope#$digest $digest()} event.
       * The scope can be removed from the scope hierarchy using {@link ng.$rootScope.Scope#$destroy $destroy()}.
       *
       * {@link ng.$rootScope.Scope#$destroy $destroy()} must be called on a scope when it is
       * desired for the scope and its child scopes to be permanently detached from the parent and
       * thus stop participating in model change detection and listener notification by invoking.
       *
       * @param {boolean} isolate If true, then the scope does not prototypically inherit from the
       *         parent scope. The scope is isolated, as it can not see parent scope properties.
       *         When creating widgets, it is useful for the widget to not accidentally read parent
       *         state.
       *
       * @param {Scope} [parent=this] The {@link ng.$rootScope.Scope `Scope`} that will be the `$parent`
       *                              of the newly created scope. Defaults to `this` scope if not provided.
       *                              This is used when creating a transclude scope to correctly place it
       *                              in the scope hierarchy while maintaining the correct prototypical
       *                              inheritance.
       *
       * @returns {Object} The newly created child scope.
       *
       */
      $new: function(isolate, parent) {
        var child;

        parent = parent || this;

        if (isolate) {
          child = new Scope();
          child.$root = this.$root;
        } else {
          // Only create a child scope class if somebody asks for one,
          // but cache it to allow the VM to optimize lookups.
          if (!this.$$ChildScope) {
            this.$$ChildScope = createChildScopeClass(this);
          }
          child = new this.$$ChildScope();
        }
        child.$parent = parent;
        child.$$prevSibling = parent.$$childTail;
        if (parent.$$childHead) {
          parent.$$childTail.$$nextSibling = child;
          parent.$$childTail = child;
        } else {
          parent.$$childHead = parent.$$childTail = child;
        }

        // When the new scope is not isolated or we inherit from `this`, and
        // the parent scope is destroyed, the property `$$destroyed` is inherited
        // prototypically. In all other cases, this property needs to be set
        // when the parent scope is destroyed.
        // The listener needs to be added after the parent is set
        if (isolate || parent != this) child.$on('$destroy', destroyChildScope);

        return child;
      },

      /**
       * @ngdoc method
       * @name $rootScope.Scope#$watch
       * @kind function
       *
       * @description
       * Registers a `listener` callback to be executed whenever the `watchExpression` changes.
       *
       * - The `watchExpression` is called on every call to {@link ng.$rootScope.Scope#$digest
       *   $digest()} and should return the value that will be watched. (Since
       *   {@link ng.$rootScope.Scope#$digest $digest()} reruns when it detects changes the
       *   `watchExpression` can execute multiple times per
       *   {@link ng.$rootScope.Scope#$digest $digest()} and should be idempotent.)
       * - The `listener` is called only when the value from the current `watchExpression` and the
       *   previous call to `watchExpression` are not equal (with the exception of the initial run,
       *   see below). Inequality is determined according to reference inequality,
       *   [strict comparison](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Operators/Comparison_Operators)
       *    via the `!==` Javascript operator, unless `objectEquality == true`
       *   (see next point)
       * - When `objectEquality == true`, inequality of the `watchExpression` is determined
       *   according to the {@link angular.equals} function. To save the value of the object for
       *   later comparison, the {@link angular.copy} function is used. This therefore means that
       *   watching complex objects will have adverse memory and performance implications.
       * - The watch `listener` may change the model, which may trigger other `listener`s to fire.
       *   This is achieved by rerunning the watchers until no changes are detected. The rerun
       *   iteration limit is 10 to prevent an infinite loop deadlock.
       *
       *
       * If you want to be notified whenever {@link ng.$rootScope.Scope#$digest $digest} is called,
       * you can register a `watchExpression` function with no `listener`. (Be prepared for
       * multiple calls to your `watchExpression` because it will execute multiple times in a
       * single {@link ng.$rootScope.Scope#$digest $digest} cycle if a change is detected.)
       *
       * After a watcher is registered with the scope, the `listener` fn is called asynchronously
       * (via {@link ng.$rootScope.Scope#$evalAsync $evalAsync}) to initialize the
       * watcher. In rare cases, this is undesirable because the listener is called when the result
       * of `watchExpression` didn't change. To detect this scenario within the `listener` fn, you
       * can compare the `newVal` and `oldVal`. If these two values are identical (`===`) then the
       * listener was called due to initialization.
       *
       *
       *
       * # Example
       * ```js
           // let's assume that scope was dependency injected as the $rootScope
           var scope = $rootScope;
           scope.name = 'misko';
           scope.counter = 0;

           expect(scope.counter).toEqual(0);
           scope.$watch('name', function(newValue, oldValue) {
             scope.counter = scope.counter + 1;
           });
           expect(scope.counter).toEqual(0);

           scope.$digest();
           // the listener is always called during the first $digest loop after it was registered
           expect(scope.counter).toEqual(1);

           scope.$digest();
           // but now it will not be called unless the value changes
           expect(scope.counter).toEqual(1);

           scope.name = 'adam';
           scope.$digest();
           expect(scope.counter).toEqual(2);



           // Using a function as a watchExpression
           var food;
           scope.foodCounter = 0;
           expect(scope.foodCounter).toEqual(0);
           scope.$watch(
             // This function returns the value being watched. It is called for each turn of the $digest loop
             function() { return food; },
             // This is the change listener, called when the value returned from the above function changes
             function(newValue, oldValue) {
               if ( newValue !== oldValue ) {
                 // Only increment the counter if the value changed
                 scope.foodCounter = scope.foodCounter + 1;
               }
             }
           );
           // No digest has been run so the counter will be zero
           expect(scope.foodCounter).toEqual(0);

           // Run the digest but since food has not changed count will still be zero
           scope.$digest();
           expect(scope.foodCounter).toEqual(0);

           // Update food and run digest.  Now the counter will increment
           food = 'cheeseburger';
           scope.$digest();
           expect(scope.foodCounter).toEqual(1);

       * ```
       *
       *
       *
       * @param {(function()|string)} watchExpression Expression that is evaluated on each
       *    {@link ng.$rootScope.Scope#$digest $digest} cycle. A change in the return value triggers
       *    a call to the `listener`.
       *
       *    - `string`: Evaluated as {@link guide/expression expression}
       *    - `function(scope)`: called with current `scope` as a parameter.
       * @param {function(newVal, oldVal, scope)} listener Callback called whenever the value
       *    of `watchExpression` changes.
       *
       *    - `newVal` contains the current value of the `watchExpression`
       *    - `oldVal` contains the previous value of the `watchExpression`
       *    - `scope` refers to the current scope
       * @param {boolean=} objectEquality Compare for object equality using {@link angular.equals} instead of
       *     comparing for reference equality.
       * @returns {function()} Returns a deregistration function for this listener.
       */
      $watch: function(watchExp, listener, objectEquality) {
        var get = $parse(watchExp);

        if (get.$$watchDelegate) {
          return get.$$watchDelegate(this, listener, objectEquality, get);
        }
        var scope = this,
            array = scope.$$watchers,
            watcher = {
              fn: listener,
              last: initWatchVal,
              get: get,
              exp: watchExp,
              eq: !!objectEquality
            };

        lastDirtyWatch = null;

        if (!isFunction(listener)) {
          watcher.fn = noop;
        }

        if (!array) {
          array = scope.$$watchers = [];
        }
        // we use unshift since we use a while loop in $digest for speed.
        // the while loop reads in reverse order.
        array.unshift(watcher);

        return function deregisterWatch() {
          arrayRemove(array, watcher);
          lastDirtyWatch = null;
        };
      },

      /**
       * @ngdoc method
       * @name $rootScope.Scope#$watchGroup
       * @kind function
       *
       * @description
       * A variant of {@link ng.$rootScope.Scope#$watch $watch()} where it watches an array of `watchExpressions`.
       * If any one expression in the collection changes the `listener` is executed.
       *
       * - The items in the `watchExpressions` array are observed via standard $watch operation and are examined on every
       *   call to $digest() to see if any items changes.
       * - The `listener` is called whenever any expression in the `watchExpressions` array changes.
       *
       * @param {Array.<string|Function(scope)>} watchExpressions Array of expressions that will be individually
       * watched using {@link ng.$rootScope.Scope#$watch $watch()}
       *
       * @param {function(newValues, oldValues, scope)} listener Callback called whenever the return value of any
       *    expression in `watchExpressions` changes
       *    The `newValues` array contains the current values of the `watchExpressions`, with the indexes matching
       *    those of `watchExpression`
       *    and the `oldValues` array contains the previous values of the `watchExpressions`, with the indexes matching
       *    those of `watchExpression`
       *    The `scope` refers to the current scope.
       * @returns {function()} Returns a de-registration function for all listeners.
       */
      $watchGroup: function(watchExpressions, listener) {
        var oldValues = new Array(watchExpressions.length);
        var newValues = new Array(watchExpressions.length);
        var deregisterFns = [];
        var self = this;
        var changeReactionScheduled = false;
        var firstRun = true;

        if (!watchExpressions.length) {
          // No expressions means we call the listener ASAP
          var shouldCall = true;
          self.$evalAsync(function() {
            if (shouldCall) listener(newValues, newValues, self);
          });
          return function deregisterWatchGroup() {
            shouldCall = false;
          };
        }

        if (watchExpressions.length === 1) {
          // Special case size of one
          return this.$watch(watchExpressions[0], function watchGroupAction(value, oldValue, scope) {
            newValues[0] = value;
            oldValues[0] = oldValue;
            listener(newValues, (value === oldValue) ? newValues : oldValues, scope);
          });
        }

        forEach(watchExpressions, function(expr, i) {
          var unwatchFn = self.$watch(expr, function watchGroupSubAction(value, oldValue) {
            newValues[i] = value;
            oldValues[i] = oldValue;
            if (!changeReactionScheduled) {
              changeReactionScheduled = true;
              self.$evalAsync(watchGroupAction);
            }
          });
          deregisterFns.push(unwatchFn);
        });

        function watchGroupAction() {
          changeReactionScheduled = false;

          if (firstRun) {
            firstRun = false;
            listener(newValues, newValues, self);
          } else {
            listener(newValues, oldValues, self);
          }
        }

        return function deregisterWatchGroup() {
          while (deregisterFns.length) {
            deregisterFns.shift()();
          }
        };
      },


      /**
       * @ngdoc method
       * @name $rootScope.Scope#$watchCollection
       * @kind function
       *
       * @description
       * Shallow watches the properties of an object and fires whenever any of the properties change
       * (for arrays, this implies watching the array items; for object maps, this implies watching
       * the properties). If a change is detected, the `listener` callback is fired.
       *
       * - The `obj` collection is observed via standard $watch operation and is examined on every
       *   call to $digest() to see if any items have been added, removed, or moved.
       * - The `listener` is called whenever anything within the `obj` has changed. Examples include
       *   adding, removing, and moving items belonging to an object or array.
       *
       *
       * # Example
       * ```js
          $scope.names = ['igor', 'matias', 'misko', 'james'];
          $scope.dataCount = 4;

          $scope.$watchCollection('names', function(newNames, oldNames) {
            $scope.dataCount = newNames.length;
          });

          expect($scope.dataCount).toEqual(4);
          $scope.$digest();

          //still at 4 ... no changes
          expect($scope.dataCount).toEqual(4);

          $scope.names.pop();
          $scope.$digest();

          //now there's been a change
          expect($scope.dataCount).toEqual(3);
       * ```
       *
       *
       * @param {string|function(scope)} obj Evaluated as {@link guide/expression expression}. The
       *    expression value should evaluate to an object or an array which is observed on each
       *    {@link ng.$rootScope.Scope#$digest $digest} cycle. Any shallow change within the
       *    collection will trigger a call to the `listener`.
       *
       * @param {function(newCollection, oldCollection, scope)} listener a callback function called
       *    when a change is detected.
       *    - The `newCollection` object is the newly modified data obtained from the `obj` expression
       *    - The `oldCollection` object is a copy of the former collection data.
       *      Due to performance considerations, the`oldCollection` value is computed only if the
       *      `listener` function declares two or more arguments.
       *    - The `scope` argument refers to the current scope.
       *
       * @returns {function()} Returns a de-registration function for this listener. When the
       *    de-registration function is executed, the internal watch operation is terminated.
       */
      $watchCollection: function(obj, listener) {
        $watchCollectionInterceptor.$stateful = true;

        var self = this;
        // the current value, updated on each dirty-check run
        var newValue;
        // a shallow copy of the newValue from the last dirty-check run,
        // updated to match newValue during dirty-check run
        var oldValue;
        // a shallow copy of the newValue from when the last change happened
        var veryOldValue;
        // only track veryOldValue if the listener is asking for it
        var trackVeryOldValue = (listener.length > 1);
        var changeDetected = 0;
        var changeDetector = $parse(obj, $watchCollectionInterceptor);
        var internalArray = [];
        var internalObject = {};
        var initRun = true;
        var oldLength = 0;

        function $watchCollectionInterceptor(_value) {
          newValue = _value;
          var newLength, key, bothNaN, newItem, oldItem;

          // If the new value is undefined, then return undefined as the watch may be a one-time watch
          if (isUndefined(newValue)) return;

          if (!isObject(newValue)) { // if primitive
            if (oldValue !== newValue) {
              oldValue = newValue;
              changeDetected++;
            }
          } else if (isArrayLike(newValue)) {
            if (oldValue !== internalArray) {
              // we are transitioning from something which was not an array into array.
              oldValue = internalArray;
              oldLength = oldValue.length = 0;
              changeDetected++;
            }

            newLength = newValue.length;

            if (oldLength !== newLength) {
              // if lengths do not match we need to trigger change notification
              changeDetected++;
              oldValue.length = oldLength = newLength;
            }
            // copy the items to oldValue and look for changes.
            for (var i = 0; i < newLength; i++) {
              oldItem = oldValue[i];
              newItem = newValue[i];

              bothNaN = (oldItem !== oldItem) && (newItem !== newItem);
              if (!bothNaN && (oldItem !== newItem)) {
                changeDetected++;
                oldValue[i] = newItem;
              }
            }
          } else {
            if (oldValue !== internalObject) {
              // we are transitioning from something which was not an object into object.
              oldValue = internalObject = {};
              oldLength = 0;
              changeDetected++;
            }
            // copy the items to oldValue and look for changes.
            newLength = 0;
            for (key in newValue) {
              if (newValue.hasOwnProperty(key)) {
                newLength++;
                newItem = newValue[key];
                oldItem = oldValue[key];

                if (key in oldValue) {
                  bothNaN = (oldItem !== oldItem) && (newItem !== newItem);
                  if (!bothNaN && (oldItem !== newItem)) {
                    changeDetected++;
                    oldValue[key] = newItem;
                  }
                } else {
                  oldLength++;
                  oldValue[key] = newItem;
                  changeDetected++;
                }
              }
            }
            if (oldLength > newLength) {
              // we used to have more keys, need to find them and destroy them.
              changeDetected++;
              for (key in oldValue) {
                if (!newValue.hasOwnProperty(key)) {
                  oldLength--;
                  delete oldValue[key];
                }
              }
            }
          }
          return changeDetected;
        }

        function $watchCollectionAction() {
          if (initRun) {
            initRun = false;
            listener(newValue, newValue, self);
          } else {
            listener(newValue, veryOldValue, self);
          }

          // make a copy for the next time a collection is changed
          if (trackVeryOldValue) {
            if (!isObject(newValue)) {
              //primitive
              veryOldValue = newValue;
            } else if (isArrayLike(newValue)) {
              veryOldValue = new Array(newValue.length);
              for (var i = 0; i < newValue.length; i++) {
                veryOldValue[i] = newValue[i];
              }
            } else { // if object
              veryOldValue = {};
              for (var key in newValue) {
                if (hasOwnProperty.call(newValue, key)) {
                  veryOldValue[key] = newValue[key];
                }
              }
            }
          }
        }

        return this.$watch(changeDetector, $watchCollectionAction);
      },

      /**
       * @ngdoc method
       * @name $rootScope.Scope#$digest
       * @kind function
       *
       * @description
       * Processes all of the {@link ng.$rootScope.Scope#$watch watchers} of the current scope and
       * its children. Because a {@link ng.$rootScope.Scope#$watch watcher}'s listener can change
       * the model, the `$digest()` keeps calling the {@link ng.$rootScope.Scope#$watch watchers}
       * until no more listeners are firing. This means that it is possible to get into an infinite
       * loop. This function will throw `'Maximum iteration limit exceeded.'` if the number of
       * iterations exceeds 10.
       *
       * Usually, you don't call `$digest()` directly in
       * {@link ng.directive:ngController controllers} or in
       * {@link ng.$compileProvider#directive directives}.
       * Instead, you should call {@link ng.$rootScope.Scope#$apply $apply()} (typically from within
       * a {@link ng.$compileProvider#directive directive}), which will force a `$digest()`.
       *
       * If you want to be notified whenever `$digest()` is called,
       * you can register a `watchExpression` function with
       * {@link ng.$rootScope.Scope#$watch $watch()} with no `listener`.
       *
       * In unit tests, you may need to call `$digest()` to simulate the scope life cycle.
       *
       * # Example
       * ```js
           var scope = ...;
           scope.name = 'misko';
           scope.counter = 0;

           expect(scope.counter).toEqual(0);
           scope.$watch('name', function(newValue, oldValue) {
             scope.counter = scope.counter + 1;
           });
           expect(scope.counter).toEqual(0);

           scope.$digest();
           // the listener is always called during the first $digest loop after it was registered
           expect(scope.counter).toEqual(1);

           scope.$digest();
           // but now it will not be called unless the value changes
           expect(scope.counter).toEqual(1);

           scope.name = 'adam';
           scope.$digest();
           expect(scope.counter).toEqual(2);
       * ```
       *
       */
      $digest: function() {
        var watch, value, last,
            watchers,
            length,
            dirty, ttl = TTL,
            next, current, target = this,
            watchLog = [],
            logIdx, logMsg, asyncTask;

        beginPhase('$digest');
        // Check for changes to browser url that happened in sync before the call to $digest
        $browser.$$checkUrlChange();

        if (this === $rootScope && applyAsyncId !== null) {
          // If this is the root scope, and $applyAsync has scheduled a deferred $apply(), then
          // cancel the scheduled $apply and flush the queue of expressions to be evaluated.
          $browser.defer.cancel(applyAsyncId);
          flushApplyAsync();
        }

        lastDirtyWatch = null;

        do { // "while dirty" loop
          dirty = false;
          current = target;

          while (asyncQueue.length) {
            try {
              asyncTask = asyncQueue.shift();
              asyncTask.scope.$eval(asyncTask.expression, asyncTask.locals);
            } catch (e) {
              $exceptionHandler(e);
            }
            lastDirtyWatch = null;
          }

          traverseScopesLoop:
          do { // "traverse the scopes" loop
            if ((watchers = current.$$watchers)) {
              // process our watches
              length = watchers.length;
              while (length--) {
                try {
                  watch = watchers[length];
                  // Most common watches are on primitives, in which case we can short
                  // circuit it with === operator, only when === fails do we use .equals
                  if (watch) {
                    if ((value = watch.get(current)) !== (last = watch.last) &&
                        !(watch.eq
                            ? equals(value, last)
                            : (typeof value === 'number' && typeof last === 'number'
                               && isNaN(value) && isNaN(last)))) {
                      dirty = true;
                      lastDirtyWatch = watch;
                      watch.last = watch.eq ? copy(value, null) : value;
                      watch.fn(value, ((last === initWatchVal) ? value : last), current);
                      if (ttl < 5) {
                        logIdx = 4 - ttl;
                        if (!watchLog[logIdx]) watchLog[logIdx] = [];
                        watchLog[logIdx].push({
                          msg: isFunction(watch.exp) ? 'fn: ' + (watch.exp.name || watch.exp.toString()) : watch.exp,
                          newVal: value,
                          oldVal: last
                        });
                      }
                    } else if (watch === lastDirtyWatch) {
                      // If the most recently dirty watcher is now clean, short circuit since the remaining watchers
                      // have already been tested.
                      dirty = false;
                      break traverseScopesLoop;
                    }
                  }
                } catch (e) {
                  $exceptionHandler(e);
                }
              }
            }

            // Insanity Warning: scope depth-first traversal
            // yes, this code is a bit crazy, but it works and we have tests to prove it!
            // this piece should be kept in sync with the traversal in $broadcast
            if (!(next = (current.$$childHead ||
                (current !== target && current.$$nextSibling)))) {
              while (current !== target && !(next = current.$$nextSibling)) {
                current = current.$parent;
              }
            }
          } while ((current = next));

          // `break traverseScopesLoop;` takes us to here

          if ((dirty || asyncQueue.length) && !(ttl--)) {
            clearPhase();
            throw $rootScopeMinErr('infdig',
                '{0} $digest() iterations reached. Aborting!\n' +
                'Watchers fired in the last 5 iterations: {1}',
                TTL, watchLog);
          }

        } while (dirty || asyncQueue.length);

        clearPhase();

        while (postDigestQueue.length) {
          try {
            postDigestQueue.shift()();
          } catch (e) {
            $exceptionHandler(e);
          }
        }
      },


      /**
       * @ngdoc event
       * @name $rootScope.Scope#$destroy
       * @eventType broadcast on scope being destroyed
       *
       * @description
       * Broadcasted when a scope and its children are being destroyed.
       *
       * Note that, in AngularJS, there is also a `$destroy` jQuery event, which can be used to
       * clean up DOM bindings before an element is removed from the DOM.
       */

      /**
       * @ngdoc method
       * @name $rootScope.Scope#$destroy
       * @kind function
       *
       * @description
       * Removes the current scope (and all of its children) from the parent scope. Removal implies
       * that calls to {@link ng.$rootScope.Scope#$digest $digest()} will no longer
       * propagate to the current scope and its children. Removal also implies that the current
       * scope is eligible for garbage collection.
       *
       * The `$destroy()` is usually used by directives such as
       * {@link ng.directive:ngRepeat ngRepeat} for managing the
       * unrolling of the loop.
       *
       * Just before a scope is destroyed, a `$destroy` event is broadcasted on this scope.
       * Application code can register a `$destroy` event handler that will give it a chance to
       * perform any necessary cleanup.
       *
       * Note that, in AngularJS, there is also a `$destroy` jQuery event, which can be used to
       * clean up DOM bindings before an element is removed from the DOM.
       */
      $destroy: function() {
        // we can't destroy the root scope or a scope that has been already destroyed
        if (this.$$destroyed) return;
        var parent = this.$parent;

        this.$broadcast('$destroy');
        this.$$destroyed = true;
        if (this === $rootScope) return;

        for (var eventName in this.$$listenerCount) {
          decrementListenerCount(this, this.$$listenerCount[eventName], eventName);
        }

        // sever all the references to parent scopes (after this cleanup, the current scope should
        // not be retained by any of our references and should be eligible for garbage collection)
        if (parent.$$childHead == this) parent.$$childHead = this.$$nextSibling;
        if (parent.$$childTail == this) parent.$$childTail = this.$$prevSibling;
        if (this.$$prevSibling) this.$$prevSibling.$$nextSibling = this.$$nextSibling;
        if (this.$$nextSibling) this.$$nextSibling.$$prevSibling = this.$$prevSibling;

        // Disable listeners, watchers and apply/digest methods
        this.$destroy = this.$digest = this.$apply = this.$evalAsync = this.$applyAsync = noop;
        this.$on = this.$watch = this.$watchGroup = function() { return noop; };
        this.$$listeners = {};

        // All of the code below is bogus code that works around V8's memory leak via optimized code
        // and inline caches.
        //
        // see:
        // - https://code.google.com/p/v8/issues/detail?id=2073#c26
        // - https://github.com/angular/angular.js/issues/6794#issuecomment-38648909
        // - https://github.com/angular/angular.js/issues/1313#issuecomment-10378451

        this.$parent = this.$$nextSibling = this.$$prevSibling = this.$$childHead =
            this.$$childTail = this.$root = this.$$watchers = null;
      },

      /**
       * @ngdoc method
       * @name $rootScope.Scope#$eval
       * @kind function
       *
       * @description
       * Executes the `expression` on the current scope and returns the result. Any exceptions in
       * the expression are propagated (uncaught). This is useful when evaluating Angular
       * expressions.
       *
       * # Example
       * ```js
           var scope = ng.$rootScope.Scope();
           scope.a = 1;
           scope.b = 2;

           expect(scope.$eval('a+b')).toEqual(3);
           expect(scope.$eval(function(scope){ return scope.a + scope.b; })).toEqual(3);
       * ```
       *
       * @param {(string|function())=} expression An angular expression to be executed.
       *
       *    - `string`: execute using the rules as defined in  {@link guide/expression expression}.
       *    - `function(scope)`: execute the function with the current `scope` parameter.
       *
       * @param {(object)=} locals Local variables object, useful for overriding values in scope.
       * @returns {*} The result of evaluating the expression.
       */
      $eval: function(expr, locals) {
        return $parse(expr)(this, locals);
      },

      /**
       * @ngdoc method
       * @name $rootScope.Scope#$evalAsync
       * @kind function
       *
       * @description
       * Executes the expression on the current scope at a later point in time.
       *
       * The `$evalAsync` makes no guarantees as to when the `expression` will be executed, only
       * that:
       *
       *   - it will execute after the function that scheduled the evaluation (preferably before DOM
       *     rendering).
       *   - at least one {@link ng.$rootScope.Scope#$digest $digest cycle} will be performed after
       *     `expression` execution.
       *
       * Any exceptions from the execution of the expression are forwarded to the
       * {@link ng.$exceptionHandler $exceptionHandler} service.
       *
       * __Note:__ if this function is called outside of a `$digest` cycle, a new `$digest` cycle
       * will be scheduled. However, it is encouraged to always call code that changes the model
       * from within an `$apply` call. That includes code evaluated via `$evalAsync`.
       *
       * @param {(string|function())=} expression An angular expression to be executed.
       *
       *    - `string`: execute using the rules as defined in {@link guide/expression expression}.
       *    - `function(scope)`: execute the function with the current `scope` parameter.
       *
       * @param {(object)=} locals Local variables object, useful for overriding values in scope.
       */
      $evalAsync: function(expr, locals) {
        // if we are outside of an $digest loop and this is the first time we are scheduling async
        // task also schedule async auto-flush
        if (!$rootScope.$$phase && !asyncQueue.length) {
          $browser.defer(function() {
            if (asyncQueue.length) {
              $rootScope.$digest();
            }
          });
        }

        asyncQueue.push({scope: this, expression: expr, locals: locals});
      },

      $$postDigest: function(fn) {
        postDigestQueue.push(fn);
      },

      /**
       * @ngdoc method
       * @name $rootScope.Scope#$apply
       * @kind function
       *
       * @description
       * `$apply()` is used to execute an expression in angular from outside of the angular
       * framework. (For example from browser DOM events, setTimeout, XHR or third party libraries).
       * Because we are calling into the angular framework we need to perform proper scope life
       * cycle of {@link ng.$exceptionHandler exception handling},
       * {@link ng.$rootScope.Scope#$digest executing watches}.
       *
       * ## Life cycle
       *
       * # Pseudo-Code of `$apply()`
       * ```js
           function $apply(expr) {
             try {
               return $eval(expr);
             } catch (e) {
               $exceptionHandler(e);
             } finally {
               $root.$digest();
             }
           }
       * ```
       *
       *
       * Scope's `$apply()` method transitions through the following stages:
       *
       * 1. The {@link guide/expression expression} is executed using the
       *    {@link ng.$rootScope.Scope#$eval $eval()} method.
       * 2. Any exceptions from the execution of the expression are forwarded to the
       *    {@link ng.$exceptionHandler $exceptionHandler} service.
       * 3. The {@link ng.$rootScope.Scope#$watch watch} listeners are fired immediately after the
       *    expression was executed using the {@link ng.$rootScope.Scope#$digest $digest()} method.
       *
       *
       * @param {(string|function())=} exp An angular expression to be executed.
       *
       *    - `string`: execute using the rules as defined in {@link guide/expression expression}.
       *    - `function(scope)`: execute the function with current `scope` parameter.
       *
       * @returns {*} The result of evaluating the expression.
       */
      $apply: function(expr) {
        try {
          beginPhase('$apply');
          return this.$eval(expr);
        } catch (e) {
          $exceptionHandler(e);
        } finally {
          clearPhase();
          try {
            $rootScope.$digest();
          } catch (e) {
            $exceptionHandler(e);
            throw e;
          }
        }
      },

      /**
       * @ngdoc method
       * @name $rootScope.Scope#$applyAsync
       * @kind function
       *
       * @description
       * Schedule the invocation of $apply to occur at a later time. The actual time difference
       * varies across browsers, but is typically around ~10 milliseconds.
       *
       * This can be used to queue up multiple expressions which need to be evaluated in the same
       * digest.
       *
       * @param {(string|function())=} exp An angular expression to be executed.
       *
       *    - `string`: execute using the rules as defined in {@link guide/expression expression}.
       *    - `function(scope)`: execute the function with current `scope` parameter.
       */
      $applyAsync: function(expr) {
        var scope = this;
        expr && applyAsyncQueue.push($applyAsyncExpression);
        scheduleApplyAsync();

        function $applyAsyncExpression() {
          scope.$eval(expr);
        }
      },

      /**
       * @ngdoc method
       * @name $rootScope.Scope#$on
       * @kind function
       *
       * @description
       * Listens on events of a given type. See {@link ng.$rootScope.Scope#$emit $emit} for
       * discussion of event life cycle.
       *
       * The event listener function format is: `function(event, args...)`. The `event` object
       * passed into the listener has the following attributes:
       *
       *   - `targetScope` - `{Scope}`: the scope on which the event was `$emit`-ed or
       *     `$broadcast`-ed.
       *   - `currentScope` - `{Scope}`: the scope that is currently handling the event. Once the
       *     event propagates through the scope hierarchy, this property is set to null.
       *   - `name` - `{string}`: name of the event.
       *   - `stopPropagation` - `{function=}`: calling `stopPropagation` function will cancel
       *     further event propagation (available only for events that were `$emit`-ed).
       *   - `preventDefault` - `{function}`: calling `preventDefault` sets `defaultPrevented` flag
       *     to true.
       *   - `defaultPrevented` - `{boolean}`: true if `preventDefault` was called.
       *
       * @param {string} name Event name to listen on.
       * @param {function(event, ...args)} listener Function to call when the event is emitted.
       * @returns {function()} Returns a deregistration function for this listener.
       */
      $on: function(name, listener) {
        var namedListeners = this.$$listeners[name];
        if (!namedListeners) {
          this.$$listeners[name] = namedListeners = [];
        }
        namedListeners.push(listener);

        var current = this;
        do {
          if (!current.$$listenerCount[name]) {
            current.$$listenerCount[name] = 0;
          }
          current.$$listenerCount[name]++;
        } while ((current = current.$parent));

        var self = this;
        return function() {
          var indexOfListener = namedListeners.indexOf(listener);
          if (indexOfListener !== -1) {
            namedListeners[indexOfListener] = null;
            decrementListenerCount(self, 1, name);
          }
        };
      },


      /**
       * @ngdoc method
       * @name $rootScope.Scope#$emit
       * @kind function
       *
       * @description
       * Dispatches an event `name` upwards through the scope hierarchy notifying the
       * registered {@link ng.$rootScope.Scope#$on} listeners.
       *
       * The event life cycle starts at the scope on which `$emit` was called. All
       * {@link ng.$rootScope.Scope#$on listeners} listening for `name` event on this scope get
       * notified. Afterwards, the event traverses upwards toward the root scope and calls all
       * registered listeners along the way. The event will stop propagating if one of the listeners
       * cancels it.
       *
       * Any exception emitted from the {@link ng.$rootScope.Scope#$on listeners} will be passed
       * onto the {@link ng.$exceptionHandler $exceptionHandler} service.
       *
       * @param {string} name Event name to emit.
       * @param {...*} args Optional one or more arguments which will be passed onto the event listeners.
       * @return {Object} Event object (see {@link ng.$rootScope.Scope#$on}).
       */
      $emit: function(name, args) {
        var empty = [],
            namedListeners,
            scope = this,
            stopPropagation = false,
            event = {
              name: name,
              targetScope: scope,
              stopPropagation: function() {stopPropagation = true;},
              preventDefault: function() {
                event.defaultPrevented = true;
              },
              defaultPrevented: false
            },
            listenerArgs = concat([event], arguments, 1),
            i, length;

        do {
          namedListeners = scope.$$listeners[name] || empty;
          event.currentScope = scope;
          for (i = 0, length = namedListeners.length; i < length; i++) {

            // if listeners were deregistered, defragment the array
            if (!namedListeners[i]) {
              namedListeners.splice(i, 1);
              i--;
              length--;
              continue;
            }
            try {
              //allow all listeners attached to the current scope to run
              namedListeners[i].apply(null, listenerArgs);
            } catch (e) {
              $exceptionHandler(e);
            }
          }
          //if any listener on the current scope stops propagation, prevent bubbling
          if (stopPropagation) {
            event.currentScope = null;
            return event;
          }
          //traverse upwards
          scope = scope.$parent;
        } while (scope);

        event.currentScope = null;

        return event;
      },


      /**
       * @ngdoc method
       * @name $rootScope.Scope#$broadcast
       * @kind function
       *
       * @description
       * Dispatches an event `name` downwards to all child scopes (and their children) notifying the
       * registered {@link ng.$rootScope.Scope#$on} listeners.
       *
       * The event life cycle starts at the scope on which `$broadcast` was called. All
       * {@link ng.$rootScope.Scope#$on listeners} listening for `name` event on this scope get
       * notified. Afterwards, the event propagates to all direct and indirect scopes of the current
       * scope and calls all registered listeners along the way. The event cannot be canceled.
       *
       * Any exception emitted from the {@link ng.$rootScope.Scope#$on listeners} will be passed
       * onto the {@link ng.$exceptionHandler $exceptionHandler} service.
       *
       * @param {string} name Event name to broadcast.
       * @param {...*} args Optional one or more arguments which will be passed onto the event listeners.
       * @return {Object} Event object, see {@link ng.$rootScope.Scope#$on}
       */
      $broadcast: function(name, args) {
        var target = this,
            current = target,
            next = target,
            event = {
              name: name,
              targetScope: target,
              preventDefault: function() {
                event.defaultPrevented = true;
              },
              defaultPrevented: false
            };

        if (!target.$$listenerCount[name]) return event;

        var listenerArgs = concat([event], arguments, 1),
            listeners, i, length;

        //down while you can, then up and next sibling or up and next sibling until back at root
        while ((current = next)) {
          event.currentScope = current;
          listeners = current.$$listeners[name] || [];
          for (i = 0, length = listeners.length; i < length; i++) {
            // if listeners were deregistered, defragment the array
            if (!listeners[i]) {
              listeners.splice(i, 1);
              i--;
              length--;
              continue;
            }

            try {
              listeners[i].apply(null, listenerArgs);
            } catch (e) {
              $exceptionHandler(e);
            }
          }

          // Insanity Warning: scope depth-first traversal
          // yes, this code is a bit crazy, but it works and we have tests to prove it!
          // this piece should be kept in sync with the traversal in $digest
          // (though it differs due to having the extra check for $$listenerCount)
          if (!(next = ((current.$$listenerCount[name] && current.$$childHead) ||
              (current !== target && current.$$nextSibling)))) {
            while (current !== target && !(next = current.$$nextSibling)) {
              current = current.$parent;
            }
          }
        }

        event.currentScope = null;
        return event;
      }
    };

    var $rootScope = new Scope();

    //The internal queues. Expose them on the $rootScope for debugging/testing purposes.
    var asyncQueue = $rootScope.$$asyncQueue = [];
    var postDigestQueue = $rootScope.$$postDigestQueue = [];
    var applyAsyncQueue = $rootScope.$$applyAsyncQueue = [];

    return $rootScope;


    function beginPhase(phase) {
      if ($rootScope.$$phase) {
        throw $rootScopeMinErr('inprog', '{0} already in progress', $rootScope.$$phase);
      }

      $rootScope.$$phase = phase;
    }

    function clearPhase() {
      $rootScope.$$phase = null;
    }


    function decrementListenerCount(current, count, name) {
      do {
        current.$$listenerCount[name] -= count;

        if (current.$$listenerCount[name] === 0) {
          delete current.$$listenerCount[name];
        }
      } while ((current = current.$parent));
    }

    /**
     * function used as an initial value for watchers.
     * because it's unique we can easily tell it apart from other values
     */
    function initWatchVal() {}

    function flushApplyAsync() {
      while (applyAsyncQueue.length) {
        try {
          applyAsyncQueue.shift()();
        } catch (e) {
          $exceptionHandler(e);
        }
      }
      applyAsyncId = null;
    }

    function scheduleApplyAsync() {
      if (applyAsyncId === null) {
        applyAsyncId = $browser.defer(function() {
          $rootScope.$apply(flushApplyAsync);
        });
      }
    }
  }];
}

/**
 * @description
 * Private service to sanitize uris for links and images. Used by $compile and $sanitize.
 */
function $$SanitizeUriProvider() {
  var aHrefSanitizationWhitelist = /^\s*(https?|ftp|mailto|tel|file):/,
    imgSrcSanitizationWhitelist = /^\s*((https?|ftp|file|blob):|data:image\/)/;

  /**
   * @description
   * Retrieves or overrides the default regular expression that is used for whitelisting of safe
   * urls during a[href] sanitization.
   *
   * The sanitization is a security measure aimed at prevent XSS attacks via html links.
   *
   * Any url about to be assigned to a[href] via data-binding is first normalized and turned into
   * an absolute url. Afterwards, the url is matched against the `aHrefSanitizationWhitelist`
   * regular expression. If a match is found, the original url is written into the dom. Otherwise,
   * the absolute url is prefixed with `'unsafe:'` string and only then is it written into the DOM.
   *
   * @param {RegExp=} regexp New regexp to whitelist urls with.
   * @returns {RegExp|ng.$compileProvider} Current RegExp if called without value or self for
   *    chaining otherwise.
   */
  this.aHrefSanitizationWhitelist = function(regexp) {
    if (isDefined(regexp)) {
      aHrefSanitizationWhitelist = regexp;
      return this;
    }
    return aHrefSanitizationWhitelist;
  };


  /**
   * @description
   * Retrieves or overrides the default regular expression that is used for whitelisting of safe
   * urls during img[src] sanitization.
   *
   * The sanitization is a security measure aimed at prevent XSS attacks via html links.
   *
   * Any url about to be assigned to img[src] via data-binding is first normalized and turned into
   * an absolute url. Afterwards, the url is matched against the `imgSrcSanitizationWhitelist`
   * regular expression. If a match is found, the original url is written into the dom. Otherwise,
   * the absolute url is prefixed with `'unsafe:'` string and only then is it written into the DOM.
   *
   * @param {RegExp=} regexp New regexp to whitelist urls with.
   * @returns {RegExp|ng.$compileProvider} Current RegExp if called without value or self for
   *    chaining otherwise.
   */
  this.imgSrcSanitizationWhitelist = function(regexp) {
    if (isDefined(regexp)) {
      imgSrcSanitizationWhitelist = regexp;
      return this;
    }
    return imgSrcSanitizationWhitelist;
  };

  this.$get = function() {
    return function sanitizeUri(uri, isImage) {
      var regex = isImage ? imgSrcSanitizationWhitelist : aHrefSanitizationWhitelist;
      var normalizedVal;
      normalizedVal = urlResolve(uri).href;
      if (normalizedVal !== '' && !normalizedVal.match(regex)) {
        return 'unsafe:' + normalizedVal;
      }
      return uri;
    };
  };
}

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 *     Any commits to this file should be reviewed with security in mind.  *
 *   Changes to this file can potentially create security vulnerabilities. *
 *          An approval from 2 Core members with history of modifying      *
 *                         this file is required.                          *
 *                                                                         *
 *  Does the change somehow allow for arbitrary javascript to be executed? *
 *    Or allows for someone to change the prototype of built-in objects?   *
 *     Or gives undesired access to variables likes document or window?    *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

var $sceMinErr = minErr('$sce');

var SCE_CONTEXTS = {
  HTML: 'html',
  CSS: 'css',
  URL: 'url',
  // RESOURCE_URL is a subtype of URL used in contexts where a privileged resource is sourced from a
  // url.  (e.g. ng-include, script src, templateUrl)
  RESOURCE_URL: 'resourceUrl',
  JS: 'js'
};

// Helper functions follow.

function adjustMatcher(matcher) {
  if (matcher === 'self') {
    return matcher;
  } else if (isString(matcher)) {
    // Strings match exactly except for 2 wildcards - '*' and '**'.
    // '*' matches any character except those from the set ':/.?&'.
    // '**' matches any character (like .* in a RegExp).
    // More than 2 *'s raises an error as it's ill defined.
    if (matcher.indexOf('***') > -1) {
      throw $sceMinErr('iwcard',
          'Illegal sequence *** in string matcher.  String: {0}', matcher);
    }
    matcher = escapeForRegexp(matcher).
                  replace('\\*\\*', '.*').
                  replace('\\*', '[^:/.?&;]*');
    return new RegExp('^' + matcher + '$');
  } else if (isRegExp(matcher)) {
    // The only other type of matcher allowed is a Regexp.
    // Match entire URL / disallow partial matches.
    // Flags are reset (i.e. no global, ignoreCase or multiline)
    return new RegExp('^' + matcher.source + '$');
  } else {
    throw $sceMinErr('imatcher',
        'Matchers may only be "self", string patterns or RegExp objects');
  }
}


function adjustMatchers(matchers) {
  var adjustedMatchers = [];
  if (isDefined(matchers)) {
    forEach(matchers, function(matcher) {
      adjustedMatchers.push(adjustMatcher(matcher));
    });
  }
  return adjustedMatchers;
}


/**
 * @ngdoc service
 * @name $sceDelegate
 * @kind function
 *
 * @description
 *
 * `$sceDelegate` is a service that is used by the `$sce` service to provide {@link ng.$sce Strict
 * Contextual Escaping (SCE)} services to AngularJS.
 *
 * Typically, you would configure or override the {@link ng.$sceDelegate $sceDelegate} instead of
 * the `$sce` service to customize the way Strict Contextual Escaping works in AngularJS.  This is
 * because, while the `$sce` provides numerous shorthand methods, etc., you really only need to
 * override 3 core functions (`trustAs`, `getTrusted` and `valueOf`) to replace the way things
 * work because `$sce` delegates to `$sceDelegate` for these operations.
 *
 * Refer {@link ng.$sceDelegateProvider $sceDelegateProvider} to configure this service.
 *
 * The default instance of `$sceDelegate` should work out of the box with little pain.  While you
 * can override it completely to change the behavior of `$sce`, the common case would
 * involve configuring the {@link ng.$sceDelegateProvider $sceDelegateProvider} instead by setting
 * your own whitelists and blacklists for trusting URLs used for loading AngularJS resources such as
 * templates.  Refer {@link ng.$sceDelegateProvider#resourceUrlWhitelist
 * $sceDelegateProvider.resourceUrlWhitelist} and {@link
 * ng.$sceDelegateProvider#resourceUrlBlacklist $sceDelegateProvider.resourceUrlBlacklist}
 */

/**
 * @ngdoc provider
 * @name $sceDelegateProvider
 * @description
 *
 * The `$sceDelegateProvider` provider allows developers to configure the {@link ng.$sceDelegate
 * $sceDelegate} service.  This allows one to get/set the whitelists and blacklists used to ensure
 * that the URLs used for sourcing Angular templates are safe.  Refer {@link
 * ng.$sceDelegateProvider#resourceUrlWhitelist $sceDelegateProvider.resourceUrlWhitelist} and
 * {@link ng.$sceDelegateProvider#resourceUrlBlacklist $sceDelegateProvider.resourceUrlBlacklist}
 *
 * For the general details about this service in Angular, read the main page for {@link ng.$sce
 * Strict Contextual Escaping (SCE)}.
 *
 * **Example**:  Consider the following case. <a name="example"></a>
 *
 * - your app is hosted at url `http://myapp.example.com/`
 * - but some of your templates are hosted on other domains you control such as
 *   `http://srv01.assets.example.com/`,  `http://srv02.assets.example.com/`, etc.
 * - and you have an open redirect at `http://myapp.example.com/clickThru?...`.
 *
 * Here is what a secure configuration for this scenario might look like:
 *
 * ```
 *  angular.module('myApp', []).config(function($sceDelegateProvider) {
 *    $sceDelegateProvider.resourceUrlWhitelist([
 *      // Allow same origin resource loads.
 *      'self',
 *      // Allow loading from our assets domain.  Notice the difference between * and **.
 *      'http://srv*.assets.example.com/**'
 *    ]);
 *
 *    // The blacklist overrides the whitelist so the open redirect here is blocked.
 *    $sceDelegateProvider.resourceUrlBlacklist([
 *      'http://myapp.example.com/clickThru**'
 *    ]);
 *  });
 * ```
 */

function $SceDelegateProvider() {
  this.SCE_CONTEXTS = SCE_CONTEXTS;

  // Resource URLs can also be trusted by policy.
  var resourceUrlWhitelist = ['self'],
      resourceUrlBlacklist = [];

  /**
   * @ngdoc method
   * @name $sceDelegateProvider#resourceUrlWhitelist
   * @kind function
   *
   * @param {Array=} whitelist When provided, replaces the resourceUrlWhitelist with the value
   *     provided.  This must be an array or null.  A snapshot of this array is used so further
   *     changes to the array are ignored.
   *
   *     Follow {@link ng.$sce#resourceUrlPatternItem this link} for a description of the items
   *     allowed in this array.
   *
   *     Note: **an empty whitelist array will block all URLs**!
   *
   * @return {Array} the currently set whitelist array.
   *
   * The **default value** when no whitelist has been explicitly set is `['self']` allowing only
   * same origin resource requests.
   *
   * @description
   * Sets/Gets the whitelist of trusted resource URLs.
   */
  this.resourceUrlWhitelist = function(value) {
    if (arguments.length) {
      resourceUrlWhitelist = adjustMatchers(value);
    }
    return resourceUrlWhitelist;
  };

  /**
   * @ngdoc method
   * @name $sceDelegateProvider#resourceUrlBlacklist
   * @kind function
   *
   * @param {Array=} blacklist When provided, replaces the resourceUrlBlacklist with the value
   *     provided.  This must be an array or null.  A snapshot of this array is used so further
   *     changes to the array are ignored.
   *
   *     Follow {@link ng.$sce#resourceUrlPatternItem this link} for a description of the items
   *     allowed in this array.
   *
   *     The typical usage for the blacklist is to **block
   *     [open redirects](http://cwe.mitre.org/data/definitions/601.html)** served by your domain as
   *     these would otherwise be trusted but actually return content from the redirected domain.
   *
   *     Finally, **the blacklist overrides the whitelist** and has the final say.
   *
   * @return {Array} the currently set blacklist array.
   *
   * The **default value** when no whitelist has been explicitly set is the empty array (i.e. there
   * is no blacklist.)
   *
   * @description
   * Sets/Gets the blacklist of trusted resource URLs.
   */

  this.resourceUrlBlacklist = function(value) {
    if (arguments.length) {
      resourceUrlBlacklist = adjustMatchers(value);
    }
    return resourceUrlBlacklist;
  };

  this.$get = ['$injector', function($injector) {

    var htmlSanitizer = function htmlSanitizer(html) {
      throw $sceMinErr('unsafe', 'Attempting to use an unsafe value in a safe context.');
    };

    if ($injector.has('$sanitize')) {
      htmlSanitizer = $injector.get('$sanitize');
    }


    function matchUrl(matcher, parsedUrl) {
      if (matcher === 'self') {
        return urlIsSameOrigin(parsedUrl);
      } else {
        // definitely a regex.  See adjustMatchers()
        return !!matcher.exec(parsedUrl.href);
      }
    }

    function isResourceUrlAllowedByPolicy(url) {
      var parsedUrl = urlResolve(url.toString());
      var i, n, allowed = false;
      // Ensure that at least one item from the whitelist allows this url.
      for (i = 0, n = resourceUrlWhitelist.length; i < n; i++) {
        if (matchUrl(resourceUrlWhitelist[i], parsedUrl)) {
          allowed = true;
          break;
        }
      }
      if (allowed) {
        // Ensure that no item from the blacklist blocked this url.
        for (i = 0, n = resourceUrlBlacklist.length; i < n; i++) {
          if (matchUrl(resourceUrlBlacklist[i], parsedUrl)) {
            allowed = false;
            break;
          }
        }
      }
      return allowed;
    }

    function generateHolderType(Base) {
      var holderType = function TrustedValueHolderType(trustedValue) {
        this.$$unwrapTrustedValue = function() {
          return trustedValue;
        };
      };
      if (Base) {
        holderType.prototype = new Base();
      }
      holderType.prototype.valueOf = function sceValueOf() {
        return this.$$unwrapTrustedValue();
      };
      holderType.prototype.toString = function sceToString() {
        return this.$$unwrapTrustedValue().toString();
      };
      return holderType;
    }

    var trustedValueHolderBase = generateHolderType(),
        byType = {};

    byType[SCE_CONTEXTS.HTML] = generateHolderType(trustedValueHolderBase);
    byType[SCE_CONTEXTS.CSS] = generateHolderType(trustedValueHolderBase);
    byType[SCE_CONTEXTS.URL] = generateHolderType(trustedValueHolderBase);
    byType[SCE_CONTEXTS.JS] = generateHolderType(trustedValueHolderBase);
    byType[SCE_CONTEXTS.RESOURCE_URL] = generateHolderType(byType[SCE_CONTEXTS.URL]);

    /**
     * @ngdoc method
     * @name $sceDelegate#trustAs
     *
     * @description
     * Returns an object that is trusted by angular for use in specified strict
     * contextual escaping contexts (such as ng-bind-html, ng-include, any src
     * attribute interpolation, any dom event binding attribute interpolation
     * such as for onclick,  etc.) that uses the provided value.
     * See {@link ng.$sce $sce} for enabling strict contextual escaping.
     *
     * @param {string} type The kind of context in which this value is safe for use.  e.g. url,
     *   resourceUrl, html, js and css.
     * @param {*} value The value that that should be considered trusted/safe.
     * @returns {*} A value that can be used to stand in for the provided `value` in places
     * where Angular expects a $sce.trustAs() return value.
     */
    function trustAs(type, trustedValue) {
      var Constructor = (byType.hasOwnProperty(type) ? byType[type] : null);
      if (!Constructor) {
        throw $sceMinErr('icontext',
            'Attempted to trust a value in invalid context. Context: {0}; Value: {1}',
            type, trustedValue);
      }
      if (trustedValue === null || trustedValue === undefined || trustedValue === '') {
        return trustedValue;
      }
      // All the current contexts in SCE_CONTEXTS happen to be strings.  In order to avoid trusting
      // mutable objects, we ensure here that the value passed in is actually a string.
      if (typeof trustedValue !== 'string') {
        throw $sceMinErr('itype',
            'Attempted to trust a non-string value in a content requiring a string: Context: {0}',
            type);
      }
      return new Constructor(trustedValue);
    }

    /**
     * @ngdoc method
     * @name $sceDelegate#valueOf
     *
     * @description
     * If the passed parameter had been returned by a prior call to {@link ng.$sceDelegate#trustAs
     * `$sceDelegate.trustAs`}, returns the value that had been passed to {@link
     * ng.$sceDelegate#trustAs `$sceDelegate.trustAs`}.
     *
     * If the passed parameter is not a value that had been returned by {@link
     * ng.$sceDelegate#trustAs `$sceDelegate.trustAs`}, returns it as-is.
     *
     * @param {*} value The result of a prior {@link ng.$sceDelegate#trustAs `$sceDelegate.trustAs`}
     *      call or anything else.
     * @returns {*} The `value` that was originally provided to {@link ng.$sceDelegate#trustAs
     *     `$sceDelegate.trustAs`} if `value` is the result of such a call.  Otherwise, returns
     *     `value` unchanged.
     */
    function valueOf(maybeTrusted) {
      if (maybeTrusted instanceof trustedValueHolderBase) {
        return maybeTrusted.$$unwrapTrustedValue();
      } else {
        return maybeTrusted;
      }
    }

    /**
     * @ngdoc method
     * @name $sceDelegate#getTrusted
     *
     * @description
     * Takes the result of a {@link ng.$sceDelegate#trustAs `$sceDelegate.trustAs`} call and
     * returns the originally supplied value if the queried context type is a supertype of the
     * created type.  If this condition isn't satisfied, throws an exception.
     *
     * @param {string} type The kind of context in which this value is to be used.
     * @param {*} maybeTrusted The result of a prior {@link ng.$sceDelegate#trustAs
     *     `$sceDelegate.trustAs`} call.
     * @returns {*} The value the was originally provided to {@link ng.$sceDelegate#trustAs
     *     `$sceDelegate.trustAs`} if valid in this context.  Otherwise, throws an exception.
     */
    function getTrusted(type, maybeTrusted) {
      if (maybeTrusted === null || maybeTrusted === undefined || maybeTrusted === '') {
        return maybeTrusted;
      }
      var constructor = (byType.hasOwnProperty(type) ? byType[type] : null);
      if (constructor && maybeTrusted instanceof constructor) {
        return maybeTrusted.$$unwrapTrustedValue();
      }
      // If we get here, then we may only take one of two actions.
      // 1. sanitize the value for the requested type, or
      // 2. throw an exception.
      if (type === SCE_CONTEXTS.RESOURCE_URL) {
        if (isResourceUrlAllowedByPolicy(maybeTrusted)) {
          return maybeTrusted;
        } else {
          throw $sceMinErr('insecurl',
              'Blocked loading resource from url not allowed by $sceDelegate policy.  URL: {0}',
              maybeTrusted.toString());
        }
      } else if (type === SCE_CONTEXTS.HTML) {
        return htmlSanitizer(maybeTrusted);
      }
      throw $sceMinErr('unsafe', 'Attempting to use an unsafe value in a safe context.');
    }

    return { trustAs: trustAs,
             getTrusted: getTrusted,
             valueOf: valueOf };
  }];
}


/**
 * @ngdoc provider
 * @name $sceProvider
 * @description
 *
 * The $sceProvider provider allows developers to configure the {@link ng.$sce $sce} service.
 * -   enable/disable Strict Contextual Escaping (SCE) in a module
 * -   override the default implementation with a custom delegate
 *
 * Read more about {@link ng.$sce Strict Contextual Escaping (SCE)}.
 */

/* jshint maxlen: false*/

/**
 * @ngdoc service
 * @name $sce
 * @kind function
 *
 * @description
 *
 * `$sce` is a service that provides Strict Contextual Escaping services to AngularJS.
 *
 * # Strict Contextual Escaping
 *
 * Strict Contextual Escaping (SCE) is a mode in which AngularJS requires bindings in certain
 * contexts to result in a value that is marked as safe to use for that context.  One example of
 * such a context is binding arbitrary html controlled by the user via `ng-bind-html`.  We refer
 * to these contexts as privileged or SCE contexts.
 *
 * As of version 1.2, Angular ships with SCE enabled by default.
 *
 * Note:  When enabled (the default), IE<11 in quirks mode is not supported.  In this mode, IE<11 allow
 * one to execute arbitrary javascript by the use of the expression() syntax.  Refer
 * <http://blogs.msdn.com/b/ie/archive/2008/10/16/ending-expressions.aspx> to learn more about them.
 * You can ensure your document is in standards mode and not quirks mode by adding `<!doctype html>`
 * to the top of your HTML document.
 *
 * SCE assists in writing code in way that (a) is secure by default and (b) makes auditing for
 * security vulnerabilities such as XSS, clickjacking, etc. a lot easier.
 *
 * Here's an example of a binding in a privileged context:
 *
 * ```
 * <input ng-model="userHtml">
 * <div ng-bind-html="userHtml"></div>
 * ```
 *
 * Notice that `ng-bind-html` is bound to `userHtml` controlled by the user.  With SCE
 * disabled, this application allows the user to render arbitrary HTML into the DIV.
 * In a more realistic example, one may be rendering user comments, blog articles, etc. via
 * bindings.  (HTML is just one example of a context where rendering user controlled input creates
 * security vulnerabilities.)
 *
 * For the case of HTML, you might use a library, either on the client side, or on the server side,
 * to sanitize unsafe HTML before binding to the value and rendering it in the document.
 *
 * How would you ensure that every place that used these types of bindings was bound to a value that
 * was sanitized by your library (or returned as safe for rendering by your server?)  How can you
 * ensure that you didn't accidentally delete the line that sanitized the value, or renamed some
 * properties/fields and forgot to update the binding to the sanitized value?
 *
 * To be secure by default, you want to ensure that any such bindings are disallowed unless you can
 * determine that something explicitly says it's safe to use a value for binding in that
 * context.  You can then audit your code (a simple grep would do) to ensure that this is only done
 * for those values that you can easily tell are safe - because they were received from your server,
 * sanitized by your library, etc.  You can organize your codebase to help with this - perhaps
 * allowing only the files in a specific directory to do this.  Ensuring that the internal API
 * exposed by that code doesn't markup arbitrary values as safe then becomes a more manageable task.
 *
 * In the case of AngularJS' SCE service, one uses {@link ng.$sce#trustAs $sce.trustAs}
 * (and shorthand methods such as {@link ng.$sce#trustAsHtml $sce.trustAsHtml}, etc.) to
 * obtain values that will be accepted by SCE / privileged contexts.
 *
 *
 * ## How does it work?
 *
 * In privileged contexts, directives and code will bind to the result of {@link ng.$sce#getTrusted
 * $sce.getTrusted(context, value)} rather than to the value directly.  Directives use {@link
 * ng.$sce#parseAs $sce.parseAs} rather than `$parse` to watch attribute bindings, which performs the
 * {@link ng.$sce#getTrusted $sce.getTrusted} behind the scenes on non-constant literals.
 *
 * As an example, {@link ng.directive:ngBindHtml ngBindHtml} uses {@link
 * ng.$sce#parseAsHtml $sce.parseAsHtml(binding expression)}.  Here's the actual code (slightly
 * simplified):
 *
 * ```
 * var ngBindHtmlDirective = ['$sce', function($sce) {
 *   return function(scope, element, attr) {
 *     scope.$watch($sce.parseAsHtml(attr.ngBindHtml), function(value) {
 *       element.html(value || '');
 *     });
 *   };
 * }];
 * ```
 *
 * ## Impact on loading templates
 *
 * This applies both to the {@link ng.directive:ngInclude `ng-include`} directive as well as
 * `templateUrl`'s specified by {@link guide/directive directives}.
 *
 * By default, Angular only loads templates from the same domain and protocol as the application
 * document.  This is done by calling {@link ng.$sce#getTrustedResourceUrl
 * $sce.getTrustedResourceUrl} on the template URL.  To load templates from other domains and/or
 * protocols, you may either either {@link ng.$sceDelegateProvider#resourceUrlWhitelist whitelist
 * them} or {@link ng.$sce#trustAsResourceUrl wrap it} into a trusted value.
 *
 * *Please note*:
 * The browser's
 * [Same Origin Policy](https://code.google.com/p/browsersec/wiki/Part2#Same-origin_policy_for_XMLHttpRequest)
 * and [Cross-Origin Resource Sharing (CORS)](http://www.w3.org/TR/cors/)
 * policy apply in addition to this and may further restrict whether the template is successfully
 * loaded.  This means that without the right CORS policy, loading templates from a different domain
 * won't work on all browsers.  Also, loading templates from `file://` URL does not work on some
 * browsers.
 *
 * ## This feels like too much overhead
 *
 * It's important to remember that SCE only applies to interpolation expressions.
 *
 * If your expressions are constant literals, they're automatically trusted and you don't need to
 * call `$sce.trustAs` on them (remember to include the `ngSanitize` module) (e.g.
 * `<div ng-bind-html="'<b>implicitly trusted</b>'"></div>`) just works.
 *
 * Additionally, `a[href]` and `img[src]` automatically sanitize their URLs and do not pass them
 * through {@link ng.$sce#getTrusted $sce.getTrusted}.  SCE doesn't play a role here.
 *
 * The included {@link ng.$sceDelegate $sceDelegate} comes with sane defaults to allow you to load
 * templates in `ng-include` from your application's domain without having to even know about SCE.
 * It blocks loading templates from other domains or loading templates over http from an https
 * served document.  You can change these by setting your own custom {@link
 * ng.$sceDelegateProvider#resourceUrlWhitelist whitelists} and {@link
 * ng.$sceDelegateProvider#resourceUrlBlacklist blacklists} for matching such URLs.
 *
 * This significantly reduces the overhead.  It is far easier to pay the small overhead and have an
 * application that's secure and can be audited to verify that with much more ease than bolting
 * security onto an application later.
 *
 * <a name="contexts"></a>
 * ## What trusted context types are supported?
 *
 * | Context             | Notes          |
 * |---------------------|----------------|
 * | `$sce.HTML`         | For HTML that's safe to source into the application.  The {@link ng.directive:ngBindHtml ngBindHtml} directive uses this context for bindings. If an unsafe value is encountered and the {@link ngSanitize $sanitize} module is present this will sanitize the value instead of throwing an error. |
 * | `$sce.CSS`          | For CSS that's safe to source into the application.  Currently unused.  Feel free to use it in your own directives. |
 * | `$sce.URL`          | For URLs that are safe to follow as links.  Currently unused (`<a href=` and `<img src=` sanitize their urls and don't constitute an SCE context. |
 * | `$sce.RESOURCE_URL` | For URLs that are not only safe to follow as links, but whose contents are also safe to include in your application.  Examples include `ng-include`, `src` / `ngSrc` bindings for tags other than `IMG` (e.g. `IFRAME`, `OBJECT`, etc.)  <br><br>Note that `$sce.RESOURCE_URL` makes a stronger statement about the URL than `$sce.URL` does and therefore contexts requiring values trusted for `$sce.RESOURCE_URL` can be used anywhere that values trusted for `$sce.URL` are required. |
 * | `$sce.JS`           | For JavaScript that is safe to execute in your application's context.  Currently unused.  Feel free to use it in your own directives. |
 *
 * ## Format of items in {@link ng.$sceDelegateProvider#resourceUrlWhitelist resourceUrlWhitelist}/{@link ng.$sceDelegateProvider#resourceUrlBlacklist Blacklist} <a name="resourceUrlPatternItem"></a>
 *
 *  Each element in these arrays must be one of the following:
 *
 *  - **'self'**
 *    - The special **string**, `'self'`, can be used to match against all URLs of the **same
 *      domain** as the application document using the **same protocol**.
 *  - **String** (except the special value `'self'`)
 *    - The string is matched against the full *normalized / absolute URL* of the resource
 *      being tested (substring matches are not good enough.)
 *    - There are exactly **two wildcard sequences** - `*` and `**`.  All other characters
 *      match themselves.
 *    - `*`: matches zero or more occurrences of any character other than one of the following 6
 *      characters: '`:`', '`/`', '`.`', '`?`', '`&`' and ';'.  It's a useful wildcard for use
 *      in a whitelist.
 *    - `**`: matches zero or more occurrences of *any* character.  As such, it's not
 *      appropriate for use in a scheme, domain, etc. as it would match too much.  (e.g.
 *      http://**.example.com/ would match http://evil.com/?ignore=.example.com/ and that might
 *      not have been the intention.)  Its usage at the very end of the path is ok.  (e.g.
 *      http://foo.example.com/templates/**).
 *  - **RegExp** (*see caveat below*)
 *    - *Caveat*:  While regular expressions are powerful and offer great flexibility,  their syntax
 *      (and all the inevitable escaping) makes them *harder to maintain*.  It's easy to
 *      accidentally introduce a bug when one updates a complex expression (imho, all regexes should
 *      have good test coverage).  For instance, the use of `.` in the regex is correct only in a
 *      small number of cases.  A `.` character in the regex used when matching the scheme or a
 *      subdomain could be matched against a `:` or literal `.` that was likely not intended.   It
 *      is highly recommended to use the string patterns and only fall back to regular expressions
 *      as a last resort.
 *    - The regular expression must be an instance of RegExp (i.e. not a string.)  It is
 *      matched against the **entire** *normalized / absolute URL* of the resource being tested
 *      (even when the RegExp did not have the `^` and `$` codes.)  In addition, any flags
 *      present on the RegExp (such as multiline, global, ignoreCase) are ignored.
 *    - If you are generating your JavaScript from some other templating engine (not
 *      recommended, e.g. in issue [#4006](https://github.com/angular/angular.js/issues/4006)),
 *      remember to escape your regular expression (and be aware that you might need more than
 *      one level of escaping depending on your templating engine and the way you interpolated
 *      the value.)  Do make use of your platform's escaping mechanism as it might be good
 *      enough before coding your own.  E.g. Ruby has
 *      [Regexp.escape(str)](http://www.ruby-doc.org/core-2.0.0/Regexp.html#method-c-escape)
 *      and Python has [re.escape](http://docs.python.org/library/re.html#re.escape).
 *      Javascript lacks a similar built in function for escaping.  Take a look at Google
 *      Closure library's [goog.string.regExpEscape(s)](
 *      http://docs.closure-library.googlecode.com/git/closure_goog_string_string.js.source.html#line962).
 *
 * Refer {@link ng.$sceDelegateProvider $sceDelegateProvider} for an example.
 *
 * ## Show me an example using SCE.
 *
 * <example module="mySceApp" deps="angular-sanitize.js">
 * <file name="index.html">
 *   <div ng-controller="AppController as myCtrl">
 *     <i ng-bind-html="myCtrl.explicitlyTrustedHtml" id="explicitlyTrustedHtml"></i><br><br>
 *     <b>User comments</b><br>
 *     By default, HTML that isn't explicitly trusted (e.g. Alice's comment) is sanitized when
 *     $sanitize is available.  If $sanitize isn't available, this results in an error instead of an
 *     exploit.
 *     <div class="well">
 *       <div ng-repeat="userComment in myCtrl.userComments">
 *         <b>{{userComment.name}}</b>:
 *         <span ng-bind-html="userComment.htmlComment" class="htmlComment"></span>
 *         <br>
 *       </div>
 *     </div>
 *   </div>
 * </file>
 *
 * <file name="script.js">
 *   angular.module('mySceApp', ['ngSanitize'])
 *     .controller('AppController', ['$http', '$templateCache', '$sce',
 *       function($http, $templateCache, $sce) {
 *         var self = this;
 *         $http.get("test_data.json", {cache: $templateCache}).success(function(userComments) {
 *           self.userComments = userComments;
 *         });
 *         self.explicitlyTrustedHtml = $sce.trustAsHtml(
 *             '<span onmouseover="this.textContent=&quot;Explicitly trusted HTML bypasses ' +
 *             'sanitization.&quot;">Hover over this text.</span>');
 *       }]);
 * </file>
 *
 * <file name="test_data.json">
 * [
 *   { "name": "Alice",
 *     "htmlComment":
 *         "<span onmouseover='this.textContent=\"PWN3D!\"'>Is <i>anyone</i> reading this?</span>"
 *   },
 *   { "name": "Bob",
 *     "htmlComment": "<i>Yes!</i>  Am I the only other one?"
 *   }
 * ]
 * </file>
 *
 * <file name="protractor.js" type="protractor">
 *   describe('SCE doc demo', function() {
 *     it('should sanitize untrusted values', function() {
 *       expect(element.all(by.css('.htmlComment')).first().getInnerHtml())
 *           .toBe('<span>Is <i>anyone</i> reading this?</span>');
 *     });
 *
 *     it('should NOT sanitize explicitly trusted values', function() {
 *       expect(element(by.id('explicitlyTrustedHtml')).getInnerHtml()).toBe(
 *           '<span onmouseover="this.textContent=&quot;Explicitly trusted HTML bypasses ' +
 *           'sanitization.&quot;">Hover over this text.</span>');
 *     });
 *   });
 * </file>
 * </example>
 *
 *
 *
 * ## Can I disable SCE completely?
 *
 * Yes, you can.  However, this is strongly discouraged.  SCE gives you a lot of security benefits
 * for little coding overhead.  It will be much harder to take an SCE disabled application and
 * either secure it on your own or enable SCE at a later stage.  It might make sense to disable SCE
 * for cases where you have a lot of existing code that was written before SCE was introduced and
 * you're migrating them a module at a time.
 *
 * That said, here's how you can completely disable SCE:
 *
 * ```
 * angular.module('myAppWithSceDisabledmyApp', []).config(function($sceProvider) {
 *   // Completely disable SCE.  For demonstration purposes only!
 *   // Do not use in new projects.
 *   $sceProvider.enabled(false);
 * });
 * ```
 *
 */
/* jshint maxlen: 100 */

function $SceProvider() {
  var enabled = true;

  /**
   * @ngdoc method
   * @name $sceProvider#enabled
   * @kind function
   *
   * @param {boolean=} value If provided, then enables/disables SCE.
   * @return {boolean} true if SCE is enabled, false otherwise.
   *
   * @description
   * Enables/disables SCE and returns the current value.
   */
  this.enabled = function(value) {
    if (arguments.length) {
      enabled = !!value;
    }
    return enabled;
  };


  /* Design notes on the default implementation for SCE.
   *
   * The API contract for the SCE delegate
   * -------------------------------------
   * The SCE delegate object must provide the following 3 methods:
   *
   * - trustAs(contextEnum, value)
   *     This method is used to tell the SCE service that the provided value is OK to use in the
   *     contexts specified by contextEnum.  It must return an object that will be accepted by
   *     getTrusted() for a compatible contextEnum and return this value.
   *
   * - valueOf(value)
   *     For values that were not produced by trustAs(), return them as is.  For values that were
   *     produced by trustAs(), return the corresponding input value to trustAs.  Basically, if
   *     trustAs is wrapping the given values into some type, this operation unwraps it when given
   *     such a value.
   *
   * - getTrusted(contextEnum, value)
   *     This function should return the a value that is safe to use in the context specified by
   *     contextEnum or throw and exception otherwise.
   *
   * NOTE: This contract deliberately does NOT state that values returned by trustAs() must be
   * opaque or wrapped in some holder object.  That happens to be an implementation detail.  For
   * instance, an implementation could maintain a registry of all trusted objects by context.  In
   * such a case, trustAs() would return the same object that was passed in.  getTrusted() would
   * return the same object passed in if it was found in the registry under a compatible context or
   * throw an exception otherwise.  An implementation might only wrap values some of the time based
   * on some criteria.  getTrusted() might return a value and not throw an exception for special
   * constants or objects even if not wrapped.  All such implementations fulfill this contract.
   *
   *
   * A note on the inheritance model for SCE contexts
   * ------------------------------------------------
   * I've used inheritance and made RESOURCE_URL wrapped types a subtype of URL wrapped types.  This
   * is purely an implementation details.
   *
   * The contract is simply this:
   *
   *     getTrusted($sce.RESOURCE_URL, value) succeeding implies that getTrusted($sce.URL, value)
   *     will also succeed.
   *
   * Inheritance happens to capture this in a natural way.  In some future, we
   * may not use inheritance anymore.  That is OK because no code outside of
   * sce.js and sceSpecs.js would need to be aware of this detail.
   */

  this.$get = ['$parse', '$sceDelegate', function(
                $parse,   $sceDelegate) {
    // Prereq: Ensure that we're not running in IE<11 quirks mode.  In that mode, IE < 11 allow
    // the "expression(javascript expression)" syntax which is insecure.
    if (enabled && msie < 8) {
      throw $sceMinErr('iequirks',
        'Strict Contextual Escaping does not support Internet Explorer version < 11 in quirks ' +
        'mode.  You can fix this by adding the text <!doctype html> to the top of your HTML ' +
        'document.  See http://docs.angularjs.org/api/ng.$sce for more information.');
    }

    var sce = shallowCopy(SCE_CONTEXTS);

    /**
     * @ngdoc method
     * @name $sce#isEnabled
     * @kind function
     *
     * @return {Boolean} true if SCE is enabled, false otherwise.  If you want to set the value, you
     * have to do it at module config time on {@link ng.$sceProvider $sceProvider}.
     *
     * @description
     * Returns a boolean indicating if SCE is enabled.
     */
    sce.isEnabled = function() {
      return enabled;
    };
    sce.trustAs = $sceDelegate.trustAs;
    sce.getTrusted = $sceDelegate.getTrusted;
    sce.valueOf = $sceDelegate.valueOf;

    if (!enabled) {
      sce.trustAs = sce.getTrusted = function(type, value) { return value; };
      sce.valueOf = identity;
    }

    /**
     * @ngdoc method
     * @name $sce#parseAs
     *
     * @description
     * Converts Angular {@link guide/expression expression} into a function.  This is like {@link
     * ng.$parse $parse} and is identical when the expression is a literal constant.  Otherwise, it
     * wraps the expression in a call to {@link ng.$sce#getTrusted $sce.getTrusted(*type*,
     * *result*)}
     *
     * @param {string} type The kind of SCE context in which this result will be used.
     * @param {string} expression String expression to compile.
     * @returns {function(context, locals)} a function which represents the compiled expression:
     *
     *    * `context` – `{object}` – an object against which any expressions embedded in the strings
     *      are evaluated against (typically a scope object).
     *    * `locals` – `{object=}` – local variables context object, useful for overriding values in
     *      `context`.
     */
    sce.parseAs = function sceParseAs(type, expr) {
      var parsed = $parse(expr);
      if (parsed.literal && parsed.constant) {
        return parsed;
      } else {
        return $parse(expr, function(value) {
          return sce.getTrusted(type, value);
        });
      }
    };

    /**
     * @ngdoc method
     * @name $sce#trustAs
     *
     * @description
     * Delegates to {@link ng.$sceDelegate#trustAs `$sceDelegate.trustAs`}.  As such,
     * returns an object that is trusted by angular for use in specified strict contextual
     * escaping contexts (such as ng-bind-html, ng-include, any src attribute
     * interpolation, any dom event binding attribute interpolation such as for onclick,  etc.)
     * that uses the provided value.  See * {@link ng.$sce $sce} for enabling strict contextual
     * escaping.
     *
     * @param {string} type The kind of context in which this value is safe for use.  e.g. url,
     *   resource_url, html, js and css.
     * @param {*} value The value that that should be considered trusted/safe.
     * @returns {*} A value that can be used to stand in for the provided `value` in places
     * where Angular expects a $sce.trustAs() return value.
     */

    /**
     * @ngdoc method
     * @name $sce#trustAsHtml
     *
     * @description
     * Shorthand method.  `$sce.trustAsHtml(value)` →
     *     {@link ng.$sceDelegate#trustAs `$sceDelegate.trustAs($sce.HTML, value)`}
     *
     * @param {*} value The value to trustAs.
     * @returns {*} An object that can be passed to {@link ng.$sce#getTrustedHtml
     *     $sce.getTrustedHtml(value)} to obtain the original value.  (privileged directives
     *     only accept expressions that are either literal constants or are the
     *     return value of {@link ng.$sce#trustAs $sce.trustAs}.)
     */

    /**
     * @ngdoc method
     * @name $sce#trustAsUrl
     *
     * @description
     * Shorthand method.  `$sce.trustAsUrl(value)` →
     *     {@link ng.$sceDelegate#trustAs `$sceDelegate.trustAs($sce.URL, value)`}
     *
     * @param {*} value The value to trustAs.
     * @returns {*} An object that can be passed to {@link ng.$sce#getTrustedUrl
     *     $sce.getTrustedUrl(value)} to obtain the original value.  (privileged directives
     *     only accept expressions that are either literal constants or are the
     *     return value of {@link ng.$sce#trustAs $sce.trustAs}.)
     */

    /**
     * @ngdoc method
     * @name $sce#trustAsResourceUrl
     *
     * @description
     * Shorthand method.  `$sce.trustAsResourceUrl(value)` →
     *     {@link ng.$sceDelegate#trustAs `$sceDelegate.trustAs($sce.RESOURCE_URL, value)`}
     *
     * @param {*} value The value to trustAs.
     * @returns {*} An object that can be passed to {@link ng.$sce#getTrustedResourceUrl
     *     $sce.getTrustedResourceUrl(value)} to obtain the original value.  (privileged directives
     *     only accept expressions that are either literal constants or are the return
     *     value of {@link ng.$sce#trustAs $sce.trustAs}.)
     */

    /**
     * @ngdoc method
     * @name $sce#trustAsJs
     *
     * @description
     * Shorthand method.  `$sce.trustAsJs(value)` →
     *     {@link ng.$sceDelegate#trustAs `$sceDelegate.trustAs($sce.JS, value)`}
     *
     * @param {*} value The value to trustAs.
     * @returns {*} An object that can be passed to {@link ng.$sce#getTrustedJs
     *     $sce.getTrustedJs(value)} to obtain the original value.  (privileged directives
     *     only accept expressions that are either literal constants or are the
     *     return value of {@link ng.$sce#trustAs $sce.trustAs}.)
     */

    /**
     * @ngdoc method
     * @name $sce#getTrusted
     *
     * @description
     * Delegates to {@link ng.$sceDelegate#getTrusted `$sceDelegate.getTrusted`}.  As such,
     * takes the result of a {@link ng.$sce#trustAs `$sce.trustAs`}() call and returns the
     * originally supplied value if the queried context type is a supertype of the created type.
     * If this condition isn't satisfied, throws an exception.
     *
     * @param {string} type The kind of context in which this value is to be used.
     * @param {*} maybeTrusted The result of a prior {@link ng.$sce#trustAs `$sce.trustAs`}
     *                         call.
     * @returns {*} The value the was originally provided to
     *              {@link ng.$sce#trustAs `$sce.trustAs`} if valid in this context.
     *              Otherwise, throws an exception.
     */

    /**
     * @ngdoc method
     * @name $sce#getTrustedHtml
     *
     * @description
     * Shorthand method.  `$sce.getTrustedHtml(value)` →
     *     {@link ng.$sceDelegate#getTrusted `$sceDelegate.getTrusted($sce.HTML, value)`}
     *
     * @param {*} value The value to pass to `$sce.getTrusted`.
     * @returns {*} The return value of `$sce.getTrusted($sce.HTML, value)`
     */

    /**
     * @ngdoc method
     * @name $sce#getTrustedCss
     *
     * @description
     * Shorthand method.  `$sce.getTrustedCss(value)` →
     *     {@link ng.$sceDelegate#getTrusted `$sceDelegate.getTrusted($sce.CSS, value)`}
     *
     * @param {*} value The value to pass to `$sce.getTrusted`.
     * @returns {*} The return value of `$sce.getTrusted($sce.CSS, value)`
     */

    /**
     * @ngdoc method
     * @name $sce#getTrustedUrl
     *
     * @description
     * Shorthand method.  `$sce.getTrustedUrl(value)` →
     *     {@link ng.$sceDelegate#getTrusted `$sceDelegate.getTrusted($sce.URL, value)`}
     *
     * @param {*} value The value to pass to `$sce.getTrusted`.
     * @returns {*} The return value of `$sce.getTrusted($sce.URL, value)`
     */

    /**
     * @ngdoc method
     * @name $sce#getTrustedResourceUrl
     *
     * @description
     * Shorthand method.  `$sce.getTrustedResourceUrl(value)` →
     *     {@link ng.$sceDelegate#getTrusted `$sceDelegate.getTrusted($sce.RESOURCE_URL, value)`}
     *
     * @param {*} value The value to pass to `$sceDelegate.getTrusted`.
     * @returns {*} The return value of `$sce.getTrusted($sce.RESOURCE_URL, value)`
     */

    /**
     * @ngdoc method
     * @name $sce#getTrustedJs
     *
     * @description
     * Shorthand method.  `$sce.getTrustedJs(value)` →
     *     {@link ng.$sceDelegate#getTrusted `$sceDelegate.getTrusted($sce.JS, value)`}
     *
     * @param {*} value The value to pass to `$sce.getTrusted`.
     * @returns {*} The return value of `$sce.getTrusted($sce.JS, value)`
     */

    /**
     * @ngdoc method
     * @name $sce#parseAsHtml
     *
     * @description
     * Shorthand method.  `$sce.parseAsHtml(expression string)` →
     *     {@link ng.$sce#parseAs `$sce.parseAs($sce.HTML, value)`}
     *
     * @param {string} expression String expression to compile.
     * @returns {function(context, locals)} a function which represents the compiled expression:
     *
     *    * `context` – `{object}` – an object against which any expressions embedded in the strings
     *      are evaluated against (typically a scope object).
     *    * `locals` – `{object=}` – local variables context object, useful for overriding values in
     *      `context`.
     */

    /**
     * @ngdoc method
     * @name $sce#parseAsCss
     *
     * @description
     * Shorthand method.  `$sce.parseAsCss(value)` →
     *     {@link ng.$sce#parseAs `$sce.parseAs($sce.CSS, value)`}
     *
     * @param {string} expression String expression to compile.
     * @returns {function(context, locals)} a function which represents the compiled expression:
     *
     *    * `context` – `{object}` – an object against which any expressions embedded in the strings
     *      are evaluated against (typically a scope object).
     *    * `locals` – `{object=}` – local variables context object, useful for overriding values in
     *      `context`.
     */

    /**
     * @ngdoc method
     * @name $sce#parseAsUrl
     *
     * @description
     * Shorthand method.  `$sce.parseAsUrl(value)` →
     *     {@link ng.$sce#parseAs `$sce.parseAs($sce.URL, value)`}
     *
     * @param {string} expression String expression to compile.
     * @returns {function(context, locals)} a function which represents the compiled expression:
     *
     *    * `context` – `{object}` – an object against which any expressions embedded in the strings
     *      are evaluated against (typically a scope object).
     *    * `locals` – `{object=}` – local variables context object, useful for overriding values in
     *      `context`.
     */

    /**
     * @ngdoc method
     * @name $sce#parseAsResourceUrl
     *
     * @description
     * Shorthand method.  `$sce.parseAsResourceUrl(value)` →
     *     {@link ng.$sce#parseAs `$sce.parseAs($sce.RESOURCE_URL, value)`}
     *
     * @param {string} expression String expression to compile.
     * @returns {function(context, locals)} a function which represents the compiled expression:
     *
     *    * `context` – `{object}` – an object against which any expressions embedded in the strings
     *      are evaluated against (typically a scope object).
     *    * `locals` – `{object=}` – local variables context object, useful for overriding values in
     *      `context`.
     */

    /**
     * @ngdoc method
     * @name $sce#parseAsJs
     *
     * @description
     * Shorthand method.  `$sce.parseAsJs(value)` →
     *     {@link ng.$sce#parseAs `$sce.parseAs($sce.JS, value)`}
     *
     * @param {string} expression String expression to compile.
     * @returns {function(context, locals)} a function which represents the compiled expression:
     *
     *    * `context` – `{object}` – an object against which any expressions embedded in the strings
     *      are evaluated against (typically a scope object).
     *    * `locals` – `{object=}` – local variables context object, useful for overriding values in
     *      `context`.
     */

    // Shorthand delegations.
    var parse = sce.parseAs,
        getTrusted = sce.getTrusted,
        trustAs = sce.trustAs;

    forEach(SCE_CONTEXTS, function(enumValue, name) {
      var lName = lowercase(name);
      sce[camelCase("parse_as_" + lName)] = function(expr) {
        return parse(enumValue, expr);
      };
      sce[camelCase("get_trusted_" + lName)] = function(value) {
        return getTrusted(enumValue, value);
      };
      sce[camelCase("trust_as_" + lName)] = function(value) {
        return trustAs(enumValue, value);
      };
    });

    return sce;
  }];
}

/**
 * !!! This is an undocumented "private" service !!!
 *
 * @name $sniffer
 * @requires $window
 * @requires $document
 *
 * @property {boolean} history Does the browser support html5 history api ?
 * @property {boolean} transitions Does the browser support CSS transition events ?
 * @property {boolean} animations Does the browser support CSS animation events ?
 *
 * @description
 * This is very simple implementation of testing browser's features.
 */
function $SnifferProvider() {
  this.$get = ['$window', '$document', function($window, $document) {
    var eventSupport = {},
        android =
          int((/android (\d+)/.exec(lowercase(($window.navigator || {}).userAgent)) || [])[1]),
        boxee = /Boxee/i.test(($window.navigator || {}).userAgent),
        document = $document[0] || {},
        vendorPrefix,
        vendorRegex = /^(Moz|webkit|ms)(?=[A-Z])/,
        bodyStyle = document.body && document.body.style,
        transitions = false,
        animations = false,
        match;

    if (bodyStyle) {
      for (var prop in bodyStyle) {
        if (match = vendorRegex.exec(prop)) {
          vendorPrefix = match[0];
          vendorPrefix = vendorPrefix.substr(0, 1).toUpperCase() + vendorPrefix.substr(1);
          break;
        }
      }

      if (!vendorPrefix) {
        vendorPrefix = ('WebkitOpacity' in bodyStyle) && 'webkit';
      }

      transitions = !!(('transition' in bodyStyle) || (vendorPrefix + 'Transition' in bodyStyle));
      animations  = !!(('animation' in bodyStyle) || (vendorPrefix + 'Animation' in bodyStyle));

      if (android && (!transitions ||  !animations)) {
        transitions = isString(document.body.style.webkitTransition);
        animations = isString(document.body.style.webkitAnimation);
      }
    }


    return {
      // Android has history.pushState, but it does not update location correctly
      // so let's not use the history API at all.
      // http://code.google.com/p/android/issues/detail?id=17471
      // https://github.com/angular/angular.js/issues/904

      // older webkit browser (533.9) on Boxee box has exactly the same problem as Android has
      // so let's not use the history API also
      // We are purposefully using `!(android < 4)` to cover the case when `android` is undefined
      // jshint -W018
      history: !!($window.history && $window.history.pushState && !(android < 4) && !boxee),
      // jshint +W018
      hasEvent: function(event) {
        // IE9 implements 'input' event it's so fubared that we rather pretend that it doesn't have
        // it. In particular the event is not fired when backspace or delete key are pressed or
        // when cut operation is performed.
        // IE10+ implements 'input' event but it erroneously fires under various situations,
        // e.g. when placeholder changes, or a form is focused.
        if (event === 'input' && msie <= 11) return false;

        if (isUndefined(eventSupport[event])) {
          var divElm = document.createElement('div');
          eventSupport[event] = 'on' + event in divElm;
        }

        return eventSupport[event];
      },
      csp: csp(),
      vendorPrefix: vendorPrefix,
      transitions: transitions,
      animations: animations,
      android: android
    };
  }];
}

var $compileMinErr = minErr('$compile');

/**
 * @ngdoc service
 * @name $templateRequest
 *
 * @description
 * The `$templateRequest` service runs security checks then downloads the provided template using
 * `$http` and, upon success, stores the contents inside of `$templateCache`. If the HTTP request
 * fails or the response data of the HTTP request is empty, a `$compile` error will be thrown (the
 * exception can be thwarted by setting the 2nd parameter of the function to true). Note that the
 * contents of `$templateCache` are trusted, so the call to `$sce.getTrustedUrl(tpl)` is omitted
 * when `tpl` is of type string and `$templateCache` has the matching entry.
 *
 * @param {string|TrustedResourceUrl} tpl The HTTP request template URL
 * @param {boolean=} ignoreRequestError Whether or not to ignore the exception when the request fails or the template is empty
 *
 * @return {Promise} the HTTP Promise for the given.
 *
 * @property {number} totalPendingRequests total amount of pending template requests being downloaded.
 */
function $TemplateRequestProvider() {
  this.$get = ['$templateCache', '$http', '$q', '$sce', function($templateCache, $http, $q, $sce) {
    function handleRequestFn(tpl, ignoreRequestError) {
      handleRequestFn.totalPendingRequests++;

      // We consider the template cache holds only trusted templates, so
      // there's no need to go through whitelisting again for keys that already
      // are included in there. This also makes Angular accept any script
      // directive, no matter its name. However, we still need to unwrap trusted
      // types.
      if (!isString(tpl) || !$templateCache.get(tpl)) {
        tpl = $sce.getTrustedResourceUrl(tpl);
      }

      var transformResponse = $http.defaults && $http.defaults.transformResponse;

      if (isArray(transformResponse)) {
        transformResponse = transformResponse.filter(function(transformer) {
          return transformer !== defaultHttpResponseTransform;
        });
      } else if (transformResponse === defaultHttpResponseTransform) {
        transformResponse = null;
      }

      var httpOptions = {
        cache: $templateCache,
        transformResponse: transformResponse
      };

      return $http.get(tpl, httpOptions)
        ['finally'](function() {
          handleRequestFn.totalPendingRequests--;
        })
        .then(function(response) {
          return response.data;
        }, handleError);

      function handleError(resp) {
        if (!ignoreRequestError) {
          throw $compileMinErr('tpload', 'Failed to load template: {0}', tpl);
        }
        return $q.reject(resp);
      }
    }

    handleRequestFn.totalPendingRequests = 0;

    return handleRequestFn;
  }];
}

function $$TestabilityProvider() {
  this.$get = ['$rootScope', '$browser', '$location',
       function($rootScope,   $browser,   $location) {

    /**
     * @name $testability
     *
     * @description
     * The private $$testability service provides a collection of methods for use when debugging
     * or by automated test and debugging tools.
     */
    var testability = {};

    /**
     * @name $$testability#findBindings
     *
     * @description
     * Returns an array of elements that are bound (via ng-bind or {{}})
     * to expressions matching the input.
     *
     * @param {Element} element The element root to search from.
     * @param {string} expression The binding expression to match.
     * @param {boolean} opt_exactMatch If true, only returns exact matches
     *     for the expression. Filters and whitespace are ignored.
     */
    testability.findBindings = function(element, expression, opt_exactMatch) {
      var bindings = element.getElementsByClassName('ng-binding');
      var matches = [];
      forEach(bindings, function(binding) {
        var dataBinding = angular.element(binding).data('$binding');
        if (dataBinding) {
          forEach(dataBinding, function(bindingName) {
            if (opt_exactMatch) {
              var matcher = new RegExp('(^|\\s)' + escapeForRegexp(expression) + '(\\s|\\||$)');
              if (matcher.test(bindingName)) {
                matches.push(binding);
              }
            } else {
              if (bindingName.indexOf(expression) != -1) {
                matches.push(binding);
              }
            }
          });
        }
      });
      return matches;
    };

    /**
     * @name $$testability#findModels
     *
     * @description
     * Returns an array of elements that are two-way found via ng-model to
     * expressions matching the input.
     *
     * @param {Element} element The element root to search from.
     * @param {string} expression The model expression to match.
     * @param {boolean} opt_exactMatch If true, only returns exact matches
     *     for the expression.
     */
    testability.findModels = function(element, expression, opt_exactMatch) {
      var prefixes = ['ng-', 'data-ng-', 'ng\\:'];
      for (var p = 0; p < prefixes.length; ++p) {
        var attributeEquals = opt_exactMatch ? '=' : '*=';
        var selector = '[' + prefixes[p] + 'model' + attributeEquals + '"' + expression + '"]';
        var elements = element.querySelectorAll(selector);
        if (elements.length) {
          return elements;
        }
      }
    };

    /**
     * @name $$testability#getLocation
     *
     * @description
     * Shortcut for getting the location in a browser agnostic way. Returns
     *     the path, search, and hash. (e.g. /path?a=b#hash)
     */
    testability.getLocation = function() {
      return $location.url();
    };

    /**
     * @name $$testability#setLocation
     *
     * @description
     * Shortcut for navigating to a location without doing a full page reload.
     *
     * @param {string} url The location url (path, search and hash,
     *     e.g. /path?a=b#hash) to go to.
     */
    testability.setLocation = function(url) {
      if (url !== $location.url()) {
        $location.url(url);
        $rootScope.$digest();
      }
    };

    /**
     * @name $$testability#whenStable
     *
     * @description
     * Calls the callback when $timeout and $http requests are completed.
     *
     * @param {function} callback
     */
    testability.whenStable = function(callback) {
      $browser.notifyWhenNoOutstandingRequests(callback);
    };

    return testability;
  }];
}

function $TimeoutProvider() {
  this.$get = ['$rootScope', '$browser', '$q', '$$q', '$exceptionHandler',
       function($rootScope,   $browser,   $q,   $$q,   $exceptionHandler) {
    var deferreds = {};


     /**
      * @ngdoc service
      * @name $timeout
      *
      * @description
      * Angular's wrapper for `window.setTimeout`. The `fn` function is wrapped into a try/catch
      * block and delegates any exceptions to
      * {@link ng.$exceptionHandler $exceptionHandler} service.
      *
      * The return value of registering a timeout function is a promise, which will be resolved when
      * the timeout is reached and the timeout function is executed.
      *
      * To cancel a timeout request, call `$timeout.cancel(promise)`.
      *
      * In tests you can use {@link ngMock.$timeout `$timeout.flush()`} to
      * synchronously flush the queue of deferred functions.
      *
      * @param {function()} fn A function, whose execution should be delayed.
      * @param {number=} [delay=0] Delay in milliseconds.
      * @param {boolean=} [invokeApply=true] If set to `false` skips model dirty checking, otherwise
      *   will invoke `fn` within the {@link ng.$rootScope.Scope#$apply $apply} block.
      * @returns {Promise} Promise that will be resolved when the timeout is reached. The value this
      *   promise will be resolved with is the return value of the `fn` function.
      *
      */
    function timeout(fn, delay, invokeApply) {
      var skipApply = (isDefined(invokeApply) && !invokeApply),
          deferred = (skipApply ? $$q : $q).defer(),
          promise = deferred.promise,
          timeoutId;

      timeoutId = $browser.defer(function() {
        try {
          deferred.resolve(fn());
        } catch (e) {
          deferred.reject(e);
          $exceptionHandler(e);
        }
        finally {
          delete deferreds[promise.$$timeoutId];
        }

        if (!skipApply) $rootScope.$apply();
      }, delay);

      promise.$$timeoutId = timeoutId;
      deferreds[timeoutId] = deferred;

      return promise;
    }


     /**
      * @ngdoc method
      * @name $timeout#cancel
      *
      * @description
      * Cancels a task associated with the `promise`. As a result of this, the promise will be
      * resolved with a rejection.
      *
      * @param {Promise=} promise Promise returned by the `$timeout` function.
      * @returns {boolean} Returns `true` if the task hasn't executed yet and was successfully
      *   canceled.
      */
    timeout.cancel = function(promise) {
      if (promise && promise.$$timeoutId in deferreds) {
        deferreds[promise.$$timeoutId].reject('canceled');
        delete deferreds[promise.$$timeoutId];
        return $browser.defer.cancel(promise.$$timeoutId);
      }
      return false;
    };

    return timeout;
  }];
}

// NOTE:  The usage of window and document instead of $window and $document here is
// deliberate.  This service depends on the specific behavior of anchor nodes created by the
// browser (resolving and parsing URLs) that is unlikely to be provided by mock objects and
// cause us to break tests.  In addition, when the browser resolves a URL for XHR, it
// doesn't know about mocked locations and resolves URLs to the real document - which is
// exactly the behavior needed here.  There is little value is mocking these out for this
// service.
var urlParsingNode = document.createElement("a");
var originUrl = urlResolve(window.location.href);


/**
 *
 * Implementation Notes for non-IE browsers
 * ----------------------------------------
 * Assigning a URL to the href property of an anchor DOM node, even one attached to the DOM,
 * results both in the normalizing and parsing of the URL.  Normalizing means that a relative
 * URL will be resolved into an absolute URL in the context of the application document.
 * Parsing means that the anchor node's host, hostname, protocol, port, pathname and related
 * properties are all populated to reflect the normalized URL.  This approach has wide
 * compatibility - Safari 1+, Mozilla 1+, Opera 7+,e etc.  See
 * http://www.aptana.com/reference/html/api/HTMLAnchorElement.html
 *
 * Implementation Notes for IE
 * ---------------------------
 * IE <= 10 normalizes the URL when assigned to the anchor node similar to the other
 * browsers.  However, the parsed components will not be set if the URL assigned did not specify
 * them.  (e.g. if you assign a.href = "foo", then a.protocol, a.host, etc. will be empty.)  We
 * work around that by performing the parsing in a 2nd step by taking a previously normalized
 * URL (e.g. by assigning to a.href) and assigning it a.href again.  This correctly populates the
 * properties such as protocol, hostname, port, etc.
 *
 * References:
 *   http://developer.mozilla.org/en-US/docs/Web/API/HTMLAnchorElement
 *   http://www.aptana.com/reference/html/api/HTMLAnchorElement.html
 *   http://url.spec.whatwg.org/#urlutils
 *   https://github.com/angular/angular.js/pull/2902
 *   http://james.padolsey.com/javascript/parsing-urls-with-the-dom/
 *
 * @kind function
 * @param {string} url The URL to be parsed.
 * @description Normalizes and parses a URL.
 * @returns {object} Returns the normalized URL as a dictionary.
 *
 *   | member name   | Description    |
 *   |---------------|----------------|
 *   | href          | A normalized version of the provided URL if it was not an absolute URL |
 *   | protocol      | The protocol including the trailing colon                              |
 *   | host          | The host and port (if the port is non-default) of the normalizedUrl    |
 *   | search        | The search params, minus the question mark                             |
 *   | hash          | The hash string, minus the hash symbol
 *   | hostname      | The hostname
 *   | port          | The port, without ":"
 *   | pathname      | The pathname, beginning with "/"
 *
 */
function urlResolve(url) {
  var href = url;

  if (msie) {
    // Normalize before parse.  Refer Implementation Notes on why this is
    // done in two steps on IE.
    urlParsingNode.setAttribute("href", href);
    href = urlParsingNode.href;
  }

  urlParsingNode.setAttribute('href', href);

  // urlParsingNode provides the UrlUtils interface - http://url.spec.whatwg.org/#urlutils
  return {
    href: urlParsingNode.href,
    protocol: urlParsingNode.protocol ? urlParsingNode.protocol.replace(/:$/, '') : '',
    host: urlParsingNode.host,
    search: urlParsingNode.search ? urlParsingNode.search.replace(/^\?/, '') : '',
    hash: urlParsingNode.hash ? urlParsingNode.hash.replace(/^#/, '') : '',
    hostname: urlParsingNode.hostname,
    port: urlParsingNode.port,
    pathname: (urlParsingNode.pathname.charAt(0) === '/')
      ? urlParsingNode.pathname
      : '/' + urlParsingNode.pathname
  };
}

/**
 * Parse a request URL and determine whether this is a same-origin request as the application document.
 *
 * @param {string|object} requestUrl The url of the request as a string that will be resolved
 * or a parsed URL object.
 * @returns {boolean} Whether the request is for the same origin as the application document.
 */
function urlIsSameOrigin(requestUrl) {
  var parsed = (isString(requestUrl)) ? urlResolve(requestUrl) : requestUrl;
  return (parsed.protocol === originUrl.protocol &&
          parsed.host === originUrl.host);
}

/**
 * @ngdoc service
 * @name $window
 *
 * @description
 * A reference to the browser's `window` object. While `window`
 * is globally available in JavaScript, it causes testability problems, because
 * it is a global variable. In angular we always refer to it through the
 * `$window` service, so it may be overridden, removed or mocked for testing.
 *
 * Expressions, like the one defined for the `ngClick` directive in the example
 * below, are evaluated with respect to the current scope.  Therefore, there is
 * no risk of inadvertently coding in a dependency on a global value in such an
 * expression.
 *
 * @example
   <example module="windowExample">
     <file name="index.html">
       <script>
         angular.module('windowExample', [])
           .controller('ExampleController', ['$scope', '$window', function($scope, $window) {
             $scope.greeting = 'Hello, World!';
             $scope.doGreeting = function(greeting) {
               $window.alert(greeting);
             };
           }]);
       </script>
       <div ng-controller="ExampleController">
         <input type="text" ng-model="greeting" />
         <button ng-click="doGreeting(greeting)">ALERT</button>
       </div>
     </file>
     <file name="protractor.js" type="protractor">
      it('should display the greeting in the input box', function() {
       element(by.model('greeting')).sendKeys('Hello, E2E Tests');
       // If we click the button it will block the test runner
       // element(':button').click();
      });
     </file>
   </example>
 */
function $WindowProvider() {
  this.$get = valueFn(window);
}

/* global currencyFilter: true,
 dateFilter: true,
 filterFilter: true,
 jsonFilter: true,
 limitToFilter: true,
 lowercaseFilter: true,
 numberFilter: true,
 orderByFilter: true,
 uppercaseFilter: true,
 */

/**
 * @ngdoc provider
 * @name $filterProvider
 * @description
 *
 * Filters are just functions which transform input to an output. However filters need to be
 * Dependency Injected. To achieve this a filter definition consists of a factory function which is
 * annotated with dependencies and is responsible for creating a filter function.
 *
 * <div class="alert alert-warning">
 * **Note:** Filter names must be valid angular {@link expression} identifiers, such as `uppercase` or `orderBy`.
 * Names with special characters, such as hyphens and dots, are not allowed. If you wish to namespace
 * your filters, then you can use capitalization (`myappSubsectionFilterx`) or underscores
 * (`myapp_subsection_filterx`).
 * </div>
 *
 * ```js
 *   // Filter registration
 *   function MyModule($provide, $filterProvider) {
 *     // create a service to demonstrate injection (not always needed)
 *     $provide.value('greet', function(name){
 *       return 'Hello ' + name + '!';
 *     });
 *
 *     // register a filter factory which uses the
 *     // greet service to demonstrate DI.
 *     $filterProvider.register('greet', function(greet){
 *       // return the filter function which uses the greet service
 *       // to generate salutation
 *       return function(text) {
 *         // filters need to be forgiving so check input validity
 *         return text && greet(text) || text;
 *       };
 *     });
 *   }
 * ```
 *
 * The filter function is registered with the `$injector` under the filter name suffix with
 * `Filter`.
 *
 * ```js
 *   it('should be the same instance', inject(
 *     function($filterProvider) {
 *       $filterProvider.register('reverse', function(){
 *         return ...;
 *       });
 *     },
 *     function($filter, reverseFilter) {
 *       expect($filter('reverse')).toBe(reverseFilter);
 *     });
 * ```
 *
 *
 * For more information about how angular filters work, and how to create your own filters, see
 * {@link guide/filter Filters} in the Angular Developer Guide.
 */

/**
 * @ngdoc service
 * @name $filter
 * @kind function
 * @description
 * Filters are used for formatting data displayed to the user.
 *
 * The general syntax in templates is as follows:
 *
 *         {{ expression [| filter_name[:parameter_value] ... ] }}
 *
 * @param {String} name Name of the filter function to retrieve
 * @return {Function} the filter function
 * @example
   <example name="$filter" module="filterExample">
     <file name="index.html">
       <div ng-controller="MainCtrl">
        <h3>{{ originalText }}</h3>
        <h3>{{ filteredText }}</h3>
       </div>
     </file>

     <file name="script.js">
      angular.module('filterExample', [])
      .controller('MainCtrl', function($scope, $filter) {
        $scope.originalText = 'hello';
        $scope.filteredText = $filter('uppercase')($scope.originalText);
      });
     </file>
   </example>
  */
$FilterProvider.$inject = ['$provide'];
function $FilterProvider($provide) {
  var suffix = 'Filter';

  /**
   * @ngdoc method
   * @name $filterProvider#register
   * @param {string|Object} name Name of the filter function, or an object map of filters where
   *    the keys are the filter names and the values are the filter factories.
   *
   *    <div class="alert alert-warning">
   *    **Note:** Filter names must be valid angular {@link expression} identifiers, such as `uppercase` or `orderBy`.
   *    Names with special characters, such as hyphens and dots, are not allowed. If you wish to namespace
   *    your filters, then you can use capitalization (`myappSubsectionFilterx`) or underscores
   *    (`myapp_subsection_filterx`).
   *    </div>
   * @returns {Object} Registered filter instance, or if a map of filters was provided then a map
   *    of the registered filter instances.
   */
  function register(name, factory) {
    if (isObject(name)) {
      var filters = {};
      forEach(name, function(filter, key) {
        filters[key] = register(key, filter);
      });
      return filters;
    } else {
      return $provide.factory(name + suffix, factory);
    }
  }
  this.register = register;

  this.$get = ['$injector', function($injector) {
    return function(name) {
      return $injector.get(name + suffix);
    };
  }];

  ////////////////////////////////////////

  /* global
    currencyFilter: false,
    dateFilter: false,
    filterFilter: false,
    jsonFilter: false,
    limitToFilter: false,
    lowercaseFilter: false,
    numberFilter: false,
    orderByFilter: false,
    uppercaseFilter: false,
  */

  register('currency', currencyFilter);
  register('date', dateFilter);
  register('filter', filterFilter);
  register('json', jsonFilter);
  register('limitTo', limitToFilter);
  register('lowercase', lowercaseFilter);
  register('number', numberFilter);
  register('orderBy', orderByFilter);
  register('uppercase', uppercaseFilter);
}

/**
 * @ngdoc filter
 * @name filter
 * @kind function
 *
 * @description
 * Selects a subset of items from `array` and returns it as a new array.
 *
 * @param {Array} array The source array.
 * @param {string|Object|function()} expression The predicate to be used for selecting items from
 *   `array`.
 *
 *   Can be one of:
 *
 *   - `string`: The string is used for matching against the contents of the `array`. All strings or
 *     objects with string properties in `array` that match this string will be returned. This also
 *     applies to nested object properties.
 *     The predicate can be negated by prefixing the string with `!`.
 *
 *   - `Object`: A pattern object can be used to filter specific properties on objects contained
 *     by `array`. For example `{name:"M", phone:"1"}` predicate will return an array of items
 *     which have property `name` containing "M" and property `phone` containing "1". A special
 *     property name `$` can be used (as in `{$:"text"}`) to accept a match against any
 *     property of the object or its nested object properties. That's equivalent to the simple
 *     substring match with a `string` as described above. The predicate can be negated by prefixing
 *     the string with `!`.
 *     For example `{name: "!M"}` predicate will return an array of items which have property `name`
 *     not containing "M".
 *
 *     Note that a named property will match properties on the same level only, while the special
 *     `$` property will match properties on the same level or deeper. E.g. an array item like
 *     `{name: {first: 'John', last: 'Doe'}}` will **not** be matched by `{name: 'John'}`, but
 *     **will** be matched by `{$: 'John'}`.
 *
 *   - `function(value, index)`: A predicate function can be used to write arbitrary filters. The
 *     function is called for each element of `array`. The final result is an array of those
 *     elements that the predicate returned true for.
 *
 * @param {function(actual, expected)|true|undefined} comparator Comparator which is used in
 *     determining if the expected value (from the filter expression) and actual value (from
 *     the object in the array) should be considered a match.
 *
 *   Can be one of:
 *
 *   - `function(actual, expected)`:
 *     The function will be given the object value and the predicate value to compare and
 *     should return true if both values should be considered equal.
 *
 *   - `true`: A shorthand for `function(actual, expected) { return angular.equals(actual, expected)}`.
 *     This is essentially strict comparison of expected and actual.
 *
 *   - `false|undefined`: A short hand for a function which will look for a substring match in case
 *     insensitive way.
 *
 * @example
   <example>
     <file name="index.html">
       <div ng-init="friends = [{name:'John', phone:'555-1276'},
                                {name:'Mary', phone:'800-BIG-MARY'},
                                {name:'Mike', phone:'555-4321'},
                                {name:'Adam', phone:'555-5678'},
                                {name:'Julie', phone:'555-8765'},
                                {name:'Juliette', phone:'555-5678'}]"></div>

       Search: <input ng-model="searchText">
       <table id="searchTextResults">
         <tr><th>Name</th><th>Phone</th></tr>
         <tr ng-repeat="friend in friends | filter:searchText">
           <td>{{friend.name}}</td>
           <td>{{friend.phone}}</td>
         </tr>
       </table>
       <hr>
       Any: <input ng-model="search.$"> <br>
       Name only <input ng-model="search.name"><br>
       Phone only <input ng-model="search.phone"><br>
       Equality <input type="checkbox" ng-model="strict"><br>
       <table id="searchObjResults">
         <tr><th>Name</th><th>Phone</th></tr>
         <tr ng-repeat="friendObj in friends | filter:search:strict">
           <td>{{friendObj.name}}</td>
           <td>{{friendObj.phone}}</td>
         </tr>
       </table>
     </file>
     <file name="protractor.js" type="protractor">
       var expectFriendNames = function(expectedNames, key) {
         element.all(by.repeater(key + ' in friends').column(key + '.name')).then(function(arr) {
           arr.forEach(function(wd, i) {
             expect(wd.getText()).toMatch(expectedNames[i]);
           });
         });
       };

       it('should search across all fields when filtering with a string', function() {
         var searchText = element(by.model('searchText'));
         searchText.clear();
         searchText.sendKeys('m');
         expectFriendNames(['Mary', 'Mike', 'Adam'], 'friend');

         searchText.clear();
         searchText.sendKeys('76');
         expectFriendNames(['John', 'Julie'], 'friend');
       });

       it('should search in specific fields when filtering with a predicate object', function() {
         var searchAny = element(by.model('search.$'));
         searchAny.clear();
         searchAny.sendKeys('i');
         expectFriendNames(['Mary', 'Mike', 'Julie', 'Juliette'], 'friendObj');
       });
       it('should use a equal comparison when comparator is true', function() {
         var searchName = element(by.model('search.name'));
         var strict = element(by.model('strict'));
         searchName.clear();
         searchName.sendKeys('Julie');
         strict.click();
         expectFriendNames(['Julie'], 'friendObj');
       });
     </file>
   </example>
 */
function filterFilter() {
  return function(array, expression, comparator) {
    if (!isArray(array)) return array;

    var expressionType = (expression !== null) ? typeof expression : 'null';
    var predicateFn;
    var matchAgainstAnyProp;

    switch (expressionType) {
      case 'function':
        predicateFn = expression;
        break;
      case 'boolean':
      case 'null':
      case 'number':
      case 'string':
        matchAgainstAnyProp = true;
        //jshint -W086
      case 'object':
        //jshint +W086
        predicateFn = createPredicateFn(expression, comparator, matchAgainstAnyProp);
        break;
      default:
        return array;
    }

    return array.filter(predicateFn);
  };
}

// Helper functions for `filterFilter`
function createPredicateFn(expression, comparator, matchAgainstAnyProp) {
  var shouldMatchPrimitives = isObject(expression) && ('$' in expression);
  var predicateFn;

  if (comparator === true) {
    comparator = equals;
  } else if (!isFunction(comparator)) {
    comparator = function(actual, expected) {
      if (isUndefined(actual)) {
        // No substring matching against `undefined`
        return false;
      }
      if ((actual === null) || (expected === null)) {
        // No substring matching against `null`; only match against `null`
        return actual === expected;
      }
      if (isObject(actual) || isObject(expected)) {
        // Prevent an object to be considered equal to a string like `'[object'`
        return false;
      }

      actual = lowercase('' + actual);
      expected = lowercase('' + expected);
      return actual.indexOf(expected) !== -1;
    };
  }

  predicateFn = function(item) {
    if (shouldMatchPrimitives && !isObject(item)) {
      return deepCompare(item, expression.$, comparator, false);
    }
    return deepCompare(item, expression, comparator, matchAgainstAnyProp);
  };

  return predicateFn;
}

function deepCompare(actual, expected, comparator, matchAgainstAnyProp, dontMatchWholeObject) {
  var actualType = (actual !== null) ? typeof actual : 'null';
  var expectedType = (expected !== null) ? typeof expected : 'null';

  if ((expectedType === 'string') && (expected.charAt(0) === '!')) {
    return !deepCompare(actual, expected.substring(1), comparator, matchAgainstAnyProp);
  } else if (isArray(actual)) {
    // In case `actual` is an array, consider it a match
    // if ANY of it's items matches `expected`
    return actual.some(function(item) {
      return deepCompare(item, expected, comparator, matchAgainstAnyProp);
    });
  }

  switch (actualType) {
    case 'object':
      var key;
      if (matchAgainstAnyProp) {
        for (key in actual) {
          if ((key.charAt(0) !== '$') && deepCompare(actual[key], expected, comparator, true)) {
            return true;
          }
        }
        return dontMatchWholeObject ? false : deepCompare(actual, expected, comparator, false);
      } else if (expectedType === 'object') {
        for (key in expected) {
          var expectedVal = expected[key];
          if (isFunction(expectedVal) || isUndefined(expectedVal)) {
            continue;
          }

          var matchAnyProperty = key === '$';
          var actualVal = matchAnyProperty ? actual : actual[key];
          if (!deepCompare(actualVal, expectedVal, comparator, matchAnyProperty, matchAnyProperty)) {
            return false;
          }
        }
        return true;
      } else {
        return comparator(actual, expected);
      }
      break;
    case 'function':
      return false;
    default:
      return comparator(actual, expected);
  }
}

/**
 * @ngdoc filter
 * @name currency
 * @kind function
 *
 * @description
 * Formats a number as a currency (ie $1,234.56). When no currency symbol is provided, default
 * symbol for current locale is used.
 *
 * @param {number} amount Input to filter.
 * @param {string=} symbol Currency symbol or identifier to be displayed.
 * @param {number=} fractionSize Number of decimal places to round the amount to, defaults to default max fraction size for current locale
 * @returns {string} Formatted number.
 *
 *
 * @example
   <example module="currencyExample">
     <file name="index.html">
       <script>
         angular.module('currencyExample', [])
           .controller('ExampleController', ['$scope', function($scope) {
             $scope.amount = 1234.56;
           }]);
       </script>
       <div ng-controller="ExampleController">
         <input type="number" ng-model="amount"> <br>
         default currency symbol ($): <span id="currency-default">{{amount | currency}}</span><br>
         custom currency identifier (USD$): <span id="currency-custom">{{amount | currency:"USD$"}}</span>
         no fractions (0): <span id="currency-no-fractions">{{amount | currency:"USD$":0}}</span>
       </div>
     </file>
     <file name="protractor.js" type="protractor">
       it('should init with 1234.56', function() {
         expect(element(by.id('currency-default')).getText()).toBe('$1,234.56');
         expect(element(by.id('currency-custom')).getText()).toBe('USD$1,234.56');
         expect(element(by.id('currency-no-fractions')).getText()).toBe('USD$1,235');
       });
       it('should update', function() {
         if (browser.params.browser == 'safari') {
           // Safari does not understand the minus key. See
           // https://github.com/angular/protractor/issues/481
           return;
         }
         element(by.model('amount')).clear();
         element(by.model('amount')).sendKeys('-1234');
         expect(element(by.id('currency-default')).getText()).toBe('($1,234.00)');
         expect(element(by.id('currency-custom')).getText()).toBe('(USD$1,234.00)');
         expect(element(by.id('currency-no-fractions')).getText()).toBe('(USD$1,234)');
       });
     </file>
   </example>
 */
currencyFilter.$inject = ['$locale'];
function currencyFilter($locale) {
  var formats = $locale.NUMBER_FORMATS;
  return function(amount, currencySymbol, fractionSize) {
    if (isUndefined(currencySymbol)) {
      currencySymbol = formats.CURRENCY_SYM;
    }

    if (isUndefined(fractionSize)) {
      fractionSize = formats.PATTERNS[1].maxFrac;
    }

    // if null or undefined pass it through
    return (amount == null)
        ? amount
        : formatNumber(amount, formats.PATTERNS[1], formats.GROUP_SEP, formats.DECIMAL_SEP, fractionSize).
            replace(/\u00A4/g, currencySymbol);
  };
}

/**
 * @ngdoc filter
 * @name number
 * @kind function
 *
 * @description
 * Formats a number as text.
 *
 * If the input is null or undefined, it will just be returned.
 * If the input is infinite (Infinity/-Infinity) the Infinity symbol '∞' is returned.
 * If the input is not a number an empty string is returned.
 *
 * @param {number|string} number Number to format.
 * @param {(number|string)=} fractionSize Number of decimal places to round the number to.
 * If this is not provided then the fraction size is computed from the current locale's number
 * formatting pattern. In the case of the default locale, it will be 3.
 * @returns {string} Number rounded to decimalPlaces and places a “,” after each third digit.
 *
 * @example
   <example module="numberFilterExample">
     <file name="index.html">
       <script>
         angular.module('numberFilterExample', [])
           .controller('ExampleController', ['$scope', function($scope) {
             $scope.val = 1234.56789;
           }]);
       </script>
       <div ng-controller="ExampleController">
         Enter number: <input ng-model='val'><br>
         Default formatting: <span id='number-default'>{{val | number}}</span><br>
         No fractions: <span>{{val | number:0}}</span><br>
         Negative number: <span>{{-val | number:4}}</span>
       </div>
     </file>
     <file name="protractor.js" type="protractor">
       it('should format numbers', function() {
         expect(element(by.id('number-default')).getText()).toBe('1,234.568');
         expect(element(by.binding('val | number:0')).getText()).toBe('1,235');
         expect(element(by.binding('-val | number:4')).getText()).toBe('-1,234.5679');
       });

       it('should update', function() {
         element(by.model('val')).clear();
         element(by.model('val')).sendKeys('3374.333');
         expect(element(by.id('number-default')).getText()).toBe('3,374.333');
         expect(element(by.binding('val | number:0')).getText()).toBe('3,374');
         expect(element(by.binding('-val | number:4')).getText()).toBe('-3,374.3330');
      });
     </file>
   </example>
 */


numberFilter.$inject = ['$locale'];
function numberFilter($locale) {
  var formats = $locale.NUMBER_FORMATS;
  return function(number, fractionSize) {

    // if null or undefined pass it through
    return (number == null)
        ? number
        : formatNumber(number, formats.PATTERNS[0], formats.GROUP_SEP, formats.DECIMAL_SEP,
                       fractionSize);
  };
}

var DECIMAL_SEP = '.';
function formatNumber(number, pattern, groupSep, decimalSep, fractionSize) {
  if (!isFinite(number) || isObject(number)) return '';

  var isNegative = number < 0;
  number = Math.abs(number);
  var numStr = number + '',
      formatedText = '',
      parts = [];

  var hasExponent = false;
  if (numStr.indexOf('e') !== -1) {
    var match = numStr.match(/([\d\.]+)e(-?)(\d+)/);
    if (match && match[2] == '-' && match[3] > fractionSize + 1) {
      number = 0;
    } else {
      formatedText = numStr;
      hasExponent = true;
    }
  }

  if (!hasExponent) {
    var fractionLen = (numStr.split(DECIMAL_SEP)[1] || '').length;

    // determine fractionSize if it is not specified
    if (isUndefined(fractionSize)) {
      fractionSize = Math.min(Math.max(pattern.minFrac, fractionLen), pattern.maxFrac);
    }

    // safely round numbers in JS without hitting imprecisions of floating-point arithmetics
    // inspired by:
    // https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Math/round
    number = +(Math.round(+(number.toString() + 'e' + fractionSize)).toString() + 'e' + -fractionSize);

    var fraction = ('' + number).split(DECIMAL_SEP);
    var whole = fraction[0];
    fraction = fraction[1] || '';

    var i, pos = 0,
        lgroup = pattern.lgSize,
        group = pattern.gSize;

    if (whole.length >= (lgroup + group)) {
      pos = whole.length - lgroup;
      for (i = 0; i < pos; i++) {
        if ((pos - i) % group === 0 && i !== 0) {
          formatedText += groupSep;
        }
        formatedText += whole.charAt(i);
      }
    }

    for (i = pos; i < whole.length; i++) {
      if ((whole.length - i) % lgroup === 0 && i !== 0) {
        formatedText += groupSep;
      }
      formatedText += whole.charAt(i);
    }

    // format fraction part.
    while (fraction.length < fractionSize) {
      fraction += '0';
    }

    if (fractionSize && fractionSize !== "0") formatedText += decimalSep + fraction.substr(0, fractionSize);
  } else {
    if (fractionSize > 0 && number < 1) {
      formatedText = number.toFixed(fractionSize);
      number = parseFloat(formatedText);
    }
  }

  if (number === 0) {
    isNegative = false;
  }

  parts.push(isNegative ? pattern.negPre : pattern.posPre,
             formatedText,
             isNegative ? pattern.negSuf : pattern.posSuf);
  return parts.join('');
}

function padNumber(num, digits, trim) {
  var neg = '';
  if (num < 0) {
    neg =  '-';
    num = -num;
  }
  num = '' + num;
  while (num.length < digits) num = '0' + num;
  if (trim)
    num = num.substr(num.length - digits);
  return neg + num;
}


function dateGetter(name, size, offset, trim) {
  offset = offset || 0;
  return function(date) {
    var value = date['get' + name]();
    if (offset > 0 || value > -offset)
      value += offset;
    if (value === 0 && offset == -12) value = 12;
    return padNumber(value, size, trim);
  };
}

function dateStrGetter(name, shortForm) {
  return function(date, formats) {
    var value = date['get' + name]();
    var get = uppercase(shortForm ? ('SHORT' + name) : name);

    return formats[get][value];
  };
}

function timeZoneGetter(date) {
  var zone = -1 * date.getTimezoneOffset();
  var paddedZone = (zone >= 0) ? "+" : "";

  paddedZone += padNumber(Math[zone > 0 ? 'floor' : 'ceil'](zone / 60), 2) +
                padNumber(Math.abs(zone % 60), 2);

  return paddedZone;
}

function getFirstThursdayOfYear(year) {
    // 0 = index of January
    var dayOfWeekOnFirst = (new Date(year, 0, 1)).getDay();
    // 4 = index of Thursday (+1 to account for 1st = 5)
    // 11 = index of *next* Thursday (+1 account for 1st = 12)
    return new Date(year, 0, ((dayOfWeekOnFirst <= 4) ? 5 : 12) - dayOfWeekOnFirst);
}

function getThursdayThisWeek(datetime) {
    return new Date(datetime.getFullYear(), datetime.getMonth(),
      // 4 = index of Thursday
      datetime.getDate() + (4 - datetime.getDay()));
}

function weekGetter(size) {
   return function(date) {
      var firstThurs = getFirstThursdayOfYear(date.getFullYear()),
         thisThurs = getThursdayThisWeek(date);

      var diff = +thisThurs - +firstThurs,
         result = 1 + Math.round(diff / 6.048e8); // 6.048e8 ms per week

      return padNumber(result, size);
   };
}

function ampmGetter(date, formats) {
  return date.getHours() < 12 ? formats.AMPMS[0] : formats.AMPMS[1];
}

function eraGetter(date, formats) {
  return date.getFullYear() <= 0 ? formats.ERAS[0] : formats.ERAS[1];
}

function longEraGetter(date, formats) {
  return date.getFullYear() <= 0 ? formats.ERANAMES[0] : formats.ERANAMES[1];
}

var DATE_FORMATS = {
  yyyy: dateGetter('FullYear', 4),
    yy: dateGetter('FullYear', 2, 0, true),
     y: dateGetter('FullYear', 1),
  MMMM: dateStrGetter('Month'),
   MMM: dateStrGetter('Month', true),
    MM: dateGetter('Month', 2, 1),
     M: dateGetter('Month', 1, 1),
    dd: dateGetter('Date', 2),
     d: dateGetter('Date', 1),
    HH: dateGetter('Hours', 2),
     H: dateGetter('Hours', 1),
    hh: dateGetter('Hours', 2, -12),
     h: dateGetter('Hours', 1, -12),
    mm: dateGetter('Minutes', 2),
     m: dateGetter('Minutes', 1),
    ss: dateGetter('Seconds', 2),
     s: dateGetter('Seconds', 1),
     // while ISO 8601 requires fractions to be prefixed with `.` or `,`
     // we can be just safely rely on using `sss` since we currently don't support single or two digit fractions
   sss: dateGetter('Milliseconds', 3),
  EEEE: dateStrGetter('Day'),
   EEE: dateStrGetter('Day', true),
     a: ampmGetter,
     Z: timeZoneGetter,
    ww: weekGetter(2),
     w: weekGetter(1),
     G: eraGetter,
     GG: eraGetter,
     GGG: eraGetter,
     GGGG: longEraGetter
};

var DATE_FORMATS_SPLIT = /((?:[^yMdHhmsaZEwG']+)|(?:'(?:[^']|'')*')|(?:E+|y+|M+|d+|H+|h+|m+|s+|a|Z|G+|w+))(.*)/,
    NUMBER_STRING = /^\-?\d+$/;

/**
 * @ngdoc filter
 * @name date
 * @kind function
 *
 * @description
 *   Formats `date` to a string based on the requested `format`.
 *
 *   `format` string can be composed of the following elements:
 *
 *   * `'yyyy'`: 4 digit representation of year (e.g. AD 1 => 0001, AD 2010 => 2010)
 *   * `'yy'`: 2 digit representation of year, padded (00-99). (e.g. AD 2001 => 01, AD 2010 => 10)
 *   * `'y'`: 1 digit representation of year, e.g. (AD 1 => 1, AD 199 => 199)
 *   * `'MMMM'`: Month in year (January-December)
 *   * `'MMM'`: Month in year (Jan-Dec)
 *   * `'MM'`: Month in year, padded (01-12)
 *   * `'M'`: Month in year (1-12)
 *   * `'dd'`: Day in month, padded (01-31)
 *   * `'d'`: Day in month (1-31)
 *   * `'EEEE'`: Day in Week,(Sunday-Saturday)
 *   * `'EEE'`: Day in Week, (Sun-Sat)
 *   * `'HH'`: Hour in day, padded (00-23)
 *   * `'H'`: Hour in day (0-23)
 *   * `'hh'`: Hour in AM/PM, padded (01-12)
 *   * `'h'`: Hour in AM/PM, (1-12)
 *   * `'mm'`: Minute in hour, padded (00-59)
 *   * `'m'`: Minute in hour (0-59)
 *   * `'ss'`: Second in minute, padded (00-59)
 *   * `'s'`: Second in minute (0-59)
 *   * `'sss'`: Millisecond in second, padded (000-999)
 *   * `'a'`: AM/PM marker
 *   * `'Z'`: 4 digit (+sign) representation of the timezone offset (-1200-+1200)
 *   * `'ww'`: Week of year, padded (00-53). Week 01 is the week with the first Thursday of the year
 *   * `'w'`: Week of year (0-53). Week 1 is the week with the first Thursday of the year
 *   * `'G'`, `'GG'`, `'GGG'`: The abbreviated form of the era string (e.g. 'AD')
 *   * `'GGGG'`: The long form of the era string (e.g. 'Anno Domini')
 *
 *   `format` string can also be one of the following predefined
 *   {@link guide/i18n localizable formats}:
 *
 *   * `'medium'`: equivalent to `'MMM d, y h:mm:ss a'` for en_US locale
 *     (e.g. Sep 3, 2010 12:05:08 PM)
 *   * `'short'`: equivalent to `'M/d/yy h:mm a'` for en_US  locale (e.g. 9/3/10 12:05 PM)
 *   * `'fullDate'`: equivalent to `'EEEE, MMMM d, y'` for en_US  locale
 *     (e.g. Friday, September 3, 2010)
 *   * `'longDate'`: equivalent to `'MMMM d, y'` for en_US  locale (e.g. September 3, 2010)
 *   * `'mediumDate'`: equivalent to `'MMM d, y'` for en_US  locale (e.g. Sep 3, 2010)
 *   * `'shortDate'`: equivalent to `'M/d/yy'` for en_US locale (e.g. 9/3/10)
 *   * `'mediumTime'`: equivalent to `'h:mm:ss a'` for en_US locale (e.g. 12:05:08 PM)
 *   * `'shortTime'`: equivalent to `'h:mm a'` for en_US locale (e.g. 12:05 PM)
 *
 *   `format` string can contain literal values. These need to be escaped by surrounding with single quotes (e.g.
 *   `"h 'in the morning'"`). In order to output a single quote, escape it - i.e., two single quotes in a sequence
 *   (e.g. `"h 'o''clock'"`).
 *
 * @param {(Date|number|string)} date Date to format either as Date object, milliseconds (string or
 *    number) or various ISO 8601 datetime string formats (e.g. yyyy-MM-ddTHH:mm:ss.sssZ and its
 *    shorter versions like yyyy-MM-ddTHH:mmZ, yyyy-MM-dd or yyyyMMddTHHmmssZ). If no timezone is
 *    specified in the string input, the time is considered to be in the local timezone.
 * @param {string=} format Formatting rules (see Description). If not specified,
 *    `mediumDate` is used.
 * @param {string=} timezone Timezone to be used for formatting. Right now, only `'UTC'` is supported.
 *    If not specified, the timezone of the browser will be used.
 * @returns {string} Formatted string or the input if input is not recognized as date/millis.
 *
 * @example
   <example>
     <file name="index.html">
       <span ng-non-bindable>{{1288323623006 | date:'medium'}}</span>:
           <span>{{1288323623006 | date:'medium'}}</span><br>
       <span ng-non-bindable>{{1288323623006 | date:'yyyy-MM-dd HH:mm:ss Z'}}</span>:
          <span>{{1288323623006 | date:'yyyy-MM-dd HH:mm:ss Z'}}</span><br>
       <span ng-non-bindable>{{1288323623006 | date:'MM/dd/yyyy @ h:mma'}}</span>:
          <span>{{'1288323623006' | date:'MM/dd/yyyy @ h:mma'}}</span><br>
       <span ng-non-bindable>{{1288323623006 | date:"MM/dd/yyyy 'at' h:mma"}}</span>:
          <span>{{'1288323623006' | date:"MM/dd/yyyy 'at' h:mma"}}</span><br>
     </file>
     <file name="protractor.js" type="protractor">
       it('should format date', function() {
         expect(element(by.binding("1288323623006 | date:'medium'")).getText()).
            toMatch(/Oct 2\d, 2010 \d{1,2}:\d{2}:\d{2} (AM|PM)/);
         expect(element(by.binding("1288323623006 | date:'yyyy-MM-dd HH:mm:ss Z'")).getText()).
            toMatch(/2010\-10\-2\d \d{2}:\d{2}:\d{2} (\-|\+)?\d{4}/);
         expect(element(by.binding("'1288323623006' | date:'MM/dd/yyyy @ h:mma'")).getText()).
            toMatch(/10\/2\d\/2010 @ \d{1,2}:\d{2}(AM|PM)/);
         expect(element(by.binding("'1288323623006' | date:\"MM/dd/yyyy 'at' h:mma\"")).getText()).
            toMatch(/10\/2\d\/2010 at \d{1,2}:\d{2}(AM|PM)/);
       });
     </file>
   </example>
 */
dateFilter.$inject = ['$locale'];
function dateFilter($locale) {


  var R_ISO8601_STR = /^(\d{4})-?(\d\d)-?(\d\d)(?:T(\d\d)(?::?(\d\d)(?::?(\d\d)(?:\.(\d+))?)?)?(Z|([+-])(\d\d):?(\d\d))?)?$/;
                     // 1        2       3         4          5          6          7          8  9     10      11
  function jsonStringToDate(string) {
    var match;
    if (match = string.match(R_ISO8601_STR)) {
      var date = new Date(0),
          tzHour = 0,
          tzMin  = 0,
          dateSetter = match[8] ? date.setUTCFullYear : date.setFullYear,
          timeSetter = match[8] ? date.setUTCHours : date.setHours;

      if (match[9]) {
        tzHour = int(match[9] + match[10]);
        tzMin = int(match[9] + match[11]);
      }
      dateSetter.call(date, int(match[1]), int(match[2]) - 1, int(match[3]));
      var h = int(match[4] || 0) - tzHour;
      var m = int(match[5] || 0) - tzMin;
      var s = int(match[6] || 0);
      var ms = Math.round(parseFloat('0.' + (match[7] || 0)) * 1000);
      timeSetter.call(date, h, m, s, ms);
      return date;
    }
    return string;
  }


  return function(date, format, timezone) {
    var text = '',
        parts = [],
        fn, match;

    format = format || 'mediumDate';
    format = $locale.DATETIME_FORMATS[format] || format;
    if (isString(date)) {
      date = NUMBER_STRING.test(date) ? int(date) : jsonStringToDate(date);
    }

    if (isNumber(date)) {
      date = new Date(date);
    }

    if (!isDate(date)) {
      return date;
    }

    while (format) {
      match = DATE_FORMATS_SPLIT.exec(format);
      if (match) {
        parts = concat(parts, match, 1);
        format = parts.pop();
      } else {
        parts.push(format);
        format = null;
      }
    }

    if (timezone && timezone === 'UTC') {
      date = new Date(date.getTime());
      date.setMinutes(date.getMinutes() + date.getTimezoneOffset());
    }
    forEach(parts, function(value) {
      fn = DATE_FORMATS[value];
      text += fn ? fn(date, $locale.DATETIME_FORMATS)
                 : value.replace(/(^'|'$)/g, '').replace(/''/g, "'");
    });

    return text;
  };
}


/**
 * @ngdoc filter
 * @name json
 * @kind function
 *
 * @description
 *   Allows you to convert a JavaScript object into JSON string.
 *
 *   This filter is mostly useful for debugging. When using the double curly {{value}} notation
 *   the binding is automatically converted to JSON.
 *
 * @param {*} object Any JavaScript object (including arrays and primitive types) to filter.
 * @param {number=} spacing The number of spaces to use per indentation, defaults to 2.
 * @returns {string} JSON string.
 *
 *
 * @example
   <example>
     <file name="index.html">
       <pre id="default-spacing">{{ {'name':'value'} | json }}</pre>
       <pre id="custom-spacing">{{ {'name':'value'} | json:4 }}</pre>
     </file>
     <file name="protractor.js" type="protractor">
       it('should jsonify filtered objects', function() {
         expect(element(by.id('default-spacing')).getText()).toMatch(/\{\n  "name": ?"value"\n}/);
         expect(element(by.id('custom-spacing')).getText()).toMatch(/\{\n    "name": ?"value"\n}/);
       });
     </file>
   </example>
 *
 */
function jsonFilter() {
  return function(object, spacing) {
    if (isUndefined(spacing)) {
        spacing = 2;
    }
    return toJson(object, spacing);
  };
}


/**
 * @ngdoc filter
 * @name lowercase
 * @kind function
 * @description
 * Converts string to lowercase.
 * @see angular.lowercase
 */
var lowercaseFilter = valueFn(lowercase);


/**
 * @ngdoc filter
 * @name uppercase
 * @kind function
 * @description
 * Converts string to uppercase.
 * @see angular.uppercase
 */
var uppercaseFilter = valueFn(uppercase);

/**
 * @ngdoc filter
 * @name limitTo
 * @kind function
 *
 * @description
 * Creates a new array or string containing only a specified number of elements. The elements
 * are taken from either the beginning or the end of the source array, string or number, as specified by
 * the value and sign (positive or negative) of `limit`. If a number is used as input, it is
 * converted to a string.
 *
 * @param {Array|string|number} input Source array, string or number to be limited.
 * @param {string|number} limit The length of the returned array or string. If the `limit` number
 *     is positive, `limit` number of items from the beginning of the source array/string are copied.
 *     If the number is negative, `limit` number  of items from the end of the source array/string
 *     are copied. The `limit` will be trimmed if it exceeds `array.length`
 * @returns {Array|string} A new sub-array or substring of length `limit` or less if input array
 *     had less than `limit` elements.
 *
 * @example
   <example module="limitToExample">
     <file name="index.html">
       <script>
         angular.module('limitToExample', [])
           .controller('ExampleController', ['$scope', function($scope) {
             $scope.numbers = [1,2,3,4,5,6,7,8,9];
             $scope.letters = "abcdefghi";
             $scope.longNumber = 2345432342;
             $scope.numLimit = 3;
             $scope.letterLimit = 3;
             $scope.longNumberLimit = 3;
           }]);
       </script>
       <div ng-controller="ExampleController">
         Limit {{numbers}} to: <input type="number" step="1" ng-model="numLimit">
         <p>Output numbers: {{ numbers | limitTo:numLimit }}</p>
         Limit {{letters}} to: <input type="number" step="1" ng-model="letterLimit">
         <p>Output letters: {{ letters | limitTo:letterLimit }}</p>
         Limit {{longNumber}} to: <input type="number" step="1" ng-model="longNumberLimit">
         <p>Output long number: {{ longNumber | limitTo:longNumberLimit }}</p>
       </div>
     </file>
     <file name="protractor.js" type="protractor">
       var numLimitInput = element(by.model('numLimit'));
       var letterLimitInput = element(by.model('letterLimit'));
       var longNumberLimitInput = element(by.model('longNumberLimit'));
       var limitedNumbers = element(by.binding('numbers | limitTo:numLimit'));
       var limitedLetters = element(by.binding('letters | limitTo:letterLimit'));
       var limitedLongNumber = element(by.binding('longNumber | limitTo:longNumberLimit'));

       it('should limit the number array to first three items', function() {
         expect(numLimitInput.getAttribute('value')).toBe('3');
         expect(letterLimitInput.getAttribute('value')).toBe('3');
         expect(longNumberLimitInput.getAttribute('value')).toBe('3');
         expect(limitedNumbers.getText()).toEqual('Output numbers: [1,2,3]');
         expect(limitedLetters.getText()).toEqual('Output letters: abc');
         expect(limitedLongNumber.getText()).toEqual('Output long number: 234');
       });

       // There is a bug in safari and protractor that doesn't like the minus key
       // it('should update the output when -3 is entered', function() {
       //   numLimitInput.clear();
       //   numLimitInput.sendKeys('-3');
       //   letterLimitInput.clear();
       //   letterLimitInput.sendKeys('-3');
       //   longNumberLimitInput.clear();
       //   longNumberLimitInput.sendKeys('-3');
       //   expect(limitedNumbers.getText()).toEqual('Output numbers: [7,8,9]');
       //   expect(limitedLetters.getText()).toEqual('Output letters: ghi');
       //   expect(limitedLongNumber.getText()).toEqual('Output long number: 342');
       // });

       it('should not exceed the maximum size of input array', function() {
         numLimitInput.clear();
         numLimitInput.sendKeys('100');
         letterLimitInput.clear();
         letterLimitInput.sendKeys('100');
         longNumberLimitInput.clear();
         longNumberLimitInput.sendKeys('100');
         expect(limitedNumbers.getText()).toEqual('Output numbers: [1,2,3,4,5,6,7,8,9]');
         expect(limitedLetters.getText()).toEqual('Output letters: abcdefghi');
         expect(limitedLongNumber.getText()).toEqual('Output long number: 2345432342');
       });
     </file>
   </example>
*/
function limitToFilter() {
  return function(input, limit) {
    if (isNumber(input)) input = input.toString();
    if (!isArray(input) && !isString(input)) return input;

    if (Math.abs(Number(limit)) === Infinity) {
      limit = Number(limit);
    } else {
      limit = int(limit);
    }

    //NaN check on limit
    if (limit) {
      return limit > 0 ? input.slice(0, limit) : input.slice(limit);
    } else {
      return isString(input) ? "" : [];
    }
  };
}

/**
 * @ngdoc filter
 * @name orderBy
 * @kind function
 *
 * @description
 * Orders a specified `array` by the `expression` predicate. It is ordered alphabetically
 * for strings and numerically for numbers. Note: if you notice numbers are not being sorted
 * correctly, make sure they are actually being saved as numbers and not strings.
 *
 * @param {Array} array The array to sort.
 * @param {function(*)|string|Array.<(function(*)|string)>=} expression A predicate to be
 *    used by the comparator to determine the order of elements.
 *
 *    Can be one of:
 *
 *    - `function`: Getter function. The result of this function will be sorted using the
 *      `<`, `===`, `>` operator.
 *    - `string`: An Angular expression. The result of this expression is used to compare elements
 *      (for example `name` to sort by a property called `name` or `name.substr(0, 3)` to sort by
 *      3 first characters of a property called `name`). The result of a constant expression
 *      is interpreted as a property name to be used in comparisons (for example `"special name"`
 *      to sort object by the value of their `special name` property). An expression can be
 *      optionally prefixed with `+` or `-` to control ascending or descending sort order
 *      (for example, `+name` or `-name`). If no property is provided, (e.g. `'+'`) then the array
 *      element itself is used to compare where sorting.
 *    - `Array`: An array of function or string predicates. The first predicate in the array
 *      is used for sorting, but when two items are equivalent, the next predicate is used.
 *
 *    If the predicate is missing or empty then it defaults to `'+'`.
 *
 * @param {boolean=} reverse Reverse the order of the array.
 * @returns {Array} Sorted copy of the source array.
 *
 *
 * @example
 * The example below demonstrates a simple ngRepeat, where the data is sorted
 * by age in descending order (predicate is set to `'-age'`).
 * `reverse` is not set, which means it defaults to `false`.
   <example module="orderByExample">
     <file name="index.html">
       <script>
         angular.module('orderByExample', [])
           .controller('ExampleController', ['$scope', function($scope) {
             $scope.friends =
                 [{name:'John', phone:'555-1212', age:10},
                  {name:'Mary', phone:'555-9876', age:19},
                  {name:'Mike', phone:'555-4321', age:21},
                  {name:'Adam', phone:'555-5678', age:35},
                  {name:'Julie', phone:'555-8765', age:29}];
           }]);
       </script>
       <div ng-controller="ExampleController">
         <table class="friend">
           <tr>
             <th>Name</th>
             <th>Phone Number</th>
             <th>Age</th>
           </tr>
           <tr ng-repeat="friend in friends | orderBy:'-age'">
             <td>{{friend.name}}</td>
             <td>{{friend.phone}}</td>
             <td>{{friend.age}}</td>
           </tr>
         </table>
       </div>
     </file>
   </example>
 *
 * The predicate and reverse parameters can be controlled dynamically through scope properties,
 * as shown in the next example.
 * @example
   <example module="orderByExample">
     <file name="index.html">
       <script>
         angular.module('orderByExample', [])
           .controller('ExampleController', ['$scope', function($scope) {
             $scope.friends =
                 [{name:'John', phone:'555-1212', age:10},
                  {name:'Mary', phone:'555-9876', age:19},
                  {name:'Mike', phone:'555-4321', age:21},
                  {name:'Adam', phone:'555-5678', age:35},
                  {name:'Julie', phone:'555-8765', age:29}];
             $scope.predicate = '-age';
           }]);
       </script>
       <div ng-controller="ExampleController">
         <pre>Sorting predicate = {{predicate}}; reverse = {{reverse}}</pre>
         <hr/>
         [ <a href="" ng-click="predicate=''">unsorted</a> ]
         <table class="friend">
           <tr>
             <th><a href="" ng-click="predicate = 'name'; reverse=false">Name</a>
                 (<a href="" ng-click="predicate = '-name'; reverse=false">^</a>)</th>
             <th><a href="" ng-click="predicate = 'phone'; reverse=!reverse">Phone Number</a></th>
             <th><a href="" ng-click="predicate = 'age'; reverse=!reverse">Age</a></th>
           </tr>
           <tr ng-repeat="friend in friends | orderBy:predicate:reverse">
             <td>{{friend.name}}</td>
             <td>{{friend.phone}}</td>
             <td>{{friend.age}}</td>
           </tr>
         </table>
       </div>
     </file>
   </example>
 *
 * It's also possible to call the orderBy filter manually, by injecting `$filter`, retrieving the
 * filter routine with `$filter('orderBy')`, and calling the returned filter routine with the
 * desired parameters.
 *
 * Example:
 *
 * @example
  <example module="orderByExample">
    <file name="index.html">
      <div ng-controller="ExampleController">
        <table class="friend">
          <tr>
            <th><a href="" ng-click="reverse=false;order('name', false)">Name</a>
              (<a href="" ng-click="order('-name',false)">^</a>)</th>
            <th><a href="" ng-click="reverse=!reverse;order('phone', reverse)">Phone Number</a></th>
            <th><a href="" ng-click="reverse=!reverse;order('age',reverse)">Age</a></th>
          </tr>
          <tr ng-repeat="friend in friends">
            <td>{{friend.name}}</td>
            <td>{{friend.phone}}</td>
            <td>{{friend.age}}</td>
          </tr>
        </table>
      </div>
    </file>

    <file name="script.js">
      angular.module('orderByExample', [])
        .controller('ExampleController', ['$scope', '$filter', function($scope, $filter) {
          var orderBy = $filter('orderBy');
          $scope.friends = [
            { name: 'John',    phone: '555-1212',    age: 10 },
            { name: 'Mary',    phone: '555-9876',    age: 19 },
            { name: 'Mike',    phone: '555-4321',    age: 21 },
            { name: 'Adam',    phone: '555-5678',    age: 35 },
            { name: 'Julie',   phone: '555-8765',    age: 29 }
          ];
          $scope.order = function(predicate, reverse) {
            $scope.friends = orderBy($scope.friends, predicate, reverse);
          };
          $scope.order('-age',false);
        }]);
    </file>
</example>
 */
orderByFilter.$inject = ['$parse'];
function orderByFilter($parse) {
  return function(array, sortPredicate, reverseOrder) {
    if (!(isArrayLike(array))) return array;
    sortPredicate = isArray(sortPredicate) ? sortPredicate : [sortPredicate];
    if (sortPredicate.length === 0) { sortPredicate = ['+']; }
    sortPredicate = sortPredicate.map(function(predicate) {
      var descending = false, get = predicate || identity;
      if (isString(predicate)) {
        if ((predicate.charAt(0) == '+' || predicate.charAt(0) == '-')) {
          descending = predicate.charAt(0) == '-';
          predicate = predicate.substring(1);
        }
        if (predicate === '') {
          // Effectively no predicate was passed so we compare identity
          return reverseComparator(compare, descending);
        }
        get = $parse(predicate);
        if (get.constant) {
          var key = get();
          return reverseComparator(function(a, b) {
            return compare(a[key], b[key]);
          }, descending);
        }
      }
      return reverseComparator(function(a, b) {
        return compare(get(a),get(b));
      }, descending);
    });
    return slice.call(array).sort(reverseComparator(comparator, reverseOrder));

    function comparator(o1, o2) {
      for (var i = 0; i < sortPredicate.length; i++) {
        var comp = sortPredicate[i](o1, o2);
        if (comp !== 0) return comp;
      }
      return 0;
    }
    function reverseComparator(comp, descending) {
      return descending
          ? function(a, b) {return comp(b,a);}
          : comp;
    }

    function isPrimitive(value) {
      switch (typeof value) {
        case 'number': /* falls through */
        case 'boolean': /* falls through */
        case 'string':
          return true;
        default:
          return false;
      }
    }

    function objectToString(value) {
      if (value === null) return 'null';
      if (typeof value.valueOf === 'function') {
        value = value.valueOf();
        if (isPrimitive(value)) return value;
      }
      if (typeof value.toString === 'function') {
        value = value.toString();
        if (isPrimitive(value)) return value;
      }
      return '';
    }

    function compare(v1, v2) {
      var t1 = typeof v1;
      var t2 = typeof v2;
      if (t1 === t2 && t1 === "object") {
        v1 = objectToString(v1);
        v2 = objectToString(v2);
      }
      if (t1 === t2) {
        if (t1 === "string") {
           v1 = v1.toLowerCase();
           v2 = v2.toLowerCase();
        }
        if (v1 === v2) return 0;
        return v1 < v2 ? -1 : 1;
      } else {
        return t1 < t2 ? -1 : 1;
      }
    }
  };
}

function ngDirective(directive) {
  if (isFunction(directive)) {
    directive = {
      link: directive
    };
  }
  directive.restrict = directive.restrict || 'AC';
  return valueFn(directive);
}

/**
 * @ngdoc directive
 * @name a
 * @restrict E
 *
 * @description
 * Modifies the default behavior of the html A tag so that the default action is prevented when
 * the href attribute is empty.
 *
 * This change permits the easy creation of action links with the `ngClick` directive
 * without changing the location or causing page reloads, e.g.:
 * `<a href="" ng-click="list.addItem()">Add Item</a>`
 */
var htmlAnchorDirective = valueFn({
  restrict: 'E',
  compile: function(element, attr) {
    if (!attr.href && !attr.xlinkHref && !attr.name) {
      return function(scope, element) {
        // If the linked element is not an anchor tag anymore, do nothing
        if (element[0].nodeName.toLowerCase() !== 'a') return;

        // SVGAElement does not use the href attribute, but rather the 'xlinkHref' attribute.
        var href = toString.call(element.prop('href')) === '[object SVGAnimatedString]' ?
                   'xlink:href' : 'href';
        element.on('click', function(event) {
          // if we have no href url, then don't navigate anywhere.
          if (!element.attr(href)) {
            event.preventDefault();
          }
        });
      };
    }
  }
});

/**
 * @ngdoc directive
 * @name ngHref
 * @restrict A
 * @priority 99
 *
 * @description
 * Using Angular markup like `{{hash}}` in an href attribute will
 * make the link go to the wrong URL if the user clicks it before
 * Angular has a chance to replace the `{{hash}}` markup with its
 * value. Until Angular replaces the markup the link will be broken
 * and will most likely return a 404 error. The `ngHref` directive
 * solves this problem.
 *
 * The wrong way to write it:
 * ```html
 * <a href="http://www.gravatar.com/avatar/{{hash}}">link1</a>
 * ```
 *
 * The correct way to write it:
 * ```html
 * <a ng-href="http://www.gravatar.com/avatar/{{hash}}">link1</a>
 * ```
 *
 * @element A
 * @param {template} ngHref any string which can contain `{{}}` markup.
 *
 * @example
 * This example shows various combinations of `href`, `ng-href` and `ng-click` attributes
 * in links and their different behaviors:
    <example>
      <file name="index.html">
        <input ng-model="value" /><br />
        <a id="link-1" href ng-click="value = 1">link 1</a> (link, don't reload)<br />
        <a id="link-2" href="" ng-click="value = 2">link 2</a> (link, don't reload)<br />
        <a id="link-3" ng-href="/{{'123'}}">link 3</a> (link, reload!)<br />
        <a id="link-4" href="" name="xx" ng-click="value = 4">anchor</a> (link, don't reload)<br />
        <a id="link-5" name="xxx" ng-click="value = 5">anchor</a> (no link)<br />
        <a id="link-6" ng-href="{{value}}">link</a> (link, change location)
      </file>
      <file name="protractor.js" type="protractor">
        it('should execute ng-click but not reload when href without value', function() {
          element(by.id('link-1')).click();
          expect(element(by.model('value')).getAttribute('value')).toEqual('1');
          expect(element(by.id('link-1')).getAttribute('href')).toBe('');
        });

        it('should execute ng-click but not reload when href empty string', function() {
          element(by.id('link-2')).click();
          expect(element(by.model('value')).getAttribute('value')).toEqual('2');
          expect(element(by.id('link-2')).getAttribute('href')).toBe('');
        });

        it('should execute ng-click and change url when ng-href specified', function() {
          expect(element(by.id('link-3')).getAttribute('href')).toMatch(/\/123$/);

          element(by.id('link-3')).click();

          // At this point, we navigate away from an Angular page, so we need
          // to use browser.driver to get the base webdriver.

          browser.wait(function() {
            return browser.driver.getCurrentUrl().then(function(url) {
              return url.match(/\/123$/);
            });
          }, 5000, 'page should navigate to /123');
        });

        xit('should execute ng-click but not reload when href empty string and name specified', function() {
          element(by.id('link-4')).click();
          expect(element(by.model('value')).getAttribute('value')).toEqual('4');
          expect(element(by.id('link-4')).getAttribute('href')).toBe('');
        });

        it('should execute ng-click but not reload when no href but name specified', function() {
          element(by.id('link-5')).click();
          expect(element(by.model('value')).getAttribute('value')).toEqual('5');
          expect(element(by.id('link-5')).getAttribute('href')).toBe(null);
        });

        it('should only change url when only ng-href', function() {
          element(by.model('value')).clear();
          element(by.model('value')).sendKeys('6');
          expect(element(by.id('link-6')).getAttribute('href')).toMatch(/\/6$/);

          element(by.id('link-6')).click();

          // At this point, we navigate away from an Angular page, so we need
          // to use browser.driver to get the base webdriver.
          browser.wait(function() {
            return browser.driver.getCurrentUrl().then(function(url) {
              return url.match(/\/6$/);
            });
          }, 5000, 'page should navigate to /6');
        });
      </file>
    </example>
 */

/**
 * @ngdoc directive
 * @name ngSrc
 * @restrict A
 * @priority 99
 *
 * @description
 * Using Angular markup like `{{hash}}` in a `src` attribute doesn't
 * work right: The browser will fetch from the URL with the literal
 * text `{{hash}}` until Angular replaces the expression inside
 * `{{hash}}`. The `ngSrc` directive solves this problem.
 *
 * The buggy way to write it:
 * ```html
 * <img src="http://www.gravatar.com/avatar/{{hash}}"/>
 * ```
 *
 * The correct way to write it:
 * ```html
 * <img ng-src="http://www.gravatar.com/avatar/{{hash}}"/>
 * ```
 *
 * @element IMG
 * @param {template} ngSrc any string which can contain `{{}}` markup.
 */

/**
 * @ngdoc directive
 * @name ngSrcset
 * @restrict A
 * @priority 99
 *
 * @description
 * Using Angular markup like `{{hash}}` in a `srcset` attribute doesn't
 * work right: The browser will fetch from the URL with the literal
 * text `{{hash}}` until Angular replaces the expression inside
 * `{{hash}}`. The `ngSrcset` directive solves this problem.
 *
 * The buggy way to write it:
 * ```html
 * <img srcset="http://www.gravatar.com/avatar/{{hash}} 2x"/>
 * ```
 *
 * The correct way to write it:
 * ```html
 * <img ng-srcset="http://www.gravatar.com/avatar/{{hash}} 2x"/>
 * ```
 *
 * @element IMG
 * @param {template} ngSrcset any string which can contain `{{}}` markup.
 */

/**
 * @ngdoc directive
 * @name ngDisabled
 * @restrict A
 * @priority 100
 *
 * @description
 *
 * This directive sets the `disabled` attribute on the element if the
 * {@link guide/expression expression} inside `ngDisabled` evaluates to truthy.
 *
 * A special directive is necessary because we cannot use interpolation inside the `disabled`
 * attribute.  The following example would make the button enabled on Chrome/Firefox
 * but not on older IEs:
 *
 * ```html
 * <!-- See below for an example of ng-disabled being used correctly -->
 * <div ng-init="isDisabled = false">
 *  <button disabled="{{isDisabled}}">Disabled</button>
 * </div>
 * ```
 *
 * This is because the HTML specification does not require browsers to preserve the values of
 * boolean attributes such as `disabled` (Their presence means true and their absence means false.)
 * If we put an Angular interpolation expression into such an attribute then the
 * binding information would be lost when the browser removes the attribute.
 *
 * @example
    <example>
      <file name="index.html">
        Click me to toggle: <input type="checkbox" ng-model="checked"><br/>
        <button ng-model="button" ng-disabled="checked">Button</button>
      </file>
      <file name="protractor.js" type="protractor">
        it('should toggle button', function() {
          expect(element(by.css('button')).getAttribute('disabled')).toBeFalsy();
          element(by.model('checked')).click();
          expect(element(by.css('button')).getAttribute('disabled')).toBeTruthy();
        });
      </file>
    </example>
 *
 * @element INPUT
 * @param {expression} ngDisabled If the {@link guide/expression expression} is truthy,
 *     then the `disabled` attribute will be set on the element
 */


/**
 * @ngdoc directive
 * @name ngChecked
 * @restrict A
 * @priority 100
 *
 * @description
 * The HTML specification does not require browsers to preserve the values of boolean attributes
 * such as checked. (Their presence means true and their absence means false.)
 * If we put an Angular interpolation expression into such an attribute then the
 * binding information would be lost when the browser removes the attribute.
 * The `ngChecked` directive solves this problem for the `checked` attribute.
 * This complementary directive is not removed by the browser and so provides
 * a permanent reliable place to store the binding information.
 * @example
    <example>
      <file name="index.html">
        Check me to check both: <input type="checkbox" ng-model="master"><br/>
        <input id="checkSlave" type="checkbox" ng-checked="master">
      </file>
      <file name="protractor.js" type="protractor">
        it('should check both checkBoxes', function() {
          expect(element(by.id('checkSlave')).getAttribute('checked')).toBeFalsy();
          element(by.model('master')).click();
          expect(element(by.id('checkSlave')).getAttribute('checked')).toBeTruthy();
        });
      </file>
    </example>
 *
 * @element INPUT
 * @param {expression} ngChecked If the {@link guide/expression expression} is truthy,
 *     then special attribute "checked" will be set on the element
 */


/**
 * @ngdoc directive
 * @name ngReadonly
 * @restrict A
 * @priority 100
 *
 * @description
 * The HTML specification does not require browsers to preserve the values of boolean attributes
 * such as readonly. (Their presence means true and their absence means false.)
 * If we put an Angular interpolation expression into such an attribute then the
 * binding information would be lost when the browser removes the attribute.
 * The `ngReadonly` directive solves this problem for the `readonly` attribute.
 * This complementary directive is not removed by the browser and so provides
 * a permanent reliable place to store the binding information.
 * @example
    <example>
      <file name="index.html">
        Check me to make text readonly: <input type="checkbox" ng-model="checked"><br/>
        <input type="text" ng-readonly="checked" value="I'm Angular"/>
      </file>
      <file name="protractor.js" type="protractor">
        it('should toggle readonly attr', function() {
          expect(element(by.css('[type="text"]')).getAttribute('readonly')).toBeFalsy();
          element(by.model('checked')).click();
          expect(element(by.css('[type="text"]')).getAttribute('readonly')).toBeTruthy();
        });
      </file>
    </example>
 *
 * @element INPUT
 * @param {expression} ngReadonly If the {@link guide/expression expression} is truthy,
 *     then special attribute "readonly" will be set on the element
 */


/**
 * @ngdoc directive
 * @name ngSelected
 * @restrict A
 * @priority 100
 *
 * @description
 * The HTML specification does not require browsers to preserve the values of boolean attributes
 * such as selected. (Their presence means true and their absence means false.)
 * If we put an Angular interpolation expression into such an attribute then the
 * binding information would be lost when the browser removes the attribute.
 * The `ngSelected` directive solves this problem for the `selected` attribute.
 * This complementary directive is not removed by the browser and so provides
 * a permanent reliable place to store the binding information.
 *
 * @example
    <example>
      <file name="index.html">
        Check me to select: <input type="checkbox" ng-model="selected"><br/>
        <select>
          <option>Hello!</option>
          <option id="greet" ng-selected="selected">Greetings!</option>
        </select>
      </file>
      <file name="protractor.js" type="protractor">
        it('should select Greetings!', function() {
          expect(element(by.id('greet')).getAttribute('selected')).toBeFalsy();
          element(by.model('selected')).click();
          expect(element(by.id('greet')).getAttribute('selected')).toBeTruthy();
        });
      </file>
    </example>
 *
 * @element OPTION
 * @param {expression} ngSelected If the {@link guide/expression expression} is truthy,
 *     then special attribute "selected" will be set on the element
 */

/**
 * @ngdoc directive
 * @name ngOpen
 * @restrict A
 * @priority 100
 *
 * @description
 * The HTML specification does not require browsers to preserve the values of boolean attributes
 * such as open. (Their presence means true and their absence means false.)
 * If we put an Angular interpolation expression into such an attribute then the
 * binding information would be lost when the browser removes the attribute.
 * The `ngOpen` directive solves this problem for the `open` attribute.
 * This complementary directive is not removed by the browser and so provides
 * a permanent reliable place to store the binding information.
 * @example
     <example>
       <file name="index.html">
         Check me check multiple: <input type="checkbox" ng-model="open"><br/>
         <details id="details" ng-open="open">
            <summary>Show/Hide me</summary>
         </details>
       </file>
       <file name="protractor.js" type="protractor">
         it('should toggle open', function() {
           expect(element(by.id('details')).getAttribute('open')).toBeFalsy();
           element(by.model('open')).click();
           expect(element(by.id('details')).getAttribute('open')).toBeTruthy();
         });
       </file>
     </example>
 *
 * @element DETAILS
 * @param {expression} ngOpen If the {@link guide/expression expression} is truthy,
 *     then special attribute "open" will be set on the element
 */

var ngAttributeAliasDirectives = {};


// boolean attrs are evaluated
forEach(BOOLEAN_ATTR, function(propName, attrName) {
  // binding to multiple is not supported
  if (propName == "multiple") return;

  var normalized = directiveNormalize('ng-' + attrName);
  ngAttributeAliasDirectives[normalized] = function() {
    return {
      restrict: 'A',
      priority: 100,
      link: function(scope, element, attr) {
        scope.$watch(attr[normalized], function ngBooleanAttrWatchAction(value) {
          attr.$set(attrName, !!value);
        });
      }
    };
  };
});

// aliased input attrs are evaluated
forEach(ALIASED_ATTR, function(htmlAttr, ngAttr) {
  ngAttributeAliasDirectives[ngAttr] = function() {
    return {
      priority: 100,
      link: function(scope, element, attr) {
        //special case ngPattern when a literal regular expression value
        //is used as the expression (this way we don't have to watch anything).
        if (ngAttr === "ngPattern" && attr.ngPattern.charAt(0) == "/") {
          var match = attr.ngPattern.match(REGEX_STRING_REGEXP);
          if (match) {
            attr.$set("ngPattern", new RegExp(match[1], match[2]));
            return;
          }
        }

        scope.$watch(attr[ngAttr], function ngAttrAliasWatchAction(value) {
          attr.$set(ngAttr, value);
        });
      }
    };
  };
});

// ng-src, ng-srcset, ng-href are interpolated
forEach(['src', 'srcset', 'href'], function(attrName) {
  var normalized = directiveNormalize('ng-' + attrName);
  ngAttributeAliasDirectives[normalized] = function() {
    return {
      priority: 99, // it needs to run after the attributes are interpolated
      link: function(scope, element, attr) {
        var propName = attrName,
            name = attrName;

        if (attrName === 'href' &&
            toString.call(element.prop('href')) === '[object SVGAnimatedString]') {
          name = 'xlinkHref';
          attr.$attr[name] = 'xlink:href';
          propName = null;
        }

        attr.$observe(normalized, function(value) {
          if (!value) {
            if (attrName === 'href') {
              attr.$set(name, null);
            }
            return;
          }

          attr.$set(name, value);

          // on IE, if "ng:src" directive declaration is used and "src" attribute doesn't exist
          // then calling element.setAttribute('src', 'foo') doesn't do anything, so we need
          // to set the property as well to achieve the desired effect.
          // we use attr[attrName] value since $set can sanitize the url.
          if (msie && propName) element.prop(propName, attr[name]);
        });
      }
    };
  };
});

/* global -nullFormCtrl, -SUBMITTED_CLASS, addSetValidityMethod: true
 */
var nullFormCtrl = {
  $addControl: noop,
  $$renameControl: nullFormRenameControl,
  $removeControl: noop,
  $setValidity: noop,
  $setDirty: noop,
  $setPristine: noop,
  $setSubmitted: noop
},
SUBMITTED_CLASS = 'ng-submitted';

function nullFormRenameControl(control, name) {
  control.$name = name;
}

/**
 * @ngdoc type
 * @name form.FormController
 *
 * @property {boolean} $pristine True if user has not interacted with the form yet.
 * @property {boolean} $dirty True if user has already interacted with the form.
 * @property {boolean} $valid True if all of the containing forms and controls are valid.
 * @property {boolean} $invalid True if at least one containing control or form is invalid.
 * @property {boolean} $submitted True if user has submitted the form even if its invalid.
 *
 * @property {Object} $error Is an object hash, containing references to controls or
 *  forms with failing validators, where:
 *
 *  - keys are validation tokens (error names),
 *  - values are arrays of controls or forms that have a failing validator for given error name.
 *
 *  Built-in validation tokens:
 *
 *  - `email`
 *  - `max`
 *  - `maxlength`
 *  - `min`
 *  - `minlength`
 *  - `number`
 *  - `pattern`
 *  - `required`
 *  - `url`
 *  - `date`
 *  - `datetimelocal`
 *  - `time`
 *  - `week`
 *  - `month`
 *
 * @description
 * `FormController` keeps track of all its controls and nested forms as well as the state of them,
 * such as being valid/invalid or dirty/pristine.
 *
 * Each {@link ng.directive:form form} directive creates an instance
 * of `FormController`.
 *
 */
//asks for $scope to fool the BC controller module
FormController.$inject = ['$element', '$attrs', '$scope', '$animate', '$interpolate'];
function FormController(element, attrs, $scope, $animate, $interpolate) {
  var form = this,
      controls = [];

  var parentForm = form.$$parentForm = element.parent().controller('form') || nullFormCtrl;

  // init state
  form.$error = {};
  form.$$success = {};
  form.$pending = undefined;
  form.$name = $interpolate(attrs.name || attrs.ngForm || '')($scope);
  form.$dirty = false;
  form.$pristine = true;
  form.$valid = true;
  form.$invalid = false;
  form.$submitted = false;

  parentForm.$addControl(form);

  /**
   * @ngdoc method
   * @name form.FormController#$rollbackViewValue
   *
   * @description
   * Rollback all form controls pending updates to the `$modelValue`.
   *
   * Updates may be pending by a debounced event or because the input is waiting for a some future
   * event defined in `ng-model-options`. This method is typically needed by the reset button of
   * a form that uses `ng-model-options` to pend updates.
   */
  form.$rollbackViewValue = function() {
    forEach(controls, function(control) {
      control.$rollbackViewValue();
    });
  };

  /**
   * @ngdoc method
   * @name form.FormController#$commitViewValue
   *
   * @description
   * Commit all form controls pending updates to the `$modelValue`.
   *
   * Updates may be pending by a debounced event or because the input is waiting for a some future
   * event defined in `ng-model-options`. This method is rarely needed as `NgModelController`
   * usually handles calling this in response to input events.
   */
  form.$commitViewValue = function() {
    forEach(controls, function(control) {
      control.$commitViewValue();
    });
  };

  /**
   * @ngdoc method
   * @name form.FormController#$addControl
   *
   * @description
   * Register a control with the form.
   *
   * Input elements using ngModelController do this automatically when they are linked.
   */
  form.$addControl = function(control) {
    // Breaking change - before, inputs whose name was "hasOwnProperty" were quietly ignored
    // and not added to the scope.  Now we throw an error.
    assertNotHasOwnProperty(control.$name, 'input');
    controls.push(control);

    if (control.$name) {
      form[control.$name] = control;
    }
  };

  // Private API: rename a form control
  form.$$renameControl = function(control, newName) {
    var oldName = control.$name;

    if (form[oldName] === control) {
      delete form[oldName];
    }
    form[newName] = control;
    control.$name = newName;
  };

  /**
   * @ngdoc method
   * @name form.FormController#$removeControl
   *
   * @description
   * Deregister a control from the form.
   *
   * Input elements using ngModelController do this automatically when they are destroyed.
   */
  form.$removeControl = function(control) {
    if (control.$name && form[control.$name] === control) {
      delete form[control.$name];
    }
    forEach(form.$pending, function(value, name) {
      form.$setValidity(name, null, control);
    });
    forEach(form.$error, function(value, name) {
      form.$setValidity(name, null, control);
    });
    forEach(form.$$success, function(value, name) {
      form.$setValidity(name, null, control);
    });

    arrayRemove(controls, control);
  };


  /**
   * @ngdoc method
   * @name form.FormController#$setValidity
   *
   * @description
   * Sets the validity of a form control.
   *
   * This method will also propagate to parent forms.
   */
  addSetValidityMethod({
    ctrl: this,
    $element: element,
    set: function(object, property, controller) {
      var list = object[property];
      if (!list) {
        object[property] = [controller];
      } else {
        var index = list.indexOf(controller);
        if (index === -1) {
          list.push(controller);
        }
      }
    },
    unset: function(object, property, controller) {
      var list = object[property];
      if (!list) {
        return;
      }
      arrayRemove(list, controller);
      if (list.length === 0) {
        delete object[property];
      }
    },
    parentForm: parentForm,
    $animate: $animate
  });

  /**
   * @ngdoc method
   * @name form.FormController#$setDirty
   *
   * @description
   * Sets the form to a dirty state.
   *
   * This method can be called to add the 'ng-dirty' class and set the form to a dirty
   * state (ng-dirty class). This method will also propagate to parent forms.
   */
  form.$setDirty = function() {
    $animate.removeClass(element, PRISTINE_CLASS);
    $animate.addClass(element, DIRTY_CLASS);
    form.$dirty = true;
    form.$pristine = false;
    parentForm.$setDirty();
  };

  /**
   * @ngdoc method
   * @name form.FormController#$setPristine
   *
   * @description
   * Sets the form to its pristine state.
   *
   * This method can be called to remove the 'ng-dirty' class and set the form to its pristine
   * state (ng-pristine class). This method will also propagate to all the controls contained
   * in this form.
   *
   * Setting a form back to a pristine state is often useful when we want to 'reuse' a form after
   * saving or resetting it.
   */
  form.$setPristine = function() {
    $animate.setClass(element, PRISTINE_CLASS, DIRTY_CLASS + ' ' + SUBMITTED_CLASS);
    form.$dirty = false;
    form.$pristine = true;
    form.$submitted = false;
    forEach(controls, function(control) {
      control.$setPristine();
    });
  };

  /**
   * @ngdoc method
   * @name form.FormController#$setUntouched
   *
   * @description
   * Sets the form to its untouched state.
   *
   * This method can be called to remove the 'ng-touched' class and set the form controls to their
   * untouched state (ng-untouched class).
   *
   * Setting a form controls back to their untouched state is often useful when setting the form
   * back to its pristine state.
   */
  form.$setUntouched = function() {
    forEach(controls, function(control) {
      control.$setUntouched();
    });
  };

  /**
   * @ngdoc method
   * @name form.FormController#$setSubmitted
   *
   * @description
   * Sets the form to its submitted state.
   */
  form.$setSubmitted = function() {
    $animate.addClass(element, SUBMITTED_CLASS);
    form.$submitted = true;
    parentForm.$setSubmitted();
  };
}

/**
 * @ngdoc directive
 * @name ngForm
 * @restrict EAC
 *
 * @description
 * Nestable alias of {@link ng.directive:form `form`} directive. HTML
 * does not allow nesting of form elements. It is useful to nest forms, for example if the validity of a
 * sub-group of controls needs to be determined.
 *
 * Note: the purpose of `ngForm` is to group controls,
 * but not to be a replacement for the `<form>` tag with all of its capabilities
 * (e.g. posting to the server, ...).
 *
 * @param {string=} ngForm|name Name of the form. If specified, the form controller will be published into
 *                       related scope, under this name.
 *
 */

 /**
 * @ngdoc directive
 * @name form
 * @restrict E
 *
 * @description
 * Directive that instantiates
 * {@link form.FormController FormController}.
 *
 * If the `name` attribute is specified, the form controller is published onto the current scope under
 * this name.
 *
 * # Alias: {@link ng.directive:ngForm `ngForm`}
 *
 * In Angular, forms can be nested. This means that the outer form is valid when all of the child
 * forms are valid as well. However, browsers do not allow nesting of `<form>` elements, so
 * Angular provides the {@link ng.directive:ngForm `ngForm`} directive which behaves identically to
 * `<form>` but can be nested.  This allows you to have nested forms, which is very useful when
 * using Angular validation directives in forms that are dynamically generated using the
 * {@link ng.directive:ngRepeat `ngRepeat`} directive. Since you cannot dynamically generate the `name`
 * attribute of input elements using interpolation, you have to wrap each set of repeated inputs in an
 * `ngForm` directive and nest these in an outer `form` element.
 *
 *
 * # CSS classes
 *  - `ng-valid` is set if the form is valid.
 *  - `ng-invalid` is set if the form is invalid.
 *  - `ng-pristine` is set if the form is pristine.
 *  - `ng-dirty` is set if the form is dirty.
 *  - `ng-submitted` is set if the form was submitted.
 *
 * Keep in mind that ngAnimate can detect each of these classes when added and removed.
 *
 *
 * # Submitting a form and preventing the default action
 *
 * Since the role of forms in client-side Angular applications is different than in classical
 * roundtrip apps, it is desirable for the browser not to translate the form submission into a full
 * page reload that sends the data to the server. Instead some javascript logic should be triggered
 * to handle the form submission in an application-specific way.
 *
 * For this reason, Angular prevents the default action (form submission to the server) unless the
 * `<form>` element has an `action` attribute specified.
 *
 * You can use one of the following two ways to specify what javascript method should be called when
 * a form is submitted:
 *
 * - {@link ng.directive:ngSubmit ngSubmit} directive on the form element
 * - {@link ng.directive:ngClick ngClick} directive on the first
  *  button or input field of type submit (input[type=submit])
 *
 * To prevent double execution of the handler, use only one of the {@link ng.directive:ngSubmit ngSubmit}
 * or {@link ng.directive:ngClick ngClick} directives.
 * This is because of the following form submission rules in the HTML specification:
 *
 * - If a form has only one input field then hitting enter in this field triggers form submit
 * (`ngSubmit`)
 * - if a form has 2+ input fields and no buttons or input[type=submit] then hitting enter
 * doesn't trigger submit
 * - if a form has one or more input fields and one or more buttons or input[type=submit] then
 * hitting enter in any of the input fields will trigger the click handler on the *first* button or
 * input[type=submit] (`ngClick`) *and* a submit handler on the enclosing form (`ngSubmit`)
 *
 * Any pending `ngModelOptions` changes will take place immediately when an enclosing form is
 * submitted. Note that `ngClick` events will occur before the model is updated. Use `ngSubmit`
 * to have access to the updated model.
 *
 * ## Animation Hooks
 *
 * Animations in ngForm are triggered when any of the associated CSS classes are added and removed.
 * These classes are: `.ng-pristine`, `.ng-dirty`, `.ng-invalid` and `.ng-valid` as well as any
 * other validations that are performed within the form. Animations in ngForm are similar to how
 * they work in ngClass and animations can be hooked into using CSS transitions, keyframes as well
 * as JS animations.
 *
 * The following example shows a simple way to utilize CSS transitions to style a form element
 * that has been rendered as invalid after it has been validated:
 *
 * <pre>
 * //be sure to include ngAnimate as a module to hook into more
 * //advanced animations
 * .my-form {
 *   transition:0.5s linear all;
 *   background: white;
 * }
 * .my-form.ng-invalid {
 *   background: red;
 *   color:white;
 * }
 * </pre>
 *
 * @example
    <example deps="angular-animate.js" animations="true" fixBase="true" module="formExample">
      <file name="index.html">
       <script>
         angular.module('formExample', [])
           .controller('FormController', ['$scope', function($scope) {
             $scope.userType = 'guest';
           }]);
       </script>
       <style>
        .my-form {
          -webkit-transition:all linear 0.5s;
          transition:all linear 0.5s;
          background: transparent;
        }
        .my-form.ng-invalid {
          background: red;
        }
       </style>
       <form name="myForm" ng-controller="FormController" class="my-form">
         userType: <input name="input" ng-model="userType" required>
         <span class="error" ng-show="myForm.input.$error.required">Required!</span><br>
         <code>userType = {{userType}}</code><br>
         <code>myForm.input.$valid = {{myForm.input.$valid}}</code><br>
         <code>myForm.input.$error = {{myForm.input.$error}}</code><br>
         <code>myForm.$valid = {{myForm.$valid}}</code><br>
         <code>myForm.$error.required = {{!!myForm.$error.required}}</code><br>
        </form>
      </file>
      <file name="protractor.js" type="protractor">
        it('should initialize to model', function() {
          var userType = element(by.binding('userType'));
          var valid = element(by.binding('myForm.input.$valid'));

          expect(userType.getText()).toContain('guest');
          expect(valid.getText()).toContain('true');
        });

        it('should be invalid if empty', function() {
          var userType = element(by.binding('userType'));
          var valid = element(by.binding('myForm.input.$valid'));
          var userInput = element(by.model('userType'));

          userInput.clear();
          userInput.sendKeys('');

          expect(userType.getText()).toEqual('userType =');
          expect(valid.getText()).toContain('false');
        });
      </file>
    </example>
 *
 * @param {string=} name Name of the form. If specified, the form controller will be published into
 *                       related scope, under this name.
 */
var formDirectiveFactory = function(isNgForm) {
  return ['$timeout', function($timeout) {
    var formDirective = {
      name: 'form',
      restrict: isNgForm ? 'EAC' : 'E',
      controller: FormController,
      compile: function ngFormCompile(formElement, attr) {
        // Setup initial state of the control
        formElement.addClass(PRISTINE_CLASS).addClass(VALID_CLASS);

        var nameAttr = attr.name ? 'name' : (isNgForm && attr.ngForm ? 'ngForm' : false);

        return {
          pre: function ngFormPreLink(scope, formElement, attr, controller) {
            // if `action` attr is not present on the form, prevent the default action (submission)
            if (!('action' in attr)) {
              // we can't use jq events because if a form is destroyed during submission the default
              // action is not prevented. see #1238
              //
              // IE 9 is not affected because it doesn't fire a submit event and try to do a full
              // page reload if the form was destroyed by submission of the form via a click handler
              // on a button in the form. Looks like an IE9 specific bug.
              var handleFormSubmission = function(event) {
                scope.$apply(function() {
                  controller.$commitViewValue();
                  controller.$setSubmitted();
                });

                event.preventDefault();
              };

              addEventListenerFn(formElement[0], 'submit', handleFormSubmission);

              // unregister the preventDefault listener so that we don't not leak memory but in a
              // way that will achieve the prevention of the default action.
              formElement.on('$destroy', function() {
                $timeout(function() {
                  removeEventListenerFn(formElement[0], 'submit', handleFormSubmission);
                }, 0, false);
              });
            }

            var parentFormCtrl = controller.$$parentForm;

            if (nameAttr) {
              setter(scope, null, controller.$name, controller, controller.$name);
              attr.$observe(nameAttr, function(newValue) {
                if (controller.$name === newValue) return;
                setter(scope, null, controller.$name, undefined, controller.$name);
                parentFormCtrl.$$renameControl(controller, newValue);
                setter(scope, null, controller.$name, controller, controller.$name);
              });
            }
            formElement.on('$destroy', function() {
              parentFormCtrl.$removeControl(controller);
              if (nameAttr) {
                setter(scope, null, attr[nameAttr], undefined, controller.$name);
              }
              extend(controller, nullFormCtrl); //stop propagating child destruction handlers upwards
            });
          }
        };
      }
    };

    return formDirective;
  }];
};

var formDirective = formDirectiveFactory();
var ngFormDirective = formDirectiveFactory(true);

/* global VALID_CLASS: false,
  INVALID_CLASS: false,
  PRISTINE_CLASS: false,
  DIRTY_CLASS: false,
  UNTOUCHED_CLASS: false,
  TOUCHED_CLASS: false,
  ngModelMinErr: false,
*/

// Regex code is obtained from SO: https://stackoverflow.com/questions/3143070/javascript-regex-iso-datetime#answer-3143231
var ISO_DATE_REGEXP = /\d{4}-[01]\d-[0-3]\dT[0-2]\d:[0-5]\d:[0-5]\d\.\d+([+-][0-2]\d:[0-5]\d|Z)/;
var URL_REGEXP = /^(ftp|http|https):\/\/(\w+:{0,1}\w*@)?(\S+)(:[0-9]+)?(\/|\/([\w#!:.?+=&%@!\-\/]))?$/;
var EMAIL_REGEXP = /^[a-z0-9!#$%&'*+\/=?^_`{|}~.-]+@[a-z0-9]([a-z0-9-]*[a-z0-9])?(\.[a-z0-9]([a-z0-9-]*[a-z0-9])?)*$/i;
var NUMBER_REGEXP = /^\s*(\-|\+)?(\d+|(\d*(\.\d*)))\s*$/;
var DATE_REGEXP = /^(\d{4})-(\d{2})-(\d{2})$/;
var DATETIMELOCAL_REGEXP = /^(\d{4})-(\d\d)-(\d\d)T(\d\d):(\d\d)(?::(\d\d)(\.\d{1,3})?)?$/;
var WEEK_REGEXP = /^(\d{4})-W(\d\d)$/;
var MONTH_REGEXP = /^(\d{4})-(\d\d)$/;
var TIME_REGEXP = /^(\d\d):(\d\d)(?::(\d\d)(\.\d{1,3})?)?$/;

var inputType = {

  /**
   * @ngdoc input
   * @name input[text]
   *
   * @description
   * Standard HTML text input with angular data binding, inherited by most of the `input` elements.
   *
   *
   * @param {string} ngModel Assignable angular expression to data-bind to.
   * @param {string=} name Property name of the form under which the control is published.
   * @param {string=} required Adds `required` validation error key if the value is not entered.
   * @param {string=} ngRequired Adds `required` attribute and `required` validation constraint to
   *    the element when the ngRequired expression evaluates to true. Use `ngRequired` instead of
   *    `required` when you want to data-bind to the `required` attribute.
   * @param {number=} ngMinlength Sets `minlength` validation error key if the value is shorter than
   *    minlength.
   * @param {number=} ngMaxlength Sets `maxlength` validation error key if the value is longer than
   *    maxlength. Setting the attribute to a negative or non-numeric value, allows view values of
   *    any length.
   * @param {string=} pattern Similar to `ngPattern` except that the attribute value is the actual string
   *    that contains the regular expression body that will be converted to a regular expression
   *    as in the ngPattern directive.
   * @param {string=} ngPattern Sets `pattern` validation error key if the ngModel value does not match
   *    a RegExp found by evaluating the Angular expression given in the attribute value.
   *    If the expression evaluates to a RegExp object then this is used directly.
   *    If the expression is a string then it will be converted to a RegExp after wrapping it in `^` and `$`
   *    characters. For instance, `"abc"` will be converted to `new RegExp('^abc$')`.
   * @param {string=} ngChange Angular expression to be executed when input changes due to user
   *    interaction with the input element.
   * @param {boolean=} [ngTrim=true] If set to false Angular will not automatically trim the input.
   *    This parameter is ignored for input[type=password] controls, which will never trim the
   *    input.
   *
   * @example
      <example name="text-input-directive" module="textInputExample">
        <file name="index.html">
         <script>
           angular.module('textInputExample', [])
             .controller('ExampleController', ['$scope', function($scope) {
               $scope.example = {
                 text: 'guest',
                 word: /^\s*\w*\s*$/
               };
             }]);
         </script>
         <form name="myForm" ng-controller="ExampleController">
           Single word: <input type="text" name="input" ng-model="example.text"
                               ng-pattern="example.word" required ng-trim="false">
           <span class="error" ng-show="myForm.input.$error.required">
             Required!</span>
           <span class="error" ng-show="myForm.input.$error.pattern">
             Single word only!</span>

           <tt>text = {{example.text}}</tt><br/>
           <tt>myForm.input.$valid = {{myForm.input.$valid}}</tt><br/>
           <tt>myForm.input.$error = {{myForm.input.$error}}</tt><br/>
           <tt>myForm.$valid = {{myForm.$valid}}</tt><br/>
           <tt>myForm.$error.required = {{!!myForm.$error.required}}</tt><br/>
          </form>
        </file>
        <file name="protractor.js" type="protractor">
          var text = element(by.binding('example.text'));
          var valid = element(by.binding('myForm.input.$valid'));
          var input = element(by.model('example.text'));

          it('should initialize to model', function() {
            expect(text.getText()).toContain('guest');
            expect(valid.getText()).toContain('true');
          });

          it('should be invalid if empty', function() {
            input.clear();
            input.sendKeys('');

            expect(text.getText()).toEqual('text =');
            expect(valid.getText()).toContain('false');
          });

          it('should be invalid if multi word', function() {
            input.clear();
            input.sendKeys('hello world');

            expect(valid.getText()).toContain('false');
          });
        </file>
      </example>
   */
  'text': textInputType,

    /**
     * @ngdoc input
     * @name input[date]
     *
     * @description
     * Input with date validation and transformation. In browsers that do not yet support
     * the HTML5 date input, a text element will be used. In that case, text must be entered in a valid ISO-8601
     * date format (yyyy-MM-dd), for example: `2009-01-06`. Since many
     * modern browsers do not yet support this input type, it is important to provide cues to users on the
     * expected input format via a placeholder or label.
     *
     * The model must always be a Date object, otherwise Angular will throw an error.
     * Invalid `Date` objects (dates whose `getTime()` is `NaN`) will be rendered as an empty string.
     *
     * The timezone to be used to read/write the `Date` instance in the model can be defined using
     * {@link ng.directive:ngModelOptions ngModelOptions}. By default, this is the timezone of the browser.
     *
     * @param {string} ngModel Assignable angular expression to data-bind to.
     * @param {string=} name Property name of the form under which the control is published.
     * @param {string=} min Sets the `min` validation error key if the value entered is less than `min`. This must be a
     * valid ISO date string (yyyy-MM-dd).
     * @param {string=} max Sets the `max` validation error key if the value entered is greater than `max`. This must be
     * a valid ISO date string (yyyy-MM-dd).
     * @param {string=} required Sets `required` validation error key if the value is not entered.
     * @param {string=} ngRequired Adds `required` attribute and `required` validation constraint to
     *    the element when the ngRequired expression evaluates to true. Use `ngRequired` instead of
     *    `required` when you want to data-bind to the `required` attribute.
     * @param {string=} ngChange Angular expression to be executed when input changes due to user
     *    interaction with the input element.
     *
     * @example
     <example name="date-input-directive" module="dateInputExample">
     <file name="index.html">
       <script>
          angular.module('dateInputExample', [])
            .controller('DateController', ['$scope', function($scope) {
              $scope.example = {
                value: new Date(2013, 9, 22)
              };
            }]);
       </script>
       <form name="myForm" ng-controller="DateController as dateCtrl">
          Pick a date in 2013:
          <input type="date" id="exampleInput" name="input" ng-model="example.value"
              placeholder="yyyy-MM-dd" min="2013-01-01" max="2013-12-31" required />
          <span class="error" ng-show="myForm.input.$error.required">
              Required!</span>
          <span class="error" ng-show="myForm.input.$error.date">
              Not a valid date!</span>
           <tt>value = {{example.value | date: "yyyy-MM-dd"}}</tt><br/>
           <tt>myForm.input.$valid = {{myForm.input.$valid}}</tt><br/>
           <tt>myForm.input.$error = {{myForm.input.$error}}</tt><br/>
           <tt>myForm.$valid = {{myForm.$valid}}</tt><br/>
           <tt>myForm.$error.required = {{!!myForm.$error.required}}</tt><br/>
       </form>
     </file>
     <file name="protractor.js" type="protractor">
        var value = element(by.binding('example.value | date: "yyyy-MM-dd"'));
        var valid = element(by.binding('myForm.input.$valid'));
        var input = element(by.model('example.value'));

        // currently protractor/webdriver does not support
        // sending keys to all known HTML5 input controls
        // for various browsers (see https://github.com/angular/protractor/issues/562).
        function setInput(val) {
          // set the value of the element and force validation.
          var scr = "var ipt = document.getElementById('exampleInput'); " +
          "ipt.value = '" + val + "';" +
          "angular.element(ipt).scope().$apply(function(s) { s.myForm[ipt.name].$setViewValue('" + val + "'); });";
          browser.executeScript(scr);
        }

        it('should initialize to model', function() {
          expect(value.getText()).toContain('2013-10-22');
          expect(valid.getText()).toContain('myForm.input.$valid = true');
        });

        it('should be invalid if empty', function() {
          setInput('');
          expect(value.getText()).toEqual('value =');
          expect(valid.getText()).toContain('myForm.input.$valid = false');
        });

        it('should be invalid if over max', function() {
          setInput('2015-01-01');
          expect(value.getText()).toContain('');
          expect(valid.getText()).toContain('myForm.input.$valid = false');
        });
     </file>
     </example>
     */
  'date': createDateInputType('date', DATE_REGEXP,
         createDateParser(DATE_REGEXP, ['yyyy', 'MM', 'dd']),
         'yyyy-MM-dd'),

   /**
    * @ngdoc input
    * @name input[datetime-local]
    *
    * @description
    * Input with datetime validation and transformation. In browsers that do not yet support
    * the HTML5 date input, a text element will be used. In that case, the text must be entered in a valid ISO-8601
    * local datetime format (yyyy-MM-ddTHH:mm:ss), for example: `2010-12-28T14:57:00`.
    *
    * The model must always be a Date object, otherwise Angular will throw an error.
    * Invalid `Date` objects (dates whose `getTime()` is `NaN`) will be rendered as an empty string.
    *
    * The timezone to be used to read/write the `Date` instance in the model can be defined using
    * {@link ng.directive:ngModelOptions ngModelOptions}. By default, this is the timezone of the browser.
    *
    * @param {string} ngModel Assignable angular expression to data-bind to.
    * @param {string=} name Property name of the form under which the control is published.
    * @param {string=} min Sets the `min` validation error key if the value entered is less than `min`. This must be a
    * valid ISO datetime format (yyyy-MM-ddTHH:mm:ss).
    * @param {string=} max Sets the `max` validation error key if the value entered is greater than `max`. This must be
    * a valid ISO datetime format (yyyy-MM-ddTHH:mm:ss).
    * @param {string=} required Sets `required` validation error key if the value is not entered.
    * @param {string=} ngRequired Adds `required` attribute and `required` validation constraint to
    *    the element when the ngRequired expression evaluates to true. Use `ngRequired` instead of
    *    `required` when you want to data-bind to the `required` attribute.
    * @param {string=} ngChange Angular expression to be executed when input changes due to user
    *    interaction with the input element.
    *
    * @example
    <example name="datetimelocal-input-directive" module="dateExample">
    <file name="index.html">
      <script>
        angular.module('dateExample', [])
          .controller('DateController', ['$scope', function($scope) {
            $scope.example = {
              value: new Date(2010, 11, 28, 14, 57)
            };
          }]);
      </script>
      <form name="myForm" ng-controller="DateController as dateCtrl">
        Pick a date between in 2013:
        <input type="datetime-local" id="exampleInput" name="input" ng-model="example.value"
            placeholder="yyyy-MM-ddTHH:mm:ss" min="2001-01-01T00:00:00" max="2013-12-31T00:00:00" required />
        <span class="error" ng-show="myForm.input.$error.required">
            Required!</span>
        <span class="error" ng-show="myForm.input.$error.datetimelocal">
            Not a valid date!</span>
        <tt>value = {{example.value | date: "yyyy-MM-ddTHH:mm:ss"}}</tt><br/>
        <tt>myForm.input.$valid = {{myForm.input.$valid}}</tt><br/>
        <tt>myForm.input.$error = {{myForm.input.$error}}</tt><br/>
        <tt>myForm.$valid = {{myForm.$valid}}</tt><br/>
        <tt>myForm.$error.required = {{!!myForm.$error.required}}</tt><br/>
      </form>
    </file>
    <file name="protractor.js" type="protractor">
      var value = element(by.binding('example.value | date: "yyyy-MM-ddTHH:mm:ss"'));
      var valid = element(by.binding('myForm.input.$valid'));
      var input = element(by.model('example.value'));

      // currently protractor/webdriver does not support
      // sending keys to all known HTML5 input controls
      // for various browsers (https://github.com/angular/protractor/issues/562).
      function setInput(val) {
        // set the value of the element and force validation.
        var scr = "var ipt = document.getElementById('exampleInput'); " +
        "ipt.value = '" + val + "';" +
        "angular.element(ipt).scope().$apply(function(s) { s.myForm[ipt.name].$setViewValue('" + val + "'); });";
        browser.executeScript(scr);
      }

      it('should initialize to model', function() {
        expect(value.getText()).toContain('2010-12-28T14:57:00');
        expect(valid.getText()).toContain('myForm.input.$valid = true');
      });

      it('should be invalid if empty', function() {
        setInput('');
        expect(value.getText()).toEqual('value =');
        expect(valid.getText()).toContain('myForm.input.$valid = false');
      });

      it('should be invalid if over max', function() {
        setInput('2015-01-01T23:59:00');
        expect(value.getText()).toContain('');
        expect(valid.getText()).toContain('myForm.input.$valid = false');
      });
    </file>
    </example>
    */
  'datetime-local': createDateInputType('datetimelocal', DATETIMELOCAL_REGEXP,
      createDateParser(DATETIMELOCAL_REGEXP, ['yyyy', 'MM', 'dd', 'HH', 'mm', 'ss', 'sss']),
      'yyyy-MM-ddTHH:mm:ss.sss'),

  /**
   * @ngdoc input
   * @name input[time]
   *
   * @description
   * Input with time validation and transformation. In browsers that do not yet support
   * the HTML5 date input, a text element will be used. In that case, the text must be entered in a valid ISO-8601
   * local time format (HH:mm:ss), for example: `14:57:00`. Model must be a Date object. This binding will always output a
   * Date object to the model of January 1, 1970, or local date `new Date(1970, 0, 1, HH, mm, ss)`.
   *
   * The model must always be a Date object, otherwise Angular will throw an error.
   * Invalid `Date` objects (dates whose `getTime()` is `NaN`) will be rendered as an empty string.
   *
   * The timezone to be used to read/write the `Date` instance in the model can be defined using
   * {@link ng.directive:ngModelOptions ngModelOptions}. By default, this is the timezone of the browser.
   *
   * @param {string} ngModel Assignable angular expression to data-bind to.
   * @param {string=} name Property name of the form under which the control is published.
   * @param {string=} min Sets the `min` validation error key if the value entered is less than `min`. This must be a
   * valid ISO time format (HH:mm:ss).
   * @param {string=} max Sets the `max` validation error key if the value entered is greater than `max`. This must be a
   * valid ISO time format (HH:mm:ss).
   * @param {string=} required Sets `required` validation error key if the value is not entered.
   * @param {string=} ngRequired Adds `required` attribute and `required` validation constraint to
   *    the element when the ngRequired expression evaluates to true. Use `ngRequired` instead of
   *    `required` when you want to data-bind to the `required` attribute.
   * @param {string=} ngChange Angular expression to be executed when input changes due to user
   *    interaction with the input element.
   *
   * @example
   <example name="time-input-directive" module="timeExample">
   <file name="index.html">
     <script>
      angular.module('timeExample', [])
        .controller('DateController', ['$scope', function($scope) {
          $scope.example = {
            value: new Date(1970, 0, 1, 14, 57, 0)
          };
        }]);
     </script>
     <form name="myForm" ng-controller="DateController as dateCtrl">
        Pick a between 8am and 5pm:
        <input type="time" id="exampleInput" name="input" ng-model="example.value"
            placeholder="HH:mm:ss" min="08:00:00" max="17:00:00" required />
        <span class="error" ng-show="myForm.input.$error.required">
            Required!</span>
        <span class="error" ng-show="myForm.input.$error.time">
            Not a valid date!</span>
        <tt>value = {{example.value | date: "HH:mm:ss"}}</tt><br/>
        <tt>myForm.input.$valid = {{myForm.input.$valid}}</tt><br/>
        <tt>myForm.input.$error = {{myForm.input.$error}}</tt><br/>
        <tt>myForm.$valid = {{myForm.$valid}}</tt><br/>
        <tt>myForm.$error.required = {{!!myForm.$error.required}}</tt><br/>
     </form>
   </file>
   <file name="protractor.js" type="protractor">
      var value = element(by.binding('example.value | date: "HH:mm:ss"'));
      var valid = element(by.binding('myForm.input.$valid'));
      var input = element(by.model('example.value'));

      // currently protractor/webdriver does not support
      // sending keys to all known HTML5 input controls
      // for various browsers (https://github.com/angular/protractor/issues/562).
      function setInput(val) {
        // set the value of the element and force validation.
        var scr = "var ipt = document.getElementById('exampleInput'); " +
        "ipt.value = '" + val + "';" +
        "angular.element(ipt).scope().$apply(function(s) { s.myForm[ipt.name].$setViewValue('" + val + "'); });";
        browser.executeScript(scr);
      }

      it('should initialize to model', function() {
        expect(value.getText()).toContain('14:57:00');
        expect(valid.getText()).toContain('myForm.input.$valid = true');
      });

      it('should be invalid if empty', function() {
        setInput('');
        expect(value.getText()).toEqual('value =');
        expect(valid.getText()).toContain('myForm.input.$valid = false');
      });

      it('should be invalid if over max', function() {
        setInput('23:59:00');
        expect(value.getText()).toContain('');
        expect(valid.getText()).toContain('myForm.input.$valid = false');
      });
   </file>
   </example>
   */
  'time': createDateInputType('time', TIME_REGEXP,
      createDateParser(TIME_REGEXP, ['HH', 'mm', 'ss', 'sss']),
     'HH:mm:ss.sss'),

   /**
    * @ngdoc input
    * @name input[week]
    *
    * @description
    * Input with week-of-the-year validation and transformation to Date. In browsers that do not yet support
    * the HTML5 week input, a text element will be used. In that case, the text must be entered in a valid ISO-8601
    * week format (yyyy-W##), for example: `2013-W02`.
    *
    * The model must always be a Date object, otherwise Angular will throw an error.
    * Invalid `Date` objects (dates whose `getTime()` is `NaN`) will be rendered as an empty string.
    *
    * The timezone to be used to read/write the `Date` instance in the model can be defined using
    * {@link ng.directive:ngModelOptions ngModelOptions}. By default, this is the timezone of the browser.
    *
    * @param {string} ngModel Assignable angular expression to data-bind to.
    * @param {string=} name Property name of the form under which the control is published.
    * @param {string=} min Sets the `min` validation error key if the value entered is less than `min`. This must be a
    * valid ISO week format (yyyy-W##).
    * @param {string=} max Sets the `max` validation error key if the value entered is greater than `max`. This must be
    * a valid ISO week format (yyyy-W##).
    * @param {string=} required Sets `required` validation error key if the value is not entered.
    * @param {string=} ngRequired Adds `required` attribute and `required` validation constraint to
    *    the element when the ngRequired expression evaluates to true. Use `ngRequired` instead of
    *    `required` when you want to data-bind to the `required` attribute.
    * @param {string=} ngChange Angular expression to be executed when input changes due to user
    *    interaction with the input element.
    *
    * @example
    <example name="week-input-directive" module="weekExample">
    <file name="index.html">
      <script>
      angular.module('weekExample', [])
        .controller('DateController', ['$scope', function($scope) {
          $scope.example = {
            value: new Date(2013, 0, 3)
          };
        }]);
      </script>
      <form name="myForm" ng-controller="DateController as dateCtrl">
        Pick a date between in 2013:
        <input id="exampleInput" type="week" name="input" ng-model="example.value"
            placeholder="YYYY-W##" min="2012-W32" max="2013-W52" required />
        <span class="error" ng-show="myForm.input.$error.required">
            Required!</span>
        <span class="error" ng-show="myForm.input.$error.week">
            Not a valid date!</span>
        <tt>value = {{example.value | date: "yyyy-Www"}}</tt><br/>
        <tt>myForm.input.$valid = {{myForm.input.$valid}}</tt><br/>
        <tt>myForm.input.$error = {{myForm.input.$error}}</tt><br/>
        <tt>myForm.$valid = {{myForm.$valid}}</tt><br/>
        <tt>myForm.$error.required = {{!!myForm.$error.required}}</tt><br/>
      </form>
    </file>
    <file name="protractor.js" type="protractor">
      var value = element(by.binding('example.value | date: "yyyy-Www"'));
      var valid = element(by.binding('myForm.input.$valid'));
      var input = element(by.model('example.value'));

      // currently protractor/webdriver does not support
      // sending keys to all known HTML5 input controls
      // for various browsers (https://github.com/angular/protractor/issues/562).
      function setInput(val) {
        // set the value of the element and force validation.
        var scr = "var ipt = document.getElementById('exampleInput'); " +
        "ipt.value = '" + val + "';" +
        "angular.element(ipt).scope().$apply(function(s) { s.myForm[ipt.name].$setViewValue('" + val + "'); });";
        browser.executeScript(scr);
      }

      it('should initialize to model', function() {
        expect(value.getText()).toContain('2013-W01');
        expect(valid.getText()).toContain('myForm.input.$valid = true');
      });

      it('should be invalid if empty', function() {
        setInput('');
        expect(value.getText()).toEqual('value =');
        expect(valid.getText()).toContain('myForm.input.$valid = false');
      });

      it('should be invalid if over max', function() {
        setInput('2015-W01');
        expect(value.getText()).toContain('');
        expect(valid.getText()).toContain('myForm.input.$valid = false');
      });
    </file>
    </example>
    */
  'week': createDateInputType('week', WEEK_REGEXP, weekParser, 'yyyy-Www'),

  /**
   * @ngdoc input
   * @name input[month]
   *
   * @description
   * Input with month validation and transformation. In browsers that do not yet support
   * the HTML5 month input, a text element will be used. In that case, the text must be entered in a valid ISO-8601
   * month format (yyyy-MM), for example: `2009-01`.
   *
   * The model must always be a Date object, otherwise Angular will throw an error.
   * Invalid `Date` objects (dates whose `getTime()` is `NaN`) will be rendered as an empty string.
   * If the model is not set to the first of the month, the next view to model update will set it
   * to the first of the month.
   *
   * The timezone to be used to read/write the `Date` instance in the model can be defined using
   * {@link ng.directive:ngModelOptions ngModelOptions}. By default, this is the timezone of the browser.
   *
   * @param {string} ngModel Assignable angular expression to data-bind to.
   * @param {string=} name Property name of the form under which the control is published.
   * @param {string=} min Sets the `min` validation error key if the value entered is less than `min`. This must be
   * a valid ISO month format (yyyy-MM).
   * @param {string=} max Sets the `max` validation error key if the value entered is greater than `max`. This must
   * be a valid ISO month format (yyyy-MM).
   * @param {string=} required Sets `required` validation error key if the value is not entered.
   * @param {string=} ngRequired Adds `required` attribute and `required` validation constraint to
   *    the element when the ngRequired expression evaluates to true. Use `ngRequired` instead of
   *    `required` when you want to data-bind to the `required` attribute.
   * @param {string=} ngChange Angular expression to be executed when input changes due to user
   *    interaction with the input element.
   *
   * @example
   <example name="month-input-directive" module="monthExample">
   <file name="index.html">
     <script>
      angular.module('monthExample', [])
        .controller('DateController', ['$scope', function($scope) {
          $scope.example = {
            value: new Date(2013, 9, 1)
          };
        }]);
     </script>
     <form name="myForm" ng-controller="DateController as dateCtrl">
       Pick a month in 2013:
       <input id="exampleInput" type="month" name="input" ng-model="example.value"
          placeholder="yyyy-MM" min="2013-01" max="2013-12" required />
       <span class="error" ng-show="myForm.input.$error.required">
          Required!</span>
       <span class="error" ng-show="myForm.input.$error.month">
          Not a valid month!</span>
       <tt>value = {{example.value | date: "yyyy-MM"}}</tt><br/>
       <tt>myForm.input.$valid = {{myForm.input.$valid}}</tt><br/>
       <tt>myForm.input.$error = {{myForm.input.$error}}</tt><br/>
       <tt>myForm.$valid = {{myForm.$valid}}</tt><br/>
       <tt>myForm.$error.required = {{!!myForm.$error.required}}</tt><br/>
     </form>
   </file>
   <file name="protractor.js" type="protractor">
      var value = element(by.binding('example.value | date: "yyyy-MM"'));
      var valid = element(by.binding('myForm.input.$valid'));
      var input = element(by.model('example.value'));

      // currently protractor/webdriver does not support
      // sending keys to all known HTML5 input controls
      // for various browsers (https://github.com/angular/protractor/issues/562).
      function setInput(val) {
        // set the value of the element and force validation.
        var scr = "var ipt = document.getElementById('exampleInput'); " +
        "ipt.value = '" + val + "';" +
        "angular.element(ipt).scope().$apply(function(s) { s.myForm[ipt.name].$setViewValue('" + val + "'); });";
        browser.executeScript(scr);
      }

      it('should initialize to model', function() {
        expect(value.getText()).toContain('2013-10');
        expect(valid.getText()).toContain('myForm.input.$valid = true');
      });

      it('should be invalid if empty', function() {
        setInput('');
        expect(value.getText()).toEqual('value =');
        expect(valid.getText()).toContain('myForm.input.$valid = false');
      });

      it('should be invalid if over max', function() {
        setInput('2015-01');
        expect(value.getText()).toContain('');
        expect(valid.getText()).toContain('myForm.input.$valid = false');
      });
   </file>
   </example>
   */
  'month': createDateInputType('month', MONTH_REGEXP,
     createDateParser(MONTH_REGEXP, ['yyyy', 'MM']),
     'yyyy-MM'),

  /**
   * @ngdoc input
   * @name input[number]
   *
   * @description
   * Text input with number validation and transformation. Sets the `number` validation
   * error if not a valid number.
   *
   * <div class="alert alert-warning">
   * The model must always be of type `number` otherwise Angular will throw an error.
   * Be aware that a string containing a number is not enough. See the {@link ngModel:numfmt}
   * error docs for more information and an example of how to convert your model if necessary.
   * </div>
   *
   * @param {string} ngModel Assignable angular expression to data-bind to.
   * @param {string=} name Property name of the form under which the control is published.
   * @param {string=} min Sets the `min` validation error key if the value entered is less than `min`.
   * @param {string=} max Sets the `max` validation error key if the value entered is greater than `max`.
   * @param {string=} required Sets `required` validation error key if the value is not entered.
   * @param {string=} ngRequired Adds `required` attribute and `required` validation constraint to
   *    the element when the ngRequired expression evaluates to true. Use `ngRequired` instead of
   *    `required` when you want to data-bind to the `required` attribute.
   * @param {number=} ngMinlength Sets `minlength` validation error key if the value is shorter than
   *    minlength.
   * @param {number=} ngMaxlength Sets `maxlength` validation error key if the value is longer than
   *    maxlength. Setting the attribute to a negative or non-numeric value, allows view values of
   *    any length.
   * @param {string=} pattern Similar to `ngPattern` except that the attribute value is the actual string
   *    that contains the regular expression body that will be converted to a regular expression
   *    as in the ngPattern directive.
   * @param {string=} ngPattern Sets `pattern` validation error key if the ngModel value does not match
   *    a RegExp found by evaluating the Angular expression given in the attribute value.
   *    If the expression evaluates to a RegExp object then this is used directly.
   *    If the expression is a string then it will be converted to a RegExp after wrapping it in `^` and `$`
   *    characters. For instance, `"abc"` will be converted to `new RegExp('^abc$')`.
   * @param {string=} ngChange Angular expression to be executed when input changes due to user
   *    interaction with the input element.
   *
   * @example
      <example name="number-input-directive" module="numberExample">
        <file name="index.html">
         <script>
           angular.module('numberExample', [])
             .controller('ExampleController', ['$scope', function($scope) {
               $scope.example = {
                 value: 12
               };
             }]);
         </script>
         <form name="myForm" ng-controller="ExampleController">
           Number: <input type="number" name="input" ng-model="example.value"
                          min="0" max="99" required>
           <span class="error" ng-show="myForm.input.$error.required">
             Required!</span>
           <span class="error" ng-show="myForm.input.$error.number">
             Not valid number!</span>
           <tt>value = {{example.value}}</tt><br/>
           <tt>myForm.input.$valid = {{myForm.input.$valid}}</tt><br/>
           <tt>myForm.input.$error = {{myForm.input.$error}}</tt><br/>
           <tt>myForm.$valid = {{myForm.$valid}}</tt><br/>
           <tt>myForm.$error.required = {{!!myForm.$error.required}}</tt><br/>
          </form>
        </file>
        <file name="protractor.js" type="protractor">
          var value = element(by.binding('example.value'));
          var valid = element(by.binding('myForm.input.$valid'));
          var input = element(by.model('example.value'));

          it('should initialize to model', function() {
            expect(value.getText()).toContain('12');
            expect(valid.getText()).toContain('true');
          });

          it('should be invalid if empty', function() {
            input.clear();
            input.sendKeys('');
            expect(value.getText()).toEqual('value =');
            expect(valid.getText()).toContain('false');
          });

          it('should be invalid if over max', function() {
            input.clear();
            input.sendKeys('123');
            expect(value.getText()).toEqual('value =');
            expect(valid.getText()).toContain('false');
          });
        </file>
      </example>
   */
  'number': numberInputType,


  /**
   * @ngdoc input
   * @name input[url]
   *
   * @description
   * Text input with URL validation. Sets the `url` validation error key if the content is not a
   * valid URL.
   *
   * <div class="alert alert-warning">
   * **Note:** `input[url]` uses a regex to validate urls that is derived from the regex
   * used in Chromium. If you need stricter validation, you can use `ng-pattern` or modify
   * the built-in validators (see the {@link guide/forms Forms guide})
   * </div>
   *
   * @param {string} ngModel Assignable angular expression to data-bind to.
   * @param {string=} name Property name of the form under which the control is published.
   * @param {string=} required Sets `required` validation error key if the value is not entered.
   * @param {string=} ngRequired Adds `required` attribute and `required` validation constraint to
   *    the element when the ngRequired expression evaluates to true. Use `ngRequired` instead of
   *    `required` when you want to data-bind to the `required` attribute.
   * @param {number=} ngMinlength Sets `minlength` validation error key if the value is shorter than
   *    minlength.
   * @param {number=} ngMaxlength Sets `maxlength` validation error key if the value is longer than
   *    maxlength. Setting the attribute to a negative or non-numeric value, allows view values of
   *    any length.
   * @param {string=} pattern Similar to `ngPattern` except that the attribute value is the actual string
   *    that contains the regular expression body that will be converted to a regular expression
   *    as in the ngPattern directive.
   * @param {string=} ngPattern Sets `pattern` validation error key if the ngModel value does not match
   *    a RegExp found by evaluating the Angular expression given in the attribute value.
   *    If the expression evaluates to a RegExp object then this is used directly.
   *    If the expression is a string then it will be converted to a RegExp after wrapping it in `^` and `$`
   *    characters. For instance, `"abc"` will be converted to `new RegExp('^abc$')`.
   * @param {string=} ngChange Angular expression to be executed when input changes due to user
   *    interaction with the input element.
   *
   * @example
      <example name="url-input-directive" module="urlExample">
        <file name="index.html">
         <script>
           angular.module('urlExample', [])
             .controller('ExampleController', ['$scope', function($scope) {
               $scope.url = {
                 text: 'http://google.com'
               };
             }]);
         </script>
         <form name="myForm" ng-controller="ExampleController">
           URL: <input type="url" name="input" ng-model="url.text" required>
           <span class="error" ng-show="myForm.input.$error.required">
             Required!</span>
           <span class="error" ng-show="myForm.input.$error.url">
             Not valid url!</span>
           <tt>text = {{url.text}}</tt><br/>
           <tt>myForm.input.$valid = {{myForm.input.$valid}}</tt><br/>
           <tt>myForm.input.$error = {{myForm.input.$error}}</tt><br/>
           <tt>myForm.$valid = {{myForm.$valid}}</tt><br/>
           <tt>myForm.$error.required = {{!!myForm.$error.required}}</tt><br/>
           <tt>myForm.$error.url = {{!!myForm.$error.url}}</tt><br/>
          </form>
        </file>
        <file name="protractor.js" type="protractor">
          var text = element(by.binding('url.text'));
          var valid = element(by.binding('myForm.input.$valid'));
          var input = element(by.model('url.text'));

          it('should initialize to model', function() {
            expect(text.getText()).toContain('http://google.com');
            expect(valid.getText()).toContain('true');
          });

          it('should be invalid if empty', function() {
            input.clear();
            input.sendKeys('');

            expect(text.getText()).toEqual('text =');
            expect(valid.getText()).toContain('false');
          });

          it('should be invalid if not url', function() {
            input.clear();
            input.sendKeys('box');

            expect(valid.getText()).toContain('false');
          });
        </file>
      </example>
   */
  'url': urlInputType,


  /**
   * @ngdoc input
   * @name input[email]
   *
   * @description
   * Text input with email validation. Sets the `email` validation error key if not a valid email
   * address.
   *
   * <div class="alert alert-warning">
   * **Note:** `input[email]` uses a regex to validate email addresses that is derived from the regex
   * used in Chromium. If you need stricter validation (e.g. requiring a top-level domain), you can
   * use `ng-pattern` or modify the built-in validators (see the {@link guide/forms Forms guide})
   * </div>
   *
   * @param {string} ngModel Assignable angular expression to data-bind to.
   * @param {string=} name Property name of the form under which the control is published.
   * @param {string=} required Sets `required` validation error key if the value is not entered.
   * @param {string=} ngRequired Adds `required` attribute and `required` validation constraint to
   *    the element when the ngRequired expression evaluates to true. Use `ngRequired` instead of
   *    `required` when you want to data-bind to the `required` attribute.
   * @param {number=} ngMinlength Sets `minlength` validation error key if the value is shorter than
   *    minlength.
   * @param {number=} ngMaxlength Sets `maxlength` validation error key if the value is longer than
   *    maxlength. Setting the attribute to a negative or non-numeric value, allows view values of
   *    any length.
   * @param {string=} pattern Similar to `ngPattern` except that the attribute value is the actual string
   *    that contains the regular expression body that will be converted to a regular expression
   *    as in the ngPattern directive.
   * @param {string=} ngPattern Sets `pattern` validation error key if the ngModel value does not match
   *    a RegExp found by evaluating the Angular expression given in the attribute value.
   *    If the expression evaluates to a RegExp object then this is used directly.
   *    If the expression is a string then it will be converted to a RegExp after wrapping it in `^` and `$`
   *    characters. For instance, `"abc"` will be converted to `new RegExp('^abc$')`.
   * @param {string=} ngChange Angular expression to be executed when input changes due to user
   *    interaction with the input element.
   *
   * @example
      <example name="email-input-directive" module="emailExample">
        <file name="index.html">
         <script>
           angular.module('emailExample', [])
             .controller('ExampleController', ['$scope', function($scope) {
               $scope.email = {
                 text: 'me@example.com'
               };
             }]);
         </script>
           <form name="myForm" ng-controller="ExampleController">
             Email: <input type="email" name="input" ng-model="email.text" required>
             <span class="error" ng-show="myForm.input.$error.required">
               Required!</span>
             <span class="error" ng-show="myForm.input.$error.email">
               Not valid email!</span>
             <tt>text = {{email.text}}</tt><br/>
             <tt>myForm.input.$valid = {{myForm.input.$valid}}</tt><br/>
             <tt>myForm.input.$error = {{myForm.input.$error}}</tt><br/>
             <tt>myForm.$valid = {{myForm.$valid}}</tt><br/>
             <tt>myForm.$error.required = {{!!myForm.$error.required}}</tt><br/>
             <tt>myForm.$error.email = {{!!myForm.$error.email}}</tt><br/>
           </form>
         </file>
        <file name="protractor.js" type="protractor">
          var text = element(by.binding('email.text'));
          var valid = element(by.binding('myForm.input.$valid'));
          var input = element(by.model('email.text'));

          it('should initialize to model', function() {
            expect(text.getText()).toContain('me@example.com');
            expect(valid.getText()).toContain('true');
          });

          it('should be invalid if empty', function() {
            input.clear();
            input.sendKeys('');
            expect(text.getText()).toEqual('text =');
            expect(valid.getText()).toContain('false');
          });

          it('should be invalid if not email', function() {
            input.clear();
            input.sendKeys('xxx');

            expect(valid.getText()).toContain('false');
          });
        </file>
      </example>
   */
  'email': emailInputType,


  /**
   * @ngdoc input
   * @name input[radio]
   *
   * @description
   * HTML radio button.
   *
   * @param {string} ngModel Assignable angular expression to data-bind to.
   * @param {string} value The value to which the expression should be set when selected.
   * @param {string=} name Property name of the form under which the control is published.
   * @param {string=} ngChange Angular expression to be executed when input changes due to user
   *    interaction with the input element.
   * @param {string} ngValue Angular expression which sets the value to which the expression should
   *    be set when selected.
   *
   * @example
      <example name="radio-input-directive" module="radioExample">
        <file name="index.html">
         <script>
           angular.module('radioExample', [])
             .controller('ExampleController', ['$scope', function($scope) {
               $scope.color = {
                 name: 'blue'
               };
               $scope.specialValue = {
                 "id": "12345",
                 "value": "green"
               };
             }]);
         </script>
         <form name="myForm" ng-controller="ExampleController">
           <input type="radio" ng-model="color.name" value="red">  Red <br/>
           <input type="radio" ng-model="color.name" ng-value="specialValue"> Green <br/>
           <input type="radio" ng-model="color.name" value="blue"> Blue <br/>
           <tt>color = {{color.name | json}}</tt><br/>
          </form>
          Note that `ng-value="specialValue"` sets radio item's value to be the value of `$scope.specialValue`.
        </file>
        <file name="protractor.js" type="protractor">
          it('should change state', function() {
            var color = element(by.binding('color.name'));

            expect(color.getText()).toContain('blue');

            element.all(by.model('color.name')).get(0).click();

            expect(color.getText()).toContain('red');
          });
        </file>
      </example>
   */
  'radio': radioInputType,


  /**
   * @ngdoc input
   * @name input[checkbox]
   *
   * @description
   * HTML checkbox.
   *
   * @param {string} ngModel Assignable angular expression to data-bind to.
   * @param {string=} name Property name of the form under which the control is published.
   * @param {expression=} ngTrueValue The value to which the expression should be set when selected.
   * @param {expression=} ngFalseValue The value to which the expression should be set when not selected.
   * @param {string=} ngChange Angular expression to be executed when input changes due to user
   *    interaction with the input element.
   *
   * @example
      <example name="checkbox-input-directive" module="checkboxExample">
        <file name="index.html">
         <script>
           angular.module('checkboxExample', [])
             .controller('ExampleController', ['$scope', function($scope) {
               $scope.checkboxModel = {
                value1 : true,
                value2 : 'YES'
              };
             }]);
         </script>
         <form name="myForm" ng-controller="ExampleController">
           Value1: <input type="checkbox" ng-model="checkboxModel.value1"> <br/>
           Value2: <input type="checkbox" ng-model="checkboxModel.value2"
                          ng-true-value="'YES'" ng-false-value="'NO'"> <br/>
           <tt>value1 = {{checkboxModel.value1}}</tt><br/>
           <tt>value2 = {{checkboxModel.value2}}</tt><br/>
          </form>
        </file>
        <file name="protractor.js" type="protractor">
          it('should change state', function() {
            var value1 = element(by.binding('checkboxModel.value1'));
            var value2 = element(by.binding('checkboxModel.value2'));

            expect(value1.getText()).toContain('true');
            expect(value2.getText()).toContain('YES');

            element(by.model('checkboxModel.value1')).click();
            element(by.model('checkboxModel.value2')).click();

            expect(value1.getText()).toContain('false');
            expect(value2.getText()).toContain('NO');
          });
        </file>
      </example>
   */
  'checkbox': checkboxInputType,

  'hidden': noop,
  'button': noop,
  'submit': noop,
  'reset': noop,
  'file': noop
};

function stringBasedInputType(ctrl) {
  ctrl.$formatters.push(function(value) {
    return ctrl.$isEmpty(value) ? value : value.toString();
  });
}

function textInputType(scope, element, attr, ctrl, $sniffer, $browser) {
  baseInputType(scope, element, attr, ctrl, $sniffer, $browser);
  stringBasedInputType(ctrl);
}

function baseInputType(scope, element, attr, ctrl, $sniffer, $browser) {
  var type = lowercase(element[0].type);

  // In composition mode, users are still inputing intermediate text buffer,
  // hold the listener until composition is done.
  // More about composition events: https://developer.mozilla.org/en-US/docs/Web/API/CompositionEvent
  if (!$sniffer.android) {
    var composing = false;

    element.on('compositionstart', function(data) {
      composing = true;
    });

    element.on('compositionend', function() {
      composing = false;
      listener();
    });
  }

  var listener = function(ev) {
    if (timeout) {
      $browser.defer.cancel(timeout);
      timeout = null;
    }
    if (composing) return;
    var value = element.val(),
        event = ev && ev.type;

    // By default we will trim the value
    // If the attribute ng-trim exists we will avoid trimming
    // If input type is 'password', the value is never trimmed
    if (type !== 'password' && (!attr.ngTrim || attr.ngTrim !== 'false')) {
      value = trim(value);
    }

    // If a control is suffering from bad input (due to native validators), browsers discard its
    // value, so it may be necessary to revalidate (by calling $setViewValue again) even if the
    // control's value is the same empty value twice in a row.
    if (ctrl.$viewValue !== value || (value === '' && ctrl.$$hasNativeValidators)) {
      ctrl.$setViewValue(value, event);
    }
  };

  // if the browser does support "input" event, we are fine - except on IE9 which doesn't fire the
  // input event on backspace, delete or cut
  if ($sniffer.hasEvent('input')) {
    element.on('input', listener);
  } else {
    var timeout;

    var deferListener = function(ev, input, origValue) {
      if (!timeout) {
        timeout = $browser.defer(function() {
          timeout = null;
          if (!input || input.value !== origValue) {
            listener(ev);
          }
        });
      }
    };

    element.on('keydown', function(event) {
      var key = event.keyCode;

      // ignore
      //    command            modifiers                   arrows
      if (key === 91 || (15 < key && key < 19) || (37 <= key && key <= 40)) return;

      deferListener(event, this, this.value);
    });

    // if user modifies input value using context menu in IE, we need "paste" and "cut" events to catch it
    if ($sniffer.hasEvent('paste')) {
      element.on('paste cut', deferListener);
    }
  }

  // if user paste into input using mouse on older browser
  // or form autocomplete on newer browser, we need "change" event to catch it
  element.on('change', listener);

  ctrl.$render = function() {
    element.val(ctrl.$isEmpty(ctrl.$viewValue) ? '' : ctrl.$viewValue);
  };
}

function weekParser(isoWeek, existingDate) {
  if (isDate(isoWeek)) {
    return isoWeek;
  }

  if (isString(isoWeek)) {
    WEEK_REGEXP.lastIndex = 0;
    var parts = WEEK_REGEXP.exec(isoWeek);
    if (parts) {
      var year = +parts[1],
          week = +parts[2],
          hours = 0,
          minutes = 0,
          seconds = 0,
          milliseconds = 0,
          firstThurs = getFirstThursdayOfYear(year),
          addDays = (week - 1) * 7;

      if (existingDate) {
        hours = existingDate.getHours();
        minutes = existingDate.getMinutes();
        seconds = existingDate.getSeconds();
        milliseconds = existingDate.getMilliseconds();
      }

      return new Date(year, 0, firstThurs.getDate() + addDays, hours, minutes, seconds, milliseconds);
    }
  }

  return NaN;
}

function createDateParser(regexp, mapping) {
  return function(iso, date) {
    var parts, map;

    if (isDate(iso)) {
      return iso;
    }

    if (isString(iso)) {
      // When a date is JSON'ified to wraps itself inside of an extra
      // set of double quotes. This makes the date parsing code unable
      // to match the date string and parse it as a date.
      if (iso.charAt(0) == '"' && iso.charAt(iso.length - 1) == '"') {
        iso = iso.substring(1, iso.length - 1);
      }
      if (ISO_DATE_REGEXP.test(iso)) {
        return new Date(iso);
      }
      regexp.lastIndex = 0;
      parts = regexp.exec(iso);

      if (parts) {
        parts.shift();
        if (date) {
          map = {
            yyyy: date.getFullYear(),
            MM: date.getMonth() + 1,
            dd: date.getDate(),
            HH: date.getHours(),
            mm: date.getMinutes(),
            ss: date.getSeconds(),
            sss: date.getMilliseconds() / 1000
          };
        } else {
          map = { yyyy: 1970, MM: 1, dd: 1, HH: 0, mm: 0, ss: 0, sss: 0 };
        }

        forEach(parts, function(part, index) {
          if (index < mapping.length) {
            map[mapping[index]] = +part;
          }
        });
        return new Date(map.yyyy, map.MM - 1, map.dd, map.HH, map.mm, map.ss || 0, map.sss * 1000 || 0);
      }
    }

    return NaN;
  };
}

function createDateInputType(type, regexp, parseDate, format) {
  return function dynamicDateInputType(scope, element, attr, ctrl, $sniffer, $browser, $filter) {
    badInputChecker(scope, element, attr, ctrl);
    baseInputType(scope, element, attr, ctrl, $sniffer, $browser);
    var timezone = ctrl && ctrl.$options && ctrl.$options.timezone;
    var previousDate;

    ctrl.$$parserName = type;
    ctrl.$parsers.push(function(value) {
      if (ctrl.$isEmpty(value)) return null;
      if (regexp.test(value)) {
        // Note: We cannot read ctrl.$modelValue, as there might be a different
        // parser/formatter in the processing chain so that the model
        // contains some different data format!
        var parsedDate = parseDate(value, previousDate);
        if (timezone === 'UTC') {
          parsedDate.setMinutes(parsedDate.getMinutes() - parsedDate.getTimezoneOffset());
        }
        return parsedDate;
      }
      return undefined;
    });

    ctrl.$formatters.push(function(value) {
      if (value && !isDate(value)) {
        throw ngModelMinErr('datefmt', 'Expected `{0}` to be a date', value);
      }
      if (isValidDate(value)) {
        previousDate = value;
        if (previousDate && timezone === 'UTC') {
          var timezoneOffset = 60000 * previousDate.getTimezoneOffset();
          previousDate = new Date(previousDate.getTime() + timezoneOffset);
        }
        return $filter('date')(value, format, timezone);
      } else {
        previousDate = null;
        return '';
      }
    });

    if (isDefined(attr.min) || attr.ngMin) {
      var minVal;
      ctrl.$validators.min = function(value) {
        return !isValidDate(value) || isUndefined(minVal) || parseDate(value) >= minVal;
      };
      attr.$observe('min', function(val) {
        minVal = parseObservedDateValue(val);
        ctrl.$validate();
      });
    }

    if (isDefined(attr.max) || attr.ngMax) {
      var maxVal;
      ctrl.$validators.max = function(value) {
        return !isValidDate(value) || isUndefined(maxVal) || parseDate(value) <= maxVal;
      };
      attr.$observe('max', function(val) {
        maxVal = parseObservedDateValue(val);
        ctrl.$validate();
      });
    }

    function isValidDate(value) {
      // Invalid Date: getTime() returns NaN
      return value && !(value.getTime && value.getTime() !== value.getTime());
    }

    function parseObservedDateValue(val) {
      return isDefined(val) ? (isDate(val) ? val : parseDate(val)) : undefined;
    }
  };
}

function badInputChecker(scope, element, attr, ctrl) {
  var node = element[0];
  var nativeValidation = ctrl.$$hasNativeValidators = isObject(node.validity);
  if (nativeValidation) {
    ctrl.$parsers.push(function(value) {
      var validity = element.prop(VALIDITY_STATE_PROPERTY) || {};
      // Detect bug in FF35 for input[email] (https://bugzilla.mozilla.org/show_bug.cgi?id=1064430):
      // - also sets validity.badInput (should only be validity.typeMismatch).
      // - see http://www.whatwg.org/specs/web-apps/current-work/multipage/forms.html#e-mail-state-(type=email)
      // - can ignore this case as we can still read out the erroneous email...
      return validity.badInput && !validity.typeMismatch ? undefined : value;
    });
  }
}

function numberInputType(scope, element, attr, ctrl, $sniffer, $browser) {
  badInputChecker(scope, element, attr, ctrl);
  baseInputType(scope, element, attr, ctrl, $sniffer, $browser);

  ctrl.$$parserName = 'number';
  ctrl.$parsers.push(function(value) {
    if (ctrl.$isEmpty(value))      return null;
    if (NUMBER_REGEXP.test(value)) return parseFloat(value);
    return undefined;
  });

  ctrl.$formatters.push(function(value) {
    if (!ctrl.$isEmpty(value)) {
      if (!isNumber(value)) {
        throw ngModelMinErr('numfmt', 'Expected `{0}` to be a number', value);
      }
      value = value.toString();
    }
    return value;
  });

  if (isDefined(attr.min) || attr.ngMin) {
    var minVal;
    ctrl.$validators.min = function(value) {
      return ctrl.$isEmpty(value) || isUndefined(minVal) || value >= minVal;
    };

    attr.$observe('min', function(val) {
      if (isDefined(val) && !isNumber(val)) {
        val = parseFloat(val, 10);
      }
      minVal = isNumber(val) && !isNaN(val) ? val : undefined;
      // TODO(matsko): implement validateLater to reduce number of validations
      ctrl.$validate();
    });
  }

  if (isDefined(attr.max) || attr.ngMax) {
    var maxVal;
    ctrl.$validators.max = function(value) {
      return ctrl.$isEmpty(value) || isUndefined(maxVal) || value <= maxVal;
    };

    attr.$observe('max', function(val) {
      if (isDefined(val) && !isNumber(val)) {
        val = parseFloat(val, 10);
      }
      maxVal = isNumber(val) && !isNaN(val) ? val : undefined;
      // TODO(matsko): implement validateLater to reduce number of validations
      ctrl.$validate();
    });
  }
}

function urlInputType(scope, element, attr, ctrl, $sniffer, $browser) {
  // Note: no badInputChecker here by purpose as `url` is only a validation
  // in browsers, i.e. we can always read out input.value even if it is not valid!
  baseInputType(scope, element, attr, ctrl, $sniffer, $browser);
  stringBasedInputType(ctrl);

  ctrl.$$parserName = 'url';
  ctrl.$validators.url = function(modelValue, viewValue) {
    var value = modelValue || viewValue;
    return ctrl.$isEmpty(value) || URL_REGEXP.test(value);
  };
}

function emailInputType(scope, element, attr, ctrl, $sniffer, $browser) {
  // Note: no badInputChecker here by purpose as `url` is only a validation
  // in browsers, i.e. we can always read out input.value even if it is not valid!
  baseInputType(scope, element, attr, ctrl, $sniffer, $browser);
  stringBasedInputType(ctrl);

  ctrl.$$parserName = 'email';
  ctrl.$validators.email = function(modelValue, viewValue) {
    var value = modelValue || viewValue;
    return ctrl.$isEmpty(value) || EMAIL_REGEXP.test(value);
  };
}

function radioInputType(scope, element, attr, ctrl) {
  // make the name unique, if not defined
  if (isUndefined(attr.name)) {
    element.attr('name', nextUid());
  }

  var listener = function(ev) {
    if (element[0].checked) {
      ctrl.$setViewValue(attr.value, ev && ev.type);
    }
  };

  element.on('click', listener);

  ctrl.$render = function() {
    var value = attr.value;
    element[0].checked = (value == ctrl.$viewValue);
  };

  attr.$observe('value', ctrl.$render);
}

function parseConstantExpr($parse, context, name, expression, fallback) {
  var parseFn;
  if (isDefined(expression)) {
    parseFn = $parse(expression);
    if (!parseFn.constant) {
      throw ngModelMinErr('constexpr', 'Expected constant expression for `{0}`, but saw ' +
                                   '`{1}`.', name, expression);
    }
    return parseFn(context);
  }
  return fallback;
}

function checkboxInputType(scope, element, attr, ctrl, $sniffer, $browser, $filter, $parse) {
  var trueValue = parseConstantExpr($parse, scope, 'ngTrueValue', attr.ngTrueValue, true);
  var falseValue = parseConstantExpr($parse, scope, 'ngFalseValue', attr.ngFalseValue, false);

  var listener = function(ev) {
    ctrl.$setViewValue(element[0].checked, ev && ev.type);
  };

  element.on('click', listener);

  ctrl.$render = function() {
    element[0].checked = ctrl.$viewValue;
  };

  // Override the standard `$isEmpty` because the $viewValue of an empty checkbox is always set to `false`
  // This is because of the parser below, which compares the `$modelValue` with `trueValue` to convert
  // it to a boolean.
  ctrl.$isEmpty = function(value) {
    return value === false;
  };

  ctrl.$formatters.push(function(value) {
    return equals(value, trueValue);
  });

  ctrl.$parsers.push(function(value) {
    return value ? trueValue : falseValue;
  });
}


/**
 * @ngdoc directive
 * @name textarea
 * @restrict E
 *
 * @description
 * HTML textarea element control with angular data-binding. The data-binding and validation
 * properties of this element are exactly the same as those of the
 * {@link ng.directive:input input element}.
 *
 * @param {string} ngModel Assignable angular expression to data-bind to.
 * @param {string=} name Property name of the form under which the control is published.
 * @param {string=} required Sets `required` validation error key if the value is not entered.
 * @param {string=} ngRequired Adds `required` attribute and `required` validation constraint to
 *    the element when the ngRequired expression evaluates to true. Use `ngRequired` instead of
 *    `required` when you want to data-bind to the `required` attribute.
 * @param {number=} ngMinlength Sets `minlength` validation error key if the value is shorter than
 *    minlength.
 * @param {number=} ngMaxlength Sets `maxlength` validation error key if the value is longer than
 *    maxlength. Setting the attribute to a negative or non-numeric value, allows view values of any
 *    length.
 * @param {string=} ngPattern Sets `pattern` validation error key if the value does not match the
 *    RegExp pattern expression. Expected value is `/regexp/` for inline patterns or `regexp` for
 *    patterns defined as scope expressions.
 * @param {string=} ngChange Angular expression to be executed when input changes due to user
 *    interaction with the input element.
 * @param {boolean=} [ngTrim=true] If set to false Angular will not automatically trim the input.
 */


/**
 * @ngdoc directive
 * @name input
 * @restrict E
 *
 * @description
 * HTML input element control. When used together with {@link ngModel `ngModel`}, it provides data-binding,
 * input state control, and validation.
 * Input control follows HTML5 input types and polyfills the HTML5 validation behavior for older browsers.
 *
 * <div class="alert alert-warning">
 * **Note:** Not every feature offered is available for all input types.
 * Specifically, data binding and event handling via `ng-model` is unsupported for `input[file]`.
 * </div>
 *
 * @param {string} ngModel Assignable angular expression to data-bind to.
 * @param {string=} name Property name of the form under which the control is published.
 * @param {string=} required Sets `required` validation error key if the value is not entered.
 * @param {boolean=} ngRequired Sets `required` attribute if set to true
 * @param {number=} ngMinlength Sets `minlength` validation error key if the value is shorter than
 *    minlength.
 * @param {number=} ngMaxlength Sets `maxlength` validation error key if the value is longer than
 *    maxlength. Setting the attribute to a negative or non-numeric value, allows view values of any
 *    length.
 * @param {string=} ngPattern Sets `pattern` validation error key if the value does not match the
 *    RegExp pattern expression. Expected value is `/regexp/` for inline patterns or `regexp` for
 *    patterns defined as scope expressions.
 * @param {string=} ngChange Angular expression to be executed when input changes due to user
 *    interaction with the input element.
 * @param {boolean=} [ngTrim=true] If set to false Angular will not automatically trim the input.
 *    This parameter is ignored for input[type=password] controls, which will never trim the
 *    input.
 *
 * @example
    <example name="input-directive" module="inputExample">
      <file name="index.html">
       <script>
          angular.module('inputExample', [])
            .controller('ExampleController', ['$scope', function($scope) {
              $scope.user = {name: 'guest', last: 'visitor'};
            }]);
       </script>
       <div ng-controller="ExampleController">
         <form name="myForm">
           User name: <input type="text" name="userName" ng-model="user.name" required>
           <span class="error" ng-show="myForm.userName.$error.required">
             Required!</span><br>
           Last name: <input type="text" name="lastName" ng-model="user.last"
             ng-minlength="3" ng-maxlength="10">
           <span class="error" ng-show="myForm.lastName.$error.minlength">
             Too short!</span>
           <span class="error" ng-show="myForm.lastName.$error.maxlength">
             Too long!</span><br>
         </form>
         <hr>
         <tt>user = {{user}}</tt><br/>
         <tt>myForm.userName.$valid = {{myForm.userName.$valid}}</tt><br>
         <tt>myForm.userName.$error = {{myForm.userName.$error}}</tt><br>
         <tt>myForm.lastName.$valid = {{myForm.lastName.$valid}}</tt><br>
         <tt>myForm.lastName.$error = {{myForm.lastName.$error}}</tt><br>
         <tt>myForm.$valid = {{myForm.$valid}}</tt><br>
         <tt>myForm.$error.required = {{!!myForm.$error.required}}</tt><br>
         <tt>myForm.$error.minlength = {{!!myForm.$error.minlength}}</tt><br>
         <tt>myForm.$error.maxlength = {{!!myForm.$error.maxlength}}</tt><br>
       </div>
      </file>
      <file name="protractor.js" type="protractor">
        var user = element(by.exactBinding('user'));
        var userNameValid = element(by.binding('myForm.userName.$valid'));
        var lastNameValid = element(by.binding('myForm.lastName.$valid'));
        var lastNameError = element(by.binding('myForm.lastName.$error'));
        var formValid = element(by.binding('myForm.$valid'));
        var userNameInput = element(by.model('user.name'));
        var userLastInput = element(by.model('user.last'));

        it('should initialize to model', function() {
          expect(user.getText()).toContain('{"name":"guest","last":"visitor"}');
          expect(userNameValid.getText()).toContain('true');
          expect(formValid.getText()).toContain('true');
        });

        it('should be invalid if empty when required', function() {
          userNameInput.clear();
          userNameInput.sendKeys('');

          expect(user.getText()).toContain('{"last":"visitor"}');
          expect(userNameValid.getText()).toContain('false');
          expect(formValid.getText()).toContain('false');
        });

        it('should be valid if empty when min length is set', function() {
          userLastInput.clear();
          userLastInput.sendKeys('');

          expect(user.getText()).toContain('{"name":"guest","last":""}');
          expect(lastNameValid.getText()).toContain('true');
          expect(formValid.getText()).toContain('true');
        });

        it('should be invalid if less than required min length', function() {
          userLastInput.clear();
          userLastInput.sendKeys('xx');

          expect(user.getText()).toContain('{"name":"guest"}');
          expect(lastNameValid.getText()).toContain('false');
          expect(lastNameError.getText()).toContain('minlength');
          expect(formValid.getText()).toContain('false');
        });

        it('should be invalid if longer than max length', function() {
          userLastInput.clear();
          userLastInput.sendKeys('some ridiculously long name');

          expect(user.getText()).toContain('{"name":"guest"}');
          expect(lastNameValid.getText()).toContain('false');
          expect(lastNameError.getText()).toContain('maxlength');
          expect(formValid.getText()).toContain('false');
        });
      </file>
    </example>
 */
var inputDirective = ['$browser', '$sniffer', '$filter', '$parse',
    function($browser, $sniffer, $filter, $parse) {
  return {
    restrict: 'E',
    require: ['?ngModel'],
    link: {
      pre: function(scope, element, attr, ctrls) {
        if (ctrls[0]) {
          (inputType[lowercase(attr.type)] || inputType.text)(scope, element, attr, ctrls[0], $sniffer,
                                                              $browser, $filter, $parse);
        }
      }
    }
  };
}];



var CONSTANT_VALUE_REGEXP = /^(true|false|\d+)$/;
/**
 * @ngdoc directive
 * @name ngValue
 *
 * @description
 * Binds the given expression to the value of `<option>` or {@link input[radio] `input[radio]`},
 * so that when the element is selected, the {@link ngModel `ngModel`} of that element is set to
 * the bound value.
 *
 * `ngValue` is useful when dynamically generating lists of radio buttons using
 * {@link ngRepeat `ngRepeat`}, as shown below.
 *
 * Likewise, `ngValue` can be used to generate `<option>` elements for
 * the {@link select `select`} element. In that case however, only strings are supported
 * for the `value `attribute, so the resulting `ngModel` will always be a string.
 * Support for `select` models with non-string values is available via `ngOptions`.
 *
 * @element input
 * @param {string=} ngValue angular expression, whose value will be bound to the `value` attribute
 *   of the `input` element
 *
 * @example
    <example name="ngValue-directive" module="valueExample">
      <file name="index.html">
       <script>
          angular.module('valueExample', [])
            .controller('ExampleController', ['$scope', function($scope) {
              $scope.names = ['pizza', 'unicorns', 'robots'];
              $scope.my = { favorite: 'unicorns' };
            }]);
       </script>
        <form ng-controller="ExampleController">
          <h2>Which is your favorite?</h2>
            <label ng-repeat="name in names" for="{{name}}">
              {{name}}
              <input type="radio"
                     ng-model="my.favorite"
                     ng-value="name"
                     id="{{name}}"
                     name="favorite">
            </label>
          <div>You chose {{my.favorite}}</div>
        </form>
      </file>
      <file name="protractor.js" type="protractor">
        var favorite = element(by.binding('my.favorite'));

        it('should initialize to model', function() {
          expect(favorite.getText()).toContain('unicorns');
        });
        it('should bind the values to the inputs', function() {
          element.all(by.model('my.favorite')).get(0).click();
          expect(favorite.getText()).toContain('pizza');
        });
      </file>
    </example>
 */
var ngValueDirective = function() {
  return {
    restrict: 'A',
    priority: 100,
    compile: function(tpl, tplAttr) {
      if (CONSTANT_VALUE_REGEXP.test(tplAttr.ngValue)) {
        return function ngValueConstantLink(scope, elm, attr) {
          attr.$set('value', scope.$eval(attr.ngValue));
        };
      } else {
        return function ngValueLink(scope, elm, attr) {
          scope.$watch(attr.ngValue, function valueWatchAction(value) {
            attr.$set('value', value);
          });
        };
      }
    }
  };
};

/**
 * @ngdoc directive
 * @name ngBind
 * @restrict AC
 *
 * @description
 * The `ngBind` attribute tells Angular to replace the text content of the specified HTML element
 * with the value of a given expression, and to update the text content when the value of that
 * expression changes.
 *
 * Typically, you don't use `ngBind` directly, but instead you use the double curly markup like
 * `{{ expression }}` which is similar but less verbose.
 *
 * It is preferable to use `ngBind` instead of `{{ expression }}` if a template is momentarily
 * displayed by the browser in its raw state before Angular compiles it. Since `ngBind` is an
 * element attribute, it makes the bindings invisible to the user while the page is loading.
 *
 * An alternative solution to this problem would be using the
 * {@link ng.directive:ngCloak ngCloak} directive.
 *
 *
 * @element ANY
 * @param {expression} ngBind {@link guide/expression Expression} to evaluate.
 *
 * @example
 * Enter a name in the Live Preview text box; the greeting below the text box changes instantly.
   <example module="bindExample">
     <file name="index.html">
       <script>
         angular.module('bindExample', [])
           .controller('ExampleController', ['$scope', function($scope) {
             $scope.name = 'Whirled';
           }]);
       </script>
       <div ng-controller="ExampleController">
         Enter name: <input type="text" ng-model="name"><br>
         Hello <span ng-bind="name"></span>!
       </div>
     </file>
     <file name="protractor.js" type="protractor">
       it('should check ng-bind', function() {
         var nameInput = element(by.model('name'));

         expect(element(by.binding('name')).getText()).toBe('Whirled');
         nameInput.clear();
         nameInput.sendKeys('world');
         expect(element(by.binding('name')).getText()).toBe('world');
       });
     </file>
   </example>
 */
var ngBindDirective = ['$compile', function($compile) {
  return {
    restrict: 'AC',
    compile: function ngBindCompile(templateElement) {
      $compile.$$addBindingClass(templateElement);
      return function ngBindLink(scope, element, attr) {
        $compile.$$addBindingInfo(element, attr.ngBind);
        element = element[0];
        scope.$watch(attr.ngBind, function ngBindWatchAction(value) {
          element.textContent = value === undefined ? '' : value;
        });
      };
    }
  };
}];


/**
 * @ngdoc directive
 * @name ngBindTemplate
 *
 * @description
 * The `ngBindTemplate` directive specifies that the element
 * text content should be replaced with the interpolation of the template
 * in the `ngBindTemplate` attribute.
 * Unlike `ngBind`, the `ngBindTemplate` can contain multiple `{{` `}}`
 * expressions. This directive is needed since some HTML elements
 * (such as TITLE and OPTION) cannot contain SPAN elements.
 *
 * @element ANY
 * @param {string} ngBindTemplate template of form
 *   <tt>{{</tt> <tt>expression</tt> <tt>}}</tt> to eval.
 *
 * @example
 * Try it here: enter text in text box and watch the greeting change.
   <example module="bindExample">
     <file name="index.html">
       <script>
         angular.module('bindExample', [])
           .controller('ExampleController', ['$scope', function($scope) {
             $scope.salutation = 'Hello';
             $scope.name = 'World';
           }]);
       </script>
       <div ng-controller="ExampleController">
        Salutation: <input type="text" ng-model="salutation"><br>
        Name: <input type="text" ng-model="name"><br>
        <pre ng-bind-template="{{salutation}} {{name}}!"></pre>
       </div>
     </file>
     <file name="protractor.js" type="protractor">
       it('should check ng-bind', function() {
         var salutationElem = element(by.binding('salutation'));
         var salutationInput = element(by.model('salutation'));
         var nameInput = element(by.model('name'));

         expect(salutationElem.getText()).toBe('Hello World!');

         salutationInput.clear();
         salutationInput.sendKeys('Greetings');
         nameInput.clear();
         nameInput.sendKeys('user');

         expect(salutationElem.getText()).toBe('Greetings user!');
       });
     </file>
   </example>
 */
var ngBindTemplateDirective = ['$interpolate', '$compile', function($interpolate, $compile) {
  return {
    compile: function ngBindTemplateCompile(templateElement) {
      $compile.$$addBindingClass(templateElement);
      return function ngBindTemplateLink(scope, element, attr) {
        var interpolateFn = $interpolate(element.attr(attr.$attr.ngBindTemplate));
        $compile.$$addBindingInfo(element, interpolateFn.expressions);
        element = element[0];
        attr.$observe('ngBindTemplate', function(value) {
          element.textContent = value === undefined ? '' : value;
        });
      };
    }
  };
}];


/**
 * @ngdoc directive
 * @name ngBindHtml
 *
 * @description
 * Evaluates the expression and inserts the resulting HTML into the element in a secure way. By default,
 * the resulting HTML content will be sanitized using the {@link ngSanitize.$sanitize $sanitize} service.
 * To utilize this functionality, ensure that `$sanitize` is available, for example, by including {@link
 * ngSanitize} in your module's dependencies (not in core Angular). In order to use {@link ngSanitize}
 * in your module's dependencies, you need to include "angular-sanitize.js" in your application.
 *
 * You may also bypass sanitization for values you know are safe. To do so, bind to
 * an explicitly trusted value via {@link ng.$sce#trustAsHtml $sce.trustAsHtml}.  See the example
 * under {@link ng.$sce#show-me-an-example-using-sce- Strict Contextual Escaping (SCE)}.
 *
 * Note: If a `$sanitize` service is unavailable and the bound value isn't explicitly trusted, you
 * will have an exception (instead of an exploit.)
 *
 * @element ANY
 * @param {expression} ngBindHtml {@link guide/expression Expression} to evaluate.
 *
 * @example

   <example module="bindHtmlExample" deps="angular-sanitize.js">
     <file name="index.html">
       <div ng-controller="ExampleController">
        <p ng-bind-html="myHTML"></p>
       </div>
     </file>

     <file name="script.js">
       angular.module('bindHtmlExample', ['ngSanitize'])
         .controller('ExampleController', ['$scope', function($scope) {
           $scope.myHTML =
              'I am an <code>HTML</code>string with ' +
              '<a href="#">links!</a> and other <em>stuff</em>';
         }]);
     </file>

     <file name="protractor.js" type="protractor">
       it('should check ng-bind-html', function() {
         expect(element(by.binding('myHTML')).getText()).toBe(
             'I am an HTMLstring with links! and other stuff');
       });
     </file>
   </example>
 */
var ngBindHtmlDirective = ['$sce', '$parse', '$compile', function($sce, $parse, $compile) {
  return {
    restrict: 'A',
    compile: function ngBindHtmlCompile(tElement, tAttrs) {
      var ngBindHtmlGetter = $parse(tAttrs.ngBindHtml);
      var ngBindHtmlWatch = $parse(tAttrs.ngBindHtml, function getStringValue(value) {
        return (value || '').toString();
      });
      $compile.$$addBindingClass(tElement);

      return function ngBindHtmlLink(scope, element, attr) {
        $compile.$$addBindingInfo(element, attr.ngBindHtml);

        scope.$watch(ngBindHtmlWatch, function ngBindHtmlWatchAction() {
          // we re-evaluate the expr because we want a TrustedValueHolderType
          // for $sce, not a string
          element.html($sce.getTrustedHtml(ngBindHtmlGetter(scope)) || '');
        });
      };
    }
  };
}];

/**
 * @ngdoc directive
 * @name ngChange
 *
 * @description
 * Evaluate the given expression when the user changes the input.
 * The expression is evaluated immediately, unlike the JavaScript onchange event
 * which only triggers at the end of a change (usually, when the user leaves the
 * form element or presses the return key).
 *
 * The `ngChange` expression is only evaluated when a change in the input value causes
 * a new value to be committed to the model.
 *
 * It will not be evaluated:
 * * if the value returned from the `$parsers` transformation pipeline has not changed
 * * if the input has continued to be invalid since the model will stay `null`
 * * if the model is changed programmatically and not by a change to the input value
 *
 *
 * Note, this directive requires `ngModel` to be present.
 *
 * @element input
 * @param {expression} ngChange {@link guide/expression Expression} to evaluate upon change
 * in input value.
 *
 * @example
 * <example name="ngChange-directive" module="changeExample">
 *   <file name="index.html">
 *     <script>
 *       angular.module('changeExample', [])
 *         .controller('ExampleController', ['$scope', function($scope) {
 *           $scope.counter = 0;
 *           $scope.change = function() {
 *             $scope.counter++;
 *           };
 *         }]);
 *     </script>
 *     <div ng-controller="ExampleController">
 *       <input type="checkbox" ng-model="confirmed" ng-change="change()" id="ng-change-example1" />
 *       <input type="checkbox" ng-model="confirmed" id="ng-change-example2" />
 *       <label for="ng-change-example2">Confirmed</label><br />
 *       <tt>debug = {{confirmed}}</tt><br/>
 *       <tt>counter = {{counter}}</tt><br/>
 *     </div>
 *   </file>
 *   <file name="protractor.js" type="protractor">
 *     var counter = element(by.binding('counter'));
 *     var debug = element(by.binding('confirmed'));
 *
 *     it('should evaluate the expression if changing from view', function() {
 *       expect(counter.getText()).toContain('0');
 *
 *       element(by.id('ng-change-example1')).click();
 *
 *       expect(counter.getText()).toContain('1');
 *       expect(debug.getText()).toContain('true');
 *     });
 *
 *     it('should not evaluate the expression if changing from model', function() {
 *       element(by.id('ng-change-example2')).click();

 *       expect(counter.getText()).toContain('0');
 *       expect(debug.getText()).toContain('true');
 *     });
 *   </file>
 * </example>
 */
var ngChangeDirective = valueFn({
  restrict: 'A',
  require: 'ngModel',
  link: function(scope, element, attr, ctrl) {
    ctrl.$viewChangeListeners.push(function() {
      scope.$eval(attr.ngChange);
    });
  }
});

function classDirective(name, selector) {
  name = 'ngClass' + name;
  return ['$animate', function($animate) {
    return {
      restrict: 'AC',
      link: function(scope, element, attr) {
        var oldVal;

        scope.$watch(attr[name], ngClassWatchAction, true);

        attr.$observe('class', function(value) {
          ngClassWatchAction(scope.$eval(attr[name]));
        });


        if (name !== 'ngClass') {
          scope.$watch('$index', function($index, old$index) {
            // jshint bitwise: false
            var mod = $index & 1;
            if (mod !== (old$index & 1)) {
              var classes = arrayClasses(scope.$eval(attr[name]));
              mod === selector ?
                addClasses(classes) :
                removeClasses(classes);
            }
          });
        }

        function addClasses(classes) {
          var newClasses = digestClassCounts(classes, 1);
          attr.$addClass(newClasses);
        }

        function removeClasses(classes) {
          var newClasses = digestClassCounts(classes, -1);
          attr.$removeClass(newClasses);
        }

        function digestClassCounts(classes, count) {
          var classCounts = element.data('$classCounts') || {};
          var classesToUpdate = [];
          forEach(classes, function(className) {
            if (count > 0 || classCounts[className]) {
              classCounts[className] = (classCounts[className] || 0) + count;
              if (classCounts[className] === +(count > 0)) {
                classesToUpdate.push(className);
              }
            }
          });
          element.data('$classCounts', classCounts);
          return classesToUpdate.join(' ');
        }

        function updateClasses(oldClasses, newClasses) {
          var toAdd = arrayDifference(newClasses, oldClasses);
          var toRemove = arrayDifference(oldClasses, newClasses);
          toAdd = digestClassCounts(toAdd, 1);
          toRemove = digestClassCounts(toRemove, -1);
          if (toAdd && toAdd.length) {
            $animate.addClass(element, toAdd);
          }
          if (toRemove && toRemove.length) {
            $animate.removeClass(element, toRemove);
          }
        }

        function ngClassWatchAction(newVal) {
          if (selector === true || scope.$index % 2 === selector) {
            var newClasses = arrayClasses(newVal || []);
            if (!oldVal) {
              addClasses(newClasses);
            } else if (!equals(newVal,oldVal)) {
              var oldClasses = arrayClasses(oldVal);
              updateClasses(oldClasses, newClasses);
            }
          }
          oldVal = shallowCopy(newVal);
        }
      }
    };

    function arrayDifference(tokens1, tokens2) {
      var values = [];

      outer:
      for (var i = 0; i < tokens1.length; i++) {
        var token = tokens1[i];
        for (var j = 0; j < tokens2.length; j++) {
          if (token == tokens2[j]) continue outer;
        }
        values.push(token);
      }
      return values;
    }

    function arrayClasses(classVal) {
      if (isArray(classVal)) {
        return classVal;
      } else if (isString(classVal)) {
        return classVal.split(' ');
      } else if (isObject(classVal)) {
        var classes = [];
        forEach(classVal, function(v, k) {
          if (v) {
            classes = classes.concat(k.split(' '));
          }
        });
        return classes;
      }
      return classVal;
    }
  }];
}

/**
 * @ngdoc directive
 * @name ngClass
 * @restrict AC
 *
 * @description
 * The `ngClass` directive allows you to dynamically set CSS classes on an HTML element by databinding
 * an expression that represents all classes to be added.
 *
 * The directive operates in three different ways, depending on which of three types the expression
 * evaluates to:
 *
 * 1. If the expression evaluates to a string, the string should be one or more space-delimited class
 * names.
 *
 * 2. If the expression evaluates to an array, each element of the array should be a string that is
 * one or more space-delimited class names.
 *
 * 3. If the expression evaluates to an object, then for each key-value pair of the
 * object with a truthy value the corresponding key is used as a class name.
 *
 * The directive won't add duplicate classes if a particular class was already set.
 *
 * When the expression changes, the previously added classes are removed and only then the
 * new classes are added.
 *
 * @animations
 * **add** - happens just before the class is applied to the elements
 *
 * **remove** - happens just before the class is removed from the element
 *
 * @element ANY
 * @param {expression} ngClass {@link guide/expression Expression} to eval. The result
 *   of the evaluation can be a string representing space delimited class
 *   names, an array, or a map of class names to boolean values. In the case of a map, the
 *   names of the properties whose values are truthy will be added as css classes to the
 *   element.
 *
 * @example Example that demonstrates basic bindings via ngClass directive.
   <example>
     <file name="index.html">
       <p ng-class="{strike: deleted, bold: important, red: error}">Map Syntax Example</p>
       <input type="checkbox" ng-model="deleted"> deleted (apply "strike" class)<br>
       <input type="checkbox" ng-model="important"> important (apply "bold" class)<br>
       <input type="checkbox" ng-model="error"> error (apply "red" class)
       <hr>
       <p ng-class="style">Using String Syntax</p>
       <input type="text" ng-model="style" placeholder="Type: bold strike red">
       <hr>
       <p ng-class="[style1, style2, style3]">Using Array Syntax</p>
       <input ng-model="style1" placeholder="Type: bold, strike or red"><br>
       <input ng-model="style2" placeholder="Type: bold, strike or red"><br>
       <input ng-model="style3" placeholder="Type: bold, strike or red"><br>
     </file>
     <file name="style.css">
       .strike {
         text-decoration: line-through;
       }
       .bold {
           font-weight: bold;
       }
       .red {
           color: red;
       }
     </file>
     <file name="protractor.js" type="protractor">
       var ps = element.all(by.css('p'));

       it('should let you toggle the class', function() {

         expect(ps.first().getAttribute('class')).not.toMatch(/bold/);
         expect(ps.first().getAttribute('class')).not.toMatch(/red/);

         element(by.model('important')).click();
         expect(ps.first().getAttribute('class')).toMatch(/bold/);

         element(by.model('error')).click();
         expect(ps.first().getAttribute('class')).toMatch(/red/);
       });

       it('should let you toggle string example', function() {
         expect(ps.get(1).getAttribute('class')).toBe('');
         element(by.model('style')).clear();
         element(by.model('style')).sendKeys('red');
         expect(ps.get(1).getAttribute('class')).toBe('red');
       });

       it('array example should have 3 classes', function() {
         expect(ps.last().getAttribute('class')).toBe('');
         element(by.model('style1')).sendKeys('bold');
         element(by.model('style2')).sendKeys('strike');
         element(by.model('style3')).sendKeys('red');
         expect(ps.last().getAttribute('class')).toBe('bold strike red');
       });
     </file>
   </example>

   ## Animations

   The example below demonstrates how to perform animations using ngClass.

   <example module="ngAnimate" deps="angular-animate.js" animations="true">
     <file name="index.html">
      <input id="setbtn" type="button" value="set" ng-click="myVar='my-class'">
      <input id="clearbtn" type="button" value="clear" ng-click="myVar=''">
      <br>
      <span class="base-class" ng-class="myVar">Sample Text</span>
     </file>
     <file name="style.css">
       .base-class {
         -webkit-transition:all cubic-bezier(0.250, 0.460, 0.450, 0.940) 0.5s;
         transition:all cubic-bezier(0.250, 0.460, 0.450, 0.940) 0.5s;
       }

       .base-class.my-class {
         color: red;
         font-size:3em;
       }
     </file>
     <file name="protractor.js" type="protractor">
       it('should check ng-class', function() {
         expect(element(by.css('.base-class')).getAttribute('class')).not.
           toMatch(/my-class/);

         element(by.id('setbtn')).click();

         expect(element(by.css('.base-class')).getAttribute('class')).
           toMatch(/my-class/);

         element(by.id('clearbtn')).click();

         expect(element(by.css('.base-class')).getAttribute('class')).not.
           toMatch(/my-class/);
       });
     </file>
   </example>


   ## ngClass and pre-existing CSS3 Transitions/Animations
   The ngClass directive still supports CSS3 Transitions/Animations even if they do not follow the ngAnimate CSS naming structure.
   Upon animation ngAnimate will apply supplementary CSS classes to track the start and end of an animation, but this will not hinder
   any pre-existing CSS transitions already on the element. To get an idea of what happens during a class-based animation, be sure
   to view the step by step details of {@link ng.$animate#addClass $animate.addClass} and
   {@link ng.$animate#removeClass $animate.removeClass}.
 */
var ngClassDirective = classDirective('', true);

/**
 * @ngdoc directive
 * @name ngClassOdd
 * @restrict AC
 *
 * @description
 * The `ngClassOdd` and `ngClassEven` directives work exactly as
 * {@link ng.directive:ngClass ngClass}, except they work in
 * conjunction with `ngRepeat` and take effect only on odd (even) rows.
 *
 * This directive can be applied only within the scope of an
 * {@link ng.directive:ngRepeat ngRepeat}.
 *
 * @element ANY
 * @param {expression} ngClassOdd {@link guide/expression Expression} to eval. The result
 *   of the evaluation can be a string representing space delimited class names or an array.
 *
 * @example
   <example>
     <file name="index.html">
        <ol ng-init="names=['John', 'Mary', 'Cate', 'Suz']">
          <li ng-repeat="name in names">
           <span ng-class-odd="'odd'" ng-class-even="'even'">
             {{name}}
           </span>
          </li>
        </ol>
     </file>
     <file name="style.css">
       .odd {
         color: red;
       }
       .even {
         color: blue;
       }
     </file>
     <file name="protractor.js" type="protractor">
       it('should check ng-class-odd and ng-class-even', function() {
         expect(element(by.repeater('name in names').row(0).column('name')).getAttribute('class')).
           toMatch(/odd/);
         expect(element(by.repeater('name in names').row(1).column('name')).getAttribute('class')).
           toMatch(/even/);
       });
     </file>
   </example>
 */
var ngClassOddDirective = classDirective('Odd', 0);

/**
 * @ngdoc directive
 * @name ngClassEven
 * @restrict AC
 *
 * @description
 * The `ngClassOdd` and `ngClassEven` directives work exactly as
 * {@link ng.directive:ngClass ngClass}, except they work in
 * conjunction with `ngRepeat` and take effect only on odd (even) rows.
 *
 * This directive can be applied only within the scope of an
 * {@link ng.directive:ngRepeat ngRepeat}.
 *
 * @element ANY
 * @param {expression} ngClassEven {@link guide/expression Expression} to eval. The
 *   result of the evaluation can be a string representing space delimited class names or an array.
 *
 * @example
   <example>
     <file name="index.html">
        <ol ng-init="names=['John', 'Mary', 'Cate', 'Suz']">
          <li ng-repeat="name in names">
           <span ng-class-odd="'odd'" ng-class-even="'even'">
             {{name}} &nbsp; &nbsp; &nbsp;
           </span>
          </li>
        </ol>
     </file>
     <file name="style.css">
       .odd {
         color: red;
       }
       .even {
         color: blue;
       }
     </file>
     <file name="protractor.js" type="protractor">
       it('should check ng-class-odd and ng-class-even', function() {
         expect(element(by.repeater('name in names').row(0).column('name')).getAttribute('class')).
           toMatch(/odd/);
         expect(element(by.repeater('name in names').row(1).column('name')).getAttribute('class')).
           toMatch(/even/);
       });
     </file>
   </example>
 */
var ngClassEvenDirective = classDirective('Even', 1);

/**
 * @ngdoc directive
 * @name ngCloak
 * @restrict AC
 *
 * @description
 * The `ngCloak` directive is used to prevent the Angular html template from being briefly
 * displayed by the browser in its raw (uncompiled) form while your application is loading. Use this
 * directive to avoid the undesirable flicker effect caused by the html template display.
 *
 * The directive can be applied to the `<body>` element, but the preferred usage is to apply
 * multiple `ngCloak` directives to small portions of the page to permit progressive rendering
 * of the browser view.
 *
 * `ngCloak` works in cooperation with the following css rule embedded within `angular.js` and
 * `angular.min.js`.
 * For CSP mode please add `angular-csp.css` to your html file (see {@link ng.directive:ngCsp ngCsp}).
 *
 * ```css
 * [ng\:cloak], [ng-cloak], [data-ng-cloak], [x-ng-cloak], .ng-cloak, .x-ng-cloak {
 *   display: none !important;
 * }
 * ```
 *
 * When this css rule is loaded by the browser, all html elements (including their children) that
 * are tagged with the `ngCloak` directive are hidden. When Angular encounters this directive
 * during the compilation of the template it deletes the `ngCloak` element attribute, making
 * the compiled element visible.
 *
 * For the best result, the `angular.js` script must be loaded in the head section of the html
 * document; alternatively, the css rule above must be included in the external stylesheet of the
 * application.
 *
 * @element ANY
 *
 * @example
   <example>
     <file name="index.html">
        <div id="template1" ng-cloak>{{ 'hello' }}</div>
        <div id="template2" class="ng-cloak">{{ 'world' }}</div>
     </file>
     <file name="protractor.js" type="protractor">
       it('should remove the template directive and css class', function() {
         expect($('#template1').getAttribute('ng-cloak')).
           toBeNull();
         expect($('#template2').getAttribute('ng-cloak')).
           toBeNull();
       });
     </file>
   </example>
 *
 */
var ngCloakDirective = ngDirective({
  compile: function(element, attr) {
    attr.$set('ngCloak', undefined);
    element.removeClass('ng-cloak');
  }
});

/**
 * @ngdoc directive
 * @name ngController
 *
 * @description
 * The `ngController` directive attaches a controller class to the view. This is a key aspect of how angular
 * supports the principles behind the Model-View-Controller design pattern.
 *
 * MVC components in angular:
 *
 * * Model — Models are the properties of a scope; scopes are attached to the DOM where scope properties
 *   are accessed through bindings.
 * * View — The template (HTML with data bindings) that is rendered into the View.
 * * Controller — The `ngController` directive specifies a Controller class; the class contains business
 *   logic behind the application to decorate the scope with functions and values
 *
 * Note that you can also attach controllers to the DOM by declaring it in a route definition
 * via the {@link ngRoute.$route $route} service. A common mistake is to declare the controller
 * again using `ng-controller` in the template itself.  This will cause the controller to be attached
 * and executed twice.
 *
 * @element ANY
 * @scope
 * @priority 500
 * @param {expression} ngController Name of a constructor function registered with the current
 * {@link ng.$controllerProvider $controllerProvider} or an {@link guide/expression expression}
 * that on the current scope evaluates to a constructor function.
 *
 * The controller instance can be published into a scope property by specifying
 * `ng-controller="as propertyName"`.
 *
 * If the current `$controllerProvider` is configured to use globals (via
 * {@link ng.$controllerProvider#allowGlobals `$controllerProvider.allowGlobals()` }), this may
 * also be the name of a globally accessible constructor function (not recommended).
 *
 * @example
 * Here is a simple form for editing user contact information. Adding, removing, clearing, and
 * greeting are methods declared on the controller (see source tab). These methods can
 * easily be called from the angular markup. Any changes to the data are automatically reflected
 * in the View without the need for a manual update.
 *
 * Two different declaration styles are included below:
 *
 * * one binds methods and properties directly onto the controller using `this`:
 * `ng-controller="SettingsController1 as settings"`
 * * one injects `$scope` into the controller:
 * `ng-controller="SettingsController2"`
 *
 * The second option is more common in the Angular community, and is generally used in boilerplates
 * and in this guide. However, there are advantages to binding properties directly to the controller
 * and avoiding scope.
 *
 * * Using `controller as` makes it obvious which controller you are accessing in the template when
 * multiple controllers apply to an element.
 * * If you are writing your controllers as classes you have easier access to the properties and
 * methods, which will appear on the scope, from inside the controller code.
 * * Since there is always a `.` in the bindings, you don't have to worry about prototypal
 * inheritance masking primitives.
 *
 * This example demonstrates the `controller as` syntax.
 *
 * <example name="ngControllerAs" module="controllerAsExample">
 *   <file name="index.html">
 *    <div id="ctrl-as-exmpl" ng-controller="SettingsController1 as settings">
 *      Name: <input type="text" ng-model="settings.name"/>
 *      [ <a href="" ng-click="settings.greet()">greet</a> ]<br/>
 *      Contact:
 *      <ul>
 *        <li ng-repeat="contact in settings.contacts">
 *          <select ng-model="contact.type">
 *             <option>phone</option>
 *             <option>email</option>
 *          </select>
 *          <input type="text" ng-model="contact.value"/>
 *          [ <a href="" ng-click="settings.clearContact(contact)">clear</a>
 *          | <a href="" ng-click="settings.removeContact(contact)">X</a> ]
 *        </li>
 *        <li>[ <a href="" ng-click="settings.addContact()">add</a> ]</li>
 *     </ul>
 *    </div>
 *   </file>
 *   <file name="app.js">
 *    angular.module('controllerAsExample', [])
 *      .controller('SettingsController1', SettingsController1);
 *
 *    function SettingsController1() {
 *      this.name = "John Smith";
 *      this.contacts = [
 *        {type: 'phone', value: '408 555 1212'},
 *        {type: 'email', value: 'john.smith@example.org'} ];
 *    }
 *
 *    SettingsController1.prototype.greet = function() {
 *      alert(this.name);
 *    };
 *
 *    SettingsController1.prototype.addContact = function() {
 *      this.contacts.push({type: 'email', value: 'yourname@example.org'});
 *    };
 *
 *    SettingsController1.prototype.removeContact = function(contactToRemove) {
 *     var index = this.contacts.indexOf(contactToRemove);
 *      this.contacts.splice(index, 1);
 *    };
 *
 *    SettingsController1.prototype.clearContact = function(contact) {
 *      contact.type = 'phone';
 *      contact.value = '';
 *    };
 *   </file>
 *   <file name="protractor.js" type="protractor">
 *     it('should check controller as', function() {
 *       var container = element(by.id('ctrl-as-exmpl'));
 *         expect(container.element(by.model('settings.name'))
 *           .getAttribute('value')).toBe('John Smith');
 *
 *       var firstRepeat =
 *           container.element(by.repeater('contact in settings.contacts').row(0));
 *       var secondRepeat =
 *           container.element(by.repeater('contact in settings.contacts').row(1));
 *
 *       expect(firstRepeat.element(by.model('contact.value')).getAttribute('value'))
 *           .toBe('408 555 1212');
 *
 *       expect(secondRepeat.element(by.model('contact.value')).getAttribute('value'))
 *           .toBe('john.smith@example.org');
 *
 *       firstRepeat.element(by.linkText('clear')).click();
 *
 *       expect(firstRepeat.element(by.model('contact.value')).getAttribute('value'))
 *           .toBe('');
 *
 *       container.element(by.linkText('add')).click();
 *
 *       expect(container.element(by.repeater('contact in settings.contacts').row(2))
 *           .element(by.model('contact.value'))
 *           .getAttribute('value'))
 *           .toBe('yourname@example.org');
 *     });
 *   </file>
 * </example>
 *
 * This example demonstrates the "attach to `$scope`" style of controller.
 *
 * <example name="ngController" module="controllerExample">
 *  <file name="index.html">
 *   <div id="ctrl-exmpl" ng-controller="SettingsController2">
 *     Name: <input type="text" ng-model="name"/>
 *     [ <a href="" ng-click="greet()">greet</a> ]<br/>
 *     Contact:
 *     <ul>
 *       <li ng-repeat="contact in contacts">
 *         <select ng-model="contact.type">
 *            <option>phone</option>
 *            <option>email</option>
 *         </select>
 *         <input type="text" ng-model="contact.value"/>
 *         [ <a href="" ng-click="clearContact(contact)">clear</a>
 *         | <a href="" ng-click="removeContact(contact)">X</a> ]
 *       </li>
 *       <li>[ <a href="" ng-click="addContact()">add</a> ]</li>
 *    </ul>
 *   </div>
 *  </file>
 *  <file name="app.js">
 *   angular.module('controllerExample', [])
 *     .controller('SettingsController2', ['$scope', SettingsController2]);
 *
 *   function SettingsController2($scope) {
 *     $scope.name = "John Smith";
 *     $scope.contacts = [
 *       {type:'phone', value:'408 555 1212'},
 *       {type:'email', value:'john.smith@example.org'} ];
 *
 *     $scope.greet = function() {
 *       alert($scope.name);
 *     };
 *
 *     $scope.addContact = function() {
 *       $scope.contacts.push({type:'email', value:'yourname@example.org'});
 *     };
 *
 *     $scope.removeContact = function(contactToRemove) {
 *       var index = $scope.contacts.indexOf(contactToRemove);
 *       $scope.contacts.splice(index, 1);
 *     };
 *
 *     $scope.clearContact = function(contact) {
 *       contact.type = 'phone';
 *       contact.value = '';
 *     };
 *   }
 *  </file>
 *  <file name="protractor.js" type="protractor">
 *    it('should check controller', function() {
 *      var container = element(by.id('ctrl-exmpl'));
 *
 *      expect(container.element(by.model('name'))
 *          .getAttribute('value')).toBe('John Smith');
 *
 *      var firstRepeat =
 *          container.element(by.repeater('contact in contacts').row(0));
 *      var secondRepeat =
 *          container.element(by.repeater('contact in contacts').row(1));
 *
 *      expect(firstRepeat.element(by.model('contact.value')).getAttribute('value'))
 *          .toBe('408 555 1212');
 *      expect(secondRepeat.element(by.model('contact.value')).getAttribute('value'))
 *          .toBe('john.smith@example.org');
 *
 *      firstRepeat.element(by.linkText('clear')).click();
 *
 *      expect(firstRepeat.element(by.model('contact.value')).getAttribute('value'))
 *          .toBe('');
 *
 *      container.element(by.linkText('add')).click();
 *
 *      expect(container.element(by.repeater('contact in contacts').row(2))
 *          .element(by.model('contact.value'))
 *          .getAttribute('value'))
 *          .toBe('yourname@example.org');
 *    });
 *  </file>
 *</example>

 */
var ngControllerDirective = [function() {
  return {
    restrict: 'A',
    scope: true,
    controller: '@',
    priority: 500
  };
}];

/**
 * @ngdoc directive
 * @name ngCsp
 *
 * @element html
 * @description
 * Enables [CSP (Content Security Policy)](https://developer.mozilla.org/en/Security/CSP) support.
 *
 * This is necessary when developing things like Google Chrome Extensions or Universal Windows Apps.
 *
 * CSP forbids apps to use `eval` or `Function(string)` generated functions (among other things).
 * For Angular to be CSP compatible there are only two things that we need to do differently:
 *
 * - don't use `Function` constructor to generate optimized value getters
 * - don't inject custom stylesheet into the document
 *
 * AngularJS uses `Function(string)` generated functions as a speed optimization. Applying the `ngCsp`
 * directive will cause Angular to use CSP compatibility mode. When this mode is on AngularJS will
 * evaluate all expressions up to 30% slower than in non-CSP mode, but no security violations will
 * be raised.
 *
 * CSP forbids JavaScript to inline stylesheet rules. In non CSP mode Angular automatically
 * includes some CSS rules (e.g. {@link ng.directive:ngCloak ngCloak}).
 * To make those directives work in CSP mode, include the `angular-csp.css` manually.
 *
 * Angular tries to autodetect if CSP is active and automatically turn on the CSP-safe mode. This
 * autodetection however triggers a CSP error to be logged in the console:
 *
 * ```
 * Refused to evaluate a string as JavaScript because 'unsafe-eval' is not an allowed source of
 * script in the following Content Security Policy directive: "default-src 'self'". Note that
 * 'script-src' was not explicitly set, so 'default-src' is used as a fallback.
 * ```
 *
 * This error is harmless but annoying. To prevent the error from showing up, put the `ngCsp`
 * directive on the root element of the application or on the `angular.js` script tag, whichever
 * appears first in the html document.
 *
 * *Note: This directive is only available in the `ng-csp` and `data-ng-csp` attribute form.*
 *
 * @example
 * This example shows how to apply the `ngCsp` directive to the `html` tag.
   ```html
     <!doctype html>
     <html ng-app ng-csp>
     ...
     ...
     </html>
   ```
  * @example
      // Note: the suffix `.csp` in the example name triggers
      // csp mode in our http server!
      <example name="example.csp" module="cspExample" ng-csp="true">
        <file name="index.html">
          <div ng-controller="MainController as ctrl">
            <div>
              <button ng-click="ctrl.inc()" id="inc">Increment</button>
              <span id="counter">
                {{ctrl.counter}}
              </span>
            </div>

            <div>
              <button ng-click="ctrl.evil()" id="evil">Evil</button>
              <span id="evilError">
                {{ctrl.evilError}}
              </span>
            </div>
          </div>
        </file>
        <file name="script.js">
           angular.module('cspExample', [])
             .controller('MainController', function() {
                this.counter = 0;
                this.inc = function() {
                  this.counter++;
                };
                this.evil = function() {
                  // jshint evil:true
                  try {
                    eval('1+2');
                  } catch (e) {
                    this.evilError = e.message;
                  }
                };
              });
        </file>
        <file name="protractor.js" type="protractor">
          var util, webdriver;

          var incBtn = element(by.id('inc'));
          var counter = element(by.id('counter'));
          var evilBtn = element(by.id('evil'));
          var evilError = element(by.id('evilError'));

          function getAndClearSevereErrors() {
            return browser.manage().logs().get('browser').then(function(browserLog) {
              return browserLog.filter(function(logEntry) {
                return logEntry.level.value > webdriver.logging.Level.WARNING.value;
              });
            });
          }

          function clearErrors() {
            getAndClearSevereErrors();
          }

          function expectNoErrors() {
            getAndClearSevereErrors().then(function(filteredLog) {
              expect(filteredLog.length).toEqual(0);
              if (filteredLog.length) {
                console.log('browser console errors: ' + util.inspect(filteredLog));
              }
            });
          }

          function expectError(regex) {
            getAndClearSevereErrors().then(function(filteredLog) {
              var found = false;
              filteredLog.forEach(function(log) {
                if (log.message.match(regex)) {
                  found = true;
                }
              });
              if (!found) {
                throw new Error('expected an error that matches ' + regex);
              }
            });
          }

          beforeEach(function() {
            util = require('util');
            webdriver = require('protractor/node_modules/selenium-webdriver');
          });

          // For now, we only test on Chrome,
          // as Safari does not load the page with Protractor's injected scripts,
          // and Firefox webdriver always disables content security policy (#6358)
          if (browser.params.browser !== 'chrome') {
            return;
          }

          it('should not report errors when the page is loaded', function() {
            // clear errors so we are not dependent on previous tests
            clearErrors();
            // Need to reload the page as the page is already loaded when
            // we come here
            browser.driver.getCurrentUrl().then(function(url) {
              browser.get(url);
            });
            expectNoErrors();
          });

          it('should evaluate expressions', function() {
            expect(counter.getText()).toEqual('0');
            incBtn.click();
            expect(counter.getText()).toEqual('1');
            expectNoErrors();
          });

          it('should throw and report an error when using "eval"', function() {
            evilBtn.click();
            expect(evilError.getText()).toMatch(/Content Security Policy/);
            expectError(/Content Security Policy/);
          });
        </file>
      </example>
  */

// ngCsp is not implemented as a proper directive any more, because we need it be processed while we
// bootstrap the system (before $parse is instantiated), for this reason we just have
// the csp.isActive() fn that looks for ng-csp attribute anywhere in the current doc

/**
 * @ngdoc directive
 * @name ngClick
 *
 * @description
 * The ngClick directive allows you to specify custom behavior when
 * an element is clicked.
 *
 * @element ANY
 * @priority 0
 * @param {expression} ngClick {@link guide/expression Expression} to evaluate upon
 * click. ({@link guide/expression#-event- Event object is available as `$event`})
 *
 * @example
   <example>
     <file name="index.html">
      <button ng-click="count = count + 1" ng-init="count=0">
        Increment
      </button>
      <span>
        count: {{count}}
      </span>
     </file>
     <file name="protractor.js" type="protractor">
       it('should check ng-click', function() {
         expect(element(by.binding('count')).getText()).toMatch('0');
         element(by.css('button')).click();
         expect(element(by.binding('count')).getText()).toMatch('1');
       });
     </file>
   </example>
 */
/*
 * A collection of directives that allows creation of custom event handlers that are defined as
 * angular expressions and are compiled and executed within the current scope.
 */
var ngEventDirectives = {};

// For events that might fire synchronously during DOM manipulation
// we need to execute their event handlers asynchronously using $evalAsync,
// so that they are not executed in an inconsistent state.
var forceAsyncEvents = {
  'blur': true,
  'focus': true
};
forEach(
  'click dblclick mousedown mouseup mouseover mouseout mousemove mouseenter mouseleave keydown keyup keypress submit focus blur copy cut paste'.split(' '),
  function(eventName) {
    var directiveName = directiveNormalize('ng-' + eventName);
    ngEventDirectives[directiveName] = ['$parse', '$rootScope', function($parse, $rootScope) {
      return {
        restrict: 'A',
        compile: function($element, attr) {
          // We expose the powerful $event object on the scope that provides access to the Window,
          // etc. that isn't protected by the fast paths in $parse.  We explicitly request better
          // checks at the cost of speed since event handler expressions are not executed as
          // frequently as regular change detection.
          var fn = $parse(attr[directiveName], /* interceptorFn */ null, /* expensiveChecks */ true);
          return function ngEventHandler(scope, element) {
            element.on(eventName, function(event) {
              var callback = function() {
                fn(scope, {$event:event});
              };
              if (forceAsyncEvents[eventName] && $rootScope.$$phase) {
                scope.$evalAsync(callback);
              } else {
                scope.$apply(callback);
              }
            });
          };
        }
      };
    }];
  }
);

/**
 * @ngdoc directive
 * @name ngDblclick
 *
 * @description
 * The `ngDblclick` directive allows you to specify custom behavior on a dblclick event.
 *
 * @element ANY
 * @priority 0
 * @param {expression} ngDblclick {@link guide/expression Expression} to evaluate upon
 * a dblclick. (The Event object is available as `$event`)
 *
 * @example
   <example>
     <file name="index.html">
      <button ng-dblclick="count = count + 1" ng-init="count=0">
        Increment (on double click)
      </button>
      count: {{count}}
     </file>
   </example>
 */


/**
 * @ngdoc directive
 * @name ngMousedown
 *
 * @description
 * The ngMousedown directive allows you to specify custom behavior on mousedown event.
 *
 * @element ANY
 * @priority 0
 * @param {expression} ngMousedown {@link guide/expression Expression} to evaluate upon
 * mousedown. ({@link guide/expression#-event- Event object is available as `$event`})
 *
 * @example
   <example>
     <file name="index.html">
      <button ng-mousedown="count = count + 1" ng-init="count=0">
        Increment (on mouse down)
      </button>
      count: {{count}}
     </file>
   </example>
 */


/**
 * @ngdoc directive
 * @name ngMouseup
 *
 * @description
 * Specify custom behavior on mouseup event.
 *
 * @element ANY
 * @priority 0
 * @param {expression} ngMouseup {@link guide/expression Expression} to evaluate upon
 * mouseup. ({@link guide/expression#-event- Event object is available as `$event`})
 *
 * @example
   <example>
     <file name="index.html">
      <button ng-mouseup="count = count + 1" ng-init="count=0">
        Increment (on mouse up)
      </button>
      count: {{count}}
     </file>
   </example>
 */

/**
 * @ngdoc directive
 * @name ngMouseover
 *
 * @description
 * Specify custom behavior on mouseover event.
 *
 * @element ANY
 * @priority 0
 * @param {expression} ngMouseover {@link guide/expression Expression} to evaluate upon
 * mouseover. ({@link guide/expression#-event- Event object is available as `$event`})
 *
 * @example
   <example>
     <file name="index.html">
      <button ng-mouseover="count = count + 1" ng-init="count=0">
        Increment (when mouse is over)
      </button>
      count: {{count}}
     </file>
   </example>
 */


/**
 * @ngdoc directive
 * @name ngMouseenter
 *
 * @description
 * Specify custom behavior on mouseenter event.
 *
 * @element ANY
 * @priority 0
 * @param {expression} ngMouseenter {@link guide/expression Expression} to evaluate upon
 * mouseenter. ({@link guide/expression#-event- Event object is available as `$event`})
 *
 * @example
   <example>
     <file name="index.html">
      <button ng-mouseenter="count = count + 1" ng-init="count=0">
        Increment (when mouse enters)
      </button>
      count: {{count}}
     </file>
   </example>
 */


/**
 * @ngdoc directive
 * @name ngMouseleave
 *
 * @description
 * Specify custom behavior on mouseleave event.
 *
 * @element ANY
 * @priority 0
 * @param {expression} ngMouseleave {@link guide/expression Expression} to evaluate upon
 * mouseleave. ({@link guide/expression#-event- Event object is available as `$event`})
 *
 * @example
   <example>
     <file name="index.html">
      <button ng-mouseleave="count = count + 1" ng-init="count=0">
        Increment (when mouse leaves)
      </button>
      count: {{count}}
     </file>
   </example>
 */


/**
 * @ngdoc directive
 * @name ngMousemove
 *
 * @description
 * Specify custom behavior on mousemove event.
 *
 * @element ANY
 * @priority 0
 * @param {expression} ngMousemove {@link guide/expression Expression} to evaluate upon
 * mousemove. ({@link guide/expression#-event- Event object is available as `$event`})
 *
 * @example
   <example>
     <file name="index.html">
      <button ng-mousemove="count = count + 1" ng-init="count=0">
        Increment (when mouse moves)
      </button>
      count: {{count}}
     </file>
   </example>
 */


/**
 * @ngdoc directive
 * @name ngKeydown
 *
 * @description
 * Specify custom behavior on keydown event.
 *
 * @element ANY
 * @priority 0
 * @param {expression} ngKeydown {@link guide/expression Expression} to evaluate upon
 * keydown. (Event object is available as `$event` and can be interrogated for keyCode, altKey, etc.)
 *
 * @example
   <example>
     <file name="index.html">
      <input ng-keydown="count = count + 1" ng-init="count=0">
      key down count: {{count}}
     </file>
   </example>
 */


/**
 * @ngdoc directive
 * @name ngKeyup
 *
 * @description
 * Specify custom behavior on keyup event.
 *
 * @element ANY
 * @priority 0
 * @param {expression} ngKeyup {@link guide/expression Expression} to evaluate upon
 * keyup. (Event object is available as `$event` and can be interrogated for keyCode, altKey, etc.)
 *
 * @example
   <example>
     <file name="index.html">
       <p>Typing in the input box below updates the key count</p>
       <input ng-keyup="count = count + 1" ng-init="count=0"> key up count: {{count}}

       <p>Typing in the input box below updates the keycode</p>
       <input ng-keyup="event=$event">
       <p>event keyCode: {{ event.keyCode }}</p>
       <p>event altKey: {{ event.altKey }}</p>
     </file>
   </example>
 */


/**
 * @ngdoc directive
 * @name ngKeypress
 *
 * @description
 * Specify custom behavior on keypress event.
 *
 * @element ANY
 * @param {expression} ngKeypress {@link guide/expression Expression} to evaluate upon
 * keypress. ({@link guide/expression#-event- Event object is available as `$event`}
 * and can be interrogated for keyCode, altKey, etc.)
 *
 * @example
   <example>
     <file name="index.html">
      <input ng-keypress="count = count + 1" ng-init="count=0">
      key press count: {{count}}
     </file>
   </example>
 */


/**
 * @ngdoc directive
 * @name ngSubmit
 *
 * @description
 * Enables binding angular expressions to onsubmit events.
 *
 * Additionally it prevents the default action (which for form means sending the request to the
 * server and reloading the current page), but only if the form does not contain `action`,
 * `data-action`, or `x-action` attributes.
 *
 * <div class="alert alert-warning">
 * **Warning:** Be careful not to cause "double-submission" by using both the `ngClick` and
 * `ngSubmit` handlers together. See the
 * {@link form#submitting-a-form-and-preventing-the-default-action `form` directive documentation}
 * for a detailed discussion of when `ngSubmit` may be triggered.
 * </div>
 *
 * @element form
 * @priority 0
 * @param {expression} ngSubmit {@link guide/expression Expression} to eval.
 * ({@link guide/expression#-event- Event object is available as `$event`})
 *
 * @example
   <example module="submitExample">
     <file name="index.html">
      <script>
        angular.module('submitExample', [])
          .controller('ExampleController', ['$scope', function($scope) {
            $scope.list = [];
            $scope.text = 'hello';
            $scope.submit = function() {
              if ($scope.text) {
                $scope.list.push(this.text);
                $scope.text = '';
              }
            };
          }]);
      </script>
      <form ng-submit="submit()" ng-controller="ExampleController">
        Enter text and hit enter:
        <input type="text" ng-model="text" name="text" />
        <input type="submit" id="submit" value="Submit" />
        <pre>list={{list}}</pre>
      </form>
     </file>
     <file name="protractor.js" type="protractor">
       it('should check ng-submit', function() {
         expect(element(by.binding('list')).getText()).toBe('list=[]');
         element(by.css('#submit')).click();
         expect(element(by.binding('list')).getText()).toContain('hello');
         expect(element(by.model('text')).getAttribute('value')).toBe('');
       });
       it('should ignore empty strings', function() {
         expect(element(by.binding('list')).getText()).toBe('list=[]');
         element(by.css('#submit')).click();
         element(by.css('#submit')).click();
         expect(element(by.binding('list')).getText()).toContain('hello');
        });
     </file>
   </example>
 */

/**
 * @ngdoc directive
 * @name ngFocus
 *
 * @description
 * Specify custom behavior on focus event.
 *
 * Note: As the `focus` event is executed synchronously when calling `input.focus()`
 * AngularJS executes the expression using `scope.$evalAsync` if the event is fired
 * during an `$apply` to ensure a consistent state.
 *
 * @element window, input, select, textarea, a
 * @priority 0
 * @param {expression} ngFocus {@link guide/expression Expression} to evaluate upon
 * focus. ({@link guide/expression#-event- Event object is available as `$event`})
 *
 * @example
 * See {@link ng.directive:ngClick ngClick}
 */

/**
 * @ngdoc directive
 * @name ngBlur
 *
 * @description
 * Specify custom behavior on blur event.
 *
 * A [blur event](https://developer.mozilla.org/en-US/docs/Web/Events/blur) fires when
 * an element has lost focus.
 *
 * Note: As the `blur` event is executed synchronously also during DOM manipulations
 * (e.g. removing a focussed input),
 * AngularJS executes the expression using `scope.$evalAsync` if the event is fired
 * during an `$apply` to ensure a consistent state.
 *
 * @element window, input, select, textarea, a
 * @priority 0
 * @param {expression} ngBlur {@link guide/expression Expression} to evaluate upon
 * blur. ({@link guide/expression#-event- Event object is available as `$event`})
 *
 * @example
 * See {@link ng.directive:ngClick ngClick}
 */

/**
 * @ngdoc directive
 * @name ngCopy
 *
 * @description
 * Specify custom behavior on copy event.
 *
 * @element window, input, select, textarea, a
 * @priority 0
 * @param {expression} ngCopy {@link guide/expression Expression} to evaluate upon
 * copy. ({@link guide/expression#-event- Event object is available as `$event`})
 *
 * @example
   <example>
     <file name="index.html">
      <input ng-copy="copied=true" ng-init="copied=false; value='copy me'" ng-model="value">
      copied: {{copied}}
     </file>
   </example>
 */

/**
 * @ngdoc directive
 * @name ngCut
 *
 * @description
 * Specify custom behavior on cut event.
 *
 * @element window, input, select, textarea, a
 * @priority 0
 * @param {expression} ngCut {@link guide/expression Expression} to evaluate upon
 * cut. ({@link guide/expression#-event- Event object is available as `$event`})
 *
 * @example
   <example>
     <file name="index.html">
      <input ng-cut="cut=true" ng-init="cut=false; value='cut me'" ng-model="value">
      cut: {{cut}}
     </file>
   </example>
 */

/**
 * @ngdoc directive
 * @name ngPaste
 *
 * @description
 * Specify custom behavior on paste event.
 *
 * @element window, input, select, textarea, a
 * @priority 0
 * @param {expression} ngPaste {@link guide/expression Expression} to evaluate upon
 * paste. ({@link guide/expression#-event- Event object is available as `$event`})
 *
 * @example
   <example>
     <file name="index.html">
      <input ng-paste="paste=true" ng-init="paste=false" placeholder='paste here'>
      pasted: {{paste}}
     </file>
   </example>
 */

/**
 * @ngdoc directive
 * @name ngIf
 * @restrict A
 *
 * @description
 * The `ngIf` directive removes or recreates a portion of the DOM tree based on an
 * {expression}. If the expression assigned to `ngIf` evaluates to a false
 * value then the element is removed from the DOM, otherwise a clone of the
 * element is reinserted into the DOM.
 *
 * `ngIf` differs from `ngShow` and `ngHide` in that `ngIf` completely removes and recreates the
 * element in the DOM rather than changing its visibility via the `display` css property.  A common
 * case when this difference is significant is when using css selectors that rely on an element's
 * position within the DOM, such as the `:first-child` or `:last-child` pseudo-classes.
 *
 * Note that when an element is removed using `ngIf` its scope is destroyed and a new scope
 * is created when the element is restored.  The scope created within `ngIf` inherits from
 * its parent scope using
 * [prototypal inheritance](https://github.com/angular/angular.js/wiki/Understanding-Scopes#javascript-prototypal-inheritance).
 * An important implication of this is if `ngModel` is used within `ngIf` to bind to
 * a javascript primitive defined in the parent scope. In this case any modifications made to the
 * variable within the child scope will override (hide) the value in the parent scope.
 *
 * Also, `ngIf` recreates elements using their compiled state. An example of this behavior
 * is if an element's class attribute is directly modified after it's compiled, using something like
 * jQuery's `.addClass()` method, and the element is later removed. When `ngIf` recreates the element
 * the added class will be lost because the original compiled state is used to regenerate the element.
 *
 * Additionally, you can provide animations via the `ngAnimate` module to animate the `enter`
 * and `leave` effects.
 *
 * @animations
 * enter - happens just after the `ngIf` contents change and a new DOM element is created and injected into the `ngIf` container
 * leave - happens just before the `ngIf` contents are removed from the DOM
 *
 * @element ANY
 * @scope
 * @priority 600
 * @param {expression} ngIf If the {@link guide/expression expression} is falsy then
 *     the element is removed from the DOM tree. If it is truthy a copy of the compiled
 *     element is added to the DOM tree.
 *
 * @example
  <example module="ngAnimate" deps="angular-animate.js" animations="true">
    <file name="index.html">
      Click me: <input type="checkbox" ng-model="checked" ng-init="checked=true" /><br/>
      Show when checked:
      <span ng-if="checked" class="animate-if">
        This is removed when the checkbox is unchecked.
      </span>
    </file>
    <file name="animations.css">
      .animate-if {
        background:white;
        border:1px solid black;
        padding:10px;
      }

      .animate-if.ng-enter, .animate-if.ng-leave {
        -webkit-transition:all cubic-bezier(0.250, 0.460, 0.450, 0.940) 0.5s;
        transition:all cubic-bezier(0.250, 0.460, 0.450, 0.940) 0.5s;
      }

      .animate-if.ng-enter,
      .animate-if.ng-leave.ng-leave-active {
        opacity:0;
      }

      .animate-if.ng-leave,
      .animate-if.ng-enter.ng-enter-active {
        opacity:1;
      }
    </file>
  </example>
 */
var ngIfDirective = ['$animate', function($animate) {
  return {
    multiElement: true,
    transclude: 'element',
    priority: 600,
    terminal: true,
    restrict: 'A',
    $$tlb: true,
    link: function($scope, $element, $attr, ctrl, $transclude) {
        var block, childScope, previousElements;
        $scope.$watch($attr.ngIf, function ngIfWatchAction(value) {

          if (value) {
            if (!childScope) {
              $transclude(function(clone, newScope) {
                childScope = newScope;
                clone[clone.length++] = document.createComment(' end ngIf: ' + $attr.ngIf + ' ');
                // Note: We only need the first/last node of the cloned nodes.
                // However, we need to keep the reference to the jqlite wrapper as it might be changed later
                // by a directive with templateUrl when its template arrives.
                block = {
                  clone: clone
                };
                $animate.enter(clone, $element.parent(), $element);
              });
            }
          } else {
            if (previousElements) {
              previousElements.remove();
              previousElements = null;
            }
            if (childScope) {
              childScope.$destroy();
              childScope = null;
            }
            if (block) {
              previousElements = getBlockNodes(block.clone);
              $animate.leave(previousElements).then(function() {
                previousElements = null;
              });
              block = null;
            }
          }
        });
    }
  };
}];

/**
 * @ngdoc directive
 * @name ngInclude
 * @restrict ECA
 *
 * @description
 * Fetches, compiles and includes an external HTML fragment.
 *
 * By default, the template URL is restricted to the same domain and protocol as the
 * application document. This is done by calling {@link $sce#getTrustedResourceUrl
 * $sce.getTrustedResourceUrl} on it. To load templates from other domains or protocols
 * you may either {@link ng.$sceDelegateProvider#resourceUrlWhitelist whitelist them} or
 * {@link $sce#trustAsResourceUrl wrap them} as trusted values. Refer to Angular's {@link
 * ng.$sce Strict Contextual Escaping}.
 *
 * In addition, the browser's
 * [Same Origin Policy](https://code.google.com/p/browsersec/wiki/Part2#Same-origin_policy_for_XMLHttpRequest)
 * and [Cross-Origin Resource Sharing (CORS)](http://www.w3.org/TR/cors/)
 * policy may further restrict whether the template is successfully loaded.
 * For example, `ngInclude` won't work for cross-domain requests on all browsers and for `file://`
 * access on some browsers.
 *
 * @animations
 * enter - animation is used to bring new content into the browser.
 * leave - animation is used to animate existing content away.
 *
 * The enter and leave animation occur concurrently.
 *
 * @scope
 * @priority 400
 *
 * @param {string} ngInclude|src angular expression evaluating to URL. If the source is a string constant,
 *                 make sure you wrap it in **single** quotes, e.g. `src="'myPartialTemplate.html'"`.
 * @param {string=} onload Expression to evaluate when a new partial is loaded.
 *
 * @param {string=} autoscroll Whether `ngInclude` should call {@link ng.$anchorScroll
 *                  $anchorScroll} to scroll the viewport after the content is loaded.
 *
 *                  - If the attribute is not set, disable scrolling.
 *                  - If the attribute is set without value, enable scrolling.
 *                  - Otherwise enable scrolling only if the expression evaluates to truthy value.
 *
 * @example
  <example module="includeExample" deps="angular-animate.js" animations="true">
    <file name="index.html">
     <div ng-controller="ExampleController">
       <select ng-model="template" ng-options="t.name for t in templates">
        <option value="">(blank)</option>
       </select>
       url of the template: <code>{{template.url}}</code>
       <hr/>
       <div class="slide-animate-container">
         <div class="slide-animate" ng-include="template.url"></div>
       </div>
     </div>
    </file>
    <file name="script.js">
      angular.module('includeExample', ['ngAnimate'])
        .controller('ExampleController', ['$scope', function($scope) {
          $scope.templates =
            [ { name: 'template1.html', url: 'template1.html'},
              { name: 'template2.html', url: 'template2.html'} ];
          $scope.template = $scope.templates[0];
        }]);
     </file>
    <file name="template1.html">
      Content of template1.html
    </file>
    <file name="template2.html">
      Content of template2.html
    </file>
    <file name="animations.css">
      .slide-animate-container {
        position:relative;
        background:white;
        border:1px solid black;
        height:40px;
        overflow:hidden;
      }

      .slide-animate {
        padding:10px;
      }

      .slide-animate.ng-enter, .slide-animate.ng-leave {
        -webkit-transition:all cubic-bezier(0.250, 0.460, 0.450, 0.940) 0.5s;
        transition:all cubic-bezier(0.250, 0.460, 0.450, 0.940) 0.5s;

        position:absolute;
        top:0;
        left:0;
        right:0;
        bottom:0;
        display:block;
        padding:10px;
      }

      .slide-animate.ng-enter {
        top:-50px;
      }
      .slide-animate.ng-enter.ng-enter-active {
        top:0;
      }

      .slide-animate.ng-leave {
        top:0;
      }
      .slide-animate.ng-leave.ng-leave-active {
        top:50px;
      }
    </file>
    <file name="protractor.js" type="protractor">
      var templateSelect = element(by.model('template'));
      var includeElem = element(by.css('[ng-include]'));

      it('should load template1.html', function() {
        expect(includeElem.getText()).toMatch(/Content of template1.html/);
      });

      it('should load template2.html', function() {
        if (browser.params.browser == 'firefox') {
          // Firefox can't handle using selects
          // See https://github.com/angular/protractor/issues/480
          return;
        }
        templateSelect.click();
        templateSelect.all(by.css('option')).get(2).click();
        expect(includeElem.getText()).toMatch(/Content of template2.html/);
      });

      it('should change to blank', function() {
        if (browser.params.browser == 'firefox') {
          // Firefox can't handle using selects
          return;
        }
        templateSelect.click();
        templateSelect.all(by.css('option')).get(0).click();
        expect(includeElem.isPresent()).toBe(false);
      });
    </file>
  </example>
 */


/**
 * @ngdoc event
 * @name ngInclude#$includeContentRequested
 * @eventType emit on the scope ngInclude was declared in
 * @description
 * Emitted every time the ngInclude content is requested.
 *
 * @param {Object} angularEvent Synthetic event object.
 * @param {String} src URL of content to load.
 */


/**
 * @ngdoc event
 * @name ngInclude#$includeContentLoaded
 * @eventType emit on the current ngInclude scope
 * @description
 * Emitted every time the ngInclude content is reloaded.
 *
 * @param {Object} angularEvent Synthetic event object.
 * @param {String} src URL of content to load.
 */


/**
 * @ngdoc event
 * @name ngInclude#$includeContentError
 * @eventType emit on the scope ngInclude was declared in
 * @description
 * Emitted when a template HTTP request yields an erroneous response (status < 200 || status > 299)
 *
 * @param {Object} angularEvent Synthetic event object.
 * @param {String} src URL of content to load.
 */
var ngIncludeDirective = ['$templateRequest', '$anchorScroll', '$animate',
                  function($templateRequest,   $anchorScroll,   $animate) {
  return {
    restrict: 'ECA',
    priority: 400,
    terminal: true,
    transclude: 'element',
    controller: angular.noop,
    compile: function(element, attr) {
      var srcExp = attr.ngInclude || attr.src,
          onloadExp = attr.onload || '',
          autoScrollExp = attr.autoscroll;

      return function(scope, $element, $attr, ctrl, $transclude) {
        var changeCounter = 0,
            currentScope,
            previousElement,
            currentElement;

        var cleanupLastIncludeContent = function() {
          if (previousElement) {
            previousElement.remove();
            previousElement = null;
          }
          if (currentScope) {
            currentScope.$destroy();
            currentScope = null;
          }
          if (currentElement) {
            $animate.leave(currentElement).then(function() {
              previousElement = null;
            });
            previousElement = currentElement;
            currentElement = null;
          }
        };

        scope.$watch(srcExp, function ngIncludeWatchAction(src) {
          var afterAnimation = function() {
            if (isDefined(autoScrollExp) && (!autoScrollExp || scope.$eval(autoScrollExp))) {
              $anchorScroll();
            }
          };
          var thisChangeId = ++changeCounter;

          if (src) {
            //set the 2nd param to true to ignore the template request error so that the inner
            //contents and scope can be cleaned up.
            $templateRequest(src, true).then(function(response) {
              if (thisChangeId !== changeCounter) return;
              var newScope = scope.$new();
              ctrl.template = response;

              // Note: This will also link all children of ng-include that were contained in the original
              // html. If that content contains controllers, ... they could pollute/change the scope.
              // However, using ng-include on an element with additional content does not make sense...
              // Note: We can't remove them in the cloneAttchFn of $transclude as that
              // function is called before linking the content, which would apply child
              // directives to non existing elements.
              var clone = $transclude(newScope, function(clone) {
                cleanupLastIncludeContent();
                $animate.enter(clone, null, $element).then(afterAnimation);
              });

              currentScope = newScope;
              currentElement = clone;

              currentScope.$emit('$includeContentLoaded', src);
              scope.$eval(onloadExp);
            }, function() {
              if (thisChangeId === changeCounter) {
                cleanupLastIncludeContent();
                scope.$emit('$includeContentError', src);
              }
            });
            scope.$emit('$includeContentRequested', src);
          } else {
            cleanupLastIncludeContent();
            ctrl.template = null;
          }
        });
      };
    }
  };
}];

// This directive is called during the $transclude call of the first `ngInclude` directive.
// It will replace and compile the content of the element with the loaded template.
// We need this directive so that the element content is already filled when
// the link function of another directive on the same element as ngInclude
// is called.
var ngIncludeFillContentDirective = ['$compile',
  function($compile) {
    return {
      restrict: 'ECA',
      priority: -400,
      require: 'ngInclude',
      link: function(scope, $element, $attr, ctrl) {
        if (/SVG/.test($element[0].toString())) {
          // WebKit: https://bugs.webkit.org/show_bug.cgi?id=135698 --- SVG elements do not
          // support innerHTML, so detect this here and try to generate the contents
          // specially.
          $element.empty();
          $compile(jqLiteBuildFragment(ctrl.template, document).childNodes)(scope,
              function namespaceAdaptedClone(clone) {
            $element.append(clone);
          }, {futureParentElement: $element});
          return;
        }

        $element.html(ctrl.template);
        $compile($element.contents())(scope);
      }
    };
  }];

/**
 * @ngdoc directive
 * @name ngInit
 * @restrict AC
 *
 * @description
 * The `ngInit` directive allows you to evaluate an expression in the
 * current scope.
 *
 * <div class="alert alert-error">
 * The only appropriate use of `ngInit` is for aliasing special properties of
 * {@link ng.directive:ngRepeat `ngRepeat`}, as seen in the demo below. Besides this case, you
 * should use {@link guide/controller controllers} rather than `ngInit`
 * to initialize values on a scope.
 * </div>
 * <div class="alert alert-warning">
 * **Note**: If you have assignment in `ngInit` along with {@link ng.$filter `$filter`}, make
 * sure you have parenthesis for correct precedence:
 * <pre class="prettyprint">
 * `<div ng-init="test1 = (data | orderBy:'name')"></div>`
 * </pre>
 * </div>
 *
 * @priority 450
 *
 * @element ANY
 * @param {expression} ngInit {@link guide/expression Expression} to eval.
 *
 * @example
   <example module="initExample">
     <file name="index.html">
   <script>
     angular.module('initExample', [])
       .controller('ExampleController', ['$scope', function($scope) {
         $scope.list = [['a', 'b'], ['c', 'd']];
       }]);
   </script>
   <div ng-controller="ExampleController">
     <div ng-repeat="innerList in list" ng-init="outerIndex = $index">
       <div ng-repeat="value in innerList" ng-init="innerIndex = $index">
          <span class="example-init">list[ {{outerIndex}} ][ {{innerIndex}} ] = {{value}};</span>
       </div>
     </div>
   </div>
     </file>
     <file name="protractor.js" type="protractor">
       it('should alias index positions', function() {
         var elements = element.all(by.css('.example-init'));
         expect(elements.get(0).getText()).toBe('list[ 0 ][ 0 ] = a;');
         expect(elements.get(1).getText()).toBe('list[ 0 ][ 1 ] = b;');
         expect(elements.get(2).getText()).toBe('list[ 1 ][ 0 ] = c;');
         expect(elements.get(3).getText()).toBe('list[ 1 ][ 1 ] = d;');
       });
     </file>
   </example>
 */
var ngInitDirective = ngDirective({
  priority: 450,
  compile: function() {
    return {
      pre: function(scope, element, attrs) {
        scope.$eval(attrs.ngInit);
      }
    };
  }
});

/**
 * @ngdoc directive
 * @name ngList
 *
 * @description
 * Text input that converts between a delimited string and an array of strings. The default
 * delimiter is a comma followed by a space - equivalent to `ng-list=", "`. You can specify a custom
 * delimiter as the value of the `ngList` attribute - for example, `ng-list=" | "`.
 *
 * The behaviour of the directive is affected by the use of the `ngTrim` attribute.
 * * If `ngTrim` is set to `"false"` then whitespace around both the separator and each
 *   list item is respected. This implies that the user of the directive is responsible for
 *   dealing with whitespace but also allows you to use whitespace as a delimiter, such as a
 *   tab or newline character.
 * * Otherwise whitespace around the delimiter is ignored when splitting (although it is respected
 *   when joining the list items back together) and whitespace around each list item is stripped
 *   before it is added to the model.
 *
 * ### Example with Validation
 *
 * <example name="ngList-directive" module="listExample">
 *   <file name="app.js">
 *      angular.module('listExample', [])
 *        .controller('ExampleController', ['$scope', function($scope) {
 *          $scope.names = ['morpheus', 'neo', 'trinity'];
 *        }]);
 *   </file>
 *   <file name="index.html">
 *    <form name="myForm" ng-controller="ExampleController">
 *      List: <input name="namesInput" ng-model="names" ng-list required>
 *      <span class="error" ng-show="myForm.namesInput.$error.required">
 *        Required!</span>
 *      <br>
 *      <tt>names = {{names}}</tt><br/>
 *      <tt>myForm.namesInput.$valid = {{myForm.namesInput.$valid}}</tt><br/>
 *      <tt>myForm.namesInput.$error = {{myForm.namesInput.$error}}</tt><br/>
 *      <tt>myForm.$valid = {{myForm.$valid}}</tt><br/>
 *      <tt>myForm.$error.required = {{!!myForm.$error.required}}</tt><br/>
 *     </form>
 *   </file>
 *   <file name="protractor.js" type="protractor">
 *     var listInput = element(by.model('names'));
 *     var names = element(by.exactBinding('names'));
 *     var valid = element(by.binding('myForm.namesInput.$valid'));
 *     var error = element(by.css('span.error'));
 *
 *     it('should initialize to model', function() {
 *       expect(names.getText()).toContain('["morpheus","neo","trinity"]');
 *       expect(valid.getText()).toContain('true');
 *       expect(error.getCssValue('display')).toBe('none');
 *     });
 *
 *     it('should be invalid if empty', function() {
 *       listInput.clear();
 *       listInput.sendKeys('');
 *
 *       expect(names.getText()).toContain('');
 *       expect(valid.getText()).toContain('false');
 *       expect(error.getCssValue('display')).not.toBe('none');
 *     });
 *   </file>
 * </example>
 *
 * ### Example - splitting on whitespace
 * <example name="ngList-directive-newlines">
 *   <file name="index.html">
 *    <textarea ng-model="list" ng-list="&#10;" ng-trim="false"></textarea>
 *    <pre>{{ list | json }}</pre>
 *   </file>
 *   <file name="protractor.js" type="protractor">
 *     it("should split the text by newlines", function() {
 *       var listInput = element(by.model('list'));
 *       var output = element(by.binding('list | json'));
 *       listInput.sendKeys('abc\ndef\nghi');
 *       expect(output.getText()).toContain('[\n  "abc",\n  "def",\n  "ghi"\n]');
 *     });
 *   </file>
 * </example>
 *
 * @element input
 * @param {string=} ngList optional delimiter that should be used to split the value.
 */
var ngListDirective = function() {
  return {
    restrict: 'A',
    priority: 100,
    require: 'ngModel',
    link: function(scope, element, attr, ctrl) {
      // We want to control whitespace trimming so we use this convoluted approach
      // to access the ngList attribute, which doesn't pre-trim the attribute
      var ngList = element.attr(attr.$attr.ngList) || ', ';
      var trimValues = attr.ngTrim !== 'false';
      var separator = trimValues ? trim(ngList) : ngList;

      var parse = function(viewValue) {
        // If the viewValue is invalid (say required but empty) it will be `undefined`
        if (isUndefined(viewValue)) return;

        var list = [];

        if (viewValue) {
          forEach(viewValue.split(separator), function(value) {
            if (value) list.push(trimValues ? trim(value) : value);
          });
        }

        return list;
      };

      ctrl.$parsers.push(parse);
      ctrl.$formatters.push(function(value) {
        if (isArray(value)) {
          return value.join(ngList);
        }

        return undefined;
      });

      // Override the standard $isEmpty because an empty array means the input is empty.
      ctrl.$isEmpty = function(value) {
        return !value || !value.length;
      };
    }
  };
};

/* global VALID_CLASS: true,
  INVALID_CLASS: true,
  PRISTINE_CLASS: true,
  DIRTY_CLASS: true,
  UNTOUCHED_CLASS: true,
  TOUCHED_CLASS: true,
*/

var VALID_CLASS = 'ng-valid',
    INVALID_CLASS = 'ng-invalid',
    PRISTINE_CLASS = 'ng-pristine',
    DIRTY_CLASS = 'ng-dirty',
    UNTOUCHED_CLASS = 'ng-untouched',
    TOUCHED_CLASS = 'ng-touched',
    PENDING_CLASS = 'ng-pending';

var ngModelMinErr = minErr('ngModel');

/**
 * @ngdoc type
 * @name ngModel.NgModelController
 *
 * @property {string} $viewValue Actual string value in the view.
 * @property {*} $modelValue The value in the model that the control is bound to.
 * @property {Array.<Function>} $parsers Array of functions to execute, as a pipeline, whenever
       the control reads value from the DOM. The functions are called in array order, each passing
       its return value through to the next. The last return value is forwarded to the
       {@link ngModel.NgModelController#$validators `$validators`} collection.

Parsers are used to sanitize / convert the {@link ngModel.NgModelController#$viewValue
`$viewValue`}.

Returning `undefined` from a parser means a parse error occurred. In that case,
no {@link ngModel.NgModelController#$validators `$validators`} will run and the `ngModel`
will be set to `undefined` unless {@link ngModelOptions `ngModelOptions.allowInvalid`}
is set to `true`. The parse error is stored in `ngModel.$error.parse`.

 *
 * @property {Array.<Function>} $formatters Array of functions to execute, as a pipeline, whenever
       the model value changes. The functions are called in reverse array order, each passing the value through to the
       next. The last return value is used as the actual DOM value.
       Used to format / convert values for display in the control.
 * ```js
 * function formatter(value) {
 *   if (value) {
 *     return value.toUpperCase();
 *   }
 * }
 * ngModel.$formatters.push(formatter);
 * ```
 *
 * @property {Object.<string, function>} $validators A collection of validators that are applied
 *      whenever the model value changes. The key value within the object refers to the name of the
 *      validator while the function refers to the validation operation. The validation operation is
 *      provided with the model value as an argument and must return a true or false value depending
 *      on the response of that validation.
 *
 * ```js
 * ngModel.$validators.validCharacters = function(modelValue, viewValue) {
 *   var value = modelValue || viewValue;
 *   return /[0-9]+/.test(value) &&
 *          /[a-z]+/.test(value) &&
 *          /[A-Z]+/.test(value) &&
 *          /\W+/.test(value);
 * };
 * ```
 *
 * @property {Object.<string, function>} $asyncValidators A collection of validations that are expected to
 *      perform an asynchronous validation (e.g. a HTTP request). The validation function that is provided
 *      is expected to return a promise when it is run during the model validation process. Once the promise
 *      is delivered then the validation status will be set to true when fulfilled and false when rejected.
 *      When the asynchronous validators are triggered, each of the validators will run in parallel and the model
 *      value will only be updated once all validators have been fulfilled. As long as an asynchronous validator
 *      is unfulfilled, its key will be added to the controllers `$pending` property. Also, all asynchronous validators
 *      will only run once all synchronous validators have passed.
 *
 * Please note that if $http is used then it is important that the server returns a success HTTP response code
 * in order to fulfill the validation and a status level of `4xx` in order to reject the validation.
 *
 * ```js
 * ngModel.$asyncValidators.uniqueUsername = function(modelValue, viewValue) {
 *   var value = modelValue || viewValue;
 *
 *   // Lookup user by username
 *   return $http.get('/api/users/' + value).
 *      then(function resolved() {
 *        //username exists, this means validation fails
 *        return $q.reject('exists');
 *      }, function rejected() {
 *        //username does not exist, therefore this validation passes
 *        return true;
 *      });
 * };
 * ```
 *
 * @property {Array.<Function>} $viewChangeListeners Array of functions to execute whenever the
 *     view value has changed. It is called with no arguments, and its return value is ignored.
 *     This can be used in place of additional $watches against the model value.
 *
 * @property {Object} $error An object hash with all failing validator ids as keys.
 * @property {Object} $pending An object hash with all pending validator ids as keys.
 *
 * @property {boolean} $untouched True if control has not lost focus yet.
 * @property {boolean} $touched True if control has lost focus.
 * @property {boolean} $pristine True if user has not interacted with the control yet.
 * @property {boolean} $dirty True if user has already interacted with the control.
 * @property {boolean} $valid True if there is no error.
 * @property {boolean} $invalid True if at least one error on the control.
 * @property {string} $name The name attribute of the control.
 *
 * @description
 *
 * `NgModelController` provides API for the {@link ngModel `ngModel`} directive.
 * The controller contains services for data-binding, validation, CSS updates, and value formatting
 * and parsing. It purposefully does not contain any logic which deals with DOM rendering or
 * listening to DOM events.
 * Such DOM related logic should be provided by other directives which make use of
 * `NgModelController` for data-binding to control elements.
 * Angular provides this DOM logic for most {@link input `input`} elements.
 * At the end of this page you can find a {@link ngModel.NgModelController#custom-control-example
 * custom control example} that uses `ngModelController` to bind to `contenteditable` elements.
 *
 * @example
 * ### Custom Control Example
 * This example shows how to use `NgModelController` with a custom control to achieve
 * data-binding. Notice how different directives (`contenteditable`, `ng-model`, and `required`)
 * collaborate together to achieve the desired result.
 *
 * `contenteditable` is an HTML5 attribute, which tells the browser to let the element
 * contents be edited in place by the user.
 *
 * We are using the {@link ng.service:$sce $sce} service here and include the {@link ngSanitize $sanitize}
 * module to automatically remove "bad" content like inline event listener (e.g. `<span onclick="...">`).
 * However, as we are using `$sce` the model can still decide to provide unsafe content if it marks
 * that content using the `$sce` service.
 *
 * <example name="NgModelController" module="customControl" deps="angular-sanitize.js">
    <file name="style.css">
      [contenteditable] {
        border: 1px solid black;
        background-color: white;
        min-height: 20px;
      }

      .ng-invalid {
        border: 1px solid red;
      }

    </file>
    <file name="script.js">
      angular.module('customControl', ['ngSanitize']).
        directive('contenteditable', ['$sce', function($sce) {
          return {
            restrict: 'A', // only activate on element attribute
            require: '?ngModel', // get a hold of NgModelController
            link: function(scope, element, attrs, ngModel) {
              if (!ngModel) return; // do nothing if no ng-model

              // Specify how UI should be updated
              ngModel.$render = function() {
                element.html($sce.getTrustedHtml(ngModel.$viewValue || ''));
              };

              // Listen for change events to enable binding
              element.on('blur keyup change', function() {
                scope.$evalAsync(read);
              });
              read(); // initialize

              // Write data to the model
              function read() {
                var html = element.html();
                // When we clear the content editable the browser leaves a <br> behind
                // If strip-br attribute is provided then we strip this out
                if ( attrs.stripBr && html == '<br>' ) {
                  html = '';
                }
                ngModel.$setViewValue(html);
              }
            }
          };
        }]);
    </file>
    <file name="index.html">
      <form name="myForm">
       <div contenteditable
            name="myWidget" ng-model="userContent"
            strip-br="true"
            required>Change me!</div>
        <span ng-show="myForm.myWidget.$error.required">Required!</span>
       <hr>
       <textarea ng-model="userContent"></textarea>
      </form>
    </file>
    <file name="protractor.js" type="protractor">
    it('should data-bind and become invalid', function() {
      if (browser.params.browser == 'safari' || browser.params.browser == 'firefox') {
        // SafariDriver can't handle contenteditable
        // and Firefox driver can't clear contenteditables very well
        return;
      }
      var contentEditable = element(by.css('[contenteditable]'));
      var content = 'Change me!';

      expect(contentEditable.getText()).toEqual(content);

      contentEditable.clear();
      contentEditable.sendKeys(protractor.Key.BACK_SPACE);
      expect(contentEditable.getText()).toEqual('');
      expect(contentEditable.getAttribute('class')).toMatch(/ng-invalid-required/);
    });
    </file>
 * </example>
 *
 *
 */
var NgModelController = ['$scope', '$exceptionHandler', '$attrs', '$element', '$parse', '$animate', '$timeout', '$rootScope', '$q', '$interpolate',
    function($scope, $exceptionHandler, $attr, $element, $parse, $animate, $timeout, $rootScope, $q, $interpolate) {
  this.$viewValue = Number.NaN;
  this.$modelValue = Number.NaN;
  this.$$rawModelValue = undefined; // stores the parsed modelValue / model set from scope regardless of validity.
  this.$validators = {};
  this.$asyncValidators = {};
  this.$parsers = [];
  this.$formatters = [];
  this.$viewChangeListeners = [];
  this.$untouched = true;
  this.$touched = false;
  this.$pristine = true;
  this.$dirty = false;
  this.$valid = true;
  this.$invalid = false;
  this.$error = {}; // keep invalid keys here
  this.$$success = {}; // keep valid keys here
  this.$pending = undefined; // keep pending keys here
  this.$name = $interpolate($attr.name || '', false)($scope);


  var parsedNgModel = $parse($attr.ngModel),
      parsedNgModelAssign = parsedNgModel.assign,
      ngModelGet = parsedNgModel,
      ngModelSet = parsedNgModelAssign,
      pendingDebounce = null,
      parserValid,
      ctrl = this;

  this.$$setOptions = function(options) {
    ctrl.$options = options;
    if (options && options.getterSetter) {
      var invokeModelGetter = $parse($attr.ngModel + '()'),
          invokeModelSetter = $parse($attr.ngModel + '($$$p)');

      ngModelGet = function($scope) {
        var modelValue = parsedNgModel($scope);
        if (isFunction(modelValue)) {
          modelValue = invokeModelGetter($scope);
        }
        return modelValue;
      };
      ngModelSet = function($scope, newValue) {
        if (isFunction(parsedNgModel($scope))) {
          invokeModelSetter($scope, {$$$p: ctrl.$modelValue});
        } else {
          parsedNgModelAssign($scope, ctrl.$modelValue);
        }
      };
    } else if (!parsedNgModel.assign) {
      throw ngModelMinErr('nonassign', "Expression '{0}' is non-assignable. Element: {1}",
          $attr.ngModel, startingTag($element));
    }
  };

  /**
   * @ngdoc method
   * @name ngModel.NgModelController#$render
   *
   * @description
   * Called when the view needs to be updated. It is expected that the user of the ng-model
   * directive will implement this method.
   *
   * The `$render()` method is invoked in the following situations:
   *
   * * `$rollbackViewValue()` is called.  If we are rolling back the view value to the last
   *   committed value then `$render()` is called to update the input control.
   * * The value referenced by `ng-model` is changed programmatically and both the `$modelValue` and
   *   the `$viewValue` are different to last time.
   *
   * Since `ng-model` does not do a deep watch, `$render()` is only invoked if the values of
   * `$modelValue` and `$viewValue` are actually different to their previous value. If `$modelValue`
   * or `$viewValue` are objects (rather than a string or number) then `$render()` will not be
   * invoked if you only change a property on the objects.
   */
  this.$render = noop;

  /**
   * @ngdoc method
   * @name ngModel.NgModelController#$isEmpty
   *
   * @description
   * This is called when we need to determine if the value of an input is empty.
   *
   * For instance, the required directive does this to work out if the input has data or not.
   *
   * The default `$isEmpty` function checks whether the value is `undefined`, `''`, `null` or `NaN`.
   *
   * You can override this for input directives whose concept of being empty is different to the
   * default. The `checkboxInputType` directive does this because in its case a value of `false`
   * implies empty.
   *
   * @param {*} value The value of the input to check for emptiness.
   * @returns {boolean} True if `value` is "empty".
   */
  this.$isEmpty = function(value) {
    return isUndefined(value) || value === '' || value === null || value !== value;
  };

  var parentForm = $element.inheritedData('$formController') || nullFormCtrl,
      currentValidationRunId = 0;

  /**
   * @ngdoc method
   * @name ngModel.NgModelController#$setValidity
   *
   * @description
   * Change the validity state, and notify the form.
   *
   * This method can be called within $parsers/$formatters or a custom validation implementation.
   * However, in most cases it should be sufficient to use the `ngModel.$validators` and
   * `ngModel.$asyncValidators` collections which will call `$setValidity` automatically.
   *
   * @param {string} validationErrorKey Name of the validator. The `validationErrorKey` will be assigned
   *        to either `$error[validationErrorKey]` or `$pending[validationErrorKey]`
   *        (for unfulfilled `$asyncValidators`), so that it is available for data-binding.
   *        The `validationErrorKey` should be in camelCase and will get converted into dash-case
   *        for class name. Example: `myError` will result in `ng-valid-my-error` and `ng-invalid-my-error`
   *        class and can be bound to as  `{{someForm.someControl.$error.myError}}` .
   * @param {boolean} isValid Whether the current state is valid (true), invalid (false), pending (undefined),
   *                          or skipped (null). Pending is used for unfulfilled `$asyncValidators`.
   *                          Skipped is used by Angular when validators do not run because of parse errors and
   *                          when `$asyncValidators` do not run because any of the `$validators` failed.
   */
  addSetValidityMethod({
    ctrl: this,
    $element: $element,
    set: function(object, property) {
      object[property] = true;
    },
    unset: function(object, property) {
      delete object[property];
    },
    parentForm: parentForm,
    $animate: $animate
  });

  /**
   * @ngdoc method
   * @name ngModel.NgModelController#$setPristine
   *
   * @description
   * Sets the control to its pristine state.
   *
   * This method can be called to remove the `ng-dirty` class and set the control to its pristine
   * state (`ng-pristine` class). A model is considered to be pristine when the control
   * has not been changed from when first compiled.
   */
  this.$setPristine = function() {
    ctrl.$dirty = false;
    ctrl.$pristine = true;
    $animate.removeClass($element, DIRTY_CLASS);
    $animate.addClass($element, PRISTINE_CLASS);
  };

  /**
   * @ngdoc method
   * @name ngModel.NgModelController#$setDirty
   *
   * @description
   * Sets the control to its dirty state.
   *
   * This method can be called to remove the `ng-pristine` class and set the control to its dirty
   * state (`ng-dirty` class). A model is considered to be dirty when the control has been changed
   * from when first compiled.
   */
  this.$setDirty = function() {
    ctrl.$dirty = true;
    ctrl.$pristine = false;
    $animate.removeClass($element, PRISTINE_CLASS);
    $animate.addClass($element, DIRTY_CLASS);
    parentForm.$setDirty();
  };

  /**
   * @ngdoc method
   * @name ngModel.NgModelController#$setUntouched
   *
   * @description
   * Sets the control to its untouched state.
   *
   * This method can be called to remove the `ng-touched` class and set the control to its
   * untouched state (`ng-untouched` class). Upon compilation, a model is set as untouched
   * by default, however this function can be used to restore that state if the model has
   * already been touched by the user.
   */
  this.$setUntouched = function() {
    ctrl.$touched = false;
    ctrl.$untouched = true;
    $animate.setClass($element, UNTOUCHED_CLASS, TOUCHED_CLASS);
  };

  /**
   * @ngdoc method
   * @name ngModel.NgModelController#$setTouched
   *
   * @description
   * Sets the control to its touched state.
   *
   * This method can be called to remove the `ng-untouched` class and set the control to its
   * touched state (`ng-touched` class). A model is considered to be touched when the user has
   * first focused the control element and then shifted focus away from the control (blur event).
   */
  this.$setTouched = function() {
    ctrl.$touched = true;
    ctrl.$untouched = false;
    $animate.setClass($element, TOUCHED_CLASS, UNTOUCHED_CLASS);
  };

  /**
   * @ngdoc method
   * @name ngModel.NgModelController#$rollbackViewValue
   *
   * @description
   * Cancel an update and reset the input element's value to prevent an update to the `$modelValue`,
   * which may be caused by a pending debounced event or because the input is waiting for a some
   * future event.
   *
   * If you have an input that uses `ng-model-options` to set up debounced events or events such
   * as blur you can have a situation where there is a period when the `$viewValue`
   * is out of synch with the ngModel's `$modelValue`.
   *
   * In this case, you can run into difficulties if you try to update the ngModel's `$modelValue`
   * programmatically before these debounced/future events have resolved/occurred, because Angular's
   * dirty checking mechanism is not able to tell whether the model has actually changed or not.
   *
   * The `$rollbackViewValue()` method should be called before programmatically changing the model of an
   * input which may have such events pending. This is important in order to make sure that the
   * input field will be updated with the new model value and any pending operations are cancelled.
   *
   * <example name="ng-model-cancel-update" module="cancel-update-example">
   *   <file name="app.js">
   *     angular.module('cancel-update-example', [])
   *
   *     .controller('CancelUpdateController', ['$scope', function($scope) {
   *       $scope.resetWithCancel = function(e) {
   *         if (e.keyCode == 27) {
   *           $scope.myForm.myInput1.$rollbackViewValue();
   *           $scope.myValue = '';
   *         }
   *       };
   *       $scope.resetWithoutCancel = function(e) {
   *         if (e.keyCode == 27) {
   *           $scope.myValue = '';
   *         }
   *       };
   *     }]);
   *   </file>
   *   <file name="index.html">
   *     <div ng-controller="CancelUpdateController">
   *       <p>Try typing something in each input.  See that the model only updates when you
   *          blur off the input.
   *        </p>
   *        <p>Now see what happens if you start typing then press the Escape key</p>
   *
   *       <form name="myForm" ng-model-options="{ updateOn: 'blur' }">
   *         <p>With $rollbackViewValue()</p>
   *         <input name="myInput1" ng-model="myValue" ng-keydown="resetWithCancel($event)"><br/>
   *         myValue: "{{ myValue }}"
   *
   *         <p>Without $rollbackViewValue()</p>
   *         <input name="myInput2" ng-model="myValue" ng-keydown="resetWithoutCancel($event)"><br/>
   *         myValue: "{{ myValue }}"
   *       </form>
   *     </div>
   *   </file>
   * </example>
   */
  this.$rollbackViewValue = function() {
    $timeout.cancel(pendingDebounce);
    ctrl.$viewValue = ctrl.$$lastCommittedViewValue;
    ctrl.$render();
  };

  /**
   * @ngdoc method
   * @name ngModel.NgModelController#$validate
   *
   * @description
   * Runs each of the registered validators (first synchronous validators and then
   * asynchronous validators).
   * If the validity changes to invalid, the model will be set to `undefined`,
   * unless {@link ngModelOptions `ngModelOptions.allowInvalid`} is `true`.
   * If the validity changes to valid, it will set the model to the last available valid
   * `$modelValue`, i.e. either the last parsed value or the last value set from the scope.
   */
  this.$validate = function() {
    // ignore $validate before model is initialized
    if (isNumber(ctrl.$modelValue) && isNaN(ctrl.$modelValue)) {
      return;
    }

    var viewValue = ctrl.$$lastCommittedViewValue;
    // Note: we use the $$rawModelValue as $modelValue might have been
    // set to undefined during a view -> model update that found validation
    // errors. We can't parse the view here, since that could change
    // the model although neither viewValue nor the model on the scope changed
    var modelValue = ctrl.$$rawModelValue;

    var prevValid = ctrl.$valid;
    var prevModelValue = ctrl.$modelValue;

    var allowInvalid = ctrl.$options && ctrl.$options.allowInvalid;

    ctrl.$$runValidators(modelValue, viewValue, function(allValid) {
      // If there was no change in validity, don't update the model
      // This prevents changing an invalid modelValue to undefined
      if (!allowInvalid && prevValid !== allValid) {
        // Note: Don't check ctrl.$valid here, as we could have
        // external validators (e.g. calculated on the server),
        // that just call $setValidity and need the model value
        // to calculate their validity.
        ctrl.$modelValue = allValid ? modelValue : undefined;

        if (ctrl.$modelValue !== prevModelValue) {
          ctrl.$$writeModelToScope();
        }
      }
    });

  };

  this.$$runValidators = function(modelValue, viewValue, doneCallback) {
    currentValidationRunId++;
    var localValidationRunId = currentValidationRunId;

    // check parser error
    if (!processParseErrors()) {
      validationDone(false);
      return;
    }
    if (!processSyncValidators()) {
      validationDone(false);
      return;
    }
    processAsyncValidators();

    function processParseErrors() {
      var errorKey = ctrl.$$parserName || 'parse';
      if (parserValid === undefined) {
        setValidity(errorKey, null);
      } else {
        if (!parserValid) {
          forEach(ctrl.$validators, function(v, name) {
            setValidity(name, null);
          });
          forEach(ctrl.$asyncValidators, function(v, name) {
            setValidity(name, null);
          });
        }
        // Set the parse error last, to prevent unsetting it, should a $validators key == parserName
        setValidity(errorKey, parserValid);
        return parserValid;
      }
      return true;
    }

    function processSyncValidators() {
      var syncValidatorsValid = true;
      forEach(ctrl.$validators, function(validator, name) {
        var result = validator(modelValue, viewValue);
        syncValidatorsValid = syncValidatorsValid && result;
        setValidity(name, result);
      });
      if (!syncValidatorsValid) {
        forEach(ctrl.$asyncValidators, function(v, name) {
          setValidity(name, null);
        });
        return false;
      }
      return true;
    }

    function processAsyncValidators() {
      var validatorPromises = [];
      var allValid = true;
      forEach(ctrl.$asyncValidators, function(validator, name) {
        var promise = validator(modelValue, viewValue);
        if (!isPromiseLike(promise)) {
          throw ngModelMinErr("$asyncValidators",
            "Expected asynchronous validator to return a promise but got '{0}' instead.", promise);
        }
        setValidity(name, undefined);
        validatorPromises.push(promise.then(function() {
          setValidity(name, true);
        }, function(error) {
          allValid = false;
          setValidity(name, false);
        }));
      });
      if (!validatorPromises.length) {
        validationDone(true);
      } else {
        $q.all(validatorPromises).then(function() {
          validationDone(allValid);
        }, noop);
      }
    }

    function setValidity(name, isValid) {
      if (localValidationRunId === currentValidationRunId) {
        ctrl.$setValidity(name, isValid);
      }
    }

    function validationDone(allValid) {
      if (localValidationRunId === currentValidationRunId) {

        doneCallback(allValid);
      }
    }
  };

  /**
   * @ngdoc method
   * @name ngModel.NgModelController#$commitViewValue
   *
   * @description
   * Commit a pending update to the `$modelValue`.
   *
   * Updates may be pending by a debounced event or because the input is waiting for a some future
   * event defined in `ng-model-options`. this method is rarely needed as `NgModelController`
   * usually handles calling this in response to input events.
   */
  this.$commitViewValue = function() {
    var viewValue = ctrl.$viewValue;

    $timeout.cancel(pendingDebounce);

    // If the view value has not changed then we should just exit, except in the case where there is
    // a native validator on the element. In this case the validation state may have changed even though
    // the viewValue has stayed empty.
    if (ctrl.$$lastCommittedViewValue === viewValue && (viewValue !== '' || !ctrl.$$hasNativeValidators)) {
      return;
    }
    ctrl.$$lastCommittedViewValue = viewValue;

    // change to dirty
    if (ctrl.$pristine) {
      this.$setDirty();
    }
    this.$$parseAndValidate();
  };

  this.$$parseAndValidate = function() {
    var viewValue = ctrl.$$lastCommittedViewValue;
    var modelValue = viewValue;
    parserValid = isUndefined(modelValue) ? undefined : true;

    if (parserValid) {
      for (var i = 0; i < ctrl.$parsers.length; i++) {
        modelValue = ctrl.$parsers[i](modelValue);
        if (isUndefined(modelValue)) {
          parserValid = false;
          break;
        }
      }
    }
    if (isNumber(ctrl.$modelValue) && isNaN(ctrl.$modelValue)) {
      // ctrl.$modelValue has not been touched yet...
      ctrl.$modelValue = ngModelGet($scope);
    }
    var prevModelValue = ctrl.$modelValue;
    var allowInvalid = ctrl.$options && ctrl.$options.allowInvalid;
    ctrl.$$rawModelValue = modelValue;

    if (allowInvalid) {
      ctrl.$modelValue = modelValue;
      writeToModelIfNeeded();
    }

    // Pass the $$lastCommittedViewValue here, because the cached viewValue might be out of date.
    // This can happen if e.g. $setViewValue is called from inside a parser
    ctrl.$$runValidators(modelValue, ctrl.$$lastCommittedViewValue, function(allValid) {
      if (!allowInvalid) {
        // Note: Don't check ctrl.$valid here, as we could have
        // external validators (e.g. calculated on the server),
        // that just call $setValidity and need the model value
        // to calculate their validity.
        ctrl.$modelValue = allValid ? modelValue : undefined;
        writeToModelIfNeeded();
      }
    });

    function writeToModelIfNeeded() {
      if (ctrl.$modelValue !== prevModelValue) {
        ctrl.$$writeModelToScope();
      }
    }
  };

  this.$$writeModelToScope = function() {
    ngModelSet($scope, ctrl.$modelValue);
    forEach(ctrl.$viewChangeListeners, function(listener) {
      try {
        listener();
      } catch (e) {
        $exceptionHandler(e);
      }
    });
  };

  /**
   * @ngdoc method
   * @name ngModel.NgModelController#$setViewValue
   *
   * @description
   * Update the view value.
   *
   * This method should be called when an input directive want to change the view value; typically,
   * this is done from within a DOM event handler.
   *
   * For example {@link ng.directive:input input} calls it when the value of the input changes and
   * {@link ng.directive:select select} calls it when an option is selected.
   *
   * If the new `value` is an object (rather than a string or a number), we should make a copy of the
   * object before passing it to `$setViewValue`.  This is because `ngModel` does not perform a deep
   * watch of objects, it only looks for a change of identity. If you only change the property of
   * the object then ngModel will not realise that the object has changed and will not invoke the
   * `$parsers` and `$validators` pipelines.
   *
   * For this reason, you should not change properties of the copy once it has been passed to
   * `$setViewValue`. Otherwise you may cause the model value on the scope to change incorrectly.
   *
   * When this method is called, the new `value` will be staged for committing through the `$parsers`
   * and `$validators` pipelines. If there are no special {@link ngModelOptions} specified then the staged
   * value sent directly for processing, finally to be applied to `$modelValue` and then the
   * **expression** specified in the `ng-model` attribute.
   *
   * Lastly, all the registered change listeners, in the `$viewChangeListeners` list, are called.
   *
   * In case the {@link ng.directive:ngModelOptions ngModelOptions} directive is used with `updateOn`
   * and the `default` trigger is not listed, all those actions will remain pending until one of the
   * `updateOn` events is triggered on the DOM element.
   * All these actions will be debounced if the {@link ng.directive:ngModelOptions ngModelOptions}
   * directive is used with a custom debounce for this particular event.
   *
   * Note that calling this function does not trigger a `$digest`.
   *
   * @param {string} value Value from the view.
   * @param {string} trigger Event that triggered the update.
   */
  this.$setViewValue = function(value, trigger) {
    ctrl.$viewValue = value;
    if (!ctrl.$options || ctrl.$options.updateOnDefault) {
      ctrl.$$debounceViewValueCommit(trigger);
    }
  };

  this.$$debounceViewValueCommit = function(trigger) {
    var debounceDelay = 0,
        options = ctrl.$options,
        debounce;

    if (options && isDefined(options.debounce)) {
      debounce = options.debounce;
      if (isNumber(debounce)) {
        debounceDelay = debounce;
      } else if (isNumber(debounce[trigger])) {
        debounceDelay = debounce[trigger];
      } else if (isNumber(debounce['default'])) {
        debounceDelay = debounce['default'];
      }
    }

    $timeout.cancel(pendingDebounce);
    if (debounceDelay) {
      pendingDebounce = $timeout(function() {
        ctrl.$commitViewValue();
      }, debounceDelay);
    } else if ($rootScope.$$phase) {
      ctrl.$commitViewValue();
    } else {
      $scope.$apply(function() {
        ctrl.$commitViewValue();
      });
    }
  };

  // model -> value
  // Note: we cannot use a normal scope.$watch as we want to detect the following:
  // 1. scope value is 'a'
  // 2. user enters 'b'
  // 3. ng-change kicks in and reverts scope value to 'a'
  //    -> scope value did not change since the last digest as
  //       ng-change executes in apply phase
  // 4. view should be changed back to 'a'
  $scope.$watch(function ngModelWatch() {
    var modelValue = ngModelGet($scope);

    // if scope model value and ngModel value are out of sync
    // TODO(perf): why not move this to the action fn?
    if (modelValue !== ctrl.$modelValue &&
       // checks for NaN is needed to allow setting the model to NaN when there's an asyncValidator
       (ctrl.$modelValue === ctrl.$modelValue || modelValue === modelValue)
    ) {
      ctrl.$modelValue = ctrl.$$rawModelValue = modelValue;
      parserValid = undefined;

      var formatters = ctrl.$formatters,
          idx = formatters.length;

      var viewValue = modelValue;
      while (idx--) {
        viewValue = formatters[idx](viewValue);
      }
      if (ctrl.$viewValue !== viewValue) {
        ctrl.$viewValue = ctrl.$$lastCommittedViewValue = viewValue;
        ctrl.$render();

        ctrl.$$runValidators(modelValue, viewValue, noop);
      }
    }

    return modelValue;
  });
}];


/**
 * @ngdoc directive
 * @name ngModel
 *
 * @element input
 * @priority 1
 *
 * @description
 * The `ngModel` directive binds an `input`,`select`, `textarea` (or custom form control) to a
 * property on the scope using {@link ngModel.NgModelController NgModelController},
 * which is created and exposed by this directive.
 *
 * `ngModel` is responsible for:
 *
 * - Binding the view into the model, which other directives such as `input`, `textarea` or `select`
 *   require.
 * - Providing validation behavior (i.e. required, number, email, url).
 * - Keeping the state of the control (valid/invalid, dirty/pristine, touched/untouched, validation errors).
 * - Setting related css classes on the element (`ng-valid`, `ng-invalid`, `ng-dirty`, `ng-pristine`, `ng-touched`, `ng-untouched`) including animations.
 * - Registering the control with its parent {@link ng.directive:form form}.
 *
 * Note: `ngModel` will try to bind to the property given by evaluating the expression on the
 * current scope. If the property doesn't already exist on this scope, it will be created
 * implicitly and added to the scope.
 *
 * For best practices on using `ngModel`, see:
 *
 *  - [Understanding Scopes](https://github.com/angular/angular.js/wiki/Understanding-Scopes)
 *
 * For basic examples, how to use `ngModel`, see:
 *
 *  - {@link ng.directive:input input}
 *    - {@link input[text] text}
 *    - {@link input[checkbox] checkbox}
 *    - {@link input[radio] radio}
 *    - {@link input[number] number}
 *    - {@link input[email] email}
 *    - {@link input[url] url}
 *    - {@link input[date] date}
 *    - {@link input[datetime-local] datetime-local}
 *    - {@link input[time] time}
 *    - {@link input[month] month}
 *    - {@link input[week] week}
 *  - {@link ng.directive:select select}
 *  - {@link ng.directive:textarea textarea}
 *
 * # CSS classes
 * The following CSS classes are added and removed on the associated input/select/textarea element
 * depending on the validity of the model.
 *
 *  - `ng-valid`: the model is valid
 *  - `ng-invalid`: the model is invalid
 *  - `ng-valid-[key]`: for each valid key added by `$setValidity`
 *  - `ng-invalid-[key]`: for each invalid key added by `$setValidity`
 *  - `ng-pristine`: the control hasn't been interacted with yet
 *  - `ng-dirty`: the control has been interacted with
 *  - `ng-touched`: the control has been blurred
 *  - `ng-untouched`: the control hasn't been blurred
 *  - `ng-pending`: any `$asyncValidators` are unfulfilled
 *
 * Keep in mind that ngAnimate can detect each of these classes when added and removed.
 *
 * ## Animation Hooks
 *
 * Animations within models are triggered when any of the associated CSS classes are added and removed
 * on the input element which is attached to the model. These classes are: `.ng-pristine`, `.ng-dirty`,
 * `.ng-invalid` and `.ng-valid` as well as any other validations that are performed on the model itself.
 * The animations that are triggered within ngModel are similar to how they work in ngClass and
 * animations can be hooked into using CSS transitions, keyframes as well as JS animations.
 *
 * The following example shows a simple way to utilize CSS transitions to style an input element
 * that has been rendered as invalid after it has been validated:
 *
 * <pre>
 * //be sure to include ngAnimate as a module to hook into more
 * //advanced animations
 * .my-input {
 *   transition:0.5s linear all;
 *   background: white;
 * }
 * .my-input.ng-invalid {
 *   background: red;
 *   color:white;
 * }
 * </pre>
 *
 * @example
 * <example deps="angular-animate.js" animations="true" fixBase="true" module="inputExample">
     <file name="index.html">
       <script>
        angular.module('inputExample', [])
          .controller('ExampleController', ['$scope', function($scope) {
            $scope.val = '1';
          }]);
       </script>
       <style>
         .my-input {
           -webkit-transition:all linear 0.5s;
           transition:all linear 0.5s;
           background: transparent;
         }
         .my-input.ng-invalid {
           color:white;
           background: red;
         }
       </style>
       Update input to see transitions when valid/invalid.
       Integer is a valid value.
       <form name="testForm" ng-controller="ExampleController">
         <input ng-model="val" ng-pattern="/^\d+$/" name="anim" class="my-input" />
       </form>
     </file>
 * </example>
 *
 * ## Binding to a getter/setter
 *
 * Sometimes it's helpful to bind `ngModel` to a getter/setter function.  A getter/setter is a
 * function that returns a representation of the model when called with zero arguments, and sets
 * the internal state of a model when called with an argument. It's sometimes useful to use this
 * for models that have an internal representation that's different than what the model exposes
 * to the view.
 *
 * <div class="alert alert-success">
 * **Best Practice:** It's best to keep getters fast because Angular is likely to call them more
 * frequently than other parts of your code.
 * </div>
 *
 * You use this behavior by adding `ng-model-options="{ getterSetter: true }"` to an element that
 * has `ng-model` attached to it. You can also add `ng-model-options="{ getterSetter: true }"` to
 * a `<form>`, which will enable this behavior for all `<input>`s within it. See
 * {@link ng.directive:ngModelOptions `ngModelOptions`} for more.
 *
 * The following example shows how to use `ngModel` with a getter/setter:
 *
 * @example
 * <example name="ngModel-getter-setter" module="getterSetterExample">
     <file name="index.html">
       <div ng-controller="ExampleController">
         <form name="userForm">
           Name:
           <input type="text" name="userName"
                  ng-model="user.name"
                  ng-model-options="{ getterSetter: true }" />
         </form>
         <pre>user.name = <span ng-bind="user.name()"></span></pre>
       </div>
     </file>
     <file name="app.js">
       angular.module('getterSetterExample', [])
         .controller('ExampleController', ['$scope', function($scope) {
           var _name = 'Brian';
           $scope.user = {
             name: function(newName) {
              // Note that newName can be undefined for two reasons:
              // 1. Because it is called as a getter and thus called with no arguments
              // 2. Because the property should actually be set to undefined. This happens e.g. if the
              //    input is invalid
              return arguments.length ? (_name = newName) : _name;
             }
           };
         }]);
     </file>
 * </example>
 */
var ngModelDirective = ['$rootScope', function($rootScope) {
  return {
    restrict: 'A',
    require: ['ngModel', '^?form', '^?ngModelOptions'],
    controller: NgModelController,
    // Prelink needs to run before any input directive
    // so that we can set the NgModelOptions in NgModelController
    // before anyone else uses it.
    priority: 1,
    compile: function ngModelCompile(element) {
      // Setup initial state of the control
      element.addClass(PRISTINE_CLASS).addClass(UNTOUCHED_CLASS).addClass(VALID_CLASS);

      return {
        pre: function ngModelPreLink(scope, element, attr, ctrls) {
          var modelCtrl = ctrls[0],
              formCtrl = ctrls[1] || nullFormCtrl;

          modelCtrl.$$setOptions(ctrls[2] && ctrls[2].$options);

          // notify others, especially parent forms
          formCtrl.$addControl(modelCtrl);

          attr.$observe('name', function(newValue) {
            if (modelCtrl.$name !== newValue) {
              formCtrl.$$renameControl(modelCtrl, newValue);
            }
          });

          scope.$on('$destroy', function() {
            formCtrl.$removeControl(modelCtrl);
          });
        },
        post: function ngModelPostLink(scope, element, attr, ctrls) {
          var modelCtrl = ctrls[0];
          if (modelCtrl.$options && modelCtrl.$options.updateOn) {
            element.on(modelCtrl.$options.updateOn, function(ev) {
              modelCtrl.$$debounceViewValueCommit(ev && ev.type);
            });
          }

          element.on('blur', function(ev) {
            if (modelCtrl.$touched) return;

            if ($rootScope.$$phase) {
              scope.$evalAsync(modelCtrl.$setTouched);
            } else {
              scope.$apply(modelCtrl.$setTouched);
            }
          });
        }
      };
    }
  };
}];

var DEFAULT_REGEXP = /(\s+|^)default(\s+|$)/;

/**
 * @ngdoc directive
 * @name ngModelOptions
 *
 * @description
 * Allows tuning how model updates are done. Using `ngModelOptions` you can specify a custom list of
 * events that will trigger a model update and/or a debouncing delay so that the actual update only
 * takes place when a timer expires; this timer will be reset after another change takes place.
 *
 * Given the nature of `ngModelOptions`, the value displayed inside input fields in the view might
 * be different than the value in the actual model. This means that if you update the model you
 * should also invoke {@link ngModel.NgModelController `$rollbackViewValue`} on the relevant input field in
 * order to make sure it is synchronized with the model and that any debounced action is canceled.
 *
 * The easiest way to reference the control's {@link ngModel.NgModelController `$rollbackViewValue`}
 * method is by making sure the input is placed inside a form that has a `name` attribute. This is
 * important because `form` controllers are published to the related scope under the name in their
 * `name` attribute.
 *
 * Any pending changes will take place immediately when an enclosing form is submitted via the
 * `submit` event. Note that `ngClick` events will occur before the model is updated. Use `ngSubmit`
 * to have access to the updated model.
 *
 * `ngModelOptions` has an effect on the element it's declared on and its descendants.
 *
 * @param {Object} ngModelOptions options to apply to the current model. Valid keys are:
 *   - `updateOn`: string specifying which event should the input be bound to. You can set several
 *     events using an space delimited list. There is a special event called `default` that
 *     matches the default events belonging of the control.
 *   - `debounce`: integer value which contains the debounce model update value in milliseconds. A
 *     value of 0 triggers an immediate update. If an object is supplied instead, you can specify a
 *     custom value for each event. For example:
 *     `ng-model-options="{ updateOn: 'default blur', debounce: {'default': 500, 'blur': 0} }"`
 *   - `allowInvalid`: boolean value which indicates that the model can be set with values that did
 *     not validate correctly instead of the default behavior of setting the model to undefined.
 *   - `getterSetter`: boolean value which determines whether or not to treat functions bound to
       `ngModel` as getters/setters.
 *   - `timezone`: Defines the timezone to be used to read/write the `Date` instance in the model for
 *     `<input type="date">`, `<input type="time">`, ... . Right now, the only supported value is `'UTC'`,
 *     otherwise the default timezone of the browser will be used.
 *
 * @example

  The following example shows how to override immediate updates. Changes on the inputs within the
  form will update the model only when the control loses focus (blur event). If `escape` key is
  pressed while the input field is focused, the value is reset to the value in the current model.

  <example name="ngModelOptions-directive-blur" module="optionsExample">
    <file name="index.html">
      <div ng-controller="ExampleController">
        <form name="userForm">
          Name:
          <input type="text" name="userName"
                 ng-model="user.name"
                 ng-model-options="{ updateOn: 'blur' }"
                 ng-keyup="cancel($event)" /><br />

          Other data:
          <input type="text" ng-model="user.data" /><br />
        </form>
        <pre>user.name = <span ng-bind="user.name"></span></pre>
      </div>
    </file>
    <file name="app.js">
      angular.module('optionsExample', [])
        .controller('ExampleController', ['$scope', function($scope) {
          $scope.user = { name: 'say', data: '' };

          $scope.cancel = function(e) {
            if (e.keyCode == 27) {
              $scope.userForm.userName.$rollbackViewValue();
            }
          };
        }]);
    </file>
    <file name="protractor.js" type="protractor">
      var model = element(by.binding('user.name'));
      var input = element(by.model('user.name'));
      var other = element(by.model('user.data'));

      it('should allow custom events', function() {
        input.sendKeys(' hello');
        input.click();
        expect(model.getText()).toEqual('say');
        other.click();
        expect(model.getText()).toEqual('say hello');
      });

      it('should $rollbackViewValue when model changes', function() {
        input.sendKeys(' hello');
        expect(input.getAttribute('value')).toEqual('say hello');
        input.sendKeys(protractor.Key.ESCAPE);
        expect(input.getAttribute('value')).toEqual('say');
        other.click();
        expect(model.getText()).toEqual('say');
      });
    </file>
  </example>

  This one shows how to debounce model changes. Model will be updated only 1 sec after last change.
  If the `Clear` button is pressed, any debounced action is canceled and the value becomes empty.

  <example name="ngModelOptions-directive-debounce" module="optionsExample">
    <file name="index.html">
      <div ng-controller="ExampleController">
        <form name="userForm">
          Name:
          <input type="text" name="userName"
                 ng-model="user.name"
                 ng-model-options="{ debounce: 1000 }" />
          <button ng-click="userForm.userName.$rollbackViewValue(); user.name=''">Clear</button><br />
        </form>
        <pre>user.name = <span ng-bind="user.name"></span></pre>
      </div>
    </file>
    <file name="app.js">
      angular.module('optionsExample', [])
        .controller('ExampleController', ['$scope', function($scope) {
          $scope.user = { name: 'say' };
        }]);
    </file>
  </example>

  This one shows how to bind to getter/setters:

  <example name="ngModelOptions-directive-getter-setter" module="getterSetterExample">
    <file name="index.html">
      <div ng-controller="ExampleController">
        <form name="userForm">
          Name:
          <input type="text" name="userName"
                 ng-model="user.name"
                 ng-model-options="{ getterSetter: true }" />
        </form>
        <pre>user.name = <span ng-bind="user.name()"></span></pre>
      </div>
    </file>
    <file name="app.js">
      angular.module('getterSetterExample', [])
        .controller('ExampleController', ['$scope', function($scope) {
          var _name = 'Brian';
          $scope.user = {
            name: function(newName) {
              // Note that newName can be undefined for two reasons:
              // 1. Because it is called as a getter and thus called with no arguments
              // 2. Because the property should actually be set to undefined. This happens e.g. if the
              //    input is invalid
              return arguments.length ? (_name = newName) : _name;
            }
          };
        }]);
    </file>
  </example>
 */
var ngModelOptionsDirective = function() {
  return {
    restrict: 'A',
    controller: ['$scope', '$attrs', function($scope, $attrs) {
      var that = this;
      this.$options = $scope.$eval($attrs.ngModelOptions);
      // Allow adding/overriding bound events
      if (this.$options.updateOn !== undefined) {
        this.$options.updateOnDefault = false;
        // extract "default" pseudo-event from list of events that can trigger a model update
        this.$options.updateOn = trim(this.$options.updateOn.replace(DEFAULT_REGEXP, function() {
          that.$options.updateOnDefault = true;
          return ' ';
        }));
      } else {
        this.$options.updateOnDefault = true;
      }
    }]
  };
};



// helper methods
function addSetValidityMethod(context) {
  var ctrl = context.ctrl,
      $element = context.$element,
      classCache = {},
      set = context.set,
      unset = context.unset,
      parentForm = context.parentForm,
      $animate = context.$animate;

  classCache[INVALID_CLASS] = !(classCache[VALID_CLASS] = $element.hasClass(VALID_CLASS));

  ctrl.$setValidity = setValidity;

  function setValidity(validationErrorKey, state, controller) {
    if (state === undefined) {
      createAndSet('$pending', validationErrorKey, controller);
    } else {
      unsetAndCleanup('$pending', validationErrorKey, controller);
    }
    if (!isBoolean(state)) {
      unset(ctrl.$error, validationErrorKey, controller);
      unset(ctrl.$$success, validationErrorKey, controller);
    } else {
      if (state) {
        unset(ctrl.$error, validationErrorKey, controller);
        set(ctrl.$$success, validationErrorKey, controller);
      } else {
        set(ctrl.$error, validationErrorKey, controller);
        unset(ctrl.$$success, validationErrorKey, controller);
      }
    }
    if (ctrl.$pending) {
      cachedToggleClass(PENDING_CLASS, true);
      ctrl.$valid = ctrl.$invalid = undefined;
      toggleValidationCss('', null);
    } else {
      cachedToggleClass(PENDING_CLASS, false);
      ctrl.$valid = isObjectEmpty(ctrl.$error);
      ctrl.$invalid = !ctrl.$valid;
      toggleValidationCss('', ctrl.$valid);
    }

    // re-read the state as the set/unset methods could have
    // combined state in ctrl.$error[validationError] (used for forms),
    // where setting/unsetting only increments/decrements the value,
    // and does not replace it.
    var combinedState;
    if (ctrl.$pending && ctrl.$pending[validationErrorKey]) {
      combinedState = undefined;
    } else if (ctrl.$error[validationErrorKey]) {
      combinedState = false;
    } else if (ctrl.$$success[validationErrorKey]) {
      combinedState = true;
    } else {
      combinedState = null;
    }

    toggleValidationCss(validationErrorKey, combinedState);
    parentForm.$setValidity(validationErrorKey, combinedState, ctrl);
  }

  function createAndSet(name, value, controller) {
    if (!ctrl[name]) {
      ctrl[name] = {};
    }
    set(ctrl[name], value, controller);
  }

  function unsetAndCleanup(name, value, controller) {
    if (ctrl[name]) {
      unset(ctrl[name], value, controller);
    }
    if (isObjectEmpty(ctrl[name])) {
      ctrl[name] = undefined;
    }
  }

  function cachedToggleClass(className, switchValue) {
    if (switchValue && !classCache[className]) {
      $animate.addClass($element, className);
      classCache[className] = true;
    } else if (!switchValue && classCache[className]) {
      $animate.removeClass($element, className);
      classCache[className] = false;
    }
  }

  function toggleValidationCss(validationErrorKey, isValid) {
    validationErrorKey = validationErrorKey ? '-' + snake_case(validationErrorKey, '-') : '';

    cachedToggleClass(VALID_CLASS + validationErrorKey, isValid === true);
    cachedToggleClass(INVALID_CLASS + validationErrorKey, isValid === false);
  }
}

function isObjectEmpty(obj) {
  if (obj) {
    for (var prop in obj) {
      return false;
    }
  }
  return true;
}

/**
 * @ngdoc directive
 * @name ngNonBindable
 * @restrict AC
 * @priority 1000
 *
 * @description
 * The `ngNonBindable` directive tells Angular not to compile or bind the contents of the current
 * DOM element. This is useful if the element contains what appears to be Angular directives and
 * bindings but which should be ignored by Angular. This could be the case if you have a site that
 * displays snippets of code, for instance.
 *
 * @element ANY
 *
 * @example
 * In this example there are two locations where a simple interpolation binding (`{{}}`) is present,
 * but the one wrapped in `ngNonBindable` is left alone.
 *
 * @example
    <example>
      <file name="index.html">
        <div>Normal: {{1 + 2}}</div>
        <div ng-non-bindable>Ignored: {{1 + 2}}</div>
      </file>
      <file name="protractor.js" type="protractor">
       it('should check ng-non-bindable', function() {
         expect(element(by.binding('1 + 2')).getText()).toContain('3');
         expect(element.all(by.css('div')).last().getText()).toMatch(/1 \+ 2/);
       });
      </file>
    </example>
 */
var ngNonBindableDirective = ngDirective({ terminal: true, priority: 1000 });

/**
 * @ngdoc directive
 * @name ngPluralize
 * @restrict EA
 *
 * @description
 * `ngPluralize` is a directive that displays messages according to en-US localization rules.
 * These rules are bundled with angular.js, but can be overridden
 * (see {@link guide/i18n Angular i18n} dev guide). You configure ngPluralize directive
 * by specifying the mappings between
 * [plural categories](http://unicode.org/repos/cldr-tmp/trunk/diff/supplemental/language_plural_rules.html)
 * and the strings to be displayed.
 *
 * # Plural categories and explicit number rules
 * There are two
 * [plural categories](http://unicode.org/repos/cldr-tmp/trunk/diff/supplemental/language_plural_rules.html)
 * in Angular's default en-US locale: "one" and "other".
 *
 * While a plural category may match many numbers (for example, in en-US locale, "other" can match
 * any number that is not 1), an explicit number rule can only match one number. For example, the
 * explicit number rule for "3" matches the number 3. There are examples of plural categories
 * and explicit number rules throughout the rest of this documentation.
 *
 * # Configuring ngPluralize
 * You configure ngPluralize by providing 2 attributes: `count` and `when`.
 * You can also provide an optional attribute, `offset`.
 *
 * The value of the `count` attribute can be either a string or an {@link guide/expression
 * Angular expression}; these are evaluated on the current scope for its bound value.
 *
 * The `when` attribute specifies the mappings between plural categories and the actual
 * string to be displayed. The value of the attribute should be a JSON object.
 *
 * The following example shows how to configure ngPluralize:
 *
 * ```html
 * <ng-pluralize count="personCount"
                 when="{'0': 'Nobody is viewing.',
 *                      'one': '1 person is viewing.',
 *                      'other': '{} people are viewing.'}">
 * </ng-pluralize>
 *```
 *
 * In the example, `"0: Nobody is viewing."` is an explicit number rule. If you did not
 * specify this rule, 0 would be matched to the "other" category and "0 people are viewing"
 * would be shown instead of "Nobody is viewing". You can specify an explicit number rule for
 * other numbers, for example 12, so that instead of showing "12 people are viewing", you can
 * show "a dozen people are viewing".
 *
 * You can use a set of closed braces (`{}`) as a placeholder for the number that you want substituted
 * into pluralized strings. In the previous example, Angular will replace `{}` with
 * <span ng-non-bindable>`{{personCount}}`</span>. The closed braces `{}` is a placeholder
 * for <span ng-non-bindable>{{numberExpression}}</span>.
 *
 * # Configuring ngPluralize with offset
 * The `offset` attribute allows further customization of pluralized text, which can result in
 * a better user experience. For example, instead of the message "4 people are viewing this document",
 * you might display "John, Kate and 2 others are viewing this document".
 * The offset attribute allows you to offset a number by any desired value.
 * Let's take a look at an example:
 *
 * ```html
 * <ng-pluralize count="personCount" offset=2
 *               when="{'0': 'Nobody is viewing.',
 *                      '1': '{{person1}} is viewing.',
 *                      '2': '{{person1}} and {{person2}} are viewing.',
 *                      'one': '{{person1}}, {{person2}} and one other person are viewing.',
 *                      'other': '{{person1}}, {{person2}} and {} other people are viewing.'}">
 * </ng-pluralize>
 * ```
 *
 * Notice that we are still using two plural categories(one, other), but we added
 * three explicit number rules 0, 1 and 2.
 * When one person, perhaps John, views the document, "John is viewing" will be shown.
 * When three people view the document, no explicit number rule is found, so
 * an offset of 2 is taken off 3, and Angular uses 1 to decide the plural category.
 * In this case, plural category 'one' is matched and "John, Mary and one other person are viewing"
 * is shown.
 *
 * Note that when you specify offsets, you must provide explicit number rules for
 * numbers from 0 up to and including the offset. If you use an offset of 3, for example,
 * you must provide explicit number rules for 0, 1, 2 and 3. You must also provide plural strings for
 * plural categories "one" and "other".
 *
 * @param {string|expression} count The variable to be bound to.
 * @param {string} when The mapping between plural category to its corresponding strings.
 * @param {number=} offset Offset to deduct from the total number.
 *
 * @example
    <example module="pluralizeExample">
      <file name="index.html">
        <script>
          angular.module('pluralizeExample', [])
            .controller('ExampleController', ['$scope', function($scope) {
              $scope.person1 = 'Igor';
              $scope.person2 = 'Misko';
              $scope.personCount = 1;
            }]);
        </script>
        <div ng-controller="ExampleController">
          Person 1:<input type="text" ng-model="person1" value="Igor" /><br/>
          Person 2:<input type="text" ng-model="person2" value="Misko" /><br/>
          Number of People:<input type="text" ng-model="personCount" value="1" /><br/>

          <!--- Example with simple pluralization rules for en locale --->
          Without Offset:
          <ng-pluralize count="personCount"
                        when="{'0': 'Nobody is viewing.',
                               'one': '1 person is viewing.',
                               'other': '{} people are viewing.'}">
          </ng-pluralize><br>

          <!--- Example with offset --->
          With Offset(2):
          <ng-pluralize count="personCount" offset=2
                        when="{'0': 'Nobody is viewing.',
                               '1': '{{person1}} is viewing.',
                               '2': '{{person1}} and {{person2}} are viewing.',
                               'one': '{{person1}}, {{person2}} and one other person are viewing.',
                               'other': '{{person1}}, {{person2}} and {} other people are viewing.'}">
          </ng-pluralize>
        </div>
      </file>
      <file name="protractor.js" type="protractor">
        it('should show correct pluralized string', function() {
          var withoutOffset = element.all(by.css('ng-pluralize')).get(0);
          var withOffset = element.all(by.css('ng-pluralize')).get(1);
          var countInput = element(by.model('personCount'));

          expect(withoutOffset.getText()).toEqual('1 person is viewing.');
          expect(withOffset.getText()).toEqual('Igor is viewing.');

          countInput.clear();
          countInput.sendKeys('0');

          expect(withoutOffset.getText()).toEqual('Nobody is viewing.');
          expect(withOffset.getText()).toEqual('Nobody is viewing.');

          countInput.clear();
          countInput.sendKeys('2');

          expect(withoutOffset.getText()).toEqual('2 people are viewing.');
          expect(withOffset.getText()).toEqual('Igor and Misko are viewing.');

          countInput.clear();
          countInput.sendKeys('3');

          expect(withoutOffset.getText()).toEqual('3 people are viewing.');
          expect(withOffset.getText()).toEqual('Igor, Misko and one other person are viewing.');

          countInput.clear();
          countInput.sendKeys('4');

          expect(withoutOffset.getText()).toEqual('4 people are viewing.');
          expect(withOffset.getText()).toEqual('Igor, Misko and 2 other people are viewing.');
        });
        it('should show data-bound names', function() {
          var withOffset = element.all(by.css('ng-pluralize')).get(1);
          var personCount = element(by.model('personCount'));
          var person1 = element(by.model('person1'));
          var person2 = element(by.model('person2'));
          personCount.clear();
          personCount.sendKeys('4');
          person1.clear();
          person1.sendKeys('Di');
          person2.clear();
          person2.sendKeys('Vojta');
          expect(withOffset.getText()).toEqual('Di, Vojta and 2 other people are viewing.');
        });
      </file>
    </example>
 */
var ngPluralizeDirective = ['$locale', '$interpolate', function($locale, $interpolate) {
  var BRACE = /{}/g,
      IS_WHEN = /^when(Minus)?(.+)$/;

  return {
    restrict: 'EA',
    link: function(scope, element, attr) {
      var numberExp = attr.count,
          whenExp = attr.$attr.when && element.attr(attr.$attr.when), // we have {{}} in attrs
          offset = attr.offset || 0,
          whens = scope.$eval(whenExp) || {},
          whensExpFns = {},
          startSymbol = $interpolate.startSymbol(),
          endSymbol = $interpolate.endSymbol(),
          braceReplacement = startSymbol + numberExp + '-' + offset + endSymbol,
          watchRemover = angular.noop,
          lastCount;

      forEach(attr, function(expression, attributeName) {
        var tmpMatch = IS_WHEN.exec(attributeName);
        if (tmpMatch) {
          var whenKey = (tmpMatch[1] ? '-' : '') + lowercase(tmpMatch[2]);
          whens[whenKey] = element.attr(attr.$attr[attributeName]);
        }
      });
      forEach(whens, function(expression, key) {
        whensExpFns[key] = $interpolate(expression.replace(BRACE, braceReplacement));

      });

      scope.$watch(numberExp, function ngPluralizeWatchAction(newVal) {
        var count = parseFloat(newVal);
        var countIsNaN = isNaN(count);

        if (!countIsNaN && !(count in whens)) {
          // If an explicit number rule such as 1, 2, 3... is defined, just use it.
          // Otherwise, check it against pluralization rules in $locale service.
          count = $locale.pluralCat(count - offset);
        }

        // If both `count` and `lastCount` are NaN, we don't need to re-register a watch.
        // In JS `NaN !== NaN`, so we have to exlicitly check.
        if ((count !== lastCount) && !(countIsNaN && isNaN(lastCount))) {
          watchRemover();
          watchRemover = scope.$watch(whensExpFns[count], updateElementText);
          lastCount = count;
        }
      });

      function updateElementText(newText) {
        element.text(newText || '');
      }
    }
  };
}];

/**
 * @ngdoc directive
 * @name ngRepeat
 *
 * @description
 * The `ngRepeat` directive instantiates a template once per item from a collection. Each template
 * instance gets its own scope, where the given loop variable is set to the current collection item,
 * and `$index` is set to the item index or key.
 *
 * Special properties are exposed on the local scope of each template instance, including:
 *
 * | Variable  | Type            | Details                                                                     |
 * |-----------|-----------------|-----------------------------------------------------------------------------|
 * | `$index`  | {@type number}  | iterator offset of the repeated element (0..length-1)                       |
 * | `$first`  | {@type boolean} | true if the repeated element is first in the iterator.                      |
 * | `$middle` | {@type boolean} | true if the repeated element is between the first and last in the iterator. |
 * | `$last`   | {@type boolean} | true if the repeated element is last in the iterator.                       |
 * | `$even`   | {@type boolean} | true if the iterator position `$index` is even (otherwise false).           |
 * | `$odd`    | {@type boolean} | true if the iterator position `$index` is odd (otherwise false).            |
 *
 * Creating aliases for these properties is possible with {@link ng.directive:ngInit `ngInit`}.
 * This may be useful when, for instance, nesting ngRepeats.
 *
 * # Iterating over object properties
 *
 * It is possible to get `ngRepeat` to iterate over the properties of an object using the following
 * syntax:
 *
 * ```js
 * <div ng-repeat="(key, value) in myObj"> ... </div>
 * ```
 *
 * You need to be aware that the JavaScript specification does not define what order
 * it will return the keys for an object. In order to have a guaranteed deterministic order
 * for the keys, Angular versions up to and including 1.3 **sort the keys alphabetically**.
 *
 * If this is not desired, the recommended workaround is to convert your object into an array
 * that is sorted into the order that you prefer before providing it to `ngRepeat`.  You could
 * do this with a filter such as [toArrayFilter](http://ngmodules.org/modules/angular-toArrayFilter)
 * or implement a `$watch` on the object yourself.
 *
 * In version 1.4 we will remove the sorting, since it seems that browsers generally follow the
 * strategy of providing keys in the order in which they were defined, although there are exceptions
 * when keys are deleted and reinstated.
 *
 *
 * # Tracking and Duplicates
 *
 * When the contents of the collection change, `ngRepeat` makes the corresponding changes to the DOM:
 *
 * * When an item is added, a new instance of the template is added to the DOM.
 * * When an item is removed, its template instance is removed from the DOM.
 * * When items are reordered, their respective templates are reordered in the DOM.
 *
 * By default, `ngRepeat` does not allow duplicate items in arrays. This is because when
 * there are duplicates, it is not possible to maintain a one-to-one mapping between collection
 * items and DOM elements.
 *
 * If you do need to repeat duplicate items, you can substitute the default tracking behavior
 * with your own using the `track by` expression.
 *
 * For example, you may track items by the index of each item in the collection, using the
 * special scope property `$index`:
 * ```html
 *    <div ng-repeat="n in [42, 42, 43, 43] track by $index">
 *      {{n}}
 *    </div>
 * ```
 *
 * You may use arbitrary expressions in `track by`, including references to custom functions
 * on the scope:
 * ```html
 *    <div ng-repeat="n in [42, 42, 43, 43] track by myTrackingFunction(n)">
 *      {{n}}
 *    </div>
 * ```
 *
 * If you are working with objects that have an identifier property, you can track
 * by the identifier instead of the whole object. Should you reload your data later, `ngRepeat`
 * will not have to rebuild the DOM elements for items it has already rendered, even if the
 * JavaScript objects in the collection have been substituted for new ones:
 * ```html
 *    <div ng-repeat="model in collection track by model.id">
 *      {{model.name}}
 *    </div>
 * ```
 *
 * When no `track by` expression is provided, it is equivalent to tracking by the built-in
 * `$id` function, which tracks items by their identity:
 * ```html
 *    <div ng-repeat="obj in collection track by $id(obj)">
 *      {{obj.prop}}
 *    </div>
 * ```
 *
 * # Special repeat start and end points
 * To repeat a series of elements instead of just one parent element, ngRepeat (as well as other ng directives) supports extending
 * the range of the repeater by defining explicit start and end points by using **ng-repeat-start** and **ng-repeat-end** respectively.
 * The **ng-repeat-start** directive works the same as **ng-repeat**, but will repeat all the HTML code (including the tag it's defined on)
 * up to and including the ending HTML tag where **ng-repeat-end** is placed.
 *
 * The example below makes use of this feature:
 * ```html
 *   <header ng-repeat-start="item in items">
 *     Header {{ item }}
 *   </header>
 *   <div class="body">
 *     Body {{ item }}
 *   </div>
 *   <footer ng-repeat-end>
 *     Footer {{ item }}
 *   </footer>
 * ```
 *
 * And with an input of {@type ['A','B']} for the items variable in the example above, the output will evaluate to:
 * ```html
 *   <header>
 *     Header A
 *   </header>
 *   <div class="body">
 *     Body A
 *   </div>
 *   <footer>
 *     Footer A
 *   </footer>
 *   <header>
 *     Header B
 *   </header>
 *   <div class="body">
 *     Body B
 *   </div>
 *   <footer>
 *     Footer B
 *   </footer>
 * ```
 *
 * The custom start and end points for ngRepeat also support all other HTML directive syntax flavors provided in AngularJS (such
 * as **data-ng-repeat-start**, **x-ng-repeat-start** and **ng:repeat-start**).
 *
 * @animations
 * **.enter** - when a new item is added to the list or when an item is revealed after a filter
 *
 * **.leave** - when an item is removed from the list or when an item is filtered out
 *
 * **.move** - when an adjacent item is filtered out causing a reorder or when the item contents are reordered
 *
 * @element ANY
 * @scope
 * @priority 1000
 * @param {repeat_expression} ngRepeat The expression indicating how to enumerate a collection. These
 *   formats are currently supported:
 *
 *   * `variable in expression` – where variable is the user defined loop variable and `expression`
 *     is a scope expression giving the collection to enumerate.
 *
 *     For example: `album in artist.albums`.
 *
 *   * `(key, value) in expression` – where `key` and `value` can be any user defined identifiers,
 *     and `expression` is the scope expression giving the collection to enumerate.
 *
 *     For example: `(name, age) in {'adam':10, 'amalie':12}`.
 *
 *   * `variable in expression track by tracking_expression` – You can also provide an optional tracking expression
 *     which can be used to associate the objects in the collection with the DOM elements. If no tracking expression
 *     is specified, ng-repeat associates elements by identity. It is an error to have
 *     more than one tracking expression value resolve to the same key. (This would mean that two distinct objects are
 *     mapped to the same DOM element, which is not possible.)  If filters are used in the expression, they should be
 *     applied before the tracking expression.
 *
 *     For example: `item in items` is equivalent to `item in items track by $id(item)`. This implies that the DOM elements
 *     will be associated by item identity in the array.
 *
 *     For example: `item in items track by $id(item)`. A built in `$id()` function can be used to assign a unique
 *     `$$hashKey` property to each item in the array. This property is then used as a key to associated DOM elements
 *     with the corresponding item in the array by identity. Moving the same object in array would move the DOM
 *     element in the same way in the DOM.
 *
 *     For example: `item in items track by item.id` is a typical pattern when the items come from the database. In this
 *     case the object identity does not matter. Two objects are considered equivalent as long as their `id`
 *     property is same.
 *
 *     For example: `item in items | filter:searchText track by item.id` is a pattern that might be used to apply a filter
 *     to items in conjunction with a tracking expression.
 *
 *   * `variable in expression as alias_expression` – You can also provide an optional alias expression which will then store the
 *     intermediate results of the repeater after the filters have been applied. Typically this is used to render a special message
 *     when a filter is active on the repeater, but the filtered result set is empty.
 *
 *     For example: `item in items | filter:x as results` will store the fragment of the repeated items as `results`, but only after
 *     the items have been processed through the filter.
 *
 * @example
 * This example initializes the scope to a list of names and
 * then uses `ngRepeat` to display every person:
  <example module="ngAnimate" deps="angular-animate.js" animations="true">
    <file name="index.html">
      <div ng-init="friends = [
        {name:'John', age:25, gender:'boy'},
        {name:'Jessie', age:30, gender:'girl'},
        {name:'Johanna', age:28, gender:'girl'},
        {name:'Joy', age:15, gender:'girl'},
        {name:'Mary', age:28, gender:'girl'},
        {name:'Peter', age:95, gender:'boy'},
        {name:'Sebastian', age:50, gender:'boy'},
        {name:'Erika', age:27, gender:'girl'},
        {name:'Patrick', age:40, gender:'boy'},
        {name:'Samantha', age:60, gender:'girl'}
      ]">
        I have {{friends.length}} friends. They are:
        <input type="search" ng-model="q" placeholder="filter friends..." />
        <ul class="example-animate-container">
          <li class="animate-repeat" ng-repeat="friend in friends | filter:q as results">
            [{{$index + 1}}] {{friend.name}} who is {{friend.age}} years old.
          </li>
          <li class="animate-repeat" ng-if="results.length == 0">
            <strong>No results found...</strong>
          </li>
        </ul>
      </div>
    </file>
    <file name="animations.css">
      .example-animate-container {
        background:white;
        border:1px solid black;
        list-style:none;
        margin:0;
        padding:0 10px;
      }

      .animate-repeat {
        line-height:40px;
        list-style:none;
        box-sizing:border-box;
      }

      .animate-repeat.ng-move,
      .animate-repeat.ng-enter,
      .animate-repeat.ng-leave {
        -webkit-transition:all linear 0.5s;
        transition:all linear 0.5s;
      }

      .animate-repeat.ng-leave.ng-leave-active,
      .animate-repeat.ng-move,
      .animate-repeat.ng-enter {
        opacity:0;
        max-height:0;
      }

      .animate-repeat.ng-leave,
      .animate-repeat.ng-move.ng-move-active,
      .animate-repeat.ng-enter.ng-enter-active {
        opacity:1;
        max-height:40px;
      }
    </file>
    <file name="protractor.js" type="protractor">
      var friends = element.all(by.repeater('friend in friends'));

      it('should render initial data set', function() {
        expect(friends.count()).toBe(10);
        expect(friends.get(0).getText()).toEqual('[1] John who is 25 years old.');
        expect(friends.get(1).getText()).toEqual('[2] Jessie who is 30 years old.');
        expect(friends.last().getText()).toEqual('[10] Samantha who is 60 years old.');
        expect(element(by.binding('friends.length')).getText())
            .toMatch("I have 10 friends. They are:");
      });

       it('should update repeater when filter predicate changes', function() {
         expect(friends.count()).toBe(10);

         element(by.model('q')).sendKeys('ma');

         expect(friends.count()).toBe(2);
         expect(friends.get(0).getText()).toEqual('[1] Mary who is 28 years old.');
         expect(friends.last().getText()).toEqual('[2] Samantha who is 60 years old.');
       });
      </file>
    </example>
 */
var ngRepeatDirective = ['$parse', '$animate', function($parse, $animate) {
  var NG_REMOVED = '$$NG_REMOVED';
  var ngRepeatMinErr = minErr('ngRepeat');

  var updateScope = function(scope, index, valueIdentifier, value, keyIdentifier, key, arrayLength) {
    // TODO(perf): generate setters to shave off ~40ms or 1-1.5%
    scope[valueIdentifier] = value;
    if (keyIdentifier) scope[keyIdentifier] = key;
    scope.$index = index;
    scope.$first = (index === 0);
    scope.$last = (index === (arrayLength - 1));
    scope.$middle = !(scope.$first || scope.$last);
    // jshint bitwise: false
    scope.$odd = !(scope.$even = (index&1) === 0);
    // jshint bitwise: true
  };

  var getBlockStart = function(block) {
    return block.clone[0];
  };

  var getBlockEnd = function(block) {
    return block.clone[block.clone.length - 1];
  };


  return {
    restrict: 'A',
    multiElement: true,
    transclude: 'element',
    priority: 1000,
    terminal: true,
    $$tlb: true,
    compile: function ngRepeatCompile($element, $attr) {
      var expression = $attr.ngRepeat;
      var ngRepeatEndComment = document.createComment(' end ngRepeat: ' + expression + ' ');

      var match = expression.match(/^\s*([\s\S]+?)\s+in\s+([\s\S]+?)(?:\s+as\s+([\s\S]+?))?(?:\s+track\s+by\s+([\s\S]+?))?\s*$/);

      if (!match) {
        throw ngRepeatMinErr('iexp', "Expected expression in form of '_item_ in _collection_[ track by _id_]' but got '{0}'.",
            expression);
      }

      var lhs = match[1];
      var rhs = match[2];
      var aliasAs = match[3];
      var trackByExp = match[4];

      match = lhs.match(/^(?:(\s*[\$\w]+)|\(\s*([\$\w]+)\s*,\s*([\$\w]+)\s*\))$/);

      if (!match) {
        throw ngRepeatMinErr('iidexp', "'_item_' in '_item_ in _collection_' should be an identifier or '(_key_, _value_)' expression, but got '{0}'.",
            lhs);
      }
      var valueIdentifier = match[3] || match[1];
      var keyIdentifier = match[2];

      if (aliasAs && (!/^[$a-zA-Z_][$a-zA-Z0-9_]*$/.test(aliasAs) ||
          /^(null|undefined|this|\$index|\$first|\$middle|\$last|\$even|\$odd|\$parent|\$root|\$id)$/.test(aliasAs))) {
        throw ngRepeatMinErr('badident', "alias '{0}' is invalid --- must be a valid JS identifier which is not a reserved name.",
          aliasAs);
      }

      var trackByExpGetter, trackByIdExpFn, trackByIdArrayFn, trackByIdObjFn;
      var hashFnLocals = {$id: hashKey};

      if (trackByExp) {
        trackByExpGetter = $parse(trackByExp);
      } else {
        trackByIdArrayFn = function(key, value) {
          return hashKey(value);
        };
        trackByIdObjFn = function(key) {
          return key;
        };
      }

      return function ngRepeatLink($scope, $element, $attr, ctrl, $transclude) {

        if (trackByExpGetter) {
          trackByIdExpFn = function(key, value, index) {
            // assign key, value, and $index to the locals so that they can be used in hash functions
            if (keyIdentifier) hashFnLocals[keyIdentifier] = key;
            hashFnLocals[valueIdentifier] = value;
            hashFnLocals.$index = index;
            return trackByExpGetter($scope, hashFnLocals);
          };
        }

        // Store a list of elements from previous run. This is a hash where key is the item from the
        // iterator, and the value is objects with following properties.
        //   - scope: bound scope
        //   - element: previous element.
        //   - index: position
        //
        // We are using no-proto object so that we don't need to guard against inherited props via
        // hasOwnProperty.
        var lastBlockMap = createMap();

        //watch props
        $scope.$watchCollection(rhs, function ngRepeatAction(collection) {
          var index, length,
              previousNode = $element[0],     // node that cloned nodes should be inserted after
                                              // initialized to the comment node anchor
              nextNode,
              // Same as lastBlockMap but it has the current state. It will become the
              // lastBlockMap on the next iteration.
              nextBlockMap = createMap(),
              collectionLength,
              key, value, // key/value of iteration
              trackById,
              trackByIdFn,
              collectionKeys,
              block,       // last object information {scope, element, id}
              nextBlockOrder,
              elementsToRemove;

          if (aliasAs) {
            $scope[aliasAs] = collection;
          }

          if (isArrayLike(collection)) {
            collectionKeys = collection;
            trackByIdFn = trackByIdExpFn || trackByIdArrayFn;
          } else {
            trackByIdFn = trackByIdExpFn || trackByIdObjFn;
            // if object, extract keys, sort them and use to determine order of iteration over obj props
            collectionKeys = [];
            for (var itemKey in collection) {
              if (collection.hasOwnProperty(itemKey) && itemKey.charAt(0) != '$') {
                collectionKeys.push(itemKey);
              }
            }
            collectionKeys.sort();
          }

          collectionLength = collectionKeys.length;
          nextBlockOrder = new Array(collectionLength);

          // locate existing items
          for (index = 0; index < collectionLength; index++) {
            key = (collection === collectionKeys) ? index : collectionKeys[index];
            value = collection[key];
            trackById = trackByIdFn(key, value, index);
            if (lastBlockMap[trackById]) {
              // found previously seen block
              block = lastBlockMap[trackById];
              delete lastBlockMap[trackById];
              nextBlockMap[trackById] = block;
              nextBlockOrder[index] = block;
            } else if (nextBlockMap[trackById]) {
              // if collision detected. restore lastBlockMap and throw an error
              forEach(nextBlockOrder, function(block) {
                if (block && block.scope) lastBlockMap[block.id] = block;
              });
              throw ngRepeatMinErr('dupes',
                  "Duplicates in a repeater are not allowed. Use 'track by' expression to specify unique keys. Repeater: {0}, Duplicate key: {1}, Duplicate value: {2}",
                  expression, trackById, value);
            } else {
              // new never before seen block
              nextBlockOrder[index] = {id: trackById, scope: undefined, clone: undefined};
              nextBlockMap[trackById] = true;
            }
          }

          // remove leftover items
          for (var blockKey in lastBlockMap) {
            block = lastBlockMap[blockKey];
            elementsToRemove = getBlockNodes(block.clone);
            $animate.leave(elementsToRemove);
            if (elementsToRemove[0].parentNode) {
              // if the element was not removed yet because of pending animation, mark it as deleted
              // so that we can ignore it later
              for (index = 0, length = elementsToRemove.length; index < length; index++) {
                elementsToRemove[index][NG_REMOVED] = true;
              }
            }
            block.scope.$destroy();
          }

          // we are not using forEach for perf reasons (trying to avoid #call)
          for (index = 0; index < collectionLength; index++) {
            key = (collection === collectionKeys) ? index : collectionKeys[index];
            value = collection[key];
            block = nextBlockOrder[index];

            if (block.scope) {
              // if we have already seen this object, then we need to reuse the
              // associated scope/element

              nextNode = previousNode;

              // skip nodes that are already pending removal via leave animation
              do {
                nextNode = nextNode.nextSibling;
              } while (nextNode && nextNode[NG_REMOVED]);

              if (getBlockStart(block) != nextNode) {
                // existing item which got moved
                $animate.move(getBlockNodes(block.clone), null, jqLite(previousNode));
              }
              previousNode = getBlockEnd(block);
              updateScope(block.scope, index, valueIdentifier, value, keyIdentifier, key, collectionLength);
            } else {
              // new item which we don't know about
              $transclude(function ngRepeatTransclude(clone, scope) {
                block.scope = scope;
                // http://jsperf.com/clone-vs-createcomment
                var endNode = ngRepeatEndComment.cloneNode(false);
                clone[clone.length++] = endNode;

                // TODO(perf): support naked previousNode in `enter` to avoid creation of jqLite wrapper?
                $animate.enter(clone, null, jqLite(previousNode));
                previousNode = endNode;
                // Note: We only need the first/last node of the cloned nodes.
                // However, we need to keep the reference to the jqlite wrapper as it might be changed later
                // by a directive with templateUrl when its template arrives.
                block.clone = clone;
                nextBlockMap[block.id] = block;
                updateScope(block.scope, index, valueIdentifier, value, keyIdentifier, key, collectionLength);
              });
            }
          }
          lastBlockMap = nextBlockMap;
        });
      };
    }
  };
}];

var NG_HIDE_CLASS = 'ng-hide';
var NG_HIDE_IN_PROGRESS_CLASS = 'ng-hide-animate';
/**
 * @ngdoc directive
 * @name ngShow
 *
 * @description
 * The `ngShow` directive shows or hides the given HTML element based on the expression
 * provided to the `ngShow` attribute. The element is shown or hidden by removing or adding
 * the `.ng-hide` CSS class onto the element. The `.ng-hide` CSS class is predefined
 * in AngularJS and sets the display style to none (using an !important flag).
 * For CSP mode please add `angular-csp.css` to your html file (see {@link ng.directive:ngCsp ngCsp}).
 *
 * ```html
 * <!-- when $scope.myValue is truthy (element is visible) -->
 * <div ng-show="myValue"></div>
 *
 * <!-- when $scope.myValue is falsy (element is hidden) -->
 * <div ng-show="myValue" class="ng-hide"></div>
 * ```
 *
 * When the `ngShow` expression evaluates to a falsy value then the `.ng-hide` CSS class is added to the class
 * attribute on the element causing it to become hidden. When truthy, the `.ng-hide` CSS class is removed
 * from the element causing the element not to appear hidden.
 *
 * ## Why is !important used?
 *
 * You may be wondering why !important is used for the `.ng-hide` CSS class. This is because the `.ng-hide` selector
 * can be easily overridden by heavier selectors. For example, something as simple
 * as changing the display style on a HTML list item would make hidden elements appear visible.
 * This also becomes a bigger issue when dealing with CSS frameworks.
 *
 * By using !important, the show and hide behavior will work as expected despite any clash between CSS selector
 * specificity (when !important isn't used with any conflicting styles). If a developer chooses to override the
 * styling to change how to hide an element then it is just a matter of using !important in their own CSS code.
 *
 * ### Overriding `.ng-hide`
 *
 * By default, the `.ng-hide` class will style the element with `display: none!important`. If you wish to change
 * the hide behavior with ngShow/ngHide then this can be achieved by restating the styles for the `.ng-hide`
 * class CSS. Note that the selector that needs to be used is actually `.ng-hide:not(.ng-hide-animate)` to cope
 * with extra animation classes that can be added.
 *
 * ```css
 * .ng-hide:not(.ng-hide-animate) {
 *   /&#42; this is just another form of hiding an element &#42;/
 *   display: block!important;
 *   position: absolute;
 *   top: -9999px;
 *   left: -9999px;
 * }
 * ```
 *
 * By default you don't need to override in CSS anything and the animations will work around the display style.
 *
 * ## A note about animations with `ngShow`
 *
 * Animations in ngShow/ngHide work with the show and hide events that are triggered when the directive expression
 * is true and false. This system works like the animation system present with ngClass except that
 * you must also include the !important flag to override the display property
 * so that you can perform an animation when the element is hidden during the time of the animation.
 *
 * ```css
 * //
 * //a working example can be found at the bottom of this page
 * //
 * .my-element.ng-hide-add, .my-element.ng-hide-remove {
 *   /&#42; this is required as of 1.3x to properly
 *      apply all styling in a show/hide animation &#42;/
 *   transition: 0s linear all;
 * }
 *
 * .my-element.ng-hide-add-active,
 * .my-element.ng-hide-remove-active {
 *   /&#42; the transition is defined in the active class &#42;/
 *   transition: 1s linear all;
 * }
 *
 * .my-element.ng-hide-add { ... }
 * .my-element.ng-hide-add.ng-hide-add-active { ... }
 * .my-element.ng-hide-remove { ... }
 * .my-element.ng-hide-remove.ng-hide-remove-active { ... }
 * ```
 *
 * Keep in mind that, as of AngularJS version 1.3.0-beta.11, there is no need to change the display
 * property to block during animation states--ngAnimate will handle the style toggling automatically for you.
 *
 * @animations
 * addClass: `.ng-hide` - happens after the `ngShow` expression evaluates to a truthy value and the just before contents are set to visible
 * removeClass: `.ng-hide` - happens after the `ngShow` expression evaluates to a non truthy value and just before the contents are set to hidden
 *
 * @element ANY
 * @param {expression} ngShow If the {@link guide/expression expression} is truthy
 *     then the element is shown or hidden respectively.
 *
 * @example
  <example module="ngAnimate" deps="angular-animate.js" animations="true">
    <file name="index.html">
      Click me: <input type="checkbox" ng-model="checked"><br/>
      <div>
        Show:
        <div class="check-element animate-show" ng-show="checked">
          <span class="glyphicon glyphicon-thumbs-up"></span> I show up when your checkbox is checked.
        </div>
      </div>
      <div>
        Hide:
        <div class="check-element animate-show" ng-hide="checked">
          <span class="glyphicon glyphicon-thumbs-down"></span> I hide when your checkbox is checked.
        </div>
      </div>
    </file>
    <file name="glyphicons.css">
      @import url(../../components/bootstrap-3.1.1/css/bootstrap.css);
    </file>
    <file name="animations.css">
      .animate-show {
        line-height: 20px;
        opacity: 1;
        padding: 10px;
        border: 1px solid black;
        background: white;
      }

      .animate-show.ng-hide-add.ng-hide-add-active,
      .animate-show.ng-hide-remove.ng-hide-remove-active {
        -webkit-transition: all linear 0.5s;
        transition: all linear 0.5s;
      }

      .animate-show.ng-hide {
        line-height: 0;
        opacity: 0;
        padding: 0 10px;
      }

      .check-element {
        padding: 10px;
        border: 1px solid black;
        background: white;
      }
    </file>
    <file name="protractor.js" type="protractor">
      var thumbsUp = element(by.css('span.glyphicon-thumbs-up'));
      var thumbsDown = element(by.css('span.glyphicon-thumbs-down'));

      it('should check ng-show / ng-hide', function() {
        expect(thumbsUp.isDisplayed()).toBeFalsy();
        expect(thumbsDown.isDisplayed()).toBeTruthy();

        element(by.model('checked')).click();

        expect(thumbsUp.isDisplayed()).toBeTruthy();
        expect(thumbsDown.isDisplayed()).toBeFalsy();
      });
    </file>
  </example>
 */
var ngShowDirective = ['$animate', function($animate) {
  return {
    restrict: 'A',
    multiElement: true,
    link: function(scope, element, attr) {
      scope.$watch(attr.ngShow, function ngShowWatchAction(value) {
        // we're adding a temporary, animation-specific class for ng-hide since this way
        // we can control when the element is actually displayed on screen without having
        // to have a global/greedy CSS selector that breaks when other animations are run.
        // Read: https://github.com/angular/angular.js/issues/9103#issuecomment-58335845
        $animate[value ? 'removeClass' : 'addClass'](element, NG_HIDE_CLASS, {
          tempClasses: NG_HIDE_IN_PROGRESS_CLASS
        });
      });
    }
  };
}];


/**
 * @ngdoc directive
 * @name ngHide
 *
 * @description
 * The `ngHide` directive shows or hides the given HTML element based on the expression
 * provided to the `ngHide` attribute. The element is shown or hidden by removing or adding
 * the `ng-hide` CSS class onto the element. The `.ng-hide` CSS class is predefined
 * in AngularJS and sets the display style to none (using an !important flag).
 * For CSP mode please add `angular-csp.css` to your html file (see {@link ng.directive:ngCsp ngCsp}).
 *
 * ```html
 * <!-- when $scope.myValue is truthy (element is hidden) -->
 * <div ng-hide="myValue" class="ng-hide"></div>
 *
 * <!-- when $scope.myValue is falsy (element is visible) -->
 * <div ng-hide="myValue"></div>
 * ```
 *
 * When the `ngHide` expression evaluates to a truthy value then the `.ng-hide` CSS class is added to the class
 * attribute on the element causing it to become hidden. When falsy, the `.ng-hide` CSS class is removed
 * from the element causing the element not to appear hidden.
 *
 * ## Why is !important used?
 *
 * You may be wondering why !important is used for the `.ng-hide` CSS class. This is because the `.ng-hide` selector
 * can be easily overridden by heavier selectors. For example, something as simple
 * as changing the display style on a HTML list item would make hidden elements appear visible.
 * This also becomes a bigger issue when dealing with CSS frameworks.
 *
 * By using !important, the show and hide behavior will work as expected despite any clash between CSS selector
 * specificity (when !important isn't used with any conflicting styles). If a developer chooses to override the
 * styling to change how to hide an element then it is just a matter of using !important in their own CSS code.
 *
 * ### Overriding `.ng-hide`
 *
 * By default, the `.ng-hide` class will style the element with `display: none!important`. If you wish to change
 * the hide behavior with ngShow/ngHide then this can be achieved by restating the styles for the `.ng-hide`
 * class in CSS:
 *
 * ```css
 * .ng-hide {
 *   /&#42; this is just another form of hiding an element &#42;/
 *   display: block!important;
 *   position: absolute;
 *   top: -9999px;
 *   left: -9999px;
 * }
 * ```
 *
 * By default you don't need to override in CSS anything and the animations will work around the display style.
 *
 * ## A note about animations with `ngHide`
 *
 * Animations in ngShow/ngHide work with the show and hide events that are triggered when the directive expression
 * is true and false. This system works like the animation system present with ngClass, except that the `.ng-hide`
 * CSS class is added and removed for you instead of your own CSS class.
 *
 * ```css
 * //
 * //a working example can be found at the bottom of this page
 * //
 * .my-element.ng-hide-add, .my-element.ng-hide-remove {
 *   transition: 0.5s linear all;
 * }
 *
 * .my-element.ng-hide-add { ... }
 * .my-element.ng-hide-add.ng-hide-add-active { ... }
 * .my-element.ng-hide-remove { ... }
 * .my-element.ng-hide-remove.ng-hide-remove-active { ... }
 * ```
 *
 * Keep in mind that, as of AngularJS version 1.3.0-beta.11, there is no need to change the display
 * property to block during animation states--ngAnimate will handle the style toggling automatically for you.
 *
 * @animations
 * removeClass: `.ng-hide` - happens after the `ngHide` expression evaluates to a truthy value and just before the contents are set to hidden
 * addClass: `.ng-hide` - happens after the `ngHide` expression evaluates to a non truthy value and just before the contents are set to visible
 *
 * @element ANY
 * @param {expression} ngHide If the {@link guide/expression expression} is truthy then
 *     the element is shown or hidden respectively.
 *
 * @example
  <example module="ngAnimate" deps="angular-animate.js" animations="true">
    <file name="index.html">
      Click me: <input type="checkbox" ng-model="checked"><br/>
      <div>
        Show:
        <div class="check-element animate-hide" ng-show="checked">
          <span class="glyphicon glyphicon-thumbs-up"></span> I show up when your checkbox is checked.
        </div>
      </div>
      <div>
        Hide:
        <div class="check-element animate-hide" ng-hide="checked">
          <span class="glyphicon glyphicon-thumbs-down"></span> I hide when your checkbox is checked.
        </div>
      </div>
    </file>
    <file name="glyphicons.css">
      @import url(../../components/bootstrap-3.1.1/css/bootstrap.css);
    </file>
    <file name="animations.css">
      .animate-hide {
        -webkit-transition: all linear 0.5s;
        transition: all linear 0.5s;
        line-height: 20px;
        opacity: 1;
        padding: 10px;
        border: 1px solid black;
        background: white;
      }

      .animate-hide.ng-hide {
        line-height: 0;
        opacity: 0;
        padding: 0 10px;
      }

      .check-element {
        padding: 10px;
        border: 1px solid black;
        background: white;
      }
    </file>
    <file name="protractor.js" type="protractor">
      var thumbsUp = element(by.css('span.glyphicon-thumbs-up'));
      var thumbsDown = element(by.css('span.glyphicon-thumbs-down'));

      it('should check ng-show / ng-hide', function() {
        expect(thumbsUp.isDisplayed()).toBeFalsy();
        expect(thumbsDown.isDisplayed()).toBeTruthy();

        element(by.model('checked')).click();

        expect(thumbsUp.isDisplayed()).toBeTruthy();
        expect(thumbsDown.isDisplayed()).toBeFalsy();
      });
    </file>
  </example>
 */
var ngHideDirective = ['$animate', function($animate) {
  return {
    restrict: 'A',
    multiElement: true,
    link: function(scope, element, attr) {
      scope.$watch(attr.ngHide, function ngHideWatchAction(value) {
        // The comment inside of the ngShowDirective explains why we add and
        // remove a temporary class for the show/hide animation
        $animate[value ? 'addClass' : 'removeClass'](element,NG_HIDE_CLASS, {
          tempClasses: NG_HIDE_IN_PROGRESS_CLASS
        });
      });
    }
  };
}];

/**
 * @ngdoc directive
 * @name ngStyle
 * @restrict AC
 *
 * @description
 * The `ngStyle` directive allows you to set CSS style on an HTML element conditionally.
 *
 * @element ANY
 * @param {expression} ngStyle
 *
 * {@link guide/expression Expression} which evals to an
 * object whose keys are CSS style names and values are corresponding values for those CSS
 * keys.
 *
 * Since some CSS style names are not valid keys for an object, they must be quoted.
 * See the 'background-color' style in the example below.
 *
 * @example
   <example>
     <file name="index.html">
        <input type="button" value="set color" ng-click="myStyle={color:'red'}">
        <input type="button" value="set background" ng-click="myStyle={'background-color':'blue'}">
        <input type="button" value="clear" ng-click="myStyle={}">
        <br/>
        <span ng-style="myStyle">Sample Text</span>
        <pre>myStyle={{myStyle}}</pre>
     </file>
     <file name="style.css">
       span {
         color: black;
       }
     </file>
     <file name="protractor.js" type="protractor">
       var colorSpan = element(by.css('span'));

       it('should check ng-style', function() {
         expect(colorSpan.getCssValue('color')).toBe('rgba(0, 0, 0, 1)');
         element(by.css('input[value=\'set color\']')).click();
         expect(colorSpan.getCssValue('color')).toBe('rgba(255, 0, 0, 1)');
         element(by.css('input[value=clear]')).click();
         expect(colorSpan.getCssValue('color')).toBe('rgba(0, 0, 0, 1)');
       });
     </file>
   </example>
 */
var ngStyleDirective = ngDirective(function(scope, element, attr) {
  scope.$watch(attr.ngStyle, function ngStyleWatchAction(newStyles, oldStyles) {
    if (oldStyles && (newStyles !== oldStyles)) {
      forEach(oldStyles, function(val, style) { element.css(style, '');});
    }
    if (newStyles) element.css(newStyles);
  }, true);
});

/**
 * @ngdoc directive
 * @name ngSwitch
 * @restrict EA
 *
 * @description
 * The `ngSwitch` directive is used to conditionally swap DOM structure on your template based on a scope expression.
 * Elements within `ngSwitch` but without `ngSwitchWhen` or `ngSwitchDefault` directives will be preserved at the location
 * as specified in the template.
 *
 * The directive itself works similar to ngInclude, however, instead of downloading template code (or loading it
 * from the template cache), `ngSwitch` simply chooses one of the nested elements and makes it visible based on which element
 * matches the value obtained from the evaluated expression. In other words, you define a container element
 * (where you place the directive), place an expression on the **`on="..."` attribute**
 * (or the **`ng-switch="..."` attribute**), define any inner elements inside of the directive and place
 * a when attribute per element. The when attribute is used to inform ngSwitch which element to display when the on
 * expression is evaluated. If a matching expression is not found via a when attribute then an element with the default
 * attribute is displayed.
 *
 * <div class="alert alert-info">
 * Be aware that the attribute values to match against cannot be expressions. They are interpreted
 * as literal string values to match against.
 * For example, **`ng-switch-when="someVal"`** will match against the string `"someVal"` not against the
 * value of the expression `$scope.someVal`.
 * </div>

 * @animations
 * enter - happens after the ngSwitch contents change and the matched child element is placed inside the container
 * leave - happens just after the ngSwitch contents change and just before the former contents are removed from the DOM
 *
 * @usage
 *
 * ```
 * <ANY ng-switch="expression">
 *   <ANY ng-switch-when="matchValue1">...</ANY>
 *   <ANY ng-switch-when="matchValue2">...</ANY>
 *   <ANY ng-switch-default>...</ANY>
 * </ANY>
 * ```
 *
 *
 * @scope
 * @priority 1200
 * @param {*} ngSwitch|on expression to match against <code>ng-switch-when</code>.
 * On child elements add:
 *
 * * `ngSwitchWhen`: the case statement to match against. If match then this
 *   case will be displayed. If the same match appears multiple times, all the
 *   elements will be displayed.
 * * `ngSwitchDefault`: the default case when no other case match. If there
 *   are multiple default cases, all of them will be displayed when no other
 *   case match.
 *
 *
 * @example
  <example module="switchExample" deps="angular-animate.js" animations="true">
    <file name="index.html">
      <div ng-controller="ExampleController">
        <select ng-model="selection" ng-options="item for item in items">
        </select>
        <code>selection={{selection}}</code>
        <hr/>
        <div class="animate-switch-container"
          ng-switch on="selection">
            <div class="animate-switch" ng-switch-when="settings">Settings Div</div>
            <div class="animate-switch" ng-switch-when="home">Home Span</div>
            <div class="animate-switch" ng-switch-default>default</div>
        </div>
      </div>
    </file>
    <file name="script.js">
      angular.module('switchExample', ['ngAnimate'])
        .controller('ExampleController', ['$scope', function($scope) {
          $scope.items = ['settings', 'home', 'other'];
          $scope.selection = $scope.items[0];
        }]);
    </file>
    <file name="animations.css">
      .animate-switch-container {
        position:relative;
        background:white;
        border:1px solid black;
        height:40px;
        overflow:hidden;
      }

      .animate-switch {
        padding:10px;
      }

      .animate-switch.ng-animate {
        -webkit-transition:all cubic-bezier(0.250, 0.460, 0.450, 0.940) 0.5s;
        transition:all cubic-bezier(0.250, 0.460, 0.450, 0.940) 0.5s;

        position:absolute;
        top:0;
        left:0;
        right:0;
        bottom:0;
      }

      .animate-switch.ng-leave.ng-leave-active,
      .animate-switch.ng-enter {
        top:-50px;
      }
      .animate-switch.ng-leave,
      .animate-switch.ng-enter.ng-enter-active {
        top:0;
      }
    </file>
    <file name="protractor.js" type="protractor">
      var switchElem = element(by.css('[ng-switch]'));
      var select = element(by.model('selection'));

      it('should start in settings', function() {
        expect(switchElem.getText()).toMatch(/Settings Div/);
      });
      it('should change to home', function() {
        select.all(by.css('option')).get(1).click();
        expect(switchElem.getText()).toMatch(/Home Span/);
      });
      it('should select default', function() {
        select.all(by.css('option')).get(2).click();
        expect(switchElem.getText()).toMatch(/default/);
      });
    </file>
  </example>
 */
var ngSwitchDirective = ['$animate', function($animate) {
  return {
    restrict: 'EA',
    require: 'ngSwitch',

    // asks for $scope to fool the BC controller module
    controller: ['$scope', function ngSwitchController() {
     this.cases = {};
    }],
    link: function(scope, element, attr, ngSwitchController) {
      var watchExpr = attr.ngSwitch || attr.on,
          selectedTranscludes = [],
          selectedElements = [],
          previousLeaveAnimations = [],
          selectedScopes = [];

      var spliceFactory = function(array, index) {
          return function() { array.splice(index, 1); };
      };

      scope.$watch(watchExpr, function ngSwitchWatchAction(value) {
        var i, ii;
        for (i = 0, ii = previousLeaveAnimations.length; i < ii; ++i) {
          $animate.cancel(previousLeaveAnimations[i]);
        }
        previousLeaveAnimations.length = 0;

        for (i = 0, ii = selectedScopes.length; i < ii; ++i) {
          var selected = getBlockNodes(selectedElements[i].clone);
          selectedScopes[i].$destroy();
          var promise = previousLeaveAnimations[i] = $animate.leave(selected);
          promise.then(spliceFactory(previousLeaveAnimations, i));
        }

        selectedElements.length = 0;
        selectedScopes.length = 0;

        if ((selectedTranscludes = ngSwitchController.cases['!' + value] || ngSwitchController.cases['?'])) {
          forEach(selectedTranscludes, function(selectedTransclude) {
            selectedTransclude.transclude(function(caseElement, selectedScope) {
              selectedScopes.push(selectedScope);
              var anchor = selectedTransclude.element;
              caseElement[caseElement.length++] = document.createComment(' end ngSwitchWhen: ');
              var block = { clone: caseElement };

              selectedElements.push(block);
              $animate.enter(caseElement, anchor.parent(), anchor);
            });
          });
        }
      });
    }
  };
}];

var ngSwitchWhenDirective = ngDirective({
  transclude: 'element',
  priority: 1200,
  require: '^ngSwitch',
  multiElement: true,
  link: function(scope, element, attrs, ctrl, $transclude) {
    ctrl.cases['!' + attrs.ngSwitchWhen] = (ctrl.cases['!' + attrs.ngSwitchWhen] || []);
    ctrl.cases['!' + attrs.ngSwitchWhen].push({ transclude: $transclude, element: element });
  }
});

var ngSwitchDefaultDirective = ngDirective({
  transclude: 'element',
  priority: 1200,
  require: '^ngSwitch',
  multiElement: true,
  link: function(scope, element, attr, ctrl, $transclude) {
    ctrl.cases['?'] = (ctrl.cases['?'] || []);
    ctrl.cases['?'].push({ transclude: $transclude, element: element });
   }
});

/**
 * @ngdoc directive
 * @name ngTransclude
 * @restrict EAC
 *
 * @description
 * Directive that marks the insertion point for the transcluded DOM of the nearest parent directive that uses transclusion.
 *
 * Any existing content of the element that this directive is placed on will be removed before the transcluded content is inserted.
 *
 * @element ANY
 *
 * @example
   <example module="transcludeExample">
     <file name="index.html">
       <script>
         angular.module('transcludeExample', [])
          .directive('pane', function(){
             return {
               restrict: 'E',
               transclude: true,
               scope: { title:'@' },
               template: '<div style="border: 1px solid black;">' +
                           '<div style="background-color: gray">{{title}}</div>' +
                           '<ng-transclude></ng-transclude>' +
                         '</div>'
             };
         })
         .controller('ExampleController', ['$scope', function($scope) {
           $scope.title = 'Lorem Ipsum';
           $scope.text = 'Neque porro quisquam est qui dolorem ipsum quia dolor...';
         }]);
       </script>
       <div ng-controller="ExampleController">
         <input ng-model="title"> <br/>
         <textarea ng-model="text"></textarea> <br/>
         <pane title="{{title}}">{{text}}</pane>
       </div>
     </file>
     <file name="protractor.js" type="protractor">
        it('should have transcluded', function() {
          var titleElement = element(by.model('title'));
          titleElement.clear();
          titleElement.sendKeys('TITLE');
          var textElement = element(by.model('text'));
          textElement.clear();
          textElement.sendKeys('TEXT');
          expect(element(by.binding('title')).getText()).toEqual('TITLE');
          expect(element(by.binding('text')).getText()).toEqual('TEXT');
        });
     </file>
   </example>
 *
 */
var ngTranscludeDirective = ngDirective({
  restrict: 'EAC',
  link: function($scope, $element, $attrs, controller, $transclude) {
    if (!$transclude) {
      throw minErr('ngTransclude')('orphan',
       'Illegal use of ngTransclude directive in the template! ' +
       'No parent directive that requires a transclusion found. ' +
       'Element: {0}',
       startingTag($element));
    }

    $transclude(function(clone) {
      $element.empty();
      $element.append(clone);
    });
  }
});

/**
 * @ngdoc directive
 * @name script
 * @restrict E
 *
 * @description
 * Load the content of a `<script>` element into {@link ng.$templateCache `$templateCache`}, so that the
 * template can be used by {@link ng.directive:ngInclude `ngInclude`},
 * {@link ngRoute.directive:ngView `ngView`}, or {@link guide/directive directives}. The type of the
 * `<script>` element must be specified as `text/ng-template`, and a cache name for the template must be
 * assigned through the element's `id`, which can then be used as a directive's `templateUrl`.
 *
 * @param {string} type Must be set to `'text/ng-template'`.
 * @param {string} id Cache name of the template.
 *
 * @example
  <example>
    <file name="index.html">
      <script type="text/ng-template" id="/tpl.html">
        Content of the template.
      </script>

      <a ng-click="currentTpl='/tpl.html'" id="tpl-link">Load inlined template</a>
      <div id="tpl-content" ng-include src="currentTpl"></div>
    </file>
    <file name="protractor.js" type="protractor">
      it('should load template defined inside script tag', function() {
        element(by.css('#tpl-link')).click();
        expect(element(by.css('#tpl-content')).getText()).toMatch(/Content of the template/);
      });
    </file>
  </example>
 */
var scriptDirective = ['$templateCache', function($templateCache) {
  return {
    restrict: 'E',
    terminal: true,
    compile: function(element, attr) {
      if (attr.type == 'text/ng-template') {
        var templateUrl = attr.id,
            text = element[0].text;

        $templateCache.put(templateUrl, text);
      }
    }
  };
}];

var ngOptionsMinErr = minErr('ngOptions');
/**
 * @ngdoc directive
 * @name select
 * @restrict E
 *
 * @description
 * HTML `SELECT` element with angular data-binding.
 *
 * # `ngOptions`
 *
 * The `ngOptions` attribute can be used to dynamically generate a list of `<option>`
 * elements for the `<select>` element using the array or object obtained by evaluating the
 * `ngOptions` comprehension expression.
 *
 * In many cases, `ngRepeat` can be used on `<option>` elements instead of `ngOptions` to achieve a
 * similar result. However, `ngOptions` provides some benefits such as reducing memory and
 * increasing speed by not creating a new scope for each repeated instance, as well as providing
 * more flexibility in how the `<select>`'s model is assigned via the `select` **`as`** part of the
 * comprehension expression. `ngOptions` should be used when the `<select>` model needs to be bound
 *  to a non-string value. This is because an option element can only be bound to string values at
 * present.
 *
 * When an item in the `<select>` menu is selected, the array element or object property
 * represented by the selected option will be bound to the model identified by the `ngModel`
 * directive.
 *
 * Optionally, a single hard-coded `<option>` element, with the value set to an empty string, can
 * be nested into the `<select>` element. This element will then represent the `null` or "not selected"
 * option. See example below for demonstration.
 *
 * <div class="alert alert-warning">
 * **Note:** `ngModel` compares by reference, not value. This is important when binding to an
 * array of objects. See an example [in this jsfiddle](http://jsfiddle.net/qWzTb/).
 * </div>
 *
 * ## `select` **`as`**
 *
 * Using `select` **`as`** will bind the result of the `select` expression to the model, but
 * the value of the `<select>` and `<option>` html elements will be either the index (for array data sources)
 * or property name (for object data sources) of the value within the collection. If a **`track by`** expression
 * is used, the result of that expression will be set as the value of the `option` and `select` elements.
 *
 *
 * ### `select` **`as`** and **`track by`**
 *
 * <div class="alert alert-warning">
 * Do not use `select` **`as`** and **`track by`** in the same expression. They are not designed to work together.
 * </div>
 *
 * Consider the following example:
 *
 * ```html
 * <select ng-options="item.subItem as item.label for item in values track by item.id" ng-model="selected">
 * ```
 *
 * ```js
 * $scope.values = [{
 *   id: 1,
 *   label: 'aLabel',
 *   subItem: { name: 'aSubItem' }
 * }, {
 *   id: 2,
 *   label: 'bLabel',
 *   subItem: { name: 'bSubItem' }
 * }];
 *
 * $scope.selected = { name: 'aSubItem' };
 * ```
 *
 * With the purpose of preserving the selection, the **`track by`** expression is always applied to the element
 * of the data source (to `item` in this example). To calculate whether an element is selected, we do the
 * following:
 *
 * 1. Apply **`track by`** to the elements in the array. In the example: `[1, 2]`
 * 2. Apply **`track by`** to the already selected value in `ngModel`.
 *    In the example: this is not possible as **`track by`** refers to `item.id`, but the selected
 *    value from `ngModel` is `{name: 'aSubItem'}`, so the **`track by`** expression is applied to
 *    a wrong object, the selected element can't be found, `<select>` is always reset to the "not
 *    selected" option.
 *
 *
 * @param {string} ngModel Assignable angular expression to data-bind to.
 * @param {string=} name Property name of the form under which the control is published.
 * @param {string=} required The control is considered valid only if value is entered.
 * @param {string=} ngRequired Adds `required` attribute and `required` validation constraint to
 *    the element when the ngRequired expression evaluates to true. Use `ngRequired` instead of
 *    `required` when you want to data-bind to the `required` attribute.
 * @param {comprehension_expression=} ngOptions in one of the following forms:
 *
 *   * for array data sources:
 *     * `label` **`for`** `value` **`in`** `array`
 *     * `select` **`as`** `label` **`for`** `value` **`in`** `array`
 *     * `label` **`group by`** `group` **`for`** `value` **`in`** `array`
 *     * `label` **`group by`** `group` **`for`** `value` **`in`** `array` **`track by`** `trackexpr`
 *     * `label` **`for`** `value` **`in`** `array` | orderBy:`orderexpr` **`track by`** `trackexpr`
 *        (for including a filter with `track by`)
 *   * for object data sources:
 *     * `label` **`for (`**`key` **`,`** `value`**`) in`** `object`
 *     * `select` **`as`** `label` **`for (`**`key` **`,`** `value`**`) in`** `object`
 *     * `label` **`group by`** `group` **`for (`**`key`**`,`** `value`**`) in`** `object`
 *     * `select` **`as`** `label` **`group by`** `group`
 *         **`for` `(`**`key`**`,`** `value`**`) in`** `object`
 *
 * Where:
 *
 *   * `array` / `object`: an expression which evaluates to an array / object to iterate over.
 *   * `value`: local variable which will refer to each item in the `array` or each property value
 *      of `object` during iteration.
 *   * `key`: local variable which will refer to a property name in `object` during iteration.
 *   * `label`: The result of this expression will be the label for `<option>` element. The
 *     `expression` will most likely refer to the `value` variable (e.g. `value.propertyName`).
 *   * `select`: The result of this expression will be bound to the model of the parent `<select>`
 *      element. If not specified, `select` expression will default to `value`.
 *   * `group`: The result of this expression will be used to group options using the `<optgroup>`
 *      DOM element.
 *   * `trackexpr`: Used when working with an array of objects. The result of this expression will be
 *      used to identify the objects in the array. The `trackexpr` will most likely refer to the
 *     `value` variable (e.g. `value.propertyName`). With this the selection is preserved
 *      even when the options are recreated (e.g. reloaded from the server).
 *
 * @example
    <example module="selectExample">
      <file name="index.html">
        <script>
        angular.module('selectExample', [])
          .controller('ExampleController', ['$scope', function($scope) {
            $scope.colors = [
              {name:'black', shade:'dark'},
              {name:'white', shade:'light'},
              {name:'red', shade:'dark'},
              {name:'blue', shade:'dark'},
              {name:'yellow', shade:'light'}
            ];
            $scope.myColor = $scope.colors[2]; // red
          }]);
        </script>
        <div ng-controller="ExampleController">
          <ul>
            <li ng-repeat="color in colors">
              Name: <input ng-model="color.name">
              [<a href ng-click="colors.splice($index, 1)">X</a>]
            </li>
            <li>
              [<a href ng-click="colors.push({})">add</a>]
            </li>
          </ul>
          <hr/>
          Color (null not allowed):
          <select ng-model="myColor" ng-options="color.name for color in colors"></select><br>

          Color (null allowed):
          <span  class="nullable">
            <select ng-model="myColor" ng-options="color.name for color in colors">
              <option value="">-- choose color --</option>
            </select>
          </span><br/>

          Color grouped by shade:
          <select ng-model="myColor" ng-options="color.name group by color.shade for color in colors">
          </select><br/>


          Select <a href ng-click="myColor = { name:'not in list', shade: 'other' }">bogus</a>.<br>
          <hr/>
          Currently selected: {{ {selected_color:myColor} }}
          <div style="border:solid 1px black; height:20px"
               ng-style="{'background-color':myColor.name}">
          </div>
        </div>
      </file>
      <file name="protractor.js" type="protractor">
         it('should check ng-options', function() {
           expect(element(by.binding('{selected_color:myColor}')).getText()).toMatch('red');
           element.all(by.model('myColor')).first().click();
           element.all(by.css('select[ng-model="myColor"] option')).first().click();
           expect(element(by.binding('{selected_color:myColor}')).getText()).toMatch('black');
           element(by.css('.nullable select[ng-model="myColor"]')).click();
           element.all(by.css('.nullable select[ng-model="myColor"] option')).first().click();
           expect(element(by.binding('{selected_color:myColor}')).getText()).toMatch('null');
         });
      </file>
    </example>
 */

var ngOptionsDirective = valueFn({
  restrict: 'A',
  terminal: true
});

// jshint maxlen: false
var selectDirective = ['$compile', '$parse', function($compile,   $parse) {
                         //000011111111110000000000022222222220000000000000000000003333333333000000000000004444444444444440000000005555555555555550000000666666666666666000000000000000777777777700000000000000000008888888888
  var NG_OPTIONS_REGEXP = /^\s*([\s\S]+?)(?:\s+as\s+([\s\S]+?))?(?:\s+group\s+by\s+([\s\S]+?))?\s+for\s+(?:([\$\w][\$\w]*)|(?:\(\s*([\$\w][\$\w]*)\s*,\s*([\$\w][\$\w]*)\s*\)))\s+in\s+([\s\S]+?)(?:\s+track\s+by\s+([\s\S]+?))?$/,
      nullModelCtrl = {$setViewValue: noop};
// jshint maxlen: 100

  return {
    restrict: 'E',
    require: ['select', '?ngModel'],
    controller: ['$element', '$scope', '$attrs', function($element, $scope, $attrs) {
      var self = this,
          optionsMap = {},
          ngModelCtrl = nullModelCtrl,
          nullOption,
          unknownOption;


      self.databound = $attrs.ngModel;


      self.init = function(ngModelCtrl_, nullOption_, unknownOption_) {
        ngModelCtrl = ngModelCtrl_;
        nullOption = nullOption_;
        unknownOption = unknownOption_;
      };


      self.addOption = function(value, element) {
        assertNotHasOwnProperty(value, '"option value"');
        optionsMap[value] = true;

        if (ngModelCtrl.$viewValue == value) {
          $element.val(value);
          if (unknownOption.parent()) unknownOption.remove();
        }
        // Workaround for https://code.google.com/p/chromium/issues/detail?id=381459
        // Adding an <option selected="selected"> element to a <select required="required"> should
        // automatically select the new element
        if (element && element[0].hasAttribute('selected')) {
          element[0].selected = true;
        }
      };


      self.removeOption = function(value) {
        if (this.hasOption(value)) {
          delete optionsMap[value];
          if (ngModelCtrl.$viewValue === value) {
            this.renderUnknownOption(value);
          }
        }
      };


      self.renderUnknownOption = function(val) {
        var unknownVal = '? ' + hashKey(val) + ' ?';
        unknownOption.val(unknownVal);
        $element.prepend(unknownOption);
        $element.val(unknownVal);
        unknownOption.prop('selected', true); // needed for IE
      };


      self.hasOption = function(value) {
        return optionsMap.hasOwnProperty(value);
      };

      $scope.$on('$destroy', function() {
        // disable unknown option so that we don't do work when the whole select is being destroyed
        self.renderUnknownOption = noop;
      });
    }],

    link: function(scope, element, attr, ctrls) {
      // if ngModel is not defined, we don't need to do anything
      if (!ctrls[1]) return;

      var selectCtrl = ctrls[0],
          ngModelCtrl = ctrls[1],
          multiple = attr.multiple,
          optionsExp = attr.ngOptions,
          nullOption = false, // if false, user will not be able to select it (used by ngOptions)
          emptyOption,
          renderScheduled = false,
          // we can't just jqLite('<option>') since jqLite is not smart enough
          // to create it in <select> and IE barfs otherwise.
          optionTemplate = jqLite(document.createElement('option')),
          optGroupTemplate =jqLite(document.createElement('optgroup')),
          unknownOption = optionTemplate.clone();

      // find "null" option
      for (var i = 0, children = element.children(), ii = children.length; i < ii; i++) {
        if (children[i].value === '') {
          emptyOption = nullOption = children.eq(i);
          break;
        }
      }

      selectCtrl.init(ngModelCtrl, nullOption, unknownOption);

      // required validator
      if (multiple) {
        ngModelCtrl.$isEmpty = function(value) {
          return !value || value.length === 0;
        };
      }

      if (optionsExp) setupAsOptions(scope, element, ngModelCtrl);
      else if (multiple) setupAsMultiple(scope, element, ngModelCtrl);
      else setupAsSingle(scope, element, ngModelCtrl, selectCtrl);


      ////////////////////////////



      function setupAsSingle(scope, selectElement, ngModelCtrl, selectCtrl) {
        ngModelCtrl.$render = function() {
          var viewValue = ngModelCtrl.$viewValue;

          if (selectCtrl.hasOption(viewValue)) {
            if (unknownOption.parent()) unknownOption.remove();
            selectElement.val(viewValue);
            if (viewValue === '') emptyOption.prop('selected', true); // to make IE9 happy
          } else {
            if (viewValue == null && emptyOption) {
              selectElement.val('');
            } else {
              selectCtrl.renderUnknownOption(viewValue);
            }
          }
        };

        selectElement.on('change', function() {
          scope.$apply(function() {
            if (unknownOption.parent()) unknownOption.remove();
            ngModelCtrl.$setViewValue(selectElement.val());
          });
        });
      }

      function setupAsMultiple(scope, selectElement, ctrl) {
        var lastView;
        ctrl.$render = function() {
          var items = new HashMap(ctrl.$viewValue);
          forEach(selectElement.find('option'), function(option) {
            option.selected = isDefined(items.get(option.value));
          });
        };

        // we have to do it on each watch since ngModel watches reference, but
        // we need to work of an array, so we need to see if anything was inserted/removed
        scope.$watch(function selectMultipleWatch() {
          if (!equals(lastView, ctrl.$viewValue)) {
            lastView = shallowCopy(ctrl.$viewValue);
            ctrl.$render();
          }
        });

        selectElement.on('change', function() {
          scope.$apply(function() {
            var array = [];
            forEach(selectElement.find('option'), function(option) {
              if (option.selected) {
                array.push(option.value);
              }
            });
            ctrl.$setViewValue(array);
          });
        });
      }

      function setupAsOptions(scope, selectElement, ctrl) {
        var match;

        if (!(match = optionsExp.match(NG_OPTIONS_REGEXP))) {
          throw ngOptionsMinErr('iexp',
            "Expected expression in form of " +
            "'_select_ (as _label_)? for (_key_,)?_value_ in _collection_'" +
            " but got '{0}'. Element: {1}",
            optionsExp, startingTag(selectElement));
        }

        var displayFn = $parse(match[2] || match[1]),
            valueName = match[4] || match[6],
            selectAs = / as /.test(match[0]) && match[1],
            selectAsFn = selectAs ? $parse(selectAs) : null,
            keyName = match[5],
            groupByFn = $parse(match[3] || ''),
            valueFn = $parse(match[2] ? match[1] : valueName),
            valuesFn = $parse(match[7]),
            track = match[8],
            trackFn = track ? $parse(match[8]) : null,
            trackKeysCache = {},
            // This is an array of array of existing option groups in DOM.
            // We try to reuse these if possible
            // - optionGroupsCache[0] is the options with no option group
            // - optionGroupsCache[?][0] is the parent: either the SELECT or OPTGROUP element
            optionGroupsCache = [[{element: selectElement, label:''}]],
            //re-usable object to represent option's locals
            locals = {};

        if (nullOption) {
          // compile the element since there might be bindings in it
          $compile(nullOption)(scope);

          // remove the class, which is added automatically because we recompile the element and it
          // becomes the compilation root
          nullOption.removeClass('ng-scope');

          // we need to remove it before calling selectElement.empty() because otherwise IE will
          // remove the label from the element. wtf?
          nullOption.remove();
        }

        // clear contents, we'll add what's needed based on the model
        selectElement.empty();

        selectElement.on('change', selectionChanged);

        ctrl.$render = render;

        scope.$watchCollection(valuesFn, scheduleRendering);
        scope.$watchCollection(getLabels, scheduleRendering);

        if (multiple) {
          scope.$watchCollection(function() { return ctrl.$modelValue; }, scheduleRendering);
        }

        // ------------------------------------------------------------------ //

        function callExpression(exprFn, key, value) {
          locals[valueName] = value;
          if (keyName) locals[keyName] = key;
          return exprFn(scope, locals);
        }

        function selectionChanged() {
          scope.$apply(function() {
            var collection = valuesFn(scope) || [];
            var viewValue;
            if (multiple) {
              viewValue = [];
              forEach(selectElement.val(), function(selectedKey) {
                  selectedKey = trackFn ? trackKeysCache[selectedKey] : selectedKey;
                viewValue.push(getViewValue(selectedKey, collection[selectedKey]));
              });
            } else {
              var selectedKey = trackFn ? trackKeysCache[selectElement.val()] : selectElement.val();
              viewValue = getViewValue(selectedKey, collection[selectedKey]);
            }
            ctrl.$setViewValue(viewValue);
            render();
          });
        }

        function getViewValue(key, value) {
          if (key === '?') {
            return undefined;
          } else if (key === '') {
            return null;
          } else {
            var viewValueFn = selectAsFn ? selectAsFn : valueFn;
            return callExpression(viewValueFn, key, value);
          }
        }

        function getLabels() {
          var values = valuesFn(scope);
          var toDisplay;
          if (values && isArray(values)) {
            toDisplay = new Array(values.length);
            for (var i = 0, ii = values.length; i < ii; i++) {
              toDisplay[i] = callExpression(displayFn, i, values[i]);
            }
            return toDisplay;
          } else if (values) {
            // TODO: Add a test for this case
            toDisplay = {};
            for (var prop in values) {
              if (values.hasOwnProperty(prop)) {
                toDisplay[prop] = callExpression(displayFn, prop, values[prop]);
              }
            }
          }
          return toDisplay;
        }

        function createIsSelectedFn(viewValue) {
          var selectedSet;
          if (multiple) {
            if (trackFn && isArray(viewValue)) {

              selectedSet = new HashMap([]);
              for (var trackIndex = 0; trackIndex < viewValue.length; trackIndex++) {
                // tracking by key
                selectedSet.put(callExpression(trackFn, null, viewValue[trackIndex]), true);
              }
            } else {
              selectedSet = new HashMap(viewValue);
            }
          } else if (trackFn) {
            viewValue = callExpression(trackFn, null, viewValue);
          }

          return function isSelected(key, value) {
            var compareValueFn;
            if (trackFn) {
              compareValueFn = trackFn;
            } else if (selectAsFn) {
              compareValueFn = selectAsFn;
            } else {
              compareValueFn = valueFn;
            }

            if (multiple) {
              return isDefined(selectedSet.remove(callExpression(compareValueFn, key, value)));
            } else {
              return viewValue === callExpression(compareValueFn, key, value);
            }
          };
        }

        function scheduleRendering() {
          if (!renderScheduled) {
            scope.$$postDigest(render);
            renderScheduled = true;
          }
        }

        /**
         * A new labelMap is created with each render.
         * This function is called for each existing option with added=false,
         * and each new option with added=true.
         * - Labels that are passed to this method twice,
         * (once with added=true and once with added=false) will end up with a value of 0, and
         * will cause no change to happen to the corresponding option.
         * - Labels that are passed to this method only once with added=false will end up with a
         * value of -1 and will eventually be passed to selectCtrl.removeOption()
         * - Labels that are passed to this method only once with added=true will end up with a
         * value of 1 and will eventually be passed to selectCtrl.addOption()
        */
        function updateLabelMap(labelMap, label, added) {
          labelMap[label] = labelMap[label] || 0;
          labelMap[label] += (added ? 1 : -1);
        }

        function render() {
          renderScheduled = false;

          // Temporary location for the option groups before we render them
          var optionGroups = {'':[]},
              optionGroupNames = [''],
              optionGroupName,
              optionGroup,
              option,
              existingParent, existingOptions, existingOption,
              viewValue = ctrl.$viewValue,
              values = valuesFn(scope) || [],
              keys = keyName ? sortedKeys(values) : values,
              key,
              value,
              groupLength, length,
              groupIndex, index,
              labelMap = {},
              selected,
              isSelected = createIsSelectedFn(viewValue),
              anySelected = false,
              lastElement,
              element,
              label,
              optionId;

          trackKeysCache = {};

          // We now build up the list of options we need (we merge later)
          for (index = 0; length = keys.length, index < length; index++) {
            key = index;
            if (keyName) {
              key = keys[index];
              if (key.charAt(0) === '$') continue;
            }
            value = values[key];

            optionGroupName = callExpression(groupByFn, key, value) || '';
            if (!(optionGroup = optionGroups[optionGroupName])) {
              optionGroup = optionGroups[optionGroupName] = [];
              optionGroupNames.push(optionGroupName);
            }

            selected = isSelected(key, value);
            anySelected = anySelected || selected;

            label = callExpression(displayFn, key, value); // what will be seen by the user

            // doing displayFn(scope, locals) || '' overwrites zero values
            label = isDefined(label) ? label : '';
            optionId = trackFn ? trackFn(scope, locals) : (keyName ? keys[index] : index);
            if (trackFn) {
              trackKeysCache[optionId] = key;
            }

            optionGroup.push({
              // either the index into array or key from object
              id: optionId,
              label: label,
              selected: selected                   // determine if we should be selected
            });
          }
          if (!multiple) {
            if (nullOption || viewValue === null) {
              // insert null option if we have a placeholder, or the model is null
              optionGroups[''].unshift({id:'', label:'', selected:!anySelected});
            } else if (!anySelected) {
              // option could not be found, we have to insert the undefined item
              optionGroups[''].unshift({id:'?', label:'', selected:true});
            }
          }

          // Now we need to update the list of DOM nodes to match the optionGroups we computed above
          for (groupIndex = 0, groupLength = optionGroupNames.length;
               groupIndex < groupLength;
               groupIndex++) {
            // current option group name or '' if no group
            optionGroupName = optionGroupNames[groupIndex];

            // list of options for that group. (first item has the parent)
            optionGroup = optionGroups[optionGroupName];

            if (optionGroupsCache.length <= groupIndex) {
              // we need to grow the optionGroups
              existingParent = {
                element: optGroupTemplate.clone().attr('label', optionGroupName),
                label: optionGroup.label
              };
              existingOptions = [existingParent];
              optionGroupsCache.push(existingOptions);
              selectElement.append(existingParent.element);
            } else {
              existingOptions = optionGroupsCache[groupIndex];
              existingParent = existingOptions[0];  // either SELECT (no group) or OPTGROUP element

              // update the OPTGROUP label if not the same.
              if (existingParent.label != optionGroupName) {
                existingParent.element.attr('label', existingParent.label = optionGroupName);
              }
            }

            lastElement = null;  // start at the beginning
            for (index = 0, length = optionGroup.length; index < length; index++) {
              option = optionGroup[index];
              if ((existingOption = existingOptions[index + 1])) {
                // reuse elements
                lastElement = existingOption.element;
                if (existingOption.label !== option.label) {
                  updateLabelMap(labelMap, existingOption.label, false);
                  updateLabelMap(labelMap, option.label, true);
                  lastElement.text(existingOption.label = option.label);
                  lastElement.prop('label', existingOption.label);
                }
                if (existingOption.id !== option.id) {
                  lastElement.val(existingOption.id = option.id);
                }
                // lastElement.prop('selected') provided by jQuery has side-effects
                if (lastElement[0].selected !== option.selected) {
                  lastElement.prop('selected', (existingOption.selected = option.selected));
                  if (msie) {
                    // See #7692
                    // The selected item wouldn't visually update on IE without this.
                    // Tested on Win7: IE9, IE10 and IE11. Future IEs should be tested as well
                    lastElement.prop('selected', existingOption.selected);
                  }
                }
              } else {
                // grow elements

                // if it's a null option
                if (option.id === '' && nullOption) {
                  // put back the pre-compiled element
                  element = nullOption;
                } else {
                  // jQuery(v1.4.2) Bug: We should be able to chain the method calls, but
                  // in this version of jQuery on some browser the .text() returns a string
                  // rather then the element.
                  (element = optionTemplate.clone())
                      .val(option.id)
                      .prop('selected', option.selected)
                      .attr('selected', option.selected)
                      .prop('label', option.label)
                      .text(option.label);
                }

                existingOptions.push(existingOption = {
                    element: element,
                    label: option.label,
                    id: option.id,
                    selected: option.selected
                });
                updateLabelMap(labelMap, option.label, true);
                if (lastElement) {
                  lastElement.after(element);
                } else {
                  existingParent.element.append(element);
                }
                lastElement = element;
              }
            }
            // remove any excessive OPTIONs in a group
            index++; // increment since the existingOptions[0] is parent element not OPTION
            while (existingOptions.length > index) {
              option = existingOptions.pop();
              updateLabelMap(labelMap, option.label, false);
              option.element.remove();
            }
          }
          // remove any excessive OPTGROUPs from select
          while (optionGroupsCache.length > groupIndex) {
            // remove all the labels in the option group
            optionGroup = optionGroupsCache.pop();
            for (index = 1; index < optionGroup.length; ++index) {
              updateLabelMap(labelMap, optionGroup[index].label, false);
            }
            optionGroup[0].element.remove();
          }
          forEach(labelMap, function(count, label) {
            if (count > 0) {
              selectCtrl.addOption(label);
            } else if (count < 0) {
              selectCtrl.removeOption(label);
            }
          });
        }
      }
    }
  };
}];

var optionDirective = ['$interpolate', function($interpolate) {
  var nullSelectCtrl = {
    addOption: noop,
    removeOption: noop
  };

  return {
    restrict: 'E',
    priority: 100,
    compile: function(element, attr) {
      if (isUndefined(attr.value)) {
        var interpolateFn = $interpolate(element.text(), true);
        if (!interpolateFn) {
          attr.$set('value', element.text());
        }
      }

      return function(scope, element, attr) {
        var selectCtrlName = '$selectController',
            parent = element.parent(),
            selectCtrl = parent.data(selectCtrlName) ||
              parent.parent().data(selectCtrlName); // in case we are in optgroup

        if (!selectCtrl || !selectCtrl.databound) {
          selectCtrl = nullSelectCtrl;
        }

        if (interpolateFn) {
          scope.$watch(interpolateFn, function interpolateWatchAction(newVal, oldVal) {
            attr.$set('value', newVal);
            if (oldVal !== newVal) {
              selectCtrl.removeOption(oldVal);
            }
            selectCtrl.addOption(newVal, element);
          });
        } else {
          selectCtrl.addOption(attr.value, element);
        }

        element.on('$destroy', function() {
          selectCtrl.removeOption(attr.value);
        });
      };
    }
  };
}];

var styleDirective = valueFn({
  restrict: 'E',
  terminal: false
});

var requiredDirective = function() {
  return {
    restrict: 'A',
    require: '?ngModel',
    link: function(scope, elm, attr, ctrl) {
      if (!ctrl) return;
      attr.required = true; // force truthy in case we are on non input element

      ctrl.$validators.required = function(modelValue, viewValue) {
        return !attr.required || !ctrl.$isEmpty(viewValue);
      };

      attr.$observe('required', function() {
        ctrl.$validate();
      });
    }
  };
};


var patternDirective = function() {
  return {
    restrict: 'A',
    require: '?ngModel',
    link: function(scope, elm, attr, ctrl) {
      if (!ctrl) return;

      var regexp, patternExp = attr.ngPattern || attr.pattern;
      attr.$observe('pattern', function(regex) {
        if (isString(regex) && regex.length > 0) {
          regex = new RegExp('^' + regex + '$');
        }

        if (regex && !regex.test) {
          throw minErr('ngPattern')('noregexp',
            'Expected {0} to be a RegExp but was {1}. Element: {2}', patternExp,
            regex, startingTag(elm));
        }

        regexp = regex || undefined;
        ctrl.$validate();
      });

      ctrl.$validators.pattern = function(modelValue, viewValue) {
        // HTML5 pattern constraint validates the input value, so we validate the viewValue
        return ctrl.$isEmpty(viewValue) || isUndefined(regexp) || regexp.test(viewValue);
      };
    }
  };
};


var maxlengthDirective = function() {
  return {
    restrict: 'A',
    require: '?ngModel',
    link: function(scope, elm, attr, ctrl) {
      if (!ctrl) return;

      var maxlength = -1;
      attr.$observe('maxlength', function(value) {
        var intVal = int(value);
        maxlength = isNaN(intVal) ? -1 : intVal;
        ctrl.$validate();
      });
      ctrl.$validators.maxlength = function(modelValue, viewValue) {
        return (maxlength < 0) || ctrl.$isEmpty(viewValue) || (viewValue.length <= maxlength);
      };
    }
  };
};

var minlengthDirective = function() {
  return {
    restrict: 'A',
    require: '?ngModel',
    link: function(scope, elm, attr, ctrl) {
      if (!ctrl) return;

      var minlength = 0;
      attr.$observe('minlength', function(value) {
        minlength = int(value) || 0;
        ctrl.$validate();
      });
      ctrl.$validators.minlength = function(modelValue, viewValue) {
        return ctrl.$isEmpty(viewValue) || viewValue.length >= minlength;
      };
    }
  };
};

  if (window.angular.bootstrap) {
    //AngularJS is already loaded, so we can return here...
    console.log('WARNING: Tried to load angular more than once.');
    return;
  }

  //try to bind to jquery now so that one can write jqLite(document).ready()
  //but we will rebind on bootstrap again.
  bindJQuery();

  publishExternalAPI(angular);

  jqLite(document).ready(function() {
    angularInit(document, bootstrap);
  });

})(window, document);

!window.angular.$$csp() && window.angular.element(document.head).prepend('<style type="text/css">@charset "UTF-8";[ng\\:cloak],[ng-cloak],[data-ng-cloak],[x-ng-cloak],.ng-cloak,.x-ng-cloak,.ng-hide:not(.ng-hide-animate){display:none !important;}ng\\:form{display:block;}</style>');
/*
 * angular-ui-bootstrap
 * http://angular-ui.github.io/bootstrap/

 * Version: 0.13.4 - 2015-09-03
 * License: MIT
 */
angular.module("ui.bootstrap", ["ui.bootstrap.tpls", "ui.bootstrap.collapse","ui.bootstrap.accordion","ui.bootstrap.alert","ui.bootstrap.bindHtml","ui.bootstrap.buttons","ui.bootstrap.carousel","ui.bootstrap.dateparser","ui.bootstrap.position","ui.bootstrap.datepicker","ui.bootstrap.dropdown","ui.bootstrap.modal","ui.bootstrap.pagination","ui.bootstrap.tooltip","ui.bootstrap.popover","ui.bootstrap.progressbar","ui.bootstrap.rating","ui.bootstrap.tabs","ui.bootstrap.timepicker","ui.bootstrap.transition","ui.bootstrap.typeahead"]);
angular.module("ui.bootstrap.tpls", ["template/accordion/accordion-group.html","template/accordion/accordion.html","template/alert/alert.html","template/carousel/carousel.html","template/carousel/slide.html","template/datepicker/datepicker.html","template/datepicker/day.html","template/datepicker/month.html","template/datepicker/popup.html","template/datepicker/year.html","template/modal/backdrop.html","template/modal/window.html","template/pagination/pager.html","template/pagination/pagination.html","template/tooltip/tooltip-html-popup.html","template/tooltip/tooltip-html-unsafe-popup.html","template/tooltip/tooltip-popup.html","template/tooltip/tooltip-template-popup.html","template/popover/popover-html.html","template/popover/popover-template.html","template/popover/popover.html","template/progressbar/bar.html","template/progressbar/progress.html","template/progressbar/progressbar.html","template/rating/rating.html","template/tabs/tab.html","template/tabs/tabset.html","template/timepicker/timepicker.html","template/typeahead/typeahead-match.html","template/typeahead/typeahead-popup.html"]);
angular.module('ui.bootstrap.collapse', [])

  .directive('collapse', ['$animate', function($animate) {
    return {
      link: function(scope, element, attrs) {
        function expand() {
          element.removeClass('collapse')
            .addClass('collapsing')
            .attr('aria-expanded', true)
            .attr('aria-hidden', false);

          $animate.addClass(element, 'in', {
            to: { height: element[0].scrollHeight + 'px' }
          }).then(expandDone);
        }

        function expandDone() {
          element.removeClass('collapsing');
          element.css({height: 'auto'});
        }

        function collapse() {
          if (!element.hasClass('collapse') && !element.hasClass('in')) {
            return collapseDone();
          }

          element
            // IMPORTANT: The height must be set before adding "collapsing" class.
            // Otherwise, the browser attempts to animate from height 0 (in
            // collapsing class) to the given height here.
            .css({height: element[0].scrollHeight + 'px'})
            // initially all panel collapse have the collapse class, this removal
            // prevents the animation from jumping to collapsed state
            .removeClass('collapse')
            .addClass('collapsing')
            .attr('aria-expanded', false)
            .attr('aria-hidden', true);

          $animate.removeClass(element, 'in', {
            to: {height: '0'}
          }).then(collapseDone);
        }

        function collapseDone() {
          element.css({height: '0'}); // Required so that collapse works when animation is disabled
          element.removeClass('collapsing');
          element.addClass('collapse');
        }

        scope.$watch(attrs.collapse, function(shouldCollapse) {
          if (shouldCollapse) {
            collapse();
          } else {
            expand();
          }
        });
      }
    };
  }]);

angular.module('ui.bootstrap.accordion', ['ui.bootstrap.collapse'])

.constant('accordionConfig', {
  closeOthers: true
})

.controller('AccordionController', ['$scope', '$attrs', 'accordionConfig', function($scope, $attrs, accordionConfig) {
  // This array keeps track of the accordion groups
  this.groups = [];

  // Ensure that all the groups in this accordion are closed, unless close-others explicitly says not to
  this.closeOthers = function(openGroup) {
    var closeOthers = angular.isDefined($attrs.closeOthers) ?
      $scope.$eval($attrs.closeOthers) : accordionConfig.closeOthers;
    if (closeOthers) {
      angular.forEach(this.groups, function(group) {
        if (group !== openGroup) {
          group.isOpen = false;
        }
      });
    }
  };

  // This is called from the accordion-group directive to add itself to the accordion
  this.addGroup = function(groupScope) {
    var that = this;
    this.groups.push(groupScope);

    groupScope.$on('$destroy', function(event) {
      that.removeGroup(groupScope);
    });
  };

  // This is called from the accordion-group directive when to remove itself
  this.removeGroup = function(group) {
    var index = this.groups.indexOf(group);
    if (index !== -1) {
      this.groups.splice(index, 1);
    }
  };

}])

// The accordion directive simply sets up the directive controller
// and adds an accordion CSS class to itself element.
.directive('accordion', function() {
  return {
    restrict: 'EA',
    controller: 'AccordionController',
    controllerAs: 'accordion',
    transclude: true,
    replace: false,
    templateUrl: function(element, attrs) {
      return attrs.templateUrl || 'template/accordion/accordion.html';
    }
  };
})

// The accordion-group directive indicates a block of html that will expand and collapse in an accordion
.directive('accordionGroup', function() {
  return {
    require: '^accordion',         // We need this directive to be inside an accordion
    restrict: 'EA',
    transclude: true,              // It transcludes the contents of the directive into the template
    replace: true,                // The element containing the directive will be replaced with the template
    templateUrl: function(element, attrs) {
      return attrs.templateUrl || 'template/accordion/accordion-group.html';
    },
    scope: {
      heading: '@',               // Interpolate the heading attribute onto this scope
      isOpen: '=?',
      isDisabled: '=?'
    },
    controller: function() {
      this.setHeading = function(element) {
        this.heading = element;
      };
    },
    link: function(scope, element, attrs, accordionCtrl) {
      accordionCtrl.addGroup(scope);

      scope.openClass = attrs.openClass || 'panel-open';
      scope.panelClass = attrs.panelClass;
      scope.$watch('isOpen', function(value) {
        element.toggleClass(scope.openClass, value);
        if (value) {
          accordionCtrl.closeOthers(scope);
        }
      });

      scope.toggleOpen = function($event) {
        if (!scope.isDisabled) {
          if (!$event || $event.which === 32) {
            scope.isOpen = !scope.isOpen;
          }
        }
      };
    }
  };
})

// Use accordion-heading below an accordion-group to provide a heading containing HTML
// <accordion-group>
//   <accordion-heading>Heading containing HTML - <img src="..."></accordion-heading>
// </accordion-group>
.directive('accordionHeading', function() {
  return {
    restrict: 'EA',
    transclude: true,   // Grab the contents to be used as the heading
    template: '',       // In effect remove this element!
    replace: true,
    require: '^accordionGroup',
    link: function(scope, element, attr, accordionGroupCtrl, transclude) {
      // Pass the heading to the accordion-group controller
      // so that it can be transcluded into the right place in the template
      // [The second parameter to transclude causes the elements to be cloned so that they work in ng-repeat]
      accordionGroupCtrl.setHeading(transclude(scope, angular.noop));
    }
  };
})

// Use in the accordion-group template to indicate where you want the heading to be transcluded
// You must provide the property on the accordion-group controller that will hold the transcluded element
// <div class="accordion-group">
//   <div class="accordion-heading" ><a ... accordion-transclude="heading">...</a></div>
//   ...
// </div>
.directive('accordionTransclude', function() {
  return {
    require: '^accordionGroup',
    link: function(scope, element, attr, controller) {
      scope.$watch(function() { return controller[attr.accordionTransclude]; }, function(heading) {
        if (heading) {
          element.find('span').html('');
          element.find('span').append(heading);
        }
      });
    }
  };
})

;

angular.module('ui.bootstrap.alert', [])

.controller('AlertController', ['$scope', '$attrs', function($scope, $attrs) {
  $scope.closeable = !!$attrs.close;
  this.close = $scope.close;
}])

.directive('alert', function() {
  return {
    controller: 'AlertController',
    controllerAs: 'alert',
    templateUrl: function(element, attrs) {
      return attrs.templateUrl || 'template/alert/alert.html';
    },
    transclude: true,
    replace: true,
    scope: {
      type: '@',
      close: '&'
    }
  };
})

.directive('dismissOnTimeout', ['$timeout', function($timeout) {
  return {
    require: 'alert',
    link: function(scope, element, attrs, alertCtrl) {
      $timeout(function() {
        alertCtrl.close();
      }, parseInt(attrs.dismissOnTimeout, 10));
    }
  };
}]);

angular.module('ui.bootstrap.bindHtml', [])

  .value('$bindHtmlUnsafeSuppressDeprecated', false)

  .directive('bindHtmlUnsafe', ['$log', '$bindHtmlUnsafeSuppressDeprecated', function ($log, $bindHtmlUnsafeSuppressDeprecated) {
    return function (scope, element, attr) {
      if (!$bindHtmlUnsafeSuppressDeprecated) {
        $log.warn('bindHtmlUnsafe is now deprecated. Use ngBindHtml instead');
      }
      element.addClass('ng-binding').data('$binding', attr.bindHtmlUnsafe);
      scope.$watch(attr.bindHtmlUnsafe, function bindHtmlUnsafeWatchAction(value) {
        element.html(value || '');
      });
    };
  }]);
angular.module('ui.bootstrap.buttons', [])

.constant('buttonConfig', {
  activeClass: 'active',
  toggleEvent: 'click'
})

.controller('ButtonsController', ['buttonConfig', function(buttonConfig) {
  this.activeClass = buttonConfig.activeClass || 'active';
  this.toggleEvent = buttonConfig.toggleEvent || 'click';
}])

.directive('btnRadio', function() {
  return {
    require: ['btnRadio', 'ngModel'],
    controller: 'ButtonsController',
    controllerAs: 'buttons',
    link: function(scope, element, attrs, ctrls) {
      var buttonsCtrl = ctrls[0], ngModelCtrl = ctrls[1];

      element.find('input').css({display: 'none'});

      //model -> UI
      ngModelCtrl.$render = function() {
        element.toggleClass(buttonsCtrl.activeClass, angular.equals(ngModelCtrl.$modelValue, scope.$eval(attrs.btnRadio)));
      };

      //ui->model
      element.bind(buttonsCtrl.toggleEvent, function() {
        if (attrs.disabled) {
          return;
        }

        var isActive = element.hasClass(buttonsCtrl.activeClass);

        if (!isActive || angular.isDefined(attrs.uncheckable)) {
          scope.$apply(function() {
            ngModelCtrl.$setViewValue(isActive ? null : scope.$eval(attrs.btnRadio));
            ngModelCtrl.$render();
          });
        }
      });
    }
  };
})

.directive('btnCheckbox', ['$document', function($document) {
  return {
    require: ['btnCheckbox', 'ngModel'],
    controller: 'ButtonsController',
    controllerAs: 'button',
    link: function(scope, element, attrs, ctrls) {
      var buttonsCtrl = ctrls[0], ngModelCtrl = ctrls[1];

      element.find('input').css({display: 'none'});

      function getTrueValue() {
        return getCheckboxValue(attrs.btnCheckboxTrue, true);
      }

      function getFalseValue() {
        return getCheckboxValue(attrs.btnCheckboxFalse, false);
      }

      function getCheckboxValue(attributeValue, defaultValue) {
        var val = scope.$eval(attributeValue);
        return angular.isDefined(val) ? val : defaultValue;
      }

      //model -> UI
      ngModelCtrl.$render = function() {
        element.toggleClass(buttonsCtrl.activeClass, angular.equals(ngModelCtrl.$modelValue, getTrueValue()));
      };

      //ui->model
      element.bind(buttonsCtrl.toggleEvent, function() {
        if (attrs.disabled) {
          return;
        }

        scope.$apply(function() {
          ngModelCtrl.$setViewValue(element.hasClass(buttonsCtrl.activeClass) ? getFalseValue() : getTrueValue());
          ngModelCtrl.$render();
        });
      });

      //accessibility
      element.on('keypress', function(e) {
        if (attrs.disabled || e.which !== 32 || $document[0].activeElement !== element[0]) {
          return;
        }

        scope.$apply(function() {
          ngModelCtrl.$setViewValue(element.hasClass(buttonsCtrl.activeClass) ? getFalseValue() : getTrueValue());
          ngModelCtrl.$render();
        });
      });
    }
  };
}]);

/**
* @ngdoc overview
* @name ui.bootstrap.carousel
*
* @description
* AngularJS version of an image carousel.
*
*/
angular.module('ui.bootstrap.carousel', [])
.controller('CarouselController', ['$scope', '$element', '$interval', '$animate', function ($scope, $element, $interval, $animate) {
  var self = this,
    slides = self.slides = $scope.slides = [],
    NEW_ANIMATE = angular.version.minor >= 4,
    NO_TRANSITION = 'uib-noTransition',
    SLIDE_DIRECTION = 'uib-slideDirection',
    currentIndex = -1,
    currentInterval, isPlaying;
  self.currentSlide = null;

  var destroyed = false;
  /* direction: "prev" or "next" */
  self.select = $scope.select = function(nextSlide, direction) {
    var nextIndex = $scope.indexOfSlide(nextSlide);
    //Decide direction if it's not given
    if (direction === undefined) {
      direction = nextIndex > self.getCurrentIndex() ? 'next' : 'prev';
    }
    //Prevent this user-triggered transition from occurring if there is already one in progress
    if (nextSlide && nextSlide !== self.currentSlide && !$scope.$currentTransition) {
      goNext(nextSlide, nextIndex, direction);
    }
  };

  function goNext(slide, index, direction) {
    // Scope has been destroyed, stop here.
    if (destroyed) { return; }

    angular.extend(slide, {direction: direction, active: true});
    angular.extend(self.currentSlide || {}, {direction: direction, active: false});
    if ($animate.enabled() && !$scope.noTransition && !$scope.$currentTransition &&
      slide.$element && self.slides.length > 1) {
      slide.$element.data(SLIDE_DIRECTION, slide.direction);
      if (self.currentSlide && self.currentSlide.$element) {
        self.currentSlide.$element.data(SLIDE_DIRECTION, slide.direction);
      }

      $scope.$currentTransition = true;
      if (NEW_ANIMATE) {
        $animate.on('addClass', slide.$element, function (element, phase) {
          if (phase === 'close') {
            $scope.$currentTransition = null;
            $animate.off('addClass', element);
          }
        });
      } else {
        slide.$element.one('$animate:close', function closeFn() {
          $scope.$currentTransition = null;
        });
      }
    }

    self.currentSlide = slide;
    currentIndex = index;

    //every time you change slides, reset the timer
    restartTimer();
  }

  $scope.$on('$destroy', function () {
    destroyed = true;
  });

  function getSlideByIndex(index) {
    if (angular.isUndefined(slides[index].index)) {
      return slides[index];
    }
    var i, len = slides.length;
    for (i = 0; i < slides.length; ++i) {
      if (slides[i].index == index) {
        return slides[i];
      }
    }
  }

  self.getCurrentIndex = function() {
    if (self.currentSlide && angular.isDefined(self.currentSlide.index)) {
      return +self.currentSlide.index;
    }
    return currentIndex;
  };

  /* Allow outside people to call indexOf on slides array */
  $scope.indexOfSlide = function(slide) {
    return angular.isDefined(slide.index) ? +slide.index : slides.indexOf(slide);
  };

  $scope.next = function() {
    var newIndex = (self.getCurrentIndex() + 1) % slides.length;

    if (newIndex === 0 && $scope.noWrap()) {
      $scope.pause();
      return;
    }

    return self.select(getSlideByIndex(newIndex), 'next');
  };

  $scope.prev = function() {
    var newIndex = self.getCurrentIndex() - 1 < 0 ? slides.length - 1 : self.getCurrentIndex() - 1;

    if ($scope.noWrap() && newIndex === slides.length - 1){
      $scope.pause();
      return;
    }

    return self.select(getSlideByIndex(newIndex), 'prev');
  };

  $scope.isActive = function(slide) {
     return self.currentSlide === slide;
  };

  $scope.$watch('interval', restartTimer);
  $scope.$on('$destroy', resetTimer);

  function restartTimer() {
    resetTimer();
    var interval = +$scope.interval;
    if (!isNaN(interval) && interval > 0) {
      currentInterval = $interval(timerFn, interval);
    }
  }

  function resetTimer() {
    if (currentInterval) {
      $interval.cancel(currentInterval);
      currentInterval = null;
    }
  }

  function timerFn() {
    var interval = +$scope.interval;
    if (isPlaying && !isNaN(interval) && interval > 0 && slides.length) {
      $scope.next();
    } else {
      $scope.pause();
    }
  }

  $scope.play = function() {
    if (!isPlaying) {
      isPlaying = true;
      restartTimer();
    }
  };
  $scope.pause = function() {
    if (!$scope.noPause) {
      isPlaying = false;
      resetTimer();
    }
  };

  self.addSlide = function(slide, element) {
    slide.$element = element;
    slides.push(slide);
    //if this is the first slide or the slide is set to active, select it
    if(slides.length === 1 || slide.active) {
      self.select(slides[slides.length-1]);
      if (slides.length == 1) {
        $scope.play();
      }
    } else {
      slide.active = false;
    }
  };

  self.removeSlide = function(slide) {
    if (angular.isDefined(slide.index)) {
      slides.sort(function(a, b) {
        return +a.index > +b.index;
      });
    }
    //get the index of the slide inside the carousel
    var index = slides.indexOf(slide);
    slides.splice(index, 1);
    if (slides.length > 0 && slide.active) {
      if (index >= slides.length) {
        self.select(slides[index-1]);
      } else {
        self.select(slides[index]);
      }
    } else if (currentIndex > index) {
      currentIndex--;
    }
    
    //clean the currentSlide when no more slide
    if (slides.length === 0) {
      self.currentSlide = null;
    }
  };

  $scope.$watch('noTransition', function(noTransition) {
    $element.data(NO_TRANSITION, noTransition);
  });

}])

/**
 * @ngdoc directive
 * @name ui.bootstrap.carousel.directive:carousel
 * @restrict EA
 *
 * @description
 * Carousel is the outer container for a set of image 'slides' to showcase.
 *
 * @param {number=} interval The time, in milliseconds, that it will take the carousel to go to the next slide.
 * @param {boolean=} noTransition Whether to disable transitions on the carousel.
 * @param {boolean=} noPause Whether to disable pausing on the carousel (by default, the carousel interval pauses on hover).
 *
 * @example
<example module="ui.bootstrap">
  <file name="index.html">
    <carousel>
      <slide>
        <img src="http://placekitten.com/150/150" style="margin:auto;">
        <div class="carousel-caption">
          <p>Beautiful!</p>
        </div>
      </slide>
      <slide>
        <img src="http://placekitten.com/100/150" style="margin:auto;">
        <div class="carousel-caption">
          <p>D'aww!</p>
        </div>
      </slide>
    </carousel>
  </file>
  <file name="demo.css">
    .carousel-indicators {
      top: auto;
      bottom: 15px;
    }
  </file>
</example>
 */
.directive('carousel', [function() {
  return {
    restrict: 'EA',
    transclude: true,
    replace: true,
    controller: 'CarouselController',
    controllerAs: 'carousel',
    require: 'carousel',
    templateUrl: function(element, attrs) {
      return attrs.templateUrl || 'template/carousel/carousel.html';
    },
    scope: {
      interval: '=',
      noTransition: '=',
      noPause: '=',
      noWrap: '&'
    }
  };
}])

/**
 * @ngdoc directive
 * @name ui.bootstrap.carousel.directive:slide
 * @restrict EA
 *
 * @description
 * Creates a slide inside a {@link ui.bootstrap.carousel.directive:carousel carousel}.  Must be placed as a child of a carousel element.
 *
 * @param {boolean=} active Model binding, whether or not this slide is currently active.
 * @param {number=} index The index of the slide. The slides will be sorted by this parameter.
 *
 * @example
<example module="ui.bootstrap">
  <file name="index.html">
<div ng-controller="CarouselDemoCtrl">
  <carousel>
    <slide ng-repeat="slide in slides" active="slide.active" index="$index">
      <img ng-src="{{slide.image}}" style="margin:auto;">
      <div class="carousel-caption">
        <h4>Slide {{$index}}</h4>
        <p>{{slide.text}}</p>
      </div>
    </slide>
  </carousel>
  Interval, in milliseconds: <input type="number" ng-model="myInterval">
  <br />Enter a negative number to stop the interval.
</div>
  </file>
  <file name="script.js">
function CarouselDemoCtrl($scope) {
  $scope.myInterval = 5000;
}
  </file>
  <file name="demo.css">
    .carousel-indicators {
      top: auto;
      bottom: 15px;
    }
  </file>
</example>
*/

.directive('slide', function() {
  return {
    require: '^carousel',
    restrict: 'EA',
    transclude: true,
    replace: true,
    templateUrl: function(element, attrs) {
      return attrs.templateUrl || 'template/carousel/slide.html';
    },
    scope: {
      active: '=?',
      actual: '=?',
      index: '=?'
    },
    link: function (scope, element, attrs, carouselCtrl) {
      carouselCtrl.addSlide(scope, element);
      //when the scope is destroyed then remove the slide from the current slides array
      scope.$on('$destroy', function() {
        carouselCtrl.removeSlide(scope);
      });

      scope.$watch('active', function(active) {
        if (active) {
          carouselCtrl.select(scope);
        }
      });
    }
  };
})

.animation('.item', [
         '$injector', '$animate',
function ($injector, $animate) {
  var NO_TRANSITION = 'uib-noTransition',
    SLIDE_DIRECTION = 'uib-slideDirection',
    $animateCss = null;

  if ($injector.has('$animateCss')) {
    $animateCss = $injector.get('$animateCss');
  }

  function removeClass(element, className, callback) {
    element.removeClass(className);
    if (callback) {
      callback();
    }
  }

  return {
    beforeAddClass: function (element, className, done) {
      // Due to transclusion, noTransition property is on parent's scope
      if (className == 'active' && element.parent() &&
          !element.parent().data(NO_TRANSITION)) {
        var stopped = false;
        var direction = element.data(SLIDE_DIRECTION);
        var directionClass = direction == 'next' ? 'left' : 'right';
        var removeClassFn = removeClass.bind(this, element,
          directionClass + ' ' + direction, done);
        element.addClass(direction);

        if ($animateCss) {
          $animateCss(element, {addClass: directionClass})
            .start()
            .done(removeClassFn);
        } else {
          $animate.addClass(element, directionClass).then(function () {
            if (!stopped) {
              removeClassFn();
            }
            done();
          });
        }

        return function () {
          stopped = true;
        };
      }
      done();
    },
    beforeRemoveClass: function (element, className, done) {
      // Due to transclusion, noTransition property is on parent's scope
      if (className === 'active' && element.parent() &&
          !element.parent().data(NO_TRANSITION)) {
        var stopped = false;
        var direction = element.data(SLIDE_DIRECTION);
        var directionClass = direction == 'next' ? 'left' : 'right';
        var removeClassFn = removeClass.bind(this, element, directionClass, done);

        if ($animateCss) {
          $animateCss(element, {addClass: directionClass})
            .start()
            .done(removeClassFn);
        } else {
          $animate.addClass(element, directionClass).then(function () {
            if (!stopped) {
              removeClassFn();
            }
            done();
          });
        }
        return function () {
          stopped = true;
        };
      }
      done();
    }
  };

}])


;

angular.module('ui.bootstrap.dateparser', [])

.service('dateParser', ['$log', '$locale', 'orderByFilter', function($log, $locale, orderByFilter) {
  // Pulled from https://github.com/mbostock/d3/blob/master/src/format/requote.js
  var SPECIAL_CHARACTERS_REGEXP = /[\\\^\$\*\+\?\|\[\]\(\)\.\{\}]/g;

  this.parsers = {};

  var formatCodeToRegex = {
    'yyyy': {
      regex: '\\d{4}',
      apply: function(value) { this.year = +value; }
    },
    'yy': {
      regex: '\\d{2}',
      apply: function(value) { this.year = +value + 2000; }
    },
    'y': {
      regex: '\\d{1,4}',
      apply: function(value) { this.year = +value; }
    },
    'MMMM': {
      regex: $locale.DATETIME_FORMATS.MONTH.join('|'),
      apply: function(value) { this.month = $locale.DATETIME_FORMATS.MONTH.indexOf(value); }
    },
    'MMM': {
      regex: $locale.DATETIME_FORMATS.SHORTMONTH.join('|'),
      apply: function(value) { this.month = $locale.DATETIME_FORMATS.SHORTMONTH.indexOf(value); }
    },
    'MM': {
      regex: '0[1-9]|1[0-2]',
      apply: function(value) { this.month = value - 1; }
    },
    'M': {
      regex: '[1-9]|1[0-2]',
      apply: function(value) { this.month = value - 1; }
    },
    'dd': {
      regex: '[0-2][0-9]{1}|3[0-1]{1}',
      apply: function(value) { this.date = +value; }
    },
    'd': {
      regex: '[1-2]?[0-9]{1}|3[0-1]{1}',
      apply: function(value) { this.date = +value; }
    },
    'EEEE': {
      regex: $locale.DATETIME_FORMATS.DAY.join('|')
    },
    'EEE': {
      regex: $locale.DATETIME_FORMATS.SHORTDAY.join('|')
    },
    'HH': {
      regex: '(?:0|1)[0-9]|2[0-3]',
      apply: function(value) { this.hours = +value; }
    },
    'hh': {
      regex: '0[0-9]|1[0-2]',
      apply: function(value) { this.hours = +value; }
    },
    'H': {
      regex: '1?[0-9]|2[0-3]',
      apply: function(value) { this.hours = +value; }
    },
    'h': {
      regex: '[0-9]|1[0-2]',
      apply: function(value) { this.hours = +value; }
    },
    'mm': {
      regex: '[0-5][0-9]',
      apply: function(value) { this.minutes = +value; }
    },
    'm': {
      regex: '[0-9]|[1-5][0-9]',
      apply: function(value) { this.minutes = +value; }
    },
    'sss': {
      regex: '[0-9][0-9][0-9]',
      apply: function(value) { this.milliseconds = +value; }
    },
    'ss': {
      regex: '[0-5][0-9]',
      apply: function(value) { this.seconds = +value; }
    },
    's': {
      regex: '[0-9]|[1-5][0-9]',
      apply: function(value) { this.seconds = +value; }
    },
    'a': {
      regex: $locale.DATETIME_FORMATS.AMPMS.join('|'),
      apply: function(value) {
        if (this.hours === 12) {
          this.hours = 0;
        }

        if (value === 'PM') {
          this.hours += 12;
        }
      }
    }
  };

  function createParser(format) {
    var map = [], regex = format.split('');

    angular.forEach(formatCodeToRegex, function(data, code) {
      var index = format.indexOf(code);

      if (index > -1) {
        format = format.split('');

        regex[index] = '(' + data.regex + ')';
        format[index] = '$'; // Custom symbol to define consumed part of format
        for (var i = index + 1, n = index + code.length; i < n; i++) {
          regex[i] = '';
          format[i] = '$';
        }
        format = format.join('');

        map.push({ index: index, apply: data.apply });
      }
    });

    return {
      regex: new RegExp('^' + regex.join('') + '$'),
      map: orderByFilter(map, 'index')
    };
  }

  this.parse = function(input, format, baseDate) {
    if (!angular.isString(input) || !format) {
      return input;
    }

    format = $locale.DATETIME_FORMATS[format] || format;
    format = format.replace(SPECIAL_CHARACTERS_REGEXP, '\\$&');

    if (!this.parsers[format]) {
      this.parsers[format] = createParser(format);
    }

    var parser = this.parsers[format],
        regex = parser.regex,
        map = parser.map,
        results = input.match(regex);

    if (results && results.length) {
      var fields, dt;
      if (angular.isDate(baseDate) && !isNaN(baseDate.getTime())) {
        fields = {
          year: baseDate.getFullYear(),
          month: baseDate.getMonth(),
          date: baseDate.getDate(),
          hours: baseDate.getHours(),
          minutes: baseDate.getMinutes(),
          seconds: baseDate.getSeconds(),
          milliseconds: baseDate.getMilliseconds()
        };
      } else {
        if (baseDate) {
          $log.warn('dateparser:', 'baseDate is not a valid date');
        }
        fields = { year: 1900, month: 0, date: 1, hours: 0, minutes: 0, seconds: 0, milliseconds: 0 };
      }

      for (var i = 1, n = results.length; i < n; i++) {
        var mapper = map[i-1];
        if (mapper.apply) {
          mapper.apply.call(fields, results[i]);
        }
      }

      if (isValid(fields.year, fields.month, fields.date)) {
        dt = new Date(fields.year, fields.month, fields.date,
          fields.hours, fields.minutes, fields.seconds,
          fields.milliseconds || 0);
      }

      return dt;
    }
  };

  // Check if date is valid for specific month (and year for February).
  // Month: 0 = Jan, 1 = Feb, etc
  function isValid(year, month, date) {
    if (date < 1) {
      return false;
    }

    if (month === 1 && date > 28) {
      return date === 29 && ((year % 4 === 0 && year % 100 !== 0) || year % 400 === 0);
    }

    if (month === 3 || month === 5 || month === 8 || month === 10) {
      return date < 31;
    }

    return true;
  }
}]);

angular.module('ui.bootstrap.position', [])

/**
 * A set of utility methods that can be use to retrieve position of DOM elements.
 * It is meant to be used where we need to absolute-position DOM elements in
 * relation to other, existing elements (this is the case for tooltips, popovers,
 * typeahead suggestions etc.).
 */
  .factory('$position', ['$document', '$window', function($document, $window) {
    function getStyle(el, cssprop) {
      if (el.currentStyle) { //IE
        return el.currentStyle[cssprop];
      } else if ($window.getComputedStyle) {
        return $window.getComputedStyle(el)[cssprop];
      }
      // finally try and get inline style
      return el.style[cssprop];
    }

    /**
     * Checks if a given element is statically positioned
     * @param element - raw DOM element
     */
    function isStaticPositioned(element) {
      return (getStyle(element, 'position') || 'static' ) === 'static';
    }

    /**
     * returns the closest, non-statically positioned parentOffset of a given element
     * @param element
     */
    var parentOffsetEl = function(element) {
      var docDomEl = $document[0];
      var offsetParent = element.offsetParent || docDomEl;
      while (offsetParent && offsetParent !== docDomEl && isStaticPositioned(offsetParent) ) {
        offsetParent = offsetParent.offsetParent;
      }
      return offsetParent || docDomEl;
    };

    return {
      /**
       * Provides read-only equivalent of jQuery's position function:
       * http://api.jquery.com/position/
       */
      position: function(element) {
        var elBCR = this.offset(element);
        var offsetParentBCR = { top: 0, left: 0 };
        var offsetParentEl = parentOffsetEl(element[0]);
        if (offsetParentEl != $document[0]) {
          offsetParentBCR = this.offset(angular.element(offsetParentEl));
          offsetParentBCR.top += offsetParentEl.clientTop - offsetParentEl.scrollTop;
          offsetParentBCR.left += offsetParentEl.clientLeft - offsetParentEl.scrollLeft;
        }

        var boundingClientRect = element[0].getBoundingClientRect();
        return {
          width: boundingClientRect.width || element.prop('offsetWidth'),
          height: boundingClientRect.height || element.prop('offsetHeight'),
          top: elBCR.top - offsetParentBCR.top,
          left: elBCR.left - offsetParentBCR.left
        };
      },

      /**
       * Provides read-only equivalent of jQuery's offset function:
       * http://api.jquery.com/offset/
       */
      offset: function(element) {
        var boundingClientRect = element[0].getBoundingClientRect();
        return {
          width: boundingClientRect.width || element.prop('offsetWidth'),
          height: boundingClientRect.height || element.prop('offsetHeight'),
          top: boundingClientRect.top + ($window.pageYOffset || $document[0].documentElement.scrollTop),
          left: boundingClientRect.left + ($window.pageXOffset || $document[0].documentElement.scrollLeft)
        };
      },

      /**
       * Provides coordinates for the targetEl in relation to hostEl
       */
      positionElements: function(hostEl, targetEl, positionStr, appendToBody) {
        var positionStrParts = positionStr.split('-');
        var pos0 = positionStrParts[0], pos1 = positionStrParts[1] || 'center';

        var hostElPos,
          targetElWidth,
          targetElHeight,
          targetElPos;

        hostElPos = appendToBody ? this.offset(hostEl) : this.position(hostEl);

        targetElWidth = targetEl.prop('offsetWidth');
        targetElHeight = targetEl.prop('offsetHeight');

        var shiftWidth = {
          center: function() {
            return hostElPos.left + hostElPos.width / 2 - targetElWidth / 2;
          },
          left: function() {
            return hostElPos.left;
          },
          right: function() {
            return hostElPos.left + hostElPos.width;
          }
        };

        var shiftHeight = {
          center: function() {
            return hostElPos.top + hostElPos.height / 2 - targetElHeight / 2;
          },
          top: function() {
            return hostElPos.top;
          },
          bottom: function() {
            return hostElPos.top + hostElPos.height;
          }
        };

        switch (pos0) {
          case 'right':
            targetElPos = {
              top: shiftHeight[pos1](),
              left: shiftWidth[pos0]()
            };
            break;
          case 'left':
            targetElPos = {
              top: shiftHeight[pos1](),
              left: hostElPos.left - targetElWidth
            };
            break;
          case 'bottom':
            targetElPos = {
              top: shiftHeight[pos0](),
              left: shiftWidth[pos1]()
            };
            break;
          default:
            targetElPos = {
              top: hostElPos.top - targetElHeight,
              left: shiftWidth[pos1]()
            };
            break;
        }

        return targetElPos;
      }
    };
  }]);

angular.module('ui.bootstrap.datepicker', ['ui.bootstrap.dateparser', 'ui.bootstrap.position'])

.value('$datepickerSuppressError', false)

.constant('datepickerConfig', {
  formatDay: 'dd',
  formatMonth: 'MMMM',
  formatYear: 'yyyy',
  formatDayHeader: 'EEE',
  formatDayTitle: 'MMMM yyyy',
  formatMonthTitle: 'yyyy',
  datepickerMode: 'day',
  minMode: 'day',
  maxMode: 'year',
  showWeeks: true,
  startingDay: 0,
  yearRange: 20,
  minDate: null,
  maxDate: null,
  shortcutPropagation: false
})

.controller('DatepickerController', ['$scope', '$attrs', '$parse', '$interpolate', '$log', 'dateFilter', 'datepickerConfig', '$datepickerSuppressError', function($scope, $attrs, $parse, $interpolate, $log, dateFilter, datepickerConfig, $datepickerSuppressError) {
  var self = this,
      ngModelCtrl = { $setViewValue: angular.noop }; // nullModelCtrl;

  // Modes chain
  this.modes = ['day', 'month', 'year'];

  // Configuration attributes
  angular.forEach(['formatDay', 'formatMonth', 'formatYear', 'formatDayHeader', 'formatDayTitle', 'formatMonthTitle',
                   'showWeeks', 'startingDay', 'yearRange', 'shortcutPropagation'], function(key, index) {
    self[key] = angular.isDefined($attrs[key]) ? (index < 6 ? $interpolate($attrs[key])($scope.$parent) : $scope.$parent.$eval($attrs[key])) : datepickerConfig[key];
  });

  // Watchable date attributes
  angular.forEach(['minDate', 'maxDate'], function(key) {
    if ($attrs[key]) {
      $scope.$parent.$watch($parse($attrs[key]), function(value) {
        self[key] = value ? new Date(value) : null;
        self.refreshView();
      });
    } else {
      self[key] = datepickerConfig[key] ? new Date(datepickerConfig[key]) : null;
    }
  });

  angular.forEach(['minMode', 'maxMode'], function(key) {
    if ($attrs[key]) {
      $scope.$parent.$watch($parse($attrs[key]), function(value) {
        self[key] = angular.isDefined(value) ? value : $attrs[key];
        $scope[key] = self[key];
        if ((key == 'minMode' && self.modes.indexOf($scope.datepickerMode) < self.modes.indexOf(self[key])) || (key == 'maxMode' && self.modes.indexOf($scope.datepickerMode) > self.modes.indexOf(self[key]))) {
          $scope.datepickerMode = self[key];
        }
      });
    } else {
      self[key] = datepickerConfig[key] || null;
      $scope[key] = self[key];
    }
  });

  $scope.datepickerMode = $scope.datepickerMode || datepickerConfig.datepickerMode;
  $scope.uniqueId = 'datepicker-' + $scope.$id + '-' + Math.floor(Math.random() * 10000);

  if (angular.isDefined($attrs.initDate)) {
    this.activeDate = $scope.$parent.$eval($attrs.initDate) || new Date();
    $scope.$parent.$watch($attrs.initDate, function(initDate) {
      if (initDate && (ngModelCtrl.$isEmpty(ngModelCtrl.$modelValue) || ngModelCtrl.$invalid)) {
        self.activeDate = initDate;
        self.refreshView();
      }
    });
  } else {
    this.activeDate = new Date();
  }

  $scope.isActive = function(dateObject) {
    if (self.compare(dateObject.date, self.activeDate) === 0) {
      $scope.activeDateId = dateObject.uid;
      return true;
    }
    return false;
  };

  this.init = function(ngModelCtrl_) {
    ngModelCtrl = ngModelCtrl_;

    ngModelCtrl.$render = function() {
      self.render();
    };
  };

  this.render = function() {
    if (ngModelCtrl.$viewValue) {
      var date = new Date(ngModelCtrl.$viewValue),
          isValid = !isNaN(date);

      if (isValid) {
        this.activeDate = date;
      } else if (!$datepickerSuppressError) {
        $log.error('Datepicker directive: "ng-model" value must be a Date object, a number of milliseconds since 01.01.1970 or a string representing an RFC2822 or ISO 8601 date.');
      }
    }
    this.refreshView();
  };

  this.refreshView = function() {
    if (this.element) {
      this._refreshView();

      var date = ngModelCtrl.$viewValue ? new Date(ngModelCtrl.$viewValue) : null;
      ngModelCtrl.$setValidity('dateDisabled', !date || (this.element && !this.isDisabled(date)));
    }
  };

  this.createDateObject = function(date, format) {
    var model = ngModelCtrl.$viewValue ? new Date(ngModelCtrl.$viewValue) : null;
    return {
      date: date,
      label: dateFilter(date, format),
      selected: model && this.compare(date, model) === 0,
      disabled: this.isDisabled(date),
      current: this.compare(date, new Date()) === 0,
      customClass: this.customClass(date)
    };
  };

  this.isDisabled = function(date) {
    return ((this.minDate && this.compare(date, this.minDate) < 0) || (this.maxDate && this.compare(date, this.maxDate) > 0) || ($attrs.dateDisabled && $scope.dateDisabled({date: date, mode: $scope.datepickerMode})));
  };

  this.customClass = function(date) {
    return $scope.customClass({date: date, mode: $scope.datepickerMode});
  };

  // Split array into smaller arrays
  this.split = function(arr, size) {
    var arrays = [];
    while (arr.length > 0) {
      arrays.push(arr.splice(0, size));
    }
    return arrays;
  };

  // Fix a hard-reprodusible bug with timezones
  // The bug depends on OS, browser, current timezone and current date
  // i.e.
  // var date = new Date(2014, 0, 1);
  // console.log(date.getFullYear(), date.getMonth(), date.getDate(), date.getHours());
  // can result in "2013 11 31 23" because of the bug.
  this.fixTimeZone = function(date) {
    var hours = date.getHours();
    date.setHours(hours === 23 ? hours + 2 : 0);
  };

  $scope.select = function(date) {
    if ($scope.datepickerMode === self.minMode) {
      var dt = ngModelCtrl.$viewValue ? new Date(ngModelCtrl.$viewValue) : new Date(0, 0, 0, 0, 0, 0, 0);
      dt.setFullYear(date.getFullYear(), date.getMonth(), date.getDate());
      ngModelCtrl.$setViewValue(dt);
      ngModelCtrl.$render();
    } else {
      self.activeDate = date;
      $scope.datepickerMode = self.modes[self.modes.indexOf($scope.datepickerMode) - 1];
    }
  };

  $scope.move = function(direction) {
    var year = self.activeDate.getFullYear() + direction * (self.step.years || 0),
        month = self.activeDate.getMonth() + direction * (self.step.months || 0);
    self.activeDate.setFullYear(year, month, 1);
    self.refreshView();
  };

  $scope.toggleMode = function(direction) {
    direction = direction || 1;

    if (($scope.datepickerMode === self.maxMode && direction === 1) || ($scope.datepickerMode === self.minMode && direction === -1)) {
      return;
    }

    $scope.datepickerMode = self.modes[self.modes.indexOf($scope.datepickerMode) + direction];
  };

  // Key event mapper
  $scope.keys = { 13: 'enter', 32: 'space', 33: 'pageup', 34: 'pagedown', 35: 'end', 36: 'home', 37: 'left', 38: 'up', 39: 'right', 40: 'down' };

  var focusElement = function() {
    self.element[0].focus();
  };

  // Listen for focus requests from popup directive
  $scope.$on('datepicker.focus', focusElement);

  $scope.keydown = function(evt) {
    var key = $scope.keys[evt.which];

    if (!key || evt.shiftKey || evt.altKey) {
      return;
    }

    evt.preventDefault();
    if (!self.shortcutPropagation) {
      evt.stopPropagation();
    }

    if (key === 'enter' || key === 'space') {
      if (self.isDisabled(self.activeDate)) {
        return; // do nothing
      }
      $scope.select(self.activeDate);
      focusElement();
    } else if (evt.ctrlKey && (key === 'up' || key === 'down')) {
      $scope.toggleMode(key === 'up' ? 1 : -1);
      focusElement();
    } else {
      self.handleKeyDown(key, evt);
      self.refreshView();
    }
  };
}])

.directive('datepicker', function() {
  return {
    restrict: 'EA',
    replace: true,
    templateUrl: function(element, attrs) {
      return attrs.templateUrl || 'template/datepicker/datepicker.html';
    },
    scope: {
      datepickerMode: '=?',
      dateDisabled: '&',
      customClass: '&',
      shortcutPropagation: '&?'
    },
    require: ['datepicker', '^ngModel'],
    controller: 'DatepickerController',
    controllerAs: 'datepicker',
    link: function(scope, element, attrs, ctrls) {
      var datepickerCtrl = ctrls[0], ngModelCtrl = ctrls[1];

      datepickerCtrl.init(ngModelCtrl);
    }
  };
})

.directive('daypicker', ['dateFilter', function(dateFilter) {
  return {
    restrict: 'EA',
    replace: true,
    templateUrl: 'template/datepicker/day.html',
    require: '^datepicker',
    link: function(scope, element, attrs, ctrl) {
      scope.showWeeks = ctrl.showWeeks;

      ctrl.step = { months: 1 };
      ctrl.element = element;

      var DAYS_IN_MONTH = [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31];
      function getDaysInMonth(year, month) {
        return ((month === 1) && (year % 4 === 0) && ((year % 100 !== 0) || (year % 400 === 0))) ? 29 : DAYS_IN_MONTH[month];
      }

      function getDates(startDate, n) {
        var dates = new Array(n), current = new Date(startDate), i = 0, date;
        while (i < n) {
          date = new Date(current);
          ctrl.fixTimeZone(date);
          dates[i++] = date;
          current.setDate(current.getDate() + 1);
        }
        return dates;
      }

      ctrl._refreshView = function() {
        var year = ctrl.activeDate.getFullYear(),
          month = ctrl.activeDate.getMonth(),
          firstDayOfMonth = new Date(year, month, 1),
          difference = ctrl.startingDay - firstDayOfMonth.getDay(),
          numDisplayedFromPreviousMonth = (difference > 0) ? 7 - difference : - difference,
          firstDate = new Date(firstDayOfMonth);

        if (numDisplayedFromPreviousMonth > 0) {
          firstDate.setDate(-numDisplayedFromPreviousMonth + 1);
        }

        // 42 is the number of days on a six-month calendar
        var days = getDates(firstDate, 42);
        for (var i = 0; i < 42; i ++) {
          days[i] = angular.extend(ctrl.createDateObject(days[i], ctrl.formatDay), {
            secondary: days[i].getMonth() !== month,
            uid: scope.uniqueId + '-' + i
          });
        }

        scope.labels = new Array(7);
        for (var j = 0; j < 7; j++) {
          scope.labels[j] = {
            abbr: dateFilter(days[j].date, ctrl.formatDayHeader),
            full: dateFilter(days[j].date, 'EEEE')
          };
        }

        scope.title = dateFilter(ctrl.activeDate, ctrl.formatDayTitle);
        scope.rows = ctrl.split(days, 7);

        if (scope.showWeeks) {
          scope.weekNumbers = [];
          var thursdayIndex = (4 + 7 - ctrl.startingDay) % 7,
              numWeeks = scope.rows.length;
          for (var curWeek = 0; curWeek < numWeeks; curWeek++) {
            scope.weekNumbers.push(
              getISO8601WeekNumber(scope.rows[curWeek][thursdayIndex].date));
          }
        }
      };

      ctrl.compare = function(date1, date2) {
        return (new Date(date1.getFullYear(), date1.getMonth(), date1.getDate()) - new Date(date2.getFullYear(), date2.getMonth(), date2.getDate()));
      };

      function getISO8601WeekNumber(date) {
        var checkDate = new Date(date);
        checkDate.setDate(checkDate.getDate() + 4 - (checkDate.getDay() || 7)); // Thursday
        var time = checkDate.getTime();
        checkDate.setMonth(0); // Compare with Jan 1
        checkDate.setDate(1);
        return Math.floor(Math.round((time - checkDate) / 86400000) / 7) + 1;
      }

      ctrl.handleKeyDown = function(key, evt) {
        var date = ctrl.activeDate.getDate();

        if (key === 'left') {
          date = date - 1;   // up
        } else if (key === 'up') {
          date = date - 7;   // down
        } else if (key === 'right') {
          date = date + 1;   // down
        } else if (key === 'down') {
          date = date + 7;
        } else if (key === 'pageup' || key === 'pagedown') {
          var month = ctrl.activeDate.getMonth() + (key === 'pageup' ? - 1 : 1);
          ctrl.activeDate.setMonth(month, 1);
          date = Math.min(getDaysInMonth(ctrl.activeDate.getFullYear(), ctrl.activeDate.getMonth()), date);
        } else if (key === 'home') {
          date = 1;
        } else if (key === 'end') {
          date = getDaysInMonth(ctrl.activeDate.getFullYear(), ctrl.activeDate.getMonth());
        }
        ctrl.activeDate.setDate(date);
      };

      ctrl.refreshView();
    }
  };
}])

.directive('monthpicker', ['dateFilter', function(dateFilter) {
  return {
    restrict: 'EA',
    replace: true,
    templateUrl: 'template/datepicker/month.html',
    require: '^datepicker',
    link: function(scope, element, attrs, ctrl) {
      ctrl.step = { years: 1 };
      ctrl.element = element;

      ctrl._refreshView = function() {
        var months = new Array(12),
            year = ctrl.activeDate.getFullYear(),
            date;

        for (var i = 0; i < 12; i++) {
          date = new Date(year, i, 1);
          ctrl.fixTimeZone(date);
          months[i] = angular.extend(ctrl.createDateObject(date, ctrl.formatMonth), {
            uid: scope.uniqueId + '-' + i
          });
        }

        scope.title = dateFilter(ctrl.activeDate, ctrl.formatMonthTitle);
        scope.rows = ctrl.split(months, 3);
      };

      ctrl.compare = function(date1, date2) {
        return new Date(date1.getFullYear(), date1.getMonth()) - new Date(date2.getFullYear(), date2.getMonth());
      };

      ctrl.handleKeyDown = function(key, evt) {
        var date = ctrl.activeDate.getMonth();

        if (key === 'left') {
          date = date - 1;   // up
        } else if (key === 'up') {
          date = date - 3;   // down
        } else if (key === 'right') {
          date = date + 1;   // down
        } else if (key === 'down') {
          date = date + 3;
        } else if (key === 'pageup' || key === 'pagedown') {
          var year = ctrl.activeDate.getFullYear() + (key === 'pageup' ? - 1 : 1);
          ctrl.activeDate.setFullYear(year);
        } else if (key === 'home') {
          date = 0;
        } else if (key === 'end') {
          date = 11;
        }
        ctrl.activeDate.setMonth(date);
      };

      ctrl.refreshView();
    }
  };
}])

.directive('yearpicker', ['dateFilter', function(dateFilter) {
  return {
    restrict: 'EA',
    replace: true,
    templateUrl: 'template/datepicker/year.html',
    require: '^datepicker',
    link: function(scope, element, attrs, ctrl) {
      var range = ctrl.yearRange;

      ctrl.step = { years: range };
      ctrl.element = element;

      function getStartingYear( year ) {
        return parseInt((year - 1) / range, 10) * range + 1;
      }

      ctrl._refreshView = function() {
        var years = new Array(range), date;

        for (var i = 0, start = getStartingYear(ctrl.activeDate.getFullYear()); i < range; i++) {
          date = new Date(start + i, 0, 1);
          ctrl.fixTimeZone(date);
          years[i] = angular.extend(ctrl.createDateObject(date, ctrl.formatYear), {
            uid: scope.uniqueId + '-' + i
          });
        }

        scope.title = [years[0].label, years[range - 1].label].join(' - ');
        scope.rows = ctrl.split(years, 5);
      };

      ctrl.compare = function(date1, date2) {
        return date1.getFullYear() - date2.getFullYear();
      };

      ctrl.handleKeyDown = function(key, evt) {
        var date = ctrl.activeDate.getFullYear();

        if (key === 'left') {
          date = date - 1;   // up
        } else if (key === 'up') {
          date = date - 5;   // down
        } else if (key === 'right') {
          date = date + 1;   // down
        } else if (key === 'down') {
          date = date + 5;
        } else if (key === 'pageup' || key === 'pagedown') {
          date += (key === 'pageup' ? - 1 : 1) * ctrl.step.years;
        } else if (key === 'home') {
          date = getStartingYear(ctrl.activeDate.getFullYear());
        } else if (key === 'end') {
          date = getStartingYear(ctrl.activeDate.getFullYear()) + range - 1;
        }
        ctrl.activeDate.setFullYear(date);
      };

      ctrl.refreshView();
    }
  };
}])

.constant('datepickerPopupConfig', {
  datepickerPopup: 'yyyy-MM-dd',
  datepickerPopupTemplateUrl: 'template/datepicker/popup.html',
  datepickerTemplateUrl: 'template/datepicker/datepicker.html',
  html5Types: {
    date: 'yyyy-MM-dd',
    'datetime-local': 'yyyy-MM-ddTHH:mm:ss.sss',
    'month': 'yyyy-MM'
  },
  currentText: 'Today',
  clearText: 'Clear',
  closeText: 'Done',
  closeOnDateSelection: true,
  appendToBody: false,
  showButtonBar: true,
  onOpenFocus: true
})

.directive('datepickerPopup', ['$compile', '$parse', '$document', '$rootScope', '$position', 'dateFilter', 'dateParser', 'datepickerPopupConfig', '$timeout',
function($compile, $parse, $document, $rootScope, $position, dateFilter, dateParser, datepickerPopupConfig, $timeout) {
  return {
    restrict: 'EA',
    require: 'ngModel',
    scope: {
      isOpen: '=?',
      currentText: '@',
      clearText: '@',
      closeText: '@',
      dateDisabled: '&',
      customClass: '&'
    },
    link: function(scope, element, attrs, ngModel) {
      var dateFormat,
          closeOnDateSelection = angular.isDefined(attrs.closeOnDateSelection) ? scope.$parent.$eval(attrs.closeOnDateSelection) : datepickerPopupConfig.closeOnDateSelection,
          appendToBody = angular.isDefined(attrs.datepickerAppendToBody) ? scope.$parent.$eval(attrs.datepickerAppendToBody) : datepickerPopupConfig.appendToBody,
          onOpenFocus = angular.isDefined(attrs.onOpenFocus) ? scope.$parent.$eval(attrs.onOpenFocus) : datepickerPopupConfig.onOpenFocus,
          datepickerPopupTemplateUrl = angular.isDefined(attrs.datepickerPopupTemplateUrl) ? attrs.datepickerPopupTemplateUrl : datepickerPopupConfig.datepickerPopupTemplateUrl,
          datepickerTemplateUrl = angular.isDefined(attrs.datepickerTemplateUrl) ? attrs.datepickerTemplateUrl : datepickerPopupConfig.datepickerTemplateUrl,
          cache = {};

      scope.showButtonBar = angular.isDefined(attrs.showButtonBar) ? scope.$parent.$eval(attrs.showButtonBar) : datepickerPopupConfig.showButtonBar;

      scope.getText = function(key) {
        return scope[key + 'Text'] || datepickerPopupConfig[key + 'Text'];
      };

      scope.isDisabled = function(date) {
        if (date === 'today') {
          date = new Date();
        }

        return ((scope.watchData.minDate && scope.compare(date, cache.minDate) < 0) ||
          (scope.watchData.maxDate && scope.compare(date, cache.maxDate) > 0));
      };

      scope.compare = function(date1, date2) {
        return (new Date(date1.getFullYear(), date1.getMonth(), date1.getDate()) - new Date(date2.getFullYear(), date2.getMonth(), date2.getDate()));
      };

      var isHtml5DateInput = false;
      if (datepickerPopupConfig.html5Types[attrs.type]) {
        dateFormat = datepickerPopupConfig.html5Types[attrs.type];
        isHtml5DateInput = true;
      } else {
        dateFormat = attrs.datepickerPopup || datepickerPopupConfig.datepickerPopup;
        attrs.$observe('datepickerPopup', function(value, oldValue) {
            var newDateFormat = value || datepickerPopupConfig.datepickerPopup;
            // Invalidate the $modelValue to ensure that formatters re-run
            // FIXME: Refactor when PR is merged: https://github.com/angular/angular.js/pull/10764
            if (newDateFormat !== dateFormat) {
              dateFormat = newDateFormat;
              ngModel.$modelValue = null;

              if (!dateFormat) {
                throw new Error('datepickerPopup must have a date format specified.');
              }
            }
        });
      }

      if (!dateFormat) {
        throw new Error('datepickerPopup must have a date format specified.');
      }

      if (isHtml5DateInput && attrs.datepickerPopup) {
        throw new Error('HTML5 date input types do not support custom formats.');
      }

      // popup element used to display calendar
      var popupEl = angular.element('<div datepicker-popup-wrap><div datepicker></div></div>');
      popupEl.attr({
        'ng-model': 'date',
        'ng-change': 'dateSelection(date)',
        'template-url': datepickerPopupTemplateUrl
      });

      function cameltoDash(string) {
        return string.replace(/([A-Z])/g, function($1) { return '-' + $1.toLowerCase(); });
      }

      // datepicker element
      var datepickerEl = angular.element(popupEl.children()[0]);
      datepickerEl.attr('template-url', datepickerTemplateUrl);

      if (isHtml5DateInput) {
        if (attrs.type === 'month') {
          datepickerEl.attr('datepicker-mode', '"month"');
          datepickerEl.attr('min-mode', 'month');
        }
      }

      if (attrs.datepickerOptions) {
        var options = scope.$parent.$eval(attrs.datepickerOptions);
        if (options && options.initDate) {
          scope.initDate = options.initDate;
          datepickerEl.attr('init-date', 'initDate');
          delete options.initDate;
        }
        angular.forEach(options, function(value, option) {
          datepickerEl.attr( cameltoDash(option), value );
        });
      }

      scope.watchData = {};
      angular.forEach(['minMode', 'maxMode', 'minDate', 'maxDate', 'datepickerMode', 'initDate', 'shortcutPropagation'], function(key) {
        if (attrs[key]) {
          var getAttribute = $parse(attrs[key]);
          scope.$parent.$watch(getAttribute, function(value) {
            scope.watchData[key] = value;
            if (key === 'minDate' || key === 'maxDate') {
              cache[key] = new Date(value);
            }
          });
          datepickerEl.attr(cameltoDash(key), 'watchData.' + key);

          // Propagate changes from datepicker to outside
          if (key === 'datepickerMode') {
            var setAttribute = getAttribute.assign;
            scope.$watch('watchData.' + key, function(value, oldvalue) {
              if (angular.isFunction(setAttribute) && value !== oldvalue) {
                setAttribute(scope.$parent, value);
              }
            });
          }
        }
      });
      if (attrs.dateDisabled) {
        datepickerEl.attr('date-disabled', 'dateDisabled({ date: date, mode: mode })');
      }

      if (attrs.showWeeks) {
        datepickerEl.attr('show-weeks', attrs.showWeeks);
      }

      if (attrs.customClass) {
        datepickerEl.attr('custom-class', 'customClass({ date: date, mode: mode })');
      }

      function parseDate(viewValue) {
        if (angular.isNumber(viewValue)) {
          // presumably timestamp to date object
          viewValue = new Date(viewValue);
        }

        if (!viewValue) {
          return null;
        } else if (angular.isDate(viewValue) && !isNaN(viewValue)) {
          return viewValue;
        } else if (angular.isString(viewValue)) {
          var date = dateParser.parse(viewValue, dateFormat, scope.date);
          if (isNaN(date)) {
            return undefined;
          } else {
            return date;
          }
        } else {
          return undefined;
        }
      }

      function validator(modelValue, viewValue) {
        var value = modelValue || viewValue;

        if (!attrs.ngRequired && !value) {
          return true;
        }

        if (angular.isNumber(value)) {
          value = new Date(value);
        }
        if (!value) {
          return true;
        } else if (angular.isDate(value) && !isNaN(value)) {
          return true;
        } else if (angular.isString(value)) {
          var date = dateParser.parse(value, dateFormat);
          return !isNaN(date);
        } else {
          return false;
        }
      }

      if (!isHtml5DateInput) {
        // Internal API to maintain the correct ng-invalid-[key] class
        ngModel.$$parserName = 'date';
        ngModel.$validators.date = validator;
        ngModel.$parsers.unshift(parseDate);
        ngModel.$formatters.push(function(value) {
          scope.date = value;
          return ngModel.$isEmpty(value) ? value : dateFilter(value, dateFormat);
        });
      } else {
        ngModel.$formatters.push(function(value) {
          scope.date = value;
          return value;
        });
      }

      // Inner change
      scope.dateSelection = function(dt) {
        if (angular.isDefined(dt)) {
          scope.date = dt;
        }
        var date = scope.date ? dateFilter(scope.date, dateFormat) : null; // Setting to NULL is necessary for form validators to function
        element.val(date);
        ngModel.$setViewValue(date);

        if (closeOnDateSelection) {
          scope.isOpen = false;
          element[0].focus();
        }
      };

      // Detect changes in the view from the text box
      ngModel.$viewChangeListeners.push(function() {
        scope.date = dateParser.parse(ngModel.$viewValue, dateFormat, scope.date);
      });

      var documentClickBind = function(event) {
        if (scope.isOpen && !(element[0].contains(event.target) || popupEl[0].contains(event.target))) {
          scope.$apply(function() {
            scope.isOpen = false;
          });
        }
      };

      var inputKeydownBind = function(evt) {
        if (evt.which === 27 && scope.isOpen) {
          evt.preventDefault();
          evt.stopPropagation();
          scope.$apply(function() {
            scope.isOpen = false;
          });
          element[0].focus();
        } else if (evt.which === 40 && !scope.isOpen) {
          evt.preventDefault();
          evt.stopPropagation();
          scope.$apply(function() {
            scope.isOpen = true;
          });
        }
      };
      element.bind('keydown', inputKeydownBind);

      scope.keydown = function(evt) {
        if (evt.which === 27) {
          scope.isOpen = false;
          element[0].focus();
        }
      };

      scope.$watch('isOpen', function(value) {
        if (value) {
          scope.position = appendToBody ? $position.offset(element) : $position.position(element);
          scope.position.top = scope.position.top + element.prop('offsetHeight');

          $timeout(function() {
            if (onOpenFocus) {
              scope.$broadcast('datepicker.focus');
            }
            $document.bind('click', documentClickBind);
          }, 0, false);
        } else {
          $document.unbind('click', documentClickBind);
        }
      });

      scope.select = function(date) {
        if (date === 'today') {
          var today = new Date();
          if (angular.isDate(scope.date)) {
            date = new Date(scope.date);
            date.setFullYear(today.getFullYear(), today.getMonth(), today.getDate());
          } else {
            date = new Date(today.setHours(0, 0, 0, 0));
          }
        }
        scope.dateSelection(date);
      };

      scope.close = function() {
        scope.isOpen = false;
        element[0].focus();
      };

      var $popup = $compile(popupEl)(scope);
      // Prevent jQuery cache memory leak (template is now redundant after linking)
      popupEl.remove();

      if (appendToBody) {
        $document.find('body').append($popup);
      } else {
        element.after($popup);
      }

      scope.$on('$destroy', function() {
        if (scope.isOpen === true) {
          if (!$rootScope.$$phase) {
            scope.$apply(function() {
              scope.isOpen = false;
            });
          }
        }

        $popup.remove();
        element.unbind('keydown', inputKeydownBind);
        $document.unbind('click', documentClickBind);
      });
    }
  };
}])

.directive('datepickerPopupWrap', function() {
  return {
    restrict:'EA',
    replace: true,
    transclude: true,
    templateUrl: function(element, attrs) {
      return attrs.templateUrl || 'template/datepicker/popup.html';
    }
  };
});

angular.module('ui.bootstrap.dropdown', ['ui.bootstrap.position'])

.constant('dropdownConfig', {
  openClass: 'open'
})

.service('dropdownService', ['$document', '$rootScope', function($document, $rootScope) {
  var openScope = null;

  this.open = function(dropdownScope) {
    if (!openScope) {
      $document.bind('click', closeDropdown);
      $document.bind('keydown', keybindFilter);
    }

    if (openScope && openScope !== dropdownScope) {
      openScope.isOpen = false;
    }

    openScope = dropdownScope;
  };

  this.close = function(dropdownScope) {
    if (openScope === dropdownScope) {
      openScope = null;
      $document.unbind('click', closeDropdown);
      $document.unbind('keydown', keybindFilter);
    }
  };

  var closeDropdown = function(evt) {
    // This method may still be called during the same mouse event that
    // unbound this event handler. So check openScope before proceeding.
    if (!openScope) { return; }

    if (evt && openScope.getAutoClose() === 'disabled')  { return ; }

    var toggleElement = openScope.getToggleElement();
    if (evt && toggleElement && toggleElement[0].contains(evt.target)) {
      return;
    }

    var dropdownElement = openScope.getDropdownElement();
    if (evt && openScope.getAutoClose() === 'outsideClick' &&
      dropdownElement && dropdownElement[0].contains(evt.target)) {
      return;
    }

    openScope.isOpen = false;

    if (!$rootScope.$$phase) {
      openScope.$apply();
    }
  };

  var keybindFilter = function(evt) {
    if (evt.which === 27) {
      openScope.focusToggleElement();
      closeDropdown();
    } else if (openScope.isKeynavEnabled() && /(38|40)/.test(evt.which) && openScope.isOpen) {
      evt.preventDefault();
      evt.stopPropagation();
      openScope.focusDropdownEntry(evt.which);
    }
  };
}])

.controller('DropdownController', ['$scope', '$attrs', '$parse', 'dropdownConfig', 'dropdownService', '$animate', '$position', '$document', '$compile', '$templateRequest', function($scope, $attrs, $parse, dropdownConfig, dropdownService, $animate, $position, $document, $compile, $templateRequest) {
  var self = this,
    scope = $scope.$new(), // create a child scope so we are not polluting original one
    templateScope,
    openClass = dropdownConfig.openClass,
    getIsOpen,
    setIsOpen = angular.noop,
    toggleInvoker = $attrs.onToggle ? $parse($attrs.onToggle) : angular.noop,
    appendToBody = false,
    keynavEnabled = false,
    selectedOption = null,
    body = $document.find('body');

  this.init = function(element) {
    self.$element = element;

    if ($attrs.isOpen) {
      getIsOpen = $parse($attrs.isOpen);
      setIsOpen = getIsOpen.assign;

      $scope.$watch(getIsOpen, function(value) {
        scope.isOpen = !!value;
      });
    }

    appendToBody = angular.isDefined($attrs.dropdownAppendToBody);
    keynavEnabled = angular.isDefined($attrs.keyboardNav);

    if (appendToBody && self.dropdownMenu) {
      body.append(self.dropdownMenu);
      body.addClass('dropdown');
      element.on('$destroy', function handleDestroyEvent() {
        self.dropdownMenu.remove();
      });
    }
  };

  this.toggle = function(open) {
    return scope.isOpen = arguments.length ? !!open : !scope.isOpen;
  };

  // Allow other directives to watch status
  this.isOpen = function() {
    return scope.isOpen;
  };

  scope.getToggleElement = function() {
    return self.toggleElement;
  };

  scope.getAutoClose = function() {
    return $attrs.autoClose || 'always'; //or 'outsideClick' or 'disabled'
  };

  scope.getElement = function() {
    return self.$element;
  };

  scope.isKeynavEnabled = function() {
    return keynavEnabled;
  };

  scope.focusDropdownEntry = function(keyCode) {
    var elems = self.dropdownMenu ? //If append to body is used.
      (angular.element(self.dropdownMenu).find('a')) :
      (angular.element(self.$element).find('ul').eq(0).find('a'));

    switch (keyCode) {
      case (40): {
        if (!angular.isNumber(self.selectedOption)) {
          self.selectedOption = 0;
        } else {
          self.selectedOption = (self.selectedOption === elems.length -1 ?
            self.selectedOption :
            self.selectedOption + 1);
        }
        break;
      }
      case (38): {
        if (!angular.isNumber(self.selectedOption)) {
          self.selectedOption = elems.length - 1;
        } else {
          self.selectedOption = self.selectedOption === 0 ?
            0 : self.selectedOption - 1;
        }
        break;
      }
    }
    elems[self.selectedOption].focus();
  };

  scope.getDropdownElement = function() {
    return self.dropdownMenu;
  };

  scope.focusToggleElement = function() {
    if (self.toggleElement) {
      self.toggleElement[0].focus();
    }
  };

  scope.$watch('isOpen', function(isOpen, wasOpen) {
    if (appendToBody && self.dropdownMenu) {
      var pos = $position.positionElements(self.$element, self.dropdownMenu, 'bottom-left', true);
      var css = {
        top: pos.top + 'px',
        display: isOpen ? 'block' : 'none'
      };

      var rightalign = self.dropdownMenu.hasClass('dropdown-menu-right');
      if (!rightalign) {
        css.left = pos.left + 'px';
        css.right = 'auto';
      } else {
        css.left = 'auto';
        css.right = (window.innerWidth - (pos.left + self.$element.prop('offsetWidth'))) + 'px';
      }

      self.dropdownMenu.css(css);
    }

    var openContainer = appendToBody ? body : self.$element;

    $animate[isOpen ? 'addClass' : 'removeClass'](openContainer, openClass).then(function() {
      if (angular.isDefined(isOpen) && isOpen !== wasOpen) {
        toggleInvoker($scope, { open: !!isOpen });
      }
    });

    if (isOpen) {
      if (self.dropdownMenuTemplateUrl) {
        $templateRequest(self.dropdownMenuTemplateUrl).then(function(tplContent) {
          templateScope = scope.$new();
          $compile(tplContent.trim())(templateScope, function(dropdownElement) {
            var newEl = dropdownElement;
            self.dropdownMenu.replaceWith(newEl);
            self.dropdownMenu = newEl;
          });
        });
      }

      scope.focusToggleElement();
      dropdownService.open(scope);
    } else {
      if (self.dropdownMenuTemplateUrl) {
        if (templateScope) {
          templateScope.$destroy();
        }
        var newEl = angular.element('<ul class="dropdown-menu"></ul>');
        self.dropdownMenu.replaceWith(newEl);
        self.dropdownMenu = newEl;
      }

      dropdownService.close(scope);
      self.selectedOption = null;
    }

    if (angular.isFunction(setIsOpen)) {
      setIsOpen($scope, isOpen);
    }
  });

  $scope.$on('$locationChangeSuccess', function() {
    if (scope.getAutoClose() !== 'disabled') {
      scope.isOpen = false;
    }
  });

  var offDestroy = $scope.$on('$destroy', function() {
    scope.$destroy();
  });
  scope.$on('$destroy', offDestroy);
}])

.directive('dropdown', function() {
  return {
    controller: 'DropdownController',
    link: function(scope, element, attrs, dropdownCtrl) {
      dropdownCtrl.init( element );
      element.addClass('dropdown');
    }
  };
})

.directive('dropdownMenu', function() {
  return {
    restrict: 'AC',
    require: '?^dropdown',
    link: function(scope, element, attrs, dropdownCtrl) {
      if (!dropdownCtrl) {
        return;
      }
      var tplUrl = attrs.templateUrl;
      if (tplUrl) {
        dropdownCtrl.dropdownMenuTemplateUrl = tplUrl;
      }
      if (!dropdownCtrl.dropdownMenu) {
        dropdownCtrl.dropdownMenu = element;
      }
    }
  };
})

.directive('keyboardNav', function() {
  return {
    restrict: 'A',
    require: '?^dropdown',
    link: function (scope, element, attrs, dropdownCtrl) {

      element.bind('keydown', function(e) {
        if ([38, 40].indexOf(e.which) !== -1) {
          e.preventDefault();
          e.stopPropagation();

          var elems = dropdownCtrl.dropdownMenu.find('a');

          switch (e.which) {
            case (40): { // Down
              if (!angular.isNumber(dropdownCtrl.selectedOption)) {
                dropdownCtrl.selectedOption = 0;
              } else {
                dropdownCtrl.selectedOption = dropdownCtrl.selectedOption === elems.length -1 ?
                  dropdownCtrl.selectedOption : dropdownCtrl.selectedOption + 1;
              }
              break;
            }
            case (38): { // Up
              if (!angular.isNumber(dropdownCtrl.selectedOption)) {
                dropdownCtrl.selectedOption = elems.length - 1;
              } else {
                dropdownCtrl.selectedOption = dropdownCtrl.selectedOption === 0 ?
                  0 : dropdownCtrl.selectedOption - 1;
              }
              break;
            }
          }
          elems[dropdownCtrl.selectedOption].focus();
        }
      });
    }
  };
})

.directive('dropdownToggle', function() {
  return {
    require: '?^dropdown',
    link: function(scope, element, attrs, dropdownCtrl) {
      if (!dropdownCtrl) {
        return;
      }

      element.addClass('dropdown-toggle');

      dropdownCtrl.toggleElement = element;

      var toggleDropdown = function(event) {
        event.preventDefault();

        if (!element.hasClass('disabled') && !attrs.disabled) {
          scope.$apply(function() {
            dropdownCtrl.toggle();
          });
        }
      };

      element.bind('click', toggleDropdown);

      // WAI-ARIA
      element.attr({ 'aria-haspopup': true, 'aria-expanded': false });
      scope.$watch(dropdownCtrl.isOpen, function( isOpen ) {
        element.attr('aria-expanded', !!isOpen);
      });

      scope.$on('$destroy', function() {
        element.unbind('click', toggleDropdown);
      });
    }
  };
});

angular.module('ui.bootstrap.modal', [])

/**
 * A helper, internal data structure that acts as a map but also allows getting / removing
 * elements in the LIFO order
 */
  .factory('$$stackedMap', function() {
    return {
      createNew: function() {
        var stack = [];

        return {
          add: function(key, value) {
            stack.push({
              key: key,
              value: value
            });
          },
          get: function(key) {
            for (var i = 0; i < stack.length; i++) {
              if (key == stack[i].key) {
                return stack[i];
              }
            }
          },
          keys: function() {
            var keys = [];
            for (var i = 0; i < stack.length; i++) {
              keys.push(stack[i].key);
            }
            return keys;
          },
          top: function() {
            return stack[stack.length - 1];
          },
          remove: function(key) {
            var idx = -1;
            for (var i = 0; i < stack.length; i++) {
              if (key == stack[i].key) {
                idx = i;
                break;
              }
            }
            return stack.splice(idx, 1)[0];
          },
          removeTop: function() {
            return stack.splice(stack.length - 1, 1)[0];
          },
          length: function() {
            return stack.length;
          }
        };
      }
    };
  })

/**
 * A helper, internal data structure that stores all references attached to key
 */
  .factory('$$multiMap', function() {
    return {
      createNew: function() {
        var map = {};

        return {
          entries: function() {
            return Object.keys(map).map(function(key) {
              return {
                key: key,
                value: map[key]
              };
            });
          },
          get: function(key) {
            return map[key];
          },
          hasKey: function(key) {
            return !!map[key];
          },
          keys: function() {
            return Object.keys(map);
          },
          put: function(key, value) {
            if (!map[key]) {
              map[key] = [];
            }

            map[key].push(value);
          },
          remove: function(key, value) {
            var values = map[key];

            if (!values) {
              return;
            }

            var idx = values.indexOf(value);

            if (idx !== -1) {
              values.splice(idx, 1);
            }

            if (!values.length) {
              delete map[key];
            }
          }
        };
      }
    };
  })

/**
 * A helper directive for the $modal service. It creates a backdrop element.
 */
  .directive('modalBackdrop', [
           '$animate', '$injector', '$modalStack',
  function($animate ,  $injector,   $modalStack) {
    var $animateCss = null;

    if ($injector.has('$animateCss')) {
      $animateCss = $injector.get('$animateCss');
    }

    return {
      restrict: 'EA',
      replace: true,
      templateUrl: 'template/modal/backdrop.html',
      compile: function(tElement, tAttrs) {
        tElement.addClass(tAttrs.backdropClass);
        return linkFn;
      }
    };

    function linkFn(scope, element, attrs) {
      if (attrs.modalInClass) {
        if ($animateCss) {
          $animateCss(element, {
            addClass: attrs.modalInClass
          }).start();
        } else {
          $animate.addClass(element, attrs.modalInClass);
        }

        scope.$on($modalStack.NOW_CLOSING_EVENT, function(e, setIsAsync) {
          var done = setIsAsync();
          if ($animateCss) {
            $animateCss(element, {
              removeClass: attrs.modalInClass
            }).start().then(done);
          } else {
            $animate.removeClass(element, attrs.modalInClass).then(done);
          }
        });
      }
    }
  }])

  .directive('modalWindow', [
           '$modalStack', '$q', '$animate', '$injector',
  function($modalStack ,  $q ,  $animate,   $injector) {
    var $animateCss = null;

    if ($injector.has('$animateCss')) {
      $animateCss = $injector.get('$animateCss');
    }

    return {
      restrict: 'EA',
      scope: {
        index: '@'
      },
      replace: true,
      transclude: true,
      templateUrl: function(tElement, tAttrs) {
        return tAttrs.templateUrl || 'template/modal/window.html';
      },
      link: function(scope, element, attrs) {
        element.addClass(attrs.windowClass || '');
        scope.size = attrs.size;

        scope.close = function(evt) {
          var modal = $modalStack.getTop();
          if (modal && modal.value.backdrop && modal.value.backdrop !== 'static' && (evt.target === evt.currentTarget)) {
            evt.preventDefault();
            evt.stopPropagation();
            $modalStack.dismiss(modal.key, 'backdrop click');
          }
        };

        // This property is only added to the scope for the purpose of detecting when this directive is rendered.
        // We can detect that by using this property in the template associated with this directive and then use
        // {@link Attribute#$observe} on it. For more details please see {@link TableColumnResize}.
        scope.$isRendered = true;

        // Deferred object that will be resolved when this modal is render.
        var modalRenderDeferObj = $q.defer();
        // Observe function will be called on next digest cycle after compilation, ensuring that the DOM is ready.
        // In order to use this way of finding whether DOM is ready, we need to observe a scope property used in modal's template.
        attrs.$observe('modalRender', function(value) {
          if (value == 'true') {
            modalRenderDeferObj.resolve();
          }
        });

        modalRenderDeferObj.promise.then(function() {
          var animationPromise = null;

          if (attrs.modalInClass) {
            if ($animateCss) {
              animationPromise = $animateCss(element, {
                addClass: attrs.modalInClass
              }).start();
            } else {
              animationPromise = $animate.addClass(element, attrs.modalInClass);
            }

            scope.$on($modalStack.NOW_CLOSING_EVENT, function(e, setIsAsync) {
              var done = setIsAsync();
              if ($animateCss) {
                $animateCss(element, {
                  removeClass: attrs.modalInClass
                }).start().then(done);
              } else {
                $animate.removeClass(element, attrs.modalInClass).then(done);
              }
            });
          }


          $q.when(animationPromise).then(function() {
            var inputsWithAutofocus = element[0].querySelectorAll('[autofocus]');
            /**
             * Auto-focusing of a freshly-opened modal element causes any child elements
             * with the autofocus attribute to lose focus. This is an issue on touch
             * based devices which will show and then hide the onscreen keyboard.
             * Attempts to refocus the autofocus element via JavaScript will not reopen
             * the onscreen keyboard. Fixed by updated the focusing logic to only autofocus
             * the modal element if the modal does not contain an autofocus element.
             */
            if (inputsWithAutofocus.length) {
              inputsWithAutofocus[0].focus();
            } else {
              element[0].focus();
            }
          });

          // Notify {@link $modalStack} that modal is rendered.
          var modal = $modalStack.getTop();
          if (modal) {
            $modalStack.modalRendered(modal.key);
          }
        });
      }
    };
  }])

  .directive('modalAnimationClass', [
    function () {
      return {
        compile: function(tElement, tAttrs) {
          if (tAttrs.modalAnimation) {
            tElement.addClass(tAttrs.modalAnimationClass);
          }
        }
      };
    }])

  .directive('modalTransclude', function() {
    return {
      link: function($scope, $element, $attrs, controller, $transclude) {
        $transclude($scope.$parent, function(clone) {
          $element.empty();
          $element.append(clone);
        });
      }
    };
  })

  .factory('$modalStack', [
             '$animate', '$timeout', '$document', '$compile', '$rootScope',
             '$q',
             '$injector',
             '$$multiMap',
             '$$stackedMap',
    function($animate ,  $timeout ,  $document ,  $compile ,  $rootScope ,
              $q,
              $injector,
              $$multiMap,
              $$stackedMap) {
      var $animateCss = null;

      if ($injector.has('$animateCss')) {
        $animateCss = $injector.get('$animateCss');
      }

      var OPENED_MODAL_CLASS = 'modal-open';

      var backdropDomEl, backdropScope;
      var openedWindows = $$stackedMap.createNew();
      var openedClasses = $$multiMap.createNew();
      var $modalStack = {
        NOW_CLOSING_EVENT: 'modal.stack.now-closing'
      };

      //Modal focus behavior
      var focusableElementList;
      var focusIndex = 0;
      var tababbleSelector = 'a[href], area[href], input:not([disabled]), ' +
        'button:not([disabled]),select:not([disabled]), textarea:not([disabled]), ' +
        'iframe, object, embed, *[tabindex], *[contenteditable=true]';

      function backdropIndex() {
        var topBackdropIndex = -1;
        var opened = openedWindows.keys();
        for (var i = 0; i < opened.length; i++) {
          if (openedWindows.get(opened[i]).value.backdrop) {
            topBackdropIndex = i;
          }
        }
        return topBackdropIndex;
      }

      $rootScope.$watch(backdropIndex, function(newBackdropIndex) {
        if (backdropScope) {
          backdropScope.index = newBackdropIndex;
        }
      });

      function removeModalWindow(modalInstance, elementToReceiveFocus) {
        var body = $document.find('body').eq(0);
        var modalWindow = openedWindows.get(modalInstance).value;

        //clean up the stack
        openedWindows.remove(modalInstance);

        removeAfterAnimate(modalWindow.modalDomEl, modalWindow.modalScope, function() {
          var modalBodyClass = modalWindow.openedClass || OPENED_MODAL_CLASS;
          openedClasses.remove(modalBodyClass, modalInstance);
          body.toggleClass(modalBodyClass, openedClasses.hasKey(modalBodyClass));
        });
        checkRemoveBackdrop();

        //move focus to specified element if available, or else to body
        if (elementToReceiveFocus && elementToReceiveFocus.focus) {
          elementToReceiveFocus.focus();
        } else {
          body.focus();
        }
      }

      function checkRemoveBackdrop() {
          //remove backdrop if no longer needed
          if (backdropDomEl && backdropIndex() == -1) {
            var backdropScopeRef = backdropScope;
            removeAfterAnimate(backdropDomEl, backdropScope, function() {
              backdropScopeRef = null;
            });
            backdropDomEl = undefined;
            backdropScope = undefined;
          }
      }

      function removeAfterAnimate(domEl, scope, done) {
        var asyncDeferred;
        var asyncPromise = null;
        var setIsAsync = function() {
          if (!asyncDeferred) {
            asyncDeferred = $q.defer();
            asyncPromise = asyncDeferred.promise;
          }

          return function asyncDone() {
            asyncDeferred.resolve();
          };
        };
        scope.$broadcast($modalStack.NOW_CLOSING_EVENT, setIsAsync);

        // Note that it's intentional that asyncPromise might be null.
        // That's when setIsAsync has not been called during the
        // NOW_CLOSING_EVENT broadcast.
        return $q.when(asyncPromise).then(afterAnimating);

        function afterAnimating() {
          if (afterAnimating.done) {
            return;
          }
          afterAnimating.done = true;

          if ($animateCss) {
            $animateCss(domEl, {
              event: 'leave'
            }).start().then(function() {
              domEl.remove();
            });
          } else {
            $animate.leave(domEl);
          }
          scope.$destroy();
          if (done) {
            done();
          }
        }
      }

      $document.bind('keydown', function(evt) {
        if (evt.isDefaultPrevented()) {
          return evt;
        }

        var modal = openedWindows.top();
        if (modal && modal.value.keyboard) {
          switch (evt.which){
            case 27: {
              evt.preventDefault();
              $rootScope.$apply(function() {
                $modalStack.dismiss(modal.key, 'escape key press');
              });
              break;
            }
            case 9: {
              $modalStack.loadFocusElementList(modal);
              var focusChanged = false;
              if (evt.shiftKey) {
                if ($modalStack.isFocusInFirstItem(evt)) {
                  focusChanged = $modalStack.focusLastFocusableElement();
                }
              } else {
                if ($modalStack.isFocusInLastItem(evt)) {
                  focusChanged = $modalStack.focusFirstFocusableElement();
                }
              }

              if (focusChanged) {
                evt.preventDefault();
                evt.stopPropagation();
              }
              break;
            }
          }
        }
      });

      $modalStack.open = function(modalInstance, modal) {
        var modalOpener = $document[0].activeElement,
          modalBodyClass = modal.openedClass || OPENED_MODAL_CLASS;

        openedWindows.add(modalInstance, {
          deferred: modal.deferred,
          renderDeferred: modal.renderDeferred,
          modalScope: modal.scope,
          backdrop: modal.backdrop,
          keyboard: modal.keyboard,
          openedClass: modal.openedClass
        });

        openedClasses.put(modalBodyClass, modalInstance);

        var body = $document.find('body').eq(0),
            currBackdropIndex = backdropIndex();

        if (currBackdropIndex >= 0 && !backdropDomEl) {
          backdropScope = $rootScope.$new(true);
          backdropScope.index = currBackdropIndex;
          var angularBackgroundDomEl = angular.element('<div modal-backdrop="modal-backdrop"></div>');
          angularBackgroundDomEl.attr('backdrop-class', modal.backdropClass);
          if (modal.animation) {
            angularBackgroundDomEl.attr('modal-animation', 'true');
          }
          backdropDomEl = $compile(angularBackgroundDomEl)(backdropScope);
          body.append(backdropDomEl);
        }

        var angularDomEl = angular.element('<div modal-window="modal-window"></div>');
        angularDomEl.attr({
          'template-url': modal.windowTemplateUrl,
          'window-class': modal.windowClass,
          'size': modal.size,
          'index': openedWindows.length() - 1,
          'animate': 'animate'
        }).html(modal.content);
        if (modal.animation) {
          angularDomEl.attr('modal-animation', 'true');
        }

        var modalDomEl = $compile(angularDomEl)(modal.scope);
        openedWindows.top().value.modalDomEl = modalDomEl;
        openedWindows.top().value.modalOpener = modalOpener;
        body.append(modalDomEl);
        body.addClass(modalBodyClass);

        $modalStack.clearFocusListCache();
      };

      function broadcastClosing(modalWindow, resultOrReason, closing) {
          return !modalWindow.value.modalScope.$broadcast('modal.closing', resultOrReason, closing).defaultPrevented;
      }

      $modalStack.close = function(modalInstance, result) {
        var modalWindow = openedWindows.get(modalInstance);
        if (modalWindow && broadcastClosing(modalWindow, result, true)) {
          modalWindow.value.modalScope.$$uibDestructionScheduled = true;
          modalWindow.value.deferred.resolve(result);
          removeModalWindow(modalInstance, modalWindow.value.modalOpener);
          return true;
        }
        return !modalWindow;
      };

      $modalStack.dismiss = function(modalInstance, reason) {
        var modalWindow = openedWindows.get(modalInstance);
        if (modalWindow && broadcastClosing(modalWindow, reason, false)) {
          modalWindow.value.modalScope.$$uibDestructionScheduled = true;
          modalWindow.value.deferred.reject(reason);
          removeModalWindow(modalInstance, modalWindow.value.modalOpener);
          return true;
        }
        return !modalWindow;
      };

      $modalStack.dismissAll = function(reason) {
        var topModal = this.getTop();
        while (topModal && this.dismiss(topModal.key, reason)) {
          topModal = this.getTop();
        }
      };

      $modalStack.getTop = function() {
        return openedWindows.top();
      };

      $modalStack.modalRendered = function(modalInstance) {
        var modalWindow = openedWindows.get(modalInstance);
        if (modalWindow) {
          modalWindow.value.renderDeferred.resolve();
        }
      };

      $modalStack.focusFirstFocusableElement = function() {
        if (focusableElementList.length > 0) {
          focusableElementList[0].focus();
          return true;
        }
        return false;
      };
      $modalStack.focusLastFocusableElement = function() {
        if (focusableElementList.length > 0) {
          focusableElementList[focusableElementList.length - 1].focus();
          return true;
        }
        return false;
      };

      $modalStack.isFocusInFirstItem = function(evt) {
        if (focusableElementList.length > 0) {
          return (evt.target || evt.srcElement) == focusableElementList[0];
        }
        return false;
      };

      $modalStack.isFocusInLastItem = function(evt) {
        if (focusableElementList.length > 0) {
          return (evt.target || evt.srcElement) == focusableElementList[focusableElementList.length - 1];
        }
        return false;
      };

      $modalStack.clearFocusListCache = function() {
        focusableElementList = [];
        focusIndex = 0;
      };

      $modalStack.loadFocusElementList = function(modalWindow) {
        if (focusableElementList === undefined || !focusableElementList.length0) {
          if (modalWindow) {
            var modalDomE1 = modalWindow.value.modalDomEl;
            if (modalDomE1 && modalDomE1.length) {
              focusableElementList = modalDomE1[0].querySelectorAll(tababbleSelector);
            }
          }
        }
      };

      return $modalStack;
    }])

  .provider('$modal', function() {
    var $modalProvider = {
      options: {
        animation: true,
        backdrop: true, //can also be false or 'static'
        keyboard: true
      },
      $get: ['$injector', '$rootScope', '$q', '$templateRequest', '$controller', '$modalStack',
        function ($injector, $rootScope, $q, $templateRequest, $controller, $modalStack) {
          var $modal = {};

          function getTemplatePromise(options) {
            return options.template ? $q.when(options.template) :
              $templateRequest(angular.isFunction(options.templateUrl) ? (options.templateUrl)() : options.templateUrl);
          }

          function getResolvePromises(resolves) {
            var promisesArr = [];
            angular.forEach(resolves, function(value) {
              if (angular.isFunction(value) || angular.isArray(value)) {
                promisesArr.push($q.when($injector.invoke(value)));
              } else if (angular.isString(value)) {
                promisesArr.push($q.when($injector.get(value)));
              } else {
                promisesArr.push($q.when(value));
              }
            });
            return promisesArr;
          }

          var promiseChain = null;
          $modal.getPromiseChain = function() {
            return promiseChain;
          };

          $modal.open = function (modalOptions) {

            var modalResultDeferred = $q.defer();
            var modalOpenedDeferred = $q.defer();
            var modalRenderDeferred = $q.defer();

            //prepare an instance of a modal to be injected into controllers and returned to a caller
            var modalInstance = {
              result: modalResultDeferred.promise,
              opened: modalOpenedDeferred.promise,
              rendered: modalRenderDeferred.promise,
              close: function (result) {
                return $modalStack.close(modalInstance, result);
              },
              dismiss: function (reason) {
                return $modalStack.dismiss(modalInstance, reason);
              }
            };

            //merge and clean up options
            modalOptions = angular.extend({}, $modalProvider.options, modalOptions);
            modalOptions.resolve = modalOptions.resolve || {};

            //verify options
            if (!modalOptions.template && !modalOptions.templateUrl) {
              throw new Error('One of template or templateUrl options is required.');
            }

            var templateAndResolvePromise =
              $q.all([getTemplatePromise(modalOptions)].concat(getResolvePromises(modalOptions.resolve)));

            // Wait for the resolution of the existing promise chain.
            // Then switch to our own combined promise dependency (regardless of how the previous modal fared).
            // Then add to $modalStack and resolve opened.
            // Finally clean up the chain variable if no subsequent modal has overwritten it.
            var samePromise;
            samePromise = promiseChain = $q.all([promiseChain])
              .then(function() { return templateAndResolvePromise; }, function() { return templateAndResolvePromise; })
              .then(function resolveSuccess(tplAndVars) {

                var modalScope = (modalOptions.scope || $rootScope).$new();
                modalScope.$close = modalInstance.close;
                modalScope.$dismiss = modalInstance.dismiss;

                modalScope.$on('$destroy', function() {
                  if (!modalScope.$$uibDestructionScheduled) {
                    modalScope.$dismiss('$uibUnscheduledDestruction');
                  }
                });

                var ctrlInstance, ctrlLocals = {};
                var resolveIter = 1;

                //controllers
                if (modalOptions.controller) {
                  ctrlLocals.$scope = modalScope;
                  ctrlLocals.$modalInstance = modalInstance;
                  angular.forEach(modalOptions.resolve, function(value, key) {
                    ctrlLocals[key] = tplAndVars[resolveIter++];
                  });

                  ctrlInstance = $controller(modalOptions.controller, ctrlLocals);
                  if (modalOptions.controllerAs) {
                    if (modalOptions.bindToController) {
                      angular.extend(ctrlInstance, modalScope);
                    }

                    modalScope[modalOptions.controllerAs] = ctrlInstance;
                  }
                }

                $modalStack.open(modalInstance, {
                  scope: modalScope,
                  deferred: modalResultDeferred,
                  renderDeferred: modalRenderDeferred,
                  content: tplAndVars[0],
                  animation: modalOptions.animation,
                  backdrop: modalOptions.backdrop,
                  keyboard: modalOptions.keyboard,
                  backdropClass: modalOptions.backdropClass,
                  windowClass: modalOptions.windowClass,
                  windowTemplateUrl: modalOptions.windowTemplateUrl,
                  size: modalOptions.size,
                  openedClass: modalOptions.openedClass
                });
                modalOpenedDeferred.resolve(true);

            }, function resolveError(reason) {
              modalOpenedDeferred.reject(reason);
              modalResultDeferred.reject(reason);
            })
            .finally(function() {
              if (promiseChain === samePromise) {
                promiseChain = null;
              }
            });

            return modalInstance;
          };

          return $modal;
        }]
    };

    return $modalProvider;
  });

angular.module('ui.bootstrap.pagination', [])
.controller('PaginationController', ['$scope', '$attrs', '$parse', function($scope, $attrs, $parse) {
  var self = this,
      ngModelCtrl = { $setViewValue: angular.noop }, // nullModelCtrl
      setNumPages = $attrs.numPages ? $parse($attrs.numPages).assign : angular.noop;

  this.init = function(ngModelCtrl_, config) {
    ngModelCtrl = ngModelCtrl_;
    this.config = config;

    ngModelCtrl.$render = function() {
      self.render();
    };

    if ($attrs.itemsPerPage) {
      $scope.$parent.$watch($parse($attrs.itemsPerPage), function(value) {
        self.itemsPerPage = parseInt(value, 10);
        $scope.totalPages = self.calculateTotalPages();
      });
    } else {
      this.itemsPerPage = config.itemsPerPage;
    }

    $scope.$watch('totalItems', function() {
      $scope.totalPages = self.calculateTotalPages();
    });

    $scope.$watch('totalPages', function(value) {
      setNumPages($scope.$parent, value); // Readonly variable

      if ( $scope.page > value ) {
        $scope.selectPage(value);
      } else {
        ngModelCtrl.$render();
      }
    });
  };

  this.calculateTotalPages = function() {
    var totalPages = this.itemsPerPage < 1 ? 1 : Math.ceil($scope.totalItems / this.itemsPerPage);
    return Math.max(totalPages || 0, 1);
  };

  this.render = function() {
    $scope.page = parseInt(ngModelCtrl.$viewValue, 10) || 1;
  };

  $scope.selectPage = function(page, evt) {
    if (evt) {
      evt.preventDefault();
    }

    var clickAllowed = !$scope.ngDisabled || !evt;
    if (clickAllowed && $scope.page !== page && page > 0 && page <= $scope.totalPages) {
      if (evt && evt.target) {
        evt.target.blur();
      }
      ngModelCtrl.$setViewValue(page);
      ngModelCtrl.$render();
    }
  };

  $scope.getText = function(key) {
    return $scope[key + 'Text'] || self.config[key + 'Text'];
  };

  $scope.noPrevious = function() {
    return $scope.page === 1;
  };

  $scope.noNext = function() {
    return $scope.page === $scope.totalPages;
  };
}])

.constant('paginationConfig', {
  itemsPerPage: 10,
  boundaryLinks: false,
  directionLinks: true,
  firstText: 'First',
  previousText: 'Previous',
  nextText: 'Next',
  lastText: 'Last',
  rotate: true
})

.directive('pagination', ['$parse', 'paginationConfig', function($parse, paginationConfig) {
  return {
    restrict: 'EA',
    scope: {
      totalItems: '=',
      firstText: '@',
      previousText: '@',
      nextText: '@',
      lastText: '@',
      ngDisabled:'='
    },
    require: ['pagination', '?ngModel'],
    controller: 'PaginationController',
    controllerAs: 'pagination',
    templateUrl: function(element, attrs) {
      return attrs.templateUrl || 'template/pagination/pagination.html';
    },
    replace: true,
    link: function(scope, element, attrs, ctrls) {
      var paginationCtrl = ctrls[0], ngModelCtrl = ctrls[1];

      if (!ngModelCtrl) {
         return; // do nothing if no ng-model
      }

      // Setup configuration parameters
      var maxSize = angular.isDefined(attrs.maxSize) ? scope.$parent.$eval(attrs.maxSize) : paginationConfig.maxSize,
          rotate = angular.isDefined(attrs.rotate) ? scope.$parent.$eval(attrs.rotate) : paginationConfig.rotate;
      scope.boundaryLinks = angular.isDefined(attrs.boundaryLinks) ? scope.$parent.$eval(attrs.boundaryLinks) : paginationConfig.boundaryLinks;
      scope.directionLinks = angular.isDefined(attrs.directionLinks) ? scope.$parent.$eval(attrs.directionLinks) : paginationConfig.directionLinks;

      paginationCtrl.init(ngModelCtrl, paginationConfig);

      if (attrs.maxSize) {
        scope.$parent.$watch($parse(attrs.maxSize), function(value) {
          maxSize = parseInt(value, 10);
          paginationCtrl.render();
        });
      }

      // Create page object used in template
      function makePage(number, text, isActive) {
        return {
          number: number,
          text: text,
          active: isActive
        };
      }

      function getPages(currentPage, totalPages) {
        var pages = [];

        // Default page limits
        var startPage = 1, endPage = totalPages;
        var isMaxSized = angular.isDefined(maxSize) && maxSize < totalPages;

        // recompute if maxSize
        if (isMaxSized) {
          if (rotate) {
            // Current page is displayed in the middle of the visible ones
            startPage = Math.max(currentPage - Math.floor(maxSize/2), 1);
            endPage   = startPage + maxSize - 1;

            // Adjust if limit is exceeded
            if (endPage > totalPages) {
              endPage   = totalPages;
              startPage = endPage - maxSize + 1;
            }
          } else {
            // Visible pages are paginated with maxSize
            startPage = ((Math.ceil(currentPage / maxSize) - 1) * maxSize) + 1;

            // Adjust last page if limit is exceeded
            endPage = Math.min(startPage + maxSize - 1, totalPages);
          }
        }

        // Add page number links
        for (var number = startPage; number <= endPage; number++) {
          var page = makePage(number, number, number === currentPage);
          pages.push(page);
        }

        // Add links to move between page sets
        if (isMaxSized && ! rotate) {
          if (startPage > 1) {
            var previousPageSet = makePage(startPage - 1, '...', false);
            pages.unshift(previousPageSet);
          }

          if (endPage < totalPages) {
            var nextPageSet = makePage(endPage + 1, '...', false);
            pages.push(nextPageSet);
          }
        }

        return pages;
      }

      var originalRender = paginationCtrl.render;
      paginationCtrl.render = function() {
        originalRender();
        if (scope.page > 0 && scope.page <= scope.totalPages) {
          scope.pages = getPages(scope.page, scope.totalPages);
        }
      };
    }
  };
}])

.constant('pagerConfig', {
  itemsPerPage: 10,
  previousText: '« Previous',
  nextText: 'Next »',
  align: true
})

.directive('pager', ['pagerConfig', function(pagerConfig) {
  return {
    restrict: 'EA',
    scope: {
      totalItems: '=',
      previousText: '@',
      nextText: '@',
      ngDisabled: '='
    },
    require: ['pager', '?ngModel'],
    controller: 'PaginationController',
    controllerAs: 'pagination',
    templateUrl: function(element, attrs) {
      return attrs.templateUrl || 'template/pagination/pager.html';
    },
    replace: true,
    link: function(scope, element, attrs, ctrls) {
      var paginationCtrl = ctrls[0], ngModelCtrl = ctrls[1];

      if (!ngModelCtrl) {
         return; // do nothing if no ng-model
      }

      scope.align = angular.isDefined(attrs.align) ? scope.$parent.$eval(attrs.align) : pagerConfig.align;
      paginationCtrl.init(ngModelCtrl, pagerConfig);
    }
  };
}]);

/**
 * The following features are still outstanding: animation as a
 * function, placement as a function, inside, support for more triggers than
 * just mouse enter/leave, html tooltips, and selector delegation.
 */
angular.module('ui.bootstrap.tooltip', ['ui.bootstrap.position', 'ui.bootstrap.bindHtml'])

/**
 * The $tooltip service creates tooltip- and popover-like directives as well as
 * houses global options for them.
 */
.provider('$tooltip', function() {
  // The default options tooltip and popover.
  var defaultOptions = {
    placement: 'top',
    animation: true,
    popupDelay: 0,
    useContentExp: false
  };

  // Default hide triggers for each show trigger
  var triggerMap = {
    'mouseenter': 'mouseleave',
    'click': 'click',
    'focus': 'blur',
    'none': ''
  };

  // The options specified to the provider globally.
  var globalOptions = {};

  /**
   * `options({})` allows global configuration of all tooltips in the
   * application.
   *
   *   var app = angular.module( 'App', ['ui.bootstrap.tooltip'], function( $tooltipProvider ) {
   *     // place tooltips left instead of top by default
   *     $tooltipProvider.options( { placement: 'left' } );
   *   });
   */
	this.options = function(value) {
		angular.extend(globalOptions, value);
	};

  /**
   * This allows you to extend the set of trigger mappings available. E.g.:
   *
   *   $tooltipProvider.setTriggers( 'openTrigger': 'closeTrigger' );
   */
  this.setTriggers = function setTriggers(triggers) {
    angular.extend(triggerMap, triggers);
  };

  /**
   * This is a helper function for translating camel-case to snake-case.
   */
  function snake_case(name) {
    var regexp = /[A-Z]/g;
    var separator = '-';
    return name.replace(regexp, function(letter, pos) {
      return (pos ? separator : '') + letter.toLowerCase();
    });
  }

  /**
   * Returns the actual instance of the $tooltip service.
   * TODO support multiple triggers
   */
  this.$get = ['$window', '$compile', '$timeout', '$document', '$position', '$interpolate', '$rootScope', '$parse', function($window, $compile, $timeout, $document, $position, $interpolate, $rootScope, $parse) {
    return function $tooltip(type, prefix, defaultTriggerShow, options) {
      options = angular.extend({}, defaultOptions, globalOptions, options);

      /**
       * Returns an object of show and hide triggers.
       *
       * If a trigger is supplied,
       * it is used to show the tooltip; otherwise, it will use the `trigger`
       * option passed to the `$tooltipProvider.options` method; else it will
       * default to the trigger supplied to this directive factory.
       *
       * The hide trigger is based on the show trigger. If the `trigger` option
       * was passed to the `$tooltipProvider.options` method, it will use the
       * mapped trigger from `triggerMap` or the passed trigger if the map is
       * undefined; otherwise, it uses the `triggerMap` value of the show
       * trigger; else it will just use the show trigger.
       */
      function getTriggers(trigger) {
        var show = (trigger || options.trigger || defaultTriggerShow).split(' ');
        var hide = show.map(function(trigger) {
          return triggerMap[trigger] || trigger;
        });
        return {
          show: show,
          hide: hide
        };
      }

      var directiveName = snake_case(type);

      var startSym = $interpolate.startSymbol();
      var endSym = $interpolate.endSymbol();
      var template =
        '<div '+ directiveName +'-popup '+
          'title="'+startSym+'title'+endSym+'" '+
          (options.useContentExp ?
            'content-exp="contentExp()" ' :
            'content="'+startSym+'content'+endSym+'" ') +
          'placement="'+startSym+'placement'+endSym+'" '+
          'popup-class="'+startSym+'popupClass'+endSym+'" '+
          'animation="animation" '+
          'is-open="isOpen"'+
          'origin-scope="origScope" '+
          '>'+
        '</div>';

      return {
        restrict: 'EA',
        compile: function(tElem, tAttrs) {
          var tooltipLinker = $compile( template );

          return function link(scope, element, attrs, tooltipCtrl) {
            var tooltip;
            var tooltipLinkedScope;
            var transitionTimeout;
            var popupTimeout;
            var positionTimeout;
            var appendToBody = angular.isDefined(options.appendToBody) ? options.appendToBody : false;
            var triggers = getTriggers(undefined);
            var hasEnableExp = angular.isDefined(attrs[prefix + 'Enable']);
            var ttScope = scope.$new(true);
            var repositionScheduled = false;
            var isOpenExp = angular.isDefined(attrs[prefix + 'IsOpen']) ? $parse(attrs[prefix + 'IsOpen']) : false;

            var positionTooltip = function() {
              if (!tooltip) { return; }

              if (!positionTimeout) {
                positionTimeout = $timeout(function() {
                  // Reset the positioning and box size for correct width and height values.
                  tooltip.css({ top: 0, left: 0, width: 'auto', height: 'auto' });

                  var ttBox = $position.position(tooltip);
                  var ttCss = $position.positionElements(element, tooltip, ttScope.placement, appendToBody);
                  ttCss.top += 'px';
                  ttCss.left += 'px';

                  ttCss.width = ttBox.width + 'px';
                  ttCss.height = ttBox.height + 'px';

                  // Now set the calculated positioning and size.
                  tooltip.css(ttCss);

                  positionTimeout = null;

                }, 0, false);
              }
            };

            // Set up the correct scope to allow transclusion later
            ttScope.origScope = scope;

            // By default, the tooltip is not open.
            // TODO add ability to start tooltip opened
            ttScope.isOpen = false;

            function toggleTooltipBind() {
              if (!ttScope.isOpen) {
                showTooltipBind();
              } else {
                hideTooltipBind();
              }
            }

            // Show the tooltip with delay if specified, otherwise show it immediately
            function showTooltipBind() {
              if (hasEnableExp && !scope.$eval(attrs[prefix + 'Enable'])) {
                return;
              }

              prepareTooltip();

              if (ttScope.popupDelay) {
                // Do nothing if the tooltip was already scheduled to pop-up.
                // This happens if show is triggered multiple times before any hide is triggered.
                if (!popupTimeout) {
                  popupTimeout = $timeout(show, ttScope.popupDelay, false);
                }
              } else {
                show();
              }
            }

            function hideTooltipBind () {
              hide();
              if (!$rootScope.$$phase) {
                $rootScope.$digest();
              }
            }

            // Show the tooltip popup element.
            function show() {
              popupTimeout = null;

              // If there is a pending remove transition, we must cancel it, lest the
              // tooltip be mysteriously removed.
              if (transitionTimeout) {
                $timeout.cancel(transitionTimeout);
                transitionTimeout = null;
              }

              // Don't show empty tooltips.
              if (!(options.useContentExp ? ttScope.contentExp() : ttScope.content)) {
                return angular.noop;
              }

              createTooltip();

              // And show the tooltip.
              ttScope.isOpen = true;
              if (isOpenExp) {
                isOpenExp.assign(ttScope.origScope, ttScope.isOpen);
              }

              if (!$rootScope.$$phase) {
                ttScope.$apply(); // digest required as $apply is not called
              }

              tooltip.css({ display: 'block' });

              positionTooltip();
            }

            // Hide the tooltip popup element.
            function hide() {
              // First things first: we don't show it anymore.
              ttScope.isOpen = false;
              if (isOpenExp) {
                isOpenExp.assign(ttScope.origScope, ttScope.isOpen);
              }

              //if tooltip is going to be shown after delay, we must cancel this
              $timeout.cancel(popupTimeout);
              popupTimeout = null;

              $timeout.cancel(positionTimeout);
              positionTimeout = null;

              // And now we remove it from the DOM. However, if we have animation, we
              // need to wait for it to expire beforehand.
              // FIXME: this is a placeholder for a port of the transitions library.
              if (ttScope.animation) {
                if (!transitionTimeout) {
                  transitionTimeout = $timeout(removeTooltip, 500);
                }
              } else {
                removeTooltip();
              }
            }

            function createTooltip() {
              // There can only be one tooltip element per directive shown at once.
              if (tooltip) {
                removeTooltip();
              }
              tooltipLinkedScope = ttScope.$new();
              tooltip = tooltipLinker(tooltipLinkedScope, function(tooltip) {
                if (appendToBody) {
                  $document.find('body').append(tooltip);
                } else {
                  element.after(tooltip);
                }
              });

              if (options.useContentExp) {
                tooltipLinkedScope.$watch('contentExp()', function(val) {
                  if (!val && ttScope.isOpen) {
                    hide();
                  }
                });

                tooltipLinkedScope.$watch(function() {
                  if (!repositionScheduled) {
                    repositionScheduled = true;
                    tooltipLinkedScope.$$postDigest(function() {
                      repositionScheduled = false;
                      if (ttScope.isOpen) {
                        positionTooltip();
                      }
                    });
                  }
                });

              }
            }

            function removeTooltip() {
              transitionTimeout = null;
              if (tooltip) {
                tooltip.remove();
                tooltip = null;
              }
              if (tooltipLinkedScope) {
                tooltipLinkedScope.$destroy();
                tooltipLinkedScope = null;
              }
            }

            function prepareTooltip() {
              prepPopupClass();
              prepPlacement();
              prepPopupDelay();
            }

            ttScope.contentExp = function() {
              return scope.$eval(attrs[type]);
            };

            /**
             * Observe the relevant attributes.
             */
            if (!options.useContentExp) {
              attrs.$observe(type, function(val) {
                ttScope.content = val;

                if (!val && ttScope.isOpen) {
                  hide();
                } else {
                  positionTooltip();
                }
              });
            }

            attrs.$observe('disabled', function(val) {
              if (popupTimeout && val) {
                $timeout.cancel(popupTimeout);
                popupTimeout = null;
              }

              if (val && ttScope.isOpen) {
                hide();
              }
            });

            attrs.$observe(prefix + 'Title', function(val) {
              ttScope.title = val;
              positionTooltip();
            });

            attrs.$observe(prefix + 'Placement', function() {
              if (ttScope.isOpen) {
                prepPlacement();
                positionTooltip();
              }
            });

            if (isOpenExp) {
              scope.$watch(isOpenExp, function(val) {
                if (val !== ttScope.isOpen) {
                  toggleTooltipBind();
                }
              });
            }

            function prepPopupClass() {
              ttScope.popupClass = attrs[prefix + 'Class'];
            }

            function prepPlacement() {
              var val = attrs[prefix + 'Placement'];
              ttScope.placement = angular.isDefined(val) ? val : options.placement;
            }

            function prepPopupDelay() {
              var val = attrs[prefix + 'PopupDelay'];
              var delay = parseInt(val, 10);
              ttScope.popupDelay = !isNaN(delay) ? delay : options.popupDelay;
            }

            var unregisterTriggers = function() {
              triggers.show.forEach(function(trigger) {
                element.unbind(trigger, showTooltipBind);
              });
              triggers.hide.forEach(function(trigger) {
                element.unbind(trigger, hideTooltipBind);
              });
            };

            function prepTriggers() {
              var val = attrs[prefix + 'Trigger'];
              unregisterTriggers();

              triggers = getTriggers(val);

              if (triggers.show !== 'none') {
                triggers.show.forEach(function(trigger, idx) {
                  // Using raw addEventListener due to jqLite/jQuery bug - #4060
                  if (trigger === triggers.hide[idx]) {
                    element[0].addEventListener(trigger, toggleTooltipBind);
                  } else if (trigger) {
                    element[0].addEventListener(trigger, showTooltipBind);
                    element[0].addEventListener(triggers.hide[idx], hideTooltipBind);
                  }
                });
              }
            }
            prepTriggers();

            var animation = scope.$eval(attrs[prefix + 'Animation']);
            ttScope.animation = angular.isDefined(animation) ? !!animation : options.animation;

            var appendToBodyVal = scope.$eval(attrs[prefix + 'AppendToBody']);
            appendToBody = angular.isDefined(appendToBodyVal) ? appendToBodyVal : appendToBody;

            // if a tooltip is attached to <body> we need to remove it on
            // location change as its parent scope will probably not be destroyed
            // by the change.
            if (appendToBody) {
              scope.$on('$locationChangeSuccess', function closeTooltipOnLocationChangeSuccess() {
                if (ttScope.isOpen) {
                  hide();
                }
              });
            }

            // Make sure tooltip is destroyed and removed.
            scope.$on('$destroy', function onDestroyTooltip() {
              $timeout.cancel(transitionTimeout);
              $timeout.cancel(popupTimeout);
              $timeout.cancel(positionTimeout);
              unregisterTriggers();
              removeTooltip();
              ttScope = null;
            });
          };
        }
      };
    };
  }];
})

// This is mostly ngInclude code but with a custom scope
.directive('tooltipTemplateTransclude', [
         '$animate', '$sce', '$compile', '$templateRequest',
function ($animate ,  $sce ,  $compile ,  $templateRequest) {
  return {
    link: function(scope, elem, attrs) {
      var origScope = scope.$eval(attrs.tooltipTemplateTranscludeScope);

      var changeCounter = 0,
        currentScope,
        previousElement,
        currentElement;

      var cleanupLastIncludeContent = function() {
        if (previousElement) {
          previousElement.remove();
          previousElement = null;
        }
        if (currentScope) {
          currentScope.$destroy();
          currentScope = null;
        }
        if (currentElement) {
          $animate.leave(currentElement).then(function() {
            previousElement = null;
          });
          previousElement = currentElement;
          currentElement = null;
        }
      };

      scope.$watch($sce.parseAsResourceUrl(attrs.tooltipTemplateTransclude), function(src) {
        var thisChangeId = ++changeCounter;

        if (src) {
          //set the 2nd param to true to ignore the template request error so that the inner
          //contents and scope can be cleaned up.
          $templateRequest(src, true).then(function(response) {
            if (thisChangeId !== changeCounter) { return; }
            var newScope = origScope.$new();
            var template = response;

            var clone = $compile(template)(newScope, function(clone) {
              cleanupLastIncludeContent();
              $animate.enter(clone, elem);
            });

            currentScope = newScope;
            currentElement = clone;

            currentScope.$emit('$includeContentLoaded', src);
          }, function() {
            if (thisChangeId === changeCounter) {
              cleanupLastIncludeContent();
              scope.$emit('$includeContentError', src);
            }
          });
          scope.$emit('$includeContentRequested', src);
        } else {
          cleanupLastIncludeContent();
        }
      });

      scope.$on('$destroy', cleanupLastIncludeContent);
    }
  };
}])

/**
 * Note that it's intentional that these classes are *not* applied through $animate.
 * They must not be animated as they're expected to be present on the tooltip on
 * initialization.
 */
.directive('tooltipClasses', function() {
  return {
    restrict: 'A',
    link: function(scope, element, attrs) {
      if (scope.placement) {
        element.addClass(scope.placement);
      }
      if (scope.popupClass) {
        element.addClass(scope.popupClass);
      }
      if (scope.animation()) {
        element.addClass(attrs.tooltipAnimationClass);
      }
    }
  };
})

.directive('tooltipPopup', function() {
  return {
    restrict: 'EA',
    replace: true,
    scope: { content: '@', placement: '@', popupClass: '@', animation: '&', isOpen: '&' },
    templateUrl: 'template/tooltip/tooltip-popup.html'
  };
})

.directive('tooltip', [ '$tooltip', function($tooltip) {
  return $tooltip('tooltip', 'tooltip', 'mouseenter');
}])

.directive('tooltipTemplatePopup', function() {
  return {
    restrict: 'EA',
    replace: true,
    scope: { contentExp: '&', placement: '@', popupClass: '@', animation: '&', isOpen: '&',
      originScope: '&' },
    templateUrl: 'template/tooltip/tooltip-template-popup.html'
  };
})

.directive('tooltipTemplate', ['$tooltip', function($tooltip) {
  return $tooltip('tooltipTemplate', 'tooltip', 'mouseenter', {
    useContentExp: true
  });
}])

.directive('tooltipHtmlPopup', function() {
  return {
    restrict: 'EA',
    replace: true,
    scope: { contentExp: '&', placement: '@', popupClass: '@', animation: '&', isOpen: '&' },
    templateUrl: 'template/tooltip/tooltip-html-popup.html'
  };
})

.directive('tooltipHtml', ['$tooltip', function($tooltip) {
  return $tooltip('tooltipHtml', 'tooltip', 'mouseenter', {
    useContentExp: true
  });
}])

/*
Deprecated
*/
.directive('tooltipHtmlUnsafePopup', function() {
  return {
    restrict: 'EA',
    replace: true,
    scope: { content: '@', placement: '@', popupClass: '@', animation: '&', isOpen: '&' },
    templateUrl: 'template/tooltip/tooltip-html-unsafe-popup.html'
  };
})

.value('tooltipHtmlUnsafeSuppressDeprecated', false)
.directive('tooltipHtmlUnsafe', [
          '$tooltip', 'tooltipHtmlUnsafeSuppressDeprecated', '$log',
function($tooltip ,  tooltipHtmlUnsafeSuppressDeprecated ,  $log) {
  if (!tooltipHtmlUnsafeSuppressDeprecated) {
    $log.warn('tooltip-html-unsafe is now deprecated. Use tooltip-html or tooltip-template instead.');
  }
  return $tooltip('tooltipHtmlUnsafe', 'tooltip', 'mouseenter');
}]);

/**
 * The following features are still outstanding: popup delay, animation as a
 * function, placement as a function, inside, support for more triggers than
 * just mouse enter/leave, and selector delegatation.
 */
angular.module( 'ui.bootstrap.popover', ['ui.bootstrap.tooltip'])

.directive('popoverTemplatePopup', function() {
  return {
    restrict: 'EA',
    replace: true,
    scope: { title: '@', contentExp: '&', placement: '@', popupClass: '@', animation: '&', isOpen: '&',
      originScope: '&' },
    templateUrl: 'template/popover/popover-template.html'
  };
})

.directive('popoverTemplate', ['$tooltip', function($tooltip) {
  return $tooltip('popoverTemplate', 'popover', 'click', {
    useContentExp: true
  });
}])

.directive('popoverHtmlPopup', function() {
  return {
    restrict: 'EA',
    replace: true,
    scope: { contentExp: '&', title: '@', placement: '@', popupClass: '@', animation: '&', isOpen: '&' },
    templateUrl: 'template/popover/popover-html.html'
  };
})

.directive('popoverHtml', ['$tooltip', function($tooltip) {
  return $tooltip( 'popoverHtml', 'popover', 'click', {
    useContentExp: true
  });
}])

.directive('popoverPopup', function() {
  return {
    restrict: 'EA',
    replace: true,
    scope: { title: '@', content: '@', placement: '@', popupClass: '@', animation: '&', isOpen: '&' },
    templateUrl: 'template/popover/popover.html'
  };
})

.directive('popover', ['$tooltip', function($tooltip) {
  return $tooltip( 'popover', 'popover', 'click' );
}]);

angular.module('ui.bootstrap.progressbar', [])

.constant('progressConfig', {
  animate: true,
  max: 100
})

.value('$progressSuppressWarning', false)

.controller('ProgressController', ['$scope', '$attrs', 'progressConfig', function($scope, $attrs, progressConfig) {
  var self = this,
      animate = angular.isDefined($attrs.animate) ? $scope.$parent.$eval($attrs.animate) : progressConfig.animate;

  this.bars = [];
  $scope.max = angular.isDefined($scope.max) ? $scope.max : progressConfig.max;

  this.addBar = function(bar, element) {
    if (!animate) {
      element.css({'transition': 'none'});
    }

    this.bars.push(bar);

    bar.max = $scope.max;

    bar.$watch('value', function(value) {
      bar.recalculatePercentage();
    });

    bar.recalculatePercentage = function() {
      bar.percent = +(100 * bar.value / bar.max).toFixed(2);

      var totalPercentage = self.bars.reduce(function(total, bar) {
        return total + bar.percent;
      }, 0);

      if (totalPercentage > 100) {
        bar.percent -= totalPercentage - 100;
      }
    };

    bar.$on('$destroy', function() {
      element = null;
      self.removeBar(bar);
    });
  };

  this.removeBar = function(bar) {
      this.bars.splice(this.bars.indexOf(bar), 1);
  };

  $scope.$watch('max', function(max) {
    self.bars.forEach(function(bar) {
      bar.max = $scope.max;
      bar.recalculatePercentage();
    });
  });
}])

.directive('uibProgress', function() {
  return {
    restrict: 'EA',
    replace: true,
    transclude: true,
    controller: 'ProgressController',
    require: 'uibProgress',
    scope: {
      max: '=?'
    },
    templateUrl: 'template/progressbar/progress.html'
  };
})

.directive('progress', ['$log', '$progressSuppressWarning', function($log, $progressSuppressWarning) {
  return {
    restrict: 'EA',
    replace: true,
    transclude: true,
    controller: 'ProgressController',
    require: 'progress',
    scope: {
      max: '=?'
    },
    templateUrl: 'template/progressbar/progress.html',
    link: function() {
      if ($progressSuppressWarning) {
        $log.warn('progress is now deprecated. Use uib-progress instead');
      }
    }
  };
}])

.directive('uibBar', function() {
  return {
    restrict: 'EA',
    replace: true,
    transclude: true,
    require: '^uibProgress',
    scope: {
      value: '=',
      type: '@'
    },
    templateUrl: 'template/progressbar/bar.html',
    link: function(scope, element, attrs, progressCtrl) {
      progressCtrl.addBar(scope, element);
    }
  };
})

.directive('bar', ['$log', '$progressSuppressWarning', function($log, $progressSuppressWarning) {
  return {
    restrict: 'EA',
    replace: true,
    transclude: true,
    require: '^progress',
    scope: {
      value: '=',
      type: '@'
    },
    templateUrl: 'template/progressbar/bar.html',
    link: function(scope, element, attrs, progressCtrl) {
      if ($progressSuppressWarning) {
        $log.warn('bar is now deprecated. Use uib-bar instead');
      }
      progressCtrl.addBar(scope, element);
    }
  };
}])

.directive('progressbar', function() {
  return {
    restrict: 'EA',
    replace: true,
    transclude: true,
    controller: 'ProgressController',
    scope: {
      value: '=',
      max: '=?',
      type: '@'
    },
    templateUrl: 'template/progressbar/progressbar.html',
    link: function(scope, element, attrs, progressCtrl) {
      progressCtrl.addBar(scope, angular.element(element.children()[0]));
    }
  };
});

angular.module('ui.bootstrap.rating', [])

.constant('ratingConfig', {
  max: 5,
  stateOn: null,
  stateOff: null,
  titles : ['one', 'two', 'three', 'four', 'five']
})

.controller('RatingController', ['$scope', '$attrs', 'ratingConfig', function($scope, $attrs, ratingConfig) {
  var ngModelCtrl  = { $setViewValue: angular.noop };

  this.init = function(ngModelCtrl_) {
    ngModelCtrl = ngModelCtrl_;
    ngModelCtrl.$render = this.render;

    ngModelCtrl.$formatters.push(function(value) {
      if (angular.isNumber(value) && value << 0 !== value) {
        value = Math.round(value);
      }
      return value;
    });

    this.stateOn = angular.isDefined($attrs.stateOn) ? $scope.$parent.$eval($attrs.stateOn) : ratingConfig.stateOn;
    this.stateOff = angular.isDefined($attrs.stateOff) ? $scope.$parent.$eval($attrs.stateOff) : ratingConfig.stateOff;
    var tmpTitles = angular.isDefined($attrs.titles)  ? $scope.$parent.$eval($attrs.titles) : ratingConfig.titles ;    
    this.titles = angular.isArray(tmpTitles) && tmpTitles.length > 0 ?
      tmpTitles : ratingConfig.titles;
    
    var ratingStates = angular.isDefined($attrs.ratingStates) ?
      $scope.$parent.$eval($attrs.ratingStates) :
      new Array(angular.isDefined($attrs.max) ? $scope.$parent.$eval($attrs.max) : ratingConfig.max);
    $scope.range = this.buildTemplateObjects(ratingStates);
  };

  this.buildTemplateObjects = function(states) {
    for (var i = 0, n = states.length; i < n; i++) {
      states[i] = angular.extend({ index: i }, { stateOn: this.stateOn, stateOff: this.stateOff, title: this.getTitle(i) }, states[i]);
    }
    return states;
  };
  
  this.getTitle = function(index) {
    if (index >= this.titles.length) {
      return index + 1;
    } else {
      return this.titles[index];
    }
  };
  
  $scope.rate = function(value) {
    if (!$scope.readonly && value >= 0 && value <= $scope.range.length) {
      ngModelCtrl.$setViewValue(ngModelCtrl.$viewValue === value ? 0 : value);
      ngModelCtrl.$render();
    }
  };

  $scope.enter = function(value) {
    if (!$scope.readonly) {
      $scope.value = value;
    }
    $scope.onHover({value: value});
  };

  $scope.reset = function() {
    $scope.value = ngModelCtrl.$viewValue;
    $scope.onLeave();
  };

  $scope.onKeydown = function(evt) {
    if (/(37|38|39|40)/.test(evt.which)) {
      evt.preventDefault();
      evt.stopPropagation();
      $scope.rate($scope.value + (evt.which === 38 || evt.which === 39 ? 1 : -1));
    }
  };

  this.render = function() {
    $scope.value = ngModelCtrl.$viewValue;
  };
}])

.directive('rating', function() {
  return {
    restrict: 'EA',
    require: ['rating', 'ngModel'],
    scope: {
      readonly: '=?',
      onHover: '&',
      onLeave: '&'
    },
    controller: 'RatingController',
    templateUrl: 'template/rating/rating.html',
    replace: true,
    link: function(scope, element, attrs, ctrls) {
      var ratingCtrl = ctrls[0], ngModelCtrl = ctrls[1];
      ratingCtrl.init( ngModelCtrl );
    }
  };
});


/**
 * @ngdoc overview
 * @name ui.bootstrap.tabs
 *
 * @description
 * AngularJS version of the tabs directive.
 */

angular.module('ui.bootstrap.tabs', [])

.controller('TabsetController', ['$scope', function TabsetCtrl($scope) {
  var ctrl = this,
      tabs = ctrl.tabs = $scope.tabs = [];

  ctrl.select = function(selectedTab) {
    angular.forEach(tabs, function(tab) {
      if (tab.active && tab !== selectedTab) {
        tab.active = false;
        tab.onDeselect();
        selectedTab.selectCalled = false;
      }
    });
    selectedTab.active = true;
    // only call select if it has not already been called
    if (!selectedTab.selectCalled) {
      selectedTab.onSelect();
      selectedTab.selectCalled = true;
    }
  };

  ctrl.addTab = function addTab(tab) {
    tabs.push(tab);
    // we can't run the select function on the first tab
    // since that would select it twice
    if (tabs.length === 1 && tab.active !== false) {
      tab.active = true;
    } else if (tab.active) {
      ctrl.select(tab);
    } else {
      tab.active = false;
    }
  };

  ctrl.removeTab = function removeTab(tab) {
    var index = tabs.indexOf(tab);
    //Select a new tab if the tab to be removed is selected and not destroyed
    if (tab.active && tabs.length > 1 && !destroyed) {
      //If this is the last tab, select the previous tab. else, the next tab.
      var newActiveIndex = index == tabs.length - 1 ? index - 1 : index + 1;
      ctrl.select(tabs[newActiveIndex]);
    }
    tabs.splice(index, 1);
  };

  var destroyed;
  $scope.$on('$destroy', function() {
    destroyed = true;
  });
}])

/**
 * @ngdoc directive
 * @name ui.bootstrap.tabs.directive:tabset
 * @restrict EA
 *
 * @description
 * Tabset is the outer container for the tabs directive
 *
 * @param {boolean=} vertical Whether or not to use vertical styling for the tabs.
 * @param {boolean=} justified Whether or not to use justified styling for the tabs.
 *
 * @example
<example module="ui.bootstrap">
  <file name="index.html">
    <tabset>
      <tab heading="Tab 1"><b>First</b> Content!</tab>
      <tab heading="Tab 2"><i>Second</i> Content!</tab>
    </tabset>
    <hr />
    <tabset vertical="true">
      <tab heading="Vertical Tab 1"><b>First</b> Vertical Content!</tab>
      <tab heading="Vertical Tab 2"><i>Second</i> Vertical Content!</tab>
    </tabset>
    <tabset justified="true">
      <tab heading="Justified Tab 1"><b>First</b> Justified Content!</tab>
      <tab heading="Justified Tab 2"><i>Second</i> Justified Content!</tab>
    </tabset>
  </file>
</example>
 */
.directive('tabset', function() {
  return {
    restrict: 'EA',
    transclude: true,
    replace: true,
    scope: {
      type: '@'
    },
    controller: 'TabsetController',
    templateUrl: 'template/tabs/tabset.html',
    link: function(scope, element, attrs) {
      scope.vertical = angular.isDefined(attrs.vertical) ? scope.$parent.$eval(attrs.vertical) : false;
      scope.justified = angular.isDefined(attrs.justified) ? scope.$parent.$eval(attrs.justified) : false;
    }
  };
})

/**
 * @ngdoc directive
 * @name ui.bootstrap.tabs.directive:tab
 * @restrict EA
 *
 * @param {string=} heading The visible heading, or title, of the tab. Set HTML headings with {@link ui.bootstrap.tabs.directive:tabHeading tabHeading}.
 * @param {string=} select An expression to evaluate when the tab is selected.
 * @param {boolean=} active A binding, telling whether or not this tab is selected.
 * @param {boolean=} disabled A binding, telling whether or not this tab is disabled.
 *
 * @description
 * Creates a tab with a heading and content. Must be placed within a {@link ui.bootstrap.tabs.directive:tabset tabset}.
 *
 * @example
<example module="ui.bootstrap">
  <file name="index.html">
    <div ng-controller="TabsDemoCtrl">
      <button class="btn btn-small" ng-click="items[0].active = true">
        Select item 1, using active binding
      </button>
      <button class="btn btn-small" ng-click="items[1].disabled = !items[1].disabled">
        Enable/disable item 2, using disabled binding
      </button>
      <br />
      <tabset>
        <tab heading="Tab 1">First Tab</tab>
        <tab select="alertMe()">
          <tab-heading><i class="icon-bell"></i> Alert me!</tab-heading>
          Second Tab, with alert callback and html heading!
        </tab>
        <tab ng-repeat="item in items"
          heading="{{item.title}}"
          disabled="item.disabled"
          active="item.active">
          {{item.content}}
        </tab>
      </tabset>
    </div>
  </file>
  <file name="script.js">
    function TabsDemoCtrl($scope) {
      $scope.items = [
        { title:"Dynamic Title 1", content:"Dynamic Item 0" },
        { title:"Dynamic Title 2", content:"Dynamic Item 1", disabled: true }
      ];

      $scope.alertMe = function() {
        setTimeout(function() {
          alert("You've selected the alert tab!");
        });
      };
    };
  </file>
</example>
 */

/**
 * @ngdoc directive
 * @name ui.bootstrap.tabs.directive:tabHeading
 * @restrict EA
 *
 * @description
 * Creates an HTML heading for a {@link ui.bootstrap.tabs.directive:tab tab}. Must be placed as a child of a tab element.
 *
 * @example
<example module="ui.bootstrap">
  <file name="index.html">
    <tabset>
      <tab>
        <tab-heading><b>HTML</b> in my titles?!</tab-heading>
        And some content, too!
      </tab>
      <tab>
        <tab-heading><i class="icon-heart"></i> Icon heading?!?</tab-heading>
        That's right.
      </tab>
    </tabset>
  </file>
</example>
 */
.directive('tab', ['$parse', '$log', function($parse, $log) {
  return {
    require: '^tabset',
    restrict: 'EA',
    replace: true,
    templateUrl: 'template/tabs/tab.html',
    transclude: true,
    scope: {
      active: '=?',
      heading: '@',
      onSelect: '&select', //This callback is called in contentHeadingTransclude
                          //once it inserts the tab's content into the dom
      onDeselect: '&deselect'
    },
    controller: function() {
      //Empty controller so other directives can require being 'under' a tab
    },
    link: function(scope, elm, attrs, tabsetCtrl, transclude) {
      scope.$watch('active', function(active) {
        if (active) {
          tabsetCtrl.select(scope);
        }
      });

      scope.disabled = false;
      if (attrs.disable) {
        scope.$parent.$watch($parse(attrs.disable), function(value) {
          scope.disabled = !! value;
        });
      }

      // Deprecation support of "disabled" parameter
      // fix(tab): IE9 disabled attr renders grey text on enabled tab #2677
      // This code is duplicated from the lines above to make it easy to remove once
      // the feature has been completely deprecated
      if (attrs.disabled) {
        $log.warn('Use of "disabled" attribute has been deprecated, please use "disable"');
        scope.$parent.$watch($parse(attrs.disabled), function(value) {
          scope.disabled = !! value;
        });
      }

      scope.select = function() {
        if (!scope.disabled) {
          scope.active = true;
        }
      };

      tabsetCtrl.addTab(scope);
      scope.$on('$destroy', function() {
        tabsetCtrl.removeTab(scope);
      });

      //We need to transclude later, once the content container is ready.
      //when this link happens, we're inside a tab heading.
      scope.$transcludeFn = transclude;
    }
  };
}])

.directive('tabHeadingTransclude', function() {
  return {
    restrict: 'A',
    require: '^tab',
    link: function(scope, elm, attrs, tabCtrl) {
      scope.$watch('headingElement', function updateHeadingElement(heading) {
        if (heading) {
          elm.html('');
          elm.append(heading);
        }
      });
    }
  };
})

.directive('tabContentTransclude', function() {
  return {
    restrict: 'A',
    require: '^tabset',
    link: function(scope, elm, attrs) {
      var tab = scope.$eval(attrs.tabContentTransclude);

      //Now our tab is ready to be transcluded: both the tab heading area
      //and the tab content area are loaded.  Transclude 'em both.
      tab.$transcludeFn(tab.$parent, function(contents) {
        angular.forEach(contents, function(node) {
          if (isTabHeading(node)) {
            //Let tabHeadingTransclude know.
            tab.headingElement = node;
          } else {
            elm.append(node);
          }
        });
      });
    }
  };

  function isTabHeading(node) {
    return node.tagName && (
      node.hasAttribute('tab-heading') ||
      node.hasAttribute('data-tab-heading') ||
      node.hasAttribute('x-tab-heading') ||
      node.tagName.toLowerCase() === 'tab-heading' ||
      node.tagName.toLowerCase() === 'data-tab-heading' ||
      node.tagName.toLowerCase() === 'x-tab-heading'
    );
  }
});

angular.module('ui.bootstrap.timepicker', [])

.constant('timepickerConfig', {
  hourStep: 1,
  minuteStep: 1,
  showMeridian: true,
  meridians: null,
  readonlyInput: false,
  mousewheel: true,
  arrowkeys: true,
  showSpinners: true
})

.controller('TimepickerController', ['$scope', '$attrs', '$parse', '$log', '$locale', 'timepickerConfig', function($scope, $attrs, $parse, $log, $locale, timepickerConfig) {
  var selected = new Date(),
      ngModelCtrl = { $setViewValue: angular.noop }, // nullModelCtrl
      meridians = angular.isDefined($attrs.meridians) ? $scope.$parent.$eval($attrs.meridians) : timepickerConfig.meridians || $locale.DATETIME_FORMATS.AMPMS;

  this.init = function(ngModelCtrl_, inputs) {
    ngModelCtrl = ngModelCtrl_;
    ngModelCtrl.$render = this.render;

    ngModelCtrl.$formatters.unshift(function(modelValue) {
      return modelValue ? new Date(modelValue) : null;
    });

    var hoursInputEl = inputs.eq(0),
        minutesInputEl = inputs.eq(1);

    var mousewheel = angular.isDefined($attrs.mousewheel) ? $scope.$parent.$eval($attrs.mousewheel) : timepickerConfig.mousewheel;
    if (mousewheel) {
      this.setupMousewheelEvents(hoursInputEl, minutesInputEl);
    }

    var arrowkeys = angular.isDefined($attrs.arrowkeys) ? $scope.$parent.$eval($attrs.arrowkeys) : timepickerConfig.arrowkeys;
    if (arrowkeys) {
      this.setupArrowkeyEvents(hoursInputEl, minutesInputEl);
    }

    $scope.readonlyInput = angular.isDefined($attrs.readonlyInput) ? $scope.$parent.$eval($attrs.readonlyInput) : timepickerConfig.readonlyInput;
    this.setupInputEvents(hoursInputEl, minutesInputEl);
  };

  var hourStep = timepickerConfig.hourStep;
  if ($attrs.hourStep) {
    $scope.$parent.$watch($parse($attrs.hourStep), function(value) {
      hourStep = parseInt(value, 10);
    });
  }

  var minuteStep = timepickerConfig.minuteStep;
  if ($attrs.minuteStep) {
    $scope.$parent.$watch($parse($attrs.minuteStep), function(value) {
      minuteStep = parseInt(value, 10);
    });
  }

  var min;
  $scope.$parent.$watch($parse($attrs.min), function(value) {
    var dt = new Date(value);
    min = isNaN(dt) ? undefined : dt;
  });

  var max;
  $scope.$parent.$watch($parse($attrs.max), function(value) {
    var dt = new Date(value);
    max = isNaN(dt) ? undefined : dt;
  });

  $scope.noIncrementHours = function() {
    var incrementedSelected = addMinutes(selected, hourStep * 60);
    return incrementedSelected > max ||
      (incrementedSelected < selected && incrementedSelected < min);
  };

  $scope.noDecrementHours = function() {
    var decrementedSelected = addMinutes(selected, -hourStep * 60);
    return decrementedSelected < min ||
      (decrementedSelected > selected && decrementedSelected > max);
  };

  $scope.noIncrementMinutes = function() {
    var incrementedSelected = addMinutes(selected, minuteStep);
    return incrementedSelected > max ||
      (incrementedSelected < selected && incrementedSelected < min);
  };

  $scope.noDecrementMinutes = function() {
    var decrementedSelected = addMinutes(selected, -minuteStep);
    return decrementedSelected < min ||
      (decrementedSelected > selected && decrementedSelected > max);
  };

  $scope.noToggleMeridian = function() {
    if (selected.getHours() < 13) {
      return addMinutes(selected, 12 * 60) > max;
    } else {
      return addMinutes(selected, -12 * 60) < min;
    }
  };

  // 12H / 24H mode
  $scope.showMeridian = timepickerConfig.showMeridian;
  if ($attrs.showMeridian) {
    $scope.$parent.$watch($parse($attrs.showMeridian), function(value) {
      $scope.showMeridian = !!value;

      if (ngModelCtrl.$error.time) {
        // Evaluate from template
        var hours = getHoursFromTemplate(), minutes = getMinutesFromTemplate();
        if (angular.isDefined(hours) && angular.isDefined(minutes)) {
          selected.setHours(hours);
          refresh();
        }
      } else {
        updateTemplate();
      }
    });
  }

  // Get $scope.hours in 24H mode if valid
  function getHoursFromTemplate() {
    var hours = parseInt($scope.hours, 10);
    var valid = $scope.showMeridian ? (hours > 0 && hours < 13) : (hours >= 0 && hours < 24);
    if (!valid) {
      return undefined;
    }

    if ($scope.showMeridian) {
      if (hours === 12) {
        hours = 0;
      }
      if ($scope.meridian === meridians[1]) {
        hours = hours + 12;
      }
    }
    return hours;
  }

  function getMinutesFromTemplate() {
    var minutes = parseInt($scope.minutes, 10);
    return (minutes >= 0 && minutes < 60) ? minutes : undefined;
  }

  function pad(value) {
    return (angular.isDefined(value) && value.toString().length < 2) ? '0' + value : value.toString();
  }

  // Respond on mousewheel spin
  this.setupMousewheelEvents = function(hoursInputEl, minutesInputEl) {
    var isScrollingUp = function(e) {
      if (e.originalEvent) {
        e = e.originalEvent;
      }
      //pick correct delta variable depending on event
      var delta = (e.wheelDelta) ? e.wheelDelta : -e.deltaY;
      return (e.detail || delta > 0);
    };

    hoursInputEl.bind('mousewheel wheel', function(e) {
      $scope.$apply(isScrollingUp(e) ? $scope.incrementHours() : $scope.decrementHours());
      e.preventDefault();
    });

    minutesInputEl.bind('mousewheel wheel', function(e) {
      $scope.$apply(isScrollingUp(e) ? $scope.incrementMinutes() : $scope.decrementMinutes());
      e.preventDefault();
    });

  };

  // Respond on up/down arrowkeys
  this.setupArrowkeyEvents = function(hoursInputEl, minutesInputEl) {
    hoursInputEl.bind('keydown', function(e) {
      if (e.which === 38) { // up
        e.preventDefault();
        $scope.incrementHours();
        $scope.$apply();
      } else if (e.which === 40) { // down
        e.preventDefault();
        $scope.decrementHours();
        $scope.$apply();
      }
    });

    minutesInputEl.bind('keydown', function(e) {
      if (e.which === 38) { // up
        e.preventDefault();
        $scope.incrementMinutes();
        $scope.$apply();
      } else if (e.which === 40) { // down
        e.preventDefault();
        $scope.decrementMinutes();
        $scope.$apply();
      }
    });
  };

  this.setupInputEvents = function(hoursInputEl, minutesInputEl) {
    if ($scope.readonlyInput) {
      $scope.updateHours = angular.noop;
      $scope.updateMinutes = angular.noop;
      return;
    }

    var invalidate = function(invalidHours, invalidMinutes) {
      ngModelCtrl.$setViewValue(null);
      ngModelCtrl.$setValidity('time', false);
      if (angular.isDefined(invalidHours)) {
        $scope.invalidHours = invalidHours;
      }
      if (angular.isDefined(invalidMinutes)) {
        $scope.invalidMinutes = invalidMinutes;
      }
    };

    $scope.updateHours = function() {
      var hours = getHoursFromTemplate(),
        minutes = getMinutesFromTemplate();

      if (angular.isDefined(hours) && angular.isDefined(minutes)) {
        selected.setHours(hours);
        if (selected < min || selected > max) {
          invalidate(true);
        } else {
          refresh('h');
        }
      } else {
        invalidate(true);
      }
    };

    hoursInputEl.bind('blur', function(e) {
      if (!$scope.invalidHours && $scope.hours < 10) {
        $scope.$apply(function() {
          $scope.hours = pad($scope.hours);
        });
      }
    });

    $scope.updateMinutes = function() {
      var minutes = getMinutesFromTemplate(),
        hours = getHoursFromTemplate();

      if (angular.isDefined(minutes) && angular.isDefined(hours)) {
        selected.setMinutes(minutes);
        if (selected < min || selected > max) {
          invalidate(undefined, true);
        } else {
          refresh('m');
        }
      } else {
        invalidate(undefined, true);
      }
    };

    minutesInputEl.bind('blur', function(e) {
      if (!$scope.invalidMinutes && $scope.minutes < 10) {
        $scope.$apply(function() {
          $scope.minutes = pad($scope.minutes);
        });
      }
    });

  };

  this.render = function() {
    var date = ngModelCtrl.$viewValue;

    if (isNaN(date)) {
      ngModelCtrl.$setValidity('time', false);
      $log.error('Timepicker directive: "ng-model" value must be a Date object, a number of milliseconds since 01.01.1970 or a string representing an RFC2822 or ISO 8601 date.');
    } else {
      if (date) {
        selected = date;
      }

      if (selected < min || selected > max) {
        ngModelCtrl.$setValidity('time', false);
        $scope.invalidHours = true;
        $scope.invalidMinutes = true;
      } else {
        makeValid();
      }
      updateTemplate();
    }
  };

  // Call internally when we know that model is valid.
  function refresh(keyboardChange) {
    makeValid();
    ngModelCtrl.$setViewValue(new Date(selected));
    updateTemplate(keyboardChange);
  }

  function makeValid() {
    ngModelCtrl.$setValidity('time', true);
    $scope.invalidHours = false;
    $scope.invalidMinutes = false;
  }

  function updateTemplate(keyboardChange) {
    var hours = selected.getHours(), minutes = selected.getMinutes();

    if ($scope.showMeridian) {
      hours = (hours === 0 || hours === 12) ? 12 : hours % 12; // Convert 24 to 12 hour system
    }

    $scope.hours = keyboardChange === 'h' ? hours : pad(hours);
    if (keyboardChange !== 'm') {
      $scope.minutes = pad(minutes);
    }
    $scope.meridian = selected.getHours() < 12 ? meridians[0] : meridians[1];
  }

  function addMinutes(date, minutes) {
    var dt = new Date(date.getTime() + minutes * 60000);
    var newDate = new Date(date);
    newDate.setHours(dt.getHours(), dt.getMinutes());
    return newDate;
  }

  function addMinutesToSelected(minutes) {
    selected = addMinutes(selected, minutes);
    refresh();
  }

  $scope.showSpinners = angular.isDefined($attrs.showSpinners) ?
    $scope.$parent.$eval($attrs.showSpinners) : timepickerConfig.showSpinners;

  $scope.incrementHours = function() {
    if (!$scope.noIncrementHours()) {
      addMinutesToSelected(hourStep * 60);
    }
  };

  $scope.decrementHours = function() {
    if (!$scope.noDecrementHours()) {
      addMinutesToSelected(-hourStep * 60);
    }
  };

  $scope.incrementMinutes = function() {
    if (!$scope.noIncrementMinutes()) {
      addMinutesToSelected(minuteStep);
    }
  };

  $scope.decrementMinutes = function() {
    if (!$scope.noDecrementMinutes()) {
      addMinutesToSelected(-minuteStep);
    }
  };

  $scope.toggleMeridian = function() {
    if (!$scope.noToggleMeridian()) {
      addMinutesToSelected(12 * 60 * (selected.getHours() < 12 ? 1 : -1));
    }
  };
}])

.directive('timepicker', function() {
  return {
    restrict: 'EA',
    require: ['timepicker', '?^ngModel'],
    controller:'TimepickerController',
    controllerAs: 'timepicker',
    replace: true,
    scope: {},
    templateUrl: function(element, attrs) {
      return attrs.templateUrl || 'template/timepicker/timepicker.html';
    },
    link: function(scope, element, attrs, ctrls) {
      var timepickerCtrl = ctrls[0], ngModelCtrl = ctrls[1];

      if (ngModelCtrl) {
        timepickerCtrl.init(ngModelCtrl, element.find('input'));
      }
    }
  };
});

angular.module('ui.bootstrap.transition', [])

.value('$transitionSuppressDeprecated', false)
/**
 * $transition service provides a consistent interface to trigger CSS 3 transitions and to be informed when they complete.
 * @param  {DOMElement} element  The DOMElement that will be animated.
 * @param  {string|object|function} trigger  The thing that will cause the transition to start:
 *   - As a string, it represents the css class to be added to the element.
 *   - As an object, it represents a hash of style attributes to be applied to the element.
 *   - As a function, it represents a function to be called that will cause the transition to occur.
 * @return {Promise}  A promise that is resolved when the transition finishes.
 */
.factory('$transition', [
        '$q', '$timeout', '$rootScope', '$log', '$transitionSuppressDeprecated',
function($q ,  $timeout ,  $rootScope ,  $log ,  $transitionSuppressDeprecated) {

  if (!$transitionSuppressDeprecated) {
    $log.warn('$transition is now deprecated. Use $animate from ngAnimate instead.');
  }

  var $transition = function(element, trigger, options) {
    options = options || {};
    var deferred = $q.defer();
    var endEventName = $transition[options.animation ? 'animationEndEventName' : 'transitionEndEventName'];

    var transitionEndHandler = function(event) {
      $rootScope.$apply(function() {
        element.unbind(endEventName, transitionEndHandler);
        deferred.resolve(element);
      });
    };

    if (endEventName) {
      element.bind(endEventName, transitionEndHandler);
    }

    // Wrap in a timeout to allow the browser time to update the DOM before the transition is to occur
    $timeout(function() {
      if ( angular.isString(trigger) ) {
        element.addClass(trigger);
      } else if ( angular.isFunction(trigger) ) {
        trigger(element);
      } else if ( angular.isObject(trigger) ) {
        element.css(trigger);
      }
      //If browser does not support transitions, instantly resolve
      if ( !endEventName ) {
        deferred.resolve(element);
      }
    });

    // Add our custom cancel function to the promise that is returned
    // We can call this if we are about to run a new transition, which we know will prevent this transition from ending,
    // i.e. it will therefore never raise a transitionEnd event for that transition
    deferred.promise.cancel = function() {
      if ( endEventName ) {
        element.unbind(endEventName, transitionEndHandler);
      }
      deferred.reject('Transition cancelled');
    };

    return deferred.promise;
  };

  // Work out the name of the transitionEnd event
  var transElement = document.createElement('trans');
  var transitionEndEventNames = {
    'WebkitTransition': 'webkitTransitionEnd',
    'MozTransition': 'transitionend',
    'OTransition': 'oTransitionEnd',
    'transition': 'transitionend'
  };
  var animationEndEventNames = {
    'WebkitTransition': 'webkitAnimationEnd',
    'MozTransition': 'animationend',
    'OTransition': 'oAnimationEnd',
    'transition': 'animationend'
  };
  function findEndEventName(endEventNames) {
    for (var name in endEventNames){
      if (transElement.style[name] !== undefined) {
        return endEventNames[name];
      }
    }
  }
  $transition.transitionEndEventName = findEndEventName(transitionEndEventNames);
  $transition.animationEndEventName = findEndEventName(animationEndEventNames);
  return $transition;
}]);

angular.module('ui.bootstrap.typeahead', ['ui.bootstrap.position'])

/**
 * A helper service that can parse typeahead's syntax (string provided by users)
 * Extracted to a separate service for ease of unit testing
 */
  .factory('typeaheadParser', ['$parse', function($parse) {

  //                      00000111000000000000022200000000000000003333333333333330000000000044000
  var TYPEAHEAD_REGEXP = /^\s*([\s\S]+?)(?:\s+as\s+([\s\S]+?))?\s+for\s+(?:([\$\w][\$\w\d]*))\s+in\s+([\s\S]+?)$/;

  return {
    parse: function(input) {
      var match = input.match(TYPEAHEAD_REGEXP);
      if (!match) {
        throw new Error(
          'Expected typeahead specification in form of "_modelValue_ (as _label_)? for _item_ in _collection_"' +
            ' but got "' + input + '".');
      }

      return {
        itemName:match[3],
        source:$parse(match[4]),
        viewMapper:$parse(match[2] || match[1]),
        modelMapper:$parse(match[1])
      };
    }
  };
}])

  .directive('typeahead', ['$compile', '$parse', '$q', '$timeout', '$document', '$window', '$rootScope', '$position', 'typeaheadParser',
    function($compile, $parse, $q, $timeout, $document, $window, $rootScope, $position, typeaheadParser) {
    var HOT_KEYS = [9, 13, 27, 38, 40];
    var eventDebounceTime = 200;

    return {
      require: ['ngModel', '^?ngModelOptions'],
      link: function(originalScope, element, attrs, ctrls) {
        var modelCtrl = ctrls[0];
        var ngModelOptions = ctrls[1];
        //SUPPORTED ATTRIBUTES (OPTIONS)

        //minimal no of characters that needs to be entered before typeahead kicks-in
        var minLength = originalScope.$eval(attrs.typeaheadMinLength);
        if (!minLength && minLength !== 0) {
          minLength = 1;
        }

        //minimal wait time after last character typed before typeahead kicks-in
        var waitTime = originalScope.$eval(attrs.typeaheadWaitMs) || 0;

        //should it restrict model values to the ones selected from the popup only?
        var isEditable = originalScope.$eval(attrs.typeaheadEditable) !== false;

        //binding to a variable that indicates if matches are being retrieved asynchronously
        var isLoadingSetter = $parse(attrs.typeaheadLoading).assign || angular.noop;

        //a callback executed when a match is selected
        var onSelectCallback = $parse(attrs.typeaheadOnSelect);

        //should it select highlighted popup value when losing focus?
        var isSelectOnBlur = angular.isDefined(attrs.typeaheadSelectOnBlur) ? originalScope.$eval(attrs.typeaheadSelectOnBlur) : false;

        //binding to a variable that indicates if there were no results after the query is completed
        var isNoResultsSetter = $parse(attrs.typeaheadNoResults).assign || angular.noop;

        var inputFormatter = attrs.typeaheadInputFormatter ? $parse(attrs.typeaheadInputFormatter) : undefined;

        var appendToBody =  attrs.typeaheadAppendToBody ? originalScope.$eval(attrs.typeaheadAppendToBody) : false;

        var focusFirst = originalScope.$eval(attrs.typeaheadFocusFirst) !== false;

        //If input matches an item of the list exactly, select it automatically
        var selectOnExact = attrs.typeaheadSelectOnExact ? originalScope.$eval(attrs.typeaheadSelectOnExact) : false;

        //INTERNAL VARIABLES

        //model setter executed upon match selection
        var parsedModel = $parse(attrs.ngModel);
        var invokeModelSetter = $parse(attrs.ngModel + '($$$p)');
        var $setModelValue = function(scope, newValue) {
          if (angular.isFunction(parsedModel(originalScope)) &&
            ngModelOptions && ngModelOptions.$options && ngModelOptions.$options.getterSetter) {
            return invokeModelSetter(scope, {$$$p: newValue});
          } else {
            return parsedModel.assign(scope, newValue);
          }
        };

        //expressions used by typeahead
        var parserResult = typeaheadParser.parse(attrs.typeahead);

        var hasFocus;

        //Used to avoid bug in iOS webview where iOS keyboard does not fire
        //mousedown & mouseup events
        //Issue #3699
        var selected;

        //create a child scope for the typeahead directive so we are not polluting original scope
        //with typeahead-specific data (matches, query etc.)
        var scope = originalScope.$new();
        var offDestroy = originalScope.$on('$destroy', function() {
			    scope.$destroy();
        });
        scope.$on('$destroy', offDestroy);

        // WAI-ARIA
        var popupId = 'typeahead-' + scope.$id + '-' + Math.floor(Math.random() * 10000);
        element.attr({
          'aria-autocomplete': 'list',
          'aria-expanded': false,
          'aria-owns': popupId
        });

        //pop-up element used to display matches
        var popUpEl = angular.element('<div typeahead-popup></div>');
        popUpEl.attr({
          id: popupId,
          matches: 'matches',
          active: 'activeIdx',
          select: 'select(activeIdx)',
          'move-in-progress': 'moveInProgress',
          query: 'query',
          position: 'position'
        });
        //custom item template
        if (angular.isDefined(attrs.typeaheadTemplateUrl)) {
          popUpEl.attr('template-url', attrs.typeaheadTemplateUrl);
        }

        if (angular.isDefined(attrs.typeaheadPopupTemplateUrl)) {
          popUpEl.attr('popup-template-url', attrs.typeaheadPopupTemplateUrl);
        }

        var resetMatches = function() {
          scope.matches = [];
          scope.activeIdx = -1;
          element.attr('aria-expanded', false);
        };

        var getMatchId = function(index) {
          return popupId + '-option-' + index;
        };

        // Indicate that the specified match is the active (pre-selected) item in the list owned by this typeahead.
        // This attribute is added or removed automatically when the `activeIdx` changes.
        scope.$watch('activeIdx', function(index) {
          if (index < 0) {
            element.removeAttr('aria-activedescendant');
          } else {
            element.attr('aria-activedescendant', getMatchId(index));
          }
        });

        var inputIsExactMatch = function(inputValue, index) {
          if (scope.matches.length > index && inputValue) {
            return inputValue.toUpperCase() === scope.matches[index].label.toUpperCase();
          }

          return false;
        };

        var getMatchesAsync = function(inputValue) {
          var locals = {$viewValue: inputValue};
          isLoadingSetter(originalScope, true);
          isNoResultsSetter(originalScope, false);
          $q.when(parserResult.source(originalScope, locals)).then(function(matches) {
            //it might happen that several async queries were in progress if a user were typing fast
            //but we are interested only in responses that correspond to the current view value
            var onCurrentRequest = (inputValue === modelCtrl.$viewValue);
            if (onCurrentRequest && hasFocus) {
              if (matches && matches.length > 0) {

                scope.activeIdx = focusFirst ? 0 : -1;
                isNoResultsSetter(originalScope, false);
                scope.matches.length = 0;

                //transform labels
                for (var i = 0; i < matches.length; i++) {
                  locals[parserResult.itemName] = matches[i];
                  scope.matches.push({
                    id: getMatchId(i),
                    label: parserResult.viewMapper(scope, locals),
                    model: matches[i]
                  });
                }

                scope.query = inputValue;
                //position pop-up with matches - we need to re-calculate its position each time we are opening a window
                //with matches as a pop-up might be absolute-positioned and position of an input might have changed on a page
                //due to other elements being rendered
                recalculatePosition();

                element.attr('aria-expanded', true);

                //Select the single remaining option if user input matches
                if (selectOnExact && scope.matches.length === 1 && inputIsExactMatch(inputValue, 0)) {
                  scope.select(0);
                }
              } else {
                resetMatches();
                isNoResultsSetter(originalScope, true);
              }
            }
            if (onCurrentRequest) {
              isLoadingSetter(originalScope, false);
            }
          }, function() {
            resetMatches();
            isLoadingSetter(originalScope, false);
            isNoResultsSetter(originalScope, true);
          });
        };

        // bind events only if appendToBody params exist - performance feature
        if (appendToBody) {
          angular.element($window).bind('resize', fireRecalculating);
          $document.find('body').bind('scroll', fireRecalculating);
        }

        // Declare the timeout promise var outside the function scope so that stacked calls can be cancelled later
        var timeoutEventPromise;

        // Default progress type
        scope.moveInProgress = false;

        function fireRecalculating() {
          if (!scope.moveInProgress) {
            scope.moveInProgress = true;
            scope.$digest();
          }

          // Cancel previous timeout
          if (timeoutEventPromise) {
            $timeout.cancel(timeoutEventPromise);
          }

          // Debounced executing recalculate after events fired
          timeoutEventPromise = $timeout(function() {
            // if popup is visible
            if (scope.matches.length) {
              recalculatePosition();
            }

            scope.moveInProgress = false;
            scope.$digest();
          }, eventDebounceTime);
        }

        // recalculate actual position and set new values to scope
        // after digest loop is popup in right position
        function recalculatePosition() {
          scope.position = appendToBody ? $position.offset(element) : $position.position(element);
          scope.position.top += element.prop('offsetHeight');
        }

        resetMatches();

        //we need to propagate user's query so we can higlight matches
        scope.query = undefined;

        //Declare the timeout promise var outside the function scope so that stacked calls can be cancelled later
        var timeoutPromise;

        var scheduleSearchWithTimeout = function(inputValue) {
          timeoutPromise = $timeout(function() {
            getMatchesAsync(inputValue);
          }, waitTime);
        };

        var cancelPreviousTimeout = function() {
          if (timeoutPromise) {
            $timeout.cancel(timeoutPromise);
          }
        };

        //plug into $parsers pipeline to open a typeahead on view changes initiated from DOM
        //$parsers kick-in on all the changes coming from the view as well as manually triggered by $setViewValue
        modelCtrl.$parsers.unshift(function(inputValue) {
          hasFocus = true;

          if (minLength === 0 || inputValue && inputValue.length >= minLength) {
            if (waitTime > 0) {
              cancelPreviousTimeout();
              scheduleSearchWithTimeout(inputValue);
            } else {
              getMatchesAsync(inputValue);
            }
          } else {
            isLoadingSetter(originalScope, false);
            cancelPreviousTimeout();
            resetMatches();
          }

          if (isEditable) {
            return inputValue;
          } else {
            if (!inputValue) {
              // Reset in case user had typed something previously.
              modelCtrl.$setValidity('editable', true);
              return null;
            } else {
              modelCtrl.$setValidity('editable', false);
              return undefined;
            }
          }
        });

        modelCtrl.$formatters.push(function(modelValue) {
          var candidateViewValue, emptyViewValue;
          var locals = {};

          // The validity may be set to false via $parsers (see above) if
          // the model is restricted to selected values. If the model
          // is set manually it is considered to be valid.
          if (!isEditable) {
            modelCtrl.$setValidity('editable', true);
          }

          if (inputFormatter) {
            locals.$model = modelValue;
            return inputFormatter(originalScope, locals);
          } else {
            //it might happen that we don't have enough info to properly render input value
            //we need to check for this situation and simply return model value if we can't apply custom formatting
            locals[parserResult.itemName] = modelValue;
            candidateViewValue = parserResult.viewMapper(originalScope, locals);
            locals[parserResult.itemName] = undefined;
            emptyViewValue = parserResult.viewMapper(originalScope, locals);

            return candidateViewValue!== emptyViewValue ? candidateViewValue : modelValue;
          }
        });

        scope.select = function(activeIdx) {
          //called from within the $digest() cycle
          var locals = {};
          var model, item;

          selected = true;
          locals[parserResult.itemName] = item = scope.matches[activeIdx].model;
          model = parserResult.modelMapper(originalScope, locals);
          $setModelValue(originalScope, model);
          modelCtrl.$setValidity('editable', true);
          modelCtrl.$setValidity('parse', true);

          onSelectCallback(originalScope, {
            $item: item,
            $model: model,
            $label: parserResult.viewMapper(originalScope, locals)
          });

          resetMatches();

          //return focus to the input element if a match was selected via a mouse click event
          // use timeout to avoid $rootScope:inprog error
          if (scope.$eval(attrs.typeaheadFocusOnSelect) !== false) {
            $timeout(function() { element[0].focus(); }, 0, false);
          }
        };

        //bind keyboard events: arrows up(38) / down(40), enter(13) and tab(9), esc(27)
        element.bind('keydown', function(evt) {
          //typeahead is open and an "interesting" key was pressed
          if (scope.matches.length === 0 || HOT_KEYS.indexOf(evt.which) === -1) {
            return;
          }

          // if there's nothing selected (i.e. focusFirst) and enter or tab is hit, clear the results
          if (scope.activeIdx === -1 && (evt.which === 9 || evt.which === 13)) {
            resetMatches();
            scope.$digest();
            return;
          }

          evt.preventDefault();

          if (evt.which === 40) {
            scope.activeIdx = (scope.activeIdx + 1) % scope.matches.length;
            scope.$digest();

          } else if (evt.which === 38) {
            scope.activeIdx = (scope.activeIdx > 0 ? scope.activeIdx : scope.matches.length) - 1;
            scope.$digest();

          } else if (evt.which === 13 || evt.which === 9) {
            scope.$apply(function () {
              scope.select(scope.activeIdx);
            });

          } else if (evt.which === 27) {
            evt.stopPropagation();

            resetMatches();
            scope.$digest();
          }
        });

        element.bind('blur', function() {
          if (isSelectOnBlur && scope.matches.length && scope.activeIdx !== -1 && !selected) {
            selected = true;
            scope.$apply(function() {
              scope.select(scope.activeIdx);
            });
          }
          hasFocus = false;
          selected = false;
        });

        // Keep reference to click handler to unbind it.
        var dismissClickHandler = function(evt) {
          // Issue #3973
          // Firefox treats right click as a click on document
          if (element[0] !== evt.target && evt.which !== 3 && scope.matches.length !== 0) {
            resetMatches();
            if (!$rootScope.$$phase) {
              scope.$digest();
            }
          }
        };

        $document.bind('click', dismissClickHandler);

        originalScope.$on('$destroy', function() {
          $document.unbind('click', dismissClickHandler);
          if (appendToBody) {
            $popup.remove();
          }
          // Prevent jQuery cache memory leak
          popUpEl.remove();
        });

        var $popup = $compile(popUpEl)(scope);

        if (appendToBody) {
          $document.find('body').append($popup);
        } else {
          element.after($popup);
        }
      }
    };

  }])

  .directive('typeaheadPopup', function() {
    return {
      restrict: 'EA',
      scope: {
        matches: '=',
        query: '=',
        active: '=',
        position: '&',
        moveInProgress: '=',
        select: '&'
      },
      replace: true,
      templateUrl: function(element, attrs) {
        return attrs.popupTemplateUrl || 'template/typeahead/typeahead-popup.html';
      },
      link: function(scope, element, attrs) {
        scope.templateUrl = attrs.templateUrl;

        scope.isOpen = function() {
          return scope.matches.length > 0;
        };

        scope.isActive = function(matchIdx) {
          return scope.active == matchIdx;
        };

        scope.selectActive = function(matchIdx) {
          scope.active = matchIdx;
        };

        scope.selectMatch = function(activeIdx) {
          scope.select({activeIdx:activeIdx});
        };
      }
    };
  })

  .directive('typeaheadMatch', ['$templateRequest', '$compile', '$parse', function($templateRequest, $compile, $parse) {
    return {
      restrict: 'EA',
      scope: {
        index: '=',
        match: '=',
        query: '='
      },
      link:function(scope, element, attrs) {
        var tplUrl = $parse(attrs.templateUrl)(scope.$parent) || 'template/typeahead/typeahead-match.html';
        $templateRequest(tplUrl).then(function(tplContent) {
          $compile(tplContent.trim())(scope, function(clonedElement) {
            element.replaceWith(clonedElement);
          });
        });
      }
    };
  }])

  .filter('typeaheadHighlight', ['$sce', '$injector', '$log', function($sce, $injector, $log) {
    var isSanitizePresent;
    isSanitizePresent = $injector.has('$sanitize');

    function escapeRegexp(queryToEscape) {
      // Regex: capture the whole query string and replace it with the string that will be used to match
      // the results, for example if the capture is "a" the result will be \a
      return queryToEscape.replace(/([.?*+^$[\]\\(){}|-])/g, '\\$1');
    }

    function containsHtml(matchItem) {
      return /<.*>/g.test(matchItem);
    }

    return function(matchItem, query) {
      if (!isSanitizePresent && containsHtml(matchItem)) {
        $log.warn('Unsafe use of typeahead please use ngSanitize'); // Warn the user about the danger
      }
      matchItem = query? ('' + matchItem).replace(new RegExp(escapeRegexp(query), 'gi'), '<strong>$&</strong>') : matchItem; // Replaces the capture string with a the same string inside of a "strong" tag
      if (!isSanitizePresent) {
        matchItem = $sce.trustAsHtml(matchItem); // If $sanitize is not present we pack the string in a $sce object for the ng-bind-html directive
      }
      return matchItem;
    };
  }]);

angular.module("template/accordion/accordion-group.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/accordion/accordion-group.html",
    "<div class=\"panel {{panelClass || 'panel-default'}}\">\n" +
    "  <div class=\"panel-heading\" ng-keypress=\"toggleOpen($event)\">\n" +
    "    <h4 class=\"panel-title\">\n" +
    "      <a href tabindex=\"0\" class=\"accordion-toggle\" ng-click=\"toggleOpen()\" accordion-transclude=\"heading\"><span ng-class=\"{'text-muted': isDisabled}\">{{heading}}</span></a>\n" +
    "    </h4>\n" +
    "  </div>\n" +
    "  <div class=\"panel-collapse collapse\" collapse=\"!isOpen\">\n" +
    "	  <div class=\"panel-body\" ng-transclude></div>\n" +
    "  </div>\n" +
    "</div>\n" +
    "");
}]);

angular.module("template/accordion/accordion.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/accordion/accordion.html",
    "<div class=\"panel-group\" ng-transclude></div>");
}]);

angular.module("template/alert/alert.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/alert/alert.html",
    "<div class=\"alert\" ng-class=\"['alert-' + (type || 'warning'), closeable ? 'alert-dismissible' : null]\" role=\"alert\">\n" +
    "    <button ng-show=\"closeable\" type=\"button\" class=\"close\" ng-click=\"close($event)\">\n" +
    "        <span aria-hidden=\"true\">&times;</span>\n" +
    "        <span class=\"sr-only\">Close</span>\n" +
    "    </button>\n" +
    "    <div ng-transclude></div>\n" +
    "</div>\n" +
    "");
}]);

angular.module("template/carousel/carousel.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/carousel/carousel.html",
    "<div ng-mouseenter=\"pause()\" ng-mouseleave=\"play()\" class=\"carousel\" ng-swipe-right=\"prev()\" ng-swipe-left=\"next()\">\n" +
    "    <ol class=\"carousel-indicators\" ng-show=\"slides.length > 1\">\n" +
    "        <li ng-repeat=\"slide in slides | orderBy:indexOfSlide track by $index\" ng-class=\"{active: isActive(slide)}\" ng-click=\"select(slide)\"></li>\n" +
    "    </ol>\n" +
    "    <div class=\"carousel-inner\" ng-transclude></div>\n" +
    "    <a class=\"left carousel-control\" ng-click=\"prev()\" ng-show=\"slides.length > 1\"><span class=\"glyphicon glyphicon-chevron-left\"></span></a>\n" +
    "    <a class=\"right carousel-control\" ng-click=\"next()\" ng-show=\"slides.length > 1\"><span class=\"glyphicon glyphicon-chevron-right\"></span></a>\n" +
    "</div>\n" +
    "");
}]);

angular.module("template/carousel/slide.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/carousel/slide.html",
    "<div ng-class=\"{\n" +
    "    'active': active\n" +
    "  }\" class=\"item text-center\" ng-transclude></div>\n" +
    "");
}]);

angular.module("template/datepicker/datepicker.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/datepicker/datepicker.html",
    "<div ng-switch=\"datepickerMode\" role=\"application\" ng-keydown=\"keydown($event)\">\n" +
    "  <daypicker ng-switch-when=\"day\" tabindex=\"0\"></daypicker>\n" +
    "  <monthpicker ng-switch-when=\"month\" tabindex=\"0\"></monthpicker>\n" +
    "  <yearpicker ng-switch-when=\"year\" tabindex=\"0\"></yearpicker>\n" +
    "</div>");
}]);

angular.module("template/datepicker/day.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/datepicker/day.html",
    "<table role=\"grid\" aria-labelledby=\"{{::uniqueId}}-title\" aria-activedescendant=\"{{activeDateId}}\">\n" +
    "  <thead>\n" +
    "    <tr>\n" +
    "      <th><button type=\"button\" class=\"btn btn-default btn-sm pull-left\" ng-click=\"move(-1)\" tabindex=\"-1\"><i class=\"glyphicon glyphicon-chevron-left\"></i></button></th>\n" +
    "      <th colspan=\"{{::5 + showWeeks}}\"><button id=\"{{::uniqueId}}-title\" role=\"heading\" aria-live=\"assertive\" aria-atomic=\"true\" type=\"button\" class=\"btn btn-default btn-sm\" ng-click=\"toggleMode()\" ng-disabled=\"datepickerMode === maxMode\" tabindex=\"-1\" style=\"width:100%;\"><strong>{{title}}</strong></button></th>\n" +
    "      <th><button type=\"button\" class=\"btn btn-default btn-sm pull-right\" ng-click=\"move(1)\" tabindex=\"-1\"><i class=\"glyphicon glyphicon-chevron-right\"></i></button></th>\n" +
    "    </tr>\n" +
    "    <tr>\n" +
    "      <th ng-if=\"showWeeks\" class=\"text-center\"></th>\n" +
    "      <th ng-repeat=\"label in ::labels track by $index\" class=\"text-center\"><small aria-label=\"{{::label.full}}\">{{::label.abbr}}</small></th>\n" +
    "    </tr>\n" +
    "  </thead>\n" +
    "  <tbody>\n" +
    "    <tr ng-repeat=\"row in rows track by $index\">\n" +
    "      <td ng-if=\"showWeeks\" class=\"text-center h6\"><em>{{ weekNumbers[$index] }}</em></td>\n" +
    "      <td ng-repeat=\"dt in row track by dt.date\" class=\"text-center\" role=\"gridcell\" id=\"{{::dt.uid}}\" ng-class=\"::dt.customClass\">\n" +
    "        <button type=\"button\" style=\"min-width:100%;\" class=\"btn btn-default btn-sm\" ng-class=\"{'btn-info': dt.selected, active: isActive(dt)}\" ng-click=\"select(dt.date)\" ng-disabled=\"dt.disabled\" tabindex=\"-1\"><span ng-class=\"::{'text-muted': dt.secondary, 'text-info': dt.current}\">{{::dt.label}}</span></button>\n" +
    "      </td>\n" +
    "    </tr>\n" +
    "  </tbody>\n" +
    "</table>\n" +
    "");
}]);

angular.module("template/datepicker/month.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/datepicker/month.html",
    "<table role=\"grid\" aria-labelledby=\"{{::uniqueId}}-title\" aria-activedescendant=\"{{activeDateId}}\">\n" +
    "  <thead>\n" +
    "    <tr>\n" +
    "      <th><button type=\"button\" class=\"btn btn-default btn-sm pull-left\" ng-click=\"move(-1)\" tabindex=\"-1\"><i class=\"glyphicon glyphicon-chevron-left\"></i></button></th>\n" +
    "      <th><button id=\"{{::uniqueId}}-title\" role=\"heading\" aria-live=\"assertive\" aria-atomic=\"true\" type=\"button\" class=\"btn btn-default btn-sm\" ng-click=\"toggleMode()\" ng-disabled=\"datepickerMode === maxMode\" tabindex=\"-1\" style=\"width:100%;\"><strong>{{title}}</strong></button></th>\n" +
    "      <th><button type=\"button\" class=\"btn btn-default btn-sm pull-right\" ng-click=\"move(1)\" tabindex=\"-1\"><i class=\"glyphicon glyphicon-chevron-right\"></i></button></th>\n" +
    "    </tr>\n" +
    "  </thead>\n" +
    "  <tbody>\n" +
    "    <tr ng-repeat=\"row in rows track by $index\">\n" +
    "      <td ng-repeat=\"dt in row track by dt.date\" class=\"text-center\" role=\"gridcell\" id=\"{{::dt.uid}}\" ng-class=\"::dt.customClass\">\n" +
    "        <button type=\"button\" style=\"min-width:100%;\" class=\"btn btn-default\" ng-class=\"{'btn-info': dt.selected, active: isActive(dt)}\" ng-click=\"select(dt.date)\" ng-disabled=\"dt.disabled\" tabindex=\"-1\"><span ng-class=\"::{'text-info': dt.current}\">{{::dt.label}}</span></button>\n" +
    "      </td>\n" +
    "    </tr>\n" +
    "  </tbody>\n" +
    "</table>\n" +
    "");
}]);

angular.module("template/datepicker/popup.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/datepicker/popup.html",
    "<ul class=\"dropdown-menu\" ng-if=\"isOpen\" style=\"display: block\" ng-style=\"{top: position.top+'px', left: position.left+'px'}\" ng-keydown=\"keydown($event)\" ng-click=\"$event.stopPropagation()\">\n" +
    "	<li ng-transclude></li>\n" +
    "	<li ng-if=\"showButtonBar\" style=\"padding:10px 9px 2px\">\n" +
    "		<span class=\"btn-group pull-left\">\n" +
    "			<button type=\"button\" class=\"btn btn-sm btn-info\" ng-click=\"select('today')\" ng-disabled=\"isDisabled('today')\">{{ getText('current') }}</button>\n" +
    "			<button type=\"button\" class=\"btn btn-sm btn-danger\" ng-click=\"select(null)\">{{ getText('clear') }}</button>\n" +
    "		</span>\n" +
    "		<button type=\"button\" class=\"btn btn-sm btn-success pull-right\" ng-click=\"close()\">{{ getText('close') }}</button>\n" +
    "	</li>\n" +
    "</ul>\n" +
    "");
}]);

angular.module("template/datepicker/year.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/datepicker/year.html",
    "<table role=\"grid\" aria-labelledby=\"{{::uniqueId}}-title\" aria-activedescendant=\"{{activeDateId}}\">\n" +
    "  <thead>\n" +
    "    <tr>\n" +
    "      <th><button type=\"button\" class=\"btn btn-default btn-sm pull-left\" ng-click=\"move(-1)\" tabindex=\"-1\"><i class=\"glyphicon glyphicon-chevron-left\"></i></button></th>\n" +
    "      <th colspan=\"3\"><button id=\"{{::uniqueId}}-title\" role=\"heading\" aria-live=\"assertive\" aria-atomic=\"true\" type=\"button\" class=\"btn btn-default btn-sm\" ng-click=\"toggleMode()\" ng-disabled=\"datepickerMode === maxMode\" tabindex=\"-1\" style=\"width:100%;\"><strong>{{title}}</strong></button></th>\n" +
    "      <th><button type=\"button\" class=\"btn btn-default btn-sm pull-right\" ng-click=\"move(1)\" tabindex=\"-1\"><i class=\"glyphicon glyphicon-chevron-right\"></i></button></th>\n" +
    "    </tr>\n" +
    "  </thead>\n" +
    "  <tbody>\n" +
    "    <tr ng-repeat=\"row in rows track by $index\">\n" +
    "      <td ng-repeat=\"dt in row track by dt.date\" class=\"text-center\" role=\"gridcell\" id=\"{{::dt.uid}}\">\n" +
    "        <button type=\"button\" style=\"min-width:100%;\" class=\"btn btn-default\" ng-class=\"{'btn-info': dt.selected, active: isActive(dt)}\" ng-click=\"select(dt.date)\" ng-disabled=\"dt.disabled\" tabindex=\"-1\"><span ng-class=\"::{'text-info': dt.current}\">{{::dt.label}}</span></button>\n" +
    "      </td>\n" +
    "    </tr>\n" +
    "  </tbody>\n" +
    "</table>\n" +
    "");
}]);

angular.module("template/modal/backdrop.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/modal/backdrop.html",
    "<div class=\"modal-backdrop\"\n" +
    "     modal-animation-class=\"fade\"\n" +
    "     modal-in-class=\"in\"\n" +
    "     ng-style=\"{'z-index': 1040 + (index && 1 || 0) + index*10}\"\n" +
    "></div>\n" +
    "");
}]);

angular.module("template/modal/window.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/modal/window.html",
    "<div modal-render=\"{{$isRendered}}\" tabindex=\"-1\" role=\"dialog\" class=\"modal\"\n" +
    "    modal-animation-class=\"fade\"\n" +
    "    modal-in-class=\"in\"\n" +
    "	ng-style=\"{'z-index': 1050 + index*10, display: 'block'}\" ng-click=\"close($event)\">\n" +
    "    <div class=\"modal-dialog\" ng-class=\"size ? 'modal-' + size : ''\"><div class=\"modal-content\" modal-transclude></div></div>\n" +
    "</div>\n" +
    "");
}]);

angular.module("template/pagination/pager.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/pagination/pager.html",
    "<ul class=\"pager\">\n" +
    "  <li ng-class=\"{disabled: noPrevious()||ngDisabled, previous: align}\"><a href ng-click=\"selectPage(page - 1, $event)\">{{::getText('previous')}}</a></li>\n" +
    "  <li ng-class=\"{disabled: noNext()||ngDisabled, next: align}\"><a href ng-click=\"selectPage(page + 1, $event)\">{{::getText('next')}}</a></li>\n" +
    "</ul>\n" +
    "");
}]);

angular.module("template/pagination/pagination.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/pagination/pagination.html",
    "<ul class=\"pagination\">\n" +
    "  <li ng-if=\"::boundaryLinks\" ng-class=\"{disabled: noPrevious()||ngDisabled}\" class=\"pagination-first\"><a href ng-click=\"selectPage(1, $event)\">{{::getText('first')}}</a></li>\n" +
    "  <li ng-if=\"::directionLinks\" ng-class=\"{disabled: noPrevious()||ngDisabled}\" class=\"pagination-prev\"><a href ng-click=\"selectPage(page - 1, $event)\">{{::getText('previous')}}</a></li>\n" +
    "  <li ng-repeat=\"page in pages track by $index\" ng-class=\"{active: page.active,disabled: ngDisabled&&!page.active}\" class=\"pagination-page\"><a href ng-click=\"selectPage(page.number, $event)\">{{page.text}}</a></li>\n" +
    "  <li ng-if=\"::directionLinks\" ng-class=\"{disabled: noNext()||ngDisabled}\" class=\"pagination-next\"><a href ng-click=\"selectPage(page + 1, $event)\">{{::getText('next')}}</a></li>\n" +
    "  <li ng-if=\"::boundaryLinks\" ng-class=\"{disabled: noNext()||ngDisabled}\" class=\"pagination-last\"><a href ng-click=\"selectPage(totalPages, $event)\">{{::getText('last')}}</a></li>\n" +
    "</ul>\n" +
    "");
}]);

angular.module("template/tooltip/tooltip-html-popup.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/tooltip/tooltip-html-popup.html",
    "<div class=\"tooltip\"\n" +
    "  tooltip-animation-class=\"fade\"\n" +
    "  tooltip-classes\n" +
    "  ng-class=\"{ in: isOpen() }\">\n" +
    "  <div class=\"tooltip-arrow\"></div>\n" +
    "  <div class=\"tooltip-inner\" ng-bind-html=\"contentExp()\"></div>\n" +
    "</div>\n" +
    "");
}]);

angular.module("template/tooltip/tooltip-html-unsafe-popup.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/tooltip/tooltip-html-unsafe-popup.html",
    "<div class=\"tooltip\"\n" +
    "  tooltip-animation-class=\"fade\"\n" +
    "  tooltip-classes\n" +
    "  ng-class=\"{ in: isOpen() }\">\n" +
    "  <div class=\"tooltip-arrow\"></div>\n" +
    "  <div class=\"tooltip-inner\" bind-html-unsafe=\"content\"></div>\n" +
    "</div>\n" +
    "");
}]);

angular.module("template/tooltip/tooltip-popup.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/tooltip/tooltip-popup.html",
    "<div class=\"tooltip\"\n" +
    "  tooltip-animation-class=\"fade\"\n" +
    "  tooltip-classes\n" +
    "  ng-class=\"{ in: isOpen() }\">\n" +
    "  <div class=\"tooltip-arrow\"></div>\n" +
    "  <div class=\"tooltip-inner\" ng-bind=\"content\"></div>\n" +
    "</div>\n" +
    "");
}]);

angular.module("template/tooltip/tooltip-template-popup.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/tooltip/tooltip-template-popup.html",
    "<div class=\"tooltip\"\n" +
    "  tooltip-animation-class=\"fade\"\n" +
    "  tooltip-classes\n" +
    "  ng-class=\"{ in: isOpen() }\">\n" +
    "  <div class=\"tooltip-arrow\"></div>\n" +
    "  <div class=\"tooltip-inner\"\n" +
    "    tooltip-template-transclude=\"contentExp()\"\n" +
    "    tooltip-template-transclude-scope=\"originScope()\"></div>\n" +
    "</div>\n" +
    "");
}]);

angular.module("template/popover/popover-html.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/popover/popover-html.html",
    "<div class=\"popover\"\n" +
    "  tooltip-animation-class=\"fade\"\n" +
    "  tooltip-classes\n" +
    "  ng-class=\"{ in: isOpen() }\">\n" +
    "  <div class=\"arrow\"></div>\n" +
    "\n" +
    "  <div class=\"popover-inner\">\n" +
    "      <h3 class=\"popover-title\" ng-bind=\"title\" ng-if=\"title\"></h3>\n" +
    "      <div class=\"popover-content\" ng-bind-html=\"contentExp()\"></div>\n" +
    "  </div>\n" +
    "</div>\n" +
    "");
}]);

angular.module("template/popover/popover-template.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/popover/popover-template.html",
    "<div class=\"popover\"\n" +
    "  tooltip-animation-class=\"fade\"\n" +
    "  tooltip-classes\n" +
    "  ng-class=\"{ in: isOpen() }\">\n" +
    "  <div class=\"arrow\"></div>\n" +
    "\n" +
    "  <div class=\"popover-inner\">\n" +
    "      <h3 class=\"popover-title\" ng-bind=\"title\" ng-if=\"title\"></h3>\n" +
    "      <div class=\"popover-content\"\n" +
    "        tooltip-template-transclude=\"contentExp()\"\n" +
    "        tooltip-template-transclude-scope=\"originScope()\"></div>\n" +
    "  </div>\n" +
    "</div>\n" +
    "");
}]);

angular.module("template/popover/popover.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/popover/popover.html",
    "<div class=\"popover\"\n" +
    "  tooltip-animation-class=\"fade\"\n" +
    "  tooltip-classes\n" +
    "  ng-class=\"{ in: isOpen() }\">\n" +
    "  <div class=\"arrow\"></div>\n" +
    "\n" +
    "  <div class=\"popover-inner\">\n" +
    "      <h3 class=\"popover-title\" ng-bind=\"title\" ng-if=\"title\"></h3>\n" +
    "      <div class=\"popover-content\" ng-bind=\"content\"></div>\n" +
    "  </div>\n" +
    "</div>\n" +
    "");
}]);

angular.module("template/progressbar/bar.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/progressbar/bar.html",
    "<div class=\"progress-bar\" ng-class=\"type && 'progress-bar-' + type\" role=\"progressbar\" aria-valuenow=\"{{value}}\" aria-valuemin=\"0\" aria-valuemax=\"{{max}}\" ng-style=\"{width: (percent < 100 ? percent : 100) + '%'}\" aria-valuetext=\"{{percent | number:0}}%\" style=\"min-width: 0;\" ng-transclude></div>\n" +
    "");
}]);

angular.module("template/progressbar/progress.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/progressbar/progress.html",
    "<div class=\"progress\" ng-transclude></div>");
}]);

angular.module("template/progressbar/progressbar.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/progressbar/progressbar.html",
    "<div class=\"progress\">\n" +
    "  <div class=\"progress-bar\" ng-class=\"type && 'progress-bar-' + type\" role=\"progressbar\" aria-valuenow=\"{{value}}\" aria-valuemin=\"0\" aria-valuemax=\"{{max}}\" ng-style=\"{width: (percent < 100 ? percent : 100) + '%'}\" aria-valuetext=\"{{percent | number:0}}%\" style=\"min-width: 0;\" ng-transclude></div>\n" +
    "</div>\n" +
    "");
}]);

angular.module("template/rating/rating.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/rating/rating.html",
    "<span ng-mouseleave=\"reset()\" ng-keydown=\"onKeydown($event)\" tabindex=\"0\" role=\"slider\" aria-valuemin=\"0\" aria-valuemax=\"{{range.length}}\" aria-valuenow=\"{{value}}\">\n" +
    "    <span ng-repeat-start=\"r in range track by $index\" class=\"sr-only\">({{ $index < value ? '*' : ' ' }})</span>\n" +
    "    <i ng-repeat-end ng-mouseenter=\"enter($index + 1)\" ng-click=\"rate($index + 1)\" class=\"glyphicon\" ng-class=\"$index < value && (r.stateOn || 'glyphicon-star') || (r.stateOff || 'glyphicon-star-empty')\" ng-attr-title=\"{{r.title}}\" ></i>\n" +
    "</span>\n" +
    "");
}]);

angular.module("template/tabs/tab.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/tabs/tab.html",
    "<li ng-class=\"{active: active, disabled: disabled}\">\n" +
    "  <a href ng-click=\"select()\" tab-heading-transclude>{{heading}}</a>\n" +
    "</li>\n" +
    "");
}]);

angular.module("template/tabs/tabset.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/tabs/tabset.html",
    "<div>\n" +
    "  <ul class=\"nav nav-{{type || 'tabs'}}\" ng-class=\"{'nav-stacked': vertical, 'nav-justified': justified}\" ng-transclude></ul>\n" +
    "  <div class=\"tab-content\">\n" +
    "    <div class=\"tab-pane\" \n" +
    "         ng-repeat=\"tab in tabs\" \n" +
    "         ng-class=\"{active: tab.active}\"\n" +
    "         tab-content-transclude=\"tab\">\n" +
    "    </div>\n" +
    "  </div>\n" +
    "</div>\n" +
    "");
}]);

angular.module("template/timepicker/timepicker.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/timepicker/timepicker.html",
    "<table>\n" +
    "  <tbody>\n" +
    "    <tr class=\"text-center\" ng-show=\"::showSpinners\">\n" +
    "      <td><a ng-click=\"incrementHours()\" ng-class=\"{disabled: noIncrementHours()}\" class=\"btn btn-link\"><span class=\"glyphicon glyphicon-chevron-up\"></span></a></td>\n" +
    "      <td>&nbsp;</td>\n" +
    "      <td><a ng-click=\"incrementMinutes()\" ng-class=\"{disabled: noIncrementMinutes()}\" class=\"btn btn-link\"><span class=\"glyphicon glyphicon-chevron-up\"></span></a></td>\n" +
    "      <td ng-show=\"showMeridian\"></td>\n" +
    "    </tr>\n" +
    "    <tr>\n" +
    "      <td class=\"form-group\" ng-class=\"{'has-error': invalidHours}\">\n" +
    "        <input style=\"width:50px;\" type=\"text\" ng-model=\"hours\" ng-change=\"updateHours()\" class=\"form-control text-center\" ng-readonly=\"::readonlyInput\" maxlength=\"2\">\n" +
    "      </td>\n" +
    "      <td>:</td>\n" +
    "      <td class=\"form-group\" ng-class=\"{'has-error': invalidMinutes}\">\n" +
    "        <input style=\"width:50px;\" type=\"text\" ng-model=\"minutes\" ng-change=\"updateMinutes()\" class=\"form-control text-center\" ng-readonly=\"::readonlyInput\" maxlength=\"2\">\n" +
    "      </td>\n" +
    "      <td ng-show=\"showMeridian\"><button type=\"button\" ng-class=\"{disabled: noToggleMeridian()}\" class=\"btn btn-default text-center\" ng-click=\"toggleMeridian()\">{{meridian}}</button></td>\n" +
    "    </tr>\n" +
    "    <tr class=\"text-center\" ng-show=\"::showSpinners\">\n" +
    "      <td><a ng-click=\"decrementHours()\" ng-class=\"{disabled: noDecrementHours()}\" class=\"btn btn-link\"><span class=\"glyphicon glyphicon-chevron-down\"></span></a></td>\n" +
    "      <td>&nbsp;</td>\n" +
    "      <td><a ng-click=\"decrementMinutes()\" ng-class=\"{disabled: noDecrementMinutes()}\" class=\"btn btn-link\"><span class=\"glyphicon glyphicon-chevron-down\"></span></a></td>\n" +
    "      <td ng-show=\"showMeridian\"></td>\n" +
    "    </tr>\n" +
    "  </tbody>\n" +
    "</table>\n" +
    "");
}]);

angular.module("template/typeahead/typeahead-match.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/typeahead/typeahead-match.html",
    "<a href tabindex=\"-1\" ng-bind-html=\"match.label | typeaheadHighlight:query\"></a>\n" +
    "");
}]);

angular.module("template/typeahead/typeahead-popup.html", []).run(["$templateCache", function($templateCache) {
  $templateCache.put("template/typeahead/typeahead-popup.html",
    "<ul class=\"dropdown-menu\" ng-show=\"isOpen() && !moveInProgress\" ng-style=\"{top: position().top+'px', left: position().left+'px'}\" style=\"display: block;\" role=\"listbox\" aria-hidden=\"{{!isOpen()}}\">\n" +
    "    <li ng-repeat=\"match in matches track by $index\" ng-class=\"{active: isActive($index) }\" ng-mouseenter=\"selectActive($index)\" ng-click=\"selectMatch($index)\" role=\"option\" id=\"{{::match.id}}\">\n" +
    "        <div typeahead-match index=\"$index\" match=\"match\" query=\"query\" template-url=\"templateUrl\"></div>\n" +
    "    </li>\n" +
    "</ul>\n" +
    "");
}]);
!angular.$$csp() && angular.element(document).find('head').prepend('<style type="text/css">.ng-animate.item:not(.left):not(.right){-webkit-transition:0s ease-in-out left;transition:0s ease-in-out left}</style>');
/**
 * @license Angular UI Tree v2.1.5
 * (c) 2010-2014. https://github.com/JimLiu/angular-ui-tree
 * License: MIT
 */
(function () {
  'use strict';

  angular.module('ui.tree', [])
    .constant('treeConfig', {
      treeClass: 'angular-ui-tree',
      emptyTreeClass: 'angular-ui-tree-empty',
      hiddenClass: 'angular-ui-tree-hidden',
      nodesClass: 'angular-ui-tree-nodes',
      nodeClass: 'angular-ui-tree-node',
      handleClass: 'angular-ui-tree-handle',
      placeHolderClass: 'angular-ui-tree-placeholder',
      dragClass: 'angular-ui-tree-drag',
      dragThreshold: 3,
      levelThreshold: 30
    });

})();

(function () {
  'use strict';

  angular.module('ui.tree')

   /**
    * @ngdoc service
    * @name ui.tree.service:$helper
    * @requires ng.$document
    * @requires ng.$window
    *
    * @description
    * angular-ui-tree.
    */
    .factory('$uiTreeHelper', ['$document', '$window',
      function ($document, $window) {
        return {

          /**
           * A hashtable used to storage data of nodes
           * @type {Object}
           */
          nodesData: {
          },

          setNodeAttribute: function(scope, attrName, val) {
            var data = this.nodesData[scope.$modelValue.$$hashKey];
            if (!data) {
              data = {};
              this.nodesData[scope.$modelValue.$$hashKey] = data;
            }
            data[attrName] = val;
          },

          getNodeAttribute: function(scope, attrName) {
            var data = this.nodesData[scope.$modelValue.$$hashKey];
            if (data) {
              return data[attrName];
            }
            return null;
          },

          /**
           * @ngdoc method
           * @methodOf ui.tree.service:$nodrag
           * @param  {Object} targetElm angular element
           * @return {Bool} check if the node can be dragged.
           */
          nodrag: function (targetElm) {
            return (typeof targetElm.attr('data-nodrag')) != "undefined";
          },

          /**
           * get the event object for touchs
           * @param  {[type]} e [description]
           * @return {[type]}   [description]
           */
          eventObj: function(e) {
            var obj = e;
            if (e.targetTouches !== undefined) {
              obj = e.targetTouches.item(0);
            } else if (e.originalEvent !== undefined && e.originalEvent.targetTouches !== undefined) {
              obj = e.originalEvent.targetTouches.item(0);
            }
            return obj;
          },

          dragInfo: function(node) {
            return {
              source: node,
              sourceInfo: {
                nodeScope: node,
                index: node.index(),
                nodesScope: node.$parentNodesScope
              },
              index: node.index(),
              siblings: node.siblings().slice(0),
              parent: node.$parentNodesScope,

              moveTo: function(parent, siblings, index) { // Move the node to a new position
                this.parent = parent;
                this.siblings = siblings.slice(0);
                var i = this.siblings.indexOf(this.source); // If source node is in the target nodes
                if (i > -1) {
                  this.siblings.splice(i, 1);
                  if (this.source.index() < index) {
                    index--;
                  }
                }
                this.siblings.splice(index, 0, this.source);
                this.index = index;
              },

              parentNode: function() {
                return this.parent.$nodeScope;
              },

              prev: function() {
                if (this.index > 0) {
                  return this.siblings[this.index - 1];
                }
                return null;
              },

              next: function() {
                if (this.index < this.siblings.length - 1) {
                  return this.siblings[this.index + 1];
                }
                return null;
              },

              isDirty: function() {
                return this.source.$parentNodesScope != this.parent ||
                        this.source.index() != this.index;
              },

              eventArgs: function(elements, pos) {
                return {
                  source: this.sourceInfo,
                  dest: {
                    index: this.index,
                    nodesScope: this.parent
                  },
                  elements: elements,
                  pos: pos
                };
              },

              apply: function() {
                var nodeData = this.source.$modelValue;
                this.source.remove();
                this.parent.insertNode(this.index, nodeData);
              }
            };
          },

          /**
          * @ngdoc method
          * @name hippo.theme#height
          * @methodOf ui.tree.service:$helper
          *
          * @description
          * Get the height of an element.
          *
          * @param {Object} element Angular element.
          * @returns {String} Height
          */
          height: function (element) {
            return element.prop('scrollHeight');
          },

          /**
          * @ngdoc method
          * @name hippo.theme#width
          * @methodOf ui.tree.service:$helper
          *
          * @description
          * Get the width of an element.
          *
          * @param {Object} element Angular element.
          * @returns {String} Width
          */
          width: function (element) {
            return element.prop('scrollWidth');
          },

          /**
          * @ngdoc method
          * @name hippo.theme#offset
          * @methodOf ui.nestedSortable.service:$helper
          *
          * @description
          * Get the offset values of an element.
          *
          * @param {Object} element Angular element.
          * @returns {Object} Object with properties width, height, top and left
          */
          offset: function (element) {
            var boundingClientRect = element[0].getBoundingClientRect();

            return {
                width: element.prop('offsetWidth'),
                height: element.prop('offsetHeight'),
                top: boundingClientRect.top + ($window.pageYOffset || $document[0].body.scrollTop || $document[0].documentElement.scrollTop),
                left: boundingClientRect.left + ($window.pageXOffset || $document[0].body.scrollLeft  || $document[0].documentElement.scrollLeft)
              };
          },

          /**
          * @ngdoc method
          * @name hippo.theme#positionStarted
          * @methodOf ui.tree.service:$helper
          *
          * @description
          * Get the start position of the target element according to the provided event properties.
          *
          * @param {Object} e Event
          * @param {Object} target Target element
          * @returns {Object} Object with properties offsetX, offsetY, startX, startY, nowX and dirX.
          */
          positionStarted: function (e, target) {
            var pos = {};
            pos.offsetX = e.pageX - this.offset(target).left;
            pos.offsetY = e.pageY - this.offset(target).top;
            pos.startX = pos.lastX = e.pageX;
            pos.startY = pos.lastY = e.pageY;
            pos.nowX = pos.nowY = pos.distX = pos.distY = pos.dirAx = 0;
            pos.dirX = pos.dirY = pos.lastDirX = pos.lastDirY = pos.distAxX = pos.distAxY = 0;
            return pos;
          },

          positionMoved: function (e, pos, firstMoving) {
            // mouse position last events
            pos.lastX = pos.nowX;
            pos.lastY = pos.nowY;

            // mouse position this events
            pos.nowX  = e.pageX;
            pos.nowY  = e.pageY;

            // distance mouse moved between events
            pos.distX = pos.nowX - pos.lastX;
            pos.distY = pos.nowY - pos.lastY;

            // direction mouse was moving
            pos.lastDirX = pos.dirX;
            pos.lastDirY = pos.dirY;

            // direction mouse is now moving (on both axis)
            pos.dirX = pos.distX === 0 ? 0 : pos.distX > 0 ? 1 : -1;
            pos.dirY = pos.distY === 0 ? 0 : pos.distY > 0 ? 1 : -1;

            // axis mouse is now moving on
            var newAx   = Math.abs(pos.distX) > Math.abs(pos.distY) ? 1 : 0;

            // do nothing on first move
            if (firstMoving) {
              pos.dirAx  = newAx;
              pos.moving = true;
              return;
            }

            // calc distance moved on this axis (and direction)
            if (pos.dirAx !== newAx) {
              pos.distAxX = 0;
              pos.distAxY = 0;
            } else {
              pos.distAxX += Math.abs(pos.distX);
              if (pos.dirX !== 0 && pos.dirX !== pos.lastDirX) {
                pos.distAxX = 0;
              }

              pos.distAxY += Math.abs(pos.distY);
              if (pos.dirY !== 0 && pos.dirY !== pos.lastDirY) {
                pos.distAxY = 0;
              }
            }

            pos.dirAx = newAx;
          }
        };
      }
    ]);

})();
(function () {
  'use strict';

  angular.module('ui.tree')

    .controller('TreeController', ['$scope', '$element', '$attrs', 'treeConfig',
      function ($scope, $element, $attrs, treeConfig) {
        this.scope = $scope;

        $scope.$element = $element;
        $scope.$nodesScope = null; // root nodes
        $scope.$type = 'uiTree';
        $scope.$emptyElm = null;
        $scope.$callbacks = null;

        $scope.dragEnabled = true;
        $scope.emptyPlaceHolderEnabled = true;
        $scope.maxDepth = 0;
        $scope.dragDelay = 0;

        // Check if it's a empty tree
        $scope.isEmpty = function() {
          return ($scope.$nodesScope && $scope.$nodesScope.$modelValue
            && $scope.$nodesScope.$modelValue.length === 0);
        };

        // add placeholder to empty tree
        $scope.place = function(placeElm) {
          $scope.$nodesScope.$element.append(placeElm);
          $scope.$emptyElm.remove();
        };

        $scope.resetEmptyElement = function() {
          if ($scope.$nodesScope.$modelValue.length === 0 &&
            $scope.emptyPlaceHolderEnabled) {
            $element.append($scope.$emptyElm);
          } else {
            $scope.$emptyElm.remove();
          }
        };

        var collapseOrExpand = function(scope, collapsed) {
          var nodes = scope.childNodes();
          for (var i = 0; i < nodes.length; i++) {
            collapsed ? nodes[i].collapse() : nodes[i].expand();
            var subScope = nodes[i].$childNodesScope;
            if (subScope) {
              collapseOrExpand(subScope, collapsed);
            }
          }
        };

        $scope.collapseAll = function() {
          collapseOrExpand($scope.$nodesScope, true);
        };

        $scope.expandAll = function() {
          collapseOrExpand($scope.$nodesScope, false);
        };

      }
    ]);
})();

(function () {
  'use strict';

  angular.module('ui.tree')

    .controller('TreeNodesController', ['$scope', '$element', 'treeConfig',
      function ($scope, $element, treeConfig) {
        this.scope = $scope;

        $scope.$element = $element;
        $scope.$modelValue = null;
        $scope.$nodeScope = null; // the scope of node which the nodes belongs to
        $scope.$treeScope = null;
        $scope.$type = 'uiTreeNodes';
        $scope.$nodesMap = {};

        $scope.nodrop = false;
        $scope.maxDepth = 0;

        $scope.initSubNode = function(subNode) {
          $scope.$nodesMap[subNode.$modelValue.$$hashKey] = subNode;
        };

        $scope.destroySubNode = function(subNode) {
          $scope.$nodesMap[subNode.$modelValue.$$hashKey] = null;
        };

        $scope.accept = function(sourceNode, destIndex) {
          return $scope.$treeScope.$callbacks.accept(sourceNode, $scope, destIndex);
        };

        $scope.beforeDrag = function(sourceNode) {
          return $scope.$treeScope.$callbacks.beforeDrag(sourceNode);
        };

        $scope.isParent = function(node) {
          return node.$parentNodesScope == $scope;
        };

        $scope.hasChild = function() {
          return $scope.$modelValue.length > 0;
        };

        $scope.safeApply = function(fn) {
          var phase = this.$root.$$phase;
          if(phase == '$apply' || phase == '$digest') {
            if(fn && (typeof(fn) === 'function')) {
              fn();
            }
          } else {
            this.$apply(fn);
          }
        };

        $scope.removeNode = function(node) {
          var index = $scope.$modelValue.indexOf(node.$modelValue);
          if (index > -1) {
            $scope.safeApply(function() {
              $scope.$modelValue.splice(index, 1)[0];
            });
            return node;
          }
          return null;
        };

        $scope.insertNode = function(index, nodeData) {
          $scope.safeApply(function() {
            $scope.$modelValue.splice(index, 0, nodeData);
          });
        };

        $scope.childNodes = function() {
          var nodes = [];
          if ($scope.$modelValue) {
            for (var i = 0; i < $scope.$modelValue.length; i++) {
              nodes.push($scope.$nodesMap[$scope.$modelValue[i].$$hashKey]);
            }
          }
          return nodes;
        };

        $scope.depth = function() {
          if ($scope.$nodeScope) {
            return $scope.$nodeScope.depth();
          }
          return 0; // if it has no $nodeScope, it's root
        };

        // check if depth limit has reached
        $scope.outOfDepth = function(sourceNode) {
          var maxDepth = $scope.maxDepth || $scope.$treeScope.maxDepth;
          if (maxDepth > 0) {
            return $scope.depth() + sourceNode.maxSubDepth() + 1 > maxDepth;
          }
          return false;
        };

      }
    ]);
})();
(function () {
  'use strict';

  angular.module('ui.tree')

    .controller('TreeNodeController', ['$scope', '$element', '$attrs', 'treeConfig',
      function ($scope, $element, $attrs, treeConfig) {
        this.scope = $scope;

        $scope.$element = $element;
        $scope.$modelValue = null; // Model value for node;
        $scope.$parentNodeScope = null; // uiTreeNode Scope of parent node;
        $scope.$childNodesScope = null; // uiTreeNodes Scope of child nodes.
        $scope.$parentNodesScope = null; // uiTreeNodes Scope of parent nodes.
        $scope.$treeScope = null; // uiTree scope
        $scope.$handleScope = null; // it's handle scope
        $scope.$type = 'uiTreeNode';
        $scope.$$apply = false; //

        $scope.collapsed = false;

        $scope.init = function(controllersArr) {
          var treeNodesCtrl = controllersArr[0];
          $scope.$treeScope = controllersArr[1] ? controllersArr[1].scope : null;

          // find the scope of it's parent node
          $scope.$parentNodeScope = treeNodesCtrl.scope.$nodeScope;
          // modelValue for current node
          $scope.$modelValue = treeNodesCtrl.scope.$modelValue[$scope.$index];
          $scope.$parentNodesScope = treeNodesCtrl.scope;
          treeNodesCtrl.scope.initSubNode($scope); // init sub nodes

          $element.on('$destroy', function() {
            treeNodesCtrl.scope.destroySubNode($scope); // destroy sub nodes
          });
        };

        $scope.index = function() {
          return $scope.$parentNodesScope.$modelValue.indexOf($scope.$modelValue);
        };

        $scope.dragEnabled = function() {
          return !($scope.$treeScope && !$scope.$treeScope.dragEnabled);
        };

        $scope.isSibling = function(targetNode) {
          return $scope.$parentNodesScope == targetNode.$parentNodesScope;
        };

        $scope.isChild = function(targetNode) {
          var nodes = $scope.childNodes();
          return nodes && nodes.indexOf(targetNode) > -1;
        };

        $scope.prev = function() {
          var index = $scope.index();
          if (index > 0) {
            return $scope.siblings()[index - 1];
          }
          return null;
        };

        $scope.siblings = function() {
          return $scope.$parentNodesScope.childNodes();
        };

        $scope.childNodesCount = function() {
          return $scope.childNodes() ? $scope.childNodes().length : 0;
        };

        $scope.hasChild = function() {
          return $scope.childNodesCount() > 0;
        };

        $scope.childNodes = function() {
          return $scope.$childNodesScope && $scope.$childNodesScope.$modelValue ?
              $scope.$childNodesScope.childNodes() :
              null;
        };

        $scope.accept = function(sourceNode, destIndex) {
          return $scope.$childNodesScope &&
                  $scope.$childNodesScope.$modelValue &&
                  $scope.$childNodesScope.accept(sourceNode, destIndex);
        };

        $scope.removeNode = function(){
          var node = $scope.remove();
          $scope.$callbacks.removed(node);
          return node;
        };

        $scope.remove = function() {
          return $scope.$parentNodesScope.removeNode($scope);
        };

        $scope.toggle = function() {
          $scope.collapsed = !$scope.collapsed;
        };

        $scope.collapse = function() {
          $scope.collapsed = true;
        };

        $scope.expand = function() {
          $scope.collapsed = false;
        };

        $scope.depth = function() {
          var parentNode = $scope.$parentNodeScope;
          if (parentNode) {
            return parentNode.depth() + 1;
          }
          return 1;
        };

        var subDepth = 0;
        var countSubDepth = function(scope) {
          var count = 0;
          var nodes = scope.childNodes();
          for (var i = 0; i < nodes.length; i++) {
            var childNodes = nodes[i].$childNodesScope;
            if (childNodes) {
              count = 1;
              countSubDepth(childNodes);
            }
          }
          subDepth += count;
        };

        $scope.maxSubDepth = function() {
          subDepth = 0;
          if ($scope.$childNodesScope) {
            countSubDepth($scope.$childNodesScope);
          }
          return subDepth;
        };

      }
    ]);
})();

(function () {
  'use strict';

  angular.module('ui.tree')

    .controller('TreeHandleController', ['$scope', '$element', '$attrs', 'treeConfig',
      function ($scope, $element, $attrs, treeConfig) {
        this.scope = $scope;

        $scope.$element = $element;
        $scope.$nodeScope = null;
        $scope.$type = 'uiTreeHandle';

      }
    ]);
})();

(function () {
  'use strict';

  angular.module('ui.tree')
  .directive('uiTree', [ 'treeConfig', '$window',
    function(treeConfig, $window) {
      return {
        restrict: 'A',
        scope: true,
        controller: 'TreeController',
        link: function(scope, element, attrs) {
          var callbacks = {
            accept: null,
            beforeDrag: null
          };

          var config = {};
          angular.extend(config, treeConfig);
          if (config.treeClass) {
            element.addClass(config.treeClass);
          }

          scope.$emptyElm = angular.element($window.document.createElement('div'));
          if (config.emptyTreeClass) {
            scope.$emptyElm.addClass(config.emptyTreeClass);
          }

          scope.$watch('$nodesScope.$modelValue.length', function() {
            if (scope.$nodesScope.$modelValue) {
              scope.resetEmptyElement();
            }
          }, true);

          scope.$watch(attrs.dragEnabled, function(val) {
            if((typeof val) == "boolean") {
              scope.dragEnabled = val;
            }
          });

          scope.$watch(attrs.emptyPlaceHolderEnabled, function(val) {
            if((typeof val) == "boolean") {
              scope.emptyPlaceHolderEnabled = val;
            }
          });

          scope.$watch(attrs.maxDepth, function(val) {
            if((typeof val) == "number") {
              scope.maxDepth = val;
            }
          });

          scope.$watch(attrs.dragDelay, function(val) {
            if((typeof val) == "number") {
              scope.dragDelay = val;
            }
          });

          // check if the dest node can accept the dragging node
          // by default, we check the 'data-nodrop' attribute in `ui-tree-nodes`
          // and the 'max-depth' attribute in `ui-tree` or `ui-tree-nodes`.
          // the method can be overrided
          callbacks.accept = function(sourceNodeScope, destNodesScope, destIndex) {
            if (destNodesScope.nodrop || destNodesScope.outOfDepth(sourceNodeScope)) {
              return false;
            }
            return true;
          };

          callbacks.beforeDrag = function(sourceNodeScope) {
            return true;
          };

          callbacks.removed = function(node){
          
          };

          callbacks.dropped = function(event) {

          };

          //
          callbacks.dragStart = function(event) {

          };

          callbacks.dragMove = function(event) {

          };

          callbacks.dragStop = function(event) {

          };

          callbacks.beforeDrop = function(event) {

          };

          scope.$watch(attrs.uiTree, function(newVal, oldVal){
            angular.forEach(newVal, function(value, key){
              if (callbacks[key]) {
                if (typeof value === "function") {
                  callbacks[key] = value;
                }
              }
            });

            scope.$callbacks = callbacks;
          }, true);


        }
      };
    }
  ]);
})();

(function () {
  'use strict';

  angular.module('ui.tree')
  .directive('uiTreeNodes', [ 'treeConfig', '$window',
    function(treeConfig) {
      return {
        require: ['ngModel', '?^uiTreeNode', '^uiTree'],
        restrict: 'A',
        scope: true,
        controller: 'TreeNodesController',
        link: function(scope, element, attrs, controllersArr) {

          var config = {};
          angular.extend(config, treeConfig);
          if (config.nodesClass) {
            element.addClass(config.nodesClass);
          }

          var ngModel = controllersArr[0];
          var treeNodeCtrl = controllersArr[1];
          var treeCtrl = controllersArr[2];
          if (treeNodeCtrl) {
            treeNodeCtrl.scope.$childNodesScope = scope;
            scope.$nodeScope = treeNodeCtrl.scope;
          }
          else { // find the root nodes if there is no parent node and have a parent ui-tree
            treeCtrl.scope.$nodesScope = scope;
          }
          scope.$treeScope = treeCtrl.scope;

          if (ngModel) {
            ngModel.$render = function() {
              if (!ngModel.$modelValue || !angular.isArray(ngModel.$modelValue)) {
                scope.$modelValue = [];
              }
              scope.$modelValue = ngModel.$modelValue;
            };
          }

          scope.$watch(attrs.maxDepth, function(val) {
            if((typeof val) == "number") {
              scope.maxDepth = val;
            }
          });

          attrs.$observe('nodrop', function(val) {
            scope.nodrop = ((typeof val) != "undefined");
          });

          attrs.$observe('horizontal', function(val) {
            scope.horizontal = ((typeof val) != "undefined");
          });

        }
      };
    }
  ]);
})();

(function () {
  'use strict';

  angular.module('ui.tree')

    .directive('uiTreeNode', ['treeConfig', '$uiTreeHelper', '$window', '$document','$timeout',
      function (treeConfig, $uiTreeHelper, $window, $document, $timeout) {
        return {
          require: ['^uiTreeNodes', '^uiTree'],
          restrict: 'A',
          controller: 'TreeNodeController',
          link: function(scope, element, attrs, controllersArr) {
            var config = {};
            angular.extend(config, treeConfig);
            if (config.nodeClass) {
              element.addClass(config.nodeClass);
            }
            scope.init(controllersArr);

            scope.collapsed = !!$uiTreeHelper.getNodeAttribute(scope, 'collapsed');

            scope.$watch(attrs.collapsed, function(val) {
              if((typeof val) == "boolean") {
                scope.collapsed = val;
              }
            });

            scope.$watch('collapsed', function(val) {
              $uiTreeHelper.setNodeAttribute(scope, 'collapsed', val);
              attrs.$set('collapsed', val);
            });

            var hasTouch = 'ontouchstart' in window;
            // todo startPos is unused
            var startPos, firstMoving, dragInfo, pos;
            var placeElm, hiddenPlaceElm, dragElm;
            var treeScope = null;
            var elements; // As a parameter for callbacks
            var dragDelaying = true;
            var dragStarted = false;
            var dragTimer = null;
            var body = document.body,
                html = document.documentElement,
                document_height,
                document_width;

            var dragStart = function(e) {
              if (!hasTouch && (e.button == 2 || e.which == 3)) {
                // disable right click
                return;
              }
              if (e.uiTreeDragging || (e.originalEvent && e.originalEvent.uiTreeDragging)) { // event has already fired in other scope.
                return;
              }

              // the element which is clicked.
              var eventElm = angular.element(e.target);
              var eventScope = eventElm.scope();
              if (!eventScope || !eventScope.$type) {
                return;
              }
              if (eventScope.$type != 'uiTreeNode'
                && eventScope.$type != 'uiTreeHandle') { // Check if it is a node or a handle
                return;
              }
              if (eventScope.$type == 'uiTreeNode'
                && eventScope.$handleScope) { // If the node has a handle, then it should be clicked by the handle
                return;
              }

              var eventElmTagName = eventElm.prop('tagName').toLowerCase();
              if (eventElmTagName == 'input' ||
                eventElmTagName == 'textarea' ||
                eventElmTagName == 'button' ||
                eventElmTagName == 'select') { // if it's a input or button, ignore it
                return;
              }

              // check if it or it's parents has a 'data-nodrag' attribute
              while (eventElm && eventElm[0] && eventElm[0] != element) {
                if ($uiTreeHelper.nodrag(eventElm)) { // if the node mark as `nodrag`, DONOT drag it.
                  return;
                }
                eventElm = eventElm.parent();
              }

              if (!scope.beforeDrag(scope)){
                return;
              }

              e.uiTreeDragging = true; // stop event bubbling
              if (e.originalEvent) {
                e.originalEvent.uiTreeDragging = true;
              }
              e.preventDefault();
              var eventObj = $uiTreeHelper.eventObj(e);

              firstMoving = true;
              dragInfo = $uiTreeHelper.dragInfo(scope);

              var tagName = scope.$element.prop('tagName');
              if (tagName.toLowerCase() === 'tr') {
                placeElm = angular.element($window.document.createElement(tagName));
                var tdElm = angular.element($window.document.createElement('td'))
                              .addClass(config.placeHolderClass);
                placeElm.append(tdElm);
              } else {
                placeElm = angular.element($window.document.createElement(tagName))
                              .addClass(config.placeHolderClass);
              }
              hiddenPlaceElm = angular.element($window.document.createElement(tagName));
              if (config.hiddenClass) {
                hiddenPlaceElm.addClass(config.hiddenClass);
              }
              pos = $uiTreeHelper.positionStarted(eventObj, scope.$element);
              placeElm.css('height', $uiTreeHelper.height(scope.$element) + 'px');
              placeElm.css('width', $uiTreeHelper.width(scope.$element) + 'px');
              dragElm = angular.element($window.document.createElement(scope.$parentNodesScope.$element.prop('tagName')))
                        .addClass(scope.$parentNodesScope.$element.attr('class')).addClass(config.dragClass);
              dragElm.css('width', $uiTreeHelper.width(scope.$element) + 'px');
              dragElm.css('z-index', 9999);

              // Prevents cursor to change rapidly in Opera 12.16 and IE when dragging an element
              var hStyle = (scope.$element[0].querySelector('.angular-ui-tree-handle') || scope.$element[0]).currentStyle;
              if (hStyle) {
                document.body.setAttribute('ui-tree-cursor', $document.find('body').css('cursor') || '');
                $document.find('body').css({'cursor': hStyle.cursor + '!important'});
              }

              scope.$element.after(placeElm);
              scope.$element.after(hiddenPlaceElm);
              dragElm.append(scope.$element);
              $document.find('body').append(dragElm);
              dragElm.css({
                'left' : eventObj.pageX - pos.offsetX + 'px',
                'top'  : eventObj.pageY - pos.offsetY + 'px'
              });
              elements = {
                placeholder: placeElm,
                dragging: dragElm
              };

              angular.element($document).bind('touchend', dragEndEvent);
              angular.element($document).bind('touchcancel', dragEndEvent);
              angular.element($document).bind('touchmove', dragMoveEvent);
              angular.element($document).bind('mouseup', dragEndEvent);
              angular.element($document).bind('mousemove', dragMoveEvent);
              angular.element($document).bind('mouseleave', dragCancelEvent);

              document_height = Math.max(body.scrollHeight, body.offsetHeight, html.clientHeight, html.scrollHeight, html.offsetHeight);
              document_width = Math.max(body.scrollWidth, body.offsetWidth, html.clientWidth, html.scrollWidth, html.offsetWidth);
            };

            var dragMove = function(e) {
              if (!dragStarted) {
                if (!dragDelaying) {
                  dragStarted = true;
                  scope.$apply(function() {
                    scope.$callbacks.dragStart(dragInfo.eventArgs(elements, pos));
                  });
                }
                return;
              }

              var eventObj = $uiTreeHelper.eventObj(e);
              var prev, leftElmPos, topElmPos;

              if (dragElm) {
                e.preventDefault();

                if ($window.getSelection) {
                  $window.getSelection().removeAllRanges();
                } else if ($window.document.selection) {
                  $window.document.selection.empty();
                }

                leftElmPos = eventObj.pageX - pos.offsetX;
                topElmPos = eventObj.pageY - pos.offsetY;

                //dragElm can't leave the screen on the left
                if(leftElmPos < 0){
                  leftElmPos = 0;
                }

                //dragElm can't leave the screen on the top
                if(topElmPos < 0){
                  topElmPos = 0;
                }

                //dragElm can't leave the screen on the bottom
                if ((topElmPos + 10) > document_height){
                  topElmPos = document_height - 10;
                }

                //dragElm can't leave the screen on the right
                if((leftElmPos + 10) > document_width) {
                  leftElmPos = document_width - 10;
                }

                dragElm.css({
                  'left': leftElmPos + 'px',
                  'top': topElmPos + 'px'
                });

                var top_scroll = window.pageYOffset || $window.document.documentElement.scrollTop;
                var bottom_scroll = top_scroll + (window.innerHeight || $window.document.clientHeight || $window.document.clientHeight);

                // to scroll down if cursor y-position is greater than the bottom position the vertical scroll
                if (bottom_scroll < eventObj.pageY && bottom_scroll <= document_height) {
                  window.scrollBy(0, 10);
                }

                // to scroll top if cursor y-position is less than the top position the vertical scroll
                if (top_scroll > eventObj.pageY) {
                  window.scrollBy(0, -10);
                }

                $uiTreeHelper.positionMoved(e, pos, firstMoving);
                if (firstMoving) {
                  firstMoving = false;
                  return;
                }

                // move horizontal
                if (pos.dirAx && pos.distAxX >= config.levelThreshold) {
                  pos.distAxX = 0;

                  // increase horizontal level if previous sibling exists and is not collapsed
                  if (pos.distX > 0) {
                    prev = dragInfo.prev();
                    if (prev && !prev.collapsed
                      && prev.accept(scope, prev.childNodesCount())) {
                      prev.$childNodesScope.$element.append(placeElm);
                      dragInfo.moveTo(prev.$childNodesScope, prev.childNodes(), prev.childNodesCount());
                    }
                  }

                  // decrease horizontal level
                  if (pos.distX < 0) {
                    // we can't decrease a level if an item preceeds the current one
                    var next = dragInfo.next();
                    if (!next) {
                      var target = dragInfo.parentNode(); // As a sibling of it's parent node
                      if (target
                        && target.$parentNodesScope.accept(scope, target.index() + 1)) {
                        target.$element.after(placeElm);
                        dragInfo.moveTo(target.$parentNodesScope, target.siblings(), target.index() + 1);
                      }
                    }
                  }
                }

                // check if add it as a child node first
                // todo decrease is unused
                var decrease = ($uiTreeHelper.offset(dragElm).left - $uiTreeHelper.offset(placeElm).left) >= config.threshold;
                var targetX = eventObj.pageX - $window.document.body.scrollLeft;
                var targetY = eventObj.pageY - (window.pageYOffset || $window.document.documentElement.scrollTop);

                // Select the drag target. Because IE does not support CSS 'pointer-events: none', it will always
                // pick the drag element itself as the target. To prevent this, we hide the drag element while
                // selecting the target.
                var displayElm;
                if (angular.isFunction(dragElm.hide)) {
                  dragElm.hide();
                }else{
                  displayElm = dragElm[0].style.display;
                  dragElm[0].style.display = "none";
                }

                // when using elementFromPoint() inside an iframe, you have to call
                // elementFromPoint() twice to make sure IE8 returns the correct value
                $window.document.elementFromPoint(targetX, targetY);

                var targetElm = angular.element($window.document.elementFromPoint(targetX, targetY));
                if (angular.isFunction(dragElm.show)) {
                  dragElm.show();
                }else{
                  dragElm[0].style.display = displayElm;
                }

                // move vertical
                if (!pos.dirAx) {
                  var targetBefore, targetNode;
                  // check it's new position
                  targetNode = targetElm.scope();
                  var isEmpty = false;
                  if (!targetNode) {
                    return;
                  }
                  if (targetNode.$type == 'uiTree' && targetNode.dragEnabled) {
                    isEmpty = targetNode.isEmpty(); // Check if it's empty tree
                  }
                  if (targetNode.$type == 'uiTreeHandle') {
                    targetNode = targetNode.$nodeScope;
                  }
                  if (targetNode.$type != 'uiTreeNode'
                    && !isEmpty) { // Check if it is a uiTreeNode or it's an empty tree
                    return;
                  }

                  // if placeholder move from empty tree, reset it.
                  if (treeScope && placeElm.parent()[0] != treeScope.$element[0]) {
                    treeScope.resetEmptyElement();
                    treeScope = null;
                  }

                  if (isEmpty) { // it's an empty tree
                    treeScope = targetNode;
                    if (targetNode.$nodesScope.accept(scope, 0)) {
                      targetNode.place(placeElm);
                      dragInfo.moveTo(targetNode.$nodesScope, targetNode.$nodesScope.childNodes(), 0);
                    }
                  } else if (targetNode.dragEnabled()){ // drag enabled
                    targetElm = targetNode.$element; // Get the element of ui-tree-node
                    var targetOffset = $uiTreeHelper.offset(targetElm);
                    targetBefore = targetNode.horizontal ? eventObj.pageX < (targetOffset.left + $uiTreeHelper.width(targetElm) / 2)
                                                         : eventObj.pageY < (targetOffset.top + $uiTreeHelper.height(targetElm) / 2);

                    if (targetNode.$parentNodesScope.accept(scope, targetNode.index())) {
                      if (targetBefore) {
                        targetElm[0].parentNode.insertBefore(placeElm[0], targetElm[0]);
                        dragInfo.moveTo(targetNode.$parentNodesScope, targetNode.siblings(), targetNode.index());
                      } else {
                        targetElm.after(placeElm);
                        dragInfo.moveTo(targetNode.$parentNodesScope, targetNode.siblings(), targetNode.index() + 1);
                      }
                    }
                    else if (!targetBefore && targetNode.accept(scope, targetNode.childNodesCount())) { // we have to check if it can add the dragging node as a child
                      targetNode.$childNodesScope.$element.append(placeElm);
                      dragInfo.moveTo(targetNode.$childNodesScope, targetNode.childNodes(), targetNode.childNodesCount());
                    }
                  }

                }

                scope.$apply(function() {
                  scope.$callbacks.dragMove(dragInfo.eventArgs(elements, pos));
                });
              }
            };

            var dragEnd = function(e) {
              e.preventDefault();

              if (dragElm) {
                scope.$treeScope.$apply(function() {
                  scope.$callbacks.beforeDrop(dragInfo.eventArgs(elements, pos));
                });
                // roll back elements changed
                hiddenPlaceElm.replaceWith(scope.$element);
                placeElm.remove();

                dragElm.remove();
                dragElm = null;
                if (scope.$$apply) {
                  dragInfo.apply();
                  scope.$treeScope.$apply(function() {
                    scope.$callbacks.dropped(dragInfo.eventArgs(elements, pos));
                  });
                } else {
                  bindDrag();
                }
                scope.$treeScope.$apply(function() {
                  scope.$callbacks.dragStop(dragInfo.eventArgs(elements, pos));
                });
                scope.$$apply = false;
                dragInfo = null;

              }

              // Restore cursor in Opera 12.16 and IE
              var oldCur = document.body.getAttribute('ui-tree-cursor');
              if (oldCur !== null) {
                $document.find('body').css({'cursor': oldCur});
                document.body.removeAttribute('ui-tree-cursor');
              }

              angular.element($document).unbind('touchend', dragEndEvent); // Mobile
              angular.element($document).unbind('touchcancel', dragEndEvent); // Mobile
              angular.element($document).unbind('touchmove', dragMoveEvent); // Mobile
              angular.element($document).unbind('mouseup', dragEndEvent);
              angular.element($document).unbind('mousemove', dragMoveEvent);
              angular.element($window.document.body).unbind('mouseleave', dragCancelEvent);
            };

            var dragStartEvent = function(e) {
              if (scope.dragEnabled()) {
                dragStart(e);
              }
            };

            var dragMoveEvent = function(e) {
              dragMove(e);
            };

            var dragEndEvent = function(e) {
              scope.$$apply = true;
              dragEnd(e);
            };

            var dragCancelEvent = function(e) {
              dragEnd(e);
            };

            var bindDrag = function() {
              element.bind('touchstart mousedown', function (e) {
                dragDelaying = true;
                dragStarted = false;
                dragStartEvent(e);
                dragTimer = $timeout(function(){dragDelaying = false;}, scope.dragDelay);
              });
              element.bind('touchend touchcancel mouseup',function(){$timeout.cancel(dragTimer);});
            };
            bindDrag();

            angular.element($window.document.body).bind("keydown", function(e) {
              if (e.keyCode == 27) {
                scope.$$apply = false;
                dragEnd(e);
              }
            });
          }
        };
      }
    ]);

})();

(function () {
  'use strict';

  angular.module('ui.tree')
  .directive('uiTreeHandle', [ 'treeConfig', '$window',
    function(treeConfig) {
      return {
        require: '^uiTreeNode',
        restrict: 'A',
        scope: true,
        controller: 'TreeHandleController',
        link: function(scope, element, attrs, treeNodeCtrl) {
          var config = {};
          angular.extend(config, treeConfig);
          if (config.handleClass) {
            element.addClass(config.handleClass);
          }
          // connect with the tree node.
          if (scope != treeNodeCtrl.scope) {
            scope.$nodeScope = treeNodeCtrl.scope;
            treeNodeCtrl.scope.$handleScope = scope;
          }
        }
      };
    }
  ]);
})();

/**
 * @license AngularJS v1.3.20
 * (c) 2010-2014 Google, Inc. http://angularjs.org
 * License: MIT
 */
(function(window, angular, undefined) {'use strict';

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
 *     Any commits to this file should be reviewed with security in mind.  *
 *   Changes to this file can potentially create security vulnerabilities. *
 *          An approval from 2 Core members with history of modifying      *
 *                         this file is required.                          *
 *                                                                         *
 *  Does the change somehow allow for arbitrary javascript to be executed? *
 *    Or allows for someone to change the prototype of built-in objects?   *
 *     Or gives undesired access to variables likes document or window?    *
 * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

var $sanitizeMinErr = angular.$$minErr('$sanitize');

/**
 * @ngdoc module
 * @name ngSanitize
 * @description
 *
 * # ngSanitize
 *
 * The `ngSanitize` module provides functionality to sanitize HTML.
 *
 *
 * <div doc-module-components="ngSanitize"></div>
 *
 * See {@link ngSanitize.$sanitize `$sanitize`} for usage.
 */

/*
 * HTML Parser By Misko Hevery (misko@hevery.com)
 * based on:  HTML Parser By John Resig (ejohn.org)
 * Original code by Erik Arvidsson, Mozilla Public License
 * http://erik.eae.net/simplehtmlparser/simplehtmlparser.js
 *
 * // Use like so:
 * htmlParser(htmlString, {
 *     start: function(tag, attrs, unary) {},
 *     end: function(tag) {},
 *     chars: function(text) {},
 *     comment: function(text) {}
 * });
 *
 */


/**
 * @ngdoc service
 * @name $sanitize
 * @kind function
 *
 * @description
 *   The input is sanitized by parsing the HTML into tokens. All safe tokens (from a whitelist) are
 *   then serialized back to properly escaped html string. This means that no unsafe input can make
 *   it into the returned string, however, since our parser is more strict than a typical browser
 *   parser, it's possible that some obscure input, which would be recognized as valid HTML by a
 *   browser, won't make it through the sanitizer. The input may also contain SVG markup.
 *   The whitelist is configured using the functions `aHrefSanitizationWhitelist` and
 *   `imgSrcSanitizationWhitelist` of {@link ng.$compileProvider `$compileProvider`}.
 *
 * @param {string} html HTML input.
 * @returns {string} Sanitized HTML.
 *
 * @example
   <example module="sanitizeExample" deps="angular-sanitize.js">
   <file name="index.html">
     <script>
         angular.module('sanitizeExample', ['ngSanitize'])
           .controller('ExampleController', ['$scope', '$sce', function($scope, $sce) {
             $scope.snippet =
               '<p style="color:blue">an html\n' +
               '<em onmouseover="this.textContent=\'PWN3D!\'">click here</em>\n' +
               'snippet</p>';
             $scope.deliberatelyTrustDangerousSnippet = function() {
               return $sce.trustAsHtml($scope.snippet);
             };
           }]);
     </script>
     <div ng-controller="ExampleController">
        Snippet: <textarea ng-model="snippet" cols="60" rows="3"></textarea>
       <table>
         <tr>
           <td>Directive</td>
           <td>How</td>
           <td>Source</td>
           <td>Rendered</td>
         </tr>
         <tr id="bind-html-with-sanitize">
           <td>ng-bind-html</td>
           <td>Automatically uses $sanitize</td>
           <td><pre>&lt;div ng-bind-html="snippet"&gt;<br/>&lt;/div&gt;</pre></td>
           <td><div ng-bind-html="snippet"></div></td>
         </tr>
         <tr id="bind-html-with-trust">
           <td>ng-bind-html</td>
           <td>Bypass $sanitize by explicitly trusting the dangerous value</td>
           <td>
           <pre>&lt;div ng-bind-html="deliberatelyTrustDangerousSnippet()"&gt;
&lt;/div&gt;</pre>
           </td>
           <td><div ng-bind-html="deliberatelyTrustDangerousSnippet()"></div></td>
         </tr>
         <tr id="bind-default">
           <td>ng-bind</td>
           <td>Automatically escapes</td>
           <td><pre>&lt;div ng-bind="snippet"&gt;<br/>&lt;/div&gt;</pre></td>
           <td><div ng-bind="snippet"></div></td>
         </tr>
       </table>
       </div>
   </file>
   <file name="protractor.js" type="protractor">
     it('should sanitize the html snippet by default', function() {
       expect(element(by.css('#bind-html-with-sanitize div')).getInnerHtml()).
         toBe('<p>an html\n<em>click here</em>\nsnippet</p>');
     });

     it('should inline raw snippet if bound to a trusted value', function() {
       expect(element(by.css('#bind-html-with-trust div')).getInnerHtml()).
         toBe("<p style=\"color:blue\">an html\n" +
              "<em onmouseover=\"this.textContent='PWN3D!'\">click here</em>\n" +
              "snippet</p>");
     });

     it('should escape snippet without any filter', function() {
       expect(element(by.css('#bind-default div')).getInnerHtml()).
         toBe("&lt;p style=\"color:blue\"&gt;an html\n" +
              "&lt;em onmouseover=\"this.textContent='PWN3D!'\"&gt;click here&lt;/em&gt;\n" +
              "snippet&lt;/p&gt;");
     });

     it('should update', function() {
       element(by.model('snippet')).clear();
       element(by.model('snippet')).sendKeys('new <b onclick="alert(1)">text</b>');
       expect(element(by.css('#bind-html-with-sanitize div')).getInnerHtml()).
         toBe('new <b>text</b>');
       expect(element(by.css('#bind-html-with-trust div')).getInnerHtml()).toBe(
         'new <b onclick="alert(1)">text</b>');
       expect(element(by.css('#bind-default div')).getInnerHtml()).toBe(
         "new &lt;b onclick=\"alert(1)\"&gt;text&lt;/b&gt;");
     });
   </file>
   </example>
 */
function $SanitizeProvider() {
  this.$get = ['$$sanitizeUri', function($$sanitizeUri) {
    return function(html) {
      var buf = [];
      htmlParser(html, htmlSanitizeWriter(buf, function(uri, isImage) {
        return !/^unsafe/.test($$sanitizeUri(uri, isImage));
      }));
      return buf.join('');
    };
  }];
}

function sanitizeText(chars) {
  var buf = [];
  var writer = htmlSanitizeWriter(buf, angular.noop);
  writer.chars(chars);
  return buf.join('');
}


// Regular Expressions for parsing tags and attributes
var START_TAG_REGEXP =
       /^<((?:[a-zA-Z])[\w:-]*)((?:\s+[\w:-]+(?:\s*=\s*(?:(?:"[^"]*")|(?:'[^']*')|[^>\s]+))?)*)\s*(\/?)\s*(>?)/,
  END_TAG_REGEXP = /^<\/\s*([\w:-]+)[^>]*>/,
  ATTR_REGEXP = /([\w:-]+)(?:\s*=\s*(?:(?:"((?:[^"])*)")|(?:'((?:[^'])*)')|([^>\s]+)))?/g,
  BEGIN_TAG_REGEXP = /^</,
  BEGING_END_TAGE_REGEXP = /^<\//,
  COMMENT_REGEXP = /<!--(.*?)-->/g,
  DOCTYPE_REGEXP = /<!DOCTYPE([^>]*?)>/i,
  CDATA_REGEXP = /<!\[CDATA\[(.*?)]]>/g,
  SURROGATE_PAIR_REGEXP = /[\uD800-\uDBFF][\uDC00-\uDFFF]/g,
  // Match everything outside of normal chars and " (quote character)
  NON_ALPHANUMERIC_REGEXP = /([^\#-~| |!])/g;


// Good source of info about elements and attributes
// http://dev.w3.org/html5/spec/Overview.html#semantics
// http://simon.html5.org/html-elements

// Safe Void Elements - HTML5
// http://dev.w3.org/html5/spec/Overview.html#void-elements
var voidElements = makeMap("area,br,col,hr,img,wbr");

// Elements that you can, intentionally, leave open (and which close themselves)
// http://dev.w3.org/html5/spec/Overview.html#optional-tags
var optionalEndTagBlockElements = makeMap("colgroup,dd,dt,li,p,tbody,td,tfoot,th,thead,tr"),
    optionalEndTagInlineElements = makeMap("rp,rt"),
    optionalEndTagElements = angular.extend({},
                                            optionalEndTagInlineElements,
                                            optionalEndTagBlockElements);

// Safe Block Elements - HTML5
var blockElements = angular.extend({}, optionalEndTagBlockElements, makeMap("address,article," +
        "aside,blockquote,caption,center,del,dir,div,dl,figure,figcaption,footer,h1,h2,h3,h4,h5," +
        "h6,header,hgroup,hr,ins,map,menu,nav,ol,pre,script,section,table,ul"));

// Inline Elements - HTML5
var inlineElements = angular.extend({}, optionalEndTagInlineElements, makeMap("a,abbr,acronym,b," +
        "bdi,bdo,big,br,cite,code,del,dfn,em,font,i,img,ins,kbd,label,map,mark,q,ruby,rp,rt,s," +
        "samp,small,span,strike,strong,sub,sup,time,tt,u,var"));

// SVG Elements
// https://wiki.whatwg.org/wiki/Sanitization_rules#svg_Elements
var svgElements = makeMap("animate,animateColor,animateMotion,animateTransform,circle,defs," +
        "desc,ellipse,font-face,font-face-name,font-face-src,g,glyph,hkern,image,linearGradient," +
        "line,marker,metadata,missing-glyph,mpath,path,polygon,polyline,radialGradient,rect,set," +
        "stop,svg,switch,text,title,tspan,use");

// Special Elements (can contain anything)
var specialElements = makeMap("script,style");

var validElements = angular.extend({},
                                   voidElements,
                                   blockElements,
                                   inlineElements,
                                   optionalEndTagElements,
                                   svgElements);

//Attributes that have href and hence need to be sanitized
var uriAttrs = makeMap("background,cite,href,longdesc,src,usemap,xlink:href");

var htmlAttrs = makeMap('abbr,align,alt,axis,bgcolor,border,cellpadding,cellspacing,class,clear,' +
    'color,cols,colspan,compact,coords,dir,face,headers,height,hreflang,hspace,' +
    'ismap,lang,language,nohref,nowrap,rel,rev,rows,rowspan,rules,' +
    'scope,scrolling,shape,size,span,start,summary,target,title,type,' +
    'valign,value,vspace,width');

// SVG attributes (without "id" and "name" attributes)
// https://wiki.whatwg.org/wiki/Sanitization_rules#svg_Attributes
var svgAttrs = makeMap('accent-height,accumulate,additive,alphabetic,arabic-form,ascent,' +
    'attributeName,attributeType,baseProfile,bbox,begin,by,calcMode,cap-height,class,color,' +
    'color-rendering,content,cx,cy,d,dx,dy,descent,display,dur,end,fill,fill-rule,font-family,' +
    'font-size,font-stretch,font-style,font-variant,font-weight,from,fx,fy,g1,g2,glyph-name,' +
    'gradientUnits,hanging,height,horiz-adv-x,horiz-origin-x,ideographic,k,keyPoints,' +
    'keySplines,keyTimes,lang,marker-end,marker-mid,marker-start,markerHeight,markerUnits,' +
    'markerWidth,mathematical,max,min,offset,opacity,orient,origin,overline-position,' +
    'overline-thickness,panose-1,path,pathLength,points,preserveAspectRatio,r,refX,refY,' +
    'repeatCount,repeatDur,requiredExtensions,requiredFeatures,restart,rotate,rx,ry,slope,stemh,' +
    'stemv,stop-color,stop-opacity,strikethrough-position,strikethrough-thickness,stroke,' +
    'stroke-dasharray,stroke-dashoffset,stroke-linecap,stroke-linejoin,stroke-miterlimit,' +
    'stroke-opacity,stroke-width,systemLanguage,target,text-anchor,to,transform,type,u1,u2,' +
    'underline-position,underline-thickness,unicode,unicode-range,units-per-em,values,version,' +
    'viewBox,visibility,width,widths,x,x-height,x1,x2,xlink:actuate,xlink:arcrole,xlink:role,' +
    'xlink:show,xlink:title,xlink:type,xml:base,xml:lang,xml:space,xmlns,xmlns:xlink,y,y1,y2,' +
    'zoomAndPan');

var validAttrs = angular.extend({},
                                uriAttrs,
                                svgAttrs,
                                htmlAttrs);

function makeMap(str) {
  var obj = {}, items = str.split(','), i;
  for (i = 0; i < items.length; i++) obj[items[i]] = true;
  return obj;
}


/**
 * @example
 * htmlParser(htmlString, {
 *     start: function(tag, attrs, unary) {},
 *     end: function(tag) {},
 *     chars: function(text) {},
 *     comment: function(text) {}
 * });
 *
 * @param {string} html string
 * @param {object} handler
 */
function htmlParser(html, handler) {
  if (typeof html !== 'string') {
    if (html === null || typeof html === 'undefined') {
      html = '';
    } else {
      html = '' + html;
    }
  }
  var index, chars, match, stack = [], last = html, text;
  stack.last = function() { return stack[stack.length - 1]; };

  while (html) {
    text = '';
    chars = true;

    // Make sure we're not in a script or style element
    if (!stack.last() || !specialElements[stack.last()]) {

      // Comment
      if (html.indexOf("<!--") === 0) {
        // comments containing -- are not allowed unless they terminate the comment
        index = html.indexOf("--", 4);

        if (index >= 0 && html.lastIndexOf("-->", index) === index) {
          if (handler.comment) handler.comment(html.substring(4, index));
          html = html.substring(index + 3);
          chars = false;
        }
      // DOCTYPE
      } else if (DOCTYPE_REGEXP.test(html)) {
        match = html.match(DOCTYPE_REGEXP);

        if (match) {
          html = html.replace(match[0], '');
          chars = false;
        }
      // end tag
      } else if (BEGING_END_TAGE_REGEXP.test(html)) {
        match = html.match(END_TAG_REGEXP);

        if (match) {
          html = html.substring(match[0].length);
          match[0].replace(END_TAG_REGEXP, parseEndTag);
          chars = false;
        }

      // start tag
      } else if (BEGIN_TAG_REGEXP.test(html)) {
        match = html.match(START_TAG_REGEXP);

        if (match) {
          // We only have a valid start-tag if there is a '>'.
          if (match[4]) {
            html = html.substring(match[0].length);
            match[0].replace(START_TAG_REGEXP, parseStartTag);
          }
          chars = false;
        } else {
          // no ending tag found --- this piece should be encoded as an entity.
          text += '<';
          html = html.substring(1);
        }
      }

      if (chars) {
        index = html.indexOf("<");

        text += index < 0 ? html : html.substring(0, index);
        html = index < 0 ? "" : html.substring(index);

        if (handler.chars) handler.chars(decodeEntities(text));
      }

    } else {
      // IE versions 9 and 10 do not understand the regex '[^]', so using a workaround with [\W\w].
      html = html.replace(new RegExp("([\\W\\w]*)<\\s*\\/\\s*" + stack.last() + "[^>]*>", 'i'),
        function(all, text) {
          text = text.replace(COMMENT_REGEXP, "$1").replace(CDATA_REGEXP, "$1");

          if (handler.chars) handler.chars(decodeEntities(text));

          return "";
      });

      parseEndTag("", stack.last());
    }

    if (html == last) {
      throw $sanitizeMinErr('badparse', "The sanitizer was unable to parse the following block " +
                                        "of html: {0}", html);
    }
    last = html;
  }

  // Clean up any remaining tags
  parseEndTag();

  function parseStartTag(tag, tagName, rest, unary) {
    tagName = angular.lowercase(tagName);
    if (blockElements[tagName]) {
      while (stack.last() && inlineElements[stack.last()]) {
        parseEndTag("", stack.last());
      }
    }

    if (optionalEndTagElements[tagName] && stack.last() == tagName) {
      parseEndTag("", tagName);
    }

    unary = voidElements[tagName] || !!unary;

    if (!unary)
      stack.push(tagName);

    var attrs = {};

    rest.replace(ATTR_REGEXP,
      function(match, name, doubleQuotedValue, singleQuotedValue, unquotedValue) {
        var value = doubleQuotedValue
          || singleQuotedValue
          || unquotedValue
          || '';

        attrs[name] = decodeEntities(value);
    });
    if (handler.start) handler.start(tagName, attrs, unary);
  }

  function parseEndTag(tag, tagName) {
    var pos = 0, i;
    tagName = angular.lowercase(tagName);
    if (tagName)
      // Find the closest opened tag of the same type
      for (pos = stack.length - 1; pos >= 0; pos--)
        if (stack[pos] == tagName)
          break;

    if (pos >= 0) {
      // Close all the open elements, up the stack
      for (i = stack.length - 1; i >= pos; i--)
        if (handler.end) handler.end(stack[i]);

      // Remove the open elements from the stack
      stack.length = pos;
    }
  }
}

var hiddenPre=document.createElement("pre");
/**
 * decodes all entities into regular string
 * @param value
 * @returns {string} A string with decoded entities.
 */
function decodeEntities(value) {
  if (!value) { return ''; }

  hiddenPre.innerHTML = value.replace(/</g,"&lt;");
  // innerText depends on styling as it doesn't display hidden elements.
  // Therefore, it's better to use textContent not to cause unnecessary reflows.
  return hiddenPre.textContent;
}

/**
 * Escapes all potentially dangerous characters, so that the
 * resulting string can be safely inserted into attribute or
 * element text.
 * @param value
 * @returns {string} escaped text
 */
function encodeEntities(value) {
  return value.
    replace(/&/g, '&amp;').
    replace(SURROGATE_PAIR_REGEXP, function(value) {
      var hi = value.charCodeAt(0);
      var low = value.charCodeAt(1);
      return '&#' + (((hi - 0xD800) * 0x400) + (low - 0xDC00) + 0x10000) + ';';
    }).
    replace(NON_ALPHANUMERIC_REGEXP, function(value) {
      return '&#' + value.charCodeAt(0) + ';';
    }).
    replace(/</g, '&lt;').
    replace(/>/g, '&gt;');
}

/**
 * create an HTML/XML writer which writes to buffer
 * @param {Array} buf use buf.jain('') to get out sanitized html string
 * @returns {object} in the form of {
 *     start: function(tag, attrs, unary) {},
 *     end: function(tag) {},
 *     chars: function(text) {},
 *     comment: function(text) {}
 * }
 */
function htmlSanitizeWriter(buf, uriValidator) {
  var ignore = false;
  var out = angular.bind(buf, buf.push);
  return {
    start: function(tag, attrs, unary) {
      tag = angular.lowercase(tag);
      if (!ignore && specialElements[tag]) {
        ignore = tag;
      }
      if (!ignore && validElements[tag] === true) {
        out('<');
        out(tag);
        angular.forEach(attrs, function(value, key) {
          var lkey=angular.lowercase(key);
          var isImage = (tag === 'img' && lkey === 'src') || (lkey === 'background');
          if (validAttrs[lkey] === true &&
            (uriAttrs[lkey] !== true || uriValidator(value, isImage))) {
            out(' ');
            out(key);
            out('="');
            out(encodeEntities(value));
            out('"');
          }
        });
        out(unary ? '/>' : '>');
      }
    },
    end: function(tag) {
        tag = angular.lowercase(tag);
        if (!ignore && validElements[tag] === true) {
          out('</');
          out(tag);
          out('>');
        }
        if (tag == ignore) {
          ignore = false;
        }
      },
    chars: function(chars) {
        if (!ignore) {
          out(encodeEntities(chars));
        }
      }
  };
}


// define ngSanitize module and register $sanitize service
angular.module('ngSanitize', []).provider('$sanitize', $SanitizeProvider);

/* global sanitizeText: false */

/**
 * @ngdoc filter
 * @name linky
 * @kind function
 *
 * @description
 * Finds links in text input and turns them into html links. Supports http/https/ftp/mailto and
 * plain email address links.
 *
 * Requires the {@link ngSanitize `ngSanitize`} module to be installed.
 *
 * @param {string} text Input text.
 * @param {string} target Window (_blank|_self|_parent|_top) or named frame to open links in.
 * @returns {string} Html-linkified text.
 *
 * @usage
   <span ng-bind-html="linky_expression | linky"></span>
 *
 * @example
   <example module="linkyExample" deps="angular-sanitize.js">
     <file name="index.html">
       <script>
         angular.module('linkyExample', ['ngSanitize'])
           .controller('ExampleController', ['$scope', function($scope) {
             $scope.snippet =
               'Pretty text with some links:\n'+
               'http://angularjs.org/,\n'+
               'mailto:us@somewhere.org,\n'+
               'another@somewhere.org,\n'+
               'and one more: ftp://127.0.0.1/.';
             $scope.snippetWithTarget = 'http://angularjs.org/';
           }]);
       </script>
       <div ng-controller="ExampleController">
       Snippet: <textarea ng-model="snippet" cols="60" rows="3"></textarea>
       <table>
         <tr>
           <td>Filter</td>
           <td>Source</td>
           <td>Rendered</td>
         </tr>
         <tr id="linky-filter">
           <td>linky filter</td>
           <td>
             <pre>&lt;div ng-bind-html="snippet | linky"&gt;<br>&lt;/div&gt;</pre>
           </td>
           <td>
             <div ng-bind-html="snippet | linky"></div>
           </td>
         </tr>
         <tr id="linky-target">
          <td>linky target</td>
          <td>
            <pre>&lt;div ng-bind-html="snippetWithTarget | linky:'_blank'"&gt;<br>&lt;/div&gt;</pre>
          </td>
          <td>
            <div ng-bind-html="snippetWithTarget | linky:'_blank'"></div>
          </td>
         </tr>
         <tr id="escaped-html">
           <td>no filter</td>
           <td><pre>&lt;div ng-bind="snippet"&gt;<br>&lt;/div&gt;</pre></td>
           <td><div ng-bind="snippet"></div></td>
         </tr>
       </table>
     </file>
     <file name="protractor.js" type="protractor">
       it('should linkify the snippet with urls', function() {
         expect(element(by.id('linky-filter')).element(by.binding('snippet | linky')).getText()).
             toBe('Pretty text with some links: http://angularjs.org/, us@somewhere.org, ' +
                  'another@somewhere.org, and one more: ftp://127.0.0.1/.');
         expect(element.all(by.css('#linky-filter a')).count()).toEqual(4);
       });

       it('should not linkify snippet without the linky filter', function() {
         expect(element(by.id('escaped-html')).element(by.binding('snippet')).getText()).
             toBe('Pretty text with some links: http://angularjs.org/, mailto:us@somewhere.org, ' +
                  'another@somewhere.org, and one more: ftp://127.0.0.1/.');
         expect(element.all(by.css('#escaped-html a')).count()).toEqual(0);
       });

       it('should update', function() {
         element(by.model('snippet')).clear();
         element(by.model('snippet')).sendKeys('new http://link.');
         expect(element(by.id('linky-filter')).element(by.binding('snippet | linky')).getText()).
             toBe('new http://link.');
         expect(element.all(by.css('#linky-filter a')).count()).toEqual(1);
         expect(element(by.id('escaped-html')).element(by.binding('snippet')).getText())
             .toBe('new http://link.');
       });

       it('should work with the target property', function() {
        expect(element(by.id('linky-target')).
            element(by.binding("snippetWithTarget | linky:'_blank'")).getText()).
            toBe('http://angularjs.org/');
        expect(element(by.css('#linky-target a')).getAttribute('target')).toEqual('_blank');
       });
     </file>
   </example>
 */
angular.module('ngSanitize').filter('linky', ['$sanitize', function($sanitize) {
  var LINKY_URL_REGEXP =
        /((ftp|https?):\/\/|(www\.)|(mailto:)?[A-Za-z0-9._%+-]+@)\S*[^\s.;,(){}<>"”’]/i,
      MAILTO_REGEXP = /^mailto:/i;

  return function(text, target) {
    if (!text) return text;
    var match;
    var raw = text;
    var html = [];
    var url;
    var i;
    while ((match = raw.match(LINKY_URL_REGEXP))) {
      // We can not end in these as they are sometimes found at the end of the sentence
      url = match[0];
      // if we did not match ftp/http/www/mailto then assume mailto
      if (!match[2] && !match[4]) {
        url = (match[3] ? 'http://' : 'mailto:') + url;
      }
      i = match.index;
      addText(raw.substr(0, i));
      addLink(url, match[0].replace(MAILTO_REGEXP, ''));
      raw = raw.substring(i + match[0].length);
    }
    addText(raw);
    return $sanitize(html.join(''));

    function addText(text) {
      if (!text) {
        return;
      }
      html.push(sanitizeText(text));
    }

    function addLink(url, text) {
      html.push('<a ');
      if (angular.isDefined(target)) {
        html.push('target="',
                  target,
                  '" ');
      }
      html.push('href="',
                url.replace(/"/g, '&quot;'),
                '">');
      addText(text);
      html.push('</a>');
    }
  };
}]);


})(window, window.angular);

// Copyright 2009-2012 by contributors, MIT License
// vim: ts=4 sts=4 sw=4 expandtab

//Add semicolon to prevent IIFE from being passed as argument to concated code.
;
// Module systems magic dance
(function (definition) {
    // RequireJS
    if (typeof define == "function") {
        define(definition);
    // YUI3
    } else if (typeof YUI == "function") {
        YUI.add("es5", definition);
    // CommonJS and <script>
    } else {
        definition();
    }
})(function () {

/**
 * Brings an environment as close to ECMAScript 5 compliance
 * as is possible with the facilities of erstwhile engines.
 *
 * Annotated ES5: http://es5.github.com/ (specific links below)
 * ES5 Spec: http://www.ecma-international.org/publications/files/ECMA-ST/Ecma-262.pdf
 * Required reading: http://javascriptweblog.wordpress.com/2011/12/05/extending-javascript-natives/
 */

// ES-5 15.1.2.2
if (parseInt('08') !== 8) {
    parseInt = (function (origParseInt) {
        var hexRegex = /^0[xX]/;
        return function parseIntES5(str, radix) {
            str = String(str).trim();
            if (!+radix) {
                radix = hexRegex.test(str) ? 16 : 10;
            }
            return origParseInt(str, radix);
        };
    }(parseInt));
}

//
// Function
// ========
//

// ES-5 15.3.4.5
// http://es5.github.com/#x15.3.4.5

function Empty() {}

if (!Function.prototype.bind) {
    Function.prototype.bind = function bind(that) { // .length is 1
        // 1. Let Target be the this value.
        var target = this;
        // 2. If IsCallable(Target) is false, throw a TypeError exception.
        if (typeof target != "function") {
            throw new TypeError("Function.prototype.bind called on incompatible " + target);
        }
        // 3. Let A be a new (possibly empty) internal list of all of the
        //   argument values provided after thisArg (arg1, arg2 etc), in order.
        // XXX slicedArgs will stand in for "A" if used
        var args = _Array_slice_.call(arguments, 1); // for normal call
        // 4. Let F be a new native ECMAScript object.
        // 11. Set the [[Prototype]] internal property of F to the standard
        //   built-in Function prototype object as specified in 15.3.3.1.
        // 12. Set the [[Call]] internal property of F as described in
        //   15.3.4.5.1.
        // 13. Set the [[Construct]] internal property of F as described in
        //   15.3.4.5.2.
        // 14. Set the [[HasInstance]] internal property of F as described in
        //   15.3.4.5.3.
        var binder = function () {

            if (this instanceof bound) {
                // 15.3.4.5.2 [[Construct]]
                // When the [[Construct]] internal method of a function object,
                // F that was created using the bind function is called with a
                // list of arguments ExtraArgs, the following steps are taken:
                // 1. Let target be the value of F's [[TargetFunction]]
                //   internal property.
                // 2. If target has no [[Construct]] internal method, a
                //   TypeError exception is thrown.
                // 3. Let boundArgs be the value of F's [[BoundArgs]] internal
                //   property.
                // 4. Let args be a new list containing the same values as the
                //   list boundArgs in the same order followed by the same
                //   values as the list ExtraArgs in the same order.
                // 5. Return the result of calling the [[Construct]] internal
                //   method of target providing args as the arguments.

                var result = target.apply(
                    this,
                    args.concat(_Array_slice_.call(arguments))
                );
                if (Object(result) === result) {
                    return result;
                }
                return this;

            } else {
                // 15.3.4.5.1 [[Call]]
                // When the [[Call]] internal method of a function object, F,
                // which was created using the bind function is called with a
                // this value and a list of arguments ExtraArgs, the following
                // steps are taken:
                // 1. Let boundArgs be the value of F's [[BoundArgs]] internal
                //   property.
                // 2. Let boundThis be the value of F's [[BoundThis]] internal
                //   property.
                // 3. Let target be the value of F's [[TargetFunction]] internal
                //   property.
                // 4. Let args be a new list containing the same values as the
                //   list boundArgs in the same order followed by the same
                //   values as the list ExtraArgs in the same order.
                // 5. Return the result of calling the [[Call]] internal method
                //   of target providing boundThis as the this value and
                //   providing args as the arguments.

                // equiv: target.call(this, ...boundArgs, ...args)
                return target.apply(
                    that,
                    args.concat(_Array_slice_.call(arguments))
                );

            }

        };

        // 15. If the [[Class]] internal property of Target is "Function", then
        //     a. Let L be the length property of Target minus the length of A.
        //     b. Set the length own property of F to either 0 or L, whichever is
        //       larger.
        // 16. Else set the length own property of F to 0.

        var boundLength = Math.max(0, target.length - args.length);

        // 17. Set the attributes of the length own property of F to the values
        //   specified in 15.3.5.1.
        var boundArgs = [];
        for (var i = 0; i < boundLength; i++) {
            boundArgs.push("$" + i);
        }

        // XXX Build a dynamic function with desired amount of arguments is the only 
        // way to set the length property of a function. 
        // In environments where Content Security Policies enabled (Chrome extensions, 
        // for ex.) all use of eval or Function costructor throws an exception. 
        // However in all of these environments Function.prototype.bind exists 
        // and so this code will never be executed.
        var bound = Function("binder", "return function(" + boundArgs.join(",") + "){return binder.apply(this,arguments)}")(binder);

        if (target.prototype) {
            Empty.prototype = target.prototype;
            bound.prototype = new Empty();
            // Clean up dangling references.
            Empty.prototype = null;
        }

        // TODO
        // 18. Set the [[Extensible]] internal property of F to true.

        // TODO
        // 19. Let thrower be the [[ThrowTypeError]] function Object (13.2.3).
        // 20. Call the [[DefineOwnProperty]] internal method of F with
        //   arguments "caller", PropertyDescriptor {[[Get]]: thrower, [[Set]]:
        //   thrower, [[Enumerable]]: false, [[Configurable]]: false}, and
        //   false.
        // 21. Call the [[DefineOwnProperty]] internal method of F with
        //   arguments "arguments", PropertyDescriptor {[[Get]]: thrower,
        //   [[Set]]: thrower, [[Enumerable]]: false, [[Configurable]]: false},
        //   and false.

        // TODO
        // NOTE Function objects created using Function.prototype.bind do not
        // have a prototype property or the [[Code]], [[FormalParameters]], and
        // [[Scope]] internal properties.
        // XXX can't delete prototype in pure-js.

        // 22. Return F.
        return bound;
    };
}

// Shortcut to an often accessed properties, in order to avoid multiple
// dereference that costs universally.
// _Please note: Shortcuts are defined after `Function.prototype.bind` as we
// us it in defining shortcuts.
var call = Function.prototype.call;
var prototypeOfArray = Array.prototype;
var prototypeOfObject = Object.prototype;
var _Array_slice_ = prototypeOfArray.slice;
// Having a toString local variable name breaks in Opera so use _toString.
var _toString = call.bind(prototypeOfObject.toString);
var owns = call.bind(prototypeOfObject.hasOwnProperty);

// If JS engine supports accessors creating shortcuts.
var defineGetter;
var defineSetter;
var lookupGetter;
var lookupSetter;
var supportsAccessors;
if ((supportsAccessors = owns(prototypeOfObject, "__defineGetter__"))) {
    defineGetter = call.bind(prototypeOfObject.__defineGetter__);
    defineSetter = call.bind(prototypeOfObject.__defineSetter__);
    lookupGetter = call.bind(prototypeOfObject.__lookupGetter__);
    lookupSetter = call.bind(prototypeOfObject.__lookupSetter__);
}

//
// Array
// =====
//

// ES5 15.4.4.12
// http://es5.github.com/#x15.4.4.12
// Default value for second param
// [bugfix, ielt9, old browsers]
// IE < 9 bug: [1,2].splice(0).join("") == "" but should be "12"
if ([1,2].splice(0).length != 2) {
    var array_splice = Array.prototype.splice;
    var array_push = Array.prototype.push;
    var array_unshift = Array.prototype.unshift;

    if (function() { // test IE < 9 to splice bug - see issue #138
        function makeArray(l) {
            var a = [];
            while (l--) {
                a.unshift(l)
            }
            return a
        }

        var array = []
            , lengthBefore
        ;

        array.splice.bind(array, 0, 0).apply(null, makeArray(20));
        array.splice.bind(array, 0, 0).apply(null, makeArray(26));

        lengthBefore = array.length; //20
        array.splice(5, 0, "XXX"); // add one element

        if (lengthBefore + 1 == array.length) {
            return true;// has right splice implementation without bugs
        }
        // else {
        //    IE8 bug
        // }
    }()) {//IE 6/7
        Array.prototype.splice = function(start, deleteCount) {
            if (!arguments.length) {
                return [];
            } else {
                return array_splice.apply(this, [
                    start === void 0 ? 0 : start,
                    deleteCount === void 0 ? (this.length - start) : deleteCount
                ].concat(_Array_slice_.call(arguments, 2)))
            }
        };
    }
    else {//IE8
        Array.prototype.splice = function(start, deleteCount) {
            var result
                , args = _Array_slice_.call(arguments, 2)
                , addElementsCount = args.length
            ;

            if (!arguments.length) {
                return [];
            }

            if (start === void 0) { // default
                start = 0;
            }
            if (deleteCount === void 0) { // default
                deleteCount = this.length - start;
            }

            if (addElementsCount > 0) {
                if (deleteCount <= 0) {
                    if (start == this.length) { // tiny optimisation #1
                        array_push.apply(this, args);
                        return [];
                    }

                    if (start == 0) { // tiny optimisation #2
                        array_unshift.apply(this, args);
                        return [];
                    }
                }

                // Array.prototype.splice implementation
                result = _Array_slice_.call(this, start, start + deleteCount);// delete part
                args.push.apply(args, _Array_slice_.call(this, start + deleteCount, this.length));// right part
                args.unshift.apply(args, _Array_slice_.call(this, 0, start));// left part

                // delete all items from this array and replace it to 'left part' + _Array_slice_.call(arguments, 2) + 'right part'
                args.unshift(0, this.length);

                array_splice.apply(this, args);

                return result;
            }

            return array_splice.call(this, start, deleteCount);
        }

    }
}

// ES5 15.4.4.12
// http://es5.github.com/#x15.4.4.13
// Return len+argCount.
// [bugfix, ielt8]
// IE < 8 bug: [].unshift(0) == undefined but should be "1"
if ([].unshift(0) != 1) {
    var array_unshift = Array.prototype.unshift;
    Array.prototype.unshift = function() {
        array_unshift.apply(this, arguments);
        return this.length;
    };
}

// ES5 15.4.3.2
// http://es5.github.com/#x15.4.3.2
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/isArray
if (!Array.isArray) {
    Array.isArray = function isArray(obj) {
        return _toString(obj) == "[object Array]";
    };
}

// The IsCallable() check in the Array functions
// has been replaced with a strict check on the
// internal class of the object to trap cases where
// the provided function was actually a regular
// expression literal, which in V8 and
// JavaScriptCore is a typeof "function".  Only in
// V8 are regular expression literals permitted as
// reduce parameters, so it is desirable in the
// general case for the shim to match the more
// strict and common behavior of rejecting regular
// expressions.

// ES5 15.4.4.18
// http://es5.github.com/#x15.4.4.18
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/array/forEach

// Check failure of by-index access of string characters (IE < 9)
// and failure of `0 in boxedString` (Rhino)
var boxedString = Object("a"),
    splitString = boxedString[0] != "a" || !(0 in boxedString);
// Check node 0.6.21 bug where third parameter is not boxed
var boxedForEach = true;
if (Array.prototype.forEach) {
    Array.prototype.forEach.call("foo", function(item, i, obj) {
        if (typeof obj !== 'object') boxedForEach = false;
    });
}

if (!Array.prototype.forEach || !boxedForEach) {
    Array.prototype.forEach = function forEach(fun /*, thisp*/) {
        var object = toObject(this),
            self = splitString && _toString(this) == "[object String]" ?
                this.split("") :
                object,
            thisp = arguments[1],
            i = -1,
            length = self.length >>> 0;

        // If no callback function or if callback is not a callable function
        if (_toString(fun) != "[object Function]") {
            throw new TypeError(); // TODO message
        }

        while (++i < length) {
            if (i in self) {
                // Invoke the callback function with call, passing arguments:
                // context, property value, property key, thisArg object
                // context
                fun.call(thisp, self[i], i, object);
            }
        }
    };
}

// ES5 15.4.4.19
// http://es5.github.com/#x15.4.4.19
// https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/map
if (!Array.prototype.map) {
    Array.prototype.map = function map(fun /*, thisp*/) {
        var object = toObject(this),
            self = splitString && _toString(this) == "[object String]" ?
                this.split("") :
                object,
            length = self.length >>> 0,
            result = Array(length),
            thisp = arguments[1];

        // If no callback function or if callback is not a callable function
        if (_toString(fun) != "[object Function]") {
            throw new TypeError(fun + " is not a function");
        }

        for (var i = 0; i < length; i++) {
            if (i in self)
                result[i] = fun.call(thisp, self[i], i, object);
        }
        return result;
    };
}

// ES5 15.4.4.20
// http://es5.github.com/#x15.4.4.20
// https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/filter
if (!Array.prototype.filter) {
    Array.prototype.filter = function filter(fun /*, thisp */) {
        var object = toObject(this),
            self = splitString && _toString(this) == "[object String]" ?
                this.split("") :
                    object,
            length = self.length >>> 0,
            result = [],
            value,
            thisp = arguments[1];

        // If no callback function or if callback is not a callable function
        if (_toString(fun) != "[object Function]") {
            throw new TypeError(fun + " is not a function");
        }

        for (var i = 0; i < length; i++) {
            if (i in self) {
                value = self[i];
                if (fun.call(thisp, value, i, object)) {
                    result.push(value);
                }
            }
        }
        return result;
    };
}

// ES5 15.4.4.16
// http://es5.github.com/#x15.4.4.16
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/every
if (!Array.prototype.every) {
    Array.prototype.every = function every(fun /*, thisp */) {
        var object = toObject(this),
            self = splitString && _toString(this) == "[object String]" ?
                this.split("") :
                object,
            length = self.length >>> 0,
            thisp = arguments[1];

        // If no callback function or if callback is not a callable function
        if (_toString(fun) != "[object Function]") {
            throw new TypeError(fun + " is not a function");
        }

        for (var i = 0; i < length; i++) {
            if (i in self && !fun.call(thisp, self[i], i, object)) {
                return false;
            }
        }
        return true;
    };
}

// ES5 15.4.4.17
// http://es5.github.com/#x15.4.4.17
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/some
if (!Array.prototype.some) {
    Array.prototype.some = function some(fun /*, thisp */) {
        var object = toObject(this),
            self = splitString && _toString(this) == "[object String]" ?
                this.split("") :
                object,
            length = self.length >>> 0,
            thisp = arguments[1];

        // If no callback function or if callback is not a callable function
        if (_toString(fun) != "[object Function]") {
            throw new TypeError(fun + " is not a function");
        }

        for (var i = 0; i < length; i++) {
            if (i in self && fun.call(thisp, self[i], i, object)) {
                return true;
            }
        }
        return false;
    };
}

// ES5 15.4.4.21
// http://es5.github.com/#x15.4.4.21
// https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/reduce
if (!Array.prototype.reduce) {
    Array.prototype.reduce = function reduce(fun /*, initial*/) {
        var object = toObject(this),
            self = splitString && _toString(this) == "[object String]" ?
                this.split("") :
                object,
            length = self.length >>> 0;

        // If no callback function or if callback is not a callable function
        if (_toString(fun) != "[object Function]") {
            throw new TypeError(fun + " is not a function");
        }

        // no value to return if no initial value and an empty array
        if (!length && arguments.length == 1) {
            throw new TypeError("reduce of empty array with no initial value");
        }

        var i = 0;
        var result;
        if (arguments.length >= 2) {
            result = arguments[1];
        } else {
            do {
                if (i in self) {
                    result = self[i++];
                    break;
                }

                // if array contains no values, no initial value to return
                if (++i >= length) {
                    throw new TypeError("reduce of empty array with no initial value");
                }
            } while (true);
        }

        for (; i < length; i++) {
            if (i in self) {
                result = fun.call(void 0, result, self[i], i, object);
            }
        }

        return result;
    };
}

// ES5 15.4.4.22
// http://es5.github.com/#x15.4.4.22
// https://developer.mozilla.org/en/Core_JavaScript_1.5_Reference/Objects/Array/reduceRight
if (!Array.prototype.reduceRight) {
    Array.prototype.reduceRight = function reduceRight(fun /*, initial*/) {
        var object = toObject(this),
            self = splitString && _toString(this) == "[object String]" ?
                this.split("") :
                object,
            length = self.length >>> 0;

        // If no callback function or if callback is not a callable function
        if (_toString(fun) != "[object Function]") {
            throw new TypeError(fun + " is not a function");
        }

        // no value to return if no initial value, empty array
        if (!length && arguments.length == 1) {
            throw new TypeError("reduceRight of empty array with no initial value");
        }

        var result, i = length - 1;
        if (arguments.length >= 2) {
            result = arguments[1];
        } else {
            do {
                if (i in self) {
                    result = self[i--];
                    break;
                }

                // if array contains no values, no initial value to return
                if (--i < 0) {
                    throw new TypeError("reduceRight of empty array with no initial value");
                }
            } while (true);
        }

        if (i < 0) {
            return result;
        }

        do {
            if (i in this) {
                result = fun.call(void 0, result, self[i], i, object);
            }
        } while (i--);

        return result;
    };
}

// ES5 15.4.4.14
// http://es5.github.com/#x15.4.4.14
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/indexOf
if (!Array.prototype.indexOf || ([0, 1].indexOf(1, 2) != -1)) {
    Array.prototype.indexOf = function indexOf(sought /*, fromIndex */ ) {
        var self = splitString && _toString(this) == "[object String]" ?
                this.split("") :
                toObject(this),
            length = self.length >>> 0;

        if (!length) {
            return -1;
        }

        var i = 0;
        if (arguments.length > 1) {
            i = toInteger(arguments[1]);
        }

        // handle negative indices
        i = i >= 0 ? i : Math.max(0, length + i);
        for (; i < length; i++) {
            if (i in self && self[i] === sought) {
                return i;
            }
        }
        return -1;
    };
}

// ES5 15.4.4.15
// http://es5.github.com/#x15.4.4.15
// https://developer.mozilla.org/en/JavaScript/Reference/Global_Objects/Array/lastIndexOf
if (!Array.prototype.lastIndexOf || ([0, 1].lastIndexOf(0, -3) != -1)) {
    Array.prototype.lastIndexOf = function lastIndexOf(sought /*, fromIndex */) {
        var self = splitString && _toString(this) == "[object String]" ?
                this.split("") :
                toObject(this),
            length = self.length >>> 0;

        if (!length) {
            return -1;
        }
        var i = length - 1;
        if (arguments.length > 1) {
            i = Math.min(i, toInteger(arguments[1]));
        }
        // handle negative indices
        i = i >= 0 ? i : length - Math.abs(i);
        for (; i >= 0; i--) {
            if (i in self && sought === self[i]) {
                return i;
            }
        }
        return -1;
    };
}

//
// Object
// ======
//

// ES5 15.2.3.14
// http://es5.github.com/#x15.2.3.14
if (!Object.keys) {
    // http://whattheheadsaid.com/2010/10/a-safer-object-keys-compatibility-implementation
    var hasDontEnumBug = true,
        dontEnums = [
            "toString",
            "toLocaleString",
            "valueOf",
            "hasOwnProperty",
            "isPrototypeOf",
            "propertyIsEnumerable",
            "constructor"
        ],
        dontEnumsLength = dontEnums.length;

    for (var key in {"toString": null}) {
        hasDontEnumBug = false;
    }

    Object.keys = function keys(object) {

        if (
            (typeof object != "object" && typeof object != "function") ||
            object === null
        ) {
            throw new TypeError("Object.keys called on a non-object");
        }

        var keys = [];
        for (var name in object) {
            if (owns(object, name)) {
                keys.push(name);
            }
        }

        if (hasDontEnumBug) {
            for (var i = 0, ii = dontEnumsLength; i < ii; i++) {
                var dontEnum = dontEnums[i];
                if (owns(object, dontEnum)) {
                    keys.push(dontEnum);
                }
            }
        }
        return keys;
    };

}

//
// Date
// ====
//

// ES5 15.9.5.43
// http://es5.github.com/#x15.9.5.43
// This function returns a String value represent the instance in time
// represented by this Date object. The format of the String is the Date Time
// string format defined in 15.9.1.15. All fields are present in the String.
// The time zone is always UTC, denoted by the suffix Z. If the time value of
// this object is not a finite Number a RangeError exception is thrown.
var negativeDate = -62198755200000,
    negativeYearString = "-000001";
if (
    !Date.prototype.toISOString ||
    (new Date(negativeDate).toISOString().indexOf(negativeYearString) === -1)
) {
    Date.prototype.toISOString = function toISOString() {
        var result, length, value, year, month;
        if (!isFinite(this)) {
            throw new RangeError("Date.prototype.toISOString called on non-finite value.");
        }

        year = this.getUTCFullYear();

        month = this.getUTCMonth();
        // see https://github.com/es-shims/es5-shim/issues/111
        year += Math.floor(month / 12);
        month = (month % 12 + 12) % 12;

        // the date time string format is specified in 15.9.1.15.
        result = [month + 1, this.getUTCDate(),
            this.getUTCHours(), this.getUTCMinutes(), this.getUTCSeconds()];
        year = (
            (year < 0 ? "-" : (year > 9999 ? "+" : "")) +
            ("00000" + Math.abs(year))
            .slice(0 <= year && year <= 9999 ? -4 : -6)
        );

        length = result.length;
        while (length--) {
            value = result[length];
            // pad months, days, hours, minutes, and seconds to have two
            // digits.
            if (value < 10) {
                result[length] = "0" + value;
            }
        }
        // pad milliseconds to have three digits.
        return (
            year + "-" + result.slice(0, 2).join("-") +
            "T" + result.slice(2).join(":") + "." +
            ("000" + this.getUTCMilliseconds()).slice(-3) + "Z"
        );
    };
}


// ES5 15.9.5.44
// http://es5.github.com/#x15.9.5.44
// This function provides a String representation of a Date object for use by
// JSON.stringify (15.12.3).
var dateToJSONIsSupported = false;
try {
    dateToJSONIsSupported = (
        Date.prototype.toJSON &&
        new Date(NaN).toJSON() === null &&
        new Date(negativeDate).toJSON().indexOf(negativeYearString) !== -1 &&
        Date.prototype.toJSON.call({ // generic
            toISOString: function () {
                return true;
            }
        })
    );
} catch (e) {
}
if (!dateToJSONIsSupported) {
    Date.prototype.toJSON = function toJSON(key) {
        // When the toJSON method is called with argument key, the following
        // steps are taken:

        // 1.  Let O be the result of calling ToObject, giving it the this
        // value as its argument.
        // 2. Let tv be toPrimitive(O, hint Number).
        var o = Object(this),
            tv = toPrimitive(o),
            toISO;
        // 3. If tv is a Number and is not finite, return null.
        if (typeof tv === "number" && !isFinite(tv)) {
            return null;
        }
        // 4. Let toISO be the result of calling the [[Get]] internal method of
        // O with argument "toISOString".
        toISO = o.toISOString;
        // 5. If IsCallable(toISO) is false, throw a TypeError exception.
        if (typeof toISO != "function") {
            throw new TypeError("toISOString property is not callable");
        }
        // 6. Return the result of calling the [[Call]] internal method of
        //  toISO with O as the this value and an empty argument list.
        return toISO.call(o);

        // NOTE 1 The argument is ignored.

        // NOTE 2 The toJSON function is intentionally generic; it does not
        // require that its this value be a Date object. Therefore, it can be
        // transferred to other kinds of objects for use as a method. However,
        // it does require that any such object have a toISOString method. An
        // object is free to use the argument key to filter its
        // stringification.
    };
}

// ES5 15.9.4.2
// http://es5.github.com/#x15.9.4.2
// based on work shared by Daniel Friesen (dantman)
// http://gist.github.com/303249
if (!Date.parse || "Date.parse is buggy") {
    // XXX global assignment won't work in embeddings that use
    // an alternate object for the context.
    Date = (function(NativeDate) {

        // Date.length === 7
        function Date(Y, M, D, h, m, s, ms) {
            var length = arguments.length;
            if (this instanceof NativeDate) {
                var date = length == 1 && String(Y) === Y ? // isString(Y)
                    // We explicitly pass it through parse:
                    new NativeDate(Date.parse(Y)) :
                    // We have to manually make calls depending on argument
                    // length here
                    length >= 7 ? new NativeDate(Y, M, D, h, m, s, ms) :
                    length >= 6 ? new NativeDate(Y, M, D, h, m, s) :
                    length >= 5 ? new NativeDate(Y, M, D, h, m) :
                    length >= 4 ? new NativeDate(Y, M, D, h) :
                    length >= 3 ? new NativeDate(Y, M, D) :
                    length >= 2 ? new NativeDate(Y, M) :
                    length >= 1 ? new NativeDate(Y) :
                                  new NativeDate();
                // Prevent mixups with unfixed Date object
                date.constructor = Date;
                return date;
            }
            return NativeDate.apply(this, arguments);
        };

        // 15.9.1.15 Date Time String Format.
        var isoDateExpression = new RegExp("^" +
            "(\\d{4}|[\+\-]\\d{6})" + // four-digit year capture or sign +
                                      // 6-digit extended year
            "(?:-(\\d{2})" + // optional month capture
            "(?:-(\\d{2})" + // optional day capture
            "(?:" + // capture hours:minutes:seconds.milliseconds
                "T(\\d{2})" + // hours capture
                ":(\\d{2})" + // minutes capture
                "(?:" + // optional :seconds.milliseconds
                    ":(\\d{2})" + // seconds capture
                    "(?:(\\.\\d{1,}))?" + // milliseconds capture
                ")?" +
            "(" + // capture UTC offset component
                "Z|" + // UTC capture
                "(?:" + // offset specifier +/-hours:minutes
                    "([-+])" + // sign capture
                    "(\\d{2})" + // hours offset capture
                    ":(\\d{2})" + // minutes offset capture
                ")" +
            ")?)?)?)?" +
        "$");

        var months = [
            0, 31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334, 365
        ];

        function dayFromMonth(year, month) {
            var t = month > 1 ? 1 : 0;
            return (
                months[month] +
                Math.floor((year - 1969 + t) / 4) -
                Math.floor((year - 1901 + t) / 100) +
                Math.floor((year - 1601 + t) / 400) +
                365 * (year - 1970)
            );
        }

        function toUTC(t) {
            return Number(new NativeDate(1970, 0, 1, 0, 0, 0, t));
        }

        // Copy any custom methods a 3rd party library may have added
        for (var key in NativeDate) {
            Date[key] = NativeDate[key];
        }

        // Copy "native" methods explicitly; they may be non-enumerable
        Date.now = NativeDate.now;
        Date.UTC = NativeDate.UTC;
        Date.prototype = NativeDate.prototype;
        Date.prototype.constructor = Date;

        // Upgrade Date.parse to handle simplified ISO 8601 strings
        Date.parse = function parse(string) {
            var match = isoDateExpression.exec(string);
            if (match) {
                // parse months, days, hours, minutes, seconds, and milliseconds
                // provide default values if necessary
                // parse the UTC offset component
                var year = Number(match[1]),
                    month = Number(match[2] || 1) - 1,
                    day = Number(match[3] || 1) - 1,
                    hour = Number(match[4] || 0),
                    minute = Number(match[5] || 0),
                    second = Number(match[6] || 0),
                    millisecond = Math.floor(Number(match[7] || 0) * 1000),
                    // When time zone is missed, local offset should be used
                    // (ES 5.1 bug)
                    // see https://bugs.ecmascript.org/show_bug.cgi?id=112
                    isLocalTime = Boolean(match[4] && !match[8]),
                    signOffset = match[9] === "-" ? 1 : -1,
                    hourOffset = Number(match[10] || 0),
                    minuteOffset = Number(match[11] || 0),
                    result;
                if (
                    hour < (
                        minute > 0 || second > 0 || millisecond > 0 ?
                        24 : 25
                    ) &&
                    minute < 60 && second < 60 && millisecond < 1000 &&
                    month > -1 && month < 12 && hourOffset < 24 &&
                    minuteOffset < 60 && // detect invalid offsets
                    day > -1 &&
                    day < (
                        dayFromMonth(year, month + 1) -
                        dayFromMonth(year, month)
                    )
                ) {
                    result = (
                        (dayFromMonth(year, month) + day) * 24 +
                        hour +
                        hourOffset * signOffset
                    ) * 60;
                    result = (
                        (result + minute + minuteOffset * signOffset) * 60 +
                        second
                    ) * 1000 + millisecond;
                    if (isLocalTime) {
                        result = toUTC(result);
                    }
                    if (-8.64e15 <= result && result <= 8.64e15) {
                        return result;
                    }
                }
                return NaN;
            }
            return NativeDate.parse.apply(this, arguments);
        };

        return Date;
    })(Date);
}

// ES5 15.9.4.4
// http://es5.github.com/#x15.9.4.4
if (!Date.now) {
    Date.now = function now() {
        return new Date().getTime();
    };
}


//
// Number
// ======
//

// ES5.1 15.7.4.5
// http://es5.github.com/#x15.7.4.5
if (!Number.prototype.toFixed || (0.00008).toFixed(3) !== '0.000' || (0.9).toFixed(0) === '0' || (1.255).toFixed(2) !== '1.25' || (1000000000000000128).toFixed(0) !== "1000000000000000128") {
    // Hide these variables and functions
    (function () {
        var base, size, data, i;

        base = 1e7;
        size = 6;
        data = [0, 0, 0, 0, 0, 0];

        function multiply(n, c) {
            var i = -1;
            while (++i < size) {
                c += n * data[i];
                data[i] = c % base;
                c = Math.floor(c / base);
            }
        }

        function divide(n) {
            var i = size, c = 0;
            while (--i >= 0) {
                c += data[i];
                data[i] = Math.floor(c / n);
                c = (c % n) * base;
            }
        }

        function toString() {
            var i = size;
            var s = '';
            while (--i >= 0) {
                if (s !== '' || i === 0 || data[i] !== 0) {
                    var t = String(data[i]);
                    if (s === '') {
                        s = t;
                    } else {
                        s += '0000000'.slice(0, 7 - t.length) + t;
                    }
                }
            }
            return s;
        }

        function pow(x, n, acc) {
            return (n === 0 ? acc : (n % 2 === 1 ? pow(x, n - 1, acc * x) : pow(x * x, n / 2, acc)));
        }

        function log(x) {
            var n = 0;
            while (x >= 4096) {
                n += 12;
                x /= 4096;
            }
            while (x >= 2) {
                n += 1;
                x /= 2;
            }
            return n;
        }

        Number.prototype.toFixed = function (fractionDigits) {
            var f, x, s, m, e, z, j, k;

            // Test for NaN and round fractionDigits down
            f = Number(fractionDigits);
            f = f !== f ? 0 : Math.floor(f);

            if (f < 0 || f > 20) {
                throw new RangeError("Number.toFixed called with invalid number of decimals");
            }

            x = Number(this);

            // Test for NaN
            if (x !== x) {
                return "NaN";
            }

            // If it is too big or small, return the string value of the number
            if (x <= -1e21 || x >= 1e21) {
                return String(x);
            }

            s = "";

            if (x < 0) {
                s = "-";
                x = -x;
            }

            m = "0";

            if (x > 1e-21) {
                // 1e-21 < x < 1e21
                // -70 < log2(x) < 70
                e = log(x * pow(2, 69, 1)) - 69;
                z = (e < 0 ? x * pow(2, -e, 1) : x / pow(2, e, 1));
                z *= 0x10000000000000; // Math.pow(2, 52);
                e = 52 - e;

                // -18 < e < 122
                // x = z / 2 ^ e
                if (e > 0) {
                    multiply(0, z);
                    j = f;

                    while (j >= 7) {
                        multiply(1e7, 0);
                        j -= 7;
                    }

                    multiply(pow(10, j, 1), 0);
                    j = e - 1;

                    while (j >= 23) {
                        divide(1 << 23);
                        j -= 23;
                    }

                    divide(1 << j);
                    multiply(1, 1);
                    divide(2);
                    m = toString();
                } else {
                    multiply(0, z);
                    multiply(1 << (-e), 0);
                    m = toString() + '0.00000000000000000000'.slice(2, 2 + f);
                }
            }

            if (f > 0) {
                k = m.length;

                if (k <= f) {
                    m = s + '0.0000000000000000000'.slice(0, f - k + 2) + m;
                } else {
                    m = s + m.slice(0, k - f) + '.' + m.slice(k - f);
                }
            } else {
                m = s + m;
            }

            return m;
        }
    }());
}


//
// String
// ======
//


// ES5 15.5.4.14
// http://es5.github.com/#x15.5.4.14

// [bugfix, IE lt 9, firefox 4, Konqueror, Opera, obscure browsers]
// Many browsers do not split properly with regular expressions or they
// do not perform the split correctly under obscure conditions.
// See http://blog.stevenlevithan.com/archives/cross-browser-split
// I've tested in many browsers and this seems to cover the deviant ones:
//    'ab'.split(/(?:ab)*/) should be ["", ""], not [""]
//    '.'.split(/(.?)(.?)/) should be ["", ".", "", ""], not ["", ""]
//    'tesst'.split(/(s)*/) should be ["t", undefined, "e", "s", "t"], not
//       [undefined, "t", undefined, "e", ...]
//    ''.split(/.?/) should be [], not [""]
//    '.'.split(/()()/) should be ["."], not ["", "", "."]

var string_split = String.prototype.split;
if (
    'ab'.split(/(?:ab)*/).length !== 2 ||
    '.'.split(/(.?)(.?)/).length !== 4 ||
    'tesst'.split(/(s)*/)[1] === "t" ||
    ''.split(/.?/).length ||
    '.'.split(/()()/).length > 1
) {
    (function () {
        var compliantExecNpcg = /()??/.exec("")[1] === void 0; // NPCG: nonparticipating capturing group

        String.prototype.split = function (separator, limit) {
            var string = this;
            if (separator === void 0 && limit === 0)
                return [];

            // If `separator` is not a regex, use native split
            if (Object.prototype.toString.call(separator) !== "[object RegExp]") {
                return string_split.apply(this, arguments);
            }

            var output = [],
                flags = (separator.ignoreCase ? "i" : "") +
                        (separator.multiline  ? "m" : "") +
                        (separator.extended   ? "x" : "") + // Proposed for ES6
                        (separator.sticky     ? "y" : ""), // Firefox 3+
                lastLastIndex = 0,
                // Make `global` and avoid `lastIndex` issues by working with a copy
                separator = new RegExp(separator.source, flags + "g"),
                separator2, match, lastIndex, lastLength;
            string += ""; // Type-convert
            if (!compliantExecNpcg) {
                // Doesn't need flags gy, but they don't hurt
                separator2 = new RegExp("^" + separator.source + "$(?!\\s)", flags);
            }
            /* Values for `limit`, per the spec:
             * If undefined: 4294967295 // Math.pow(2, 32) - 1
             * If 0, Infinity, or NaN: 0
             * If positive number: limit = Math.floor(limit); if (limit > 4294967295) limit -= 4294967296;
             * If negative number: 4294967296 - Math.floor(Math.abs(limit))
             * If other: Type-convert, then use the above rules
             */
            limit = limit === void 0 ?
                -1 >>> 0 : // Math.pow(2, 32) - 1
                limit >>> 0; // ToUint32(limit)
            while (match = separator.exec(string)) {
                // `separator.lastIndex` is not reliable cross-browser
                lastIndex = match.index + match[0].length;
                if (lastIndex > lastLastIndex) {
                    output.push(string.slice(lastLastIndex, match.index));
                    // Fix browsers whose `exec` methods don't consistently return `undefined` for
                    // nonparticipating capturing groups
                    if (!compliantExecNpcg && match.length > 1) {
                        match[0].replace(separator2, function () {
                            for (var i = 1; i < arguments.length - 2; i++) {
                                if (arguments[i] === void 0) {
                                    match[i] = void 0;
                                }
                            }
                        });
                    }
                    if (match.length > 1 && match.index < string.length) {
                        Array.prototype.push.apply(output, match.slice(1));
                    }
                    lastLength = match[0].length;
                    lastLastIndex = lastIndex;
                    if (output.length >= limit) {
                        break;
                    }
                }
                if (separator.lastIndex === match.index) {
                    separator.lastIndex++; // Avoid an infinite loop
                }
            }
            if (lastLastIndex === string.length) {
                if (lastLength || !separator.test("")) {
                    output.push("");
                }
            } else {
                output.push(string.slice(lastLastIndex));
            }
            return output.length > limit ? output.slice(0, limit) : output;
        };
    }());

// [bugfix, chrome]
// If separator is undefined, then the result array contains just one String,
// which is the this value (converted to a String). If limit is not undefined,
// then the output array is truncated so that it contains no more than limit
// elements.
// "0".split(undefined, 0) -> []
} else if ("0".split(void 0, 0).length) {
    String.prototype.split = function(separator, limit) {
        if (separator === void 0 && limit === 0) return [];
        return string_split.apply(this, arguments);
    }
}


// ECMA-262, 3rd B.2.3
// Note an ECMAScript standart, although ECMAScript 3rd Edition has a
// non-normative section suggesting uniform semantics and it should be
// normalized across all browsers
// [bugfix, IE lt 9] IE < 9 substr() with negative value not working in IE
if ("".substr && "0b".substr(-1) !== "b") {
    var string_substr = String.prototype.substr;
    /**
     *  Get the substring of a string
     *  @param  {integer}  start   where to start the substring
     *  @param  {integer}  length  how many characters to return
     *  @return {string}
     */
    String.prototype.substr = function(start, length) {
        return string_substr.call(
            this,
            start < 0 ? ((start = this.length + start) < 0 ? 0 : start) : start,
            length
        );
    }
}

// ES5 15.5.4.20
// http://es5.github.com/#x15.5.4.20
var ws = "\x09\x0A\x0B\x0C\x0D\x20\xA0\u1680\u180E\u2000\u2001\u2002\u2003" +
    "\u2004\u2005\u2006\u2007\u2008\u2009\u200A\u202F\u205F\u3000\u2028" +
    "\u2029\uFEFF";
if (!String.prototype.trim || ws.trim()) {
    // http://blog.stevenlevithan.com/archives/faster-trim-javascript
    // http://perfectionkills.com/whitespace-deviations/
    ws = "[" + ws + "]";
    var trimBeginRegexp = new RegExp("^" + ws + ws + "*"),
        trimEndRegexp = new RegExp(ws + ws + "*$");
    String.prototype.trim = function trim() {
        if (this === void 0 || this === null) {
            throw new TypeError("can't convert "+this+" to object");
        }
        return String(this)
            .replace(trimBeginRegexp, "")
            .replace(trimEndRegexp, "");
    };
}

//
// Util
// ======
//

// ES5 9.4
// http://es5.github.com/#x9.4
// http://jsperf.com/to-integer

function toInteger(n) {
    n = +n;
    if (n !== n) { // isNaN
        n = 0;
    } else if (n !== 0 && n !== (1/0) && n !== -(1/0)) {
        n = (n > 0 || -1) * Math.floor(Math.abs(n));
    }
    return n;
}

function isPrimitive(input) {
    var type = typeof input;
    return (
        input === null ||
        type === "undefined" ||
        type === "boolean" ||
        type === "number" ||
        type === "string"
    );
}

function toPrimitive(input) {
    var val, valueOf, toString;
    if (isPrimitive(input)) {
        return input;
    }
    valueOf = input.valueOf;
    if (typeof valueOf === "function") {
        val = valueOf.call(input);
        if (isPrimitive(val)) {
            return val;
        }
    }
    toString = input.toString;
    if (typeof toString === "function") {
        val = toString.call(input);
        if (isPrimitive(val)) {
            return val;
        }
    }
    throw new TypeError();
}

// ES5 9.9
// http://es5.github.com/#x9.9
var toObject = function (o) {
    if (o == null) { // this matches both null and undefined
        throw new TypeError("can't convert "+o+" to object");
    }
    return Object(o);
};

});

(function webpackUniversalModuleDefinition(root, factory) {
	if(typeof exports === 'object' && typeof module === 'object')
		module.exports = factory(require("fs"));
	else if(typeof define === 'function' && define.amd)
		define(["fs"], factory);
	else if(typeof exports === 'object')
		exports["Parser"] = factory(require("fs"));
	else
		root["RAML"] = root["RAML"] || {}, root["RAML"]["Parser"] = factory(root["fs"]);
})(this, function(__WEBPACK_EXTERNAL_MODULE_36__) {
return /******/ (function(modules) { // webpackBootstrap
/******/ 	// The module cache
/******/ 	var installedModules = {};
/******/
/******/ 	// The require function
/******/ 	function __webpack_require__(moduleId) {
/******/
/******/ 		// Check if module is in cache
/******/ 		if(installedModules[moduleId])
/******/ 			return installedModules[moduleId].exports;
/******/
/******/ 		// Create a new module (and put it into the cache)
/******/ 		var module = installedModules[moduleId] = {
/******/ 			exports: {},
/******/ 			id: moduleId,
/******/ 			loaded: false
/******/ 		};
/******/
/******/ 		// Execute the module function
/******/ 		modules[moduleId].call(module.exports, module, module.exports, __webpack_require__);
/******/
/******/ 		// Flag the module as loaded
/******/ 		module.loaded = true;
/******/
/******/ 		// Return the exports of the module
/******/ 		return module.exports;
/******/ 	}
/******/
/******/
/******/ 	// expose the modules object (__webpack_modules__)
/******/ 	__webpack_require__.m = modules;
/******/
/******/ 	// expose the module cache
/******/ 	__webpack_require__.c = installedModules;
/******/
/******/ 	// __webpack_public_path__
/******/ 	__webpack_require__.p = "";
/******/
/******/ 	// Load entry module and return exports
/******/ 	return __webpack_require__(0);
/******/ })
/************************************************************************/
/******/ ([
/* 0 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var apiLoader = __webpack_require__(9);
	var path = __webpack_require__(15);
	var PromiseConstructor = __webpack_require__(20);
	/**
	 * RAML 1.0 top-level AST interfaces.
	 */
	exports.api10 = __webpack_require__(12);
	/**
	 * RAML 0.8 top-level AST interfaces.
	 */
	exports.api08 = __webpack_require__(13);
	function loadApiSync(apiPath, arg1, arg2) {
	    return apiLoader.loadApi(apiPath, arg1, arg2).getOrElse(null);
	}
	exports.loadApiSync = loadApiSync;
	function loadRAMLSync(ramlPath, arg1, arg2) {
	    return apiLoader.loadApi(ramlPath, arg1, arg2).getOrElse(null);
	}
	exports.loadRAMLSync = loadRAMLSync;
	function optionsForContent(content, arg2) {
	    return {
	        fsResolver: {
	            content: function (pathStr) {
	                if (pathStr == path.resolve("/", "#local.raml")) {
	                    return content;
	                }
	                if (arg2) {
	                    if (arg2.fsResolver) {
	                        return arg2.fsResolver.content(pathStr);
	                    }
	                }
	            },
	            contentAsync: function (pathStr) {
	                if (pathStr == path.resolve("/", "#local.raml")) {
	                    return Promise.resolve(content);
	                }
	                if (arg2) {
	                    if (arg2.fsResolver) {
	                        return arg2.fsResolver.contentAsync(pathStr);
	                    }
	                }
	            }
	        },
	        httpResolver: arg2 ? arg2.httpResolver : null,
	        rejectOnErrors: arg2 ? arg2.rejectOnErrors : false,
	        attributeDefaults: arg2 ? arg2.attributeDefaults : true
	    };
	}
	/**
	 * Load RAML synchronously. May load both Api and Typed fragments. If the 'rejectOnErrors' option is set to true, [[ApiLoadingError]] is thrown for RAML which contains errors.
	 * @param content content of the raml
	 * @param options Load options  (note you should path a resolvers if you want includes to be resolved)
	 * @return RAMLLanguageElement instance.
	 **/
	function parseRAMLSync(content, arg2) {
	    return apiLoader.loadApi("/#local.raml", [], optionsForContent(content, arg2)).getOrElse(null);
	}
	exports.parseRAMLSync = parseRAMLSync;
	/**
	 * Load RAML asynchronously. May load both Api and Typed fragments. If the 'rejectOnErrors' option is set to true, [[ApiLoadingError]] is thrown for RAML which contains errors.
	 * @param content content of the raml
	 * @param options Load options  (note you should path a resolvers if you want includes to be resolved)
	 * @return RAMLLanguageElement instance.
	 **/
	function parseRAML(content, arg2) {
	    return apiLoader.loadApi("/#local.raml", [], optionsForContent(content, arg2)).getOrElse(null);
	}
	exports.parseRAML = parseRAML;
	function loadApi(apiPath, arg1, arg2) {
	    return apiLoader.loadApiAsync(apiPath, arg1, arg2);
	}
	exports.loadApi = loadApi;
	function loadRAML(ramlPath, arg1, arg2) {
	    return apiLoader.loadRAMLAsync(ramlPath, arg1, arg2);
	}
	exports.loadRAML = loadRAML;
	/**
	 * Gets AST node by runtime type, if runtime type matches any.
	 * @param runtimeType - runtime type to find the match for
	 */
	function getLanguageElementByRuntimeType(runtimeType) {
	    return apiLoader.getLanguageElementByRuntimeType(runtimeType);
	}
	exports.getLanguageElementByRuntimeType = getLanguageElementByRuntimeType;
	/**
	 * Check if the AST node represents fragment
	 */
	function isFragment(node) {
	    return exports.api10.isFragment(node);
	}
	exports.isFragment = isFragment;
	/**
	 * Convert fragment representing node to FragmentDeclaration instance.
	 */
	function asFragment(node) {
	    return exports.api10.asFragment(node);
	}
	exports.asFragment = asFragment;
	/**
	 * High-level AST interfaces.
	 */
	exports.hl = __webpack_require__(10);
	/**
	 * Low-level AST interfaces.
	 */
	exports.ll = __webpack_require__(11);
	/**
	 * Search functionality, operates on high AST level.
	 */
	exports.search = __webpack_require__(1);
	/**
	 * High-level stub node factory methods.
	 */
	exports.stubs = __webpack_require__(2);
	exports.utils = __webpack_require__(3);
	/**
	 * Low-level project factory.
	 */
	exports.project = __webpack_require__(4);
	/**
	 * Helpers for classification of high-level AST entity types.
	 */
	exports.universeHelpers = __webpack_require__(14);
	/**
	 * Definition system.
	 */
	exports.ds = __webpack_require__(33);
	/**
	 * Schema utilities.
	 */
	exports.schema = __webpack_require__(5);
	/**
	 * A set of constants describing definition system entities.
	 * @hidden
	 **/
	exports.universes = exports.ds.universesInfo;
	/**
	 * Exposed parser model modification methods. Operate on high-level.
	 */
	exports.parser = __webpack_require__(6);
	/**
	 * Applies traits and resources types to API on high-level.
	 * Top-level expansion should be performed via calling expand() method of API node.
	 */
	exports.expander = __webpack_require__(7);
	/**
	 * Exposed part of custom methods applied to top-level AST during generation.
	 * Not to be used by parser clients.
	 */
	exports.wrapperHelper = __webpack_require__(8);
	if (typeof Promise === 'undefined' && typeof window !== 'undefined') {
	    window.Promise = PromiseConstructor;
	}
	//# sourceMappingURL=index.js.map

/***/ },
/* 1 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var search = __webpack_require__(27);
	var hlimpl = __webpack_require__(16);
	(function (LocationKind) {
	    LocationKind[LocationKind["VALUE_COMPLETION"] = 0] = "VALUE_COMPLETION";
	    LocationKind[LocationKind["KEY_COMPLETION"] = 1] = "KEY_COMPLETION";
	    LocationKind[LocationKind["PATH_COMPLETION"] = 2] = "PATH_COMPLETION";
	    LocationKind[LocationKind["DIRECTIVE_COMPLETION"] = 3] = "DIRECTIVE_COMPLETION";
	    LocationKind[LocationKind["VERSION_COMPLETION"] = 4] = "VERSION_COMPLETION";
	    LocationKind[LocationKind["ANNOTATION_COMPLETION"] = 5] = "ANNOTATION_COMPLETION";
	    LocationKind[LocationKind["SEQUENCE_KEY_COPLETION"] = 6] = "SEQUENCE_KEY_COPLETION";
	    LocationKind[LocationKind["INCOMMENT"] = 7] = "INCOMMENT";
	})(exports.LocationKind || (exports.LocationKind = {}));
	var LocationKind = exports.LocationKind;
	function determineCompletionKind(text, offset) {
	    return search.determineCompletionKind(text, offset);
	}
	exports.determineCompletionKind = determineCompletionKind;
	function enumValues(c, n) {
	    return search.enumValues(c, n);
	}
	exports.enumValues = enumValues;
	function globalDeclarations(n) {
	    return search.globalDeclarations(n);
	}
	exports.globalDeclarations = globalDeclarations;
	function qName(n, p) {
	    return hlimpl.qName(n, p);
	}
	exports.qName = qName;
	function subTypesWithLocals(t, n) {
	    return search.subTypesWithLocals(t, n);
	}
	exports.subTypesWithLocals = subTypesWithLocals;
	function nodesDeclaringType(t, n) {
	    return search.nodesDeclaringType(t, n);
	}
	exports.nodesDeclaringType = nodesDeclaringType;
	function isExampleNodeContent(n) {
	    return search.isExampleNodeContent(n);
	}
	exports.isExampleNodeContent = isExampleNodeContent;
	function findExampleContentType(n) {
	    return search.findExampleContentType(n);
	}
	exports.findExampleContentType = findExampleContentType;
	function parseDocumentationContent(n, t) {
	    return search.parseDocumentationContent(n, t);
	}
	exports.parseDocumentationContent = parseDocumentationContent;
	function parseStructuredExample(exampleNode, type) {
	    return search.parseStructuredExample(exampleNode, type);
	}
	exports.parseStructuredExample = parseStructuredExample;
	function isExampleNode(node) {
	    return search.isExampleNode(node);
	}
	exports.isExampleNode = isExampleNode;
	function referenceTargets(p0, c) {
	    return search.referenceTargets(p0, c);
	}
	exports.referenceTargets = referenceTargets;
	function findUsages(unit, offset) {
	    return search.findUsages(unit, offset);
	}
	exports.findUsages = findUsages;
	function findDeclaration(unit, offset, nodePart) {
	    return search.findDeclaration(unit, offset, nodePart);
	}
	exports.findDeclaration = findDeclaration;
	//# sourceMappingURL=searchProxy.js.map

/***/ },
/* 2 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var __extends = (this && this.__extends) || function (d, b) {
	    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
	    function __() { this.constructor = d; }
	    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
	};
	var hlimpl = __webpack_require__(16);
	var jsyaml = __webpack_require__(21);
	var stubs = __webpack_require__(17);
	function createStubNode(t, p, key, unit) {
	    if (key === void 0) { key = null; }
	    return stubs.createStubNode(t, p, key, unit);
	}
	exports.createStubNode = createStubNode;
	function createStub(parent, property, key) {
	    return stubs.createStub(parent, property, key);
	}
	exports.createStub = createStub;
	function createStubNoParentPatch(parent, property, key) {
	    return stubs.createStub0(parent, property, key);
	}
	exports.createStubNoParentPatch = createStubNoParentPatch;
	function createResourceStub(parent, key) {
	    return stubs.createResourceStub(parent, key);
	}
	exports.createResourceStub = createResourceStub;
	function createMethodStub(parent, key) {
	    return stubs.createMethodStub(parent, key);
	}
	exports.createMethodStub = createMethodStub;
	function createResponseStub(parent, key) {
	    return stubs.createResourceStub(parent, key);
	}
	exports.createResponseStub = createResponseStub;
	function createBodyStub(parent, key) {
	    return stubs.createBodyStub(parent, key);
	}
	exports.createBodyStub = createBodyStub;
	function createUriParameterStub(parent, key) {
	    return stubs.createUriParameterStub(parent, key);
	}
	exports.createUriParameterStub = createUriParameterStub;
	function createQueryParameterStub(parent, key) {
	    return stubs.createQueryParameterStub(parent, key);
	}
	exports.createQueryParameterStub = createQueryParameterStub;
	function createASTPropImpl(node, parent, _def, _prop, fk) {
	    if (fk === void 0) { fk = false; }
	    return new hlimpl.ASTPropImpl(node, parent, _def, _prop, fk);
	}
	exports.createASTPropImpl = createASTPropImpl;
	function createASTNodeImpl(node, parent, _def, _prop) {
	    return new hlimpl.ASTNodeImpl(node, parent, _def, _prop);
	}
	exports.createASTNodeImpl = createASTNodeImpl;
	function createVirtualASTPropImpl(node, parent, _def, _prop) {
	    return new VirtualAttr(node, parent, _def, _prop);
	}
	exports.createVirtualASTPropImpl = createVirtualASTPropImpl;
	function createVirtualNodeImpl(node, parent, _def, _prop) {
	    return new VirtualNode(node, parent, _def, _prop);
	}
	exports.createVirtualNodeImpl = createVirtualNodeImpl;
	var VirtualAttr = (function (_super) {
	    __extends(VirtualAttr, _super);
	    function VirtualAttr() {
	        _super.apply(this, arguments);
	    }
	    VirtualAttr.prototype.value = function () {
	        return "";
	    };
	    return VirtualAttr;
	}(hlimpl.ASTPropImpl));
	var VirtualNode = (function (_super) {
	    __extends(VirtualNode, _super);
	    function VirtualNode() {
	        _super.apply(this, arguments);
	    }
	    VirtualNode.prototype.value = function () {
	        return "";
	    };
	    return VirtualNode;
	}(hlimpl.ASTNodeImpl));
	function createMapping(name, value) {
	    return jsyaml.createMapping(name, value);
	}
	exports.createMapping = createMapping;
	function createMap() {
	    return jsyaml.createMap([]);
	}
	exports.createMap = createMap;
	function createAttr(_property, val) {
	    return stubs.createAttr(_property, val);
	}
	exports.createAttr = createAttr;
	//# sourceMappingURL=stubProxy.js.map

/***/ },
/* 3 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var rs = __webpack_require__(22);
	var hlimpl = __webpack_require__(16);
	var defs = __webpack_require__(33);
	var jsyaml = __webpack_require__(21);
	var expander = __webpack_require__(24);
	var linter = __webpack_require__(25);
	var builder = __webpack_require__(26);
	function hasAsyncRequests() {
	    return rs.hasAsyncRequests();
	}
	exports.hasAsyncRequests = hasAsyncRequests;
	function addLoadCallback(x) {
	    rs.addLoadCallback(x);
	}
	exports.addLoadCallback = addLoadCallback;
	function getTransformerNames() {
	    return expander.getTransformNames();
	}
	exports.getTransformerNames = getTransformerNames;
	exports.updateType = function (node) {
	    var type = builder.doDescrimination(node);
	    if (type == null && node.property()) {
	        type = node.property().range();
	    }
	    if (type) {
	        node.patchType(type);
	    }
	};
	function getFragmentDefenitionName(node) {
	    return hlimpl.getFragmentDefenitionName(node);
	}
	exports.getFragmentDefenitionName = getFragmentDefenitionName;
	function genStructuredValue(name, parent, pr) {
	    if (pr.range() instanceof defs.ReferenceType) {
	        var t = pr.range();
	        var mockNode = jsyaml.createNode(name);
	        return new hlimpl.StructuredValue(mockNode, parent, pr);
	    }
	    else
	        return name;
	}
	exports.genStructuredValue = genStructuredValue;
	function parseUrl(u) {
	    return new linter.UrlParameterNameValidator().parseUrl(u);
	}
	exports.parseUrl = parseUrl;
	//# sourceMappingURL=utils.js.map

/***/ },
/* 4 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var limpl = __webpack_require__(21);
	function createProject(path, r, h) {
	    return new limpl.Project(path, r, h);
	}
	exports.createProject = createProject;
	//# sourceMappingURL=project.js.map

/***/ },
/* 5 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var def = __webpack_require__(33);
	var refResolvers = __webpack_require__(23);
	var schemaGenImpl = __webpack_require__(18);
	var contentprovider = __webpack_require__(31);
	var su = def.getSchemaUtils();
	function createSchema(c, u) {
	    return su.createSchema(c, new contentprovider.ContentProvider(u));
	}
	exports.createSchema = createSchema;
	function getXMLSchema(c) {
	    return su.getXMLSchema(c);
	}
	exports.getXMLSchema = getXMLSchema;
	function getJSONSchema(c, u) {
	    return su.getJSONSchema(c, new contentprovider.ContentProvider(u));
	}
	exports.getJSONSchema = getJSONSchema;
	function completeReference(includePath, includeReference, content) {
	    return refResolvers.completeReference(includePath, includeReference, content);
	}
	exports.completeReference = completeReference;
	function getIncludePath(p) {
	    return refResolvers.getIncludePath(p);
	}
	exports.getIncludePath = getIncludePath;
	function getIncludeReference(p) {
	    return refResolvers.getIncludeReference(p);
	}
	exports.getIncludeReference = getIncludeReference;
	function createSchemaModelGenerator() {
	    return new schemaGenImpl.SchemaToModelGenerator();
	}
	exports.createSchemaModelGenerator = createSchemaModelGenerator;
	function createModelToSchemaGenerator() {
	    return new schemaGenImpl.ModelToSchemaGenerator();
	}
	exports.createModelToSchemaGenerator = createModelToSchemaGenerator;
	//# sourceMappingURL=schema.js.map

/***/ },
/* 6 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	exports.modify = __webpack_require__(19);
	//# sourceMappingURL=parser.js.map

/***/ },
/* 7 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var ex = __webpack_require__(24);
	function expandTraitsAndResourceTypes(api) {
	    return ex.expandTraitsAndResourceTypes(api);
	}
	exports.expandTraitsAndResourceTypes = expandTraitsAndResourceTypes;
	//# sourceMappingURL=expanderStub.js.map

/***/ },
/* 8 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var wh = __webpack_require__(32);
	function completeRelativeUri(res) {
	    return wh.completeRelativeUri(res);
	}
	exports.completeRelativeUri = completeRelativeUri;
	//  function schema(body:api.TypeDeclaration, api:api.Api):Opt<SchemaDef> {
	//     return wh.schema(body,api);
	// } 
	//# sourceMappingURL=wrapperHelperStub.js.map

/***/ },
/* 9 */
/***/ function(module, exports, __webpack_require__) {

	/// <reference path="../../typings/main.d.ts" />
	"use strict";
	var RamlWrapper1Impl = __webpack_require__(28);
	var path = __webpack_require__(15);
	var Opt = __webpack_require__(29);
	var jsyaml = __webpack_require__(21);
	var hlimpl = __webpack_require__(16);
	var llimpl = __webpack_require__(21);
	var expander = __webpack_require__(24);
	var universeDef = __webpack_require__(30);
	var ramlServices = __webpack_require__(34);
	var universeProvider = __webpack_require__(35);
	/***
	 * Load API synchronously. Detects RAML version and uses corresponding parser.
	 * @param apiPath Path to API: local file system path or Web URL
	 * @param options Load options
	 * @return Opt&lt;Api&gt;, where Api belongs to RAML 1.0 or RAML 0.8 model.
	 ***/
	function loadApi(apiPath, arg1, arg2) {
	    var api = loadRAMLInternal(apiPath, arg1, arg2);
	    // if (false) {
	    //     //TODO loaded RAML is API
	    //     throw new Error("Loaded RAML is not API");
	    // } else {
	    return new Opt(api);
	    // }
	}
	exports.loadApi = loadApi;
	/***
	 * Load RAML synchronously. Detects RAML version and uses corresponding parser.
	 * @param ramlPath Path to RAML: local file system path or Web URL
	 * @param options Load options
	 * @return Opt&lt;RAMLLanguageElement&gt;, where RAMLLanguageElement belongs to RAML 1.0 or RAML 0.8 model.
	 ***/
	function loadRAML(ramlPath, arg1, arg2) {
	    var result = loadRAMLInternal(ramlPath, arg1, arg2);
	    return new Opt(result);
	}
	exports.loadRAML = loadRAML;
	function loadRAMLInternal(apiPath, arg1, arg2) {
	    var gotArray = Array.isArray(arg1);
	    var extensionsAndOverlays = (gotArray ? arg1 : null);
	    var options = (gotArray ? arg2 : arg1);
	    options = options || {};
	    var project = getProject(apiPath, options);
	    var pr = apiPath.indexOf("://");
	    var unitName = (pr != -1 && pr < 6) ? apiPath : path.basename(apiPath);
	    var unit = project.unit(unitName);
	    if (arg2 && !extensionsAndOverlays) {
	        extensionsAndOverlays = null;
	    }
	    var api;
	    if (unit) {
	        if (extensionsAndOverlays && extensionsAndOverlays.length > 0) {
	            var extensionUnits = [];
	            extensionsAndOverlays.forEach(function (currentPath) {
	                if (!currentPath || currentPath.trim().length == 0) {
	                    throw new Error("Extensions and overlays list should contain legal file paths");
	                }
	            });
	            extensionsAndOverlays.forEach(function (unitPath) {
	                extensionUnits.push(project.unit(path.basename(unitPath)));
	            });
	            //calling to perform the checks, we do not actually need the api itself
	            extensionUnits.forEach(function (extensionUnit) { return toApi(extensionUnit, options); });
	            api = toApi(expander.mergeAPIs(unit, extensionUnits, hlimpl.OverlayMergeMode.MERGE), options);
	        }
	        else {
	            api = toApi(unit, options);
	            api.highLevel().setMergeMode(hlimpl.OverlayMergeMode.MERGE);
	        }
	    }
	    if (!unit) {
	        throw new Error("Can not resolve :" + apiPath);
	    }
	    if (options.rejectOnErrors && api && api.errors().filter(function (x) { return !x.isWarning; }).length) {
	        throw toError(api);
	    }
	    if (options.attributeDefaults != null && api) {
	        api.setAttributeDefaults(options.attributeDefaults);
	    }
	    else if (api) {
	        api.setAttributeDefaults(true);
	    }
	    return api;
	}
	/***
	 * Load API asynchronously. Detects RAML version and uses corresponding parser.
	 * @param apiPath Path to API: local file system path or Web URL
	 * @param options Load options
	 * @return Promise&lt;Api&gt;, where Api belongs to RAML 1.0 or RAML 0.8 model.
	 ***/
	function loadApiAsync(apiPath, arg1, arg2) {
	    var ramlPromise = loadRAMLAsync(apiPath, arg1, arg2);
	    return ramlPromise.then(function (loadedRaml) {
	        // if (false) {
	        //     //TODO check that loaded RAML is API
	        //     return Promise.reject("Specified RAML is not API");
	        // } else {
	        return loadedRaml;
	        // }
	    });
	}
	exports.loadApiAsync = loadApiAsync;
	/***
	 * Load API asynchronously. Detects RAML version and uses corresponding parser.
	 * @param ramlPath Path to RAML: local file system path or Web URL
	 * @param options Load options
	 * @return Promise&lt;RAMLLanguageElement&gt;, where RAMLLanguageElement belongs to RAML 1.0 or RAML 0.8 model.
	 ***/
	function loadRAMLAsync(ramlPath, arg1, arg2) {
	    var gotArray = Array.isArray(arg1);
	    var extensionsAndOverlays = (gotArray ? arg1 : null);
	    var options = (gotArray ? arg2 : arg1);
	    options = options || {};
	    var project = getProject(ramlPath, options);
	    var pr = ramlPath.indexOf("://");
	    var unitName = (pr != -1 && pr < 6) ? ramlPath : path.basename(ramlPath);
	    if (arg2 && !extensionsAndOverlays) {
	        extensionsAndOverlays = null;
	    }
	    if (!extensionsAndOverlays || extensionsAndOverlays.length == 0) {
	        return fetchAndLoadApiAsync(project, unitName, options).then(function (masterApi) {
	            masterApi.highLevel().setMergeMode(hlimpl.OverlayMergeMode.MERGE);
	            if (options.attributeDefaults != null && masterApi) {
	                masterApi.setAttributeDefaults(options.attributeDefaults);
	            }
	            else if (masterApi) {
	                masterApi.setAttributeDefaults(true);
	            }
	            return masterApi;
	        });
	    }
	    else {
	        extensionsAndOverlays.forEach(function (currentPath) {
	            if (!currentPath || currentPath.trim().length == 0) {
	                throw new Error("Extensions and overlays list should contain legal file paths");
	            }
	        });
	        return fetchAndLoadApiAsync(project, unitName, options).then(function (masterApi) {
	            var apiPromises = [];
	            extensionsAndOverlays.forEach(function (extensionUnitPath) {
	                apiPromises.push(fetchAndLoadApiAsync(project, path.basename(extensionUnitPath), options));
	            });
	            return Promise.all(apiPromises).then(function (apis) {
	                var overlayUnits = [];
	                apis.forEach(function (currentApi) { return overlayUnits.push(currentApi.highLevel().lowLevel().unit()); });
	                var result = expander.mergeAPIs(masterApi.highLevel().lowLevel().unit(), overlayUnits, hlimpl.OverlayMergeMode.MERGE);
	                if (options.attributeDefaults != null && result) {
	                    result.setAttributeDefaults(options.attributeDefaults);
	                }
	                else if (result) {
	                    result.setAttributeDefaults(true);
	                }
	                return result;
	            }).then(function (mergedHighLevel) {
	                return toApi(mergedHighLevel, options);
	            });
	        });
	    }
	}
	exports.loadRAMLAsync = loadRAMLAsync;
	/**
	 * Gets AST node by runtime type, if runtime type matches any.
	 * @param runtimeType
	 */
	function getLanguageElementByRuntimeType(runtimeType) {
	    if (runtimeType == null) {
	        return null;
	    }
	    var highLevelNode = runtimeType.getAdapter(ramlServices.RAMLService).getDeclaringNode();
	    if (highLevelNode == null) {
	        return null;
	    }
	    return highLevelNode.wrapperNode();
	}
	exports.getLanguageElementByRuntimeType = getLanguageElementByRuntimeType;
	function fetchAndLoadApiAsync(project, unitName, options) {
	    return llimpl.fetchIncludesAndMasterAsync(project, unitName).then(function (x) {
	        try {
	            var api = toApi(x, options);
	            if (options.rejectOnErrors && api && api.errors().filter(function (x) { return !x.isWarning; }).length) {
	                return Promise.reject(toError(api));
	            }
	            return api;
	        }
	        catch (err) {
	            return Promise.reject(err);
	        }
	    });
	}
	function getProject(apiPath, options) {
	    options = options || {};
	    var includeResolver = options.fsResolver;
	    var httpResolver = options.httpResolver;
	    var projectRoot = path.dirname(apiPath);
	    var project = new jsyaml.Project(projectRoot, includeResolver, httpResolver);
	    return project;
	}
	;
	function toApi(unitOrHighlevel, options, checkApisOverlays) {
	    if (checkApisOverlays === void 0) { checkApisOverlays = false; }
	    if (!unitOrHighlevel) {
	        return null;
	    }
	    var unit = null;
	    var highLevel = null;
	    if (unitOrHighlevel.isRAMLUnit) {
	        unit = unitOrHighlevel;
	    }
	    else {
	        highLevel = unitOrHighlevel;
	        unit = highLevel.lowLevel().unit();
	    }
	    var api;
	    var contents = unit.contents();
	    var ramlFirstLine = contents.match(/^\s*#%RAML\s+(\d\.\d)\s*(\w*)\s*$/m);
	    if (!ramlFirstLine) {
	        //TODO throw sensible error
	        return null;
	    }
	    var verStr = ramlFirstLine[1];
	    var ramlFileType = ramlFirstLine[2];
	    var typeName;
	    var apiImpl;
	    var ramlVersion;
	    if (verStr == '0.8') {
	        ramlVersion = 'RAML08';
	    }
	    else if (verStr == '1.0') {
	        ramlVersion = 'RAML10';
	    }
	    if (!ramlVersion) {
	        throw new Error("Unknown version of RAML expected to see one of '#%RAML 0.8' or '#%RAML 1.0'");
	    }
	    if (ramlVersion == 'RAML08' && checkApisOverlays) {
	        throw new Error('Extensions and overlays are not supported in RAML 0.8.');
	    }
	    //if (!ramlFileType || ramlFileType.trim() === "") {
	    //    if (verStr=='0.8') {
	    //        typeName = universeDef.Universe08.Api.name;
	    //        apiImpl = RamlWrapper08.ApiImpl;
	    //    } else if(verStr=='1.0'){
	    //        typeName = universeDef.Universe10.Api.name;
	    //        apiImpl = RamlWrapper1.ApiImpl;
	    //    }
	    //} else if (ramlFileType === "Overlay") {
	    //    apiImpl = RamlWrapper1.OverlayImpl;
	    //    typeName = universeDef.Universe10.Overlay.name;
	    //} else if (ramlFileType === "Extension") {
	    //    apiImpl = RamlWrapper1.ExtensionImpl;
	    //    typeName = universeDef.Universe10.Extension.name;
	    //}
	    var universe = universeProvider(ramlVersion);
	    var apiType = universe.type(typeName);
	    if (!highLevel) {
	        highLevel = hlimpl.fromUnit(unit);
	    }
	    //api = new apiImpl(highLevel);
	    api = highLevel.wrapperNode();
	    return api;
	}
	;
	function toError(api) {
	    var error = new Error('Api contains errors.');
	    error.parserErrors = api.errors();
	    return error;
	}
	exports.toError = toError;
	function loadApis1(projectRoot, cacheChildren, expandTraitsAndResourceTypes) {
	    if (cacheChildren === void 0) { cacheChildren = false; }
	    if (expandTraitsAndResourceTypes === void 0) { expandTraitsAndResourceTypes = true; }
	    var universe = universeProvider("RAML10");
	    var apiType = universe.type(universeDef.Universe10.Api.name);
	    var p = new jsyaml.Project(projectRoot);
	    var result = [];
	    p.units().forEach(function (x) {
	        var lowLevel = x.ast();
	        if (cacheChildren) {
	            lowLevel = llimpl.toChildCahcingNode(lowLevel);
	        }
	        var api = new RamlWrapper1Impl.ApiImpl(new hlimpl.ASTNodeImpl(lowLevel, null, apiType, null));
	        if (expandTraitsAndResourceTypes) {
	            api = expander.expandTraitsAndResourceTypes(api);
	        }
	        result.push(api);
	    });
	    return result;
	}
	exports.loadApis1 = loadApis1;
	//# sourceMappingURL=apiLoader.js.map

/***/ },
/* 10 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	(function (NodeKind) {
	    NodeKind[NodeKind["BASIC"] = 0] = "BASIC";
	    NodeKind[NodeKind["NODE"] = 1] = "NODE";
	    NodeKind[NodeKind["ATTRIBUTE"] = 2] = "ATTRIBUTE";
	})(exports.NodeKind || (exports.NodeKind = {}));
	var NodeKind = exports.NodeKind;
	(function (RAMLVersion) {
	    RAMLVersion[RAMLVersion["RAML10"] = 0] = "RAML10";
	    RAMLVersion[RAMLVersion["RAML08"] = 1] = "RAML08";
	})(exports.RAMLVersion || (exports.RAMLVersion = {}));
	var RAMLVersion = exports.RAMLVersion;
	(function (IssueCode) {
	    IssueCode[IssueCode["UNRESOLVED_REFERENCE"] = 0] = "UNRESOLVED_REFERENCE";
	    IssueCode[IssueCode["YAML_ERROR"] = 1] = "YAML_ERROR";
	    IssueCode[IssueCode["UNKNOWN_NODE"] = 2] = "UNKNOWN_NODE";
	    IssueCode[IssueCode["MISSING_REQUIRED_PROPERTY"] = 3] = "MISSING_REQUIRED_PROPERTY";
	    IssueCode[IssueCode["PROPERTY_EXPECT_TO_HAVE_SINGLE_VALUE"] = 4] = "PROPERTY_EXPECT_TO_HAVE_SINGLE_VALUE";
	    //TODO IMPLEMENT
	    IssueCode[IssueCode["KEY_SHOULD_BE_UNIQUE_INTHISCONTEXT"] = 5] = "KEY_SHOULD_BE_UNIQUE_INTHISCONTEXT";
	    IssueCode[IssueCode["UNABLE_TO_RESOLVE_INCLUDE_FILE"] = 6] = "UNABLE_TO_RESOLVE_INCLUDE_FILE";
	    IssueCode[IssueCode["INVALID_VALUE_SCHEMA"] = 7] = "INVALID_VALUE_SCHEMA";
	    IssueCode[IssueCode["MISSED_CONTEXT_REQUIREMENT"] = 8] = "MISSED_CONTEXT_REQUIREMENT";
	    IssueCode[IssueCode["NODE_HAS_VALUE"] = 9] = "NODE_HAS_VALUE";
	    IssueCode[IssueCode["ONLY_OVERRIDE_ALLOWED"] = 10] = "ONLY_OVERRIDE_ALLOWED";
	    IssueCode[IssueCode["ILLEGAL_PROPERTY_VALUE"] = 11] = "ILLEGAL_PROPERTY_VALUE";
	    IssueCode[IssueCode["ILLEGAL_PROPERTY"] = 12] = "ILLEGAL_PROPERTY";
	    IssueCode[IssueCode["INVALID_PROPERTY"] = 13] = "INVALID_PROPERTY";
	})(exports.IssueCode || (exports.IssueCode = {}));
	var IssueCode = exports.IssueCode;
	//# sourceMappingURL=highLevelAST.js.map

/***/ },
/* 11 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var ASTDelta = (function () {
	    function ASTDelta() {
	    }
	    return ASTDelta;
	}());
	exports.ASTDelta = ASTDelta;
	(function (CommandKind) {
	    CommandKind[CommandKind["ADD_CHILD"] = 0] = "ADD_CHILD";
	    CommandKind[CommandKind["REMOVE_CHILD"] = 1] = "REMOVE_CHILD";
	    CommandKind[CommandKind["MOVE_CHILD"] = 2] = "MOVE_CHILD";
	    CommandKind[CommandKind["CHANGE_KEY"] = 3] = "CHANGE_KEY";
	    CommandKind[CommandKind["CHANGE_VALUE"] = 4] = "CHANGE_VALUE";
	    CommandKind[CommandKind["INIT_RAML_FILE"] = 5] = "INIT_RAML_FILE";
	})(exports.CommandKind || (exports.CommandKind = {}));
	var CommandKind = exports.CommandKind;
	var TextChangeCommand = (function () {
	    function TextChangeCommand(offset, replacementLength, text, unit, target) {
	        if (target === void 0) { target = null; }
	        this.offset = offset;
	        this.replacementLength = replacementLength;
	        this.text = text;
	        this.unit = unit;
	        this.target = target;
	    }
	    return TextChangeCommand;
	}());
	exports.TextChangeCommand = TextChangeCommand;
	var CompositeCommand = (function () {
	    function CompositeCommand() {
	        this.commands = [];
	    }
	    return CompositeCommand;
	}());
	exports.CompositeCommand = CompositeCommand;
	(function (InsertionPointType) {
	    InsertionPointType[InsertionPointType["NONE"] = 0] = "NONE";
	    InsertionPointType[InsertionPointType["START"] = 1] = "START";
	    InsertionPointType[InsertionPointType["END"] = 2] = "END";
	    InsertionPointType[InsertionPointType["POINT"] = 3] = "POINT";
	})(exports.InsertionPointType || (exports.InsertionPointType = {}));
	var InsertionPointType = exports.InsertionPointType;
	var ASTChangeCommand = (function () {
	    function ASTChangeCommand(kind, target, value, position) {
	        this.toSeq = false;
	        this.kind = kind;
	        this.target = target;
	        this.value = value;
	        this.position = position;
	    }
	    return ASTChangeCommand;
	}());
	exports.ASTChangeCommand = ASTChangeCommand;
	function setAttr(t, value) {
	    return new ASTChangeCommand(CommandKind.CHANGE_VALUE, t, value, -1);
	}
	exports.setAttr = setAttr;
	function setAttrStructured(t, value) {
	    return new ASTChangeCommand(CommandKind.CHANGE_VALUE, t, value.lowLevel(), -1);
	}
	exports.setAttrStructured = setAttrStructured;
	function setKey(t, value) {
	    return new ASTChangeCommand(CommandKind.CHANGE_KEY, t, value, -1);
	}
	exports.setKey = setKey;
	function removeNode(t, child) {
	    return new ASTChangeCommand(CommandKind.REMOVE_CHILD, t, child, -1);
	}
	exports.removeNode = removeNode;
	function insertNode(t, child, insertAfter, toSeq) {
	    if (insertAfter === void 0) { insertAfter = null; }
	    if (toSeq === void 0) { toSeq = false; }
	    var s = new ASTChangeCommand(CommandKind.ADD_CHILD, t, child, -1);
	    s.insertionPoint = insertAfter;
	    s.toSeq = toSeq;
	    return s;
	}
	exports.insertNode = insertNode;
	function initRamlFile(root, newroot) {
	    return new ASTChangeCommand(CommandKind.INIT_RAML_FILE, root, newroot, -1);
	}
	exports.initRamlFile = initRamlFile;
	var LineMapperImpl = (function () {
	    function LineMapperImpl(content, absPath) {
	        this.content = content;
	        this.absPath = absPath;
	    }
	    LineMapperImpl.prototype.position = function (_pos) {
	        var pos = _pos;
	        this.initMapping();
	        for (var i = 0; i < this.mapping.length; i++) {
	            var lineLength = this.mapping[i];
	            if (pos < lineLength) {
	                return {
	                    line: i,
	                    column: pos,
	                    position: _pos
	                };
	            }
	            pos -= lineLength;
	        }
	        if (pos == 1) {
	            //sometimes YAML library reports an error at a position of document length + 1, no idea what they want
	            //to tell us that way
	            return {
	                line: this.mapping.length - 1,
	                column: this.mapping[this.mapping.length - 1] - 1,
	                position: _pos - 1
	            };
	        }
	        throw new Error("Character position exceeds text length: " + _pos + " > + " + this.content.length + ".\nUnit path: " + this.absPath);
	    };
	    LineMapperImpl.prototype.initMapping = function () {
	        if (this.mapping != null) {
	            return;
	        }
	        if (this.content == null) {
	            throw new Error("Line Mapper has been given null content" + (this.absPath != null
	                ? ('. Path: ' + this.absPath) : ' and null path.'));
	        }
	        this.mapping = [];
	        var ind = 0;
	        var l = this.content.length;
	        for (var i = 0; i < l; i++) {
	            if (this.content.charAt(i) == '\r') {
	                if (i < l - 1 && this.content.charAt(i + 1) == '\n') {
	                    this.mapping.push(i - ind + 2);
	                    ind = i + 2;
	                    i++;
	                }
	                else {
	                    this.mapping.push(i - ind + 1);
	                    ind = i + 1;
	                }
	            }
	            else if (this.content.charAt(i) == '\n') {
	                this.mapping.push(i - ind + 1);
	                ind = i + 1;
	            }
	        }
	        this.mapping.push(l - ind);
	    };
	    return LineMapperImpl;
	}());
	exports.LineMapperImpl = LineMapperImpl;
	//# sourceMappingURL=lowLevelAST.js.map

/***/ },
/* 12 */
/***/ function(module, exports, __webpack_require__) {

	/**
	 * <p>See <a href="http://raml.org">http://raml.org</a> for more information about RAML.</p>
	 *
	 * <p>This parser is at a beta state of development, as part of the API Workbench development cycle (<a href="http://apiworkbench.com">http://apiworkbench.com</a>).</p>
	 *
	 * <p><a href="https://github.com/raml-org/raml-js-parser-2/blob/master/documentation/GettingStarted.md">Getting Started Guide</a> describes the first steps with the parser.</p>
	 *
	 * <h2>Installation</h2>
	 *
	 * <pre><code>git clone https://github.com/raml-org/raml-js-parser-2
	 *
	 * cd raml-js-parser-2
	 *
	 * npm install
	 *
	 * node test/test.js  //here you should observe JSON representation of XKCD API in your console
	 *
	 * node test/testAsync.js  //same as above but in asynchronous mode
	 * </code></pre>
	 *
	 * <h2>Usage</h2>
	 *
	 * <ul>
	 * <li>For parser usage example refer to <code>test/test.js</code></li>
	 * <li>For asynchrounous usage example refer to <code>test/testAsync.js</code></li>
	 * </ul>
	 **/
	"use strict";
	/**
	 * Custom type guard for Api. Returns true if node is instance of Api. Returns false otherwise.
	 * Also returns false for super interfaces of Api.
	 */
	function isApi(node) {
	    return node.kind() == "Api" && node.RAMLVersion() == "RAML10";
	}
	exports.isApi = isApi;
	/**
	 * Custom type guard for LibraryBase. Returns true if node is instance of LibraryBase. Returns false otherwise.
	 * Also returns false for super interfaces of LibraryBase.
	 */
	function isLibraryBase(node) {
	    return node.kind() == "LibraryBase" && node.RAMLVersion() == "RAML10";
	}
	exports.isLibraryBase = isLibraryBase;
	/**
	 * Custom type guard for Annotable. Returns true if node is instance of Annotable. Returns false otherwise.
	 * Also returns false for super interfaces of Annotable.
	 */
	function isAnnotable(node) {
	    return node.kind() == "Annotable" && node.RAMLVersion() == "RAML10";
	}
	exports.isAnnotable = isAnnotable;
	/**
	 * Custom type guard for AnnotationRef. Returns true if node is instance of AnnotationRef. Returns false otherwise.
	 * Also returns false for super interfaces of AnnotationRef.
	 */
	function isAnnotationRef(node) {
	    return node.kind() == "AnnotationRef" && node.RAMLVersion() == "RAML10";
	}
	exports.isAnnotationRef = isAnnotationRef;
	/**
	 * Custom type guard for Reference. Returns true if node is instance of Reference. Returns false otherwise.
	 * Also returns false for super interfaces of Reference.
	 */
	function isReference(node) {
	    return node.kind() == "Reference" && node.RAMLVersion() == "RAML10";
	}
	exports.isReference = isReference;
	/**
	 * Custom type guard for ValueType. Returns true if node is instance of ValueType. Returns false otherwise.
	 * Also returns false for super interfaces of ValueType.
	 */
	function isValueType(node) {
	    return node.kind() == "ValueType" && node.RAMLVersion() == "RAML10";
	}
	exports.isValueType = isValueType;
	/**
	 * Custom type guard for StringType. Returns true if node is instance of StringType. Returns false otherwise.
	 * Also returns false for super interfaces of StringType.
	 */
	function isStringType(node) {
	    return node.kind() == "StringType" && node.RAMLVersion() == "RAML10";
	}
	exports.isStringType = isStringType;
	/**
	 * Custom type guard for UriTemplate. Returns true if node is instance of UriTemplate. Returns false otherwise.
	 * Also returns false for super interfaces of UriTemplate.
	 */
	function isUriTemplate(node) {
	    return node.kind() == "UriTemplate" && node.RAMLVersion() == "RAML10";
	}
	exports.isUriTemplate = isUriTemplate;
	/**
	 * Custom type guard for RelativeUriString. Returns true if node is instance of RelativeUriString. Returns false otherwise.
	 * Also returns false for super interfaces of RelativeUriString.
	 */
	function isRelativeUriString(node) {
	    return node.kind() == "RelativeUriString" && node.RAMLVersion() == "RAML10";
	}
	exports.isRelativeUriString = isRelativeUriString;
	/**
	 * Custom type guard for FullUriTemplateString. Returns true if node is instance of FullUriTemplateString. Returns false otherwise.
	 * Also returns false for super interfaces of FullUriTemplateString.
	 */
	function isFullUriTemplateString(node) {
	    return node.kind() == "FullUriTemplateString" && node.RAMLVersion() == "RAML10";
	}
	exports.isFullUriTemplateString = isFullUriTemplateString;
	/**
	 * Custom type guard for StatusCodeString. Returns true if node is instance of StatusCodeString. Returns false otherwise.
	 * Also returns false for super interfaces of StatusCodeString.
	 */
	function isStatusCodeString(node) {
	    return node.kind() == "StatusCodeString" && node.RAMLVersion() == "RAML10";
	}
	exports.isStatusCodeString = isStatusCodeString;
	/**
	 * Custom type guard for FixedUriString. Returns true if node is instance of FixedUriString. Returns false otherwise.
	 * Also returns false for super interfaces of FixedUriString.
	 */
	function isFixedUriString(node) {
	    return node.kind() == "FixedUriString" && node.RAMLVersion() == "RAML10";
	}
	exports.isFixedUriString = isFixedUriString;
	/**
	 * Custom type guard for ContentType. Returns true if node is instance of ContentType. Returns false otherwise.
	 * Also returns false for super interfaces of ContentType.
	 */
	function isContentType(node) {
	    return node.kind() == "ContentType" && node.RAMLVersion() == "RAML10";
	}
	exports.isContentType = isContentType;
	/**
	 * Custom type guard for MarkdownString. Returns true if node is instance of MarkdownString. Returns false otherwise.
	 * Also returns false for super interfaces of MarkdownString.
	 */
	function isMarkdownString(node) {
	    return node.kind() == "MarkdownString" && node.RAMLVersion() == "RAML10";
	}
	exports.isMarkdownString = isMarkdownString;
	/**
	 * Custom type guard for SchemaString. Returns true if node is instance of SchemaString. Returns false otherwise.
	 * Also returns false for super interfaces of SchemaString.
	 */
	function isSchemaString(node) {
	    return node.kind() == "SchemaString" && node.RAMLVersion() == "RAML10";
	}
	exports.isSchemaString = isSchemaString;
	/**
	 * Custom type guard for MimeType. Returns true if node is instance of MimeType. Returns false otherwise.
	 * Also returns false for super interfaces of MimeType.
	 */
	function isMimeType(node) {
	    return node.kind() == "MimeType" && node.RAMLVersion() == "RAML10";
	}
	exports.isMimeType = isMimeType;
	/**
	 * Custom type guard for AnyType. Returns true if node is instance of AnyType. Returns false otherwise.
	 * Also returns false for super interfaces of AnyType.
	 */
	function isAnyType(node) {
	    return node.kind() == "AnyType" && node.RAMLVersion() == "RAML10";
	}
	exports.isAnyType = isAnyType;
	/**
	 * Custom type guard for NumberType. Returns true if node is instance of NumberType. Returns false otherwise.
	 * Also returns false for super interfaces of NumberType.
	 */
	function isNumberType(node) {
	    return node.kind() == "NumberType" && node.RAMLVersion() == "RAML10";
	}
	exports.isNumberType = isNumberType;
	/**
	 * Custom type guard for IntegerType. Returns true if node is instance of IntegerType. Returns false otherwise.
	 * Also returns false for super interfaces of IntegerType.
	 */
	function isIntegerType(node) {
	    return node.kind() == "IntegerType" && node.RAMLVersion() == "RAML10";
	}
	exports.isIntegerType = isIntegerType;
	/**
	 * Custom type guard for NullType. Returns true if node is instance of NullType. Returns false otherwise.
	 * Also returns false for super interfaces of NullType.
	 */
	function isNullType(node) {
	    return node.kind() == "NullType" && node.RAMLVersion() == "RAML10";
	}
	exports.isNullType = isNullType;
	/**
	 * Custom type guard for TimeOnlyType. Returns true if node is instance of TimeOnlyType. Returns false otherwise.
	 * Also returns false for super interfaces of TimeOnlyType.
	 */
	function isTimeOnlyType(node) {
	    return node.kind() == "TimeOnlyType" && node.RAMLVersion() == "RAML10";
	}
	exports.isTimeOnlyType = isTimeOnlyType;
	/**
	 * Custom type guard for DateOnlyType. Returns true if node is instance of DateOnlyType. Returns false otherwise.
	 * Also returns false for super interfaces of DateOnlyType.
	 */
	function isDateOnlyType(node) {
	    return node.kind() == "DateOnlyType" && node.RAMLVersion() == "RAML10";
	}
	exports.isDateOnlyType = isDateOnlyType;
	/**
	 * Custom type guard for DateTimeOnlyType. Returns true if node is instance of DateTimeOnlyType. Returns false otherwise.
	 * Also returns false for super interfaces of DateTimeOnlyType.
	 */
	function isDateTimeOnlyType(node) {
	    return node.kind() == "DateTimeOnlyType" && node.RAMLVersion() == "RAML10";
	}
	exports.isDateTimeOnlyType = isDateTimeOnlyType;
	/**
	 * Custom type guard for DateTimeType. Returns true if node is instance of DateTimeType. Returns false otherwise.
	 * Also returns false for super interfaces of DateTimeType.
	 */
	function isDateTimeType(node) {
	    return node.kind() == "DateTimeType" && node.RAMLVersion() == "RAML10";
	}
	exports.isDateTimeType = isDateTimeType;
	/**
	 * Custom type guard for FileType. Returns true if node is instance of FileType. Returns false otherwise.
	 * Also returns false for super interfaces of FileType.
	 */
	function isFileType(node) {
	    return node.kind() == "FileType" && node.RAMLVersion() == "RAML10";
	}
	exports.isFileType = isFileType;
	/**
	 * Custom type guard for BooleanType. Returns true if node is instance of BooleanType. Returns false otherwise.
	 * Also returns false for super interfaces of BooleanType.
	 */
	function isBooleanType(node) {
	    return node.kind() == "BooleanType" && node.RAMLVersion() == "RAML10";
	}
	exports.isBooleanType = isBooleanType;
	/**
	 * Custom type guard for AnnotationTarget. Returns true if node is instance of AnnotationTarget. Returns false otherwise.
	 * Also returns false for super interfaces of AnnotationTarget.
	 */
	function isAnnotationTarget(node) {
	    return node.kind() == "AnnotationTarget" && node.RAMLVersion() == "RAML10";
	}
	exports.isAnnotationTarget = isAnnotationTarget;
	/**
	 * Custom type guard for TraitRef. Returns true if node is instance of TraitRef. Returns false otherwise.
	 * Also returns false for super interfaces of TraitRef.
	 */
	function isTraitRef(node) {
	    return node.kind() == "TraitRef" && node.RAMLVersion() == "RAML10";
	}
	exports.isTraitRef = isTraitRef;
	/**
	 * Custom type guard for Trait. Returns true if node is instance of Trait. Returns false otherwise.
	 * Also returns false for super interfaces of Trait.
	 */
	function isTrait(node) {
	    return node.kind() == "Trait" && node.RAMLVersion() == "RAML10";
	}
	exports.isTrait = isTrait;
	/**
	 * Custom type guard for MethodBase. Returns true if node is instance of MethodBase. Returns false otherwise.
	 * Also returns false for super interfaces of MethodBase.
	 */
	function isMethodBase(node) {
	    return node.kind() == "MethodBase" && node.RAMLVersion() == "RAML10";
	}
	exports.isMethodBase = isMethodBase;
	/**
	 * Custom type guard for Operation. Returns true if node is instance of Operation. Returns false otherwise.
	 * Also returns false for super interfaces of Operation.
	 */
	function isOperation(node) {
	    return node.kind() == "Operation" && node.RAMLVersion() == "RAML10";
	}
	exports.isOperation = isOperation;
	/**
	 * Custom type guard for TypeDeclaration. Returns true if node is instance of TypeDeclaration. Returns false otherwise.
	 * Also returns false for super interfaces of TypeDeclaration.
	 */
	function isTypeDeclaration(node) {
	    return node.kind() == "TypeDeclaration" && node.RAMLVersion() == "RAML10";
	}
	exports.isTypeDeclaration = isTypeDeclaration;
	/**
	 * Custom type guard for ModelLocation. Returns true if node is instance of ModelLocation. Returns false otherwise.
	 * Also returns false for super interfaces of ModelLocation.
	 */
	function isModelLocation(node) {
	    return node.kind() == "ModelLocation" && node.RAMLVersion() == "RAML10";
	}
	exports.isModelLocation = isModelLocation;
	/**
	 * Custom type guard for LocationKind. Returns true if node is instance of LocationKind. Returns false otherwise.
	 * Also returns false for super interfaces of LocationKind.
	 */
	function isLocationKind(node) {
	    return node.kind() == "LocationKind" && node.RAMLVersion() == "RAML10";
	}
	exports.isLocationKind = isLocationKind;
	/**
	 * Custom type guard for ExampleSpec. Returns true if node is instance of ExampleSpec. Returns false otherwise.
	 * Also returns false for super interfaces of ExampleSpec.
	 */
	function isExampleSpec(node) {
	    return node.kind() == "ExampleSpec" && node.RAMLVersion() == "RAML10";
	}
	exports.isExampleSpec = isExampleSpec;
	/**
	 * Custom type guard for XMLFacetInfo. Returns true if node is instance of XMLFacetInfo. Returns false otherwise.
	 * Also returns false for super interfaces of XMLFacetInfo.
	 */
	function isXMLFacetInfo(node) {
	    return node.kind() == "XMLFacetInfo" && node.RAMLVersion() == "RAML10";
	}
	exports.isXMLFacetInfo = isXMLFacetInfo;
	/**
	 * Custom type guard for UsesDeclaration. Returns true if node is instance of UsesDeclaration. Returns false otherwise.
	 * Also returns false for super interfaces of UsesDeclaration.
	 */
	function isUsesDeclaration(node) {
	    return node.kind() == "UsesDeclaration" && node.RAMLVersion() == "RAML10";
	}
	exports.isUsesDeclaration = isUsesDeclaration;
	/**
	 * Custom type guard for ArrayTypeDeclaration. Returns true if node is instance of ArrayTypeDeclaration. Returns false otherwise.
	 * Also returns false for super interfaces of ArrayTypeDeclaration.
	 */
	function isArrayTypeDeclaration(node) {
	    return node.kind() == "ArrayTypeDeclaration" && node.RAMLVersion() == "RAML10";
	}
	exports.isArrayTypeDeclaration = isArrayTypeDeclaration;
	/**
	 * Custom type guard for UnionTypeDeclaration. Returns true if node is instance of UnionTypeDeclaration. Returns false otherwise.
	 * Also returns false for super interfaces of UnionTypeDeclaration.
	 */
	function isUnionTypeDeclaration(node) {
	    return node.kind() == "UnionTypeDeclaration" && node.RAMLVersion() == "RAML10";
	}
	exports.isUnionTypeDeclaration = isUnionTypeDeclaration;
	/**
	 * Custom type guard for ObjectTypeDeclaration. Returns true if node is instance of ObjectTypeDeclaration. Returns false otherwise.
	 * Also returns false for super interfaces of ObjectTypeDeclaration.
	 */
	function isObjectTypeDeclaration(node) {
	    return node.kind() == "ObjectTypeDeclaration" && node.RAMLVersion() == "RAML10";
	}
	exports.isObjectTypeDeclaration = isObjectTypeDeclaration;
	/**
	 * Custom type guard for StringTypeDeclaration. Returns true if node is instance of StringTypeDeclaration. Returns false otherwise.
	 * Also returns false for super interfaces of StringTypeDeclaration.
	 */
	function isStringTypeDeclaration(node) {
	    return node.kind() == "StringTypeDeclaration" && node.RAMLVersion() == "RAML10";
	}
	exports.isStringTypeDeclaration = isStringTypeDeclaration;
	/**
	 * Custom type guard for BooleanTypeDeclaration. Returns true if node is instance of BooleanTypeDeclaration. Returns false otherwise.
	 * Also returns false for super interfaces of BooleanTypeDeclaration.
	 */
	function isBooleanTypeDeclaration(node) {
	    return node.kind() == "BooleanTypeDeclaration" && node.RAMLVersion() == "RAML10";
	}
	exports.isBooleanTypeDeclaration = isBooleanTypeDeclaration;
	/**
	 * Custom type guard for NumberTypeDeclaration. Returns true if node is instance of NumberTypeDeclaration. Returns false otherwise.
	 * Also returns false for super interfaces of NumberTypeDeclaration.
	 */
	function isNumberTypeDeclaration(node) {
	    return node.kind() == "NumberTypeDeclaration" && node.RAMLVersion() == "RAML10";
	}
	exports.isNumberTypeDeclaration = isNumberTypeDeclaration;
	/**
	 * Custom type guard for IntegerTypeDeclaration. Returns true if node is instance of IntegerTypeDeclaration. Returns false otherwise.
	 * Also returns false for super interfaces of IntegerTypeDeclaration.
	 */
	function isIntegerTypeDeclaration(node) {
	    return node.kind() == "IntegerTypeDeclaration" && node.RAMLVersion() == "RAML10";
	}
	exports.isIntegerTypeDeclaration = isIntegerTypeDeclaration;
	/**
	 * Custom type guard for DateOnlyTypeDeclaration. Returns true if node is instance of DateOnlyTypeDeclaration. Returns false otherwise.
	 * Also returns false for super interfaces of DateOnlyTypeDeclaration.
	 */
	function isDateOnlyTypeDeclaration(node) {
	    return node.kind() == "DateOnlyTypeDeclaration" && node.RAMLVersion() == "RAML10";
	}
	exports.isDateOnlyTypeDeclaration = isDateOnlyTypeDeclaration;
	/**
	 * Custom type guard for TimeOnlyTypeDeclaration. Returns true if node is instance of TimeOnlyTypeDeclaration. Returns false otherwise.
	 * Also returns false for super interfaces of TimeOnlyTypeDeclaration.
	 */
	function isTimeOnlyTypeDeclaration(node) {
	    return node.kind() == "TimeOnlyTypeDeclaration" && node.RAMLVersion() == "RAML10";
	}
	exports.isTimeOnlyTypeDeclaration = isTimeOnlyTypeDeclaration;
	/**
	 * Custom type guard for DateTimeOnlyTypeDeclaration. Returns true if node is instance of DateTimeOnlyTypeDeclaration. Returns false otherwise.
	 * Also returns false for super interfaces of DateTimeOnlyTypeDeclaration.
	 */
	function isDateTimeOnlyTypeDeclaration(node) {
	    return node.kind() == "DateTimeOnlyTypeDeclaration" && node.RAMLVersion() == "RAML10";
	}
	exports.isDateTimeOnlyTypeDeclaration = isDateTimeOnlyTypeDeclaration;
	/**
	 * Custom type guard for DateTimeTypeDeclaration. Returns true if node is instance of DateTimeTypeDeclaration. Returns false otherwise.
	 * Also returns false for super interfaces of DateTimeTypeDeclaration.
	 */
	function isDateTimeTypeDeclaration(node) {
	    return node.kind() == "DateTimeTypeDeclaration" && node.RAMLVersion() == "RAML10";
	}
	exports.isDateTimeTypeDeclaration = isDateTimeTypeDeclaration;
	/**
	 * Custom type guard for DateTypeDeclaration. Returns true if node is instance of DateTypeDeclaration. Returns false otherwise.
	 * Also returns false for super interfaces of DateTypeDeclaration.
	 */
	function isDateTypeDeclaration(node) {
	    return node.kind() == "DateTypeDeclaration" && node.RAMLVersion() == "RAML10";
	}
	exports.isDateTypeDeclaration = isDateTypeDeclaration;
	/**
	 * Custom type guard for FileTypeDeclaration. Returns true if node is instance of FileTypeDeclaration. Returns false otherwise.
	 * Also returns false for super interfaces of FileTypeDeclaration.
	 */
	function isFileTypeDeclaration(node) {
	    return node.kind() == "FileTypeDeclaration" && node.RAMLVersion() == "RAML10";
	}
	exports.isFileTypeDeclaration = isFileTypeDeclaration;
	/**
	 * Custom type guard for Response. Returns true if node is instance of Response. Returns false otherwise.
	 * Also returns false for super interfaces of Response.
	 */
	function isResponse(node) {
	    return node.kind() == "Response" && node.RAMLVersion() == "RAML10";
	}
	exports.isResponse = isResponse;
	/**
	 * Custom type guard for SecuritySchemePart. Returns true if node is instance of SecuritySchemePart. Returns false otherwise.
	 * Also returns false for super interfaces of SecuritySchemePart.
	 */
	function isSecuritySchemePart(node) {
	    return node.kind() == "SecuritySchemePart" && node.RAMLVersion() == "RAML10";
	}
	exports.isSecuritySchemePart = isSecuritySchemePart;
	/**
	 * Custom type guard for SecuritySchemeRef. Returns true if node is instance of SecuritySchemeRef. Returns false otherwise.
	 * Also returns false for super interfaces of SecuritySchemeRef.
	 */
	function isSecuritySchemeRef(node) {
	    return node.kind() == "SecuritySchemeRef" && node.RAMLVersion() == "RAML10";
	}
	exports.isSecuritySchemeRef = isSecuritySchemeRef;
	/**
	 * Custom type guard for AbstractSecurityScheme. Returns true if node is instance of AbstractSecurityScheme. Returns false otherwise.
	 * Also returns false for super interfaces of AbstractSecurityScheme.
	 */
	function isAbstractSecurityScheme(node) {
	    return node.kind() == "AbstractSecurityScheme" && node.RAMLVersion() == "RAML10";
	}
	exports.isAbstractSecurityScheme = isAbstractSecurityScheme;
	/**
	 * Custom type guard for SecuritySchemeSettings. Returns true if node is instance of SecuritySchemeSettings. Returns false otherwise.
	 * Also returns false for super interfaces of SecuritySchemeSettings.
	 */
	function isSecuritySchemeSettings(node) {
	    return node.kind() == "SecuritySchemeSettings" && node.RAMLVersion() == "RAML10";
	}
	exports.isSecuritySchemeSettings = isSecuritySchemeSettings;
	/**
	 * Custom type guard for OAuth1SecuritySchemeSettings. Returns true if node is instance of OAuth1SecuritySchemeSettings. Returns false otherwise.
	 * Also returns false for super interfaces of OAuth1SecuritySchemeSettings.
	 */
	function isOAuth1SecuritySchemeSettings(node) {
	    return node.kind() == "OAuth1SecuritySchemeSettings" && node.RAMLVersion() == "RAML10";
	}
	exports.isOAuth1SecuritySchemeSettings = isOAuth1SecuritySchemeSettings;
	/**
	 * Custom type guard for OAuth2SecuritySchemeSettings. Returns true if node is instance of OAuth2SecuritySchemeSettings. Returns false otherwise.
	 * Also returns false for super interfaces of OAuth2SecuritySchemeSettings.
	 */
	function isOAuth2SecuritySchemeSettings(node) {
	    return node.kind() == "OAuth2SecuritySchemeSettings" && node.RAMLVersion() == "RAML10";
	}
	exports.isOAuth2SecuritySchemeSettings = isOAuth2SecuritySchemeSettings;
	/**
	 * Custom type guard for OAuth2SecurityScheme. Returns true if node is instance of OAuth2SecurityScheme. Returns false otherwise.
	 * Also returns false for super interfaces of OAuth2SecurityScheme.
	 */
	function isOAuth2SecurityScheme(node) {
	    return node.kind() == "OAuth2SecurityScheme" && node.RAMLVersion() == "RAML10";
	}
	exports.isOAuth2SecurityScheme = isOAuth2SecurityScheme;
	/**
	 * Custom type guard for OAuth1SecurityScheme. Returns true if node is instance of OAuth1SecurityScheme. Returns false otherwise.
	 * Also returns false for super interfaces of OAuth1SecurityScheme.
	 */
	function isOAuth1SecurityScheme(node) {
	    return node.kind() == "OAuth1SecurityScheme" && node.RAMLVersion() == "RAML10";
	}
	exports.isOAuth1SecurityScheme = isOAuth1SecurityScheme;
	/**
	 * Custom type guard for PassThroughSecurityScheme. Returns true if node is instance of PassThroughSecurityScheme. Returns false otherwise.
	 * Also returns false for super interfaces of PassThroughSecurityScheme.
	 */
	function isPassThroughSecurityScheme(node) {
	    return node.kind() == "PassThroughSecurityScheme" && node.RAMLVersion() == "RAML10";
	}
	exports.isPassThroughSecurityScheme = isPassThroughSecurityScheme;
	/**
	 * Custom type guard for BasicSecurityScheme. Returns true if node is instance of BasicSecurityScheme. Returns false otherwise.
	 * Also returns false for super interfaces of BasicSecurityScheme.
	 */
	function isBasicSecurityScheme(node) {
	    return node.kind() == "BasicSecurityScheme" && node.RAMLVersion() == "RAML10";
	}
	exports.isBasicSecurityScheme = isBasicSecurityScheme;
	/**
	 * Custom type guard for DigestSecurityScheme. Returns true if node is instance of DigestSecurityScheme. Returns false otherwise.
	 * Also returns false for super interfaces of DigestSecurityScheme.
	 */
	function isDigestSecurityScheme(node) {
	    return node.kind() == "DigestSecurityScheme" && node.RAMLVersion() == "RAML10";
	}
	exports.isDigestSecurityScheme = isDigestSecurityScheme;
	/**
	 * Custom type guard for CustomSecurityScheme. Returns true if node is instance of CustomSecurityScheme. Returns false otherwise.
	 * Also returns false for super interfaces of CustomSecurityScheme.
	 */
	function isCustomSecurityScheme(node) {
	    return node.kind() == "CustomSecurityScheme" && node.RAMLVersion() == "RAML10";
	}
	exports.isCustomSecurityScheme = isCustomSecurityScheme;
	/**
	 * Custom type guard for Method. Returns true if node is instance of Method. Returns false otherwise.
	 * Also returns false for super interfaces of Method.
	 */
	function isMethod(node) {
	    return node.kind() == "Method" && node.RAMLVersion() == "RAML10";
	}
	exports.isMethod = isMethod;
	/**
	 * Custom type guard for ResourceTypeRef. Returns true if node is instance of ResourceTypeRef. Returns false otherwise.
	 * Also returns false for super interfaces of ResourceTypeRef.
	 */
	function isResourceTypeRef(node) {
	    return node.kind() == "ResourceTypeRef" && node.RAMLVersion() == "RAML10";
	}
	exports.isResourceTypeRef = isResourceTypeRef;
	/**
	 * Custom type guard for ResourceType. Returns true if node is instance of ResourceType. Returns false otherwise.
	 * Also returns false for super interfaces of ResourceType.
	 */
	function isResourceType(node) {
	    return node.kind() == "ResourceType" && node.RAMLVersion() == "RAML10";
	}
	exports.isResourceType = isResourceType;
	/**
	 * Custom type guard for ResourceBase. Returns true if node is instance of ResourceBase. Returns false otherwise.
	 * Also returns false for super interfaces of ResourceBase.
	 */
	function isResourceBase(node) {
	    return node.kind() == "ResourceBase" && node.RAMLVersion() == "RAML10";
	}
	exports.isResourceBase = isResourceBase;
	/**
	 * Custom type guard for Resource. Returns true if node is instance of Resource. Returns false otherwise.
	 * Also returns false for super interfaces of Resource.
	 */
	function isResource(node) {
	    return node.kind() == "Resource" && node.RAMLVersion() == "RAML10";
	}
	exports.isResource = isResource;
	/**
	 * Custom type guard for DocumentationItem. Returns true if node is instance of DocumentationItem. Returns false otherwise.
	 * Also returns false for super interfaces of DocumentationItem.
	 */
	function isDocumentationItem(node) {
	    return node.kind() == "DocumentationItem" && node.RAMLVersion() == "RAML10";
	}
	exports.isDocumentationItem = isDocumentationItem;
	/**
	 * Custom type guard for Library. Returns true if node is instance of Library. Returns false otherwise.
	 * Also returns false for super interfaces of Library.
	 */
	function isLibrary(node) {
	    return node.kind() == "Library" && node.RAMLVersion() == "RAML10";
	}
	exports.isLibrary = isLibrary;
	/**
	 * Custom type guard for Overlay. Returns true if node is instance of Overlay. Returns false otherwise.
	 * Also returns false for super interfaces of Overlay.
	 */
	function isOverlay(node) {
	    return node.kind() == "Overlay" && node.RAMLVersion() == "RAML10";
	}
	exports.isOverlay = isOverlay;
	/**
	 * Custom type guard for Extension. Returns true if node is instance of Extension. Returns false otherwise.
	 * Also returns false for super interfaces of Extension.
	 */
	function isExtension(node) {
	    return node.kind() == "Extension" && node.RAMLVersion() == "RAML10";
	}
	exports.isExtension = isExtension;
	/**
	 * Check if the AST node represents fragment
	 */
	function isFragment(node) {
	    return node.highLevel().parent() == null;
	}
	exports.isFragment = isFragment;
	/**
	 * Convert fragment representing node to FragmentDeclaration instance.
	 */
	function asFragment(node) {
	    return isFragment(node) ? node : null;
	}
	exports.asFragment = asFragment;
	//# sourceMappingURL=raml10parserapi.js.map

/***/ },
/* 13 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	/**
	 * Custom type guard for Api. Returns true if node is instance of Api. Returns false otherwise.
	 * Also returns false for super interfaces of Api.
	 */
	function isApi(node) {
	    return node.kind() == "Api" && node.RAMLVersion() == "RAML08";
	}
	exports.isApi = isApi;
	/**
	 * Custom type guard for FullUriTemplateString. Returns true if node is instance of FullUriTemplateString. Returns false otherwise.
	 * Also returns false for super interfaces of FullUriTemplateString.
	 */
	function isFullUriTemplateString(node) {
	    return node.kind() == "FullUriTemplateString" && node.RAMLVersion() == "RAML08";
	}
	exports.isFullUriTemplateString = isFullUriTemplateString;
	/**
	 * Custom type guard for UriTemplate. Returns true if node is instance of UriTemplate. Returns false otherwise.
	 * Also returns false for super interfaces of UriTemplate.
	 */
	function isUriTemplate(node) {
	    return node.kind() == "UriTemplate" && node.RAMLVersion() == "RAML08";
	}
	exports.isUriTemplate = isUriTemplate;
	/**
	 * Custom type guard for StringType. Returns true if node is instance of StringType. Returns false otherwise.
	 * Also returns false for super interfaces of StringType.
	 */
	function isStringType(node) {
	    return node.kind() == "StringType" && node.RAMLVersion() == "RAML08";
	}
	exports.isStringType = isStringType;
	/**
	 * Custom type guard for ValueType. Returns true if node is instance of ValueType. Returns false otherwise.
	 * Also returns false for super interfaces of ValueType.
	 */
	function isValueType(node) {
	    return node.kind() == "ValueType" && node.RAMLVersion() == "RAML08";
	}
	exports.isValueType = isValueType;
	/**
	 * Custom type guard for AnyType. Returns true if node is instance of AnyType. Returns false otherwise.
	 * Also returns false for super interfaces of AnyType.
	 */
	function isAnyType(node) {
	    return node.kind() == "AnyType" && node.RAMLVersion() == "RAML08";
	}
	exports.isAnyType = isAnyType;
	/**
	 * Custom type guard for NumberType. Returns true if node is instance of NumberType. Returns false otherwise.
	 * Also returns false for super interfaces of NumberType.
	 */
	function isNumberType(node) {
	    return node.kind() == "NumberType" && node.RAMLVersion() == "RAML08";
	}
	exports.isNumberType = isNumberType;
	/**
	 * Custom type guard for BooleanType. Returns true if node is instance of BooleanType. Returns false otherwise.
	 * Also returns false for super interfaces of BooleanType.
	 */
	function isBooleanType(node) {
	    return node.kind() == "BooleanType" && node.RAMLVersion() == "RAML08";
	}
	exports.isBooleanType = isBooleanType;
	/**
	 * Custom type guard for Reference. Returns true if node is instance of Reference. Returns false otherwise.
	 * Also returns false for super interfaces of Reference.
	 */
	function isReference(node) {
	    return node.kind() == "Reference" && node.RAMLVersion() == "RAML08";
	}
	exports.isReference = isReference;
	/**
	 * Custom type guard for ResourceTypeRef. Returns true if node is instance of ResourceTypeRef. Returns false otherwise.
	 * Also returns false for super interfaces of ResourceTypeRef.
	 */
	function isResourceTypeRef(node) {
	    return node.kind() == "ResourceTypeRef" && node.RAMLVersion() == "RAML08";
	}
	exports.isResourceTypeRef = isResourceTypeRef;
	/**
	 * Custom type guard for ResourceType. Returns true if node is instance of ResourceType. Returns false otherwise.
	 * Also returns false for super interfaces of ResourceType.
	 */
	function isResourceType(node) {
	    return node.kind() == "ResourceType" && node.RAMLVersion() == "RAML08";
	}
	exports.isResourceType = isResourceType;
	/**
	 * Custom type guard for Method. Returns true if node is instance of Method. Returns false otherwise.
	 * Also returns false for super interfaces of Method.
	 */
	function isMethod(node) {
	    return node.kind() == "Method" && node.RAMLVersion() == "RAML08";
	}
	exports.isMethod = isMethod;
	/**
	 * Custom type guard for MethodBase. Returns true if node is instance of MethodBase. Returns false otherwise.
	 * Also returns false for super interfaces of MethodBase.
	 */
	function isMethodBase(node) {
	    return node.kind() == "MethodBase" && node.RAMLVersion() == "RAML08";
	}
	exports.isMethodBase = isMethodBase;
	/**
	 * Custom type guard for Response. Returns true if node is instance of Response. Returns false otherwise.
	 * Also returns false for super interfaces of Response.
	 */
	function isResponse(node) {
	    return node.kind() == "Response" && node.RAMLVersion() == "RAML08";
	}
	exports.isResponse = isResponse;
	/**
	 * Custom type guard for StatusCodeString. Returns true if node is instance of StatusCodeString. Returns false otherwise.
	 * Also returns false for super interfaces of StatusCodeString.
	 */
	function isStatusCodeString(node) {
	    return node.kind() == "StatusCodeString" && node.RAMLVersion() == "RAML08";
	}
	exports.isStatusCodeString = isStatusCodeString;
	/**
	 * Custom type guard for Parameter. Returns true if node is instance of Parameter. Returns false otherwise.
	 * Also returns false for super interfaces of Parameter.
	 */
	function isParameter(node) {
	    return node.kind() == "Parameter" && node.RAMLVersion() == "RAML08";
	}
	exports.isParameter = isParameter;
	/**
	 * Custom type guard for ParameterLocation. Returns true if node is instance of ParameterLocation. Returns false otherwise.
	 * Also returns false for super interfaces of ParameterLocation.
	 */
	function isParameterLocation(node) {
	    return node.kind() == "ParameterLocation" && node.RAMLVersion() == "RAML08";
	}
	exports.isParameterLocation = isParameterLocation;
	/**
	 * Custom type guard for MarkdownString. Returns true if node is instance of MarkdownString. Returns false otherwise.
	 * Also returns false for super interfaces of MarkdownString.
	 */
	function isMarkdownString(node) {
	    return node.kind() == "MarkdownString" && node.RAMLVersion() == "RAML08";
	}
	exports.isMarkdownString = isMarkdownString;
	/**
	 * Custom type guard for StringTypeDeclaration. Returns true if node is instance of StringTypeDeclaration. Returns false otherwise.
	 * Also returns false for super interfaces of StringTypeDeclaration.
	 */
	function isStringTypeDeclaration(node) {
	    return node.kind() == "StringTypeDeclaration" && node.RAMLVersion() == "RAML08";
	}
	exports.isStringTypeDeclaration = isStringTypeDeclaration;
	/**
	 * Custom type guard for BooleanTypeDeclaration. Returns true if node is instance of BooleanTypeDeclaration. Returns false otherwise.
	 * Also returns false for super interfaces of BooleanTypeDeclaration.
	 */
	function isBooleanTypeDeclaration(node) {
	    return node.kind() == "BooleanTypeDeclaration" && node.RAMLVersion() == "RAML08";
	}
	exports.isBooleanTypeDeclaration = isBooleanTypeDeclaration;
	/**
	 * Custom type guard for NumberTypeDeclaration. Returns true if node is instance of NumberTypeDeclaration. Returns false otherwise.
	 * Also returns false for super interfaces of NumberTypeDeclaration.
	 */
	function isNumberTypeDeclaration(node) {
	    return node.kind() == "NumberTypeDeclaration" && node.RAMLVersion() == "RAML08";
	}
	exports.isNumberTypeDeclaration = isNumberTypeDeclaration;
	/**
	 * Custom type guard for IntegerTypeDeclaration. Returns true if node is instance of IntegerTypeDeclaration. Returns false otherwise.
	 * Also returns false for super interfaces of IntegerTypeDeclaration.
	 */
	function isIntegerTypeDeclaration(node) {
	    return node.kind() == "IntegerTypeDeclaration" && node.RAMLVersion() == "RAML08";
	}
	exports.isIntegerTypeDeclaration = isIntegerTypeDeclaration;
	/**
	 * Custom type guard for DateTypeDeclaration. Returns true if node is instance of DateTypeDeclaration. Returns false otherwise.
	 * Also returns false for super interfaces of DateTypeDeclaration.
	 */
	function isDateTypeDeclaration(node) {
	    return node.kind() == "DateTypeDeclaration" && node.RAMLVersion() == "RAML08";
	}
	exports.isDateTypeDeclaration = isDateTypeDeclaration;
	/**
	 * Custom type guard for FileTypeDeclaration. Returns true if node is instance of FileTypeDeclaration. Returns false otherwise.
	 * Also returns false for super interfaces of FileTypeDeclaration.
	 */
	function isFileTypeDeclaration(node) {
	    return node.kind() == "FileTypeDeclaration" && node.RAMLVersion() == "RAML08";
	}
	exports.isFileTypeDeclaration = isFileTypeDeclaration;
	/**
	 * Custom type guard for BodyLike. Returns true if node is instance of BodyLike. Returns false otherwise.
	 * Also returns false for super interfaces of BodyLike.
	 */
	function isBodyLike(node) {
	    return node.kind() == "BodyLike" && node.RAMLVersion() == "RAML08";
	}
	exports.isBodyLike = isBodyLike;
	/**
	 * Custom type guard for SchemaString. Returns true if node is instance of SchemaString. Returns false otherwise.
	 * Also returns false for super interfaces of SchemaString.
	 */
	function isSchemaString(node) {
	    return node.kind() == "SchemaString" && node.RAMLVersion() == "RAML08";
	}
	exports.isSchemaString = isSchemaString;
	/**
	 * Custom type guard for JSonSchemaString. Returns true if node is instance of JSonSchemaString. Returns false otherwise.
	 * Also returns false for super interfaces of JSonSchemaString.
	 */
	function isJSonSchemaString(node) {
	    return node.kind() == "JSonSchemaString" && node.RAMLVersion() == "RAML08";
	}
	exports.isJSonSchemaString = isJSonSchemaString;
	/**
	 * Custom type guard for XMLSchemaString. Returns true if node is instance of XMLSchemaString. Returns false otherwise.
	 * Also returns false for super interfaces of XMLSchemaString.
	 */
	function isXMLSchemaString(node) {
	    return node.kind() == "XMLSchemaString" && node.RAMLVersion() == "RAML08";
	}
	exports.isXMLSchemaString = isXMLSchemaString;
	/**
	 * Custom type guard for ExampleString. Returns true if node is instance of ExampleString. Returns false otherwise.
	 * Also returns false for super interfaces of ExampleString.
	 */
	function isExampleString(node) {
	    return node.kind() == "ExampleString" && node.RAMLVersion() == "RAML08";
	}
	exports.isExampleString = isExampleString;
	/**
	 * Custom type guard for JSONExample. Returns true if node is instance of JSONExample. Returns false otherwise.
	 * Also returns false for super interfaces of JSONExample.
	 */
	function isJSONExample(node) {
	    return node.kind() == "JSONExample" && node.RAMLVersion() == "RAML08";
	}
	exports.isJSONExample = isJSONExample;
	/**
	 * Custom type guard for XMLExample. Returns true if node is instance of XMLExample. Returns false otherwise.
	 * Also returns false for super interfaces of XMLExample.
	 */
	function isXMLExample(node) {
	    return node.kind() == "XMLExample" && node.RAMLVersion() == "RAML08";
	}
	exports.isXMLExample = isXMLExample;
	/**
	 * Custom type guard for XMLBody. Returns true if node is instance of XMLBody. Returns false otherwise.
	 * Also returns false for super interfaces of XMLBody.
	 */
	function isXMLBody(node) {
	    return node.kind() == "XMLBody" && node.RAMLVersion() == "RAML08";
	}
	exports.isXMLBody = isXMLBody;
	/**
	 * Custom type guard for JSONBody. Returns true if node is instance of JSONBody. Returns false otherwise.
	 * Also returns false for super interfaces of JSONBody.
	 */
	function isJSONBody(node) {
	    return node.kind() == "JSONBody" && node.RAMLVersion() == "RAML08";
	}
	exports.isJSONBody = isJSONBody;
	/**
	 * Custom type guard for SecuritySchemeRef. Returns true if node is instance of SecuritySchemeRef. Returns false otherwise.
	 * Also returns false for super interfaces of SecuritySchemeRef.
	 */
	function isSecuritySchemeRef(node) {
	    return node.kind() == "SecuritySchemeRef" && node.RAMLVersion() == "RAML08";
	}
	exports.isSecuritySchemeRef = isSecuritySchemeRef;
	/**
	 * Custom type guard for AbstractSecurityScheme. Returns true if node is instance of AbstractSecurityScheme. Returns false otherwise.
	 * Also returns false for super interfaces of AbstractSecurityScheme.
	 */
	function isAbstractSecurityScheme(node) {
	    return node.kind() == "AbstractSecurityScheme" && node.RAMLVersion() == "RAML08";
	}
	exports.isAbstractSecurityScheme = isAbstractSecurityScheme;
	/**
	 * Custom type guard for SecuritySchemePart. Returns true if node is instance of SecuritySchemePart. Returns false otherwise.
	 * Also returns false for super interfaces of SecuritySchemePart.
	 */
	function isSecuritySchemePart(node) {
	    return node.kind() == "SecuritySchemePart" && node.RAMLVersion() == "RAML08";
	}
	exports.isSecuritySchemePart = isSecuritySchemePart;
	/**
	 * Custom type guard for TraitRef. Returns true if node is instance of TraitRef. Returns false otherwise.
	 * Also returns false for super interfaces of TraitRef.
	 */
	function isTraitRef(node) {
	    return node.kind() == "TraitRef" && node.RAMLVersion() == "RAML08";
	}
	exports.isTraitRef = isTraitRef;
	/**
	 * Custom type guard for Trait. Returns true if node is instance of Trait. Returns false otherwise.
	 * Also returns false for super interfaces of Trait.
	 */
	function isTrait(node) {
	    return node.kind() == "Trait" && node.RAMLVersion() == "RAML08";
	}
	exports.isTrait = isTrait;
	/**
	 * Custom type guard for SecuritySchemeSettings. Returns true if node is instance of SecuritySchemeSettings. Returns false otherwise.
	 * Also returns false for super interfaces of SecuritySchemeSettings.
	 */
	function isSecuritySchemeSettings(node) {
	    return node.kind() == "SecuritySchemeSettings" && node.RAMLVersion() == "RAML08";
	}
	exports.isSecuritySchemeSettings = isSecuritySchemeSettings;
	/**
	 * Custom type guard for OAuth1SecuritySchemeSettings. Returns true if node is instance of OAuth1SecuritySchemeSettings. Returns false otherwise.
	 * Also returns false for super interfaces of OAuth1SecuritySchemeSettings.
	 */
	function isOAuth1SecuritySchemeSettings(node) {
	    return node.kind() == "OAuth1SecuritySchemeSettings" && node.RAMLVersion() == "RAML08";
	}
	exports.isOAuth1SecuritySchemeSettings = isOAuth1SecuritySchemeSettings;
	/**
	 * Custom type guard for FixedUri. Returns true if node is instance of FixedUri. Returns false otherwise.
	 * Also returns false for super interfaces of FixedUri.
	 */
	function isFixedUri(node) {
	    return node.kind() == "FixedUri" && node.RAMLVersion() == "RAML08";
	}
	exports.isFixedUri = isFixedUri;
	/**
	 * Custom type guard for OAuth2SecuritySchemeSettings. Returns true if node is instance of OAuth2SecuritySchemeSettings. Returns false otherwise.
	 * Also returns false for super interfaces of OAuth2SecuritySchemeSettings.
	 */
	function isOAuth2SecuritySchemeSettings(node) {
	    return node.kind() == "OAuth2SecuritySchemeSettings" && node.RAMLVersion() == "RAML08";
	}
	exports.isOAuth2SecuritySchemeSettings = isOAuth2SecuritySchemeSettings;
	/**
	 * Custom type guard for OAuth2SecurityScheme. Returns true if node is instance of OAuth2SecurityScheme. Returns false otherwise.
	 * Also returns false for super interfaces of OAuth2SecurityScheme.
	 */
	function isOAuth2SecurityScheme(node) {
	    return node.kind() == "OAuth2SecurityScheme" && node.RAMLVersion() == "RAML08";
	}
	exports.isOAuth2SecurityScheme = isOAuth2SecurityScheme;
	/**
	 * Custom type guard for OAuth1SecurityScheme. Returns true if node is instance of OAuth1SecurityScheme. Returns false otherwise.
	 * Also returns false for super interfaces of OAuth1SecurityScheme.
	 */
	function isOAuth1SecurityScheme(node) {
	    return node.kind() == "OAuth1SecurityScheme" && node.RAMLVersion() == "RAML08";
	}
	exports.isOAuth1SecurityScheme = isOAuth1SecurityScheme;
	/**
	 * Custom type guard for BasicSecurityScheme. Returns true if node is instance of BasicSecurityScheme. Returns false otherwise.
	 * Also returns false for super interfaces of BasicSecurityScheme.
	 */
	function isBasicSecurityScheme(node) {
	    return node.kind() == "BasicSecurityScheme" && node.RAMLVersion() == "RAML08";
	}
	exports.isBasicSecurityScheme = isBasicSecurityScheme;
	/**
	 * Custom type guard for DigestSecurityScheme. Returns true if node is instance of DigestSecurityScheme. Returns false otherwise.
	 * Also returns false for super interfaces of DigestSecurityScheme.
	 */
	function isDigestSecurityScheme(node) {
	    return node.kind() == "DigestSecurityScheme" && node.RAMLVersion() == "RAML08";
	}
	exports.isDigestSecurityScheme = isDigestSecurityScheme;
	/**
	 * Custom type guard for CustomSecurityScheme. Returns true if node is instance of CustomSecurityScheme. Returns false otherwise.
	 * Also returns false for super interfaces of CustomSecurityScheme.
	 */
	function isCustomSecurityScheme(node) {
	    return node.kind() == "CustomSecurityScheme" && node.RAMLVersion() == "RAML08";
	}
	exports.isCustomSecurityScheme = isCustomSecurityScheme;
	/**
	 * Custom type guard for MimeType. Returns true if node is instance of MimeType. Returns false otherwise.
	 * Also returns false for super interfaces of MimeType.
	 */
	function isMimeType(node) {
	    return node.kind() == "MimeType" && node.RAMLVersion() == "RAML08";
	}
	exports.isMimeType = isMimeType;
	/**
	 * Custom type guard for RelativeUriString. Returns true if node is instance of RelativeUriString. Returns false otherwise.
	 * Also returns false for super interfaces of RelativeUriString.
	 */
	function isRelativeUriString(node) {
	    return node.kind() == "RelativeUriString" && node.RAMLVersion() == "RAML08";
	}
	exports.isRelativeUriString = isRelativeUriString;
	/**
	 * Custom type guard for GlobalSchema. Returns true if node is instance of GlobalSchema. Returns false otherwise.
	 * Also returns false for super interfaces of GlobalSchema.
	 */
	function isGlobalSchema(node) {
	    return node.kind() == "GlobalSchema" && node.RAMLVersion() == "RAML08";
	}
	exports.isGlobalSchema = isGlobalSchema;
	/**
	 * Custom type guard for RAMLSimpleElement. Returns true if node is instance of RAMLSimpleElement. Returns false otherwise.
	 * Also returns false for super interfaces of RAMLSimpleElement.
	 */
	function isRAMLSimpleElement(node) {
	    return node.kind() == "RAMLSimpleElement" && node.RAMLVersion() == "RAML08";
	}
	exports.isRAMLSimpleElement = isRAMLSimpleElement;
	/**
	 * Custom type guard for DocumentationItem. Returns true if node is instance of DocumentationItem. Returns false otherwise.
	 * Also returns false for super interfaces of DocumentationItem.
	 */
	function isDocumentationItem(node) {
	    return node.kind() == "DocumentationItem" && node.RAMLVersion() == "RAML08";
	}
	exports.isDocumentationItem = isDocumentationItem;
	/**
	 * Custom type guard for Resource. Returns true if node is instance of Resource. Returns false otherwise.
	 * Also returns false for super interfaces of Resource.
	 */
	function isResource(node) {
	    return node.kind() == "Resource" && node.RAMLVersion() == "RAML08";
	}
	exports.isResource = isResource;
	//# sourceMappingURL=raml08parserapi.js.map

/***/ },
/* 14 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var universe = __webpack_require__(30);
	/////////////////////// properties
	function isDocumentationProperty(p) {
	    return p.nameId() === universe.Universe10.Api.properties.documentation.name ||
	        p.nameId() === universe.Universe08.Api.properties.documentation.name;
	}
	exports.isDocumentationProperty = isDocumentationProperty;
	function isUsagePropertyName(name) {
	    return name === universe.Universe10.Trait.properties.usage.name ||
	        name === universe.Universe08.Trait.properties.usage.name ||
	        name === universe.Universe10.ResourceType.properties.usage.name ||
	        name === universe.Universe08.ResourceType.properties.usage.name ||
	        name === universe.Universe10.Library.properties.usage.name ||
	        name === universe.Universe10.Overlay.properties.usage.name ||
	        name === universe.Universe10.Extension.properties.usage.name;
	}
	exports.isUsagePropertyName = isUsagePropertyName;
	function isUsageProperty(p) {
	    return isUsagePropertyName(p.nameId());
	}
	exports.isUsageProperty = isUsageProperty;
	function isMasterRefProperty(p) {
	    return p.nameId() == universe.Universe10.Overlay.properties.extends.name ||
	        p.nameId() == universe.Universe10.Extension.properties.extends.name;
	}
	exports.isMasterRefProperty = isMasterRefProperty;
	function isDescriptionPropertyName(name) {
	    return name === universe.Universe10.TypeDeclaration.properties.description.name ||
	        name === "description";
	    //TODO too long to actually list every element having a description, so a couple of checks to cause compile error, and a simple equals check. Also we do not want to affect performance that much.
	}
	exports.isDescriptionPropertyName = isDescriptionPropertyName;
	function isDescriptionProperty(p) {
	    return isDescriptionPropertyName(p.nameId());
	}
	exports.isDescriptionProperty = isDescriptionProperty;
	function isRequiredPropertyName(name) {
	    return name === universe.Universe10.TypeDeclaration.properties.required.name ||
	        name === universe.Universe08.Parameter.properties.required.name ||
	        name === "required";
	    //TODO too long to actually list every element having displayname, so a couple of checks to cause compile error, and a simple equals check. Also we do not want to affect performance that much.
	}
	exports.isRequiredPropertyName = isRequiredPropertyName;
	function isDisplayNamePropertyName(name) {
	    return name === universe.Universe10.TypeDeclaration.properties.displayName.name ||
	        name === "displayName";
	    //TODO too long to actually list every element having displayname, so a couple of checks to cause compile error, and a simple equals check. Also we do not want to affect performance that much.
	}
	exports.isDisplayNamePropertyName = isDisplayNamePropertyName;
	function isDisplayNameProperty(p) {
	    return isDisplayNamePropertyName(p.nameId());
	}
	exports.isDisplayNameProperty = isDisplayNameProperty;
	function isRequiredProperty(p) {
	    return isRequiredPropertyName(p.nameId());
	}
	exports.isRequiredProperty = isRequiredProperty;
	function isTitlePropertyName(name) {
	    return name === universe.Universe10.Api.properties.title.name ||
	        name === universe.Universe08.Api.properties.title.name ||
	        name === universe.Universe10.DocumentationItem.properties.title.name ||
	        name === universe.Universe08.DocumentationItem.properties.title.name ||
	        name === universe.Universe10.Overlay.properties.title.name ||
	        name === universe.Universe10.Extension.properties.title.name;
	}
	exports.isTitlePropertyName = isTitlePropertyName;
	function isTitleProperty(p) {
	    return isTitlePropertyName(p.nameId());
	}
	exports.isTitleProperty = isTitleProperty;
	function isHeadersProperty(p) {
	    return isHeadersPropertyName(p.nameId());
	}
	exports.isHeadersProperty = isHeadersProperty;
	function isHeadersPropertyName(name) {
	    return name === universe.Universe08.MethodBase.properties.headers.name ||
	        name === universe.Universe08.Response.properties.headers.name ||
	        name === universe.Universe08.SecuritySchemePart.properties.headers.name ||
	        name === universe.Universe10.MethodBase.properties.headers.name ||
	        name === universe.Universe10.Response.properties.headers.name;
	}
	exports.isHeadersPropertyName = isHeadersPropertyName;
	function isFormParametersProperty(p) {
	    return isFormParametersPropertyName(p.nameId());
	}
	exports.isFormParametersProperty = isFormParametersProperty;
	function isFormParametersPropertyName(name) {
	    return name === universe.Universe08.BodyLike.properties.formParameters.name;
	}
	exports.isFormParametersPropertyName = isFormParametersPropertyName;
	function isQueryParametersProperty(p) {
	    return isQueryParametersPropertyName(p.nameId());
	}
	exports.isQueryParametersProperty = isQueryParametersProperty;
	function isQueryParametersPropertyName(name) {
	    return name === universe.Universe08.MethodBase.properties.queryParameters.name ||
	        name === universe.Universe08.SecuritySchemePart.properties.queryParameters.name ||
	        name === universe.Universe10.MethodBase.properties.queryParameters.name;
	}
	exports.isQueryParametersPropertyName = isQueryParametersPropertyName;
	function isAnnotationsProperty(p) {
	    return p.nameId() === universe.Universe10.Api.properties.annotations.name ||
	        //p.nameId() === universe.Universe10.AbstractSecurityScheme.properties.annotations.name ||
	        p.nameId() === universe.Universe10.TypeDeclaration.properties.annotations.name ||
	        p.nameId() === universe.Universe10.Response.properties.annotations.name;
	}
	exports.isAnnotationsProperty = isAnnotationsProperty;
	function isAnnotationProperty(p) {
	    return p.nameId() === universe.Universe10.AnnotationRef.properties.annotation.name;
	}
	exports.isAnnotationProperty = isAnnotationProperty;
	function isIsProperty(p) {
	    return p.nameId() === universe.Universe10.MethodBase.properties.is.name ||
	        p.nameId() === universe.Universe08.Method.properties.is.name ||
	        p.nameId() === universe.Universe10.ResourceBase.properties.is.name ||
	        p.nameId() === universe.Universe08.ResourceType.properties.is.name ||
	        p.nameId() === universe.Universe08.Resource.properties.is.name;
	}
	exports.isIsProperty = isIsProperty;
	function isSecuredByProperty(p) {
	    return p.nameId() === universe.Universe10.Api.properties.securedBy.name ||
	        p.nameId() === universe.Universe08.Api.properties.securedBy.name ||
	        p.nameId() === universe.Universe10.MethodBase.properties.securedBy.name ||
	        p.nameId() === universe.Universe08.MethodBase.properties.securedBy.name ||
	        p.nameId() === universe.Universe08.ResourceType.properties.securedBy.name ||
	        p.nameId() === universe.Universe08.Resource.properties.securedBy.name ||
	        p.nameId() === universe.Universe10.ResourceBase.properties.securedBy.name;
	}
	exports.isSecuredByProperty = isSecuredByProperty;
	function isSecuritySchemesProperty(p) {
	    return p.nameId() === universe.Universe10.LibraryBase.properties.securitySchemes.name ||
	        p.nameId() === universe.Universe08.Api.properties.securitySchemes.name;
	}
	exports.isSecuritySchemesProperty = isSecuritySchemesProperty;
	function isSecuritySchemeProperty(p) {
	    return p.nameId() === universe.Universe10.SecuritySchemeRef.properties.securityScheme.name ||
	        p.nameId() === universe.Universe08.SecuritySchemeRef.properties.securityScheme.name;
	}
	exports.isSecuritySchemeProperty = isSecuritySchemeProperty;
	function isTypeProperty(p) {
	    return p.nameId() === universe.Universe10.AbstractSecurityScheme.properties.type.name ||
	        p.nameId() === universe.Universe08.AbstractSecurityScheme.properties.type.name ||
	        p.nameId() === universe.Universe08.ResourceType.properties.type.name ||
	        p.nameId() === universe.Universe08.Resource.properties.type.name ||
	        p.nameId() === universe.Universe08.Parameter.properties.type.name ||
	        p.nameId() === universe.Universe10.ResourceBase.properties.type.name ||
	        p.nameId() === universe.Universe10.TypeDeclaration.properties.type.name;
	}
	exports.isTypeProperty = isTypeProperty;
	function isPropertiesProperty(p) {
	    return p.nameId() === universe.Universe10.ObjectTypeDeclaration.properties.properties.name;
	}
	exports.isPropertiesProperty = isPropertiesProperty;
	function isResponsesProperty(p) {
	    return p.nameId() === universe.Universe10.MethodBase.properties.responses.name ||
	        p.nameId() === universe.Universe08.MethodBase.properties.responses.name;
	}
	exports.isResponsesProperty = isResponsesProperty;
	function isProtocolsProperty(p) {
	    return p.nameId() === universe.Universe10.Api.properties.protocols.name ||
	        p.nameId() === universe.Universe08.Api.properties.protocols.name ||
	        p.nameId() === universe.Universe10.MethodBase.properties.protocols.name;
	}
	exports.isProtocolsProperty = isProtocolsProperty;
	function isNameProperty(p) {
	    return p.nameId() === universe.Universe10.TypeDeclaration.properties.name.name ||
	        p.nameId() === universe.Universe10.TypeDeclaration.properties.name.name ||
	        p.nameId() === universe.Universe08.AbstractSecurityScheme.properties.name.name ||
	        p.nameId() === universe.Universe10.AbstractSecurityScheme.properties.name.name ||
	        p.nameId() === universe.Universe08.Trait.properties.name.name ||
	        p.nameId() === universe.Universe10.Trait.properties.name.name ||
	        p.nameId() === "name";
	    //TODO too long to actually list every element having a name, so a couple of checks to cause compile error, and a simple equals check. Also we do not want to affect performance that much.
	}
	exports.isNameProperty = isNameProperty;
	function isBodyProperty(p) {
	    return p.nameId() === universe.Universe10.MethodBase.properties.body.name ||
	        p.nameId() === universe.Universe08.MethodBase.properties.body.name ||
	        p.nameId() === universe.Universe10.Response.properties.body.name ||
	        p.nameId() === universe.Universe08.Response.properties.body.name;
	}
	exports.isBodyProperty = isBodyProperty;
	function isSchemaProperty(p) {
	    return p.nameId() === universe.Universe08.BodyLike.properties.schema.name ||
	        p.nameId() === universe.Universe08.XMLBody.properties.schema.name ||
	        p.nameId() === universe.Universe08.JSONBody.properties.schema.name ||
	        p.nameId() === universe.Universe10.TypeDeclaration.properties.schema.name;
	}
	exports.isSchemaProperty = isSchemaProperty;
	function isTraitsProperty(p) {
	    return p.nameId() === universe.Universe08.Api.properties.traits.name ||
	        p.nameId() === universe.Universe10.LibraryBase.properties.traits.name;
	}
	exports.isTraitsProperty = isTraitsProperty;
	function isTraitProperty(p) {
	    return p.nameId() === universe.Universe08.TraitRef.properties.trait.name ||
	        p.nameId() === universe.Universe10.TraitRef.properties.trait.name;
	}
	exports.isTraitProperty = isTraitProperty;
	function isResourceTypesProperty(p) {
	    return p.nameId() === universe.Universe08.Api.properties.resourceTypes.name ||
	        p.nameId() === universe.Universe10.LibraryBase.properties.resourceTypes.name;
	}
	exports.isResourceTypesProperty = isResourceTypesProperty;
	function isResourceTypeProperty(p) {
	    return p.nameId() === universe.Universe08.ResourceTypeRef.properties.resourceType.name ||
	        p.nameId() === universe.Universe10.ResourceTypeRef.properties.resourceType.name;
	}
	exports.isResourceTypeProperty = isResourceTypeProperty;
	function isFacetsProperty(p) {
	    return p.nameId() === universe.Universe10.TypeDeclaration.properties.facets.name;
	}
	exports.isFacetsProperty = isFacetsProperty;
	function isSchemasProperty(p) {
	    return p.nameId() === universe.Universe08.Api.properties.schemas.name ||
	        p.nameId() === universe.Universe10.LibraryBase.properties.schemas.name;
	}
	exports.isSchemasProperty = isSchemasProperty;
	//export function isSignatureProperty(p:hl.IProperty) : boolean {
	//    return p.nameId() === universe.Universe10.Method.properties.signature.name ||
	//    p.nameId() === universe.Universe10.Resource.properties.signature.name;
	//}
	function isResourcesProperty(p) {
	    return p.nameId() === universe.Universe10.Api.properties.resources.name ||
	        p.nameId() === universe.Universe08.Api.properties.resources.name ||
	        p.nameId() === universe.Universe10.Resource.properties.resources.name ||
	        p.nameId() === universe.Universe08.Resource.properties.resources.name;
	}
	exports.isResourcesProperty = isResourcesProperty;
	function isMethodsProperty(p) {
	    return p.nameId() === universe.Universe10.ResourceBase.properties.methods.name ||
	        p.nameId() === universe.Universe08.Resource.properties.methods.name ||
	        p.nameId() === universe.Universe08.ResourceType.properties.methods.name;
	}
	exports.isMethodsProperty = isMethodsProperty;
	function isTypesProperty(p) {
	    return p.nameId() === universe.Universe10.LibraryBase.properties.types.name;
	}
	exports.isTypesProperty = isTypesProperty;
	function isExampleProperty(p) {
	    return p.nameId() === universe.Universe10.TypeDeclaration.properties.example.name ||
	        p.nameId() === "example";
	    //TODO too long to actually list every element having an example, so a couple of checks to cause compile error, and a simple equals check. Also we do not want to affect performance that much.
	}
	exports.isExampleProperty = isExampleProperty;
	function isEnumProperty(p) {
	    return p.nameId() === universe.Universe10.StringTypeDeclaration.properties.enum.name
	        || p.nameId() === universe.Universe10.NumberTypeDeclaration.properties.enum.name
	        || p.nameId() === universe.Universe08.StringTypeDeclaration.properties.enum.name;
	}
	exports.isEnumProperty = isEnumProperty;
	function isExamplesProperty(p) {
	    return p.nameId() === universe.Universe10.TypeDeclaration.properties.example.name || p.nameId() === universe.Universe10.TypeDeclaration.properties.examples.name;
	}
	exports.isExamplesProperty = isExamplesProperty;
	function isValueProperty(p) {
	    return p.nameId() === universe.Universe08.GlobalSchema.properties.value.name;
	}
	exports.isValueProperty = isValueProperty;
	function isUriParametersProperty(p) {
	    return p.nameId() === universe.Universe08.Api.properties.uriParameters.name ||
	        p.nameId() === universe.Universe08.ResourceType.properties.uriParameters.name ||
	        p.nameId() === universe.Universe08.Resource.properties.uriParameters.name ||
	        p.nameId() === universe.Universe10.ResourceBase.properties.uriParameters.name;
	}
	exports.isUriParametersProperty = isUriParametersProperty;
	function isBaseUriParametersProperty(p) {
	    return p.nameId() === universe.Universe08.Resource.properties.baseUriParameters.name ||
	        p.nameId() === universe.Universe08.Api.properties.baseUriParameters.name ||
	        p.nameId() === universe.Universe10.Api.properties.baseUriParameters.name;
	}
	exports.isBaseUriParametersProperty = isBaseUriParametersProperty;
	function isRAMLVersionProperty(p) {
	    return p.nameId() === universe.Universe08.Api.properties.RAMLVersion.name ||
	        p.nameId() === universe.Universe10.Api.properties.RAMLVersion.name;
	}
	exports.isRAMLVersionProperty = isRAMLVersionProperty;
	function isUsesProperty(p) {
	    return p.nameId() === universe.Universe10.FragmentDeclaration.properties.uses.name;
	}
	exports.isUsesProperty = isUsesProperty;
	function isAnnotationTypesProperty(p) {
	    return p.nameId() === universe.Universe10.LibraryBase.properties.annotationTypes.name;
	}
	exports.isAnnotationTypesProperty = isAnnotationTypesProperty;
	function isRepeatProperty(p) {
	    return p.nameId() === universe.Universe08.Parameter.properties.repeat.name ||
	        p.nameId() === universe.Universe10.TypeDeclaration.properties.repeat.name;
	}
	exports.isRepeatProperty = isRepeatProperty;
	/////////////////////// types
	function isMethodType(type) {
	    return type.key() == universe.Universe10.Method ||
	        type.key() == universe.Universe08.Method;
	}
	exports.isMethodType = isMethodType;
	function isApiType(type) {
	    return type.key() == universe.Universe10.Api ||
	        type.key() == universe.Universe08.Api;
	}
	exports.isApiType = isApiType;
	function isBooleanTypeType(type) {
	    return type.key() == universe.Universe10.BooleanType ||
	        type.key() == universe.Universe08.BooleanType;
	}
	exports.isBooleanTypeType = isBooleanTypeType;
	function isMarkdownStringType(type) {
	    return type.key() == universe.Universe10.MarkdownString ||
	        type.key() == universe.Universe08.MarkdownString;
	}
	exports.isMarkdownStringType = isMarkdownStringType;
	function isResourceType(type) {
	    return type.key() == universe.Universe10.Resource ||
	        type.key() == universe.Universe08.Resource;
	}
	exports.isResourceType = isResourceType;
	function isTraitType(type) {
	    return type.key() == universe.Universe10.Trait ||
	        type.key() == universe.Universe08.Trait;
	}
	exports.isTraitType = isTraitType;
	function isTraitRefType(type) {
	    return type.key() == universe.Universe10.TraitRef ||
	        type.key() == universe.Universe08.TraitRef;
	}
	exports.isTraitRefType = isTraitRefType;
	function isResourceTypeRefType(type) {
	    return type.key() == universe.Universe10.ResourceTypeRef ||
	        type.key() == universe.Universe08.ResourceTypeRef;
	}
	exports.isResourceTypeRefType = isResourceTypeRefType;
	function isGlobalSchemaType(type) {
	    return type.key() == universe.Universe08.GlobalSchema;
	}
	exports.isGlobalSchemaType = isGlobalSchemaType;
	function isSecuritySchemaType(type) {
	    return type.key() == universe.Universe10.AbstractSecurityScheme ||
	        type.key() == universe.Universe08.AbstractSecurityScheme;
	}
	exports.isSecuritySchemaType = isSecuritySchemaType;
	function isSecuritySchemeRefType(type) {
	    return type.key() == universe.Universe10.SecuritySchemeRef ||
	        type.key() == universe.Universe08.SecuritySchemeRef;
	}
	exports.isSecuritySchemeRefType = isSecuritySchemeRefType;
	function isTypeDeclarationType(type) {
	    return type.key() == universe.Universe10.TypeDeclaration;
	}
	exports.isTypeDeclarationType = isTypeDeclarationType;
	function isResponseType(type) {
	    return type.key() == universe.Universe10.Response ||
	        type.key() == universe.Universe08.Response;
	}
	exports.isResponseType = isResponseType;
	function isBodyLikeType(type) {
	    return type.key() == universe.Universe08.BodyLike;
	}
	exports.isBodyLikeType = isBodyLikeType;
	function isOverlayType(type) {
	    return type.key() == universe.Universe10.Overlay;
	}
	exports.isOverlayType = isOverlayType;
	function isAnnotationTypeType(type) {
	    return false;
	}
	exports.isAnnotationTypeType = isAnnotationTypeType;
	function isResourceTypeType(type) {
	    return type.key() == universe.Universe10.ResourceType ||
	        type.key() == universe.Universe08.ResourceType;
	}
	exports.isResourceTypeType = isResourceTypeType;
	function isSchemaStringType(type) {
	    return type.key() == universe.Universe10.SchemaString ||
	        type.key() == universe.Universe08.SchemaString;
	}
	exports.isSchemaStringType = isSchemaStringType;
	function isMethodBaseType(type) {
	    return type.key() == universe.Universe10.MethodBase ||
	        type.key() == universe.Universe08.MethodBase;
	}
	exports.isMethodBaseType = isMethodBaseType;
	function isLibraryType(type) {
	    return type.key() == universe.Universe10.Library;
	}
	exports.isLibraryType = isLibraryType;
	function isStringTypeType(type) {
	    return type.key() == universe.Universe10.StringType ||
	        type.key() == universe.Universe08.StringType;
	}
	exports.isStringTypeType = isStringTypeType;
	function isExampleSpecType(type) {
	    return type.key() == universe.Universe10.ExampleSpec;
	}
	exports.isExampleSpecType = isExampleSpecType;
	function isExtensionType(type) {
	    return type.key() == universe.Universe10.Extension;
	}
	exports.isExtensionType = isExtensionType;
	function isTypeDeclarationTypeOrDescendant(type) {
	    return type.isAssignableFrom(universe.Universe10.TypeDeclaration.name);
	}
	exports.isTypeDeclarationTypeOrDescendant = isTypeDeclarationTypeOrDescendant;
	function isDocumentationType(type) {
	    return type.key() == universe.Universe10.DocumentationItem ||
	        type.key() == universe.Universe08.DocumentationItem;
	}
	exports.isDocumentationType = isDocumentationType;
	function isAnnotationRefTypeOrDescendant(type) {
	    return type.isAssignableFrom(universe.Universe10.AnnotationRef.name);
	}
	exports.isAnnotationRefTypeOrDescendant = isAnnotationRefTypeOrDescendant;
	function isApiSibling(type) {
	    return type.isAssignableFrom(universe.Universe10.Api.name) || type.isAssignableFrom(universe.Universe08.Api.name);
	}
	exports.isApiSibling = isApiSibling;
	function isLibraryBaseSibling(type) {
	    return type.isAssignableFrom(universe.Universe10.LibraryBase.name);
	}
	exports.isLibraryBaseSibling = isLibraryBaseSibling;
	function isResourceBaseSibling(type) {
	    return type.isAssignableFrom(universe.Universe10.ResourceBase.name) || type.isAssignableFrom(universe.Universe08.Resource.name);
	}
	exports.isResourceBaseSibling = isResourceBaseSibling;
	function isObjectTypeDeclarationSibling(type) {
	    return type.isAssignableFrom(universe.Universe10.ObjectTypeDeclaration.name);
	}
	exports.isObjectTypeDeclarationSibling = isObjectTypeDeclarationSibling;
	function isTypeDeclarationSibling(type) {
	    return type.isAssignableFrom(universe.Universe10.TypeDeclaration.name);
	}
	exports.isTypeDeclarationSibling = isTypeDeclarationSibling;
	function isMethodBaseSibling(type) {
	    return type.isAssignableFrom(universe.Universe10.MethodBase.name) ||
	        type.isAssignableFrom(universe.Universe08.MethodBase.name);
	}
	exports.isMethodBaseSibling = isMethodBaseSibling;
	function isSecuritySchemePartType(type) {
	    return type.key() == universe.Universe10.SecuritySchemePart ||
	        type.key() == universe.Universe08.SecuritySchemePart;
	}
	exports.isSecuritySchemePartType = isSecuritySchemePartType;
	function isMediaTypeProperty(p) {
	    return p.nameId() === universe.Universe08.Api.properties.mediaType.name ||
	        p.nameId() === universe.Universe10.Api.properties.mediaType.name;
	}
	exports.isMediaTypeProperty = isMediaTypeProperty;
	function isRAML08Type(type) {
	    return type.universe().version() == "RAML08";
	}
	exports.isRAML08Type = isRAML08Type;
	function isRAML10Type(type) {
	    return type.universe().version() == "RAML10";
	}
	exports.isRAML10Type = isRAML10Type;
	//# sourceMappingURL=universeHelpers.js.map

/***/ },
/* 15 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(process) {// Copyright Joyent, Inc. and other Node contributors.
	//
	// Permission is hereby granted, free of charge, to any person obtaining a
	// copy of this software and associated documentation files (the
	// "Software"), to deal in the Software without restriction, including
	// without limitation the rights to use, copy, modify, merge, publish,
	// distribute, sublicense, and/or sell copies of the Software, and to permit
	// persons to whom the Software is furnished to do so, subject to the
	// following conditions:
	//
	// The above copyright notice and this permission notice shall be included
	// in all copies or substantial portions of the Software.
	//
	// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
	// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
	// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
	// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
	// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
	// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
	// USE OR OTHER DEALINGS IN THE SOFTWARE.

	// resolves . and .. elements in a path array with directory names there
	// must be no slashes, empty elements, or device names (c:\) in the array
	// (so also no leading and trailing slashes - it does not distinguish
	// relative and absolute paths)
	function normalizeArray(parts, allowAboveRoot) {
	  // if the path tries to go above the root, `up` ends up > 0
	  var up = 0;
	  for (var i = parts.length - 1; i >= 0; i--) {
	    var last = parts[i];
	    if (last === '.') {
	      parts.splice(i, 1);
	    } else if (last === '..') {
	      parts.splice(i, 1);
	      up++;
	    } else if (up) {
	      parts.splice(i, 1);
	      up--;
	    }
	  }

	  // if the path is allowed to go above the root, restore leading ..s
	  if (allowAboveRoot) {
	    for (; up--; up) {
	      parts.unshift('..');
	    }
	  }

	  return parts;
	}

	// Split a filename into [root, dir, basename, ext], unix version
	// 'root' is just a slash, or nothing.
	var splitPathRe =
	    /^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/;
	var splitPath = function(filename) {
	  return splitPathRe.exec(filename).slice(1);
	};

	// path.resolve([from ...], to)
	// posix version
	exports.resolve = function() {
	  var resolvedPath = '',
	      resolvedAbsolute = false;

	  for (var i = arguments.length - 1; i >= -1 && !resolvedAbsolute; i--) {
	    var path = (i >= 0) ? arguments[i] : process.cwd();

	    // Skip empty and invalid entries
	    if (typeof path !== 'string') {
	      throw new TypeError('Arguments to path.resolve must be strings');
	    } else if (!path) {
	      continue;
	    }

	    resolvedPath = path + '/' + resolvedPath;
	    resolvedAbsolute = path.charAt(0) === '/';
	  }

	  // At this point the path should be resolved to a full absolute path, but
	  // handle relative paths to be safe (might happen when process.cwd() fails)

	  // Normalize the path
	  resolvedPath = normalizeArray(filter(resolvedPath.split('/'), function(p) {
	    return !!p;
	  }), !resolvedAbsolute).join('/');

	  return ((resolvedAbsolute ? '/' : '') + resolvedPath) || '.';
	};

	// path.normalize(path)
	// posix version
	exports.normalize = function(path) {
	  var isAbsolute = exports.isAbsolute(path),
	      trailingSlash = substr(path, -1) === '/';

	  // Normalize the path
	  path = normalizeArray(filter(path.split('/'), function(p) {
	    return !!p;
	  }), !isAbsolute).join('/');

	  if (!path && !isAbsolute) {
	    path = '.';
	  }
	  if (path && trailingSlash) {
	    path += '/';
	  }

	  return (isAbsolute ? '/' : '') + path;
	};

	// posix version
	exports.isAbsolute = function(path) {
	  return path.charAt(0) === '/';
	};

	// posix version
	exports.join = function() {
	  var paths = Array.prototype.slice.call(arguments, 0);
	  return exports.normalize(filter(paths, function(p, index) {
	    if (typeof p !== 'string') {
	      throw new TypeError('Arguments to path.join must be strings');
	    }
	    return p;
	  }).join('/'));
	};


	// path.relative(from, to)
	// posix version
	exports.relative = function(from, to) {
	  from = exports.resolve(from).substr(1);
	  to = exports.resolve(to).substr(1);

	  function trim(arr) {
	    var start = 0;
	    for (; start < arr.length; start++) {
	      if (arr[start] !== '') break;
	    }

	    var end = arr.length - 1;
	    for (; end >= 0; end--) {
	      if (arr[end] !== '') break;
	    }

	    if (start > end) return [];
	    return arr.slice(start, end - start + 1);
	  }

	  var fromParts = trim(from.split('/'));
	  var toParts = trim(to.split('/'));

	  var length = Math.min(fromParts.length, toParts.length);
	  var samePartsLength = length;
	  for (var i = 0; i < length; i++) {
	    if (fromParts[i] !== toParts[i]) {
	      samePartsLength = i;
	      break;
	    }
	  }

	  var outputParts = [];
	  for (var i = samePartsLength; i < fromParts.length; i++) {
	    outputParts.push('..');
	  }

	  outputParts = outputParts.concat(toParts.slice(samePartsLength));

	  return outputParts.join('/');
	};

	exports.sep = '/';
	exports.delimiter = ':';

	exports.dirname = function(path) {
	  var result = splitPath(path),
	      root = result[0],
	      dir = result[1];

	  if (!root && !dir) {
	    // No dirname whatsoever
	    return '.';
	  }

	  if (dir) {
	    // It has a dirname, strip trailing slash
	    dir = dir.substr(0, dir.length - 1);
	  }

	  return root + dir;
	};


	exports.basename = function(path, ext) {
	  var f = splitPath(path)[2];
	  // TODO: make this comparison case-insensitive on windows?
	  if (ext && f.substr(-1 * ext.length) === ext) {
	    f = f.substr(0, f.length - ext.length);
	  }
	  return f;
	};


	exports.extname = function(path) {
	  return splitPath(path)[3];
	};

	function filter (xs, f) {
	    if (xs.filter) return xs.filter(f);
	    var res = [];
	    for (var i = 0; i < xs.length; i++) {
	        if (f(xs[i], i, xs)) res.push(xs[i]);
	    }
	    return res;
	}

	// String.prototype.substr - negative index don't work in IE8
	var substr = 'ab'.substr(-1) === 'b'
	    ? function (str, start, len) { return str.substr(start, len) }
	    : function (str, start, len) {
	        if (start < 0) start = str.length + start;
	        return str.substr(start, len);
	    }
	;
	
	/* WEBPACK VAR INJECTION */}.call(exports, __webpack_require__(56)))

/***/ },
/* 16 */
/***/ function(module, exports, __webpack_require__) {

	/// <reference path="../../typings/main.d.ts" />
	"use strict";
	var __extends = (this && this.__extends) || function (d, b) {
	    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
	    function __() { this.constructor = d; }
	    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
	};
	var defs = __webpack_require__(33);
	var hl = __webpack_require__(10);
	var _ = __webpack_require__(61);
	var proxy = __webpack_require__(37);
	var def = defs;
	var builder = __webpack_require__(26);
	var search = __webpack_require__(27);
	var mutators = __webpack_require__(38);
	var linter = __webpack_require__(25);
	var expander = __webpack_require__(24);
	var typeBuilder = __webpack_require__(39);
	var universes = __webpack_require__(30);
	var jsyaml = __webpack_require__(21);
	var textutil = __webpack_require__(40);
	var services = def;
	var yaml = __webpack_require__(70);
	var factory10 = __webpack_require__(41);
	var factory08 = __webpack_require__(42);
	var universeHelpers = __webpack_require__(14);
	var resourceRegistry = __webpack_require__(22);
	var rTypes = defs.rt;
	var contentprovider = __webpack_require__(31);
	function qName(x, context) {
	    //var dr=search.declRoot(context);
	    var nm = x.name();
	    if (x.lowLevel().unit() != context.lowLevel().unit()) {
	        var root = context;
	        while (true) {
	            if (root.lowLevel().includePath() || root.parent() == null) {
	                if (!root.unitMap) {
	                    root.unitMap = {};
	                    root.asElement().elements().forEach(function (x) {
	                        if (x.definition().key() == universes.Universe10.UsesDeclaration) {
	                            var mm = x.attr("value");
	                            if (mm) {
	                                var unit = root.lowLevel().unit().resolve(mm.value());
	                                if (unit != null) {
	                                    var key = x.attr("key");
	                                    if (key) {
	                                        root.unitMap[unit.absolutePath()] = key.value();
	                                    }
	                                }
	                            }
	                        }
	                    });
	                }
	                var prefix = root.unitMap[x.lowLevel().unit().absolutePath()];
	                if (prefix) {
	                    return prefix + "." + nm;
	                }
	            }
	            if (!root.parent()) {
	                break;
	            }
	            else {
	                root = root.parent();
	            }
	        }
	    }
	    return nm;
	}
	exports.qName = qName;
	var BasicASTNode = (function () {
	    function BasicASTNode(_node, _parent) {
	        this._node = _node;
	        this._parent = _parent;
	        this._implicit = false;
	        this.values = {};
	        if (_node) {
	            _node.setHighLevelParseResult(this);
	        }
	    }
	    BasicASTNode.prototype.getKind = function () {
	        return hl.NodeKind.BASIC;
	    };
	    BasicASTNode.prototype.asAttr = function () {
	        return null;
	    };
	    BasicASTNode.prototype.asElement = function () {
	        return null;
	    };
	    BasicASTNode.prototype.hashkey = function () {
	        if (!this._hashkey)
	            this._hashkey = this.parent() ? this.parent().hashkey() + "/" + this.name() : this.name();
	        return this._hashkey;
	    };
	    BasicASTNode.prototype.root = function () {
	        if (this.parent()) {
	            return this.parent().root();
	        }
	        return this;
	    };
	    BasicASTNode.prototype.version = function () {
	        return "";
	    };
	    BasicASTNode.prototype.getLowLevelStart = function () {
	        if (this.lowLevel().kind() === jsyaml.Kind.SCALAR) {
	            return this.lowLevel().start();
	        }
	        return this.lowLevel().keyStart();
	    };
	    BasicASTNode.prototype.getLowLevelEnd = function () {
	        if (this.lowLevel().kind() === jsyaml.Kind.SCALAR) {
	            return this.lowLevel().end();
	        }
	        return this.lowLevel().keyEnd();
	    };
	    BasicASTNode.prototype.isSameNode = function (n) {
	        if (n) {
	            if (n.lowLevel().actual() == this.lowLevel().actual()) {
	                return true;
	            }
	        }
	        return false;
	    };
	    BasicASTNode.prototype.checkContextValue = function (name, value, thisObj) {
	        var vl = this.computedValue(name);
	        if (vl && vl.indexOf(value) != -1) {
	            return true; //FIXME
	        }
	        return value == vl || value == 'false';
	    };
	    BasicASTNode.prototype.printDetails = function (indent) {
	        return (indent ? indent : "") + "Unkown\n";
	    };
	    /**
	     * Used for test comparison of two trees. Touching this will require AST tests update.
	     * @param indent
	     * @returns {string}
	     */
	    BasicASTNode.prototype.testSerialize = function (indent) {
	        return (indent ? indent : "") + "Unkown\n";
	    };
	    BasicASTNode.prototype.errors = function () {
	        var errors = [];
	        var q = {
	            accept: function (c) {
	                errors.push(c);
	            },
	            begin: function () {
	            },
	            end: function () {
	            }
	        };
	        this.validate(q);
	        return errors;
	    };
	    BasicASTNode.prototype.markCh = function () {
	        var n = this.lowLevel();
	        n = n._node ? n._node : n;
	        if (n['markCh']) {
	            return true;
	        }
	        n['markCh'] = 1;
	    };
	    BasicASTNode.prototype.unmarkCh = function () {
	        var n = this.lowLevel();
	        n = n._node ? n._node : n;
	        delete n['markCh'];
	    };
	    BasicASTNode.prototype.validate = function (v) {
	        linter.validate(this, v);
	    };
	    BasicASTNode.prototype.allowRecursive = function () {
	        return false;
	    };
	    BasicASTNode.prototype.setComputed = function (name, v) {
	        this.values[name] = v;
	    };
	    BasicASTNode.prototype.computedValue = function (name) {
	        var vl = this.values[name];
	        if (!vl && this.parent()) {
	            return this.parent().computedValue(name);
	        }
	        return vl;
	    };
	    BasicASTNode.prototype.lowLevel = function () {
	        return this._node;
	    };
	    BasicASTNode.prototype.name = function () {
	        var c = this.lowLevel().key();
	        if (!c) {
	            return "";
	        }
	        return c;
	    };
	    BasicASTNode.prototype.optional = function () {
	        var llNode = this.lowLevel();
	        var ownValue = llNode.optional();
	        if (llNode.key() != null) {
	            return ownValue;
	        }
	        var p = this.property();
	        if (!p || !p.isMultiValue()) {
	            return ownValue;
	        }
	        var llParent = llNode.parent();
	        while (llParent && llParent.highLevelNode() == null) {
	            if (llParent.kind() == yaml.Kind.MAPPING) {
	                return llParent.optional();
	            }
	            llParent = llParent.parent();
	        }
	        return ownValue;
	    };
	    BasicASTNode.prototype.parent = function () {
	        return this._parent;
	    };
	    BasicASTNode.prototype.setParent = function (parent) {
	        this._parent = parent;
	    };
	    BasicASTNode.prototype.isElement = function () {
	        return false;
	    };
	    BasicASTNode.prototype.directChildren = function () {
	        return this.children();
	    };
	    BasicASTNode.prototype.children = function () {
	        return [];
	    };
	    BasicASTNode.prototype.isAttached = function () {
	        return this.parent() != null;
	    };
	    BasicASTNode.prototype.isImplicit = function () {
	        return this._implicit;
	    };
	    BasicASTNode.prototype.isAttr = function () {
	        return false;
	    };
	    BasicASTNode.prototype.isUnknown = function () {
	        return true;
	    };
	    BasicASTNode.prototype.id = function () {
	        var _this = this;
	        if (this.cachedId) {
	            return this.cachedId;
	        }
	        if (this._parent) {
	            var parentId = this.parent().id();
	            parentId += "." + this.name();
	            var sameName = this.parent().directChildren().filter(function (x) { return x.name() == _this.name(); });
	            if (sameName.length > 1) {
	                var ind = sameName.indexOf(this);
	                parentId += "[" + ind + "]";
	            }
	            this.cachedId = parentId;
	            return parentId;
	        }
	        this.cachedId = "";
	        return this.cachedId;
	    };
	    BasicASTNode.prototype.localId = function () {
	        return this.name();
	    };
	    BasicASTNode.prototype.fullLocalId = function () {
	        var _this = this;
	        if (this.cachedFullId) {
	            return this.cachedFullId;
	        }
	        if (this._parent) {
	            var result = "." + this.name();
	            var sameName = this.parent().directChildren().filter(function (x) { return x.name() == _this.name(); });
	            if (sameName.length > 1) {
	                var ind = sameName.indexOf(this);
	                result += "[" + ind + "]";
	            }
	            this.cachedFullId = result;
	            return result;
	        }
	        this.cachedFullId = this.localId();
	        return this.cachedFullId;
	    };
	    BasicASTNode.prototype.property = function () {
	        return null;
	    };
	    return BasicASTNode;
	}());
	exports.BasicASTNode = BasicASTNode;
	var StructuredValue = (function () {
	    function StructuredValue(node, _parent, _pr, kv) {
	        if (kv === void 0) { kv = null; }
	        this.node = node;
	        this._parent = _parent;
	        this.kv = kv;
	        this._pr = _pr;
	    }
	    StructuredValue.prototype.valueName = function () {
	        var res = null;
	        if (this.kv) {
	            res = this.kv;
	        }
	        res = this.node.key();
	        if (this._pr && this._pr.isAnnotation()) {
	            if (res && res.charAt(0) == '(') {
	                res = res.substring(1, res.length - 1);
	            }
	        }
	        return res;
	    };
	    StructuredValue.prototype.children = function () {
	        return this.node.children().map(function (x) { return new StructuredValue(x, null, null); });
	    };
	    StructuredValue.prototype.lowLevel = function () {
	        return this.node;
	    };
	    StructuredValue.prototype.toHighLevel = function (parent) {
	        if (!parent && this._parent)
	            parent = this._parent;
	        if (this._hl) {
	            return this._hl;
	        }
	        var vn = this.valueName();
	        var cands = search.referenceTargets(this._pr, parent).filter(function (x) { return qName(x, parent) == vn; });
	        if (cands && cands[0]) {
	            var tp = cands[0].localType();
	            var node = new ASTNodeImpl(this.node, parent, tp, this._pr);
	            if (this._pr) {
	                this._pr.childRestrictions().forEach(function (y) {
	                    node.setComputed(y.name, y.value);
	                });
	            }
	            this._hl = node;
	            return node;
	        }
	        //if (this._pr.range()){
	        //    var node=new ASTNodeImpl(parent.lowLevel(),parent,this._pr.range(),this._pr);
	        //    if (this._pr){
	        //        this._pr.childRestrictions().forEach(y=>{
	        //            node.setComputed(y.name,y.value)
	        //        })
	        //    }
	        //    return node;
	        //}
	        return null;
	    };
	    StructuredValue.prototype.toHighLevel2 = function (parent) {
	        if (!parent && this._parent)
	            parent = this._parent;
	        var vn = this.valueName();
	        var cands = search.referenceTargets(this._pr, parent).filter(function (x) { return qName(x, parent) == vn; });
	        if (cands && cands[0]) {
	            var tp = cands[0].localType();
	            var node = new ASTNodeImpl(this.node, parent, tp, this._pr);
	            if (this._pr) {
	                this._pr.childRestrictions().forEach(function (y) {
	                    node.setComputed(y.name, y.value);
	                });
	            }
	            return node;
	        }
	        if (this._pr.range()) {
	            var node = new ASTNodeImpl(this.node.parent(), parent, this._pr.range(), this._pr);
	            if (this._pr) {
	                this._pr.childRestrictions().forEach(function (y) {
	                    node.setComputed(y.name, y.value);
	                });
	            }
	            return node;
	        }
	        return null;
	    };
	    return StructuredValue;
	}());
	exports.StructuredValue = StructuredValue;
	var ASTPropImpl = (function (_super) {
	    __extends(ASTPropImpl, _super);
	    function ASTPropImpl(node, parent, _def, _prop, fromKey) {
	        if (fromKey === void 0) { fromKey = false; }
	        _super.call(this, node, parent);
	        this._def = _def;
	        this._prop = _prop;
	        this.fromKey = fromKey;
	    }
	    ASTPropImpl.prototype.definition = function () {
	        return this._def;
	    };
	    ASTPropImpl.prototype.asAttr = function () {
	        return this;
	    };
	    ASTPropImpl.prototype.errors = function () {
	        var errors = [];
	        var q = {
	            accept: function (c) {
	                if (c.node === this) {
	                    errors.push(c);
	                }
	            },
	            begin: function () {
	            },
	            end: function () {
	            }
	        };
	        this.parent().validate(q);
	        return errors;
	    };
	    ASTPropImpl.prototype.isString = function () {
	        if (this._def) {
	            if (this._def.key() === universes.Universe08.StringType || this._def.key() == universes.Universe10.StringType) {
	                return true;
	            }
	        }
	        return false;
	    };
	    ASTPropImpl.prototype.isAnnotatedScalar = function () {
	        if (!this.property().isAnnotation() && !this.property().isKey()) {
	            return this.lowLevel().isAnnotatedScalar();
	        }
	        return false;
	    };
	    ASTPropImpl.prototype.annotations = function () {
	        var ch = this.lowLevel().children();
	        var annotations = [];
	        var u = this.definition().universe().type(universes.Universe10.Annotable.name);
	        if (!u) {
	            return annotations;
	        }
	        var pr = u.property("annotations");
	        for (var i = 0; i < ch.length; i++) {
	            var child = ch[i];
	            var key = child.key();
	            if (key != null && key[0] == ("(") && key[key.length - 1] == (")")) {
	                var attr = new ASTPropImpl(child, this.parent(), pr.range(), pr);
	                annotations.push(attr);
	            }
	        }
	        return annotations;
	    };
	    ASTPropImpl.prototype.getKind = function () {
	        return hl.NodeKind.ATTRIBUTE;
	    };
	    ASTPropImpl.prototype.owningWrapper = function () {
	        return {
	            node: this.parent().wrapperNode(),
	            property: this.name()
	        };
	    };
	    ASTPropImpl.prototype.patchType = function (t) {
	        this._def = t;
	    };
	    ASTPropImpl.prototype.findReferenceDeclaration = function () {
	        var _this = this;
	        var targets = search.referenceTargets(this.property(), this.parent());
	        var vl = this.value();
	        if (vl instanceof StructuredValue) {
	            var st = vl;
	            var nm = st.valueName();
	        }
	        else {
	            var nm = "" + vl;
	        }
	        var t = _.find(targets, function (x) { return qName(x, _this.parent()) == nm; });
	        return t;
	    };
	    ASTPropImpl.prototype.findReferencedValue = function () {
	        var c = this.findReferenceDeclaration();
	        if (c) {
	            var vl = c.attr("value");
	            var ck = c.definition().key();
	            if (ck === universes.Universe08.GlobalSchema) {
	                if (vl) {
	                    var actualValue = vl.value();
	                    if (actualValue) {
	                        var rf = linter.isValid(this._def, this.parent(), actualValue, vl.property());
	                        return rf;
	                    }
	                }
	                return null;
	            }
	        }
	        return c;
	    };
	    ASTPropImpl.prototype.isElement = function () {
	        return false;
	    };
	    ASTPropImpl.prototype.property = function () {
	        return this._prop;
	    };
	    ASTPropImpl.prototype.convertMultivalueToString = function (value) {
	        //|\n  xxx\n  yyy\n  zzz
	        var gap = 0;
	        var pos = 2;
	        while (value[pos] == ' ') {
	            gap++;
	            pos++;
	        }
	        //console.log('gap: ' + gap);
	        var lines = textutil.splitOnLines(value);
	        lines = lines.map(function (line) {
	            //console.log('line: ' + line);
	            return line.substring(gap, line.length);
	        });
	        return lines.join('');
	    };
	    ASTPropImpl.prototype.overrideValue = function (value) {
	        this._value = value;
	    };
	    ASTPropImpl.prototype.value = function () {
	        if (this._value) {
	            return this._value;
	        }
	        this._value = this.calcValue();
	        return this._value;
	    };
	    ASTPropImpl.prototype.calcValue = function () {
	        if (this._computed) {
	            return this.computedValue(this.property().nameId());
	        }
	        if (this.fromKey) {
	            return this._node.key();
	        }
	        if (this.property().isAnnotation() && this._node.key() && this._node.key() != 'annotations') {
	            return new StructuredValue(this._node, this.parent(), this._prop);
	        }
	        var isString = this.property() != null && universeHelpers.isStringTypeType(this.property().range());
	        var actualValue = this._node.value(isString); //TODO FIXME
	        if (this.property().isSelfNode()) {
	            if (!actualValue || actualValue instanceof jsyaml.ASTNode) {
	                actualValue = this._node;
	                if (actualValue.children().length == 0) {
	                    actualValue = null;
	                }
	            }
	        }
	        if (actualValue instanceof jsyaml.ASTNode || actualValue instanceof proxy.LowLevelProxyNode) {
	            var isAnnotatedScalar = false;
	            if (!this.property().range().hasStructure()) {
	                if (this._node.isAnnotatedScalar()) {
	                    this._node.children().forEach(function (x) {
	                        if (x.key() === "value") {
	                            actualValue = x.value(isString);
	                            isAnnotatedScalar = true;
	                        }
	                    });
	                }
	            }
	            if (!isAnnotatedScalar) {
	                if (this._sval) {
	                    return this._sval;
	                }
	                this._sval = new StructuredValue(actualValue, this.parent(), this._prop);
	                return this._sval;
	            }
	        }
	        if (typeof (actualValue) == 'string' && textutil.isMultiLineValue(actualValue)) {
	            var res = this.convertMultivalueToString(actualValue);
	            //console.log('converted: [' + textutil.replaceNewlines(res) + ']');
	            return res;
	        }
	        return actualValue;
	    };
	    ASTPropImpl.prototype.name = function () {
	        return this._prop.nameId();
	    };
	    ASTPropImpl.prototype.printDetails = function (indent) {
	        var className = this.definition().nameId();
	        var definitionClassName = this.property().range().nameId();
	        var result = (indent ? indent : "") +
	            (this.name() + " : " + className
	                + "[" + definitionClassName + "]"
	                + "  =  " + this.value()) + (this.property().isKey() && this.optional() ? "?" : "")
	            + "\n";
	        if (this.value() instanceof StructuredValue) {
	            var structuredHighLevel = this.value().toHighLevel();
	            if (structuredHighLevel && structuredHighLevel.printDetails) {
	                result += structuredHighLevel.printDetails(indent + "\t");
	            }
	        }
	        return result;
	    };
	    /**
	     * Used for test comparison of two trees. Touching this will require AST tests update.
	     * @param indent
	     * @returns {string}
	     */
	    ASTPropImpl.prototype.testSerialize = function (indent) {
	        var className = this.definition().nameId();
	        var result = (indent ? indent : "") +
	            (this.name() + " : " + className
	                + "  =  " + this.value()) +
	            "\n";
	        if (this.value() instanceof StructuredValue) {
	            var structuredHighLevel = this.value().toHighLevel();
	            if (structuredHighLevel && structuredHighLevel.testSerialize) {
	                result += structuredHighLevel.testSerialize((indent ? indent : "") + "  ");
	            }
	            else {
	                var lowLevel = this.value().lowLevel();
	                var dumpObject = lowLevel.dumpToObject();
	                var dump = JSON.stringify(dumpObject);
	                var indentedDump = "";
	                var dumpLines = dump.split("\n");
	                dumpLines.forEach(function (dumpLine) { return indentedDump += ((indent ? indent : "") + "  " + dumpLine + "\n"); });
	                result += indentedDump + "\n";
	            }
	        }
	        return result;
	    };
	    ASTPropImpl.prototype.isAttr = function () {
	        return true;
	    };
	    ASTPropImpl.prototype.isUnknown = function () {
	        return false;
	    };
	    ASTPropImpl.prototype.setValue = function (value) {
	        mutators.setValue(this, value);
	        this._value = null;
	    };
	    ASTPropImpl.prototype.setKey = function (value) {
	        mutators.setKey(this, value);
	        this._value = null;
	    };
	    ASTPropImpl.prototype.children = function () {
	        return [];
	    };
	    ASTPropImpl.prototype.addStringValue = function (value) {
	        mutators.addStringValue(this, value);
	        this._value = null;
	    };
	    ASTPropImpl.prototype.addStructuredValue = function (sv) {
	        mutators.addStructuredValue(this, sv);
	        this._value = null;
	    };
	    ASTPropImpl.prototype.addValue = function (value) {
	        if (!this.property().isMultiValue())
	            throw new Error("setValue(string) only apply to multi-values properties");
	        if (typeof value == 'string') {
	            this.addStringValue(value);
	        }
	        else {
	            this.addStructuredValue(value);
	        }
	        this._value = null;
	    };
	    ASTPropImpl.prototype.isEmbedded = function () {
	        var keyname = this.lowLevel().asMapping().key.value;
	        //console.log('propery: ' + this.property().name());
	        //console.log('mapping: ' + keyname);
	        return this.property().canBeValue() && keyname != this.property().nameId();
	    };
	    ASTPropImpl.prototype.remove = function () {
	        mutators.removeAttr(this);
	    };
	    ASTPropImpl.prototype.setValues = function (values) {
	        mutators.setValues(this, values);
	        this._value = null;
	    };
	    ASTPropImpl.prototype.isEmpty = function () {
	        if (!this.property().isMultiValue())
	            throw new Error("isEmpty() only apply to multi-values attributes");
	        //console.log('remove: ' + this.name());
	        var node = this.parent();
	        var llnode = node.lowLevel();
	        //node.lowLevel().show('Parent:');
	        var attrs = node.attributes(this.name());
	        //console.log('attributes: ' + attrs.length);
	        if (attrs.length == 0) {
	            return true;
	        }
	        else if (attrs.length == 1) {
	            var anode = attrs[0].lowLevel();
	            //console.log('attribute : ' + anode.kindName());
	            //anode.show("ATTR:");
	            if (anode.isMapping() && anode.value() == null) {
	                // that's crazy but it means zero length array indeed )
	                return true;
	            }
	            else {
	                return false;
	            }
	        }
	        else {
	            return false;
	        }
	    };
	    return ASTPropImpl;
	}(BasicASTNode));
	exports.ASTPropImpl = ASTPropImpl;
	var nodeBuilder = new builder.BasicNodeBuilder();
	(function (OverlayMergeMode) {
	    OverlayMergeMode[OverlayMergeMode["MERGE"] = 0] = "MERGE";
	    OverlayMergeMode[OverlayMergeMode["AGGREGATE"] = 1] = "AGGREGATE";
	})(exports.OverlayMergeMode || (exports.OverlayMergeMode = {}));
	var OverlayMergeMode = exports.OverlayMergeMode;
	var LowLevelWrapperForTypeSystem = (function (_super) {
	    __extends(LowLevelWrapperForTypeSystem, _super);
	    function LowLevelWrapperForTypeSystem(_node, _highLevelRoot) {
	        _super.call(this);
	        this._node = _node;
	        this._highLevelRoot = _highLevelRoot;
	        var v = _highLevelRoot.root();
	        var mst = v.getMaster();
	        if (mst && this._node === _highLevelRoot.lowLevel()) {
	            var master = _highLevelRoot.getMasterCounterPart();
	            if (master) {
	                this._toMerge = new LowLevelWrapperForTypeSystem(master.lowLevel(), master);
	            }
	        }
	    }
	    LowLevelWrapperForTypeSystem.prototype.contentProvider = function () {
	        var root = this._node && this._node.includeBaseUnit() && ((this._node.includePath && this._node.includePath()) ? this._node.includeBaseUnit().resolve(this._node.includePath()) : this._node.includeBaseUnit());
	        return new contentprovider.ContentProvider(root);
	    };
	    LowLevelWrapperForTypeSystem.prototype.key = function () {
	        var vl = this._node.key();
	        if (this._node.optional()) {
	            vl = vl + "?";
	        }
	        return vl;
	    };
	    LowLevelWrapperForTypeSystem.prototype.value = function () {
	        var vk = this._node.valueKind();
	        if (vk === yaml.Kind.SEQ) {
	            return this.children().map(function (x) { return x.value(); });
	        }
	        else if (vk === yaml.Kind.MAP || vk === yaml.Kind.ANCHOR_REF) {
	            var vl = this._node.dumpToObject(true);
	            return vl[this.key()];
	        }
	        else if (this._node.kind() == yaml.Kind.MAP) {
	            var vl = this._node.dumpToObject(true);
	            return vl;
	        }
	        return this._node.value();
	    };
	    LowLevelWrapperForTypeSystem.prototype.children = function () {
	        var _this = this;
	        if (this._children) {
	            return this._children;
	        }
	        if (this.key() == "uses" && !this._node.parent().parent()) {
	            this._children = this._node.children().map(function (x) { return new UsesNodeWrapperFoTypeSystem(x, _this._highLevelRoot); });
	        }
	        else {
	            this._children = this._node.children().map(function (x) { return new LowLevelWrapperForTypeSystem(x, _this._highLevelRoot); });
	        }
	        this.childByKey = {};
	        for (var i = 0; i < this._children.length; i++) {
	            var c = this._children[i];
	            this.childByKey[c.key()] = c;
	        }
	        if (this._toMerge) {
	            var mrg = this._toMerge.children();
	            for (var i = 0; i < mrg.length; i++) {
	                var c = mrg[i];
	                var existing = this.childByKey[c.key()];
	                if (existing) {
	                    existing._toMerge = c;
	                }
	                else {
	                    this._children.push(c);
	                    this.childByKey[c.key()] = c;
	                }
	            }
	        }
	        return this._children;
	    };
	    LowLevelWrapperForTypeSystem.prototype.childWithKey = function (k) {
	        if (!this._children) {
	            this.children();
	        }
	        return this.childByKey[k];
	    };
	    LowLevelWrapperForTypeSystem.prototype.kind = function () {
	        var vk = this._node.valueKind();
	        if (vk == yaml.Kind.MAPPING || vk === null) {
	            return rTypes.NodeKind.MAP;
	        }
	        if (vk == yaml.Kind.MAP) {
	            return rTypes.NodeKind.MAP;
	        }
	        var knd = this._node.kind();
	        if (knd == yaml.Kind.MAP) {
	            return rTypes.NodeKind.MAP;
	        }
	        if (vk == yaml.Kind.SEQ) {
	            return rTypes.NodeKind.ARRAY;
	        }
	        if (vk == yaml.Kind.INCLUDE_REF) {
	            if (this._node.children().length > 0) {
	                //we can safely assume that it is map in the type system in this case
	                return rTypes.NodeKind.MAP;
	            }
	        }
	        return rTypes.NodeKind.SCALAR;
	    };
	    LowLevelWrapperForTypeSystem.prototype.getSource = function () {
	        if (!this._node)
	            return null;
	        var highLevelNode = this._node.highLevelNode();
	        if (!highLevelNode) {
	            var position = this._node.start();
	            var result = search.deepFindNode(this._highLevelRoot, position, position, true, false);
	            if (result) {
	                this._node.setHighLevelParseResult(result);
	                if (result instanceof ASTNodeImpl) {
	                    this._node.setHighLevelNode(result);
	                }
	            }
	            return result;
	        }
	    };
	    return LowLevelWrapperForTypeSystem;
	}(defs.SourceProvider));
	exports.LowLevelWrapperForTypeSystem = LowLevelWrapperForTypeSystem;
	var UsesNodeWrapperFoTypeSystem = (function (_super) {
	    __extends(UsesNodeWrapperFoTypeSystem, _super);
	    function UsesNodeWrapperFoTypeSystem() {
	        _super.apply(this, arguments);
	    }
	    UsesNodeWrapperFoTypeSystem.prototype.children = function () {
	        var s = this._node.unit().resolve(this.value());
	        if (s && s.isRAMLUnit()) {
	            return new LowLevelWrapperForTypeSystem(s.ast(), this._highLevelRoot).children();
	        }
	        return [];
	    };
	    UsesNodeWrapperFoTypeSystem.prototype.anchor = function () {
	        return this._node.actual();
	    };
	    UsesNodeWrapperFoTypeSystem.prototype.childWithKey = function (k) {
	        var mm = this.children();
	        for (var i = 0; i < mm.length; i++) {
	            if (mm[i].key() == k) {
	                return mm[i];
	            }
	        }
	        return null;
	    };
	    return UsesNodeWrapperFoTypeSystem;
	}(LowLevelWrapperForTypeSystem));
	exports.UsesNodeWrapperFoTypeSystem = UsesNodeWrapperFoTypeSystem;
	var ASTNodeImpl = (function (_super) {
	    __extends(ASTNodeImpl, _super);
	    function ASTNodeImpl(node, parent, _def, _prop) {
	        _super.call(this, node, parent);
	        this._def = _def;
	        this._prop = _prop;
	        this._expanded = false;
	        this._allowQuestion = false;
	        this._subTypesCache = null;
	        this._auxChecked = false;
	        /**
	         * Depending on the merge mode, overlays and extensions are either merged with the master, or their trees are joined via aggregation
	         * @type {OverlayMergeMode}
	         */
	        this.overlayMergeMode = OverlayMergeMode.MERGE;
	        if (node) {
	            node.setHighLevelNode(this);
	        }
	        if (node instanceof proxy.LowLevelProxyNode) {
	            this._expanded = true;
	        }
	    }
	    ASTNodeImpl.prototype.validate = function (v) {
	        var k = this.definition().key();
	        if (k == universes.Universe10.Api || k == universes.Universe08.Api || k == universes.Universe10.Extension) {
	            if (!this.isExpanded()) {
	                var nm = expander.expandTraitsAndResourceTypes(this.wrapperNode());
	                var hlnode = nm.highLevel();
	                hlnode.resetChildren();
	                hlnode.children();
	                hlnode._expanded = true;
	                hlnode.clearTypesCache();
	                hlnode.validate(v);
	                return;
	            }
	        }
	        if (k == universes.Universe10.Overlay || k == universes.Universe10.Extension) {
	            this.clearTypesCache();
	        }
	        linter.validate(this, v);
	    };
	    ASTNodeImpl.prototype.clearTypesCache = function () {
	        this._types = null;
	        var c = this.lowLevel().actual();
	        c.types = null;
	    };
	    ASTNodeImpl.prototype.types = function () {
	        var _this = this;
	        if (!this._types) {
	            if (this.parent() && (this.definition().key() !== universes.Universe10.Library)) {
	                return this.parent().types();
	            }
	            else {
	                var c = this.lowLevel().actual();
	                if (c.types) {
	                    return c.types;
	                }
	                this._types = rTypes.parseFromAST(new LowLevelWrapperForTypeSystem(this.lowLevel(), this));
	                this._types.types().forEach(function (x) {
	                    var convertedType = typeBuilder.convertType(_this, x);
	                    // if (defs.instanceOfHasExtra(convertedType)) {
	                    convertedType.putExtra(defs.USER_DEFINED_EXTRA, true);
	                    // }
	                });
	                c.types = this._types;
	            }
	        }
	        return this._types;
	    };
	    ASTNodeImpl.prototype.setTypes = function (t) {
	        this._types = t;
	    };
	    ASTNodeImpl.prototype.parsedType = function () {
	        if (!this._ptype) {
	            if (this.property() && this.property().nameId() == universes.Universe10.MethodBase.properties.body.name) {
	                this._ptype = rTypes.parseTypeFromAST(this.name(), new LowLevelWrapperForTypeSystem(this.lowLevel(), this), this.types(), true, false, false);
	            }
	            else {
	                var annotation = this.property() && this.property().nameId() == universes.Universe10.LibraryBase.properties.annotationTypes.name;
	                var tl = (!this.property()) || (this.property().nameId() == universes.Universe10.LibraryBase.properties.types.name || this.property().nameId() == universes.Universe10.LibraryBase.properties.schemas.name);
	                this._ptype = rTypes.parseTypeFromAST(this.name(), new LowLevelWrapperForTypeSystem(this.lowLevel(), this), this.types(), false, annotation, tl);
	            }
	            if (this.property() && universeHelpers.isTypesProperty(this.property())
	                && this.parent() && universeHelpers.isApiType(this.parent().definition())) {
	                //top level types declared via "types"
	                // this._ptype.setExtra()
	                if (this._ptype.putExtra) {
	                    this._ptype.putExtra(defs.DEFINED_IN_TYPES_EXTRA, true);
	                }
	            }
	            var potentialHasExtra = this._ptype;
	            potentialHasExtra.putExtra(defs.USER_DEFINED_EXTRA, true);
	            this._ptype.putExtra(defs.SOURCE_EXTRA, this);
	        }
	        return this._ptype;
	    };
	    ASTNodeImpl.prototype.localType = function () {
	        return typeBuilder.typeFromNode(this);
	    };
	    ASTNodeImpl.prototype.patchProp = function (pr) {
	        this._prop = pr;
	    };
	    ASTNodeImpl.prototype.getKind = function () {
	        return hl.NodeKind.NODE;
	    };
	    ASTNodeImpl.prototype.wrapperNode = function () {
	        if (!this._wrapperNode) {
	            //forcing discrimination
	            this.children();
	            this._wrapperNode = this.buildWrapperNode();
	        }
	        return this._wrapperNode;
	    };
	    ASTNodeImpl.prototype.asElement = function () {
	        return this;
	    };
	    ASTNodeImpl.prototype.buildWrapperNode = function () {
	        var ramlVersion = this.definition().universe().version();
	        if (ramlVersion == 'RAML10') {
	            return factory10.buildWrapperNode(this);
	        }
	        else if (ramlVersion == 'RAML08') {
	            return factory08.buildWrapperNode(this);
	        }
	        return null;
	    };
	    ASTNodeImpl.prototype.propertiesAllowedToUse = function () {
	        var _this = this;
	        return this.definition().allProperties().filter(function (x) { return _this.isAllowedToUse(x); });
	    };
	    ASTNodeImpl.prototype.isAllowedToUse = function (p) {
	        var _this = this;
	        var ok = true;
	        if (p.getAdapter(services.RAMLPropertyService).isSystem()) {
	            return false;
	        }
	        p.getContextRequirements().forEach(function (y) {
	            if (y.name.indexOf('(') != -1) {
	                //TODO HANDLE IT LATER
	                return true;
	            }
	            var vl = _this.computedValue(y.name);
	            if (vl) {
	                ok = ok && (vl == y.value);
	            }
	            else {
	                if (y.value) {
	                    ok = false;
	                }
	            }
	        });
	        return ok;
	    };
	    ASTNodeImpl.prototype.allowRecursive = function () {
	        if (this.definition().getAdapter(services.RAMLService).isUserDefined()) {
	            return true;
	        }
	        return false;
	    };
	    ASTNodeImpl.prototype.setWrapperNode = function (node) {
	        this._wrapperNode = node;
	    };
	    ASTNodeImpl.prototype.setAssociatedType = function (d) {
	        this._associatedDef = d;
	    };
	    ASTNodeImpl.prototype.associatedType = function () {
	        return this._associatedDef;
	    };
	    ASTNodeImpl.prototype.knownIds = function () {
	        //initializing ids if needed
	        //TODO refactor workaround
	        this.isAuxilary();
	        if (this._knownIds) {
	            return this._knownIds;
	        }
	        else {
	            return {};
	        }
	    };
	    ASTNodeImpl.prototype.findById = function (id) {
	        var _this = this;
	        var v = this._knownIds;
	        if (!v) {
	            this._knownIds = {};
	            var all = search.allChildren(this);
	            all.forEach(function (x) { return _this._knownIds[x.id()] = x; });
	        }
	        return this._knownIds[id];
	    };
	    ASTNodeImpl.prototype.isAuxilary = function () {
	        if (this._isAux) {
	            return true;
	        }
	        if (this._auxChecked) {
	            return false;
	        }
	        this._auxChecked = true;
	        var masterApi = this.getMaster();
	        if (masterApi) {
	            this._isAux = true;
	            this.initilizeKnownIDs(masterApi);
	            return true;
	        }
	        return false;
	    };
	    ASTNodeImpl.prototype.initilizeKnownIDs = function (api) {
	        var _this = this;
	        this._knownIds = {};
	        var allChildren = search.allChildren(api);
	        allChildren.forEach(function (x) { return _this._knownIds[x.id()] = x; });
	        this._knownIds[""] = api;
	    };
	    ASTNodeImpl.prototype.getMaster = function () {
	        if (this.masterApi) {
	            return this.masterApi;
	        }
	        return this.calculateMasterByRef();
	    };
	    /**
	     * Forcefully sets a master unit for this API, which may be different from the one, current unit points to
	     * via masterRef.
	     * @param master
	     */
	    ASTNodeImpl.prototype.overrideMaster = function (master) {
	        this.masterApi = master;
	        this.resetAuxilaryState();
	    };
	    ASTNodeImpl.prototype.setMergeMode = function (mergeMode) {
	        this.overlayMergeMode = mergeMode;
	        this.resetAuxilaryState();
	    };
	    ASTNodeImpl.prototype.getMergeMode = function () {
	        return this.overlayMergeMode;
	    };
	    ASTNodeImpl.prototype.calculateMasterByRef = function () {
	        var unit = this.lowLevel().unit();
	        if (!unit)
	            return null;
	        var masterReferenceNode = unit.getMasterReferenceNode();
	        if (!masterReferenceNode || !masterReferenceNode.value()) {
	            return null;
	        }
	        var lc = this.lowLevel();
	        if (lc.master) {
	            return lc.master;
	        }
	        var masterPath = masterReferenceNode.value();
	        var masterUnit = this.lowLevel().unit().project().resolve(this.lowLevel().unit().path(), masterPath);
	        if (!masterUnit) {
	            return null;
	        }
	        var result = masterUnit.expandedHighLevel();
	        result.setMergeMode(this.overlayMergeMode);
	        lc.master = result;
	        return result;
	    };
	    ASTNodeImpl.prototype.resetAuxilaryState = function () {
	        this._isAux = false;
	        this._auxChecked = false;
	        this._knownIds = null;
	        this.clearChildrenCache();
	    };
	    ASTNodeImpl.prototype.printDetails = function (indent) {
	        var result = "";
	        if (!indent)
	            indent = "";
	        var classname = this.definition().nameId();
	        var definitionClasName = this.property() ? this.property().range().nameId() : "";
	        var parentPropertyName = this.property() ? this.property().nameId() : "";
	        result += indent + classname + "[" + definitionClasName + "]" + " <--- " + parentPropertyName + "\n";
	        this.children().forEach(function (child) {
	            result += child.printDetails(indent + "\t");
	        });
	        return result;
	    };
	    /**
	     * Used for test comparison of two trees. Touching this will require AST tests update.
	     * @param indent
	     * @returns {string}
	     */
	    ASTNodeImpl.prototype.testSerialize = function (indent) {
	        var result = "";
	        if (!indent)
	            indent = "";
	        var classname = this.definition().nameId();
	        var parentPropertyName = this.property() ? this.property().nameId() : "";
	        result += indent + classname + " <-- " + parentPropertyName + "\n";
	        this.children().forEach(function (child) {
	            if (child.testSerialize) {
	                result += child.testSerialize(indent + "  ");
	            }
	        });
	        return result;
	    };
	    ASTNodeImpl.prototype.getExtractedChildren = function () {
	        var r = this.root();
	        if (r.isAuxilary()) {
	            if (r._knownIds) {
	                var i = r._knownIds[this.id()];
	                if (i) {
	                    var v = i.children();
	                    return v;
	                }
	            }
	            return [];
	        }
	        return [];
	    };
	    ASTNodeImpl.prototype.getMasterCounterPart = function () {
	        var r = this.root();
	        if (r.isAuxilary()) {
	            if (r._knownIds) {
	                var i = r._knownIds[this.id()];
	                return i;
	            }
	            return null;
	        }
	        return null;
	    };
	    ASTNodeImpl.prototype.getExtractedLowLevelChildren = function (n) {
	        var r = this.root();
	        if (r.isAuxilary()) {
	            if (r._knownLowLevelIds) {
	                var i = r._knownLowLevelIds[this.id()];
	                if (i) {
	                    return i.children();
	                }
	            }
	            return [];
	        }
	        return [];
	    };
	    ASTNodeImpl.prototype.allowsQuestion = function () {
	        return this._allowQuestion || this.definition().getAdapter(services.RAMLService).getAllowQuestion();
	    };
	    ASTNodeImpl.prototype.findReferences = function () {
	        var _this = this;
	        var rs = [];
	        search.refFinder(this.root(), this, rs);
	        //TODO FIX ME
	        if (rs.length > 1) {
	            rs = rs.filter(function (x) { return x != _this && x.parent() != _this; });
	        }
	        //filtering out equal results
	        var filteredReferences = [];
	        rs.forEach(function (ref) {
	            if (!_.find(filteredReferences, function (existing) { return existing == ref; })) {
	                filteredReferences.push(ref);
	            }
	        });
	        return filteredReferences;
	    };
	    ASTNodeImpl.prototype.setNamePatch = function (s) {
	        this._patchedName = s;
	    };
	    ASTNodeImpl.prototype.isNamePatch = function () {
	        return this._patchedName;
	    };
	    ASTNodeImpl.prototype.name = function () {
	        if (this._patchedName) {
	            return this._patchedName;
	        }
	        var ka = _.find(this.directChildren(), function (x) { return x.property() && x.property().getAdapter(services.RAMLPropertyService).isKey(); });
	        if (ka && ka instanceof ASTPropImpl) {
	            var c = ka.value();
	            return c;
	        }
	        return _super.prototype.name.call(this);
	    };
	    ASTNodeImpl.prototype.findElementAtOffset = function (n) {
	        return this._findNode(this, n, n);
	    };
	    ASTNodeImpl.prototype.isElement = function () {
	        return true;
	    };
	    ASTNodeImpl.prototype.universe = function () {
	        if (this._universe) {
	            return this._universe;
	        }
	        return this.definition().universe();
	    };
	    ASTNodeImpl.prototype.setUniverse = function (u) {
	        this._universe = u;
	    };
	    ASTNodeImpl.prototype._findNode = function (n, offset, end) {
	        var _this = this;
	        if (n == null) {
	            return null;
	        }
	        if (n.lowLevel()) {
	            //var node:ASTNode=<ASTNode>n;
	            if (n.lowLevel().start() <= offset && n.lowLevel().end() >= end) {
	                var res = n;
	                //TODO INCLUDES
	                n.elements().forEach(function (x) {
	                    if (x.lowLevel().unit() != n.lowLevel().unit()) {
	                        return;
	                    }
	                    var m = _this._findNode(x, offset, end);
	                    if (m) {
	                        res = m;
	                    }
	                });
	                return res;
	            }
	        }
	        return null;
	    };
	    ASTNodeImpl.prototype.isStub = function () {
	        return (!this.lowLevel().unit()) || this.lowLevel().unit().isStubUnit();
	    };
	    ASTNodeImpl.prototype.add = function (node) {
	        mutators.addToNode(this, node);
	    };
	    ASTNodeImpl.prototype.remove = function (node) {
	        mutators.removeNodeFrom(this, node);
	    };
	    ASTNodeImpl.prototype.dump = function (flavor) {
	        return this._node.dump();
	    };
	    ASTNodeImpl.prototype.patchType = function (d) {
	        this._def = d;
	        var ass = this._associatedDef;
	        this._associatedDef = null;
	        this._children = null;
	        this._mergedChildren = null;
	    };
	    ASTNodeImpl.prototype.children = function () {
	        var lowLevel = this.lowLevel();
	        if (lowLevel && lowLevel.isValueInclude && lowLevel.isValueInclude() && resourceRegistry.isWaitingFor(lowLevel.includePath())) {
	            this._children = null;
	            return [];
	        }
	        if (this._children) {
	            if (this._mergedChildren) {
	                return this._mergedChildren;
	            }
	            this._mergedChildren = this.mergeChildren(this._children, this.getExtractedChildren());
	            return this._mergedChildren;
	        }
	        if (this._node) {
	            this._children = nodeBuilder.process(this, this._node.children());
	            this._children = this._children.filter(function (x) { return x != null; });
	            //FIXME
	            return this.mergeChildren(this._children, this.getExtractedChildren());
	        }
	        return [];
	    };
	    ASTNodeImpl.prototype.mergeChildren = function (originalChildren, masterChildren) {
	        var _this = this;
	        var root = this.root();
	        if (root.overlayMergeMode == OverlayMergeMode.AGGREGATE) {
	            //simply joining the sets
	            return originalChildren.concat(masterChildren);
	        }
	        else if (root.overlayMergeMode == OverlayMergeMode.MERGE) {
	            var result = [];
	            originalChildren.forEach(function (originalChild) {
	                var masterCounterpart = _.find(masterChildren, function (masterChild) { return masterChild.fullLocalId() == originalChild.fullLocalId(); });
	                if (!masterCounterpart) {
	                    //we dont have a counterpart, so simply adding to result
	                    result.push(originalChild);
	                }
	                else {
	                    //there is a counterpart, so deciding what to do:
	                    _this.mergeChild(result, originalChild, masterCounterpart);
	                }
	            });
	            masterChildren.forEach(function (masterChild) {
	                var originalCounterpart = _.find(originalChildren, function (originalChild) { return masterChild.fullLocalId() == originalChild.fullLocalId(); });
	                if (!originalCounterpart) {
	                    //we dont have a counterpart, so simply adding to result
	                    result.push(masterChild);
	                }
	            });
	            return result;
	        }
	        return null;
	    };
	    ASTNodeImpl.prototype.mergeLowLevelChildren = function (originalChildren, masterChildren) {
	        var _this = this;
	        var root = this.root();
	        if (root.overlayMergeMode == OverlayMergeMode.AGGREGATE) {
	            //simply joining the sets
	            return originalChildren.concat(masterChildren);
	        }
	        else if (root.overlayMergeMode == OverlayMergeMode.MERGE) {
	            var result = [];
	            originalChildren.forEach(function (originalChild) {
	                var masterCounterpart = _.find(masterChildren, function (masterChild) { return masterChild.key() == originalChild.key(); });
	                if (!masterCounterpart) {
	                    //we dont have a counterpart, so simply adding to result
	                    result.push(originalChild);
	                }
	                else {
	                    //there is a counterpart, so deciding what to do:
	                    _this.mergeLowLevelChild(result, originalChild, masterCounterpart);
	                }
	            });
	            masterChildren.forEach(function (masterChild) {
	                var originalCounterpart = _.find(originalChildren, function (originalChild) { return masterChild.key() == originalChild.key(); });
	                if (!originalCounterpart) {
	                    //we dont have a counterpart, so simply adding to result
	                    result.push(masterChild);
	                }
	            });
	            return result;
	        }
	        return null;
	    };
	    ASTNodeImpl.prototype.mergeLowLevelChild = function (result, originalChild, masterChild) {
	        if (originalChild.kind() != masterChild.kind()) {
	            //should not happen theoretically
	            result.push(originalChild);
	            result.push(masterChild);
	            return;
	        }
	        result.push(originalChild);
	    };
	    ASTNodeImpl.prototype.mergeChild = function (result, originalChild, masterChild) {
	        if (originalChild.getKind() != masterChild.getKind()) {
	            //should not happen theoretically
	            result.push(originalChild);
	            result.push(masterChild);
	            return;
	        }
	        if (originalChild.getKind() == hl.NodeKind.NODE) {
	            result.push(originalChild);
	            return;
	        }
	        else if (originalChild.getKind() == hl.NodeKind.ATTRIBUTE) {
	            //if ((<ASTPropImpl>originalChild).name() == "displayName" ||
	            //    (<ASTPropImpl>originalChild).name() == "title") {
	            //    console.log("OriginalChildForDisplayName: " + (<ASTPropImpl>originalChild).value())
	            //    console.log("MasterChildForDisplayName: " + (<ASTPropImpl>masterChild).value())
	            //
	            //}
	            result.push(originalChild);
	            return;
	        }
	        else if (originalChild.getKind() == hl.NodeKind.BASIC) {
	            //we do not know what to do with basic nodes, so adding both.
	            result.push(originalChild);
	            result.push(masterChild);
	            return;
	        }
	    };
	    ASTNodeImpl.prototype.directChildren = function () {
	        if (this._children) {
	            return this._children;
	        }
	        if (this._node) {
	            this._children = nodeBuilder.process(this, this._node.children());
	            return this._children;
	        }
	        return [];
	    };
	    ASTNodeImpl.prototype.resetChildren = function () {
	        this._children = null;
	        this._mergedChildren = null;
	    };
	    ASTNodeImpl.prototype.isEmptyRamlFile = function () {
	        var llroot = this.lowLevel().root();
	        return llroot.isScalar();
	    };
	    ASTNodeImpl.prototype.initRamlFile = function () {
	        mutators.initEmptyRAMLFile(this);
	    };
	    ASTNodeImpl.prototype.createAttr = function (n, v) {
	        mutators.createAttr(this, n, v);
	    };
	    ASTNodeImpl.prototype.isAttr = function () {
	        return false;
	    };
	    ASTNodeImpl.prototype.isUnknown = function () {
	        return false;
	    };
	    ASTNodeImpl.prototype.value = function () {
	        return this._node.value();
	    };
	    ASTNodeImpl.prototype.valuesOf = function (propName) {
	        var pr = this._def.property(propName);
	        if (pr != null) {
	            return this.elements().filter(function (x) { return x.property() == pr; });
	        }
	        return [];
	    };
	    ASTNodeImpl.prototype.attr = function (n) {
	        return _.find(this.attrs(), function (y) { return y.name() == n; });
	    };
	    ASTNodeImpl.prototype.attrOrCreate = function (name) {
	        var a = this.attr(name);
	        if (!a)
	            this.createAttr(name, '');
	        return this.attr(name);
	    };
	    ASTNodeImpl.prototype.attrValue = function (n) {
	        var a = this.attr(n);
	        return a ? a.value() : null;
	    };
	    ASTNodeImpl.prototype.attributes = function (n) {
	        return _.filter(this.attrs(), function (y) { return y.name() == n; });
	    };
	    ASTNodeImpl.prototype.attrs = function () {
	        var rs = this.children().filter(function (x) { return x.isAttr(); });
	        if (this._patchedName) {
	            var kp = _.find(this.definition().allProperties(), function (x) { return x.getAdapter(services.RAMLPropertyService).isKey(); });
	            if (kp) {
	                var mm = new ASTPropImpl(this.lowLevel(), this, kp.range(), kp, true);
	                mm._value = this._patchedName;
	                return [mm].concat(rs);
	            }
	        }
	        return rs;
	    };
	    ASTNodeImpl.prototype.elements = function () {
	        return this.children()
	            .filter(function (x) { return !x.isAttr() && !x.isUnknown(); });
	    };
	    ASTNodeImpl.prototype.element = function (n) {
	        var r = this.elementsOfKind(n);
	        if (r.length > 0) {
	            return r[0];
	        }
	        return null;
	    };
	    ASTNodeImpl.prototype.elementsOfKind = function (n) {
	        var r = this.elements().filter(function (x) { return x.property().nameId() == n; });
	        return r;
	    };
	    ASTNodeImpl.prototype.definition = function () {
	        return this._def;
	    };
	    ASTNodeImpl.prototype.property = function () {
	        return this._prop;
	    };
	    ASTNodeImpl.prototype.isExpanded = function () {
	        return this._expanded;
	    };
	    ASTNodeImpl.prototype.copy = function () {
	        return new ASTNodeImpl(this.lowLevel().copy(), this.parent(), this.definition(), this.property());
	    };
	    ASTNodeImpl.prototype.clearChildrenCache = function () {
	        this._children = null;
	        this._mergedChildren = null;
	    };
	    ASTNodeImpl.prototype.optionalProperties = function () {
	        var def = this.definition();
	        if (def == null) {
	            return [];
	        }
	        var result = [];
	        var map = {};
	        var children = this.lowLevel().children();
	        children.forEach(function (x) {
	            if (x.optional()) {
	                map[x.key()] = true;
	            }
	        });
	        var props = def.allProperties();
	        props.forEach(function (x) {
	            var prop = x;
	            if (map[prop.nameId()]) {
	                result.push(prop.nameId());
	            }
	        });
	        return result;
	    };
	    return ASTNodeImpl;
	}(BasicASTNode));
	exports.ASTNodeImpl = ASTNodeImpl;
	exports.universeProvider = __webpack_require__(35);
	var getDefinitionSystemType = function (contents, ast) {
	    var spec = "";
	    var ptype = "Api";
	    var num = 0;
	    var pt = 0;
	    for (var n = 0; n < contents.length; n++) {
	        var c = contents.charAt(n);
	        if (c == '\r' || c == '\n') {
	            if (spec) {
	                ptype = contents.substring(pt, n).trim();
	            }
	            else {
	                spec = contents.substring(0, n).trim();
	            }
	            break;
	        }
	        if (c == ' ') {
	            num++;
	            if (!spec && num == 2) {
	                spec = contents.substring(0, n);
	                pt = n;
	            }
	        }
	    }
	    var localUniverse = spec == "#%RAML 1.0" ? new def.Universe(null, "RAML10", exports.universeProvider("RAML10"), "RAML10") : new def.Universe(null, "RAML08", exports.universeProvider("RAML08"));
	    if (ptype == 'API') {
	        ptype = "Api";
	    }
	    if (ptype == 'NamedExample') {
	        ptype = "ExampleSpec";
	    }
	    if (ptype == 'DataType') {
	        ptype = "TypeDeclaration";
	    }
	    if (ptype == 'SecurityScheme') {
	        ptype = "AbstractSecurityScheme";
	    }
	    localUniverse.setTopLevel(ptype);
	    localUniverse.setTypedVersion(spec);
	    // localUniverse.setDescription(spec);
	    return { ptype: ptype, localUniverse: localUniverse };
	};
	function getFragmentDefenitionName(highLevelNode) {
	    var contents = highLevelNode.lowLevel() && highLevelNode.lowLevel().unit() && highLevelNode.lowLevel().unit().contents();
	    if (contents == null) {
	        return null;
	    }
	    return getDefinitionSystemType(contents, highLevelNode.lowLevel()).ptype;
	}
	exports.getFragmentDefenitionName = getFragmentDefenitionName;
	function fromUnit(l) {
	    if (l == null)
	        return null;
	    var contents = l.contents();
	    var ast = l.ast();
	    var __ret = getDefinitionSystemType(contents, ast);
	    var ptype = __ret.ptype;
	    var localUniverse = __ret.localUniverse;
	    var apiType = localUniverse.type(ptype);
	    if (!apiType)
	        apiType = localUniverse.type("Api");
	    var api = new ASTNodeImpl(ast, null, apiType, null);
	    api.setUniverse(localUniverse);
	    //forcing discrimination
	    api.children();
	    return api;
	}
	exports.fromUnit = fromUnit;
	//# sourceMappingURL=highLevelImpl.js.map

/***/ },
/* 17 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var jsyaml = __webpack_require__(21);
	var hlimpl = __webpack_require__(16);
	var yaml = __webpack_require__(70);
	//*** THis is not needed any more *///
	function createStub0(parent, property, key) {
	    var p = parent.definition().property(property);
	    if (!p)
	        return null;
	    var nc = p.range();
	    var node = createStubNode(nc, p, key);
	    return node;
	}
	exports.createStub0 = createStub0;
	function genStructuredValue(type, name, mappings, parent) {
	    var map = yaml.newMap(mappings.map(function (mapping) { return yaml.newMapping(yaml.newScalar(mapping.key), yaml.newScalar(mapping.value)); }));
	    var node = new jsyaml.ASTNode(map, (parent ? parent.lowLevel().unit() : null), parent ? parent.lowLevel() : null, null, null);
	    return new hlimpl.StructuredValue(node, parent, parent ? parent.definition().property(type) : null, name);
	}
	exports.genStructuredValue = genStructuredValue;
	function createStub(parent, property, key) {
	    var p = parent.definition().property(property);
	    if (!p)
	        return null;
	    var nc = p.range();
	    var su = parent.lowLevel().unit().stub();
	    var node = createStubNode(nc, p, key, su);
	    node.isInEdit = true;
	    node.lowLevel()._unit = su;
	    node._parent = parent.copy();
	    node._parent.lowLevel()._unit = su;
	    return node;
	}
	exports.createStub = createStub;
	function createResourceStub(parent, key) {
	    return createStub(parent, "resources", key);
	}
	exports.createResourceStub = createResourceStub;
	function createMethodStub(parent, key) {
	    return createStub(parent, 'methods', key);
	}
	exports.createMethodStub = createMethodStub;
	function createResponseStub(parent, key) {
	    return createStub(parent, 'responses', key);
	}
	exports.createResponseStub = createResponseStub;
	function createBodyStub(parent, key) {
	    return createStub(parent, 'body', key);
	}
	exports.createBodyStub = createBodyStub;
	function createUriParameterStub(parent, key) {
	    return createStub(parent, 'uriParameters', key);
	}
	exports.createUriParameterStub = createUriParameterStub;
	function createQueryParameterStub(parent, key) {
	    return createStub(parent, 'queryParameters', key);
	}
	exports.createQueryParameterStub = createQueryParameterStub;
	function createAttr(_property, val) {
	    var lowLevel = jsyaml.createMapping(_property.nameId(), val);
	    var nm = new hlimpl.ASTPropImpl(lowLevel, null, _property.range(), _property);
	    return nm;
	}
	exports.createAttr = createAttr;
	function createStubNode(t, p, key, unit) {
	    if (key === void 0) { key = null; }
	    var lowLevel = jsyaml.createNode(key ? key : "key");
	    var nm = new hlimpl.ASTNodeImpl(lowLevel, null, t, p);
	    if (!lowLevel.unit()) {
	        lowLevel._unit = unit;
	    }
	    nm.children();
	    return nm;
	}
	exports.createStubNode = createStubNode;
	//# sourceMappingURL=stubs.js.map

/***/ },
/* 18 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var _ = __webpack_require__(61);
	var textutil = __webpack_require__(40);
	var wrapper = __webpack_require__(28);
	var SchemaToModelGenerator = (function () {
	    function SchemaToModelGenerator() {
	    }
	    SchemaToModelGenerator.prototype.generateText = function (schema) {
	        var _this = this;
	        var obj = JSON.parse(schema);
	        var items = obj['items'];
	        if (!items)
	            return '';
	        var text = '';
	        var itemsArray = (items instanceof Array) ? items : [items];
	        text += 'types:\n';
	        itemsArray.forEach(function (e) {
	            //console.log('Item: ' + e.title + ' ' + e.type);
	            text += '  - ' + e.title + ':\n';
	            text += _this.generateObj(e, 3);
	        });
	        return text;
	    };
	    SchemaToModelGenerator.prototype.generateObj = function (e, lev) {
	        var text = '';
	        text += textutil.indent(lev, 'type: ' + e.type) + '\n';
	        if (!e.properties)
	            return;
	        text += textutil.indent(lev, 'properties:\n');
	        //console.log('props: ' + e.properties);
	        for (var name in e.properties) {
	            //console.log('  property: ' + JSON.stringify(p));
	            var p = e.properties[name];
	            text += textutil.indent(lev + 1, name + ':\n');
	            //console.log('  property ' + name + ': ' + p.type);
	            if (p.type == 'object') {
	                text += this.generateObj(p, lev + 2);
	            }
	            else {
	                text += textutil.indent(lev + 2, 'type: ' + p.type) + '\n';
	            }
	        }
	        return text;
	    };
	    SchemaToModelGenerator.prototype.generateTo = function (api, schema, title) {
	        var _this = this;
	        var obj = JSON.parse(schema);
	        var items = obj['items'];
	        if (!items) {
	            if (obj.title)
	                title = obj.title;
	            //console.log('title: ' + title);
	            var type = new wrapper.ObjectTypeDeclarationImpl(title);
	            this.generateObjTo(type, obj);
	            new wrapper.BasicSecuritySchemeImpl(api).addToProp(type, 'types');
	            return [title];
	        }
	        else {
	            var itemsArray = (items instanceof Array) ? items : [items];
	            var types = [];
	            itemsArray.forEach(function (e) {
	                var type = new wrapper.ObjectTypeDeclarationImpl(e.title);
	                _this.generateObjTo(type, e);
	                new wrapper.BasicSecuritySchemeImpl(api).addToProp(type, 'types');
	                types.push(e.title);
	            });
	            return types;
	        }
	    };
	    SchemaToModelGenerator.prototype.generateObjTo = function (type, e) {
	        type.setType(e.type);
	        //console.log('type: ' + type.definition().name());
	        //util.showTypeProperties(type.definition());
	        //type.attrOrCreate('type').setValue(e.type);
	        if (!e.properties)
	            return;
	        //text += textutil.indent(lev, 'properties:\n');
	        //console.log('props: ' + e.properties);
	        for (var name in e.properties) {
	            var p = e.properties[name];
	            var field = this.makeTypeField(name, p);
	            if (p.type == 'array') {
	            }
	            //console.log('  property: ' + JSON.stringify(p));
	            //text += textutil.indent(lev+1, name + ':\n');
	            //console.log('  property ' + name + ': ' + p.type);
	            type.addToProp(field, 'properties');
	        }
	    };
	    SchemaToModelGenerator.prototype.makeTypeField = function (name, p) {
	        var field = this.makeType(name, p.type);
	        if (p.type)
	            field.setType(p.type);
	        if (p.type == 'number') {
	            var n = field;
	            if (p.minimum != undefined)
	                (n).setMinimum(p.minimum);
	            if (p.maximum != undefined)
	                (n).setMaximum(p.maximum);
	        }
	        if (p.type == 'array') {
	            var itype = p.items.type;
	            field.setType(itype + '[]');
	            var a = field;
	            if (p.minItems != undefined)
	                a.setMinItems(p.minItems);
	            if (p.maxItems != undefined)
	                a.setMaxItems(p.maxItems);
	            if (p.uniqueItems != undefined)
	                a.setUniqueItems(p.uniqueItems);
	        }
	        if (p.type == 'object') {
	            this.generateObjTo(field, p);
	        }
	        return field;
	    };
	    SchemaToModelGenerator.prototype.makeType = function (name, type) {
	        if (type == 'number')
	            return new wrapper.NumberTypeDeclarationImpl(name);
	        if (type == 'string')
	            return new wrapper.StringTypeDeclarationImpl(name);
	        if (type == 'array')
	            return new wrapper.ArrayTypeDeclarationImpl(name);
	        return new wrapper.ObjectTypeDeclarationImpl(name);
	    };
	    SchemaToModelGenerator.prototype.generateItemsTo = function (a, obj) {
	        var items = obj['items'];
	        if (!items)
	            return;
	        var itemsArray = (items instanceof Array) ? items : [items];
	        itemsArray.forEach(function (item) {
	            //TODO add items here
	        });
	    };
	    return SchemaToModelGenerator;
	}());
	exports.SchemaToModelGenerator = SchemaToModelGenerator;
	var ModelToSchemaGenerator = (function () {
	    function ModelToSchemaGenerator() {
	    }
	    ModelToSchemaGenerator.prototype.generateSchema = function (node) {
	        var obj = this.generateType(node);
	        obj["$schema"] = "http://json-schema.org/draft-04/schema#";
	        return obj;
	    };
	    ModelToSchemaGenerator.prototype.isSimpleType = function (name) {
	        return name == 'string' || name == 'number' || name == 'boolean' || name == 'object';
	    };
	    ModelToSchemaGenerator.prototype.generateType = function (type) {
	        var typelist = this.allTypes(type);
	        var obj = {};
	        obj.title = type.attrValue('name');
	        var properties = {};
	        if (type.attrValue('type')) {
	            // support multiple inheritance
	            var types = type.attributes('type');
	            //var properties = {};
	            var inherited = false;
	            var simple = false;
	            for (var i in types) {
	                var typevalue = types[i].value();
	                var ll = types[i].lowLevel();
	                obj.type = '';
	                if (ll.isValueInclude()) {
	                    var schema = JSON.parse(typevalue);
	                    obj.type = 'object';
	                    obj.properties = schema.properties;
	                }
	                else {
	                    //console.log('type value: ' + typevalue);
	                    if (this.isSimpleType(typevalue)) {
	                        obj.type = typevalue;
	                        simple = true;
	                        if (inherited)
	                            throw new Error("couldn't mix user defined and basic types in inheritance");
	                    }
	                    else {
	                        var t = this.resolveType(type, typevalue);
	                        if (t) {
	                            var ppp = this.generateTypeExp(typevalue, typelist);
	                            //console.log('res: ' + typevalue + '\n' + JSON.stringify(ppp));
	                            //_.extend(properties, ppp.properties);
	                            if (obj.properties) {
	                                _.extend(obj.properties, ppp.properties);
	                            }
	                            else {
	                                obj.properties = ppp.properties;
	                            }
	                            obj.type = 'object';
	                            inherited = true;
	                            if (simple)
	                                throw new Error("couldn't mix user defined and basic types in inheritance");
	                        }
	                        else {
	                            var ppp = this.generateTypeExp(typevalue, typelist);
	                            //console.log('xtype: ' + typevalue + '\n' + JSON.stringify(ppp));
	                            obj.type = 'object';
	                            inherited = true;
	                            if (ppp.anyOf) {
	                                obj.anyOf = ppp.anyOf;
	                            }
	                        }
	                    }
	                }
	            }
	        }
	        else {
	            obj.type = 'object';
	        }
	        //var ps = this.generateProperties(type);
	        //this.generatePropertiesTo(properties, type);
	        var ownProps = this.generateProperties(type);
	        //_.extend(properties, ownProps);
	        //if(Object.getOwnPropertyNames(properties).length > 0) {
	        if (obj.properties) {
	            //console.log('own.p : ' + obj.properties);
	            //console.log('own: ' + JSON.stringify(ownProps));
	            //console.log('obj.p1: ' + obj.properties);
	            _.extend(obj.properties, ownProps);
	        }
	        else {
	            obj.properties = ownProps;
	        }
	        return obj;
	    };
	    ModelToSchemaGenerator.prototype.makeUnion = function (typelist, types) {
	        var _this = this;
	        var anyof = [];
	        typelist.forEach(function (t) {
	            t = t.trim();
	            if (types[t]) {
	                anyof.push({
	                    type: 'object',
	                    properties: _this.generateType(types[t]).properties
	                });
	            }
	            else {
	                anyof.push({ type: t });
	            }
	        });
	        return anyof;
	    };
	    ModelToSchemaGenerator.prototype.generateTypeExp = function (type, types) {
	        var obj = {};
	        //console.log('type: ' + type);
	        if (textutil.endsWith(type, '[]')) {
	            obj.type = 'array';
	            obj.items = { type: type.substring(0, type.length - 2) };
	        }
	        else if (type.indexOf('|') > 0) {
	            var typelist = type.split('|');
	            obj.anyOf = this.makeUnion(typelist, types);
	        }
	        else {
	            if (types[type]) {
	                var schema = this.generateType(types[type]);
	                obj.type = 'object';
	                obj.properties = schema.properties;
	            }
	            else {
	                obj.type = type;
	            }
	        }
	        return obj;
	    };
	    ModelToSchemaGenerator.prototype.allTypes = function (node) {
	        var api = node.root();
	        var modelTypes = api.elementsOfKind('types');
	        var types = {};
	        modelTypes.forEach(function (type) {
	            //console.log('  types: ' + type.name());
	            types[type.name()] = type;
	        });
	        return types;
	    };
	    ModelToSchemaGenerator.prototype.resolveType = function (node, name) {
	        var types = this.allTypes(node);
	        return types[name];
	    };
	    ModelToSchemaGenerator.prototype.generateProperty = function (node, optional) {
	        var _this = this;
	        var types = this.allTypes(node);
	        var obj = {};
	        var props = node.definition().allProperties();
	        props.forEach(function (p) {
	            if (p.nameId() == 'name')
	                return;
	            var value = node.attrValue(p.nameId());
	            if (!(value != null && value != undefined && value != 'undefined'))
	                return;
	            if (p.nameId() == 'type') {
	                var t = _this.generateTypeExp(value, types);
	                _.extend(obj, t);
	            }
	            else if (p.nameId() == 'enum') {
	                var values = node.attributes('enum');
	                var arr = values.map(function (a) { return a.value(); });
	                obj.enum = arr;
	            }
	            else {
	                obj[p.nameId()] = value;
	            }
	        });
	        if (optional)
	            obj.required = false;
	        var elements = node.elements();
	        var properties = this.generateProperties(node);
	        if (Object.getOwnPropertyNames(properties).length > 0) {
	            obj.properties = properties;
	        }
	        return obj;
	    };
	    ModelToSchemaGenerator.prototype.generateProperties = function (node) {
	        var _this = this;
	        var props = {};
	        var elements = node.elements();
	        var empty = true;
	        elements.forEach(function (p) {
	            var name = p.attrValue('name').trim();
	            var optional = p.optional();
	            props[name] = _this.generateProperty(p, optional);
	            empty = false;
	        });
	        return props;
	    };
	    return ModelToSchemaGenerator;
	}());
	exports.ModelToSchemaGenerator = ModelToSchemaGenerator;
	//# sourceMappingURL=schemaModelGen.js.map

/***/ },
/* 19 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var parser10impl = __webpack_require__(28);
	var defSys = __webpack_require__(33);
	var jsyaml = __webpack_require__(21);
	var ll = __webpack_require__(11);
	function createTypeDeclaration(typeName) {
	    return new parser10impl.TypeDeclarationImpl(typeName);
	}
	exports.createTypeDeclaration = createTypeDeclaration;
	function createObjectTypeDeclaration(typeName) {
	    return new parser10impl.ObjectTypeDeclarationImpl(typeName);
	}
	exports.createObjectTypeDeclaration = createObjectTypeDeclaration;
	//TODO it would be probably better to generate modification interface too
	function setTypeDeclarationSchema(type, schema) {
	    type.setSchema(schema);
	}
	exports.setTypeDeclarationSchema = setTypeDeclarationSchema;
	function setTypeDeclarationExample(type, example) {
	    var exampleSpecType = defSys.getUniverse("RAML10").type(defSys.universesInfo.Universe10.ExampleSpec.name);
	    var examplePropName = defSys.universesInfo.Universe10.TypeDeclaration.properties.example.name;
	    var hlParent = type.highLevel();
	    var llParent = hlParent.lowLevel();
	    var exampleNodes = hlParent.children().filter(function (x) { return x.lowLevel().key() == examplePropName; });
	    var llNode = jsyaml.createNode(examplePropName);
	    ll.setAttr(llNode, example);
	    if (exampleNodes.length > 0) {
	        ll.removeNode(llParent, exampleNodes[0].lowLevel());
	        exampleNodes[0]._node = llNode;
	    }
	    ll.insertNode(llParent, llNode);
	}
	exports.setTypeDeclarationExample = setTypeDeclarationExample;
	function addChild(parent, child) {
	    parent.add(child);
	}
	exports.addChild = addChild;
	//# sourceMappingURL=parserMod.js.map

/***/ },
/* 20 */
/***/ function(module, exports, __webpack_require__) {

	(function (root) {

	  // Store setTimeout reference so promise-polyfill will be unaffected by
	  // other code modifying setTimeout (like sinon.useFakeTimers())
	  var setTimeoutFunc = setTimeout;

	  function noop() {
	  }

	  // Use polyfill for setImmediate for performance gains
	  var asap = (typeof setImmediate === 'function' && setImmediate) ||
	    function (fn) {
	      setTimeoutFunc(fn, 1);
	    };

	  var onUnhandledRejection = function onUnhandledRejection(err) {
	    if (typeof console !== 'undefined' && console) {
	      console.warn('Possible Unhandled Promise Rejection:', err); // eslint-disable-line no-console
	    }
	  };

	  // Polyfill for Function.prototype.bind
	  function bind(fn, thisArg) {
	    return function () {
	      fn.apply(thisArg, arguments);
	    };
	  }

	  function Promise(fn) {
	    if (typeof this !== 'object') throw new TypeError('Promises must be constructed via new');
	    if (typeof fn !== 'function') throw new TypeError('not a function');
	    this._state = 0;
	    this._handled = false;
	    this._value = undefined;
	    this._deferreds = [];

	    doResolve(fn, this);
	  }

	  function handle(self, deferred) {
	    while (self._state === 3) {
	      self = self._value;
	    }
	    if (self._state === 0) {
	      self._deferreds.push(deferred);
	      return;
	    }
	    self._handled = true;
	    asap(function () {
	      var cb = self._state === 1 ? deferred.onFulfilled : deferred.onRejected;
	      if (cb === null) {
	        (self._state === 1 ? resolve : reject)(deferred.promise, self._value);
	        return;
	      }
	      var ret;
	      try {
	        ret = cb(self._value);
	      } catch (e) {
	        reject(deferred.promise, e);
	        return;
	      }
	      resolve(deferred.promise, ret);
	    });
	  }

	  function resolve(self, newValue) {
	    try {
	      // Promise Resolution Procedure: https://github.com/promises-aplus/promises-spec#the-promise-resolution-procedure
	      if (newValue === self) throw new TypeError('A promise cannot be resolved with itself.');
	      if (newValue && (typeof newValue === 'object' || typeof newValue === 'function')) {
	        var then = newValue.then;
	        if (newValue instanceof Promise) {
	          self._state = 3;
	          self._value = newValue;
	          finale(self);
	          return;
	        } else if (typeof then === 'function') {
	          doResolve(bind(then, newValue), self);
	          return;
	        }
	      }
	      self._state = 1;
	      self._value = newValue;
	      finale(self);
	    } catch (e) {
	      reject(self, e);
	    }
	  }

	  function reject(self, newValue) {
	    self._state = 2;
	    self._value = newValue;
	    finale(self);
	  }

	  function finale(self) {
	    if (self._state === 2 && self._deferreds.length === 0) {
	      asap(function() {
	        if (!self._handled) {
	          onUnhandledRejection(self._value);
	        }
	      }, 1);
	    }
	    
	    for (var i = 0, len = self._deferreds.length; i < len; i++) {
	      handle(self, self._deferreds[i]);
	    }
	    self._deferreds = null;
	  }

	  function Handler(onFulfilled, onRejected, promise) {
	    this.onFulfilled = typeof onFulfilled === 'function' ? onFulfilled : null;
	    this.onRejected = typeof onRejected === 'function' ? onRejected : null;
	    this.promise = promise;
	  }

	  /**
	   * Take a potentially misbehaving resolver function and make sure
	   * onFulfilled and onRejected are only called once.
	   *
	   * Makes no guarantees about asynchrony.
	   */
	  function doResolve(fn, self) {
	    var done = false;
	    try {
	      fn(function (value) {
	        if (done) return;
	        done = true;
	        resolve(self, value);
	      }, function (reason) {
	        if (done) return;
	        done = true;
	        reject(self, reason);
	      });
	    } catch (ex) {
	      if (done) return;
	      done = true;
	      reject(self, ex);
	    }
	  }

	  Promise.prototype['catch'] = function (onRejected) {
	    return this.then(null, onRejected);
	  };

	  Promise.prototype.then = function (onFulfilled, onRejected) {
	    var prom = new Promise(noop);
	    handle(this, new Handler(onFulfilled, onRejected, prom));
	    return prom;
	  };

	  Promise.all = function (arr) {
	    var args = Array.prototype.slice.call(arr);

	    return new Promise(function (resolve, reject) {
	      if (args.length === 0) return resolve([]);
	      var remaining = args.length;

	      function res(i, val) {
	        try {
	          if (val && (typeof val === 'object' || typeof val === 'function')) {
	            var then = val.then;
	            if (typeof then === 'function') {
	              then.call(val, function (val) {
	                res(i, val);
	              }, reject);
	              return;
	            }
	          }
	          args[i] = val;
	          if (--remaining === 0) {
	            resolve(args);
	          }
	        } catch (ex) {
	          reject(ex);
	        }
	      }

	      for (var i = 0; i < args.length; i++) {
	        res(i, args[i]);
	      }
	    });
	  };

	  Promise.resolve = function (value) {
	    if (value && typeof value === 'object' && value.constructor === Promise) {
	      return value;
	    }

	    return new Promise(function (resolve) {
	      resolve(value);
	    });
	  };

	  Promise.reject = function (value) {
	    return new Promise(function (resolve, reject) {
	      reject(value);
	    });
	  };

	  Promise.race = function (values) {
	    return new Promise(function (resolve, reject) {
	      for (var i = 0, len = values.length; i < len; i++) {
	        values[i].then(resolve, reject);
	      }
	    });
	  };

	  /**
	   * Set the immediate function to execute callbacks
	   * @param fn {function} Function to execute
	   * @private
	   */
	  Promise._setImmediateFn = function _setImmediateFn(fn) {
	    asap = fn;
	  };
	  
	  Promise._setUnhandledRejectionFn = function _setUnhandledRejectionFn(fn) {
	    onUnhandledRejection = fn;
	  };

	  if (typeof module !== 'undefined' && module.exports) {
	    module.exports = Promise;
	  } else if (!root.Promise) {
	    root.Promise = Promise;
	  }

	})(this);


/***/ },
/* 21 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	/// <reference path="../../../typings/main.d.ts" />
	var lowlevel = __webpack_require__(11);
	var path = __webpack_require__(15);
	var fs = __webpack_require__(36);
	var yaml = __webpack_require__(70);
	var _ = __webpack_require__(61);
	var textutil = __webpack_require__(40);
	var hli = __webpack_require__(16);
	var services = __webpack_require__(34);
	var rr = __webpack_require__(22);
	var util = __webpack_require__(43);
	var URL = __webpack_require__(57);
	var refResolvers = __webpack_require__(23);
	var schemes = __webpack_require__(44);
	var universes = __webpack_require__(30);
	var expander = __webpack_require__(24);
	var Error = yaml.YAMLException;
	exports.Kind = {
	    SCALAR: yaml.Kind.SCALAR
	};
	var MarkupIndentingBuffer = (function () {
	    function MarkupIndentingBuffer(indent) {
	        this.text = '';
	        this.indent = indent;
	    }
	    MarkupIndentingBuffer.prototype.isLastNL = function () {
	        return this.text.length > 0 && this.text[this.text.length - 1] == '\n';
	    };
	    MarkupIndentingBuffer.prototype.addWithIndent = function (lev, s) {
	        if (this.isLastNL()) {
	            this.text += textutil.indent(lev);
	            this.text += this.indent;
	        }
	        this.text += s;
	    };
	    MarkupIndentingBuffer.prototype.addChar = function (ch) {
	        if (this.isLastNL()) {
	            this.text += this.indent;
	        }
	        this.text += ch;
	    };
	    MarkupIndentingBuffer.prototype.append = function (s) {
	        for (var i = 0; i < s.length; i++) {
	            this.addChar(s[i]);
	        }
	    };
	    return MarkupIndentingBuffer;
	}());
	exports.MarkupIndentingBuffer = MarkupIndentingBuffer;
	var CompilationUnit = (function () {
	    function CompilationUnit(_path, _content, _tl, _project, _apath) {
	        this._path = _path;
	        this._content = _content;
	        this._tl = _tl;
	        this._project = _project;
	        this._apath = _apath;
	    }
	    CompilationUnit.prototype.highLevel = function () {
	        if (this._hl) {
	            return this._hl;
	        }
	        this._hl = hli.fromUnit(this);
	        return this._hl;
	    };
	    CompilationUnit.prototype.isStubUnit = function () {
	        return this.stu;
	    };
	    CompilationUnit.prototype.resolveAsync = function (p) {
	        var unit = this._project.resolveAsync(this._path, p);
	        return unit;
	    };
	    CompilationUnit.prototype.getIncludeNodes = function () {
	        var ast = this.ast();
	        var arr = [];
	        ast.gatherIncludes(arr);
	        ast.children().forEach(function (x) {
	            if (x.key() == "uses") {
	                x.children().forEach(function (y) {
	                    arr.push({
	                        includePath: function () { return y.value(); }
	                    });
	                });
	            }
	        });
	        return arr;
	    };
	    CompilationUnit.prototype.cloneToProject = function (p) {
	        var newUnit = new CompilationUnit(this._path, this._content, this._tl, p, this._apath);
	        return newUnit;
	    };
	    CompilationUnit.prototype.clone = function () {
	        var newUnit = new CompilationUnit(this._path, this._content, this._tl, this.project(), this._apath);
	        return newUnit;
	    };
	    CompilationUnit.prototype.stub = function () {
	        var newUnit = new CompilationUnit(this._path, this._content, this._tl, this.project(), this._apath);
	        newUnit.stu = true;
	        return newUnit;
	    };
	    CompilationUnit.prototype.isDirty = function () {
	        return false;
	    };
	    CompilationUnit.prototype.expandedHighLevel = function () {
	        if (this.expanded) {
	            return this.expanded;
	        }
	        var result = this.highLevel().asElement();
	        var nm = expander.expandTraitsAndResourceTypes(result.wrapperNode());
	        var hlnode = nm.highLevel();
	        hlnode._expanded = true;
	        this.expanded = hlnode;
	        return hlnode;
	    };
	    CompilationUnit.prototype.absolutePath = function () {
	        return this._apath;
	    };
	    CompilationUnit.prototype.isRAMLUnit = function () {
	        var en = path.extname(this._path);
	        return en == '.raml' || en == '.yaml' || en == '.yml';
	    };
	    CompilationUnit.prototype.contents = function () {
	        return this._content;
	    };
	    CompilationUnit.prototype.resolve = function (p) {
	        if (typeof p != "string") {
	            p = "" + p;
	        }
	        var unit = this._project.resolve(this._path, p);
	        return unit;
	    };
	    CompilationUnit.prototype.path = function () {
	        return this._path;
	    };
	    CompilationUnit.prototype.lexerErrors = function () {
	        if (this.errors == null) {
	            this.ast();
	        }
	        return this.errors;
	    };
	    CompilationUnit.prototype.ast = function () {
	        var _this = this;
	        if (this._node) {
	            return this._node;
	        }
	        try {
	            var result = yaml.load(this._content, {});
	            this.errors = result.errors;
	            this.errors.forEach(function (x) {
	                if (x.mark) {
	                    x.mark.filePath = _this.absolutePath();
	                }
	            });
	            this._node = new ASTNode(result, this, null, null, null);
	            this._node._errors = this.errors;
	            return this._node;
	        }
	        catch (e) {
	            this.errors = [];
	            this.errors.push(new Error(e.message));
	            //console.log(this._content)
	            //console.log(e)
	            this._node = null;
	            return this._node;
	        }
	    };
	    CompilationUnit.prototype.isTopLevel = function () {
	        return this._tl;
	    };
	    CompilationUnit.prototype.updateContent = function (n) {
	        this._content = n;
	        this.errors = null;
	        this._node = null; //todo incremental update
	        this._lineMapper = null;
	    };
	    CompilationUnit.prototype.updateContentSafe = function (n) {
	        this._content = n;
	        this._lineMapper = null;
	        this._hl = null;
	    };
	    CompilationUnit.prototype.project = function () {
	        return this._project;
	    };
	    CompilationUnit.prototype.lineMapper = function () {
	        if (this._lineMapper == null) {
	            this._lineMapper = new lowlevel.LineMapperImpl(this.contents(), this.absolutePath());
	        }
	        return this._lineMapper;
	    };
	    //ramlVersion():string{
	    //    return this._ramlVersion;
	    //}
	    /**
	     * Returns true if this unit is overlay or extension, false otherwise.
	     */
	    CompilationUnit.prototype.isOverlayOrExtension = function () {
	        var contents = this.contents();
	        var spec = "";
	        var ptype = null;
	        var num = 0;
	        var pt = 0;
	        for (var n = 0; n < contents.length; n++) {
	            var c = contents.charAt(n);
	            if (c == '\r' || c == '\n') {
	                if (spec) {
	                    ptype = contents.substring(pt, n).trim();
	                }
	                else {
	                    spec = contents.substring(0, n).trim();
	                }
	                break;
	            }
	            if (c == ' ') {
	                num++;
	                if (!spec && num == 2) {
	                    spec = contents.substring(0, n);
	                    pt = n;
	                }
	            }
	        }
	        return ptype == "Extension" || ptype == "Overlay";
	    };
	    /**
	     * Returns master reference if presents, null otherwise.
	     */
	    CompilationUnit.prototype.getMasterReferenceNode = function () {
	        return _.find(this.ast().children(), function (x) { return x.key() == universes.Universe10.Overlay.properties.extends.name; });
	    };
	    return CompilationUnit;
	}());
	exports.CompilationUnit = CompilationUnit;
	var XhrSync = __webpack_require__(55).XMLHttpRequest;
	var XhrAsync = __webpack_require__(55).XMLHttpRequest;
	var XMLHttpRequestWrapper = (function () {
	    function XMLHttpRequestWrapper() {
	    }
	    XMLHttpRequestWrapper.prototype.open = function (method, url, async) {
	        this.xhr = async ? new XhrAsync() : new XhrSync();
	        this.async = async;
	        this.xhr.open(method, url, async);
	    };
	    XMLHttpRequestWrapper.prototype.setRequestHeader = function (name, value) {
	        this.xhr.setRequestHeader(name, value);
	    };
	    XMLHttpRequestWrapper.prototype.getResponseHeader = function (name) {
	        return this.xhr.getResponseHeader(name);
	    };
	    XMLHttpRequestWrapper.prototype.getAllResponseHeaders = function () {
	        return this.xhr.getAllResponseHeaders();
	    };
	    XMLHttpRequestWrapper.prototype.send = function (content) {
	        var _this = this;
	        this.xhr.onload = function () { return _this.onResponse(false); };
	        this.xhr.onerror = function () { return _this.onResponse(true); };
	        this.xhr.send(content);
	    };
	    XMLHttpRequestWrapper.prototype.onResponse = function (isError) {
	        this.statusText = this.xhr.statusText;
	        this.responseText = this.xhr.responseText;
	        this.responseType = this.xhr.responseType;
	        this.status = this.xhr.status;
	        if (isError && this.onerror) {
	            this.onerror();
	            return;
	        }
	        if (this.onload) {
	            this.onload();
	        }
	    };
	    return XMLHttpRequestWrapper;
	}());
	exports.XMLHttpRequestWrapper = XMLHttpRequestWrapper;
	function buildXHR() {
	    return new XMLHttpRequestWrapper();
	}
	exports.buildXHR = buildXHR;
	var SimpleExecutor = (function () {
	    function SimpleExecutor() {
	    }
	    SimpleExecutor.prototype.execute = function (req, doAppendParams) {
	        if (doAppendParams === void 0) { doAppendParams = true; }
	        var xhr = buildXHR();
	        var url = req.url;
	        if (doAppendParams) {
	            url = this.appendParams(req, req.url);
	        }
	        xhr.open(req.method, url, false);
	        this.doRequest(req, xhr);
	        //rheaders=xhr.getAllResponseHeaders();
	        var status = xhr.status;
	        if (status > 300 && status < 400) {
	            var locHeader = xhr.getResponseHeader('location');
	            if (locHeader) {
	                req.url = locHeader;
	                return this.execute(req, false);
	            }
	        }
	        var response = {
	            status: status,
	            statusText: xhr.statusText,
	            headers: xhr.getAllResponseHeaders().split('\n').map(function (x) {
	                var ind = x.indexOf(':');
	                return {
	                    name: x.substring(0, ind).trim(),
	                    value: x.substring(ind + 1).trim()
	                };
	            }),
	            content: {
	                text: xhr.responseText,
	                mimeType: xhr.responseType
	            }
	        };
	        return response;
	    };
	    SimpleExecutor.prototype.appendParams = function (req, url) {
	        var gotQueryParams = (req.queryString && req.queryString.length > 0);
	        if (gotQueryParams) {
	            url = url + '?';
	            var arr = [];
	            if (gotQueryParams) {
	                arr = arr.concat(req.queryString.map(function (q) {
	                    return encodeURIComponent(q.name) + '=' + encodeURIComponent(q.value);
	                }));
	            }
	            url += arr.join('&');
	        }
	        return url;
	    };
	    SimpleExecutor.prototype.log = function (varName, value) {
	    };
	    SimpleExecutor.prototype.executeAsync = function (req, doAppendParams) {
	        if (doAppendParams === void 0) { doAppendParams = true; }
	        var xhr = buildXHR();
	        var url = req.url;
	        if (doAppendParams) {
	            url = this.appendParams(req, req.url);
	        }
	        var outer = this;
	        return new Promise(function (resolve, reject) {
	            xhr.open(req.method, url, true);
	            xhr.onload = function () {
	                var status = xhr.status;
	                var response = {
	                    status: status,
	                    statusText: xhr.statusText,
	                    headers: xhr.getAllResponseHeaders().split('\n').map(function (x) {
	                        var ind = x.indexOf(':');
	                        return {
	                            name: x.substring(0, ind).trim(),
	                            value: x.substring(ind + 1).trim()
	                        };
	                    }),
	                    content: {
	                        text: xhr.responseText,
	                        mimeType: xhr.responseType
	                    }
	                };
	                resolve(response);
	            };
	            xhr.onerror = function () {
	                reject(new Error("Network Error"));
	            };
	            outer.doRequest(req, xhr);
	        });
	    };
	    SimpleExecutor.prototype.doRequest = function (req, xhr) {
	        if (req.headers) {
	            req.headers.forEach(function (x) { return xhr.setRequestHeader(x.name, x.value); });
	        }
	        if (req.postData) {
	            if (req.postData.params) {
	                var body = req.postData.params.map(function (p) { return encodeURIComponent(p.name) + '=' + encodeURIComponent(p.value); }).join('&');
	                xhr.send(body);
	            }
	            else {
	                xhr.send(req.postData.text);
	            }
	        }
	        else {
	            xhr.send();
	        }
	    };
	    return SimpleExecutor;
	}());
	exports.SimpleExecutor = SimpleExecutor;
	var HTTPResolverImpl = (function () {
	    function HTTPResolverImpl() {
	        this.executor = new SimpleExecutor();
	    }
	    HTTPResolverImpl.prototype.getResource = function (url) {
	        if (typeof atom !== 'undefined' && atom != null) {
	            var cached = rr.get(url);
	            if (cached) {
	                return cached;
	            }
	            rr.addNotify(url);
	            try {
	                var resultWithCallback = {
	                    content: ""
	                };
	                this.getResourceAsync(url).then(function (x) {
	                    try {
	                        if (x.errorMessage) {
	                            rr.set(url, { content: null, errorMessage: null });
	                        }
	                        else {
	                            x.errorMessage = null;
	                            rr.set(url, x);
	                        }
	                    }
	                    finally {
	                        if (resultWithCallback.callback) {
	                            resultWithCallback.callback(rr.get(url));
	                        }
	                        rr.removeNotity(url);
	                    }
	                }, function (e) {
	                    rr.set(url, { content: null, errorMessage: null });
	                    if (resultWithCallback.callback) {
	                        resultWithCallback.callback(rr.get(url));
	                    }
	                    rr.removeNotity(url);
	                });
	                return resultWithCallback;
	            }
	            catch (e) {
	                console.log("Error");
	                console.log(e);
	            }
	        }
	        var response = this.executor.execute({
	            method: 'get',
	            url: url
	        });
	        if (!response) {
	            throw new Error("Unable to execute GET " + url);
	        }
	        var result = this.toResponse(response, url);
	        return result;
	    };
	    HTTPResolverImpl.prototype.getResourceAsync = function (url) {
	        var _this = this;
	        return this.executor.executeAsync({
	            method: 'get',
	            url: url
	        }).then(function (x) {
	            if (!x) {
	                return Promise.reject(new Error("Unable to execute GET " + url));
	            }
	            var result = _this.toResponse(x, url);
	            return result;
	        }, function (x) {
	            return Promise.reject(new Error("Unable to execute GET " + url));
	        });
	    };
	    HTTPResolverImpl.prototype.toResponse = function (response, url) {
	        var msg = null;
	        if (response.status >= 400) {
	            msg = "GET " + url + "\nreturned error: " + response.status;
	            if (response.statusText) {
	                msg += " " + response.statusText;
	            }
	        }
	        var content = null;
	        if (response.content && response.content.text) {
	            content = response.content.text;
	        }
	        var result = {
	            content: content,
	            errorMessage: msg
	        };
	        return result;
	    };
	    return HTTPResolverImpl;
	}());
	exports.HTTPResolverImpl = HTTPResolverImpl;
	var FSResolverImpl = (function () {
	    function FSResolverImpl() {
	    }
	    FSResolverImpl.prototype.content = function (path) {
	        if (typeof path != "string") {
	            path = "" + path;
	        }
	        if (!fs.existsSync(path)) {
	            return null;
	        }
	        try {
	            return fs.readFileSync(path).toString();
	        }
	        catch (e) {
	            return null;
	        }
	    };
	    FSResolverImpl.prototype.list = function (path) {
	        return fs.readdirSync(path);
	    };
	    FSResolverImpl.prototype.contentAsync = function (path) {
	        return new Promise(function (resolve, reject) {
	            fs.readFile(path, function (err, data) {
	                if (err != null) {
	                    return reject(err);
	                }
	                var content = data.toString();
	                resolve(content);
	            });
	        });
	    };
	    FSResolverImpl.prototype.listAsync = function (path) {
	        return new Promise(function (reject, resolve) {
	            fs.readdir(path, function (err, files) {
	                if (err != null) {
	                    return reject(err);
	                }
	                resolve(files);
	            });
	        });
	    };
	    return FSResolverImpl;
	}());
	exports.FSResolverImpl = FSResolverImpl;
	function copyNode(n) {
	    if (n == null) {
	        return null;
	    }
	    switch (n.kind) {
	        case yaml.Kind.SCALAR:
	            return {
	                errors: [],
	                startPosition: n.startPosition,
	                endPosition: n.endPosition,
	                value: n.value,
	                kind: yaml.Kind.SCALAR,
	                parent: n.parent
	            };
	        case yaml.Kind.MAPPING:
	            var map = n;
	            return {
	                errors: [],
	                key: copyNode(map.key),
	                value: copyNode(map.value),
	                startPosition: map.startPosition,
	                endPosition: map.endPosition,
	                kind: yaml.Kind.MAPPING,
	                parent: map.parent
	            };
	        case yaml.Kind.MAP:
	            var ymap = n;
	            return {
	                errors: [],
	                startPosition: n.startPosition,
	                endPosition: n.endPosition,
	                mappings: ymap.mappings.map(function (x) { return copyNode(x); }),
	                kind: yaml.Kind.MAP,
	                parent: ymap.parent
	            };
	    }
	    return n;
	}
	var innerShift = function (offset, yaNode, shift) {
	    if (!yaNode)
	        return;
	    if (yaNode.startPosition >= offset) {
	        yaNode.startPosition += shift;
	    }
	    if (yaNode.endPosition > offset) {
	        yaNode.endPosition += shift;
	    }
	    //this kind is a separate case
	    if (yaNode.kind == yaml.Kind.MAPPING) {
	        var m = yaNode;
	        innerShift(offset, m.key, shift);
	        innerShift(offset, m.value, shift);
	    }
	};
	function splitOnLines(text) {
	    var lines = text.match(/^.*((\r\n|\n|\r)|$)/gm);
	    return lines;
	}
	//TODO IMPROVE INDENTS
	function stripIndent(text, indent) {
	    var lines = splitOnLines(text);
	    var rs = [];
	    for (var i = 0; i < lines.length; i++) {
	        if (i == 0) {
	            rs.push(lines[0]);
	        }
	        else {
	            rs.push(lines[i].substring(indent.length));
	        }
	    }
	    return rs.join("");
	}
	var leadingIndent = function (node, text) {
	    var leading = "";
	    var pos = node.start() - 1;
	    //if(pos > 0 && text[pos] == ' ' && text[pos-1] == '-') {
	    //    // seq here
	    //    pos -= 2;
	    //}
	    while (pos > 0) {
	        var ch = text[pos];
	        //if (ch == '\r' || ch == '\n' || ch != ' ') break;
	        //console.log('char: [' + ch + ']');
	        if (ch != ' ' && ch != '-')
	            break;
	        leading = ' ' + leading;
	        pos--;
	    }
	    return leading;
	};
	function indent(line) {
	    var rs = "";
	    for (var i = 0; i < line.length; i++) {
	        var c = line[i];
	        if (c == '\r' || c == '\n') {
	            continue;
	        }
	        if (c == ' ' || c == '\t') {
	            rs += c;
	            continue;
	        }
	        break;
	    }
	    return rs;
	}
	function indentLines(s, indent) {
	    return s.split("\n").map(function (x) {
	        if (x.trim().length == 0) {
	            return x;
	        }
	        return indent + x;
	    }).join("\n");
	}
	function extraIndent(text, indent) {
	    var lines = splitOnLines(text);
	    var rs = [];
	    for (var i = 0; i < lines.length; i++) {
	        if (i == 0) {
	            rs.push(lines[0]);
	        }
	        else {
	            if (lines[i].trim().length > 0) {
	                rs.push(indent + lines[i]);
	            }
	            else {
	                rs.push("");
	            }
	        }
	    }
	    return rs.join("");
	}
	var Project = (function () {
	    /**
	     *
	     * @param rootPath - path to folder where your root api is located
	     * @param resolver
	     * @param _httpResolver
	     */
	    function Project(rootPath, resolver, _httpResolver) {
	        this.rootPath = rootPath;
	        this.resolver = resolver;
	        this._httpResolver = _httpResolver;
	        this.listeners = [];
	        this.tlisteners = [];
	        this.pathToUnit = {};
	        this.failedUnits = {};
	        if (this.resolver == null) {
	            this.resolver = new FSResolverImpl();
	        }
	        if (this._httpResolver == null) {
	            this._httpResolver = new HTTPResolverImpl();
	        }
	    }
	    Project.prototype.getRootPath = function () {
	        return this.rootPath;
	    };
	    Project.prototype.cloneWithResolver = function (newResolver, httpResolver) {
	        if (httpResolver === void 0) { httpResolver = null; }
	        var newProject = new Project(this.rootPath, newResolver, httpResolver ? httpResolver : this._httpResolver);
	        for (var unitPath in this.pathToUnit) {
	            newProject.pathToUnit[unitPath] = this.pathToUnit[unitPath].cloneToProject(newProject);
	        }
	        return newProject;
	    };
	    Project.prototype.setCachedUnitContent = function (pth, cnt, tl) {
	        if (tl === void 0) { tl = true; }
	        var relPath = pth;
	        var apath = toAbsolutePath(this.rootPath, pth);
	        var unit = new CompilationUnit(relPath, cnt, tl, this, apath);
	        this.pathToUnit[apath] = unit;
	        return unit;
	    };
	    Project.prototype.resolveAsync = function (unitPath, pathInUnit) {
	        var _this = this;
	        if (!pathInUnit) {
	            return Promise.reject(new Error("Unit path is null"));
	        }
	        var includeReference = refResolvers.getIncludeReference(pathInUnit);
	        var oldPath = pathInUnit;
	        if (includeReference) {
	            pathInUnit = includeReference.getIncludePath();
	        }
	        var absPath = this.buildPath(pathInUnit, unitPath);
	        if (includeReference) {
	            var result;
	            var refPath = path.dirname(toAbsolutePath(this.rootPath, unitPath)) + '/' + includeReference.encodedName();
	            // if (this.pathToUnit[refPath]) {
	            //     result = this.pathToUnit[refPath];
	            // } else {
	            //     this.pathToUnit[refPath] = new CompilationUnit(includeReference.encodedName(), refResolvers.resolveContents(oldPath), false, this, refPath);
	            //
	            //     result = this.pathToUnit[refPath];
	            // }
	            this.pathToUnit[absPath] ? Promise.resolve(result).then(function (unit) {
	                _this.pathToUnit[refPath] = new CompilationUnit(includeReference.encodedName(), refResolvers.resolveContents(oldPath, _this.pathToUnit[absPath].contents()), false, _this, refPath);
	                return _this.pathToUnit[refPath];
	            }) : this.unitAsync(absPath, true).then(function (unit) {
	                _this.pathToUnit[absPath] = unit;
	                _this.pathToUnit[refPath] = new CompilationUnit(includeReference.encodedName(), refResolvers.resolveContents(oldPath, _this.pathToUnit[absPath].contents()), false, _this, refPath);
	                return _this.pathToUnit[refPath];
	            });
	        }
	        return this.unitAsync(absPath, true);
	    };
	    Project.prototype.resolve = function (unitPath, pathInUnit) {
	        if (!pathInUnit) {
	            return null;
	        }
	        var includeReference = refResolvers.getIncludeReference(pathInUnit);
	        var oldPath = pathInUnit;
	        if (includeReference) {
	            pathInUnit = includeReference.getIncludePath();
	        }
	        var absPath = this.buildPath(pathInUnit, unitPath);
	        if (includeReference) {
	            if (!this.pathToUnit[absPath]) {
	                this.pathToUnit[absPath] = this.unit(absPath, true);
	            }
	            var wrappedUnit = this.pathToUnit[absPath];
	            var refPath = path.dirname(toAbsolutePath(this.rootPath, unitPath)) + '/' + includeReference.encodedName();
	            if (this.pathToUnit[refPath]) {
	                return this.pathToUnit[refPath];
	            }
	            this.pathToUnit[refPath] = new CompilationUnit(includeReference.encodedName(), refResolvers.resolveContents(oldPath, wrappedUnit && wrappedUnit.contents()), false, this, refPath);
	            return this.pathToUnit[refPath];
	        }
	        return this.unit(absPath, true);
	    };
	    Project.prototype.buildPath = function (pathInUnit, unitPath) {
	        if (path.isAbsolute(pathInUnit)) {
	            var e = path.extname(unitPath);
	            if (e != ".json" && e != ".xsd") {
	                //SUPPORTING 0.8 style resolving due to compatiblity reasons
	                pathInUnit = pathInUnit.substr(1);
	                unitPath = this.rootPath + "/" + path.basename(unitPath);
	            }
	        }
	        if (isWebPath(pathInUnit) || path.isAbsolute(pathInUnit)) {
	            return pathInUnit;
	        }
	        if (isWebPath(unitPath) || path.isAbsolute(unitPath)) {
	            return toAbsolutePath(path.dirname(unitPath), pathInUnit);
	        }
	        return toAbsolutePath(path.dirname(toAbsolutePath(this.rootPath, unitPath)), pathInUnit);
	    };
	    Project.prototype.units = function () {
	        var _this = this;
	        if (!this.resolver.list) {
	            throw new Error("Provided FSResolver is unable to list files. Please, use ExtendedFSResolver.");
	        }
	        var names = this.resolver.list(this.rootPath).filter(function (x) { return path.extname(x) == '.raml'; });
	        return names.map(function (x) { return _this.unit(x); }).filter(function (y) { return y.isTopLevel(); });
	    };
	    Project.prototype.unitsAsync = function () {
	        var _this = this;
	        if (!this.resolver.listAsync) {
	            return Promise.reject(new Error("Provided FSResolver is unable to list files. Please, use ExtendedFSResolver."));
	        }
	        return this.resolver.listAsync(this.rootPath).then(function (x) {
	            var promises = x.filter(function (x) { return path.extname(x) == '.raml'; }).map(function (x) { return _this.unitAsync(x).then(function (x) {
	                return x.isTopLevel() ? x : null;
	            }, function (x) {
	                return null;
	            }); });
	            return Promise.all(promises).then(function (arr) {
	                return arr.filter(function (x) { return x != null; });
	            });
	        });
	    };
	    Project.prototype.lexerErrors = function () {
	        var results = [];
	        this.units().forEach(function (x) {
	            results = results.concat(x.lexerErrors());
	        });
	        return results;
	    };
	    Project.prototype.deleteUnit = function (p, absolute) {
	        if (absolute === void 0) { absolute = false; }
	        var apath = null;
	        if (isWebPath(p)) {
	            apath = p;
	        }
	        else {
	            apath = absolute ? p : toAbsolutePath(this.rootPath, p);
	        }
	        delete this.pathToUnit[apath];
	    };
	    Project.prototype.unit = function (p, absolute) {
	        if (absolute === void 0) { absolute = false; }
	        if (absolute || isWebPath(p)) {
	            if (this.failedUnits[p] != null) {
	                if (!this.failedUnits[p].inner) {
	                    throw (this.failedUnits[p]);
	                }
	            }
	        }
	        else {
	            var ap = toAbsolutePath(this.rootPath, p);
	            if (this.failedUnits[ap]) {
	                if (!this.failedUnits[p].inner) {
	                    throw (this.failedUnits[p]);
	                }
	            }
	        }
	        var cnt = null;
	        var apath = p;
	        var response;
	        if (isWebPath(p)) {
	            if (this.pathToUnit[apath]) {
	                return this.pathToUnit[apath];
	            }
	            if (this._httpResolver) {
	                response = this._httpResolver.getResource(p);
	                if (response && response.errorMessage) {
	                    throw new Error(response.errorMessage);
	                }
	                if (response) {
	                    cnt = response.content;
	                }
	                else {
	                    cnt = null;
	                }
	            }
	            else {
	                response = new HTTPResolverImpl().getResource(apath);
	                if (response) {
	                    cnt = response.content;
	                }
	                else {
	                    cnt = null;
	                }
	            }
	        }
	        else {
	            if (p.charAt(0) == '/' && !absolute) {
	                p = p.substr(1); //TODO REVIEW IT
	            }
	            var apath = toAbsolutePath(this.rootPath, p);
	            if (this.pathToUnit[apath]) {
	                return this.pathToUnit[apath];
	            }
	            if (isWebPath(apath)) {
	                if (this._httpResolver) {
	                    var resp = this._httpResolver.getResource(apath);
	                    if (resp && resp.errorMessage) {
	                        throw new Error(resp.errorMessage);
	                    }
	                    if (resp) {
	                        cnt = resp.content;
	                    }
	                    else {
	                        cnt = null;
	                    }
	                }
	                else {
	                    var resourceResponse = new HTTPResolverImpl().getResource(apath);
	                    if (resourceResponse) {
	                        cnt = resourceResponse.content;
	                    }
	                    else {
	                        cnt = null;
	                    }
	                }
	            }
	            else {
	                cnt = this.resolver.content(apath);
	            }
	        }
	        if (cnt == null) {
	            return null;
	        }
	        var tl = util.stringStartsWith(cnt, "#%RAML");
	        var relPath = (isWebPath(this.rootPath) == isWebPath(apath)) ? path.relative(this.rootPath, apath) : apath;
	        var unit = new CompilationUnit(relPath, cnt, tl, this, apath);
	        this.pathToUnit[apath] = unit;
	        if (response) {
	            response.callback = function (contentHolder) {
	                unit.updateContent(contentHolder && contentHolder.content);
	            };
	        }
	        return unit;
	    };
	    Project.prototype.unitAsync = function (p, absolute) {
	        var _this = this;
	        if (absolute === void 0) { absolute = false; }
	        var cnt = null;
	        var apath = p;
	        if (isWebPath(p)) {
	            if (this.pathToUnit[apath]) {
	                return Promise.resolve(this.pathToUnit[apath]);
	            }
	            if (this._httpResolver) {
	                var resp = this._httpResolver.getResourceAsync(apath);
	                cnt = resp.then(function (x) {
	                    if (x.errorMessage) {
	                        return Promise.reject(new Error(x.errorMessage));
	                    }
	                    return x.content;
	                });
	            }
	            else {
	                cnt = new HTTPResolverImpl().getResourceAsync(apath);
	            }
	        }
	        else {
	            if (p.charAt(0) == '/' && !absolute) {
	                p = p.substr(1); //TODO REVIEW IT
	            }
	            if (absolute) {
	                apath = p;
	            }
	            else {
	                apath = toAbsolutePath(this.rootPath, p);
	            }
	            if (this.pathToUnit[apath]) {
	                return Promise.resolve(this.pathToUnit[apath]);
	            }
	            if (isWebPath(apath)) {
	                if (this._httpResolver) {
	                    var resp = this._httpResolver.getResourceAsync(apath);
	                    cnt = resp.then(function (x) {
	                        if (x.errorMessage) {
	                            return Promise.reject(new Error(x.errorMessage));
	                        }
	                        return x.content;
	                    });
	                }
	                else {
	                    cnt = new HTTPResolverImpl().getResourceAsync(apath);
	                }
	            }
	            else {
	                cnt = this.resolver.contentAsync(apath);
	            }
	        }
	        if (cnt == null) {
	            return Promise.resolve(null);
	        }
	        var relPath = (isWebPath(this.rootPath) == isWebPath(apath)) ? path.relative(this.rootPath, apath) : apath;
	        return cnt.then(function (x) {
	            if (!x) {
	                return Promise.reject(new Error("Can note resolve " + apath));
	            }
	            var tl = util.stringStartsWith(x, "#%RAML");
	            var unit = new CompilationUnit(relPath, x, tl, _this, apath);
	            _this.pathToUnit[apath] = unit;
	            return unit;
	        }).then(function (unit) {
	            if (unit.isRAMLUnit()) {
	                return unit;
	            }
	            return schemes.isScheme(unit.contents()) ? schemes.startDownloadingReferencesAsync(unit.contents(), unit) : unit;
	        });
	    };
	    Project.prototype.visualizeNewlines = function (s) {
	        var res = '';
	        for (var i = 0; i < s.length; i++) {
	            var ch = s[i];
	            if (ch == '\r')
	                ch = '\\r';
	            if (ch == '\n')
	                ch = '\\n';
	            res += ch;
	        }
	        return res;
	    };
	    Project.prototype.indent = function (node) {
	        //node.show('NODE');
	        var text = node.unit().contents();
	        //console.log('node text: ' + textutil.replaceNewlines(text.substring(node.start(), node.end())));
	        //console.log('node parent: ' + node.parent());
	        //console.log('node unit: ' + node.unit());
	        if (node == node.root()) {
	            //console.log('node is root');
	            return '';
	        }
	        var leading = leadingIndent(node, text);
	        //console.log('leading: [' + leading + '] ' + leading.length);
	        var dmp = splitOnLines(node.dump());
	        if (dmp.length > 1) {
	            if (dmp[1].trim().length > 0) {
	                //console.log('DMP0: [' + dmp[0] + ']');
	                //console.log('DMP1: [' + dmp[1] + ']');
	                var extra = indent(dmp[1]);
	                return leading + extra;
	            }
	        }
	        //console.log('LEADING: [' + this.visualizeNewlines(leading) + '] ');
	        return leading + '  ';
	    };
	    Project.prototype.startIndent = function (node) {
	        var text = node.unit().contents();
	        //console.log('Node text:\n' + this.visualizeNewlines(text.substring(node.start(), node.end())));
	        if (node == node.root())
	            return '';
	        var dmp = splitOnLines(node.dump());
	        if (dmp.length > 0) {
	            console.log('FIRST: ' + dmp[0]);
	            var extra = indent(dmp[0]);
	            return extra + '  ';
	        }
	        //console.log('LEADING: [' + this.visualizeNewlines(leading) + '] ');
	        return '';
	    };
	    Project.prototype.canWriteInOneLine = function (node) {
	        return false;
	    };
	    Project.prototype.isOneLine = function (node) {
	        return node.text().indexOf('\n') < 0;
	    };
	    Project.prototype.recalcPositionsUp = function (target) {
	        var np = target;
	        while (np) {
	            np.recalcEndPositionFromChilds();
	            np = np.parent();
	        }
	    };
	    Project.prototype.add2 = function (target, node, toSeq, ipoint, json) {
	        if (json === void 0) { json = false; }
	        var unit = target.unit();
	        var api = target.root();
	        //console.log('api: ' + api);
	        var point = null;
	        if (ipoint) {
	            if (ipoint instanceof ASTNode) {
	                //console.log('insertion: ast node');
	                point = ipoint;
	            }
	            if (ipoint instanceof InsertionPoint) {
	                //console.log('insertion: ip');
	                point = ipoint.point;
	            }
	        }
	        //console.log('target: ' + target.kindName() + '/' + target.valueKindName() + ' node: ' + node.kindName());
	        //if(point) point.show('POINT:');
	        if (target.isValueInclude()) {
	            //console.log('insert to include ref');
	            var childs = target.children();
	            if (childs.length == 0) {
	                throw new Error("not implemented: insert into empty include ref");
	            }
	            var parent = childs[0].parent();
	            //console.log('parent: ' + parent);
	            //parent.show('INCLUDE PARENT:');
	            this.add2(parent, node, toSeq, point, json);
	            return;
	        }
	        var range = new textutil.TextRange(unit.contents(), node.start(), node.end());
	        var targetRange = new textutil.TextRange(unit.contents(), target.start(), target.end());
	        var unitText = target.unit().contents();
	        if (target.valueKind() == yaml.Kind.SEQ) {
	            target = createSeq(target.valueAsSeq(), target, target.unit());
	        }
	        var json = this.isJson(target);
	        //console.log('target: ' + target.start() + '..' + target.end());
	        var originalIndent = json ? '' : this.indent(target.isSeq() ? target.parent() : target);
	        //console.log('indent: [' + originalIndent + '] ' + originalIndent.length + '; toseq: ' + toSeq + '; json: ' + json);
	        var xindent = originalIndent;
	        var indentLength = originalIndent.length;
	        var isTargetSeq = target.isSeq() || target.isMapping() && (target.isValueSeq() || target.isValueScalar() || !target.asMapping().value); //target.valueKind() == yaml.Kind.SEQ || target.isSeq();
	        //toSeq = false;
	        //console.log('target: ' + target.kindName() + '/' + yaml.Kind[target.valueKind()] + '; toseq: ' + toSeq);
	        //target.root().show("API:");
	        //target.show("TARGET:");
	        //console.log('oindent: ' + originalIndent.length);
	        toSeq = toSeq; // || isTargetSeq;
	        if (toSeq) {
	            if (json) {
	            }
	            else {
	                if (isTargetSeq) {
	                    xindent += "  ";
	                    indentLength += 2;
	                }
	            }
	        }
	        //console.log('xindent: ' + xindent.length);
	        var buf = new MarkupIndentingBuffer(xindent);
	        //target.show('TARGET:');
	        //node.show('NODE1');
	        node.markupNode(buf, node._actualNode(), 0, json);
	        var text = buf.text;
	        //node.show('NODE2', 0, text);
	        //console.log('TEXT TO ADD0: ' + textutil.replaceNewlines(text));
	        if (toSeq) {
	            //if(target.valueKind() == yaml.Kind.SEQ) {
	            var trimText = textutil.trimEnd(text);
	            var trimLen = text.length - trimText.length;
	            if (trimLen > 0) {
	                //console.log('trim len: ' + trimLen);
	                var textlen = text.length;
	                text = text.substring(0, textlen - trimLen);
	                node.shiftNodes(textlen - trimLen, -trimLen);
	            }
	        }
	        //target.show('TARGET2');
	        //node.show('NODE2', 0, text);
	        //console.log('TEXT TO ADD1: ' + textutil.replaceNewlines(text));
	        //console.log('TEXT TO ADD:\n' + this.visualizeNewlines(text));
	        //console.log('toseq: ' + toSeq);
	        if (toSeq && !json) {
	            if (node.highLevelNode()) {
	            }
	            //console.log('target: ' + target.kindName());
	            if (target.isMapping()) {
	            }
	            if (target.isSeq() || target.isMapping() && (target.isValueSeq() || target.isValueScalar() || !target.asMapping().value)) {
	                //console.log('--- make it seq');
	                text = originalIndent + '- ' + text;
	            }
	            else {
	                //console.log('--- keep it map');
	                text = originalIndent + text;
	            }
	        }
	        else {
	            text = originalIndent + text;
	        }
	        //console.log('TEXT TO ADD2: ' + textutil.replaceNewlines(text));
	        //target.show('TARGET3');
	        var pos = target.end();
	        //console.log('insert to target end: ' + pos+ ' ; point: ' + point);
	        if (point) {
	            //point.show("POINT");
	            if (point != target) {
	                pos = point.end();
	            }
	            else {
	                if (json && toSeq) {
	                }
	                else {
	                    pos = target.keyEnd() + 1;
	                    pos = new textutil.TextRange(unitText, pos, pos).extendAnyUntilNewLines().endpos();
	                }
	            }
	        }
	        else {
	            if (json && toSeq) {
	                var seq = target.asSeq();
	                if (seq) {
	                    if (seq.items.length > 0) {
	                        pos = seq.items[seq.items.length - 1].endPosition;
	                    }
	                    else {
	                        pos = seq.endPosition - 1;
	                    }
	                }
	            }
	            else {
	                if (ipoint && (ipoint instanceof InsertionPoint)) {
	                    //ipoint.show('insertion point provided');
	                    var ip = ipoint;
	                    if (ip.type == InsertionPointType.START) {
	                        pos = target.keyEnd() + 1;
	                        pos = new textutil.TextRange(unitText, pos, pos).extendAnyUntilNewLines().endpos();
	                    }
	                }
	            }
	        }
	        //console.log('insert poition: ' + pos);
	        var insertionRange = new textutil.TextRange(unitText, 0, pos);
	        pos = insertionRange.extendToNewlines().reduceSpaces().endpos();
	        if (json && target.isSeq()) {
	            var seq = target.asSeq();
	            if (seq.items.length > 0) {
	                text = ', ' + text;
	                indentLength += 2;
	            }
	        }
	        else if (pos > 0 && unitText[pos - 1] != '\n') {
	            text = "\n" + text;
	            indentLength++;
	        }
	        var suffixLen = 0;
	        if (toSeq && !json) {
	            text += '\n';
	            suffixLen++;
	        }
	        //console.log('FINAL TEXT TO ADD: [' + textutil.replaceNewlines(text) + '] at position ' + pos);
	        var newtext = unitText.substring(0, pos) + text + unitText.substring(pos, unitText.length);
	        var cu = unit;
	        cu.updateContentSafe(newtext);
	        this.executeReplace(new textutil.TextRange(unitText, pos, pos), text, cu);
	        //console.log('shift root from position: ' + pos);
	        target.root().shiftNodes(pos, indentLength + (node.end() - node.start()) + suffixLen);
	        //console.log('node len: ' + (node.end()-node.start()));
	        //console.log('text len: ' + text.length);
	        //(<ASTNode>target.root()).shiftNodes(pos, text.length+indentLength);
	        //target.show('TARGET2:');
	        //node.show('NODE TO ADD:');
	        if (point) {
	            var childs = target.children();
	            var index = -1;
	            for (var i = 0; i < childs.length; i++) {
	                var x = childs[i];
	                if (x.start() == point.start() && x.end() == point.end()) {
	                    index = i;
	                    break;
	                }
	            }
	            //console.log('index: ' + index);
	            if (index >= 0) {
	                target.addChild(node, index + 1);
	            }
	            else {
	                target.addChild(node);
	            }
	        }
	        else {
	            target.addChild(node);
	        }
	        node.shiftNodes(0, pos + indentLength);
	        //target.show('TARGET UPDATED:');
	        this.recalcPositionsUp(target);
	        //target.show('TARGET UPDATED POSITIONS:');
	        //api.show('ROOT UPDATED POSITIONS:');
	        node.setUnit(target.unit());
	        node.visit(function (n) {
	            var node = n;
	            node.setUnit(target.unit());
	            return true;
	        });
	    };
	    Project.prototype.isJsonMap = function (node) {
	        if (!node.isMap())
	            return false;
	        var text = node.text().trim();
	        return text.length >= 2 && text[0] == '{' && text[text.length - 1] == '}';
	    };
	    Project.prototype.isJsonSeq = function (node) {
	        if (!node.isSeq())
	            return false;
	        var text = node.text().trim();
	        return text.length >= 2 && text[0] == '[' && text[text.length - 1] == ']';
	    };
	    Project.prototype.isJson = function (node) {
	        return this.isJsonMap(node) || this.isJsonSeq(node);
	    };
	    Project.prototype.remove = function (unit, target, node) {
	        var parent = node.parent();
	        node._oldText = node.dump();
	        //node.showParents('PARENTS:');
	        //console.log('REMOVE NODE: ' + node.kindName() + ' from ' + target.kindName());
	        //console.log('INITIAL SELECTION: [' + textutil.replaceNewlines(range.text()) + ']');
	        //console.log('  text: \n' + unitText.substring(startpos,endpos));
	        if (this.isOneLine(node) && node.isMapping() && node.parent().isMap()) {
	            var mapnode = node.parent();
	            if (mapnode.asMap().mappings.length == 1 && mapnode.parent() != null) {
	                //console.log('REMOVE MAP INSTEAD!');
	                this.remove(unit, mapnode.parent(), mapnode);
	                return;
	            }
	        }
	        if (this.isOneLine(node) && node.isScalar() && node.parent().isSeq()) {
	            var seqnode = node.parent();
	            var seqn = seqnode.asSeq();
	            //console.log('SEQ: ' + seqn.items.length);
	            if (seqn.items.length == 1) {
	                //console.log('REMOVE SEQ INSTEAD!');
	                this.remove(unit, seqnode.parent(), seqnode);
	                return;
	            }
	        }
	        if (target.isMapping() && node.isSeq()) {
	            //console.log('remove seq from mapping');
	            var map = target.parent();
	            //console.log('REMOVE MAPPING INSTEAD!');
	            this.remove(unit, map, target);
	            return;
	        }
	        //target.show('TARGET:');
	        //node.show('NODE:');
	        var range = new textutil.TextRange(unit.contents(), node.start(), node.end());
	        var targetRange = new textutil.TextRange(unit.contents(), target.start(), target.end());
	        var parentRange = new textutil.TextRange(unit.contents(), parent.start(), parent.end());
	        var originalStartPos = range.startpos();
	        //console.log('REMOVE TEXT: ' +  this.visualizeNewlines(range.text()));
	        if (target.isSeq()) {
	            // extend range to start of line
	            //console.log('RANGE SEQ 0: ' + textutil.replaceNewlines(range.text()));
	            var seq = (node.isSeq() ? node : node.parentOfKind(yaml.Kind.SEQ));
	            //console.log('seq: ' + seq.text() + ' json: ' + this.isJson(seq));
	            if (seq && this.isJson(seq)) {
	                range = range.extendSpaces().extendCharIfAny(',').extendSpaces();
	            }
	            else {
	                range = range.extendToStartOfLine().extendAnyUntilNewLines().extendToNewlines(); //
	            }
	        }
	        if (target.isMap()) {
	            // extend range to end of line
	            //console.log('RANGE MAP 0: [' +  this.visualizeNewlines(range.text()) + ']');
	            range = range.trimEnd().extendAnyUntilNewLines().extendToNewlines();
	            //console.log('RANGE MAP 1: [' +  this.visualizeNewlines(range.text()) + ']');
	            range = range.extendToStartOfLine().extendUntilNewlinesBack();
	        }
	        if (target.kind() == yaml.Kind.MAPPING) {
	            //console.log('RANGE MAPPING 0: ' +  this.visualizeNewlines(range.text()));
	            //console.log('NODE TEXT: ' + node.text());
	            if (this.isJson(node) && this.isOneLine(node)) {
	            }
	            else {
	                // extend range to end of line
	                //console.log('RANGE MAP 0: ' +  this.visualizeNewlines(range.text()));
	                range = range.extendSpacesUntilNewLines();
	                range = range.extendToNewlines();
	                //console.log('RANGE MAP 2: ' +  this.visualizeNewlines(range.text()));
	                range = range.extendToStartOfLine().extendUntilNewlinesBack();
	            }
	        }
	        if (node.isSeq()) {
	            //console.log('cleanup seq');
	            range = range.reduceSpaces();
	        }
	        //console.log('NODE:\n-----------\n' + range.unitText() + '\n-------------');
	        //console.log('TARGET: ' + target.kindName());
	        //target.show('TARGET');
	        //console.log('FINAL REMOVE TEXT: [' +  this.visualizeNewlines(range.text()) + ']');
	        //console.log('NEW TEXT:\n-----------\n' + range.remove() + '\n-------------');
	        var cu = unit;
	        cu.updateContentSafe(range.remove());
	        this.executeReplace(range, "", cu);
	        //node.parent().show('Before remove');
	        node.parent().removeChild(node);
	        var shift = -range.len();
	        //console.log('shift: ' + shift);
	        target.root().shiftNodes(originalStartPos, shift);
	        this.recalcPositionsUp(target);
	        //this.executeTextChange(new lowlevel.TextChangeCommand(range.startpos(), range.len(), "", unit))
	        //target.show('TARGET AFTER REMOVE:');
	        //target.root().show('API AFTER REMOVE:');
	    };
	    Project.prototype.changeKey = function (unit, attr, newval) {
	        //console.log('set key: ' + newval);
	        var range = new textutil.TextRange(attr.unit().contents(), attr.keyStart(), attr.keyEnd());
	        if (attr.kind() == yaml.Kind.MAPPING) {
	            var sc = attr._actualNode().key;
	            sc.value = newval;
	            sc.endPosition = sc.startPosition + newval.length;
	        }
	        var cu = unit;
	        this.executeReplace(range, newval, cu);
	        //console.log('new text: ' + this.visualizeNewlines(newtext));
	        var shift = newval.length - range.len();
	        //console.log('shift: ' + shift);
	        attr.root().shiftNodes(range.startpos(), shift, attr);
	        this.recalcPositionsUp(attr);
	    };
	    Project.prototype.executeReplace = function (r, txt, unit) {
	        var command = new lowlevel.TextChangeCommand(r.startpos(), r.endpos() - r.startpos(), txt, unit);
	        unit.project();
	        try {
	            this.tlisteners.forEach(function (x) { return x(command); });
	        }
	        catch (e) {
	            return false;
	        }
	        var newtext = r.replace(txt);
	        unit.updateContentSafe(newtext);
	        return true;
	    };
	    Project.prototype.changeValue = function (unit, attr, newval) {
	        //console.log('set value: ' + newval);mark
	        //console.log('ATTR ' + yaml.Kind[attr.kind()] + '; VALUE: ' + val + ' => ' + newval);
	        //attr.root().show('NODE:');
	        //console.log('TEXT:\n' + attr.unit().contents());
	        var range = new textutil.TextRange(attr.unit().contents(), attr.start(), attr.end());
	        //console.log('Range0: ' + range.startpos() + '..' + range.endpos() + ': [' + this.visualizeNewlines(range.text()) + ']');
	        //console.log('ATTR: ' + attr.kindName());
	        //attr.root().show('BEFORE');
	        var newNodeText;
	        var prefix = 0;
	        var delta = 0;
	        var replacer = null;
	        var mapping = null;
	        //console.log('attr: ' + attr.kindName());
	        if (attr.kind() == yaml.Kind.SCALAR) {
	            if (typeof newval == 'string') {
	                attr.asScalar().value = newval;
	                //range = range.withStart(attr.valueStart()).withEnd(attr.valueEnd());
	                //console.log('Range1: ' + this.visualizeNewlines(range.text()));
	                //console.log('Range0: ' + range.startpos() + '..' + range.endpos());
	                newNodeText = newval;
	            }
	            else {
	                throw new Error("not implemented");
	            }
	        }
	        else if (attr.kind() == yaml.Kind.MAPPING) {
	            //attr.show('ATTR:');
	            mapping = attr.asMapping();
	            //console.log('mapping val: ' + attr.valueKindName());
	            if (attr.isValueInclude()) {
	                var inc = attr.valueAsInclude();
	                var includeString = inc.value;
	                var includePath = includeString;
	                //console.log("attr.setValue: path: " + includePath);
	                var resolved = attr.unit().resolve(includePath);
	                if (resolved == null) {
	                    console.log("attr.setValue: couldn't resolve: " + includePath);
	                    return; // "can not resolve "+includePath
	                }
	                //console.log("attr.setValue: resolved: " + includePath);
	                if (resolved.isRAMLUnit()) {
	                    //TODO DIFFERENT DATA TYPES, inner references
	                    return;
	                }
	                //TODO for now disabling an update from outline details to JSON schema when there is a reference
	                //to an inner element of the schema
	                if (!refResolvers.getIncludeReference(includeString)) {
	                    resolved.updateContent(newval);
	                }
	                return;
	            }
	            //console.log('Range0: ' + range.startpos() + '..' + range.endpos() + ': [' + this.visualizeNewlines(range.text()) + ']');
	            if (mapping.value)
	                range = range.withStart(attr.valueStart()).withEnd(attr.valueEnd());
	            else
	                range = range.withStart(attr.keyEnd() + 1).withEnd(attr.keyEnd() + 1);
	            //console.log('Range1: ' + range.startpos() + '..' + range.endpos());
	            range = range.reduceNewlinesEnd();
	            //console.log('Range2: ' + range.startpos() + '..' + range.endpos() + ': [' + this.visualizeNewlines(range.text()) + ']');
	            if (newval == null) {
	                newNodeText = '';
	                mapping.value = null;
	            }
	            else if (typeof newval == 'string' || newval == null) {
	                var newstr = newval;
	                var ind = this.indent(attr);
	                //console.log('indent: ' + ind.length);
	                if (newstr && textutil.isMultiLine(newstr)) {
	                    newstr = '' + textutil.makeMutiLine(newstr, ind.length / 2);
	                }
	                newNodeText = newstr;
	                //var valueNode = null;
	                if (!mapping.value) {
	                    console.log('no value');
	                    mapping.value = yaml.newScalar(newstr);
	                    mapping.value.startPosition = attr.keyEnd() + 1;
	                    mapping.value.endPosition = mapping.value.startPosition + newstr.length;
	                    mapping.endPosition = mapping.value.endPosition;
	                    if (unit.contents().length > attr.keyEnd() + 1) {
	                        var vlPos = attr.keyEnd() + 1;
	                        if (unit.contents()[vlPos - 1] == ':') {
	                            newNodeText = " " + newNodeText;
	                            mapping.value.startPosition++;
	                            mapping.value.endPosition++;
	                            mapping.endPosition++;
	                            delta++;
	                        }
	                    }
	                }
	                else if (mapping.value.kind == yaml.Kind.SEQ) {
	                    console.log('seq value');
	                    var v = mapping.value.items[0];
	                    //TODO !!! assign value
	                    throw "assign value!!!";
	                }
	                else if (mapping.value.kind == yaml.Kind.SCALAR) {
	                    //console.log('scalar value');
	                    var sc = mapping.value;
	                    var oldtext = sc.value;
	                    //console.log('oldval: ' + sc.value);
	                    //console.log('newstr: ' + newstr + ' ' + newstr.length);
	                    sc.value = newstr;
	                    //console.log('value1: ' + mapping.value.startPosition + '..' + mapping.value.endPosition);
	                    mapping.value.endPosition = mapping.value.startPosition + newstr.length;
	                    //console.log('value2: ' + mapping.value.startPosition + '..' + mapping.value.endPosition);
	                    mapping.endPosition = mapping.value.endPosition;
	                    //console.log('mvalue: ' + mapping.startPosition + '..' + mapping.endPosition);
	                    //console.log('newval: ' + sc.value);
	                    delta += newstr.length - oldtext.length;
	                }
	            }
	            else {
	                var n = newval;
	                if (n.isMapping()) {
	                    newval = createMap([n.asMapping()]);
	                    n = newval;
	                }
	                else if (n.isMap()) {
	                }
	                else {
	                    throw new Error("only MAP/MAPPING nodes allowed as values");
	                }
	                //n.show('NODE1');
	                var buf = new MarkupIndentingBuffer('');
	                n.markupNode(buf, n._actualNode(), 0, true);
	                //n.show('NODE2');
	                newNodeText = '' + buf.text + '';
	                //indent++;
	                //n.shiftNodes(0, 1);
	                //console.log('node text: [[[' + newNodeText + ']]]');
	                //n.show("NN1:", 0, newNodeText);
	                //range = mapping.value? range.withStart(attr.valueStart()).withEnd(attr.valueEnd()) : range.withStart(attr.keyEnd()+1).withEnd(attr.keyEnd()+1 + newNodeText);
	                n.shiftNodes(0, range.startpos() + delta);
	                //n.show("NN2:");
	                replacer = n;
	            }
	        }
	        else {
	            console.log('Unsupported change value case: ' + attr.kindName());
	        }
	        //console.log('RangeX: ' + range.startpos() + '..' + range.endpos() + ': [' + this.visualizeNewlines(range.text()) + ']');
	        //console.log('new node text: ' + newNodeText);
	        var cu = unit;
	        //console.log('Range1: ' + range.startpos() + '..' + range.endpos());
	        //console.log('replace: ' + range.len());
	        //console.log('Range: ' + range.startpos() + '..' + range.endpos());
	        //console.log('OldText: ' + this.visualizeNewlines(cu.contents()));
	        this.executeReplace(range, newNodeText, cu);
	        //var newtext = range.replace(newNodeText);
	        //console.log('NewText: ' + this.visualizeNewlines(newtext));
	        //cu.updateContentSafe(newtext);
	        var shift = newNodeText.length - range.len();
	        //var shift = delta;
	        //attr.root().show('BEFORE SHIFT');
	        //console.log('shift: ' + shift + '; from: ' + (range.endpos() + prefix) + '; delta: ' + delta + '; prefix: ' + prefix);
	        attr.root().shiftNodes(range.endpos() + prefix, shift, attr);
	        //(<ASTNode>attr.root()).shiftNodes(range.endpos()+indent, shift);
	        //attr.show('ATTR2:');
	        if (replacer) {
	            mapping.value = replacer._actualNode();
	        }
	        this.recalcPositionsUp(attr);
	    };
	    Project.prototype.initWithRoot = function (root, newroot) {
	        var shift = root.end();
	        newroot.markup(false);
	        newroot._actualNode().startPosition = shift;
	        newroot._actualNode().endPosition = shift;
	        newroot.setUnit(root.unit());
	    };
	    Project.prototype.execute = function (cmd) {
	        var _this = this;
	        //console.log('Commands: ' + cmd.commands.length);
	        cmd.commands.forEach(function (x) {
	            //console.log('EXECUTE: kind: ' + lowlevel.CommandKind[x.kind] + '; val: ' + x.value);
	            switch (x.kind) {
	                case lowlevel.CommandKind.CHANGE_VALUE:
	                    var attr = x.target;
	                    var curval = attr.value();
	                    if (!curval) {
	                        curval = "";
	                    }
	                    var newval = x.value;
	                    console.log('set value: ' + (typeof curval) + ' ==> ' + (typeof newval));
	                    if ((typeof (curval) == 'string' ||
	                        typeof (curval) == 'number' ||
	                        typeof (curval) == 'boolean') && typeof newval == 'string') {
	                        //console.log('set value: str => str');
	                        if (curval != newval) {
	                            _this.changeValue(attr.unit(), attr, newval);
	                        }
	                    }
	                    else if ((typeof (curval) == 'string' ||
	                        typeof (curval) == 'number' ||
	                        typeof (curval) == 'boolean')
	                        && typeof (newval) != 'string') {
	                        //console.log('set value: str => obj');
	                        // change structure
	                        //this.changeValue(attr.unit(), attr, null);
	                        _this.changeValue(attr.unit(), attr, newval);
	                    }
	                    else if (typeof curval != 'string' && typeof newval == 'string') {
	                        var newstr = x.value;
	                        if (curval.kind() == yaml.Kind.MAPPING) {
	                            if (textutil.isMultiLine(newstr)) {
	                                //console.log('multiline');
	                                attr.children().forEach(function (n) {
	                                    _this.remove(attr.unit(), attr, n);
	                                });
	                                _this.changeValue(attr.unit(), attr, newstr);
	                            }
	                            else {
	                                //console.log('singleline');
	                                _this.changeKey(attr.unit(), curval, newstr);
	                            }
	                        }
	                        else {
	                            throw new Error('unsupported case: attribute value conversion: ' + (typeof curval) + ' ==> ' + (typeof newval) + ' not supported');
	                        }
	                    }
	                    else if (typeof curval != 'string' && typeof newval != 'string') {
	                        var newvalnode = newval;
	                        //(<ASTNode>curval).show("OLD:");
	                        //newvalnode.show("NEW:");
	                        if (newvalnode.isMapping()) {
	                            newval = createMap([newvalnode.asMapping()]);
	                        }
	                        //console.log('obj obj: ' + (curval == newval));
	                        if (curval == newval)
	                            break;
	                        // change structure
	                        //console.log('set value: obj => obj');
	                        var node = newval;
	                        var map = node.asMap();
	                        //console.log('attr: ' + attr.kindName() + " " + attr.dump());
	                        attr.children().forEach(function (n) {
	                            _this.remove(attr.unit(), attr, n);
	                        });
	                        node.children().forEach(function (m) {
	                            //this.add2(attr, <ASTNode>m, false, null, true);
	                        });
	                        _this.changeValue(attr.unit(), attr, newval);
	                    }
	                    else {
	                        throw new Error("shouldn't be this case: attribute value conversion " + (typeof curval) + ' ==> ' + (typeof newval) + ' not supported');
	                    }
	                    return;
	                case lowlevel.CommandKind.CHANGE_KEY:
	                    var attr = x.target;
	                    _this.changeKey(attr.unit(), attr, x.value);
	                    return;
	                case lowlevel.CommandKind.ADD_CHILD:
	                    var attr = x.target;
	                    var newValueNode = x.value;
	                    _this.add2(attr, newValueNode, x.toSeq, x.insertionPoint);
	                    return;
	                case lowlevel.CommandKind.REMOVE_CHILD:
	                    var target = x.target;
	                    var node = x.value;
	                    _this.remove(target.unit(), target, node);
	                    return;
	                case lowlevel.CommandKind.INIT_RAML_FILE:
	                    var root = x.target;
	                    var newroot = x.value;
	                    _this.initWithRoot(root, newroot);
	                    return;
	                default:
	                    console.log('UNSUPPORTED COMMAND: ' + lowlevel.CommandKind[x.kind]);
	                    return;
	            }
	        });
	    };
	    Project.prototype.replaceYamlNode = function (target, newNodeContent, offset, shift, unit) {
	        //console.log('New content:\n' + newNodeContent);
	        //target.show('OLD TARGET');
	        var newYamlNode = yaml.load(newNodeContent, {});
	        //console.log('new yaml: ' + yaml.Kind[newYamlNode.kind]);
	        this.updatePositions(target.start(), newYamlNode);
	        //console.log('Shift: ' + shift);
	        //(<ASTNode>unit.ast()).shiftNodes(offset, shift);
	        target.root().shiftNodes(offset, shift);
	        var targetParent = target.parent();
	        var targetYamlNode = target._actualNode();
	        var parent = targetYamlNode.parent;
	        newYamlNode.parent = parent;
	        if (targetParent && targetParent.kind() == yaml.Kind.MAP) {
	            //console.log('MAP!!!');
	            var targetParentMapNode = targetParent._actualNode();
	            targetParentMapNode.mappings = targetParentMapNode.mappings.map(function (x) {
	                if (x != targetYamlNode) {
	                    return x;
	                }
	                return newYamlNode;
	            });
	        }
	        target.updateFrom(newYamlNode);
	        //target.show('MEW TARGET');
	        this.recalcPositionsUp(target);
	    };
	    Project.prototype.executeTextChange2 = function (textCommand) {
	        var cu = textCommand.unit;
	        var unitText = cu.contents();
	        var target = textCommand.target;
	        if (target) {
	            var cnt = unitText.substring(target.start(), target.end());
	            var original = unitText;
	            unitText = unitText.substr(0, textCommand.offset) + textCommand.text + unitText.substr(textCommand.offset + textCommand.replacementLength);
	            var newNodeContent = cnt.substr(0, textCommand.offset - target.start()) +
	                textCommand.text + cnt.substr(textCommand.offset - target.start() + textCommand.replacementLength);
	            cu.updateContentSafe(unitText);
	            if (textCommand.offset > target.start()) {
	                try {
	                    var shift = textCommand.text.length - textCommand.replacementLength;
	                    var offset = textCommand.offset;
	                    target.unit().project().replaceYamlNode(target, newNodeContent, offset, shift, textCommand.unit);
	                }
	                catch (e) {
	                    console.log('New node contents (causes error below): \n' + newNodeContent);
	                    console.log('Reparse error: ' + e.stack);
	                }
	            }
	        }
	        else {
	            unitText = unitText.substr(0, textCommand.offset) + textCommand.text + unitText.substr(textCommand.offset + textCommand.replacementLength);
	        }
	        cu.updateContent(unitText);
	        this.listeners.forEach(function (x) {
	            x(null);
	        });
	        this.tlisteners.forEach(function (x) {
	            x(textCommand);
	        });
	    };
	    Project.prototype.executeTextChange = function (textCommand) {
	        var l0 = new Date().getTime();
	        try {
	            var oc = textCommand.unit.contents();
	            //console.log('Offset: ' + textCommand.offset + '; end: ' + (textCommand.offset + textCommand.replacementLength) + '; len: ' + textCommand.replacementLength);
	            var target = textCommand.target;
	            if (target == null) {
	                target = this.findNode(textCommand.unit.ast(), textCommand.offset, textCommand.offset + textCommand.replacementLength);
	            }
	            var cu = textCommand.unit;
	            if (target) {
	                var cnt = oc.substring(target.start(), target.end());
	                //console.log('Content: ' + cnt);
	                var original = oc;
	                oc = oc.substr(0, textCommand.offset) + textCommand.text + oc.substr(textCommand.offset + textCommand.replacementLength);
	                var newNodeContent = cnt.substr(0, textCommand.offset - target.start()) +
	                    textCommand.text + cnt.substr(textCommand.offset - target.start() + textCommand.replacementLength);
	                cu.updateContentSafe(oc);
	                //console.log('UPDATED TEXT: ' + oc);
	                var hasNewLines = breaksTheLine(original, textCommand);
	                if (textCommand.offset > target.start()) {
	                    //we can just reparse new node content;
	                    //console.log(newNodeContent)
	                    try {
	                        var newYamlNode = yaml.load(newNodeContent, {});
	                        this.updatePositions(target.start(), newYamlNode);
	                        //console.log("Positions updated")
	                        //lets shift all after it
	                        var shift = textCommand.text.length - textCommand.replacementLength;
	                        //console.log('shift: ' + shift);
	                        //console.log('offset: ' + textCommand.offset);
	                        textCommand.unit.ast().shiftNodes(textCommand.offset, shift);
	                        //console.log('Unit AST: ' + textCommand.unit.ast())
	                        if (newYamlNode != null && newYamlNode.kind == yaml.Kind.MAP) {
	                            var actualResult = newYamlNode.mappings[0];
	                            var targetYamlNode = target._actualNode();
	                            var parent = targetYamlNode.parent;
	                            var cmd = new lowlevel.ASTDelta();
	                            var unit = textCommand.unit;
	                            cmd.commands = [
	                                new lowlevel.ASTChangeCommand(lowlevel.CommandKind.CHANGE_VALUE, new ASTNode(copyNode(targetYamlNode), unit, null, null, null), new ASTNode(actualResult, unit, null, null, null), 0)
	                            ];
	                            if (parent && parent.kind == yaml.Kind.MAP) {
	                                var map = parent;
	                                map.mappings = map.mappings.map(function (x) {
	                                    if (x != targetYamlNode) {
	                                        return x;
	                                    }
	                                    return actualResult;
	                                });
	                            }
	                            actualResult.parent = parent;
	                            //updating low level ast from yaml
	                            this.recalcPositionsUp(target);
	                            target.updateFrom(actualResult);
	                            //console.log("Incremental without listeners: "+(new Date().getTime()-l0));
	                            //console.log("Notify listeners1: " + this.listeners.length + ":" + this.tlisteners.length);
	                            this.listeners.forEach(function (x) {
	                                x(cmd);
	                            });
	                            this.tlisteners.forEach(function (x) {
	                                x(textCommand);
	                            });
	                            //console.log("Incremental update processed");
	                            return;
	                        }
	                    }
	                    catch (e) {
	                        console.log('New node contents (causes error below): \n' + newNodeContent);
	                        console.log('Reparse error: ' + e.stack);
	                    }
	                }
	            }
	            else {
	                oc = oc.substr(0, textCommand.offset) + textCommand.text + oc.substr(textCommand.offset + textCommand.replacementLength);
	            }
	            var t2 = new Date().getTime();
	            //console.log("Full without listeners:"+(t2-l0));
	            //!find node in scope
	            cu.updateContent(oc);
	            //console.log("Notify listeners2: " + this.listeners.length + ":" + this.tlisteners.length);
	            this.listeners.forEach(function (x) {
	                x(null);
	            });
	            this.tlisteners.forEach(function (x) {
	                x(textCommand);
	            });
	        }
	        finally {
	            var t2 = new Date().getTime();
	        }
	    };
	    Project.prototype.updatePositions = function (offset, n) {
	        var _this = this;
	        if (n == null) {
	            return;
	        }
	        if (n.startPosition == -1) {
	            n.startPosition = offset;
	        }
	        else {
	            n.startPosition = offset + n.startPosition;
	        }
	        n.endPosition = offset + n.endPosition;
	        //console.log('SET POS: ' + n.startPosition + ".." + n.endPosition);
	        switch (n.kind) {
	            case yaml.Kind.MAP:
	                var m = n;
	                m.mappings.forEach(function (x) { return _this.updatePositions(offset, x); });
	                break;
	            case yaml.Kind.MAPPING:
	                var ma = n;
	                this.updatePositions(offset, ma.key);
	                this.updatePositions(offset, ma.value);
	                break;
	            case yaml.Kind.SCALAR:
	                break;
	            case yaml.Kind.SEQ:
	                var s = n;
	                s.items.forEach(function (x) { return _this.updatePositions(offset, x); });
	                break;
	        }
	    };
	    Project.prototype.findNode = function (n, offset, end) {
	        var _this = this;
	        if (n == null) {
	            return null;
	        }
	        var node = n;
	        if (n.start() <= offset && n.end() >= end) {
	            var res = n;
	            node.directChildren().forEach(function (x) {
	                var m = _this.findNode(x, offset, end);
	                if (m) {
	                    res = m;
	                }
	            });
	            return res;
	        }
	        return null;
	    };
	    //shiftNodes(n:lowlevel.ILowLevelASTNode, offset:number, shift:number):lowlevel.ILowLevelASTNode{
	    //    var node:ASTNode=<ASTNode>n;
	    //    if (node==null){
	    //        return null;
	    //    }
	    //    node.directChildren().forEach(x=> {
	    //        var m = this.shiftNodes(x, offset, shift);
	    //    })
	    //    var yaNode=(<ASTNode>n)._actualNode();
	    //    if(yaNode) innerShift(offset, yaNode, shift);
	    //    return null;
	    //}
	    Project.prototype.addTextChangeListener = function (listener) {
	        this.tlisteners.push(listener);
	    };
	    Project.prototype.removeTextChangeListener = function (listener) {
	        this.tlisteners = this.tlisteners.filter(function (x) { return x != listener; });
	    };
	    Project.prototype.addListener = function (listener) {
	        this.listeners.push(listener);
	    };
	    Project.prototype.removeListener = function (listener) {
	        this.listeners = this.listeners.filter(function (x) { return x != listener; });
	    };
	    return Project;
	}());
	exports.Project = Project;
	function breaksTheLine(oc, textCommand) {
	    var oldText = oc.substr(textCommand.offset, textCommand.replacementLength);
	    if (oldText.indexOf('\n') != -1) {
	        return true;
	    }
	    if (textCommand.text.indexOf('\n') != -1) {
	        return true;
	    }
	}
	function tryParseScalar(q) {
	    if (q == "true") {
	        q = true;
	    }
	    else if (q == "false") {
	        q = false;
	    }
	    else {
	        var vl = parseFloat(q);
	        if (!isNaN(vl)) {
	            if (("" + q).match("^[-+]?[0-9]*\.?[0-9]+$")) {
	                q = vl;
	            }
	        }
	    }
	    return q;
	}
	var ASTNode = (function () {
	    function ASTNode(_node, _unit, _parent, _anchor, _include, cacheChildren, _includesContents) {
	        if (cacheChildren === void 0) { cacheChildren = false; }
	        if (_includesContents === void 0) { _includesContents = false; }
	        this._node = _node;
	        this._unit = _unit;
	        this._parent = _parent;
	        this._anchor = _anchor;
	        this._include = _include;
	        this.cacheChildren = cacheChildren;
	        this._includesContents = _includesContents;
	        this._errors = [];
	        if (_node == null) {
	            console.log("null");
	        }
	    }
	    ASTNode.prototype.actual = function () {
	        return this._node;
	    };
	    ASTNode.prototype.yamlNode = function () {
	        return this._node;
	    };
	    ASTNode.prototype.includesContents = function () {
	        return this._includesContents;
	    };
	    ASTNode.prototype.setIncludesContents = function (includesContents) {
	        this._includesContents = includesContents;
	    };
	    ASTNode.prototype.gatherIncludes = function (s, inc, anc, inOneMemberMap) {
	        var _this = this;
	        if (s === void 0) { s = []; }
	        if (inc === void 0) { inc = null; }
	        if (anc === void 0) { anc = null; }
	        if (inOneMemberMap === void 0) { inOneMemberMap = true; }
	        if (this._node == null) {
	            return; //TODO FIXME
	        }
	        var kind = this._node.kind;
	        if (kind == yaml.Kind.SCALAR) {
	            if (schemes.isScheme(this._node.value)) {
	                var references = schemes.getReferences(this._node.value, this.unit());
	                references.forEach(function (reference) {
	                    var includeNode = yaml.newScalar(reference);
	                    includeNode.kind = yaml.Kind.INCLUDE_REF;
	                    var includeAST = new ASTNode(includeNode, _this.unit(), null, null, null);
	                    s.push(includeAST);
	                });
	            }
	            return;
	        }
	        else if (kind == yaml.Kind.MAP) {
	            var map = this._node;
	            if (map.mappings.length == 1 && !inOneMemberMap) {
	                new ASTNode(map.mappings[0].value, this._unit, this, inc, anc, this.cacheChildren).gatherIncludes(s);
	            }
	            else {
	                map.mappings.
	                    map(function (x) { return new ASTNode(x, _this._unit, _this, anc ? anc : _this._anchor, inc ? inc : _this._include, _this.cacheChildren); }).
	                    forEach(function (x) { return x.gatherIncludes(s); });
	            }
	        }
	        else if (kind == yaml.Kind.MAPPING) {
	            var mapping = this._node;
	            if (mapping.value == null) {
	            }
	            else {
	                new ASTNode(mapping.value, this._unit, this, anc ? anc : this._anchor, inc ? inc : this._include, this.cacheChildren).gatherIncludes(s);
	            }
	        }
	        else if (kind == yaml.Kind.SEQ) {
	            var seq = this._node;
	            seq.items.filter(function (x) { return x != null; }).map(function (x) { return new ASTNode(x, _this._unit, _this, anc ? anc : _this._anchor, inc ? inc : _this._include, _this.cacheChildren); }).forEach(function (x) { return x.gatherIncludes(s); });
	        }
	        else if (kind == yaml.Kind.INCLUDE_REF) {
	            if (this._unit) {
	                s.push(this);
	            }
	        }
	    };
	    ASTNode.prototype.setHighLevelParseResult = function (highLevelParseResult) {
	        this._highLevelParseResult = highLevelParseResult;
	    };
	    ASTNode.prototype.highLevelParseResult = function () {
	        return this._highLevelParseResult;
	    };
	    ASTNode.prototype.setHighLevelNode = function (highLevel) {
	        this._highLevelNode = highLevel;
	    };
	    ASTNode.prototype.highLevelNode = function () {
	        return this._highLevelNode;
	    };
	    ASTNode.prototype.start = function () {
	        return this._node.startPosition;
	    };
	    ASTNode.prototype.errors = function () {
	        return this._errors;
	    };
	    ASTNode.prototype.parent = function () {
	        return this._parent;
	    };
	    ASTNode.prototype.recalcEndPositionFromChilds = function () {
	        var childs = this.children();
	        //if(this.children().length == 0) return;
	        var max = 0;
	        var first = this.children()[0];
	        var last = this.children()[this.children().length - 1];
	        //this.children().forEach(n=> {
	        //    var node: ASTNode = <ASTNode>n;
	        //    if(node._node.endPosition > max) max = node._node.endPosition;
	        //});
	        if (this.isMapping()) {
	            var mapping = this.asMapping();
	            //console.log('reposition: mapping');
	            if (mapping.value) {
	                if (mapping.value.kind == yaml.Kind.MAP) {
	                    var map = mapping.value;
	                    if (map.startPosition < 0 && first) {
	                        map.startPosition = first.start();
	                    }
	                    if (last)
	                        this._node.endPosition = last._node.endPosition;
	                    //console.log('embedded map: ' + map.startPosition + ".." + map.endPosition);
	                    this._node.endPosition = Math.max(this._node.endPosition, mapping.value.endPosition);
	                }
	                else if (mapping.value.kind == yaml.Kind.SEQ) {
	                    var seq = mapping.value;
	                    if (seq.startPosition < 0) {
	                        //console.log('*** missed start position');
	                        if (seq.items.length > 0) {
	                            var pos = seq.items[0].startPosition;
	                            var range = new textutil.TextRange(this.unit().contents(), pos, pos);
	                            range = range.extendSpacesBack().extendCharIfAnyBack('-');
	                            seq.startPosition = range.startpos();
	                        }
	                        else {
	                        }
	                    }
	                    //console.log('mapping1     : ' + mapping.startPosition + ".." + mapping.endPosition);
	                    //console.log('embedded seq1: ' + seq.startPosition + ".." + seq.endPosition);
	                    if (seq.items.length > 0) {
	                        var ilast = seq.items[seq.items.length - 1];
	                        this._node.endPosition = Math.max(this._node.endPosition, seq.endPosition, ilast.endPosition);
	                        seq.endPosition = Math.max(this._node.endPosition, seq.endPosition, ilast.endPosition);
	                    }
	                }
	                else if (mapping.value.kind == yaml.Kind.SCALAR) {
	                }
	                else {
	                    if (last)
	                        this._node.endPosition = last._node.endPosition;
	                }
	            }
	        }
	        else {
	            if (last)
	                this._node.endPosition = last._node.endPosition;
	        }
	        //this._node.endPosition = max;;
	    };
	    ASTNode.prototype.isValueLocal = function () {
	        if (this._node.kind == yaml.Kind.MAPPING) {
	            var knd = this._node.value.kind;
	            return knd != yaml.Kind.INCLUDE_REF && knd != yaml.Kind.ANCHOR_REF;
	        }
	        return true;
	    };
	    ASTNode.prototype.keyStart = function () {
	        if (this._node.kind == yaml.Kind.MAPPING) {
	            return this._node.key.startPosition;
	        }
	        return -1;
	    };
	    ASTNode.prototype.keyEnd = function () {
	        if (this._node.kind == yaml.Kind.MAPPING) {
	            return this._node.key.endPosition;
	        }
	        return -1;
	    };
	    ASTNode.prototype.valueStart = function () {
	        if (this._node.kind == yaml.Kind.MAPPING) {
	            var mapping = this.asMapping();
	            if (mapping.value)
	                return mapping.value.startPosition;
	            else
	                return mapping.endPosition;
	        }
	        return -1;
	    };
	    ASTNode.prototype.valueEnd = function () {
	        if (this._node.kind == yaml.Kind.MAPPING) {
	            var mapping = this.asMapping();
	            return mapping.value ? mapping.value.endPosition : mapping.endPosition;
	        }
	        return -1;
	    };
	    ASTNode.prototype.end = function () {
	        return this._node.endPosition;
	    };
	    ASTNode.prototype.dump = function () {
	        if (this._oldText) {
	            return this._oldText;
	        }
	        if (this._unit && this._node.startPosition > 0 && this._node.endPosition > 0) {
	            var originalText = this._unit.contents().substring(this._node.startPosition, this._node.endPosition);
	            originalText = stripIndent(originalText, leadingIndent(this, this._unit.contents()));
	            //console.log("L:");
	            //console.log(originalText);
	            return originalText;
	        }
	        return yaml.dump(this.dumpToObject(), {});
	    };
	    ASTNode.prototype.dumpToObject = function (full) {
	        if (full === void 0) { full = false; }
	        return this.dumpNode(this._node, full);
	    };
	    ASTNode.prototype.dumpNode = function (n, full) {
	        var _this = this;
	        if (full === void 0) { full = false; }
	        if (!n) {
	            return null;
	        }
	        if (n.kind == yaml.Kind.INCLUDE_REF) {
	            if (this._unit) {
	                var s = n;
	                var includePath = s.value;
	                var resolved = null;
	                try {
	                    resolved = this._unit.resolve(includePath);
	                }
	                catch (Error) {
	                }
	                if (resolved == null) {
	                    return null;
	                }
	                else if (resolved.isRAMLUnit() && this.canInclude(resolved)) {
	                    var ast = resolved.ast();
	                    if (ast) {
	                        return ast.dumpToObject(full);
	                    }
	                }
	            }
	            return null;
	        }
	        if (n.kind == yaml.Kind.SEQ) {
	            var seq = n;
	            var arr = [];
	            seq.items.forEach(function (x) { return arr.push(_this.dumpNode(x, full)); });
	            return arr;
	        }
	        if (n.kind == yaml.Kind.ANCHOR_REF) {
	            var aref = n;
	            return this.dumpNode(aref.value, full);
	        }
	        if (n.kind == yaml.Kind.MAPPING) {
	            var c = n;
	            var v = {};
	            var val = c.value;
	            var mm = this.dumpNode(val, full);
	            v["" + this.dumpNode(c.key, full)] = mm;
	            return v;
	        }
	        if (n.kind == yaml.Kind.SCALAR) {
	            var s = n;
	            var q = s.value;
	            if (s.plainScalar) {
	                q = tryParseScalar(q);
	            }
	            return q;
	        }
	        if (n.kind == yaml.Kind.MAP) {
	            var map = n;
	            var res = {};
	            if (map.mappings) {
	                map.mappings.forEach(function (x) {
	                    var ms = _this.dumpNode(x.value, full);
	                    if (ms == null) {
	                        ms = "!$$$novalue";
	                    }
	                    if ((ms + "").length > 0 || full) {
	                        res[_this.dumpNode(x.key, full) + ""] = ms;
	                    }
	                });
	            }
	            return res;
	        }
	    };
	    ASTNode.prototype.keyKind = function () {
	        if (this._node.key) {
	            return this._node.key.kind;
	        }
	        return null;
	    };
	    ASTNode.prototype._actualNode = function () {
	        return this._node;
	    };
	    ASTNode.prototype.execute = function (cmd) {
	        if (this.unit()) {
	            this.unit().project().execute(cmd);
	        }
	        else {
	            cmd.commands.forEach(function (x) {
	                switch (x.kind) {
	                    case lowlevel.CommandKind.CHANGE_VALUE:
	                        var attr = x.target;
	                        var newValue = x.value;
	                        var va = attr._actualNode();
	                        var as = attr.start();
	                        if (va.kind == yaml.Kind.MAPPING) {
	                            va.value = yaml.newScalar("" + newValue);
	                        }
	                        //this.executeTextChange(new lowlevel.TextChangeCommand(as,attr.value().length,<string>newValue,attr.unit()))
	                        return;
	                    case lowlevel.CommandKind.CHANGE_KEY:
	                        var attr = x.target;
	                        var newValue = x.value;
	                        var va = attr._actualNode();
	                        if (va.kind == yaml.Kind.MAPPING) {
	                            var sc = va.key;
	                            sc.value = newValue;
	                        }
	                        return;
	                }
	            });
	        }
	    };
	    ASTNode.prototype.updateFrom = function (n) {
	        this._node = n;
	    };
	    ASTNode.prototype.isAnnotatedScalar = function () {
	        if (this.kind() == yaml.Kind.MAPPING && this.unit()) {
	            if (this.valueKind() == yaml.Kind.MAP && this._node.value.mappings) {
	                var isScalar = this._node.value.mappings.length > 0;
	                this._node.value.mappings.forEach(function (x) {
	                    if (x.key.value === "value") {
	                        return;
	                    }
	                    if (x.key.value) {
	                        if (x.key.value.charAt(0) == '(' && x.key.value.charAt(x.key.value.length - 1) == ')') {
	                            return;
	                        }
	                    }
	                    isScalar = false;
	                });
	                return isScalar;
	            }
	        }
	        return false;
	    };
	    ASTNode.prototype.value = function (toString) {
	        if (!this._node) {
	            return "";
	        }
	        if (this._node.kind == yaml.Kind.SCALAR) {
	            //TODO WHAT IS IT IS INCLUDE ACTUALLY
	            if (!toString && ("" + this._node['valueObject'] === this._node['value'])) {
	                return this._node['valueObject'];
	            }
	            var q = this._node['value'];
	            if (!toString) {
	                if (this._node.plainScalar) {
	                    q = tryParseScalar(q);
	                }
	            }
	            return q;
	        }
	        if (this._node.kind == yaml.Kind.ANCHOR_REF) {
	            var ref = this._node;
	            return new ASTNode(ref.value, this._unit, this, null, null).value(toString);
	        }
	        if (this._node.kind == yaml.Kind.MAPPING) {
	            var map = this._node;
	            if (map.value == null) {
	                return null;
	            }
	            if (this.isAnnotatedScalar()) {
	                var child = new ASTNode(map.value, this._unit, this, null, null);
	                var ch = child.children();
	                for (var i = 0; i < ch.length; i++) {
	                    if (ch[i].key() === "value") {
	                        return ch[i].value();
	                    }
	                }
	            }
	            return new ASTNode(map.value, this._unit, this, null, null).value(toString);
	        }
	        if (this._node.kind == yaml.Kind.INCLUDE_REF) {
	            //here we should resolve include
	            var includeString = this._node['value'];
	            var includePath = includeString;
	            var resolved = null;
	            try {
	                resolved = this._unit.resolve(includePath);
	            }
	            catch (Error) {
	                //not sure why we're returning this as a value, but that's what we do with failed units due to unknown cause below,
	                //so doing the same @Denis
	                return "can not resolve " + includePath + " due to: " + Error.message;
	            }
	            if (resolved == null) {
	                return "can not resolve " + includePath;
	            }
	            if (resolved.isRAMLUnit()) {
	                return resolved.ast().value();
	            }
	            var text = resolved.contents();
	            if (textutil.isMultiLineValue(text)) {
	                text = textutil.fromMutiLine(text);
	            }
	            return text;
	        }
	        if (this._node.kind == yaml.Kind.MAP) {
	            var amap = this._node;
	            if (amap.mappings.length == 1) {
	                //handle map with one member case differently
	                return new ASTNode(amap.mappings[0], this._unit, this, null, null);
	            }
	        }
	        if (this._node.kind == yaml.Kind.SEQ) {
	            var aseq = this._node;
	            if (aseq.items.length == 1 && true) {
	                //handle seq with one member case differently
	                return new ASTNode(aseq.items[0], this._unit, this, null, null).value(toString);
	            }
	        }
	        //this are only kinds which has values
	        return null;
	    };
	    ASTNode.prototype.printDetails = function (indent) {
	        var result = "";
	        if (!indent)
	            indent = "";
	        var typeName = this.kindName();
	        if (this.kind() == yaml.Kind.SCALAR) {
	            result += indent + "[" + typeName + "]" + " " + this.value() + "\n";
	        }
	        else if (this.kind() == yaml.Kind.MAPPING &&
	            this._node.value &&
	            this._node.value.kind == yaml.Kind.SCALAR) {
	            result += indent + "[" + typeName + "]" + " " + this.key()
	                + " = " + this.value() + "\n";
	        }
	        else if (this.kind() == yaml.Kind.MAPPING) {
	            result += indent + "[" + typeName + "]" + " " + this.key()
	                + " = :\n";
	            this.children().forEach(function (child) {
	                result += child.printDetails(indent + "\t");
	            });
	        }
	        else {
	            result += indent + "[" + typeName + "]" + " :\n";
	            this.children().forEach(function (child) {
	                result += child.printDetails(indent + "\t");
	            });
	        }
	        return result;
	    };
	    ASTNode.prototype.visit = function (v) {
	        this.children().forEach(function (x) {
	            if (v(x)) {
	                x.visit(v);
	            }
	        });
	    };
	    ASTNode.prototype.rawKey = function () {
	        if (!this._node) {
	            return "";
	        }
	        if (this._node.kind == yaml.Kind.MAPPING) {
	            var map = this._node;
	            if (map.key.kind == yaml.Kind.SEQ) {
	                var items = map.key;
	                var mn = "[";
	                items.items.forEach(function (x) { return mn += x.value; });
	                return mn + "]";
	            }
	            return map.key.value;
	        }
	        if (this._node.kind == yaml.Kind.INCLUDE_REF) {
	            var m = this.children();
	            if (m.length == 1) {
	                return m[0].key();
	            }
	        }
	        //other kinds do not have keys
	        return null;
	    };
	    ASTNode.prototype.key = function () {
	        var key = this.rawKey();
	        if (key != null && util.stringEndsWith(key, '?')) {
	            key = key.substring(0, key.length - 1);
	        }
	        return key;
	    };
	    ASTNode.prototype.optional = function () {
	        var key = this.rawKey();
	        return key != null && util.stringEndsWith(key, '?');
	    };
	    ASTNode.prototype.addChild = function (n, pos) {
	        if (pos === void 0) { pos = -1; }
	        //this.show('ADD TARGET:');
	        var node = n;
	        //console.log('add-child: ' + this.kindName() + ' .add ' + node.kindName());
	        node._parent = this;
	        this._oldText = null;
	        if (this.isMap()) {
	            //console.log('pos: ' + pos);
	            var map = this.asMap();
	            if (map.mappings == null || map.mappings == undefined) {
	                map.mappings = [];
	            }
	            if (pos >= 0) {
	                map.mappings.splice(pos, 0, node.asMapping());
	            }
	            else {
	                map.mappings.push(node.asMapping());
	            }
	        }
	        else if (this.isMapping()) {
	            var mapping = this.asMapping();
	            var val = mapping.value;
	            //console.log('mapping value: ' + val);
	            if (!mapping.value && node.isMap()) {
	                mapping.value = node._actualNode();
	                return;
	            }
	            if (mapping.value && mapping.value.kind == yaml.Kind.SCALAR) {
	                // cleanup old value
	                mapping.value = null;
	                val = null;
	            }
	            if (!val) {
	                if (node.isScalar() || node.highLevelNode() && node.highLevelNode().property().getAdapter(services.RAMLPropertyParserService).isEmbedMap()) {
	                    val = yaml.newSeq();
	                }
	                else {
	                    val = yaml.newMap();
	                }
	                mapping.value = val;
	            }
	            if (val.kind == yaml.Kind.MAP) {
	                var map = val;
	                if (map.mappings == null || map.mappings == undefined) {
	                    map.mappings = [];
	                }
	                if (node.isScalar()) {
	                }
	                if (pos >= 0) {
	                    map.mappings.splice(pos, 0, node.asMapping());
	                }
	                else {
	                    map.mappings.push(node.asMapping());
	                }
	            }
	            else if (val.kind == yaml.Kind.SEQ) {
	                var seq = val;
	                if (pos >= 0) {
	                    seq.items.splice(pos, 0, node._actualNode());
	                }
	                else {
	                    seq.items.push(node._actualNode());
	                }
	            }
	            else {
	                throw new Error("Insert into mapping with " + yaml.Kind[mapping.value.kind] + " value not supported");
	            }
	        }
	        else if (this.isSeq()) {
	            var seq = this.asSeq();
	            if (pos >= 0) {
	                seq.items.splice(pos, 0, node._actualNode());
	            }
	            else {
	                seq.items.push(node._actualNode());
	            }
	        }
	        else {
	            throw new Error("Insert into " + this.kindName() + " not supported");
	        }
	    };
	    ASTNode.prototype.removeChild = function (n) {
	        this._oldText = null;
	        var node = n;
	        var ynode;
	        var index;
	        //console.log('*** REMOVE FROM: ' + this.kindName());
	        if (this.kind() == yaml.Kind.SEQ) {
	            //console.log('remove from seq');
	            var seq = this.asSeq();
	            //val = <yaml.YamlMap>((<yaml.YAMLMapping>this._node).value);
	            ynode = node._node;
	            index = seq.items.indexOf(ynode);
	            if (index > -1)
	                seq.items.splice(index, 1);
	        }
	        else if (this.kind() == yaml.Kind.MAP) {
	            //val = <yaml.YamlMap>((<yaml.YAMLMapping>this._node).value);
	            var map = this.asMap();
	            //console.log('remove from map: ' + map.mappings.length);
	            ynode = node.asMapping();
	            index = map.mappings.indexOf(ynode);
	            //console.log('  index: ' + index);
	            if (index > -1)
	                map.mappings.splice(index, 1);
	        }
	        else if (this.kind() == yaml.Kind.MAPPING) {
	            //console.log('*** REMOVE FROM MAPPING');
	            //val = <yaml.YamlMap>((<yaml.YAMLMapping>this._node).value);
	            //console.log('remove from mapping with map as value');
	            var mapping = this.asMapping();
	            //this.show("REMOVE TARGET: ***");
	            //node.show("REMOVE NODE: ***");
	            if (node._actualNode() == mapping.value) {
	                // remove right from mapping
	                //console.log('*** remove map from mapping!');
	                mapping.value = null;
	            }
	            else {
	                var map = (mapping.value);
	                ynode = node.asMapping();
	                if (map && map.mappings) {
	                    index = map.mappings.indexOf(ynode);
	                    if (index > -1)
	                        map.mappings.splice(index, 1);
	                }
	            }
	        }
	        else {
	            throw new Error("Delete from " + yaml.Kind[this.kind()] + " unsupported");
	        }
	    };
	    ASTNode.prototype.hasInnerIncludeError = function () {
	        return this.innerIncludeErrors;
	    };
	    ASTNode.prototype.includeErrors = function () {
	        if (this._node.kind == yaml.Kind.MAPPING) {
	            var mapping = this._node;
	            if (mapping.value == null) {
	                return [];
	            }
	            var node = new ASTNode(mapping.value, this._unit, this, this._anchor, this._include);
	            var res = node.includeErrors();
	            this.innerIncludeErrors = node.hasInnerIncludeError();
	            return res;
	        }
	        var rs = [];
	        if (this._node.kind == yaml.Kind.INCLUDE_REF) {
	            var mapping = this._node;
	            if (mapping.value == null) {
	                return [];
	            }
	            var includePath = this.includePath();
	            var resolved = null;
	            try {
	                resolved = this._unit.resolve(includePath);
	            }
	            catch (Error) {
	                this.innerIncludeErrors = Error.inner;
	                var s = "Can not resolve " + includePath + " due to: " + Error.message;
	                //known cause of failure
	                rs.push(s);
	                return rs;
	            }
	            if (resolved == null) {
	                //unknown cause of failure
	                rs.push("Can not resolve " + includePath);
	                return rs;
	            }
	            if (resolved.isRAMLUnit()) {
	                var ast = resolved.ast();
	                if (ast) {
	                    return [];
	                }
	                else {
	                    rs.push("" + includePath + " can not be parsed");
	                }
	            }
	            else {
	            }
	        }
	        return rs;
	    };
	    ASTNode.prototype.children = function (inc, anc, inOneMemberMap) {
	        var _this = this;
	        if (inc === void 0) { inc = null; }
	        if (anc === void 0) { anc = null; }
	        if (inOneMemberMap === void 0) { inOneMemberMap = true; }
	        if (this._node == null) {
	            return []; //TODO FIXME
	        }
	        if (this.cacheChildren && this._children) {
	            return this._children;
	        }
	        var result;
	        var kind = this._node.kind;
	        if (kind == yaml.Kind.SCALAR) {
	            result = [];
	        }
	        else if (kind == yaml.Kind.MAP) {
	            var map = this._node;
	            if (map.mappings.length == 1 && !inOneMemberMap) {
	                //handle map with one member case differently
	                // q:
	                //  []
	                //   - a
	                //   - b
	                // ->
	                // q:
	                //  a
	                //  b
	                result = new ASTNode(map.mappings[0].value, this._unit, this, inc, anc, this.cacheChildren).children(null, null, true);
	            }
	            else {
	                result = map.mappings.map(function (x) { return new ASTNode(x, _this._unit, _this, anc ? anc : _this._anchor, inc ? inc : _this._include, _this.cacheChildren); });
	            }
	        }
	        else if (kind == yaml.Kind.MAPPING) {
	            var mapping = this._node;
	            if (mapping.value == null) {
	                result = [];
	            }
	            else {
	                var proxy = new ASTNode(mapping.value, this._unit, this, anc ? anc : this._anchor, inc ? inc : this._include, this.cacheChildren);
	                result = proxy.children();
	                if (proxy.includesContents()) {
	                    this.setIncludesContents(true);
	                }
	            }
	        }
	        else if (kind == yaml.Kind.SEQ) {
	            var seq = this._node;
	            result = seq.items.filter(function (x) { return x != null; }).map(function (x) { return new ASTNode(x, _this._unit, _this, anc ? anc : _this._anchor, inc ? inc : _this._include, _this.cacheChildren); });
	        }
	        else if (kind == yaml.Kind.INCLUDE_REF) {
	            if (this._unit) {
	                var includePath = this.includePath();
	                var resolved = null;
	                try {
	                    resolved = this._unit.resolve(includePath);
	                }
	                catch (Error) {
	                }
	                if (resolved == null) {
	                    result = [];
	                }
	                else if (resolved.isRAMLUnit() && this.canInclude(resolved)) {
	                    var ast = resolved.ast();
	                    if (ast) {
	                        if (this.cacheChildren) {
	                            ast = toChildCahcingNode(ast);
	                        } //else {
	                        //    ast = <ASTNode>toIncludingNode(ast);
	                        //}
	                        result = resolved.ast().children(this, null);
	                        this.setIncludesContents(true);
	                    }
	                }
	            }
	            if (!result) {
	                result = [];
	            }
	        }
	        else if (kind == yaml.Kind.ANCHOR_REF) {
	            var ref = this._node;
	            result = new ASTNode(ref.value, this._unit, this, null, null, this.cacheChildren).children();
	        }
	        else {
	            throw new Error("Should never happen; kind : " + yaml.Kind[this._node.kind]);
	        }
	        if (this.cacheChildren) {
	            this._children = result;
	        }
	        return result;
	    };
	    ASTNode.prototype.canInclude = function (unit) {
	        var includedFrom = this.includedFrom();
	        while (includedFrom != null) {
	            if (includedFrom.unit().absolutePath() == unit.absolutePath()) {
	                return false;
	            }
	            includedFrom = includedFrom.includedFrom();
	        }
	        return true;
	    };
	    ASTNode.prototype.directChildren = function (inc, anc, inOneMemberMap) {
	        var _this = this;
	        if (inc === void 0) { inc = null; }
	        if (anc === void 0) { anc = null; }
	        if (inOneMemberMap === void 0) { inOneMemberMap = true; }
	        if (this._node) {
	            switch (this._node.kind) {
	                case yaml.Kind.SCALAR:
	                    return [];
	                case yaml.Kind.MAP:
	                    {
	                        var map = this._node;
	                        if (map.mappings.length == 1 && !inOneMemberMap) {
	                            //handle map with one member case differently
	                            return new ASTNode(map.mappings[0].value, this._unit, this, inc, anc).directChildren(null, null, true);
	                        }
	                        return map.mappings.map(function (x) { return new ASTNode(x, _this._unit, _this, anc ? anc : _this._anchor, inc ? inc : _this._include); });
	                    }
	                case yaml.Kind.MAPPING:
	                    {
	                        var mapping = this._node;
	                        if (mapping.value == null) {
	                            return [];
	                        }
	                        return new ASTNode(mapping.value, this._unit, this, anc ? anc : this._anchor, inc ? inc : this._include).directChildren();
	                    }
	                case yaml.Kind.SEQ:
	                    {
	                        var seq = this._node;
	                        return seq.items.filter(function (x) { return x != null; }).map(function (x) { return new ASTNode(x, _this._unit, _this, anc ? anc : _this._anchor, inc ? inc : _this._include); });
	                    }
	                case yaml.Kind.INCLUDE_REF:
	                    {
	                        return [];
	                    }
	                case yaml.Kind.ANCHOR_REF:
	                    {
	                        return [];
	                    }
	            }
	            throw new Error("Should never happen; kind : " + yaml.Kind[this._node.kind]);
	        }
	        return [];
	    };
	    ASTNode.prototype.anchorId = function () {
	        return this._node.anchorId;
	    };
	    ASTNode.prototype.unit = function () {
	        return this._unit;
	        //if(this._unit) return this._unit;
	        //if(!this.parent()) return null;
	        //return this.parent().unit();
	    };
	    ASTNode.prototype.includeBaseUnit = function () {
	        return this._unit;
	    };
	    ASTNode.prototype.setUnit = function (unit) {
	        this._unit = unit;
	    };
	    ASTNode.prototype.includePath = function () {
	        var includeString = this.getIncludeString();
	        if (!includeString) {
	            return null;
	        }
	        return includeString;
	    };
	    ASTNode.prototype.includeReference = function () {
	        var includeString = this.getIncludeString();
	        if (!includeString) {
	            return null;
	        }
	        return refResolvers.getIncludeReference(includeString);
	    };
	    ASTNode.prototype.getIncludeString = function () {
	        if (this._node.kind == yaml.Kind.INCLUDE_REF) {
	            var includePath = this._node['value'];
	            return includePath;
	        }
	        else if (this._node.kind == yaml.Kind.MAPPING) {
	            var mapping = this._node;
	            if (mapping.value == null)
	                return null;
	            return new ASTNode(mapping.value, this._unit, this, null, null).getIncludeString();
	        }
	        return null;
	    };
	    ASTNode.prototype.anchoredFrom = function () {
	        return this._anchor;
	    };
	    ASTNode.prototype.includedFrom = function () {
	        return this._include;
	    };
	    ASTNode.prototype.kind = function () {
	        return this._actualNode().kind;
	    };
	    ASTNode.prototype.valueKind = function () {
	        if (this._node.kind != yaml.Kind.MAPPING) {
	            return null;
	        }
	        var map = this._node;
	        if (!map.value) {
	            return null;
	        }
	        return map.value.kind;
	    };
	    ASTNode.prototype.valueKindName = function () {
	        var kind = this.valueKind();
	        return kind != undefined ? yaml.Kind[kind] : null;
	    };
	    ASTNode.prototype.kindName = function () {
	        return yaml.Kind[this.kind()];
	    };
	    ASTNode.prototype.indent = function (lev, str) {
	        if (str === void 0) { str = ''; }
	        var leading = '';
	        //leading += '[' + lev + ']';
	        for (var i = 0; i < lev; i++)
	            leading += '  ';
	        return leading + str;
	    };
	    ASTNode.prototype.replaceNewlines = function (s, rep) {
	        if (rep === void 0) { rep = null; }
	        var res = '';
	        for (var i = 0; i < s.length; i++) {
	            var ch = s[i];
	            if (ch == '\r')
	                ch = rep == null ? '\\r' : rep;
	            if (ch == '\n')
	                ch = rep == null ? '\\n' : rep;
	            res += ch;
	        }
	        return res;
	    };
	    ASTNode.prototype.shortText = function (unittext, maxlen) {
	        if (maxlen === void 0) { maxlen = 50; }
	        var elen = this.end() - this.start();
	        var len = elen;
	        //var len = Math.min(elen,50);
	        var unit = this.unit();
	        if (!unittext && unit) {
	            unittext = unit.contents();
	        }
	        var text;
	        if (!unittext) {
	            text = '[no-unit]';
	        }
	        else {
	            var s = unittext;
	            text = s ? s.substring(this.start(), this.end()) : '[no-text]';
	        }
	        text = "[" + this.start() + ".." + this.end() + "] " + elen + " // " + text + ' //';
	        if (len < elen)
	            text += '...';
	        text = this.replaceNewlines(text);
	        return text;
	    };
	    ASTNode.prototype.nodeShortText = function (node, unittext, maxlen) {
	        if (maxlen === void 0) { maxlen = 50; }
	        var elen = node.endPosition - node.startPosition;
	        var len = elen;
	        //var len = Math.min(elen,50);
	        var unit = this.unit();
	        if (!unittext && unit) {
	            unittext = unit.contents();
	        }
	        var text;
	        if (!unittext) {
	            text = '[no-unit]';
	        }
	        else {
	            var s = unittext;
	            text = s ? s.substring(node.startPosition, node.endPosition) : '[no-text]';
	        }
	        text = "[" + node.startPosition + ".." + node.endPosition + "] " + elen + " // " + text + ' //';
	        if (len < elen)
	            text += '...';
	        text = this.replaceNewlines(text);
	        return text;
	    };
	    ASTNode.prototype.show = function (message, lev, text) {
	        if (message === void 0) { message = null; }
	        if (lev === void 0) { lev = 0; }
	        if (text === void 0) { text = null; }
	        if (message && lev == 0) {
	            console.log(message);
	        }
	        var children = this.children();
	        var desc = this.kindName();
	        var val = this._actualNode().value;
	        if (this.kind() == yaml.Kind.MAPPING) {
	            desc += '[' + this._actualNode().key.value + ']';
	        }
	        if (val) {
	            desc += "/" + yaml.Kind[val.kind];
	        }
	        else
	            desc += "";
	        if (children.length == 0) {
	            //desc += "/" + this.value();
	            console.log(this.indent(lev) + desc + " // " + this.shortText(text));
	            if (this.isMapping() && this.asMapping().value) {
	                console.log(this.indent(lev + 1) + '// ' + this.valueKindName() + ': ' + this.nodeShortText(this.asMapping().value, text));
	            }
	        }
	        else {
	            console.log(this.indent(lev) + desc + " { // " + this.shortText(text));
	            if (this.isMapping() && this.asMapping().value) {
	                console.log(this.indent(lev + 1) + '// ' + this.valueKindName() + ': ' + this.nodeShortText(this.asMapping().value, text));
	            }
	            children.forEach(function (node) {
	                var n = node;
	                n.show(null, lev + 1, text);
	            });
	            console.log(this.indent(lev) + '}');
	        }
	    };
	    ASTNode.prototype.showParents = function (message, lev) {
	        if (lev === void 0) { lev = 0; }
	        if (message && lev == 0) {
	            console.log(message);
	        }
	        var depth = 0;
	        if (this.parent()) {
	            var n = this.parent();
	            depth = n.showParents(null, lev + 1);
	        }
	        var desc = this.kindName();
	        var val = this._actualNode().value;
	        if (val)
	            desc += "/" + yaml.Kind[val.kind];
	        else
	            desc += "/null";
	        console.log(this.indent(depth) + desc + " // " + this.shortText(null));
	        return depth + 1;
	    };
	    ASTNode.prototype.inlined = function (kind) {
	        return kind == yaml.Kind.SCALAR || kind == yaml.Kind.INCLUDE_REF;
	    };
	    ASTNode.prototype.markupNode = function (xbuf, node, lev, json) {
	        if (json === void 0) { json = false; }
	        var start = xbuf.text.length;
	        //console.log('node: ' + node);
	        switch (node.kind) {
	            case yaml.Kind.MAP:
	                if (json)
	                    xbuf.append('{');
	                var mappings = node.mappings;
	                //console.log('map: ' + mappings.length);
	                for (var i = 0; i < mappings.length; i++) {
	                    if (json && i > 0)
	                        xbuf.append(', ');
	                    this.markupNode(xbuf, mappings[i], lev, json);
	                }
	                if (json)
	                    xbuf.append('}');
	                break;
	            case yaml.Kind.SEQ:
	                var items = node.items;
	                //console.log('seq: ' + items.length);
	                for (var i = 0; i < items.length; i++) {
	                    xbuf.append(this.indent(lev, '- '));
	                    //this.markupNode(xindent, pos+xbuf.text.length-(lev+1)*2, items[i], lev+1, xbuf);
	                    this.markupNode(xbuf, items[i], lev + 1, json);
	                }
	                break;
	            case yaml.Kind.MAPPING:
	                var mapping = node;
	                var val = mapping.value;
	                //console.log('mapping: ' + mapping.key.value + ' ' + val.kind);
	                if (json) {
	                    if (!val) {
	                        xbuf.append('\n');
	                        break;
	                    }
	                    xbuf.append(mapping.key.value);
	                    xbuf.append(': ');
	                    if (val.kind == yaml.Kind.SCALAR) {
	                        var sc = val;
	                        xbuf.append(sc.value);
	                    }
	                    else if (val.kind == yaml.Kind.MAP) {
	                        //var mp = <yaml.YamlMap>val;
	                        this.markupNode(xbuf, mapping.value, lev + 1, json);
	                    }
	                    else {
	                        throw new Error("markup not implemented: " + yaml.Kind[val.kind]);
	                    }
	                    break;
	                }
	                xbuf.addWithIndent(lev, mapping.key.value + ':');
	                if (!val) {
	                    xbuf.append('\n');
	                    break;
	                }
	                if (val.kind == yaml.Kind.SCALAR) {
	                    var sc = val;
	                }
	                //xbuf.append(this.indent(lev, mapping.key.value + ':'));
	                if (mapping.value) {
	                    xbuf.append(this.inlined(mapping.value.kind) ? ' ' : '\n');
	                    this.markupNode(xbuf, mapping.value, lev + 1, json);
	                }
	                else {
	                    xbuf.append('\n');
	                }
	                //console.log('xbuf: ' + xbuf);
	                break;
	            case yaml.Kind.SCALAR:
	                var sc = node;
	                if (textutil.isMultiLine(sc.value)) {
	                    xbuf.append('|\n');
	                    var lines = splitOnLines(sc.value);
	                    for (var i = 0; i < lines.length; i++) {
	                        xbuf.append(this.indent(lev, lines[i]));
	                    }
	                    xbuf.append('\n');
	                }
	                else {
	                    xbuf.append(sc.value + '\n');
	                }
	                //console.log('SCALAR: ' + textutil.replaceNewlines(sc.value));
	                break;
	            case yaml.Kind.INCLUDE_REF:
	                var ref = node;
	                xbuf.append('!include ' + ref.value + '\n');
	                break;
	            default:
	                throw new Error('Unknown node kind: ' + yaml.Kind[node.kind]);
	        }
	        while (start < xbuf.text.length && xbuf.text[start] == ' ')
	            start++;
	        node.startPosition = start;
	        node.endPosition = xbuf.text.length;
	    };
	    ASTNode.prototype.markup = function (json) {
	        if (json === void 0) { json = false; }
	        var buf = new MarkupIndentingBuffer('');
	        this.markupNode(buf, this._actualNode(), 0, json);
	        return buf.text;
	    };
	    ASTNode.prototype.root = function () {
	        var node = this;
	        while (node.parent()) {
	            var p = node.parent();
	            //if(p.isValueInclude()) break; // stop on include
	            node = p;
	        }
	        return node;
	    };
	    ASTNode.prototype.parentOfKind = function (kind) {
	        var p = this.parent();
	        while (p) {
	            if (p.kind() == kind)
	                return p;
	            p = p.parent();
	        }
	        return null;
	    };
	    ASTNode.prototype.find = function (name) {
	        var found = null;
	        //console.log('Looking for: ' + name);
	        this.directChildren().forEach(function (y) {
	            if (y.key() && y.key() == name) {
	                if (!found)
	                    found = y;
	            }
	        });
	        return found;
	    };
	    ASTNode.prototype.shiftNodes = function (offset, shift, exclude) {
	        this.directChildren().forEach(function (x) {
	            if (exclude && exclude.start() == x.start() && exclude.end() == x.end()) {
	            }
	            else {
	                var m = x.shiftNodes(offset, shift, exclude);
	            }
	        });
	        if (exclude && exclude.start() == this.start() && exclude.end() == this.end()) {
	        }
	        else {
	            var yaNode = this._actualNode();
	            if (yaNode)
	                innerShift(offset, yaNode, shift);
	        }
	        return null;
	    };
	    ASTNode.prototype.isMap = function () {
	        return this.kind() == yaml.Kind.MAP;
	    };
	    ASTNode.prototype.isMapping = function () {
	        return this.kind() == yaml.Kind.MAPPING;
	    };
	    ASTNode.prototype.isSeq = function () {
	        return this.kind() == yaml.Kind.SEQ;
	    };
	    ASTNode.prototype.isScalar = function () {
	        return this.kind() == yaml.Kind.SCALAR;
	    };
	    ASTNode.prototype.asMap = function () {
	        if (!this.isMap())
	            throw new Error("map expected instead of " + this.kindName());
	        return (this._actualNode());
	    };
	    ASTNode.prototype.asMapping = function () {
	        if (!this.isMapping())
	            throw new Error("maping expected instead of " + this.kindName());
	        return (this._actualNode());
	    };
	    ASTNode.prototype.asSeq = function () {
	        if (!this.isSeq())
	            throw new Error("seq expected instead of " + this.kindName());
	        return (this._actualNode());
	    };
	    ASTNode.prototype.asScalar = function () {
	        if (!this.isScalar())
	            throw new Error("scalar expected instead of " + this.kindName());
	        return (this._actualNode());
	    };
	    ASTNode.prototype.isValueSeq = function () {
	        return this.valueKind() == yaml.Kind.SEQ;
	    };
	    ASTNode.prototype.isValueMap = function () {
	        return this.valueKind() == yaml.Kind.MAP;
	    };
	    ASTNode.prototype.isValueInclude = function () {
	        return this.valueKind() == yaml.Kind.INCLUDE_REF;
	    };
	    ASTNode.prototype.isValueScalar = function () {
	        return this.valueKind() == yaml.Kind.SCALAR;
	    };
	    ASTNode.prototype.valueAsSeq = function () {
	        if (!this.isMapping())
	            throw new Error("mapping expected instead of " + this.kindName());
	        if (this.valueKind() != yaml.Kind.SEQ)
	            throw new Error("mappng/seq expected instead of mapping/" + this.kindName());
	        return (this.asMapping().value);
	    };
	    ASTNode.prototype.valueAsMap = function () {
	        if (!this.isMapping())
	            throw new Error("mapping expected instead of " + this.kindName());
	        if (this.valueKind() != yaml.Kind.MAP)
	            throw new Error("mappng/map expected instead of mapping/" + this.kindName());
	        return (this.asMapping().value);
	    };
	    ASTNode.prototype.valueAsScalar = function () {
	        if (!this.isMapping())
	            throw new Error("mapping expected instead of " + this.kindName());
	        if (this.valueKind() != yaml.Kind.SCALAR)
	            throw new Error("mappng/scalar expected instead of mapping/" + this.kindName());
	        return (this.asMapping().value);
	    };
	    ASTNode.prototype.valueAsInclude = function () {
	        if (!this.isMapping())
	            throw new Error("mapping expected instead of " + this.kindName());
	        if (this.valueKind() != yaml.Kind.INCLUDE_REF)
	            throw new Error("mappng/include expected instead of mapping/" + this.kindName());
	        return (this.asMapping().value);
	    };
	    ASTNode.prototype.text = function (unitText) {
	        if (unitText === void 0) { unitText = null; }
	        if (!unitText) {
	            if (!this.unit())
	                return '[no-text]';
	            unitText = this.unit().contents();
	        }
	        return unitText.substring(this.start(), this.end());
	    };
	    ASTNode.prototype.copy = function () {
	        var yn = copyNode(this._actualNode());
	        return new ASTNode(yn, this._unit, this._parent, this._anchor, this._include, this._includesContents);
	    };
	    ASTNode.prototype.nodeDefinition = function () {
	        return getDefinitionForLowLevelNode(this);
	    };
	    return ASTNode;
	}());
	exports.ASTNode = ASTNode;
	(function (InsertionPointType) {
	    InsertionPointType[InsertionPointType["NONE"] = 0] = "NONE";
	    InsertionPointType[InsertionPointType["START"] = 1] = "START";
	    InsertionPointType[InsertionPointType["END"] = 2] = "END";
	    InsertionPointType[InsertionPointType["POINT"] = 3] = "POINT";
	})(exports.InsertionPointType || (exports.InsertionPointType = {}));
	var InsertionPointType = exports.InsertionPointType;
	var InsertionPoint = (function () {
	    function InsertionPoint(type, point) {
	        if (point === void 0) { point = null; }
	        this.type = type;
	        this.point = point;
	    }
	    InsertionPoint.after = function (point) {
	        return new InsertionPoint(InsertionPointType.POINT, point);
	    };
	    InsertionPoint.atStart = function () {
	        return new InsertionPoint(InsertionPointType.START);
	    };
	    InsertionPoint.atEnd = function () {
	        return new InsertionPoint(InsertionPointType.END);
	    };
	    InsertionPoint.node = function () {
	        return new InsertionPoint(InsertionPointType.NONE);
	    };
	    InsertionPoint.prototype.show = function (msg) {
	        if (msg) {
	            console.log(msg);
	            console.log('  insertion point type: ' + InsertionPointType[this.type]);
	        }
	        else {
	            console.log('insertion point type: ' + InsertionPointType[this.type]);
	        }
	        if (this.type == InsertionPointType.POINT && this.point) {
	            this.point.show();
	        }
	    };
	    return InsertionPoint;
	}());
	exports.InsertionPoint = InsertionPoint;
	function createNode(key, parent) {
	    //console.log('create node: ' + key);
	    var node = yaml.newMapping(yaml.newScalar(key), yaml.newMap());
	    return new ASTNode(node, null, parent, null, null);
	}
	exports.createNode = createNode;
	function createMap(mappings) {
	    //console.log('create node: ' + key);
	    var node = yaml.newMap(mappings);
	    return new ASTNode(node, null, null, null, null);
	}
	exports.createMap = createMap;
	function createScalar(value) {
	    var node = yaml.newScalar(value);
	    return new ASTNode(node, null, null, null, null);
	}
	exports.createScalar = createScalar;
	function createSeq(sn, parent, unit) {
	    return new ASTNode(sn, unit, parent, null, null);
	}
	exports.createSeq = createSeq;
	/*
	export function createMappingWithMap(key:string, map: yaml.YAMLNode){
	    //console.log('create node: ' + key);
	    var node:yaml.YAMLNode=yaml.newMapping(yaml.newScalar(key),map);
	    return new ASTNode(node,null,null,null,null);
	}

	export function createMap(){
	    //console.log('create node: ' + key);
	    var node:yaml.YAMLNode=yaml.newMap();
	    return new ASTNode(node,null,null,null,null);
	}
	*/
	function createSeqNode(key) {
	    var node = yaml.newMapping(yaml.newScalar(key), yaml.newItems());
	    return new ASTNode(node, null, null, null, null);
	}
	exports.createSeqNode = createSeqNode;
	function createMapNode(key) {
	    var node = yaml.newMapping(yaml.newScalar(key), yaml.newMap());
	    return new ASTNode(node, null, null, null, null);
	}
	exports.createMapNode = createMapNode;
	function createMapping(key, v) {
	    //console.log('create mapping: ' + key);
	    var node = yaml.newMapping(yaml.newScalar(key), yaml.newScalar(v));
	    return new ASTNode(node, null, null, null, null);
	}
	exports.createMapping = createMapping;
	function toChildCahcingNode(node) {
	    if (!(node instanceof ASTNode)) {
	        return null;
	    }
	    var astNode = node;
	    var result = new ASTNode(astNode.yamlNode(), astNode.unit(), null, null, null, true);
	    result._errors = astNode._errors;
	    return result;
	}
	exports.toChildCahcingNode = toChildCahcingNode;
	function toIncludingNode(node) {
	    if (!(node instanceof ASTNode)) {
	        return null;
	    }
	    var astNode = node;
	    var result = new ASTNode(astNode.yamlNode(), astNode.unit(), null, null, null, false);
	    result._errors = astNode._errors;
	    return result;
	}
	exports.toIncludingNode = toIncludingNode;
	function getDefinitionForLowLevelNode(node) {
	    var hl = node.highLevelNode();
	    if (hl) {
	        return hl.definition();
	    }
	    var parent = node.parent();
	    if (!parent) {
	        return null;
	    }
	    var key = node.key();
	    if (!key) {
	        return null;
	    }
	    var parentDef = parent.nodeDefinition();
	    if (!parentDef) {
	        return null;
	    }
	    if (!parentDef.property) {
	        return null;
	    }
	    var prop = parentDef.property(key);
	    if (!prop) {
	        return null;
	    }
	    return prop.range();
	}
	exports.getDefinitionForLowLevelNode = getDefinitionForLowLevelNode;
	function fetchMasterReference(unit, map, errors, lMap) {
	    if (!unit.isOverlayOrExtension())
	        return;
	    var masterReferenceNode = unit.getMasterReferenceNode();
	    if (!masterReferenceNode)
	        return;
	    var masterReferenceText = masterReferenceNode.value();
	    if (!masterReferenceText)
	        return;
	    var unitPath = path.dirname(unit.absolutePath());
	    var absIncludePath = toAbsolutePath(unitPath, masterReferenceText);
	    if (map[absIncludePath]) {
	        return;
	    }
	    if (errors[absIncludePath]) {
	        masterReferenceNode.errors().push(new Error(errors[masterReferenceText]));
	        return;
	    }
	    var arr = lMap[absIncludePath];
	    if (!arr) {
	        arr = [];
	        lMap[absIncludePath] = arr;
	    }
	    arr.push(masterReferenceNode);
	}
	function fetchIncludesAndMasterAsync(project, apiPath) {
	    var map = {};
	    var errors = {};
	    var nodes = [];
	    var units = [];
	    var processUnits = function (ind) {
	        var refs = [];
	        var lMap = {};
	        while (ind < units.length) {
	            var unit = units[ind];
	            var unitPath = path.dirname(unit.absolutePath());
	            fetchMasterReference(unit, map, errors, lMap);
	            var includeNodes = unit.getIncludeNodes();
	            includeNodes.forEach(function (x) {
	                var ip = x.includePath();
	                var includeReference = refResolvers.getIncludeReference(ip);
	                if (includeReference) {
	                    refs.push(project.resolveAsync(unit.absolutePath(), ip));
	                    return;
	                }
	                if (!ip)
	                    return;
	                if (path.isAbsolute(ip)) {
	                    var e = path.extname(ip);
	                    if (e != ".json" && e != ".xsd") {
	                        //SUPPORTING 0.8 style resolving due to compatiblity reasons
	                        ip = ip.substr(1);
	                        ip = project.getRootPath() + "/" + ip;
	                    }
	                }
	                var absIncludePath = toAbsolutePath(unitPath, ip);
	                if (map[absIncludePath]) {
	                    return;
	                }
	                if (errors[absIncludePath]) {
	                    if (x.errors) {
	                        x.errors().push(new Error(errors[ip]));
	                        return;
	                    }
	                }
	                var arr = lMap[absIncludePath];
	                if (!arr) {
	                    arr = [];
	                    lMap[absIncludePath] = arr;
	                }
	                arr.push(x);
	            });
	            ind++;
	        }
	        var unitPaths = Object.keys(lMap);
	        if (refs.length == 0 && unitPaths.length == 0) {
	            return Promise.resolve();
	        }
	        var promises = refs;
	        unitPaths.forEach(function (unitPath) {
	            promises.push(project.unitAsync(unitPath, true).then(function (x) {
	                if (!map[x.absolutePath()]) {
	                    map[x.absolutePath()] = true;
	                    units.push(x);
	                }
	            }, function (x) {
	                lMap[unitPath].forEach(function (node) {
	                    if (node.errors) {
	                        node.errors().push(new Error(x));
	                    }
	                });
	                errors[unitPath] = x;
	                project.failedUnits[unitPath] = x;
	                if (project.pathToUnit[unitPath]) {
	                    x.inner = true;
	                }
	            }));
	        });
	        return Promise.all(promises).then(function (x) {
	            return processUnits(ind);
	        });
	    };
	    return project.unitAsync(apiPath).then(function (x) {
	        units.push(x);
	        map[x.absolutePath()] = true;
	        return processUnits(0);
	    }).then(function (x) {
	        return units.length > 0 ? units[0] : null;
	    });
	}
	exports.fetchIncludesAndMasterAsync = fetchIncludesAndMasterAsync;
	function toAbsolutePath(rootPath, relPath) {
	    if (isWebPath(relPath)) {
	        return relPath;
	    }
	    var apath;
	    if (isWebPath(rootPath)) {
	        var rp = util.stringEndsWith(rootPath, "/") ? rootPath : rootPath + "/";
	        apath = URL.resolve(rp, relPath);
	    }
	    else {
	        apath = path.resolve(rootPath, relPath);
	    }
	    return apath;
	}
	function isWebPath(str) {
	    if (str == null)
	        return false;
	    return util.stringStartsWith(str, "http://") || util.stringStartsWith(str, "https://");
	}
	//# sourceMappingURL=jsyaml2lowLevel.js.map

/***/ },
/* 22 */
/***/ function(module, exports, __webpack_require__) {

	/// <reference path="../../../typings/main.d.ts" />
	"use strict";
	var HttpResponse = __webpack_require__(58);
	__webpack_require__(59);
	__webpack_require__(64);
	var lru = __webpack_require__(66);
	var globalCache = lru(50);
	function hasAsyncRequests() {
	    return Object.keys(notifies).length > 0;
	}
	exports.hasAsyncRequests = hasAsyncRequests;
	function addLoadCallback(listener) {
	    nlisteners.push(listener);
	}
	exports.addLoadCallback = addLoadCallback;
	var nlisteners = [];
	var notifies = {};
	function addNotify(url) {
	    notifies[url] = true;
	}
	exports.addNotify = addNotify;
	function removeNotity(url) {
	    delete notifies[url];
	    nlisteners.forEach(function (x) { return x(url); });
	}
	exports.removeNotity = removeNotity;
	function isWaitingFor(url) {
	    return notifies[url] ? true : false;
	}
	exports.isWaitingFor = isWaitingFor;
	function set(url, content) {
	    globalCache.set(url, content);
	}
	exports.set = set;
	function get(url) {
	    return globalCache.get(url);
	}
	exports.get = get;
	//# sourceMappingURL=resourceRegistry.js.map

/***/ },
/* 23 */
/***/ function(module, exports, __webpack_require__) {

	/// <reference path="../../../typings/main.d.ts" />
	"use strict";
	var _ = __webpack_require__(61);
	var DOMParser = __webpack_require__(65).DOMParser;
	var base64 = __webpack_require__(60);
	/**
	 * Gets pure include path portion from the complete include.
	 * Does not include the reference part.
	 * @param includeString
	 */
	function getIncludePath(includeString) {
	    if (!includeString) {
	        return includeString;
	    }
	    var index = includeString.indexOf("#");
	    if (index == -1)
	        return includeString;
	    return includeString.substring(0, index);
	}
	exports.getIncludePath = getIncludePath;
	/**
	 * Gets reference portion of the include string and returns it as
	 * an array of segments. Returns null of no reference is contained in the include.
	 * @param includeString
	 */
	function getIncludeReference(includeString) {
	    if (!includeString) {
	        return null;
	    }
	    if (typeof includeString != "string") {
	        includeString = "" + includeString;
	    }
	    var index = includeString.indexOf("#");
	    if (index == -1)
	        return null;
	    var referenceString = index == includeString.length - 1 ? "" : includeString.substring(index + 1, includeString.length);
	    var segments = referenceString.split("/");
	    if (segments.length == 0)
	        return null;
	    if (segments[0].trim() == "") {
	        segments.splice(0, 1);
	    }
	    return new IncludeReferenceImpl(referenceString, getIncludePath(includeString), segments);
	}
	exports.getIncludeReference = getIncludeReference;
	/**
	 * Factory method returning all include reference resolvers, registered in the system.
	 */
	function getIncludeReferenceResolvers() {
	    return [new JSONResolver(), new XMLResolver()];
	}
	exports.getIncludeReferenceResolvers = getIncludeReferenceResolvers;
	/**
	 * Checks all resolvers, finds the suitable one, resolves the reference and returns the result
	 * of resolving. Returns null if no suitable resolver is found or resolver itself fails to resolve.
	 * @param includeString - complete include string
	 * @param content - include contents
	 */
	function resolveContents(includeString, content) {
	    if (!includeString) {
	        return content;
	    }
	    var reference = getIncludeReference(includeString);
	    if (!reference) {
	        return content;
	    }
	    var includePath = getIncludePath(includeString);
	    return resolve(includePath, reference, content).content;
	}
	exports.resolveContents = resolveContents;
	/**
	 * Checks all resolvers, finds the suitable one, resolves the reference and returns the result
	 * of resolving. Returns null if no suitable resolver is found or resolver itself fails to resolve.
	 * @param includePath
	 * @param includeReference
	 * @param content
	 */
	function resolve(includePath, includeReference, content) {
	    var resolver = _.find(getIncludeReferenceResolvers(), function (currentResolver) { return currentResolver.isApplicable(includePath, content); });
	    if (!resolver)
	        return {
	            content: content,
	            validation: []
	        };
	    return resolver.resolveReference(content, includeReference);
	}
	exports.resolve = resolve;
	function completeReference(includePath, includeReference, content) {
	    if (!content) {
	        return [];
	    }
	    var resolver = _.find(getIncludeReferenceResolvers(), function (currentResolver) { return currentResolver.isApplicable(includePath, content); });
	    if (!resolver)
	        return [];
	    return resolver.completeReference(content, includeReference);
	}
	exports.completeReference = completeReference;
	var IncludeReferenceImpl = (function () {
	    function IncludeReferenceImpl(originalString, includePath, segments) {
	        this.includePath = includePath;
	        this.segments = segments;
	        this.originalString = originalString;
	    }
	    IncludeReferenceImpl.prototype.getIncludePath = function () {
	        return this.includePath;
	    };
	    IncludeReferenceImpl.prototype.getFragments = function () {
	        return this.segments;
	    };
	    IncludeReferenceImpl.prototype.asString = function () {
	        return this.originalString;
	    };
	    IncludeReferenceImpl.prototype.encodedName = function (withExtention) {
	        if (withExtention === void 0) { withExtention = true; }
	        return base64(this.includePath + '/' + this.asString()) + (withExtention ? this.includePath.substring(this.includePath.lastIndexOf('.')) : '');
	    };
	    return IncludeReferenceImpl;
	}());
	var JSONResolver = (function () {
	    function JSONResolver() {
	    }
	    JSONResolver.prototype.isApplicable = function (includePath, content) {
	        return includePath && (endsWith(includePath.trim(), '.js') || endsWith(includePath.trim(), '.json'));
	    };
	    JSONResolver.prototype.resolveReference = function (content, reference) {
	        try {
	            var resultJson = {};
	            resultJson['$ref'] = reference.getIncludePath() + '#' + reference.asString();
	            return {
	                content: JSON.stringify(resultJson, null, 2),
	                validation: []
	            };
	        }
	        catch (Error) {
	            console.log(Error);
	        }
	        return {
	            content: content,
	            validation: []
	        };
	    };
	    JSONResolver.prototype.completeReference = function (content, reference) {
	        try {
	            var jsonRoot = JSON.parse(content);
	            var fragments = reference.getFragments();
	            if (!fragments || fragments.length == 0) {
	                return this.getChildren(jsonRoot);
	            }
	            var currentJSON = jsonRoot;
	            var emptyPrefixCompletion = reference.asString().lastIndexOf("/") == reference.asString().length - 1;
	            var limit = emptyPrefixCompletion ? fragments.length : fragments.length - 1;
	            for (var i = 0; i < fragments.length - 1; i++) {
	                var fragment = fragments[i];
	                currentJSON = this.findChild(currentJSON, fragment);
	                if (!currentJSON) {
	                    return [];
	                }
	            }
	            if (emptyPrefixCompletion) {
	                return this.getChildren(currentJSON);
	            }
	            else {
	                var lastPrefix = fragments[fragments.length - 1];
	                var result = [];
	                this.getChildren(currentJSON).forEach(function (child) {
	                    if (child.indexOf(lastPrefix) == 0) {
	                        result.push(child);
	                    }
	                });
	                return result;
	            }
	        }
	        catch (Error) {
	            console.log(Error);
	        }
	        return [];
	    };
	    JSONResolver.prototype.findChild = function (jsonObject, fragment) {
	        var decoded = fragment.replace('~1', '/');
	        decoded = fragment.replace('~0', '~');
	        return jsonObject[decoded];
	    };
	    JSONResolver.prototype.getChildren = function (jsonObject) {
	        return Object.keys(jsonObject);
	    };
	    return JSONResolver;
	}());
	var XMLResolver = (function () {
	    function XMLResolver() {
	    }
	    XMLResolver.prototype.isApplicable = function (includePath, content) {
	        return includePath && (endsWith(includePath.trim(), '.xml') || endsWith(includePath.trim(), '.xsd'));
	    };
	    XMLResolver.prototype.resolveReference = function (content, reference) {
	        try {
	            var doc = new DOMParser().parseFromString(content);
	            var requestedName = reference.asString();
	            var uniqueName = reference.encodedName(false);
	            var schema = elementChildrenByName(doc, 'xs:schema')[0];
	            var elements = elementChildrenByName(schema, 'xs:element');
	            var types = elementChildrenByName(schema, 'xs:complexType');
	            var canBeElement = _.find(elements, function (element) { return element.getAttribute('name') === requestedName; });
	            var canBeType = canBeElement ? _.find(types, function (type) { return type.getAttribute('name') === canBeElement.getAttribute('type'); }) : _.find(types, function (type) { return type.getAttribute('name') === requestedName; });
	            var element = doc.createElement('xs:element');
	            element.setAttribute('name', uniqueName);
	            if (canBeType) {
	                element.setAttribute('type', canBeType.getAttribute('name'));
	            }
	            if (canBeElement) {
	                element.setAttribute('originalname', canBeElement.getAttribute('name'));
	            }
	            element.setAttribute('requestedname', requestedName);
	            element.setAttribute('extraelement', 'true');
	            schema.appendChild(element);
	            return {
	                content: doc.toString(),
	                validation: []
	            };
	        }
	        catch (throwable) {
	            console.log(throwable);
	        }
	        return {
	            content: content,
	            validation: []
	        };
	    };
	    XMLResolver.prototype.completeReference = function (content, reference) {
	        try {
	            var doc = new DOMParser().parseFromString(content);
	            var result = [];
	            var schema = elementChildrenByName(doc, 'xs:schema')[0];
	            var elements = elementChildrenByName(schema, 'xs:element');
	            var types = elementChildrenByName(schema, 'xs:complexType');
	            elements.forEach(function (element) { return result.push(element.getAttribute('name')); });
	            types.forEach(function (type) { return result.push(type.getAttribute('name')); });
	            var emptyPrefixCompletion = reference.asString().trim().length === 0;
	            if (emptyPrefixCompletion) {
	                return result;
	            }
	            else {
	                return result.filter(function (value) { return value.indexOf(reference.asString()) === 0; });
	            }
	        }
	        catch (exception) {
	            return [];
	        }
	    };
	    return XMLResolver;
	}());
	function endsWith(input, ends) {
	    if (!input) {
	        return false;
	    }
	    if (!ends) {
	        return false;
	    }
	    return input.lastIndexOf(ends) === (input.length - ends.length);
	}
	function elementChildrenByName(parent, tagName) {
	    var elements = parent.getElementsByTagName(tagName);
	    var result = [];
	    for (var i = 0; i < elements.length; i++) {
	        var child = elements[i];
	        if (child.parentNode === parent) {
	            result.push(child);
	        }
	    }
	    return result;
	}
	//# sourceMappingURL=includeRefResolvers.js.map

/***/ },
/* 24 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var __extends = (this && this.__extends) || function (d, b) {
	    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
	    function __() { this.constructor = d; }
	    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
	};
	var hl = __webpack_require__(10);
	var hlimpl = __webpack_require__(16);
	var yaml = __webpack_require__(70);
	var util = __webpack_require__(43);
	var proxy = __webpack_require__(37);
	var RamlWrapperImpl = __webpack_require__(28);
	var RamlWrapper08Impl = __webpack_require__(45);
	var factory10 = __webpack_require__(41);
	var factory08 = __webpack_require__(42);
	var wrapperHelper = __webpack_require__(32);
	var wrapperHelper08 = __webpack_require__(46);
	var pluralize = __webpack_require__(67);
	var universeDef = __webpack_require__(30);
	var _ = __webpack_require__(61);
	var changeCase = __webpack_require__(69);
	function expandTraitsAndResourceTypes(api) {
	    if (!(api instanceof RamlWrapperImpl.ApiImpl || api instanceof RamlWrapper08Impl.ApiImpl)) {
	        return null;
	    }
	    return new TraitsAndResourceTypesExpander()
	        .expandTraitsAndResourceTypes(api);
	}
	exports.expandTraitsAndResourceTypes = expandTraitsAndResourceTypes;
	function mergeAPIs(masterUnit, extensionsAndOverlays, mergeMode) {
	    var masterApi = hlimpl.fromUnit(masterUnit);
	    if (!masterApi)
	        throw new Error("couldn't load api from " + masterUnit.absolutePath());
	    if (!extensionsAndOverlays || extensionsAndOverlays.length == 0) {
	        return masterApi;
	    }
	    var highLevelNodes = [];
	    for (var i = 0; i < extensionsAndOverlays.length; i++) {
	        var unit = extensionsAndOverlays[i];
	        var hlNode = hlimpl.fromUnit(unit);
	        if (!hlNode) {
	            throw new Error("couldn't load api from " + unit.absolutePath());
	        }
	        highLevelNodes.push(hlNode);
	    }
	    var lastExtensionOrOverlay = mergeHighLevelNodes(masterApi, highLevelNodes, mergeMode);
	    return lastExtensionOrOverlay;
	}
	exports.mergeAPIs = mergeAPIs;
	function mergeHighLevelNodes(masterApi, highLevelNodes, mergeMode) {
	    var currentMaster = masterApi;
	    highLevelNodes.forEach(function (currentApi) {
	        currentApi.overrideMaster(currentMaster);
	        currentApi.setMergeMode(mergeMode);
	        currentMaster = currentApi;
	    });
	    return currentMaster;
	}
	;
	var TraitsAndResourceTypesExpander = (function () {
	    function TraitsAndResourceTypesExpander() {
	    }
	    TraitsAndResourceTypesExpander.prototype.expandTraitsAndResourceTypes = function (api) {
	        var _this = this;
	        if (api.definition().key() == universeDef.Universe10.Overlay) {
	            return api;
	        }
	        this.ramlVersion = api.highLevel().definition().universe().version();
	        var factory = this.ramlVersion == "RAML10" ? factory10 : factory08;
	        var isRAML1 = api instanceof RamlWrapperImpl.ApiImpl;
	        this.globalTraits = this.ramlVersion == "RAML10"
	            ? wrapperHelper.allTraits(api)
	            : wrapperHelper08.allTraits(api);
	        this.globalResourceTypes = this.ramlVersion == "RAML10"
	            ? wrapperHelper.allResourceTypes(api)
	            : wrapperHelper08.allResourceTypes(api);
	        //if ((!traits || traits.length == 0) && (!resourceTypes || resourceTypes.length == 0)) {
	        //    return api;
	        //}
	        if (this.globalTraits.length == 0 && this.globalResourceTypes.length == 0) {
	            return api;
	        }
	        var hlNode = this.createHighLevelNode(api.highLevel());
	        var result = factory.buildWrapperNode(hlNode);
	        result.setAttributeDefaults(api.getDefaultsCalculator().isEnabled());
	        this.traitMap = {};
	        this.resourceTypeMap = {};
	        result.highLevel().setMergeMode(api.highLevel().getMergeMode());
	        var resources = result.resources();
	        resources.forEach(function (x) { return _this.processResource(x); });
	        return result;
	    };
	    TraitsAndResourceTypesExpander.prototype.getTemplate = function (name, context, cache, globalList) {
	        var unitPath = context.lowLevel().unit().path();
	        var unitCache = cache[unitPath];
	        if (!unitCache) {
	            unitCache = {};
	            cache[unitPath] = unitCache;
	        }
	        var val = unitCache[name];
	        if (val !== undefined) {
	            return val;
	        }
	        val = null;
	        val = _.find(globalList, function (x) { return hlimpl.qName(x.highLevel(), context) == name; });
	        if (!val) {
	            val = null;
	        }
	        unitCache[name] = val;
	        return val;
	    };
	    TraitsAndResourceTypesExpander.prototype.createHighLevelNode = function (api) {
	        var highLevelNodes = [];
	        var node = api;
	        while (node) {
	            var llNode = node.lowLevel();
	            var topComposite = new proxy.LowLevelCompositeNode(llNode, null, null, this.ramlVersion);
	            var nodeType = node.definition();
	            var newNode = new hlimpl.ASTNodeImpl(topComposite, null, nodeType, null);
	            highLevelNodes.push(newNode);
	            node = node.getMaster();
	        }
	        var masterApi = highLevelNodes.pop();
	        highLevelNodes = highLevelNodes.reverse();
	        var mergeMode = api.getMergeMode();
	        return mergeHighLevelNodes(masterApi, highLevelNodes, mergeMode);
	    };
	    TraitsAndResourceTypesExpander.prototype.processResource = function (resource) {
	        var _this = this;
	        var resourceData = this.collectResourceData(resource, resource);
	        var resourceLowLevel = resource.highLevel().lowLevel();
	        resourceData.filter(function (x) { return x.resourceType != null; }).forEach(function (x) {
	            var resourceTypeLowLevel = x.resourceType.node.highLevel().lowLevel();
	            var resourceTypeTransformer = new DefaultTransformer(resource, x.resourceType.transformer);
	            resourceLowLevel.adopt(resourceTypeLowLevel, resourceTypeTransformer);
	        });
	        var methods = resource.methods();
	        methods.forEach(function (m) {
	            var methodLowLevel = m.highLevel().lowLevel();
	            var name = m.method();
	            resourceData.forEach(function (x) {
	                var methodTraits = x.methodTraits[name];
	                if (methodTraits) {
	                    methodTraits.forEach(function (x) {
	                        var traitLowLevel = x.node.highLevel().lowLevel();
	                        var traitTransformer = new DefaultTransformer(m, x.transformer);
	                        methodLowLevel.adopt(traitLowLevel, traitTransformer);
	                    });
	                }
	                var resourceTraits = x.traits;
	                if (resourceTraits) {
	                    resourceTraits.forEach(function (x) {
	                        var traitLowLevel = x.node.highLevel().lowLevel();
	                        var traitTransformer = new DefaultTransformer(m, x.transformer);
	                        methodLowLevel.adopt(traitLowLevel, traitTransformer);
	                    });
	                }
	            });
	        });
	        var resources = resource.resources();
	        resources.forEach(function (x) { return _this.processResource(x); });
	    };
	    TraitsAndResourceTypesExpander.prototype.collectResourceData = function (original, obj, arr, transformer, occuredResourceTypes) {
	        var _this = this;
	        if (arr === void 0) { arr = []; }
	        if (occuredResourceTypes === void 0) { occuredResourceTypes = {}; }
	        var ownTraits = this.extractTraits(obj, transformer);
	        var methodTraitsMap = {};
	        var methods = obj.methods();
	        methods.forEach(function (x) {
	            var methodTraits = _this.extractTraits(x, transformer);
	            if (methodTraits && methodTraits.length > 0) {
	                methodTraitsMap[x.method()] = methodTraits;
	            }
	        });
	        var rtData;
	        var rt = obj.type();
	        if (rt && !occuredResourceTypes[rt.name()]) {
	            occuredResourceTypes[rt.name()] = true;
	            rtData = this.readGenerictData(original, rt, obj.highLevel(), this.resourceTypeMap, this.globalResourceTypes, 'resource type', transformer);
	        }
	        arr.push({
	            resourceType: rtData,
	            traits: ownTraits,
	            methodTraits: methodTraitsMap
	        });
	        if (rtData) {
	            this.collectResourceData(original, rtData.node, arr, rtData.transformer, occuredResourceTypes);
	        }
	        return arr;
	    };
	    TraitsAndResourceTypesExpander.prototype.extractTraits = function (obj, _transformer, occuredTraits) {
	        var _this = this;
	        if (occuredTraits === void 0) { occuredTraits = {}; }
	        var arr = [];
	        for (var i = -1; i < arr.length; i++) {
	            var gd = i < 0 ? null : arr[i];
	            var _obj = gd ? gd.node : obj;
	            var transformer = gd ? gd.transformer : _transformer;
	            if (!_obj['is']) {
	                continue;
	            }
	            _obj.is().forEach(function (x) {
	                var traitData = _this.readGenerictData(obj, x, _obj.highLevel(), _this.traitMap, _this.globalTraits, 'trait', transformer);
	                if (traitData) {
	                    var name = traitData.name;
	                    //if (!occuredTraits[name]) {
	                    occuredTraits[name] = true;
	                    arr.push(traitData);
	                }
	            });
	        }
	        return arr;
	    };
	    TraitsAndResourceTypesExpander.prototype.readGenerictData = function (r, obj, context, cache, globalList, template, transformer) {
	        var value = obj.value();
	        if (typeof (value) == 'string') {
	            if (transformer) {
	                value = transformer.transform(value).value;
	            }
	            var node = this.getTemplate(value, context, cache, globalList);
	            if (node) {
	                return {
	                    name: value,
	                    transformer: null,
	                    node: node
	                };
	            }
	        }
	        else if (value instanceof hlimpl.StructuredValue) {
	            var sv = value;
	            var name = sv.valueName();
	            if (transformer) {
	                name = transformer.transform(name).value;
	            }
	            var scalarParams = {};
	            var structuredParams = {};
	            var node = this.getTemplate(name, context, cache, globalList);
	            ;
	            //var t = hlimpl.typeFromNode(node.highLevel());
	            if (node) {
	                if (this.ramlVersion == 'RAML08') {
	                    if (transformer) {
	                        sv.children().forEach(function (x) { return scalarParams[x.valueName()] = transformer.transform(x.lowLevel().value()).value; });
	                    }
	                    else {
	                        sv.children().forEach(function (x) { return scalarParams[x.valueName()] = x.lowLevel().value(); });
	                    }
	                }
	                else {
	                    sv.children().forEach(function (x) {
	                        var llNode = x.lowLevel();
	                        if (llNode.valueKind() == yaml.Kind.SCALAR) {
	                            scalarParams[x.valueName()] = llNode.value();
	                        }
	                        else {
	                            structuredParams[x.valueName()] = llNode;
	                        }
	                    });
	                }
	                var ds = new DefaultTransformer(r, null);
	                Object.keys(scalarParams).forEach(function (x) {
	                    var q = ds.transform(scalarParams[x]);
	                    //if (q.value){
	                    if (q) {
	                        if (typeof q !== "object") {
	                            scalarParams[x] = q;
	                        }
	                    }
	                    //}
	                });
	                return {
	                    name: name,
	                    transformer: new ValueTransformer(template, name, scalarParams, structuredParams),
	                    node: node
	                };
	            }
	        }
	        return null;
	    };
	    return TraitsAndResourceTypesExpander;
	}());
	var TransformMatches = (function () {
	    function TransformMatches(name, transformer) {
	        this.name = name;
	        this.regexp = new RegExp(TransformMatches.leftTransformRegexp.source + name + TransformMatches.rightTransformRegexp.source);
	        this.transformer = transformer;
	    }
	    TransformMatches.leftTransformRegexp = /\|\s*!\s*/;
	    TransformMatches.rightTransformRegexp = /\s*$/;
	    return TransformMatches;
	}());
	var transformers = [
	    new TransformMatches("singularize", function (arg) { return pluralize.singular(arg); }),
	    new TransformMatches("pluralize", function (arg) { return pluralize.plural(arg); }),
	    new TransformMatches("uppercase", function (arg) { return arg ? arg.toUpperCase() : arg; }),
	    new TransformMatches("lowercase", function (arg) { return arg ? arg.toLowerCase() : arg; }),
	    new TransformMatches("lowercamelcase", function (arg) {
	        if (!arg) {
	            return arg;
	        }
	        return changeCase.camelCase(arg);
	    }),
	    new TransformMatches("uppercamelcase", function (arg) {
	        if (!arg) {
	            return arg;
	        }
	        var lowerCamelCase = changeCase.camelCase(arg);
	        return lowerCamelCase[0].toUpperCase() + lowerCamelCase.substring(1, lowerCamelCase.length);
	    }),
	    new TransformMatches("lowerunderscorecase", function (arg) {
	        if (!arg) {
	            return arg;
	        }
	        var snakeCase = changeCase.snake(arg);
	        return snakeCase.toLowerCase();
	    }),
	    new TransformMatches("upperunderscorecase", function (arg) {
	        if (!arg) {
	            return arg;
	        }
	        var snakeCase = changeCase.snake(arg);
	        return snakeCase.toUpperCase();
	    }),
	    new TransformMatches("lowerhyphencase", function (arg) {
	        if (!arg) {
	            return arg;
	        }
	        var paramCase = changeCase.param(arg);
	        return paramCase.toLowerCase();
	    }),
	    new TransformMatches("upperhyphencase", function (arg) {
	        if (!arg) {
	            return arg;
	        }
	        var paramCase = changeCase.param(arg);
	        return paramCase.toUpperCase();
	    })
	];
	function getTransformNames() {
	    return transformers.map(function (transformer) { return transformer.name; });
	}
	exports.getTransformNames = getTransformNames;
	function getTransformerForOccurence(occurence) {
	    var result;
	    for (var i = 0; i < transformers.length; i++) {
	        if (occurence.match(transformers[i].regexp)) {
	            result = transformers[i].transformer;
	            break;
	        }
	    }
	    return result;
	}
	exports.getTransformerForOccurence = getTransformerForOccurence;
	var TransformationBuffer = (function () {
	    function TransformationBuffer() {
	        this.buf = null;
	    }
	    TransformationBuffer.prototype.append = function (value) {
	        if (value !== "") {
	            if (this.buf != null) {
	                if (value != null) {
	                    if (typeof (this.buf) != "string") {
	                        this.buf = "" + this.buf;
	                    }
	                    this.buf += value;
	                }
	            }
	            else if (value !== "") {
	                this.buf = value;
	            }
	        }
	    };
	    TransformationBuffer.prototype.value = function () {
	        return this.buf != null ? this.buf : "";
	    };
	    return TransformationBuffer;
	}());
	var ValueTransformer = (function () {
	    function ValueTransformer(templateKind, templateName, params, structuredParams) {
	        this.templateKind = templateKind;
	        this.templateName = templateName;
	        this.params = params;
	        this.structuredParams = structuredParams;
	    }
	    ValueTransformer.prototype.transform = function (obj, toString) {
	        var undefParams = {};
	        var errors = [];
	        if (typeof (obj) === 'string') {
	            if (this.structuredParams && util.stringStartsWith(obj, "<<") && util.stringEndsWith(obj, ">>")) {
	                var paramName = obj.substring(2, obj.length - 2);
	                var structuredValue = this.structuredParams[paramName];
	                if (structuredValue != null) {
	                    return { value: structuredValue.value(toString), errors: errors };
	                }
	            }
	            var str = obj;
	            var buf = new TransformationBuffer();
	            var prev = 0;
	            for (var i = str.indexOf('<<'); i >= 0; i = str.indexOf('<<', prev)) {
	                buf.append(str.substring(prev, i));
	                var i0 = i;
	                i += '<<'.length;
	                prev = str.indexOf('>>', i);
	                if (prev == -1) {
	                    break;
	                }
	                var paramOccurence = str.substring(i, prev);
	                prev += '>>'.length;
	                var originalString = str.substring(i0, prev);
	                var val;
	                var paramName;
	                var transformer = getTransformerForOccurence(paramOccurence);
	                if (transformer) {
	                    var ind = paramOccurence.lastIndexOf('|');
	                    paramName = paramOccurence.substring(0, ind).trim();
	                    val = this.params[paramName];
	                    if (val) {
	                        val = transformer(val);
	                    }
	                }
	                else {
	                    paramName = paramOccurence.trim();
	                    val = this.params[paramName];
	                }
	                if (val === null || val === undefined) {
	                    undefParams[paramName] = true;
	                    val = originalString;
	                }
	                buf.append(val);
	            }
	            var upArr = Object.keys(undefParams);
	            if (upArr.length > 0) {
	                var errStr = upArr.join(', ').trim();
	                var message = "Undefined " + this.templateKind + " parameter" + (upArr.length > 1 ? 's' : '') + ": " + errStr;
	                var error = {
	                    code: hl.IssueCode.MISSING_REQUIRED_PROPERTY,
	                    isWarning: false,
	                    message: message,
	                    node: null,
	                    start: -1,
	                    end: -1,
	                    path: null
	                };
	                errors.push(error);
	            }
	            buf.append(str.substring(prev, str.length));
	            return { value: buf.value(), errors: errors };
	        }
	        else {
	            return { value: obj, errors: errors };
	        }
	    };
	    ValueTransformer.prototype.children = function (node) {
	        var substitution = this.substitutionNode(node);
	        if (substitution) {
	            return substitution.children();
	        }
	        return null;
	    };
	    ValueTransformer.prototype.valueKind = function (node) {
	        var substitution = this.substitutionNode(node);
	        if (substitution) {
	            return substitution.valueKind();
	        }
	        return null;
	    };
	    ValueTransformer.prototype.substitutionNode = function (node) {
	        var paramName = this.paramName(node);
	        return paramName && this.structuredParams[paramName];
	    };
	    ValueTransformer.prototype.paramName = function (node) {
	        var paramName = null;
	        if (node.valueKind() == yaml.Kind.SCALAR) {
	            var val = ("" + node.value()).trim();
	            if (util.stringStartsWith(val, "<<") && util.stringEndsWith(val, ">>")) {
	                paramName = val.substring(2, val.length - 2);
	            }
	        }
	        return paramName;
	    };
	    return ValueTransformer;
	}());
	exports.ValueTransformer = ValueTransformer;
	var DefaultTransformer = (function (_super) {
	    __extends(DefaultTransformer, _super);
	    function DefaultTransformer(owner, delegate) {
	        _super.call(this, delegate != null ? delegate.templateKind : "", delegate != null ? delegate.templateName : "");
	        this.owner = owner;
	        this.delegate = delegate;
	    }
	    DefaultTransformer.prototype.transform = function (obj, toString) {
	        if (obj == null) {
	            return {
	                value: obj,
	                errors: []
	            };
	        }
	        var ownResult = {
	            value: obj,
	            errors: []
	        };
	        var gotDefaultParam = false;
	        defaultParameters.forEach(function (x) { return gotDefaultParam = gotDefaultParam || obj.toString().indexOf('<<' + x) >= 0; });
	        if (gotDefaultParam) {
	            this.initParams();
	            ownResult = _super.prototype.transform.call(this, obj);
	        }
	        var result = this.delegate != null ? this.delegate.transform(ownResult.value, toString) : ownResult.value;
	        return result;
	    };
	    DefaultTransformer.prototype.initParams = function () {
	        var methodName;
	        var resourcePath = "";
	        var resourcePathName;
	        var ll = this.owner.highLevel().lowLevel();
	        var node = ll instanceof proxy.LowLevelProxyNode ? ll.originalNode().originalNode() : ll;
	        var last = null;
	        while (node) {
	            var key = node.key();
	            if (key != null) {
	                if (util.stringStartsWith(key, '/')) {
	                    if (!resourcePathName) {
	                        var arr = key.split('/');
	                        for (var i = arr.length - 1; i >= 0; i--) {
	                            var seg = arr[i];
	                            if (seg.indexOf('{') == -1) {
	                                resourcePathName = arr[i];
	                                break;
	                            }
	                            if (seg.length > 0) {
	                                last = seg;
	                            }
	                        }
	                    }
	                    resourcePath = key + resourcePath;
	                }
	                else {
	                    methodName = key;
	                }
	            }
	            node = node.parent();
	        }
	        if (!resourcePathName) {
	            if (last) {
	                resourcePathName = "";
	            }
	        }
	        this.params = {
	            resourcePath: resourcePath,
	            resourcePathName: resourcePathName
	        };
	        if (methodName) {
	            this.params['methodName'] = methodName;
	        }
	    };
	    DefaultTransformer.prototype.children = function (node) {
	        return this.delegate != null ? this.delegate.children(node) : null;
	    };
	    DefaultTransformer.prototype.valueKind = function (node) {
	        return this.delegate != null ? this.delegate.valueKind(node) : null;
	    };
	    return DefaultTransformer;
	}(ValueTransformer));
	exports.DefaultTransformer = DefaultTransformer;
	var defaultParameters = ['resourcePath', 'resourcePathName', 'methodName'];
	//# sourceMappingURL=expander.js.map

/***/ },
/* 25 */
/***/ function(module, exports, __webpack_require__) {

	/// <reference path="../../../typings/main.d.ts" />
	"use strict";
	var jsyaml = __webpack_require__(21);
	var json = __webpack_require__(47);
	var stringify = __webpack_require__(62);
	var proxy = __webpack_require__(37);
	var defs = __webpack_require__(33);
	var hl = __webpack_require__(10);
	var _ = __webpack_require__(61);
	var yaml = __webpack_require__(70);
	var def = __webpack_require__(33);
	var hlimpl = __webpack_require__(16);
	var path = __webpack_require__(15);
	var fs = __webpack_require__(36);
	var universes = __webpack_require__(30);
	var universeHelpers = __webpack_require__(14);
	var universeProvider = __webpack_require__(35);
	var services = def;
	var OverloadingValidator = __webpack_require__(48);
	var expander = __webpack_require__(24);
	var search = __webpack_require__(27);
	var rtypes = def.rt;
	var util = __webpack_require__(40);
	var contentprovider = __webpack_require__(31);
	var su = def.getSchemaUtils();
	var mediaTypeParser = __webpack_require__(63);
	var xmlutil = __webpack_require__(49);
	var changeCase = __webpack_require__(69);
	var pluralize = __webpack_require__(67);
	var LinterSettings = (function () {
	    function LinterSettings() {
	        this.validateNotStrictExamples = true;
	    }
	    return LinterSettings;
	}());
	var settings = new LinterSettings();
	var loophole = __webpack_require__(76);
	function evalInSandbox(code, thisArg, args) {
	    return new loophole.Function(code).call(thisArg, args);
	}
	var MAX_RECURSION_LEVEL = 400;
	exports.RESERVED_TEMPLATE_PARAMETERS = {
	    "resourcePathName": "Part of the resource path following the rightmost \"/\"",
	    "methodName": "Method name",
	    "resourcePath": "Path of the resource"
	};
	var lintWithFile = function (customLinter, acceptor, astNode) {
	    if (fs.existsSync(customLinter)) {
	        try {
	            var content = fs.readFileSync(customLinter).toString();
	            var factr = new LinterExtensionsImpl(acceptor);
	            evalInSandbox(content, factr, null);
	            factr.visit(astNode);
	        }
	        catch (e) {
	            console.log("Error in custom linter");
	            console.log(e);
	        }
	    }
	};
	function checkPropertyQuard(n, v) {
	    var pr = n.property();
	    if (pr) {
	        pr.getContextRequirements().forEach(function (x) {
	            if (!n.checkContextValue(x.name, x.value, x.value)) {
	                v.accept(createIssue(hl.IssueCode.MISSED_CONTEXT_REQUIREMENT, x.name + " should be " + x.value + " to use property " + pr.nameId(), n));
	            }
	        });
	    }
	    return pr;
	}
	;
	function lintNode(astNode, acceptor) {
	    if (typeof fs === "undefined") {
	        return;
	    }
	    if (!fs) {
	        return;
	    }
	    var fsMethods = ['exists', 'readFile', 'writeFile', 'readdir', 'existsSync', 'readFileSync', 'writeFileSync', 'readdirSync'];
	    var existingFsFields = Object.keys(fs);
	    for (var i = 0; i < fsMethods.length; i++) {
	        if (!fs[fsMethods[i]]) {
	            return;
	        }
	    }
	    var ps = astNode.lowLevel().unit().absolutePath();
	    var dr = path.dirname(ps);
	    var customLinter = path.resolve(dr, "raml-lint.js");
	    lintWithFile(customLinter, acceptor, astNode);
	    var dir = path.resolve(dr, ".raml");
	    if (fs.existsSync(dir)) {
	        var st = fs.statSync(dir);
	        if (st.isDirectory()) {
	            var files = fs.readdirSync(dir);
	            files.forEach(function (x) {
	                if (x.indexOf("-lint.js") != -1) {
	                    lintWithFile(path.resolve(dir, x), acceptor, astNode);
	                }
	                //console.log(x);
	            });
	        }
	    }
	}
	;
	var LinterExtensionsImpl = (function () {
	    function LinterExtensionsImpl(acceptor) {
	        this.acceptor = acceptor;
	        this.nodes = {};
	    }
	    LinterExtensionsImpl.prototype.error = function (w, message) {
	        this.acceptor.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, message, w.highLevel()));
	    };
	    LinterExtensionsImpl.prototype.errorOnProperty = function (w, property, message) {
	        var pr = w.highLevel().attr(property);
	        this.acceptor.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, message, pr));
	    };
	    LinterExtensionsImpl.prototype.warningOnProperty = function (w, property, message) {
	        var pr = w.highLevel().attr(property);
	        this.acceptor.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, message, pr, true));
	    };
	    LinterExtensionsImpl.prototype.warning = function (w, message) {
	        this.acceptor.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, message, w.highLevel(), true));
	    };
	    LinterExtensionsImpl.prototype.registerRule = function (nodeType, rule) {
	        var q = this.nodes[nodeType];
	        if (!q) {
	            q = [];
	            this.nodes[nodeType] = q;
	        }
	        q.push(rule);
	    };
	    LinterExtensionsImpl.prototype.visit = function (h) {
	        var _this = this;
	        var nd = h.definition();
	        this.process(nd, h);
	        nd.allSuperTypes().forEach(function (x) { return _this.process(x, h); });
	        h.elements().forEach(function (y) { return _this.visit(y); });
	    };
	    LinterExtensionsImpl.prototype.process = function (d, h) {
	        var _this = this;
	        if (d instanceof def.NodeClass) {
	            if (!d.getAdapter(services.RAMLService).getDeclaringNode()) {
	                var rules = this.nodes[d.nameId()];
	                if (rules) {
	                    rules.forEach(function (x) { return x(h.wrapperNode(), _this); });
	                }
	            }
	        }
	    };
	    return LinterExtensionsImpl;
	}());
	var StackNode = (function () {
	    function StackNode() {
	    }
	    StackNode.prototype.toString = function () {
	        if (this.prev) {
	            return this.value + "." + this.prev.toString();
	        }
	        return this.value;
	    };
	    StackNode.prototype.last = function () {
	        if (this.prev) {
	            return this.prev.last();
	        }
	        return this;
	    };
	    return StackNode;
	}());
	function isTypeOrSchema(d) {
	    return d.nameId() == universes.Universe10.TypeDeclaration.properties.type.name || d.nameId() == universes.Universe10.TypeDeclaration.properties.schema.name;
	}
	function isExampleProp(d) {
	    if (!d.domain()) {
	        return;
	    }
	    if (d.domain().getAdapter(services.RAMLService).isUserDefined()) {
	        return false;
	    }
	    return (d.nameId() == universes.Universe10.TypeDeclaration.properties.example.name);
	}
	function isSecuredBy(d) {
	    if (!d.domain()) {
	        return;
	    }
	    if (d.domain().getAdapter(services.RAMLService).isUserDefined()) {
	        return false;
	    }
	    return (d.nameId() == universes.Universe08.MethodBase.properties.securedBy.name);
	}
	/**
	 * For descendants of templates returns template type. Returns null for all other nodes.
	 */
	function typeOfContainingTemplate(h) {
	    var declRoot = h;
	    while (true) {
	        if (declRoot.definition().getAdapter(services.RAMLService).isInlinedTemplates()) {
	            return declRoot.definition().nameId();
	        }
	        var np = declRoot.parent();
	        if (!np) {
	            break;
	        }
	        else {
	            declRoot = np;
	        }
	    }
	    return null;
	}
	function restrictUnknownNodeError(node) {
	    var parentNode = node.parent();
	    var issue = null;
	    var parentDef = parentNode.definition();
	    if (parentNode && parentDef instanceof def.UserDefinedClass) {
	        var parentProperty = parentNode.property();
	        if (universeHelpers.isIsProperty(parentProperty)
	            || universeHelpers.isTypeProperty(parentProperty)) {
	            var paramName = node.name();
	            if (exports.RESERVED_TEMPLATE_PARAMETERS[paramName] != null) {
	                //Handling reserved parameter names;
	                issue = createIssue(hl.IssueCode.INVALID_PROPERTY, "Invalid parameter name: " + paramName + " is reserved", node);
	            }
	            else {
	                issue = createIssue(hl.IssueCode.UNKNOWN_NODE, "Unused parameter: " + paramName, node);
	            }
	        }
	    }
	    if (!issue) {
	        var propName = node.name();
	        var universe08 = universeProvider("RAML08");
	        var isRAML08 = parentDef.universe().version() == universe08.version();
	        if (isRAML08) {
	            var parameterTypeName = universes.Universe08.Parameter.name;
	            var typeDeclarationTypeName = universes.Universe10.TypeDeclaration.name;
	            if (isRAML08 && parentDef.isAssignableFrom(parameterTypeName)) {
	                var possibleDefs = universe08.type(parameterTypeName).allSubTypes().filter(function (x) {
	                    return universes.Universe08[x.nameId()]['properties'][propName] != null;
	                });
	                var possibleDefsMap = {};
	                for (var i = 0; i < possibleDefs.length; i++) {
	                    var x = possibleDefs[i];
	                    if (possibleDefsMap[x.nameId()]) {
	                        continue;
	                    }
	                    var valueRequirements = x.valueRequirements();
	                    if (!(valueRequirements && valueRequirements.length != 0)) {
	                        continue;
	                    }
	                    var typeRquirements = valueRequirements.filter(function (x) { return x.name == 'type'; }).map(function (x) { return x.value; });
	                    if (typeRquirements.length == 0) {
	                        continue;
	                    }
	                    var runtimeName = typeRquirements[0];
	                    possibleDefsMap[x.nameId()] = runtimeName;
	                    x.allSubTypes().forEach(function (y) { return possibleDefs.push(y); });
	                }
	                var runtimeNames = Object.keys(possibleDefsMap).map(function (x) { return possibleDefsMap[x]; }).sort();
	                ;
	                if (runtimeNames.length > 0) {
	                    var namesStr = runtimeNames.map(function (x, i) {
	                        var x1 = "'" + x + "'";
	                        if (i == runtimeNames.length - 1) {
	                            return x1;
	                        }
	                        if (i == runtimeNames.length - 2) {
	                            return x1 + ' or ';
	                        }
	                        return x1 + ', ';
	                    }).join('');
	                    var message = "Property '" + propName + "' can only be used if type is " + namesStr;
	                    issue = createIssue(hl.IssueCode.ILLEGAL_PROPERTY, message, node);
	                }
	            }
	        }
	    }
	    return issue;
	}
	;
	function validateBasic(node, v, requiredOnly) {
	    if (requiredOnly === void 0) { requiredOnly = false; }
	    var parentNode = node.parent();
	    var llValue = node.lowLevel().value();
	    if (node.lowLevel()) {
	        if (node.lowLevel().keyKind() == yaml.Kind.MAP) {
	            v.accept(createIssue(hl.IssueCode.UNKNOWN_NODE, "Node key can not be map", node));
	        }
	        if (node.lowLevel().keyKind() == yaml.Kind.SEQ) {
	            if (llValue == null) {
	                var isPattern = false;
	                if (node.isElement()) {
	                    if (node.asElement().definition().isAssignableFrom(universes.Universe10.TypeDeclaration.name)) {
	                        isPattern = true;
	                    }
	                }
	                if (!isPattern) {
	                    v.accept(createIssue(hl.IssueCode.UNKNOWN_NODE, "Node key can not be sequence", node));
	                }
	            }
	        }
	        if (parentNode == null) {
	            node.lowLevel().errors().forEach(function (x) {
	                var ps = x.mark ? x.mark.position : 0;
	                var em = {
	                    code: hl.IssueCode.YAML_ERROR,
	                    message: x.message,
	                    node: null,
	                    start: ps,
	                    end: ps + 1,
	                    isWarning: false,
	                    path: node.lowLevel().unit() == node.root().lowLevel().unit() ? null : node.lowLevel().unit().path(),
	                    unit: node.lowLevel().unit()
	                };
	                v.accept(em);
	            });
	        }
	    }
	    // if (node.errorMessage){
	    //     v.accept(createIssue(hl.IssueCode.UNKNOWN_NODE, node.errorMessage, node));
	    //     return;
	    // }
	    if (node.isUnknown()) {
	        if (node.name().indexOf("<<") != -1) {
	            if (typeOfContainingTemplate(parentNode) != null) {
	                new TraitVariablesValidator().validateName(node, v);
	                return;
	            }
	        }
	        if (node.needSequence) {
	            v.accept(createIssue(hl.IssueCode.UNKNOWN_NODE, "node: " + node.name() + " should be wrapped in sequence", node));
	        }
	        if (node.needMap) {
	            v.accept(createIssue(hl.IssueCode.UNKNOWN_NODE, (node.knownProperty ? node.knownProperty.nameId() : "") + " should be a map in RAML 1.0", node));
	            return;
	        }
	        if (node.unresolvedRef) {
	            v.accept(createIssue(hl.IssueCode.UNKNOWN_NODE, "reference: " + llValue + " can not be resolved", node));
	        }
	        if (node.knownProperty) {
	            //if (!node.lowLevel().)
	            if (node.lowLevel().includeErrors().length == 0) {
	                if (typeOfContainingTemplate(parentNode)
	                    && util.startsWith(llValue, "<<")
	                    && util.endsWith(llValue, ">>")) {
	                    return;
	                }
	                if (node.name() == "body" && node.computedValue("mediaType")) {
	                    return;
	                }
	                if (node.lowLevel().value() != '~') {
	                    v.accept(createIssue(hl.IssueCode.UNKNOWN_NODE, "property " + node.name() + " can not have scalar value", node));
	                }
	            }
	        }
	        else {
	            var issue = restrictUnknownNodeError(node);
	            if (!issue) {
	                issue = createIssue(hl.IssueCode.UNKNOWN_NODE, "Unknown node: " + node.name(), node);
	            }
	            v.accept(issue);
	        }
	    }
	    if (node.markCh() && !node.allowRecursive()) {
	        if (!node.property()) {
	            return;
	        }
	        v.accept(createIssue(hl.IssueCode.UNKNOWN_NODE, "Recursive definition: " + node.name(), node));
	        return;
	    }
	    try {
	        node.directChildren().filter(function (child) {
	            return !requiredOnly || (child.property && child.property() && child.property().isRequired());
	        }).forEach(function (x) {
	            if (x.errorMessage) {
	                v.accept(createIssue(hl.IssueCode.UNKNOWN_NODE, x.errorMessage, x.name() ? x : node));
	                return;
	            }
	            x.validate(v);
	        });
	    }
	    finally {
	        node.unmarkCh();
	    }
	}
	exports.validateBasic = validateBasic;
	function hasTemplateArgs(node) {
	    var vl = node.value();
	    if (typeof vl == "string") {
	        if (vl.indexOf("<<") != -1) {
	            return true;
	        }
	    }
	    var x = node.children();
	    for (var i = 0; i < x.length; i++) {
	        if (hasTemplateArgs(x[i])) {
	            return true;
	        }
	    }
	    return false;
	}
	function validate(node, v) {
	    if (!node.parent()) {
	        try {
	            validateIncludes(node, v);
	        }
	        finally {
	            cleanupIncludesFlag(node, v);
	        }
	    }
	    if (node.isAttr()) {
	        new CompositePropertyValidator().validate(node, v);
	    }
	    else if (node.isElement()) {
	        var highLevelNode = node;
	        if (highLevelNode.definition().isAnnotationType() || highLevelNode.property() && highLevelNode.property().nameId() == "annotations") {
	            new FixedFacetsValidator().validate(highLevelNode, v);
	            return;
	        }
	        if (highLevelNode.definition().isAssignableFrom(universes.Universe10.UsesDeclaration.name)) {
	            var vn = highLevelNode.attr(universes.Universe10.UsesDeclaration.properties.value.name);
	            if (vn && vn.value()) {
	                var rs = highLevelNode.lowLevel().unit().resolve(vn.value());
	                if (!rs) {
	                    v.accept(createIssue(hl.IssueCode.UNRESOLVED_REFERENCE, "Can not resolve library from path:" + vn.value(), highLevelNode, false));
	                }
	                else {
	                    var issues = [];
	                    rs.highLevel().validate({
	                        begin: function () {
	                        },
	                        accept: function (x) {
	                            issues.push(x);
	                        },
	                        end: function () {
	                        }
	                    });
	                    if (issues.length > 0) {
	                        var brand = createIssue(hl.IssueCode.UNRESOLVED_REFERENCE, "Issues in the used library:" + vn.value(), highLevelNode, false);
	                        issues.forEach(function (x) { x.unit = rs; x.path = rs.absolutePath(); });
	                        brand.extras = issues;
	                        v.accept(brand);
	                    }
	                }
	            }
	        }
	        if (highLevelNode.definition().isAssignableFrom(universes.Universe10.TypeDeclaration.name)) {
	            if (typeOfContainingTemplate(highLevelNode)) {
	                if (hasTemplateArgs(highLevelNode.lowLevel())) {
	                    return;
	                }
	            }
	            highLevelNode.attrs().forEach(function (a) {
	                var range = a.property().range().key();
	                if (range == universes.Universe08.RelativeUriString || range == universes.Universe10.RelativeUriString) {
	                    new UriValidator().validate(a, v);
	                    return;
	                }
	                if (range == universes.Universe08.FullUriTemplateString || range == universes.Universe10.FullUriTemplateString) {
	                    new UriValidator().validate(a, v);
	                    return;
	                }
	                if (a.property().getAdapter(services.RAMLPropertyService).isKey()) {
	                    var nameId = node.property() && node.property().nameId();
	                    if (nameId == universes.Universe08.Resource.properties.uriParameters.name
	                        || nameId == universes.Universe08.Resource.properties.baseUriParameters.name) {
	                        //new UrlParameterNameValidator().validate(a, v);
	                        return;
	                    }
	                    if (highLevelNode.property()) {
	                        if (highLevelNode.property().nameId() ==
	                            universes.Universe10.MethodBase.properties.body.name) {
	                            new MediaTypeValidator().validate(a, v);
	                            return;
	                        }
	                    }
	                }
	            });
	            if (highLevelNode.parent() && !highLevelNode.parent().parent()) {
	                if (rtypes.builtInTypes().get(highLevelNode.name())) {
	                    v.accept(createIssue(hl.IssueCode.ILLEGAL_PROPERTY_VALUE, "redefining a built in type:" + highLevelNode.name(), highLevelNode));
	                }
	            }
	            new RecurrentOverlayValidator().validate(highLevelNode, v);
	            new RecurrentValidateChildrenKeys().validate(highLevelNode, v);
	            new NodeSpecificValidator().validate(highLevelNode, v);
	            new TypeDeclarationValidator().validate(highLevelNode, v);
	            return;
	        }
	        if (highLevelNode.definition().isAssignableFrom(universes.Universe10.LibraryBase.name)) {
	            var hasSchemas = false;
	            var hasTypes = false;
	            var vv;
	            highLevelNode.lowLevel().children().forEach(function (x) {
	                if (x.key() == "schemas") {
	                    hasSchemas = true;
	                    vv = x;
	                }
	                if (x.key() == "types") {
	                    hasTypes = true;
	                }
	            });
	            if (hasSchemas && hasTypes) {
	                v.accept(localLowLevelError(vv, highLevelNode, hl.IssueCode.ILLEGAL_PROPERTY_VALUE, false, "types and schemas are mutually exclusive", false));
	            }
	        }
	        var hasRequireds = highLevelNode.definition().requiredProperties() && highLevelNode.definition().requiredProperties().length > 0;
	        var isAllowAny = highLevelNode.definition().getAdapter(services.RAMLService).getAllowAny();
	        if (isAllowAny) {
	            if (hasRequireds) {
	                validateBasic(node, v, true);
	            }
	        }
	        else {
	            validateBasic(node, v);
	        }
	        new UriParametersValidator().validate(highLevelNode, v);
	        new CompositeNodeValidator().validate(highLevelNode, v);
	        new TemplateCyclesDetector().validate(highLevelNode, v);
	    }
	    else {
	        validateBasic(node, v);
	    }
	    new OptionalPropertiesValidator().validate(node, v);
	}
	exports.validate = validate;
	function cleanupIncludesFlag(node, v) {
	    var val = node.lowLevel().actual();
	    delete val._inc;
	    node.children().forEach(function (x) { return cleanupIncludesFlag(x, v); });
	}
	function validateIncludes(node, v) {
	    var val = node.lowLevel().actual();
	    if (val._inc) {
	        return;
	    }
	    if (node.isElement()) {
	        var vl = node.name();
	        if (typeof vl == "string") {
	            if (vl != null && vl.indexOf(" ") != -1) {
	                v.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, "Keys should not have spaces '" + vl + "'", node, true));
	            }
	        }
	    }
	    val._inc = true;
	    if (node.lowLevel()) {
	        node.lowLevel().includeErrors().forEach(function (x) {
	            var isWarn = false;
	            if (node.lowLevel().hasInnerIncludeError()) {
	                isWarn = true;
	            }
	            var em = createIssue(hl.IssueCode.UNABLE_TO_RESOLVE_INCLUDE_FILE, x, node, isWarn);
	            v.accept(em);
	        });
	    }
	    node.children().forEach(function (x) { return validateIncludes(x, v); });
	}
	var validateRegexp = function (cleanedValue, v, node) {
	    try {
	        new RegExp(cleanedValue);
	    }
	    catch (Error) {
	        v.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, "Illegal pattern " + cleanedValue, node));
	    }
	};
	var TraitVariablesValidator = (function () {
	    function TraitVariablesValidator() {
	    }
	    TraitVariablesValidator.prototype.validateName = function (node, acceptor) {
	        var name = node.name();
	        if (name) {
	            var start = node.lowLevel().keyStart();
	            this.check(name, start, node, acceptor);
	        }
	    };
	    TraitVariablesValidator.prototype.validateValue = function (node, acceptor) {
	        var value = node.value();
	        if (typeof (value) === 'string') {
	            var start = node.lowLevel().valueStart();
	            this.check(value, start, node, acceptor);
	        }
	    };
	    TraitVariablesValidator.prototype.check = function (str, start, node, acceptor) {
	        var errors = [];
	        var prev = 0;
	        for (var i = str.indexOf('<<'); i >= 0; i = str.indexOf('<<', prev)) {
	            var i0 = i;
	            i += '<<'.length;
	            prev = str.indexOf('>>', i);
	            var paramOccurence = str.substring(i, prev);
	            var ind = paramOccurence.lastIndexOf('|');
	            var paramName = ind >= 0 ? paramOccurence.substring(0, ind) : paramOccurence;
	            if (paramName.trim().length == 0) {
	                var msg = "Trait or resource type parameter name must contain non whitespace characters";
	                var issue = createIssue(hl.IssueCode.ILLEGAL_PROPERTY_VALUE, msg, node, false);
	                issue.start = start + i;
	                issue.end = start + prev;
	                acceptor.accept(issue);
	            }
	            if (ind != -1) {
	                ind++;
	                var transformerName = paramOccurence.substring(ind).trim();
	                var functionNames = expander.getTransformNames();
	                if (!_.find(functionNames, function (functionName) {
	                    return transformerName === functionName || transformerName === ('!' + functionName);
	                })) {
	                    var msg = "Unknown function applied to parameter: " + transformerName;
	                    var issue = createIssue(hl.IssueCode.ILLEGAL_PROPERTY_VALUE, msg, node, false);
	                    issue.start = start + ind;
	                    issue.end = start + prev;
	                    acceptor.accept(issue);
	                }
	            }
	            prev += '>>'.length;
	        }
	        return errors;
	    };
	    return TraitVariablesValidator;
	}());
	var MethodBodyValidator = (function () {
	    function MethodBodyValidator() {
	    }
	    MethodBodyValidator.prototype.validate = function (node, validationAcceptor) {
	        var methodNode = node.parent();
	        if (!methodNode) {
	            return;
	        }
	        if (!(methodNode.definition().isAssignableFrom(universes.Universe08.Method.name) || methodNode.definition().isAssignableFrom(universes.Universe10.Method.name))) {
	            return;
	        }
	        var hasBody = _.find(methodNode.lowLevel() && methodNode.lowLevel().children() || [], function (child) {
	            var keyValue = child.key();
	            return keyValue && (universes.Universe08.MethodBase.properties.body.name === keyValue || universes.Universe10.MethodBase.properties.body.name === keyValue);
	        });
	        if (hasBody && _.find(MethodBodyValidator.methodsWithoutRequestBody, function (methodDisabled) { return methodNode.name() === methodDisabled; })) {
	            validationAcceptor.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, 'Request body is disabled for "' + methodNode.name() + '" method.', methodNode));
	        }
	    };
	    MethodBodyValidator.methodsWithoutRequestBody = ['trace'];
	    return MethodBodyValidator;
	}());
	var CompositePropertyValidator = (function () {
	    function CompositePropertyValidator() {
	    }
	    CompositePropertyValidator.prototype.validate = function (node, v) {
	        var pr = checkPropertyQuard(node, v);
	        var vl = node.value();
	        if (!node.property().range().hasStructure()) {
	            if (vl instanceof hlimpl.StructuredValue && !node.property().isSelfNode()) {
	                //TODO THIS SHOULD BE MOVED TO TYPESYSTEM FOR STS AT SOME MOMENT
	                if (isTypeOrSchema(node.property())) {
	                    if (node.property().domain().key() == universes.Universe08.BodyLike) {
	                        var structValue = vl;
	                        var newNode = new hlimpl.ASTNodeImpl(node.lowLevel(), node.parent(), node.parent().definition().universe().type(universes.Universe08.BodyLike.name), node.property());
	                        newNode.validate(v);
	                        return;
	                    }
	                }
	                if (node.parent().definition().universe().version() == "RAML10"
	                    && typeOfContainingTemplate(node.parent()) != null) {
	                    return;
	                }
	                v.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, "Scalar is expected here", node));
	            }
	            else {
	                var vk = node.lowLevel().valueKind();
	                if (node.lowLevel().valueKind() != yaml.Kind.INCLUDE_REF && !node.property().getAdapter(services.RAMLPropertyService).isKey()) {
	                    if ((!node.property().isMultiValue())) {
	                        var k = node.property().range().key();
	                        if (k == universes.Universe08.StringType || k == universes.Universe08.MarkdownString || k == universes.Universe08.MimeType) {
	                            if (vk == yaml.Kind.SEQ || vk == yaml.Kind.MAPPING || vk == yaml.Kind.MAP || ((node.property().isRequired() || node.property().nameId() == "mediaType") && (vk == null || vk === undefined))) {
	                                if (!node.property().domain().getAdapter(services.RAMLService).isInlinedTemplates()) {
	                                    v.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, "property '" + node.name() + "' must be a string", node));
	                                }
	                            }
	                        }
	                    }
	                }
	            }
	            if (node.isAnnotatedScalar()) {
	                var fvl = new FixedFacetsValidator();
	                node.annotations().forEach(function (x) {
	                    var vl = x.value();
	                    var highLevel = vl.toHighLevel();
	                    if (!highLevel) {
	                        v.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, "unknown annotation " + vl.valueName(), x));
	                    }
	                    else {
	                        fvl.validate(highLevel, v);
	                    }
	                });
	            }
	        }
	        if (typeof vl == 'string' && vl.indexOf("<<") != -1) {
	            if (vl.indexOf(">>") > vl.indexOf("<<")) {
	                new TraitVariablesValidator().validateValue(node, v);
	                if (typeOfContainingTemplate(node.parent()) != null) {
	                    return;
	                }
	            }
	        }
	        new MethodBodyValidator().validate(node, v);
	        if ((node.property().range().key() == universes.Universe08.MimeType ||
	            node.property().range().key() == universes.Universe10.MimeType) ||
	            (node.property().nameId() == universes.Universe10.TypeDeclaration.properties.name.name
	                && node.parent().property().nameId() ==
	                    universes.Universe10.MethodBase.properties.body.name)) {
	            new MediaTypeValidator().validate(node, v);
	            return;
	        }
	        if (isExampleProp(node.property())) {
	            if (node.definition().universe().version() == "RAML08") {
	                var llv = node.lowLevel().value();
	                if (node.lowLevel().children().length > 0) {
	                    v.accept(createIssue(hl.IssueCode.ILLEGAL_PROPERTY_VALUE, "example should be a string", node, false));
	                }
	            }
	            new ExampleValidator().validate(node, v);
	        }
	        if (isSecuredBy(node.property())) {
	            if (node.definition().universe().version() == "RAML08") {
	                var np = node.lowLevel().parent();
	                var ysc = yaml.Kind.SEQ;
	                var msg = "`securedBy` should be a list in RAML08";
	                if (node.lowLevel() instanceof proxy.LowLevelProxyNode) {
	                    if (np.valueKind() != ysc) {
	                        v.accept(createIssue(hl.IssueCode.ILLEGAL_PROPERTY_VALUE, msg, node, false));
	                    }
	                }
	                else {
	                    if (np.kind() != ysc) {
	                        v.accept(createIssue(hl.IssueCode.ILLEGAL_PROPERTY_VALUE, msg, node, false));
	                    }
	                }
	            }
	            new ExampleValidator().validate(node, v);
	        }
	        if (node.property().nameId() == universes.Universe10.TypeDeclaration.properties.name.name) {
	            //TODO MOVE TO DEF SYSTEM
	            var nameId = node.parent().property() && node.parent().property().nameId();
	            if (nameId == universes.Universe08.Resource.properties.uriParameters.name
	                || nameId == universes.Universe08.Resource.properties.baseUriParameters.name) {
	                //                    new UrlParameterNameValidator().validate(node, v);
	                return;
	            }
	        }
	        var range = node.property().range().key();
	        if (range == universes.Universe08.RelativeUriString || range == universes.Universe10.RelativeUriString) {
	            new UriValidator().validate(node, v);
	            return;
	        }
	        if (range == universes.Universe08.FullUriTemplateString || range == universes.Universe10.FullUriTemplateString) {
	            new UriValidator().validate(node, v);
	            return;
	        }
	        if ("pattern" == node.name() && universes.Universe10.StringType == node.definition().key()
	            && node.parent().definition().isAssignableFrom("StringTypeDeclaration")) {
	            validateRegexp(node.value(), v, node);
	        }
	        if ("name" == node.name() && universes.Universe10.StringType == node.definition().key()
	            && (typeof node.value() == "string")
	            && node.value().indexOf("[") == 0
	            && node.value().lastIndexOf("]") == node.value().length - 1) {
	            if (node.parent() instanceof hlimpl.ASTNodeImpl &&
	                universes.Universe10.ObjectTypeDeclaration.properties.properties.name == node.parent().property().nameId()) {
	                if (node.parent().parent() instanceof hlimpl.ASTNodeImpl &&
	                    universes.Universe10.ObjectTypeDeclaration == node.parent().parent().definition().key()) {
	                    var cleanedValue = node.value().substr(1, node.value().length - 2);
	                    validateRegexp(cleanedValue, v, node);
	                }
	            }
	        }
	        if (pr.isReference() || pr.isDescriminator()) {
	            new DescriminatorOrReferenceValidator().validate(node, v);
	        }
	        else {
	            new NormalValidator().validate(node, v);
	        }
	    };
	    return CompositePropertyValidator;
	}());
	function isValid(t, h, value, p, attr) {
	    if (t.hasArrayInHierarchy()) {
	        return isValidArray(t, h, value, p, attr);
	    }
	    else if (t.hasValueTypeInHierarchy()) {
	        return isValidValueType(t, h, value, p, attr);
	    }
	    return true;
	}
	exports.isValid = isValid;
	function isValidArray(t, h, v, p, attr) {
	    if (t.arrayInHierarchy().componentType()) {
	        return isValid(t.arrayInHierarchy().componentType(), h, v, p);
	    }
	    return true;
	}
	function isValidValueType(t, h, v, p, attr) {
	    //FIXME
	    try {
	        if (t.key() == universes.Universe10.AnnotationRef) {
	            var targets = search.referenceTargets(p, h);
	            var actualAnnotation = _.find(targets, function (x) { return hlimpl.qName(x, h) == v; });
	            if (actualAnnotation != null) {
	                var attrs = actualAnnotation.attributes("allowedTargets");
	                if (attrs) {
	                    var aVals = attrs.map(function (x) { return x.value(); });
	                    if (aVals.length > 0) {
	                        var found = false;
	                        //no we should actually check that we are applying annotation properly
	                        var tps = h.definition().allSuperTypes();
	                        tps = tps.concat([h.definition()]);
	                        var tpNames = tps.map(function (x) { return x.nameId(); });
	                        aVals.forEach(function (x) {
	                            //FIXME this is deeply wrong code
	                            if (x == "API") {
	                                x = "Api";
	                            }
	                            if (x == "NamedExample") {
	                                x = "ExampleSpec";
	                            }
	                            if (x == "SecurityScheme") {
	                                x = "AbstractSecurityScheme";
	                            }
	                            if (x == "SecuritySchemeSettings") {
	                                x = "SecuritySchemeSettings";
	                            }
	                            if (_.find(tpNames, function (y) { return y == x; })) {
	                                found = true;
	                            }
	                            else {
	                                if (x == "Parameter") {
	                                    if (h.computedValue("location")) {
	                                        found = true;
	                                    }
	                                }
	                                if (x == "Field") {
	                                    if (h.computedValue("field")) {
	                                        found = true;
	                                    }
	                                }
	                            }
	                        });
	                        if (!found) {
	                            return new Error("annotation " + v + " can not be placed at this location, allowed targets are:" + aVals);
	                        }
	                    }
	                }
	            }
	            return tm;
	        }
	        if (t.key() == universes.Universe08.SchemaString || t.key() == universes.Universe10.SchemaString) {
	            var tm = su.createSchema(v, new contentprovider.ContentProvider(h.lowLevel().unit()));
	            if (tm instanceof Error) {
	                tm.canBeRef = true;
	            }
	            return tm;
	        }
	        if (t.key() == universes.Universe08.StatusCodeString || t.key() == universes.Universe10.StatusCodeString) {
	            var err = validateResponseString(v);
	            if (err != null) {
	                return err;
	            }
	        }
	        if (t.key() == universes.Universe08.BooleanType || t.isAssignableFrom(universes.Universe10.BooleanType.name)) {
	            if (!(v === 'true' || v === 'false' || v === true || v === false)) {
	                return new Error("'true' or 'false' is expected here");
	            }
	            if (attr) {
	                var stringValue = attr.lowLevel().value(true);
	                if (!(stringValue === 'true' || stringValue === 'false')) {
	                    return new Error("'true' or 'false' is expected here");
	                }
	            }
	        }
	        if (t.key() == universes.Universe08.NumberType || t.isAssignableFrom(universes.Universe10.NumberType.name)) {
	            var q = parseFloat(v);
	            if (isNaN(q)) {
	                return new Error("the value of " + p.nameId() + " must be a number");
	            }
	        }
	        if (t.key() == universes.Universe08.StringType || t.isAssignableFrom(universes.Universe10.StringType.name)) {
	            if (v === null) {
	                //checking if there is at least something in the node.
	                //We have many tests and APIs with the text like 'propertyName:' without a value. I do not know if such cases are
	                //actually valid, but not reporting this for now.
	                if (h && p) {
	                    var highLevelProperty = h.attr(p.nameId());
	                    if (highLevelProperty) {
	                        var lowLevelChildren = highLevelProperty.lowLevel().children();
	                        if (lowLevelChildren && lowLevelChildren.length > 0) {
	                            return new Error(p.nameId() + " must be a string");
	                        }
	                    }
	                }
	            }
	        }
	        return true;
	    }
	    catch (e) {
	        e.canBeRef = true; //FIXME
	        return e;
	    }
	}
	var NormalValidator = (function () {
	    function NormalValidator() {
	    }
	    NormalValidator.prototype.validate = function (node, cb) {
	        var vl = node.value();
	        var pr = node.property();
	        var range = pr.range();
	        var dnode = range.getAdapter(services.RAMLService).getDeclaringNode();
	        if (dnode && range.isUserDefined()) {
	            var rof = dnode.parsedType();
	            var dp = node.parent().lowLevel().dumpToObject();
	            var tempVal = dp[node.parent().name()];
	            var isVal = pr.canBeValue();
	            var val = (isVal || (tempVal === null || tempVal === undefined)) ? tempVal : tempVal[pr.nameId()];
	            var validateObject = rof.validate(val, true);
	            if (!validateObject.isOk()) {
	                validateObject.getErrors().forEach(function (e) { return cb.accept(createIssue(hl.IssueCode.ILLEGAL_PROPERTY_VALUE, e.getMessage(), node, false)); });
	            }
	        }
	        var v = cb;
	        if (node.lowLevel().keyKind() != yaml.Kind.SEQ) {
	            var validation = isValid(pr.range(), node.parent(), vl, pr, node);
	        }
	        else {
	            validation = true;
	        }
	        if (validation instanceof Error) {
	            if (!validation.canBeRef) {
	                v.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, validation.message, node));
	                validation = null;
	                return;
	            }
	        }
	        if (!validation || validation instanceof Error) {
	            if (pr.nameId() != 'value') {
	                if (!checkReference(pr, node, vl, v)) {
	                    if (pr.nameId() == universes.Universe10.TypeDeclaration.properties.schema.name
	                        || universes.Universe10.TypeDeclaration.properties.type.name) {
	                        if (vl && vl.trim() && (pr.domain().key() == universes.Universe08.BodyLike
	                            || pr.domain().key() == universes.Universe10.TypeDeclaration)) {
	                            var testSchema = vl.trim().charAt(0); //FIXME
	                            if (testSchema != '{' && testSchema != '<') {
	                                return;
	                            }
	                        }
	                    }
	                    var decl = node.findReferencedValue();
	                    if (decl instanceof Error) {
	                        v.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, decl.message, node));
	                    }
	                    if (!decl) {
	                        if (vl) {
	                            if (pr.nameId() == universes.Universe10.TypeDeclaration.properties.schema.name) {
	                                var z = vl.trim();
	                                if (z.charAt(0) != '{' && z.charAt(0) != '<') {
	                                    if (vl.indexOf('|') != -1 || vl.indexOf('[]') != -1 || vl.indexOf("(") != -1) {
	                                        return;
	                                    }
	                                }
	                            }
	                        }
	                        if (validation instanceof Error && vl) {
	                            v.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, validation.message, node));
	                            validation = null;
	                            return;
	                        }
	                        if (node.property().isRequired() && node.value() == null) {
	                            v.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, "Empty value is not allowed here", node));
	                        }
	                        else {
	                            var ck = node.lowLevel().valueKind();
	                            if (ck == yaml.Kind.MAP || ck == yaml.Kind.SEQ || ck == yaml.Kind.MAPPING) {
	                                v.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, "Empty value is not allowed here", node));
	                            }
	                        }
	                    }
	                }
	            }
	            else {
	                var vl = node.value();
	                var message = "Invalid value schema:" + vl;
	                if (validation instanceof Error) {
	                    message = validation.message;
	                }
	                v.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, message, node, pr.range().key() == universes.Universe08.SchemaString));
	            }
	        }
	        var values = pr.enumOptions();
	        if (values) {
	            if (typeof vl !== 'string') {
	                return;
	            }
	            if (typeof values == 'string') {
	                if (values != vl) {
	                    if (vl && (vl.indexOf("x-") == 0) && pr.nameId() == universes.Universe08.AbstractSecurityScheme.properties.type.name) {
	                    }
	                    else {
	                        v.accept(createIssue(hl.IssueCode.UNRESOLVED_REFERENCE, "Invalid value:" + vl + " allowed values are:" + values, node));
	                    }
	                }
	            }
	            else if (values.length > 0) {
	                if (!_.find(values, function (x) { return x == vl; })) {
	                    if (vl && (vl.indexOf("x-") == 0) && pr.nameId() == universes.Universe08.AbstractSecurityScheme.properties.type.name) {
	                    }
	                    else {
	                        v.accept(createIssue(hl.IssueCode.UNRESOLVED_REFERENCE, "Invalid value:" + vl + " allowed values are:" + values.join(","), node));
	                    }
	                }
	            }
	        }
	    };
	    return NormalValidator;
	}());
	var UriValidator = (function () {
	    function UriValidator() {
	    }
	    UriValidator.prototype.validate = function (node, cb) {
	        try {
	            var values = new UrlParameterNameValidator().parseUrl(node.value());
	            if (values.some(function (x) { return x == "version"; }) && node.property().nameId() == "baseUri") {
	                var version = node.root().attr("version");
	                if (!version) {
	                    cb.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, "missing version", node, false));
	                }
	            }
	            if (values.some(function (x) { return x.length == 0; })) {
	                cb.accept(createIssue(hl.IssueCode.ILLEGAL_PROPERTY_VALUE, "URI parameter must have name specified", node, false));
	            }
	        }
	        catch (e) {
	            cb.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, e.message, node, false));
	        }
	    };
	    return UriValidator;
	}());
	var MediaTypeValidator = (function () {
	    function MediaTypeValidator() {
	    }
	    MediaTypeValidator.prototype.validate = function (node, cb) {
	        try {
	            var v = node.value();
	            if (!v) {
	                return;
	            }
	            if (v == "*/*") {
	                return;
	            }
	            if (v.indexOf("/*") == v.length - 2) {
	                v = v.substring(0, v.length - 2) + "/xxx";
	            }
	            if (node.parent() && node.parent().parent() && node.parent().parent().definition().isAssignableFrom(universes.Universe10.Trait.name)) {
	                if (v.indexOf("<<") >= 0) {
	                    return;
	                }
	            }
	            if (v == "body") {
	                if (node.parent().parent()) {
	                    var ppc = node.parent().parent().definition().key();
	                    if (ppc === universes.Universe08.Response || ppc === universes.Universe10.Response ||
	                        node.parent().parent().definition().isAssignableFrom(universes.Universe10.MethodBase.name)) {
	                        v = node.parent().computedValue("mediaType");
	                    }
	                }
	            }
	            var res = mediaTypeParser.parse(v);
	            var types = {
	                application: 1,
	                audio: 1,
	                example: 1,
	                image: 1,
	                message: 1,
	                model: 1,
	                multipart: 1,
	                text: 1,
	                video: 1,
	                binary: 1
	            };
	            if (!types[res.type]) {
	                cb.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, "Unknown media type 'type'", node));
	            }
	        }
	        catch (e) {
	            cb.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, "" + e.message, node));
	        }
	        if (node.value() && node.value() == ("multipart/form-data") || node.value() == ("application/x-www-form-urlencoded")) {
	            if (node.parent() && node.parent().parent() && node.parent().parent().property()) {
	                if (node.parent().parent().property().nameId() == universes.Universe10.MethodBase.properties.responses.name) {
	                    cb.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, "Form related media types can not be used in responses", node, true));
	                }
	            }
	        }
	        return;
	    };
	    return MediaTypeValidator;
	}());
	//class SignatureValidator implements PropertyValidator{
	//    validate(node:hl.IAttribute,cb:hl.ValidationAcceptor){
	//        var vl=node.value();
	//        var q = vl?vl.trim():"";
	//        if (q.length > 0 ) {
	//            try {
	//                //ramlSignature.validate(vl, node, cb);
	//            }catch (e){
	//                cb.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA,"Error during signature parse:"+e.message,node))
	//            }
	//            return;
	//        }
	//        return;
	//    }
	//}
	var UrlParameterNameValidator = (function () {
	    function UrlParameterNameValidator() {
	    }
	    UrlParameterNameValidator.prototype.checkBaseUri = function (node, c, vl, v) {
	        var bu = c.root().attr("baseUri");
	        if (bu) {
	            var tnv = bu.value();
	            try {
	                var pNames = this.parseUrl(tnv);
	                if (!_.find(pNames, function (x) { return x == vl; })) {
	                    v.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, "Unused url parameter", node));
	                }
	            }
	            catch (e) {
	            }
	        }
	        else {
	            v.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, "Unused url parameter", node));
	        }
	    };
	    UrlParameterNameValidator.prototype.parseUrl = function (value) {
	        var result = [];
	        var temp = "";
	        var inPar = false;
	        var count = 0;
	        for (var a = 0; a < value.length; a++) {
	            var c = value[a];
	            if (c == '{') {
	                count++;
	                inPar = true;
	                continue;
	            }
	            if (c == '}') {
	                count--;
	                inPar = false;
	                result.push(temp);
	                temp = "";
	                continue;
	            }
	            if (inPar) {
	                temp += c;
	            }
	        }
	        if (count > 0) {
	            throw new Error("Unmatched '{'");
	        }
	        if (count < 0) {
	            throw new Error("Unmatched '}'");
	        }
	        return result;
	    };
	    UrlParameterNameValidator.prototype.validate = function (node, cb) {
	        var vl = node.value();
	        if (node.parent().property().nameId() == universes.Universe10.Api.properties.baseUri.name) {
	            var c = node.parent().parent();
	            this.checkBaseUri(node, c, vl, cb);
	            return;
	        }
	        var c = node.parent().parent();
	        var tn = c.name();
	        if (c.definition().key() === universes.Universe10.Api ||
	            c.definition().key() === universes.Universe08.Api) {
	            this.checkBaseUri(node, c, vl, cb);
	            return;
	        }
	        if (c.definition().key() == universes.Universe10.ResourceType ||
	            c.definition().key() == universes.Universe08.ResourceType) {
	            return;
	        }
	        try {
	            var pNames = this.parseUrl(tn);
	            var foundInLocalParameters = _.find(pNames, function (x) { return x == vl; });
	            if (!foundInLocalParameters) {
	                var baseUri = node.root().attr(universes.Universe10.Api.properties.baseUri.name);
	                if (baseUri && node.name() === universes.Universe08.Api.properties.baseUriParameters.name) {
	                    var baseUriValue = baseUri.value();
	                    if (baseUriValue) {
	                        pNames = this.parseUrl(baseUriValue);
	                        if (pNames && pNames.length > 0) {
	                            if (_.find(pNames, function (x) { return x == vl; }))
	                                return;
	                        }
	                    }
	                }
	                cb.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, "Unused url parameter '" + vl + "'", node));
	            }
	        }
	        catch (e) {
	        }
	    };
	    return UrlParameterNameValidator;
	}());
	exports.UrlParameterNameValidator = UrlParameterNameValidator;
	//TODO this should be probably moved to a more general file/module
	exports.typeToName = {};
	exports.typeToName[universes.Universe08.Trait.name] = "trait";
	exports.typeToName[universes.Universe08.ResourceType.name] = "resource type";
	exports.typeToName[universes.Universe10.Trait.name] = "trait";
	exports.typeToName[universes.Universe10.ResourceType.name] = "resource type";
	exports.typeToName[universes.Universe10.AbstractSecurityScheme.name] = "security scheme";
	exports.typeToName[universes.Universe10.Method.name] = "method";
	exports.typeToName[universes.Universe08.Method.name] = "method";
	exports.typeToName[universes.Universe10.Resource.name] = "resource";
	exports.typeToName[universes.Universe08.Resource.name] = "resource";
	exports.typeToName[universes.Universe10.Api.name] = "api";
	exports.typeToName[universes.Universe08.Api.name] = "api";
	exports.typeToName[universes.Universe10.Response.name] = "response";
	exports.typeToName[universes.Universe08.Response.name] = "response";
	exports.typeToName[universes.Universe08.BodyLike.name] = "body";
	exports.parameterPropertyToName = {};
	exports.parameterPropertyToName[universes.Universe08.MethodBase.properties.headers.name] = "header";
	exports.parameterPropertyToName[universes.Universe08.MethodBase.properties.queryParameters.name] = "query parameter";
	exports.parameterPropertyToName[universes.Universe08.Api.properties.uriParameters.name] = "uri parameter";
	exports.parameterPropertyToName[universes.Universe08.Api.properties.baseUriParameters.name] = "base uri parameter";
	exports.parameterPropertyToName[universes.Universe08.BodyLike.properties.formParameters.name] = "form parameter";
	exports.parameterPropertyToName[universes.Universe10.MethodBase.properties.headers.name] = "header";
	exports.parameterPropertyToName[universes.Universe10.MethodBase.properties.queryParameters.name] = "query parameter";
	exports.parameterPropertyToName[universes.Universe10.ResourceBase.properties.uriParameters.name] = "uri parameter";
	exports.parameterPropertyToName[universes.Universe10.Api.properties.baseUriParameters.name] = "base uri parameter";
	exports.parameterPropertyToName[universes.Universe10.MethodBase.properties.body.name] = "body";
	function getHumanReadableNodeName(astNode) {
	    if (!astNode)
	        return null;
	    if (astNode.isElement()) {
	        var element = astNode;
	        var definition = element.definition();
	        if (definition && exports.typeToName.hasOwnProperty(definition.nameId())) {
	            return exports.typeToName[definition.nameId()];
	        }
	        if (definition.isAssignableFrom(universes.Universe10.TypeDeclaration.name) ||
	            definition.isAssignableFrom(universes.Universe08.Parameter.name)) {
	            if (element.property() && exports.parameterPropertyToName.hasOwnProperty(element.property().nameId())) {
	                return exports.parameterPropertyToName[element.property().nameId()];
	            }
	            if (element.property() && element.parent() &&
	                element.property().nameId() == universes.Universe10.LibraryBase.properties.types.name &&
	                element.parent().definition() && element.parent().definition().isAssignableFrom(universes.Universe10.LibraryBase.name)) {
	                return "type";
	            }
	            if (element.property() && element.parent() &&
	                element.property().nameId() == universes.Universe10.LibraryBase.properties.securitySchemes.name &&
	                element.parent().definition() && element.parent().definition().isAssignableFrom(universes.Universe10.LibraryBase.name)) {
	                return "security scheme";
	            }
	        }
	    }
	    return null;
	}
	exports.getHumanReadableNodeName = getHumanReadableNodeName;
	function isValidPropertyValue(pr, vl, c) {
	    var node = search.declRoot(c);
	    if (!node._cach) {
	        node._cach = {};
	    }
	    var id = pr.id();
	    if (pr.domain()) {
	        id += pr.domain().nameId();
	    }
	    if (id) {
	        var cached = node._cach[id];
	        if (cached) {
	            return cached[vl] != null;
	        }
	    }
	    var vls = search.enumValues(pr, c);
	    var mm = {};
	    vls.forEach(function (x) { return mm[x] = 1; });
	    if (pr.id()) {
	        node._cach[id] = mm;
	    }
	    return mm[vl] != null;
	}
	function checkReference(pr, astNode, vl, cb) {
	    checkTraitReference(pr, astNode, cb);
	    checkResourceTypeReference(pr, astNode, cb);
	    if (!vl) {
	        return;
	    }
	    if (vl == 'null') {
	        if (pr.isAllowNull()) {
	            return;
	        }
	    }
	    var adapter = pr.getAdapter(services.RAMLPropertyService);
	    var valid = isValidPropertyValue(pr, vl, astNode.parent());
	    if (!valid && astNode.lowLevel().unit().absolutePath() !== astNode.parent().lowLevel().unit().absolutePath()) {
	        valid = isValidPropertyValue(pr, vl, hlimpl.fromUnit(astNode.lowLevel().unit()));
	    }
	    if (!valid) {
	        if (typeof vl == 'string') {
	            if ((vl.indexOf("x-") == 0) && pr.nameId() == universes.Universe10.TypeDeclaration.properties.type.name) {
	                return true;
	            }
	        }
	        var expected = (adapter.isReference && adapter.isReference() && adapter.referencesTo && adapter.referencesTo() && adapter.referencesTo().nameId && adapter.referencesTo().nameId());
	        var referencedToName = exports.typeToName[expected] || nameForNonReference(astNode);
	        var message = referencedToName ? ("Unrecognized " + referencedToName + " '" + vl + "'.") : ("Unresolved reference: " + vl);
	        var spesializedMessage = specializeReferenceError(message, pr, astNode);
	        cb.accept(createIssue(hl.IssueCode.UNRESOLVED_REFERENCE, spesializedMessage, astNode, pr.range().key() === universes.Universe08.SchemaString));
	        return true;
	    }
	    if (isDuplicateSibling(astNode) && universeHelpers.isTraitRefType(astNode.definition())) {
	        var message = "Duplicate trait reference '" + vl + "'.";
	        var spesializedMessage = specializeReferenceError(message, pr, astNode);
	        cb.accept(createIssue(hl.IssueCode.ILLEGAL_PROPERTY_VALUE, spesializedMessage, astNode));
	        return true;
	    }
	    return false;
	}
	function isDuplicateSibling(attr) {
	    var ramlVersion = attr.property().domain().universe().version();
	    var siblingName;
	    if (ramlVersion == "RAML10") {
	        siblingName = stringify(json.serialize(attr.lowLevel()));
	    }
	    else {
	        siblingName = attr.value() && attr.value().valueName && attr.value().valueName();
	    }
	    if (!siblingName) {
	        return false;
	    }
	    var parent = attr.parent && attr.parent();
	    if (!parent) {
	        return false;
	    }
	    var propertyName = attr.name && attr.name();
	    if (!propertyName) {
	        return false;
	    }
	    var siblings = parent.attributes && parent.attributes(propertyName);
	    if (!siblings) {
	        return false;
	    }
	    if (siblings.length === 0) {
	        return false;
	    }
	    var count = 0;
	    siblings.forEach(function (sibling) {
	        var name;
	        if (ramlVersion == "RAML10") {
	            siblingName = stringify(json.serialize(sibling.lowLevel()));
	        }
	        else {
	            name = sibling.value && sibling.value() && sibling.value().valueName && sibling.value().valueName();
	        }
	        if (name === siblingName) {
	            count++;
	        }
	    });
	    return count > 1;
	}
	function checkTraitReference(property, astNode, acceptor) {
	    //"is" property value must be an array
	    if (!universeHelpers.isIsProperty(property)) {
	        return;
	    }
	    var lowLevel = astNode.lowLevel();
	    if (lowLevel == null) {
	        return;
	    }
	    //trying to find "is" mapping, looking 2 nodes up max
	    var isMappingNode = null;
	    var lowLevelParent = lowLevel.parent();
	    var lowLevelParentParent = lowLevelParent != null ? lowLevelParent.parent() : null;
	    if (lowLevel.kind() == yaml.Kind.MAPPING && lowLevel.key() && lowLevel.key() == "is") {
	        isMappingNode = lowLevel;
	    }
	    else if (lowLevelParent != null &&
	        lowLevelParent.kind() == yaml.Kind.MAPPING && lowLevelParent.key() && lowLevelParent.key() == "is") {
	        isMappingNode = lowLevelParent;
	    }
	    else if (lowLevelParentParent != null &&
	        lowLevelParentParent.kind() == yaml.Kind.MAPPING && lowLevelParentParent.key() && lowLevelParentParent.key() == "is") {
	        isMappingNode = lowLevelParentParent;
	    }
	    if (isMappingNode == null) {
	        return;
	    }
	    //having a single value is bad
	    if (isMappingNode.value() != null && (!isMappingNode.children() || isMappingNode.children().length == 0)) {
	        acceptor.accept(createIssue(hl.IssueCode.ILLEGAL_PROPERTY_VALUE, "property 'is' must be an array", astNode));
	    }
	    //only maps and scalars are allowed as direct children
	    var illegalChildFound = false;
	    isMappingNode.children().forEach(function (child) {
	        if (child.kind() != yaml.Kind.SCALAR && child.kind() != yaml.Kind.MAP) {
	            illegalChildFound = true;
	        }
	    });
	    if (illegalChildFound) {
	        acceptor.accept(createIssue(hl.IssueCode.ILLEGAL_PROPERTY_VALUE, "property 'is' must be an array", astNode));
	    }
	}
	function checkResourceTypeReference(property, astNode, acceptor) {
	    if (!universeHelpers.isTypeProperty(property)) {
	        return;
	    }
	    if (!universeHelpers.isResourceTypeRefType(astNode.definition())) {
	        return;
	    }
	    var lowLevel = astNode.lowLevel();
	    if (astNode.value() == null && lowLevel && lowLevel.children() &&
	        lowLevel.children().length == 0) {
	        if (lowLevel.kind() == yaml.Kind.MAPPING && lowLevel.valueKind() != null) {
	            //no value, no children in the mapping, but some value, that means empty map or something like this.
	            acceptor.accept(createIssue(hl.IssueCode.ILLEGAL_PROPERTY_VALUE, "resource type name must be provided", astNode));
	        }
	    }
	    else if (astNode.value() == null && lowLevel && lowLevel.children() &&
	        lowLevel.children().length > 1) {
	        //more than a single resource type in a list / map
	        acceptor.accept(createIssue(hl.IssueCode.ILLEGAL_PROPERTY_VALUE, "a resource or resourceType can inherit from a single resourceType", astNode));
	    }
	}
	/**
	 * Sometimes we need a more specialized message for the bad references, which diviate from a general algorithm.
	 * Like listing possible values etc.
	 * This method is responsible for such cases.
	 * @param originalMessage
	 * @param pr
	 * @param astNode
	 * @returns {string}
	 */
	function specializeReferenceError(originalMessage, property, astNode) {
	    if (property.nameId() == "type" && property.domain().universe().version() == "RAML08") {
	        if (property.domain().isAssignableFrom(universes.Universe08.Parameter.name)) {
	            return "type can be either of: string, number, integer, file, date or boolean";
	        }
	    }
	    if (astNode.parent() != null && universeHelpers.isSecuritySchemaType(astNode.parent().definition())) {
	        return originalMessage +
	            " Allowed values are:OAuth 1.0,OAuth 2.0,Basic Authentication,DigestSecurityScheme Authentication,x-{other}";
	    }
	    return originalMessage;
	}
	function nameForNonReference(astNode) {
	    var propertyName = astNode && astNode.lowLevel() && astNode.lowLevel().key();
	    if (propertyName === universes.Universe10.AbstractSecurityScheme.properties.type.name) {
	        var domain = astNode.parent() && astNode.parent().definition() && astNode.parent().definition().nameId();
	        if (domain === universes.Universe10.AbstractSecurityScheme.name) {
	            return "security scheme type";
	        }
	    }
	    else if (propertyName === universes.Universe08.BodyLike.properties.schema.name) {
	        var domain = astNode.parent() && astNode.parent().definition() && astNode.parent().definition().nameId();
	        if (domain === universes.Universe08.BodyLike.name) {
	            return "schema";
	        }
	    }
	}
	var DescriminatorOrReferenceValidator = (function () {
	    function DescriminatorOrReferenceValidator() {
	    }
	    DescriminatorOrReferenceValidator.prototype.validate = function (node, cb) {
	        var vl = node.value();
	        var valueKey = vl;
	        var pr = node.property();
	        if (typeof vl == 'string') {
	            checkReference(pr, node, vl, cb);
	            if (pr.range() instanceof defs.ReferenceType) {
	                var t = pr.range();
	                if (true) {
	                    var mockNode = jsyaml.createNode("" + vl, node.lowLevel().parent());
	                    mockNode._actualNode().startPosition = node.lowLevel().valueStart();
	                    mockNode._actualNode().endPosition = node.lowLevel().valueEnd();
	                    var stv = new hlimpl.StructuredValue(mockNode, node.parent(), node.property());
	                    var hn = stv.toHighLevel();
	                    if (hn) {
	                        hn.validate(cb);
	                    }
	                }
	            }
	        }
	        else if (vl != null) {
	            var st = vl;
	            if (st) {
	                valueKey = st.valueName();
	                var vn = st.valueName();
	                if (!checkReference(pr, node, vn, cb)) {
	                    var hnode = st.toHighLevel();
	                    if (hnode)
	                        hnode.validate(cb);
	                }
	            }
	            else {
	                valueKey = null;
	            }
	        }
	        else {
	            //there is no value, but still a reference: calling checkReference with null value
	            if (node.definition().isAssignableFrom(universes.Universe10.Reference.name)) {
	                checkReference(pr, node, null, cb);
	            }
	        }
	        if (valueKey) {
	            var validation = isValid(pr.range(), node.parent(), valueKey, pr);
	            if (validation instanceof Error) {
	                cb.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, validation.message, node));
	                validation = null;
	            }
	        }
	    };
	    return DescriminatorOrReferenceValidator;
	}());
	var allowOverride = { resources: 1, queryParameters: 1, headers: 1, body: 1, methods: 1, responses: 1 };
	var RAMLVersionAndFragmentValidator = (function () {
	    function RAMLVersionAndFragmentValidator() {
	    }
	    RAMLVersionAndFragmentValidator.prototype.validate = function (node, v) {
	        var u = node.universe();
	        var tv = u.getTypedVersion();
	        if (tv) {
	            if (util.startsWith(tv, "#%")) {
	                if (tv !== "#%RAML 0.8" && tv !== "#%RAML 1.0") {
	                    var i = createIssue(hl.IssueCode.NODE_HAS_VALUE, "Unknown version of RAML expected to see one of '#%RAML 0.8' or '#%RAML 1.0'", node);
	                    v.accept(i);
	                }
	                var tl = u.getTopLevel();
	                if (tl) {
	                    if (tl != node.definition().nameId()) {
	                        if (node.definition().nameId() == "Api") {
	                            var i = createIssue(hl.IssueCode.NODE_HAS_VALUE, "Unknown top level type:" + tl, node);
	                            v.accept(i);
	                        }
	                    }
	                }
	            }
	        }
	    };
	    return RAMLVersionAndFragmentValidator;
	}());
	var RequiredPropertiesAndContextRequirementsValidator = (function () {
	    function RequiredPropertiesAndContextRequirementsValidator() {
	    }
	    RequiredPropertiesAndContextRequirementsValidator.prototype.validate = function (node, v) {
	        var _this = this;
	        (node.definition()).getAdapter(services.RAMLService).getContextRequirements().forEach(function (x) {
	            if (!node.checkContextValue(x.name, x.value, x.value)) {
	                var message = x.name + (" should be " + x.value + " to use type " + node.definition().nameId());
	                if (x.name == 'location' && x.value == "ParameterLocation.FORM") {
	                    message = "file type can be only used in web forms";
	                }
	                v.accept(createIssue(hl.IssueCode.MISSED_CONTEXT_REQUIREMENT, message, node));
	            }
	        });
	        var t;
	        var isInlinedTemplate = node.definition().getAdapter(services.RAMLService).isInlinedTemplates();
	        if (isInlinedTemplate) {
	            var paramsMap = {};
	            for (var _i = 0, _a = node.lowLevel().children(); _i < _a.length; _i++) {
	                var ch = _a[_i];
	                paramsMap[ch.key()] = ch.value(true);
	            }
	            var templateKind = node.definition().isAssignableFrom(universes.Universe10.Trait.name) ? "trait" : "resource type";
	            var vt = new expander.ValueTransformer(templateKind, node.definition().nameId(), paramsMap);
	            var parent = node.parent();
	            var def = parent ? parent.definition() : node.definition();
	            while (parent != null && !universeHelpers.isResourceType(def) && !universeHelpers.isMethodType(def)) {
	                parent = parent.parent();
	            }
	            t = new expander.DefaultTransformer(parent, vt);
	        }
	        node.definition().requiredProperties().forEach(function (x) {
	            if (isInlinedTemplate) {
	                var paths = x.getAdapter(services.RAMLPropertyService).meta("templatePaths");
	                if (paths) {
	                    var parent = node.parent();
	                    var hasSufficientChild = false;
	                    for (var _i = 0, paths_1 = paths; _i < paths_1.length; _i++) {
	                        var path = paths_1[_i];
	                        path = path.map(function (x) { return t.transform(x).value; });
	                        if (_this.checkPathSufficiency(parent.lowLevel(), path, parent)) {
	                            hasSufficientChild = true;
	                            break;
	                        }
	                    }
	                    if (!hasSufficientChild) {
	                        return;
	                    }
	                }
	            }
	            var r = x.range();
	            if (r.hasArrayInHierarchy()) {
	                r = r.arrayInHierarchy().componentType();
	            }
	            if (r.hasValueTypeInHierarchy()) {
	                var nm = node.attr(x.nameId());
	                var gotValue = false;
	                if (nm != null) {
	                    if (nm.lowLevel().kind() == yaml.Kind.SCALAR
	                        || nm.lowLevel().valueKind() == yaml.Kind.SCALAR
	                        || nm.lowLevel().kind() == yaml.Kind.INCLUDE_REF
	                        || nm.lowLevel().valueKind() == yaml.Kind.INCLUDE_REF
	                        || (nm.lowLevel().valueKind() === null && !isInlinedTemplate)) {
	                        //if(nm.value()!=null){
	                        gotValue = true;
	                    }
	                    else if (nm.lowLevel().children().length != 0) {
	                        gotValue = true;
	                    }
	                }
	                if (!gotValue) {
	                    var msg = "Missing required property " + x.nameId();
	                    if (isInlinedTemplate) {
	                        msg = "value was not provided for parameter: " + x.nameId();
	                    }
	                    var i = createIssue(hl.IssueCode.MISSING_REQUIRED_PROPERTY, msg, node);
	                    v.accept(i);
	                }
	            }
	            else {
	                var el = node.elementsOfKind(x.nameId());
	                if (!el || el.length == 0) {
	                    var i = createIssue(hl.IssueCode.MISSING_REQUIRED_PROPERTY, "Missing required property " + x.nameId(), node);
	                    v.accept(i);
	                }
	            }
	        });
	    };
	    RequiredPropertiesAndContextRequirementsValidator.prototype.checkPathSufficiency = function (node, path, hlParent) {
	        if (hlParent == null || hlParent.definition() == null) {
	            return false;
	        }
	        var definition = hlParent.definition();
	        if (universeHelpers.isResourceTypeType(definition) || universeHelpers.isTraitType(definition)) {
	            return true;
	        }
	        if (path.length == 0) {
	            return false;
	        }
	        if (node == null) {
	            return false;
	        }
	        var segment = path[0];
	        if (segment == null) {
	            return false;
	        }
	        if (segment == "/") {
	            return this.checkPathSufficiency(node, path.slice(1), hlParent);
	        }
	        if (segment.length == 0) {
	            return true;
	        }
	        var children = node.children().filter(function (x) { return x.key() == segment; });
	        if (children.length == 0) {
	            path.indexOf("/") < 0;
	        }
	        var lowLevel = children[0];
	        if (lowLevel instanceof proxy.LowLevelCompositeNode) {
	            lowLevel = lowLevel.primaryNode();
	        }
	        if (lowLevel == null) {
	            return path.indexOf("/") < 0;
	        }
	        if (lowLevel.key() == "type") {
	            return true;
	        }
	        if (path.length == 1) {
	            // if(hlName==prop.nameId()&&node.definition().nameId()==prop.domain().nameId()){
	            //     return true;
	            // }
	            return lowLevel == null || lowLevel.value() == null;
	        }
	        else {
	            var path1 = path.slice(1);
	            return this.checkPathSufficiency(lowLevel, path1, hlParent);
	        }
	    };
	    return RequiredPropertiesAndContextRequirementsValidator;
	}());
	var ScalarQuoteValidator = (function () {
	    function ScalarQuoteValidator() {
	    }
	    ScalarQuoteValidator.prototype.validate = function (node, v) {
	        var r = node.lowLevel().unit();
	        node.lowLevel().visit(function (x) {
	            if (x.unit() != r) {
	                return false;
	            }
	            if (x.value() && x._node && x._node.value) {
	                if (x._node.value.doubleQuoted) {
	                    var ind = (x.value() + "").indexOf(":");
	                    var nl = (x.value() + "").indexOf("\n");
	                    if (ind != -1 && nl != -1 && (!x.includePath() || x.includePath().length == 0)) {
	                        var i = createIssue(hl.IssueCode.NODE_HAS_VALUE, "Suspicious double quoted multiline scalar, it is likely that you forgot closing \" " + x.value(), node, true);
	                        i.start = x._node.value.startPosition;
	                        i.end = x._node.value.endPosition;
	                        if (i.start == i.end) {
	                            i.end++;
	                        }
	                        v.accept(i);
	                    }
	                }
	            }
	            return true;
	        });
	    };
	    return ScalarQuoteValidator;
	}());
	var FixedFacetsValidator = (function () {
	    function FixedFacetsValidator() {
	    }
	    FixedFacetsValidator.prototype.validate = function (node, v) {
	        var nc = node.definition();
	        var dnode = nc.getAdapter(services.RAMLService).getDeclaringNode();
	        if (dnode) {
	            var rof = dnode.parsedType();
	            var dp = node.lowLevel().dumpToObject(true);
	            if (dp) {
	                dp = dp[Object.keys(dp)[0]];
	            }
	            if (!dp) {
	                if (nc.isAnnotationType()) {
	                    if (nc.isAssignableFrom(universes.Universe10.StringType.name)) {
	                        dp = "";
	                    }
	                }
	            }
	            var validateObject = rof.validate(dp, true, false);
	            if (!validateObject.isOk()) {
	                validateObject.getErrors().forEach(function (e) { return v.accept(createIssue(hl.IssueCode.ILLEGAL_PROPERTY_VALUE, e.getMessage(), mapPath(node, e), false)); });
	            }
	        }
	    };
	    return FixedFacetsValidator;
	}());
	var TypeDeclarationValidator = (function () {
	    function TypeDeclarationValidator() {
	    }
	    TypeDeclarationValidator.prototype.validate = function (node, v) {
	        var nc = node.definition();
	        var rof = node.parsedType();
	        var validateObject = rof.validateType(node.types().getAnnotationTypeRegistry());
	        if (!validateObject.isOk()) {
	            validateObject.getErrors().forEach(function (e) { v.accept(createIssue(hl.IssueCode.ILLEGAL_PROPERTY_VALUE, e.getMessage(), mapPath(node, e), e.isWarning())); });
	        }
	    };
	    return TypeDeclarationValidator;
	}());
	function mapPath(node, e) {
	    var src = e.getValidationPath();
	    return findElementAtPath(node, src);
	}
	function findElementAtPath(n, p) {
	    if (!p) {
	        return n;
	    }
	    var chld = n.children();
	    for (var i = 0; i < chld.length; i++) {
	        if (chld[i].name() === p.name) {
	            return findElementAtPath(chld[i], p.child);
	        }
	    }
	    if (!n.lowLevel()) {
	        return n;
	    }
	    var lchld = n.lowLevel().children();
	    for (var i = 0; i < lchld.length; i++) {
	        if (lchld[i].key() === p.name) {
	            var nn = new hlimpl.BasicASTNode(lchld[i], n);
	            return findElementAtPath(nn, p.child);
	        }
	    }
	    if (!isNaN(p.name)) {
	        if (lchld[p.name]) {
	            var node = lchld[p.name];
	            var nn = new hlimpl.BasicASTNode(node, n);
	            return findElementAtPath(nn, p.child);
	        }
	    }
	    return n;
	}
	var CompositeNodeValidator = (function () {
	    function CompositeNodeValidator() {
	    }
	    CompositeNodeValidator.prototype.validate = function (node, acceptor) {
	        if (node.definition().isAnnotationType()) {
	            return;
	        }
	        if (node.lowLevel().keyKind() == yaml.Kind.SEQ) {
	            var isPattern = node.definition().isAssignableFrom(universes.Universe10.TypeDeclaration.name);
	            if (!isPattern) {
	                acceptor.accept(createIssue(hl.IssueCode.UNKNOWN_NODE, "Node key can not be sequence", node));
	            }
	        }
	        if (node.definition().key() == universes.Universe08.GlobalSchema) {
	            if (node.lowLevel().valueKind() != yaml.Kind.SCALAR) {
	                var isString = false;
	                if (node.lowLevel().valueKind() == yaml.Kind.ANCHOR_REF || node.lowLevel().valueKind() == yaml.Kind.INCLUDE_REF) {
	                    var vl = node.lowLevel().value();
	                    if (typeof vl === "string") {
	                        isString = true;
	                    }
	                }
	                if (!isString) {
	                    acceptor.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, "schema " + node.name() + " must be a string", node));
	                }
	            }
	        }
	        if (!node.parent()) {
	            new RAMLVersionAndFragmentValidator().validate(node, acceptor);
	            //Note: overloading validator now checks for oveloading and rejects it
	            if (node.definition().key() == universes.Universe08.Api || node.definition().key() == universes.Universe10.Api) {
	                new OverloadingValidator().validateApi(node.wrapperNode(), acceptor);
	            }
	            new ScalarQuoteValidator().validate(node, acceptor);
	            lintNode(node, acceptor);
	        }
	        new OverlayNodesValidator().validate(node, acceptor);
	        var nc = node.definition();
	        if (nc.key() == universes.Universe08.BodyLike) {
	            if (node.lowLevel().children().map(function (x) { return x.key(); }).some(function (x) { return x === "formParameters"; })) {
	                if (node.parent() && node.parent().definition().key() == universes.Universe08.Response) {
	                    var i = createIssue(hl.IssueCode.NODE_HAS_VALUE, "form parameters can not be used in response", node);
	                    acceptor.accept(i);
	                }
	                else if (node.lowLevel().children().map(function (x) { return x.key(); }).some(function (x) { return x === "schema" || x === "example"; })) {
	                    var i = createIssue(hl.IssueCode.NODE_HAS_VALUE, "formParameters cannot be used together with the example or schema properties", node);
	                    acceptor.accept(i);
	                }
	            }
	        }
	        if (nc.key() == universes.Universe10.OAuth2SecuritySchemeSettings) {
	            var requireUrl = false;
	            node.attributes("authorizationGrants").forEach(function (x) {
	                var vl = x.value();
	                if (vl === "authorization_code" || vl === "implicit") {
	                    requireUrl = true;
	                }
	                else if (vl !== "password" && vl !== 'client_credentials') {
	                    if (vl && typeof vl === "string" && vl.indexOf("://") == -1 && vl.indexOf(":") == -1) {
	                        var i = createIssue(hl.IssueCode.NODE_HAS_VALUE, "authorizationGrants should be one of authorization_code,implicit,password,client_credentials or to be an abolute URI", x);
	                        acceptor.accept(i);
	                    }
	                }
	            });
	            if (requireUrl) {
	                if (!node.attr("authorizationUri")) {
	                    var i = createIssue(hl.IssueCode.NODE_HAS_VALUE, "authorizationUri is required when `authorization_code` or `implicit` grant type are used ", node);
	                    acceptor.accept(i);
	                }
	            }
	        }
	        //validation of enum values;
	        if (node.definition().isAssignableFrom(universes.Universe08.Parameter.name)
	            || node.definition().isAssignableFrom(universes.Universe10.TypeDeclaration.name)) {
	            var vls = node.attributes("enum").map(function (x) { return x.value(); });
	            if (vls.length != _.uniq(vls).length) {
	                var i = createIssue(hl.IssueCode.NODE_HAS_VALUE, "enum contains duplicated values", node);
	                acceptor.accept(i);
	            }
	            if (node.definition().isAssignableFrom(universes.Universe08.NumberTypeDeclaration.name) || node.definition().isAssignableFrom(universes.Universe10.NumberTypeDeclaration.name)) {
	                var isInteger = node.definition().isAssignableFrom(universes.Universe08.IntegerTypeDeclaration.name) || node.definition().isAssignableFrom(universes.Universe10.IntegerTypeDeclaration.name);
	                node.attributes("enum").forEach(function (attribute) {
	                    var value = isInteger ? parseInt(attribute.value()) : parseFloat(attribute.value());
	                    var isValid = isInteger ? !isNaN(value) && attribute.value().indexOf('.') === -1 : !isNaN(value);
	                    if (!isValid) {
	                        var issue = createIssue(hl.IssueCode.NODE_HAS_VALUE, (isInteger ? "Integer" : "Number") + " is expected", attribute);
	                        acceptor.accept(issue);
	                    }
	                });
	            }
	        }
	        if (universeHelpers.isResourceTypeType(node.definition())) {
	            if (node.value() == null && node.lowLevel().value(true) === "null") {
	                acceptor.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, "Resource type can not be null", node));
	            }
	        }
	        checkPropertyQuard(node, acceptor);
	        var nodeValue = node.value();
	        if ((typeof nodeValue == 'string'
	            || typeof nodeValue == 'number'
	            || typeof nodeValue == 'boolean')
	            && !node.definition().getAdapter(services.RAMLService).allowValue()) {
	            if (node.parent()) {
	                if (nodeValue != '~') {
	                    var i = createIssue(hl.IssueCode.NODE_HAS_VALUE, "node " + node.name() + " can not be a scalar", node);
	                    acceptor.accept(i);
	                }
	            }
	        }
	        new RequiredPropertiesAndContextRequirementsValidator().validate(node, acceptor);
	        new ValidateChildrenKeys().validate(node, acceptor);
	        new NodeSpecificValidator().validate(node, acceptor);
	    };
	    return CompositeNodeValidator;
	}());
	var BaseUriParameterValidator = (function () {
	    function BaseUriParameterValidator() {
	    }
	    BaseUriParameterValidator.prototype.validate = function (node, acceptor) {
	        //we cant have "version" base uri parameter
	        var nameAttributeValue = node.attrValue(universes.Universe10.TypeDeclaration.properties.name.name);
	        if ("version" == nameAttributeValue) {
	            //I dont like the message, but its coming from JS 0.8 parser @Denis
	            acceptor.accept(createIssue(hl.IssueCode.ILLEGAL_PROPERTY, "version parameter not allowed here", node));
	        }
	    };
	    return BaseUriParameterValidator;
	}());
	var NodeSpecificValidatorRegistryEntry = (function () {
	    /**
	     *
	     * @param definition - array of definitions from universes
	     * @param propertyName - name of the property. May be null, then property is not tested.
	     * @param assignableFrom - whether instead of direct definition comparison, the tested node will be checked
	     * for assignability from the specified definitions
	     */
	    function NodeSpecificValidatorRegistryEntry(definitions, propertyName, validator, assignableFrom) {
	        if (assignableFrom === void 0) { assignableFrom = false; }
	        this.definitions = definitions;
	        this.propertyName = propertyName;
	        this.assignableFrom = assignableFrom;
	        this.validator = validator;
	    }
	    /**
	     * Checks whether this entry is applicable to the node. If so, invokes its validator.
	     * @param node
	     * @param cb
	     */
	    NodeSpecificValidatorRegistryEntry.prototype.validate = function (node, acceptor) {
	        var nodeDefinition = node.definition();
	        if (nodeDefinition == null)
	            return;
	        var definitionMatched = false;
	        if (!this.assignableFrom) {
	            definitionMatched =
	                this.definitions.some(function (currentDefinition) { return currentDefinition === nodeDefinition; });
	        }
	        else {
	            definitionMatched =
	                this.definitions.some(function (currentDefinition) { return nodeDefinition.isAssignableFrom(currentDefinition.name); });
	        }
	        if (!definitionMatched)
	            return;
	        if (this.propertyName != null) {
	            if (node.property() == null)
	                return;
	            if (node.property().nameId() != this.propertyName)
	                return;
	        }
	        //definition and property matched, invoking validator
	        this.validator.validate(node, acceptor);
	    };
	    return NodeSpecificValidatorRegistryEntry;
	}());
	/**
	 * A central switch for validations specific to a particular node.
	 * In future it would be nice to migrate all node-specific validation scattered around the code here.
	 */
	var NodeSpecificValidator = (function () {
	    function NodeSpecificValidator() {
	    }
	    NodeSpecificValidator.createRegistry = function () {
	        var result = [];
	        NodeSpecificValidator.registerValidator(result, [universes.Universe10.TypeDeclaration, universes.Universe08.Parameter], universes.Universe10.Api.properties.baseUriParameters.name, new BaseUriParameterValidator(), true);
	        return result;
	    };
	    NodeSpecificValidator.registerValidator = function (listToAddTo, definitions, propertyName, validator, assignableFrom) {
	        if (assignableFrom === void 0) { assignableFrom = false; }
	        var entry = new NodeSpecificValidatorRegistryEntry(definitions, propertyName, validator, assignableFrom);
	        listToAddTo.push(entry);
	    };
	    NodeSpecificValidator.prototype.validate = function (node, acceptor) {
	        NodeSpecificValidator.entries.forEach(function (entry) { return entry.validate(node, acceptor); });
	    };
	    NodeSpecificValidator.entries = NodeSpecificValidator.createRegistry();
	    return NodeSpecificValidator;
	}());
	var OverlayNodesValidator = (function () {
	    function OverlayNodesValidator() {
	    }
	    /**
	     * Checks that this node is in white list and
	     * makes itself and all of its children allowed to exist in overlay even
	     * if there is no master counterpart
	     * @param node
	     * @param root
	     * @returns {boolean}
	     */
	    OverlayNodesValidator.prototype.allowsAnyChildren = function (node, root) {
	        var property = node.property();
	        var definition = node.definition();
	        //accepting new annotation types
	        if ((universeHelpers.isAnnotationTypeType(definition) || universeHelpers.isTypeDeclarationTypeOrDescendant(definition))
	            && universeHelpers.isAnnotationTypesProperty(property))
	            return true;
	        //accepting new top-level type declarations
	        if (node.parent() == root && universeHelpers.isTypesProperty(property)
	            && universeHelpers.isTypeDeclarationTypeOrDescendant(definition))
	            return true;
	        //as we allow types, it is logical to also allow schemas as "schemas are only aliases for types"
	        if (universeHelpers.isSchemasProperty(property)
	            && universeHelpers.isTypeDeclarationTypeOrDescendant(definition))
	            return true;
	        //accepting documentation
	        if (node.parent() == root && universeHelpers.isDocumentationProperty(property)
	            && universeHelpers.isDocumentationType(definition))
	            return true;
	        //accepting annotations
	        if (universeHelpers.isAnnotationsProperty(property))
	            return true;
	        //uses allowed
	        if (universeHelpers.isUsesProperty(property))
	            return true;
	        //examples allowed
	        if (universeHelpers.isExamplesProperty(property))
	            return true;
	        return false;
	    };
	    /**
	     * Checks that this node is allowed to exist in overlay even if there is no master counterpart
	     * due to it or its parent being in the white list.
	     * @param node
	     * @param root
	     */
	    OverlayNodesValidator.prototype.nodeAllowedDueToParent = function (node, root) {
	        var currentNode = node;
	        while (currentNode != root && currentNode != null) {
	            if (this.allowsAnyChildren(currentNode, root)) {
	                return true;
	            }
	            currentNode = currentNode.parent();
	        }
	        return false;
	    };
	    OverlayNodesValidator.prototype.validate = function (node, v) {
	        var root = node.root();
	        var property = node.property();
	        var definition = node.definition();
	        //we are only validating overlays
	        if (!universeHelpers.isOverlayType(root.definition()))
	            return;
	        //for root only validate properties
	        if (node == root) {
	            this.validateProperties(node, v);
	            return;
	        }
	        //we have a whitelist of IHighLevelNodes allowed to be added in an overlay like new types, annotation types,
	        //annotation etc. The contents of such nodes is checked here.
	        if (this.nodeAllowedDueToParent(node, root))
	            return;
	        //checking for a node, this node overrides
	        var overrides = root.knownIds();
	        if (!overrides) {
	            //should never happen
	            return;
	        }
	        var override = overrides.hasOwnProperty(node.id());
	        if (override) {
	            //overrides are allowed, but we need to check properties, this override potentially brings in or changes:
	            this.validateProperties(node, v);
	            return;
	        }
	        //otherwise reporting an illegal node:
	        v.accept(createIssue(hl.IssueCode.ONLY_OVERRIDE_ALLOWED, "The '" + node.id() + "' node does not match any node of the master api.", node));
	    };
	    OverlayNodesValidator.prototype.validateProperties = function (node, acceptor) {
	        node.attrs().forEach(function (attribute) {
	            //ignoring key properties as they are not overriding anything
	            if (attribute.property().getAdapter(services.RAMLPropertyService).isKey()) {
	                return;
	            }
	            //ignoring nodes, which are not coming from this node, but from is master chain
	            if (attribute.parent() != node) {
	                return;
	            }
	            //yes, that also happens!
	            if (attribute.isElement()) {
	                return;
	            }
	            //title allowed
	            if (universeHelpers.isTitlePropertyName(attribute.name()))
	                return;
	            //description allowed
	            if (universeHelpers.isDescriptionPropertyName(attribute.name()))
	                return;
	            //displayName allowed
	            if (universeHelpers.isDisplayNamePropertyName(attribute.name()))
	                return;
	            //usage allowed
	            if (universeHelpers.isUsagePropertyName(attribute.name()))
	                return;
	            //example allowed
	            if (universeHelpers.isExampleProperty(attribute.property()))
	                return;
	            //masterRef allowed
	            if (universeHelpers.isMasterRefProperty(attribute.property()))
	                return;
	            //annotations allowed
	            if (universeHelpers.isAnnotationsProperty(attribute.property()))
	                return;
	            //uses allowed
	            if (universeHelpers.isUsesProperty(attribute.property()))
	                return;
	            //reporting the error
	            var message = "Property " + attribute.name() +
	                " is not allowed to be overriden or added in overlays";
	            acceptor.accept(createIssue(hl.IssueCode.ONLY_OVERRIDE_ALLOWED, message, attribute));
	        });
	    };
	    return OverlayNodesValidator;
	}());
	var RecurrentOverlayValidator = (function () {
	    function RecurrentOverlayValidator() {
	    }
	    RecurrentOverlayValidator.prototype.validate = function (node, v) {
	        var _this = this;
	        var z = new OverlayNodesValidator();
	        z.validate(node, v);
	        node.directChildren().forEach(function (x) { if (x.isElement()) {
	            _this.validate(x.asElement(), v);
	        } });
	    };
	    return RecurrentOverlayValidator;
	}());
	var RecurrentValidateChildrenKeys = (function () {
	    function RecurrentValidateChildrenKeys() {
	    }
	    RecurrentValidateChildrenKeys.prototype.val = function (node, v, p) {
	        var _this = this;
	        if (node.kind() == yaml.Kind.MAP || node.kind() == yaml.Kind.MAPPING) {
	            var ms = {};
	            node.children().forEach(function (x) {
	                var c = x.key();
	                if (c) {
	                    if (ms.hasOwnProperty(c)) {
	                        var issue = createIssue(hl.IssueCode.KEY_SHOULD_BE_UNIQUE_INTHISCONTEXT, "keys should be unique", p, false);
	                        if (x.unit() == p.lowLevel().unit()) {
	                            issue.start = x.keyStart();
	                            issue.end = x.keyEnd();
	                        }
	                        v.accept(issue);
	                    }
	                    ms[c] = 1;
	                }
	            });
	        }
	        node.children().forEach(function (x) {
	            _this.val(x, v, p);
	        });
	    };
	    RecurrentValidateChildrenKeys.prototype.validate = function (node, v) {
	        this.val(node.lowLevel(), v, node);
	    };
	    return RecurrentValidateChildrenKeys;
	}());
	var ValidateChildrenKeys = (function () {
	    function ValidateChildrenKeys() {
	    }
	    ValidateChildrenKeys.prototype.validate = function (node, acceptor) {
	        //validation is being performed at high level instead of low-level
	        //to provide more meaningful and specific error messages
	        this.validateChildElements(node, acceptor);
	        var lowLevelChildren = node.lowLevel().children();
	        var keyToLowLevelChildren = _.groupBy(lowLevelChildren.filter(function (x) { return x.key() != null; }), function (x) { return x.key(); });
	        this.validateChildAttributes(node, keyToLowLevelChildren, acceptor);
	        this.validateUnrecognizedLowLevelChildren(node, keyToLowLevelChildren, acceptor);
	    };
	    ValidateChildrenKeys.prototype.validateChildElements = function (node, acceptor) {
	        //testing for child elements having equal keys
	        var keyToElements = {};
	        var childElements = node.directChildren().filter(function (x) { return x.isElement(); });
	        childElements.forEach(function (childNode) {
	            var childElement = childNode;
	            if (childElement["_computed"]) {
	                return;
	            }
	            if (!childElement.name()) {
	                return; //handling nodes with no key (documentation)
	            }
	            var elementKey = childElement.name() + childElement.property().nameId();
	            if (keyToElements.hasOwnProperty(elementKey)) {
	                if (!childElement.isNamePatch()) {
	                    keyToElements[elementKey].push(childElement);
	                }
	            }
	            else {
	                keyToElements[elementKey] = [childElement];
	            }
	        });
	        Object.keys(keyToElements).forEach(function (key) {
	            var childElements = keyToElements[key];
	            if (!childElements || childElements.length < 2)
	                return;
	            childElements.forEach(function (childElement) {
	                var message = "";
	                var humanReadableName = getHumanReadableNodeName(childElement);
	                if (humanReadableName) {
	                    var capitalized = humanReadableName.charAt(0).toUpperCase() + humanReadableName.slice(1);
	                    var message = capitalized + " '" + childElement.name() + "' already exists";
	                }
	                else {
	                    message = childElement.name() + " already exists in this context";
	                }
	                var issue = createIssue(hl.IssueCode.KEY_SHOULD_BE_UNIQUE_INTHISCONTEXT, message, childElement);
	                acceptor.accept(issue);
	            });
	        });
	    };
	    ValidateChildrenKeys.prototype.validateChildAttributes = function (node, keyToLowLevelChildren, acceptor) {
	        var highLevelAttributes = this.getHighLevelAttributes(node);
	        var nameToHighLevelAttributes = _.groupBy(highLevelAttributes, function (x) { return x.name(); });
	        var allowsAnyAndHasRequireds = this.allowsAnyAndHasRequireds(node);
	        Object.keys(nameToHighLevelAttributes).forEach(function (attributeName) {
	            if (nameToHighLevelAttributes[attributeName].length < 2) {
	                return;
	            }
	            var isUnknown = nameToHighLevelAttributes[attributeName][0].isUnknown();
	            var isMultiValue = !isUnknown && nameToHighLevelAttributes[attributeName][0].property().isMultiValue();
	            if (isMultiValue && (node.definition().isAssignableFrom(universes.Universe08.SecuritySchemeSettings.name) ||
	                node.definition().isAssignableFrom(universes.Universe10.SecuritySchemeSettings.name))) {
	                isMultiValue = keyToLowLevelChildren[attributeName] && keyToLowLevelChildren[attributeName].length === 1;
	            }
	            if ((isUnknown && allowsAnyAndHasRequireds) || !isMultiValue ||
	                (isMultiValue && keyToLowLevelChildren[attributeName] != null && keyToLowLevelChildren[attributeName].length > 1)) {
	                //we blame even multivalue properties if they have duplicated low-level keys as YAML forbids this
	                nameToHighLevelAttributes[attributeName].forEach(function (attribute) {
	                    var message = "property already used: '" + (attribute.property() ? attribute.property().nameId() : attribute.name()) + "'";
	                    var humanReadableParent = getHumanReadableNodeName(attribute.parent());
	                    if (humanReadableParent) {
	                        var capitalizedParent = humanReadableParent.charAt(0).toUpperCase() + humanReadableParent.slice(1);
	                        message = capitalizedParent + " " + message;
	                    }
	                    var issue = createIssue(hl.IssueCode.PROPERTY_EXPECT_TO_HAVE_SINGLE_VALUE, message, attribute);
	                    acceptor.accept(issue);
	                });
	            }
	        });
	    };
	    ValidateChildrenKeys.prototype.validateUnrecognizedLowLevelChildren = function (node, keyToLowLevelChildren, acceptor) {
	        var highLevelChildren = node.directChildren();
	        var nameToHighLevelChildren = _.groupBy(highLevelChildren, function (x) { return x.name(); });
	        Object.keys(keyToLowLevelChildren).forEach(function (lowLevelChildKey) {
	            if (lowLevelChildKey) {
	                if (keyToLowLevelChildren[lowLevelChildKey].length > 1 && !nameToHighLevelChildren[lowLevelChildKey]) {
	                    if (node.definition().isAssignableFrom(universes.Universe10.ObjectTypeDeclaration.name)) {
	                        return;
	                    }
	                    var message = "property already used: '" + lowLevelChildKey + "'";
	                    var humanReadableNode = getHumanReadableNodeName(node);
	                    if (humanReadableNode) {
	                        var capitalizedParent = humanReadableNode.charAt(0).toUpperCase() + humanReadableNode.slice(1);
	                        message = capitalizedParent + " " + message;
	                    }
	                    keyToLowLevelChildren[lowLevelChildKey].forEach(function (lowLevelChild) {
	                        var i = createLLIssue(hl.IssueCode.PROPERTY_EXPECT_TO_HAVE_SINGLE_VALUE, message, lowLevelChild, node);
	                        i.start = lowLevelChild.keyStart();
	                        i.end = lowLevelChild.keyEnd();
	                        acceptor.accept(i);
	                    });
	                }
	            }
	        });
	    };
	    ValidateChildrenKeys.prototype.filterMultiValueAnnotations = function (node, keyToLowLevelChildren, acceptor) {
	        var highLevelAttributes = this.getHighLevelAttributes(node);
	        var computedAnnotationsMultiplValues = false;
	        Object.keys(keyToLowLevelChildren).forEach(function (lowLevelChildKey) {
	            if (lowLevelChildKey.charAt(0) !== '(' || keyToLowLevelChildren[lowLevelChildKey].length < 2) {
	                return;
	            }
	        });
	    };
	    ValidateChildrenKeys.prototype.getHighLevelAttributes = function (node) {
	        var allowsAnyAndHasRequireds = this.allowsAnyAndHasRequireds(node);
	        return node.directChildren().filter(function (x) { return x.isAttr() || allowsAnyAndHasRequireds; });
	    };
	    ValidateChildrenKeys.prototype.allowsAnyAndHasRequireds = function (node) {
	        var requireds = node.definition().requiredProperties();
	        var hasRequireds = requireds && requireds.length > 0;
	        var ramlService = node.definition().getAdapter(services.RAMLService);
	        var isAllowAny = ramlService && ramlService.getAllowAny();
	        var anyExceptRequireds = isAllowAny && hasRequireds;
	        return anyExceptRequireds;
	    };
	    return ValidateChildrenKeys;
	}());
	/**
	 * validates examples
	 */
	var ExampleValidator = (function () {
	    function ExampleValidator() {
	    }
	    ExampleValidator.prototype.validate = function (node, cb) {
	        //check if we expect to do strict validation
	        var strictValidation = this.isStrict(node);
	        if (!strictValidation) {
	            if (!settings.validateNotStrictExamples) {
	                return;
	            }
	        }
	        var pObj = this.parseObject(node, cb, strictValidation);
	        if (!pObj) {
	            return;
	        }
	        var schema = this.aquireSchema(node);
	        if (schema) {
	            schema.validate(pObj, cb, strictValidation);
	        }
	    };
	    ExampleValidator.prototype.isExampleNode = function (node) {
	        return this.isSingleExampleNode(node) || this.isExampleNodeInMultipleDecl(node);
	    };
	    ExampleValidator.prototype.isSingleExampleNode = function (node) {
	        return node.name() == universes.Universe10.TypeDeclaration.properties.example.name;
	    };
	    ExampleValidator.prototype.isExampleNodeInMultipleDecl = function (node) {
	        var parent = node.parent();
	        if (parent) {
	            return universeHelpers.isExampleSpecType(parent.definition());
	        }
	        return false;
	    };
	    ExampleValidator.prototype.findParentSchemaOrTypeAttribute = function (node) {
	        var attribute = node.parent().attr(universes.Universe10.TypeDeclaration.properties.schema.name);
	        if (attribute) {
	            return attribute;
	        }
	        attribute = node.parent().attr(universes.Universe10.TypeDeclaration.properties.type.name);
	        if (attribute) {
	            return attribute;
	        }
	        if (!node.parent()) {
	            return null;
	        }
	        attribute = node.parent().parent().attr(universes.Universe10.TypeDeclaration.properties.schema.name);
	        if (attribute) {
	            return attribute;
	        }
	        attribute = node.parent().parent().attr(universes.Universe10.TypeDeclaration.properties.type.name);
	        if (attribute) {
	            return attribute;
	        }
	        return null;
	    };
	    ExampleValidator.prototype.aquireSchema = function (node) {
	        var sp = node.parent().definition().isAssignableFrom(universes.Universe10.TypeDeclaration.name);
	        if (this.isExampleNode(node)) {
	            var sampleRoot = node;
	            if (this.isExampleNodeInMultipleDecl(node)) {
	                sampleRoot = node.parent();
	            }
	            if (sampleRoot.parent()) {
	                if (sampleRoot.parent().definition().isAssignableFrom(universes.Universe10.TypeDeclaration.name) && sampleRoot.parent().parent() === null) {
	                    sp = false;
	                }
	                else if (sampleRoot.parent().property().nameId() == universes.Universe10.LibraryBase.properties.types.name) {
	                    sp = false;
	                }
	                if (sampleRoot.parent().parent()) {
	                    var ppc = sampleRoot.parent().parent().definition().key();
	                    if (ppc == universes.Universe08.Method || ppc == universes.Universe10.Method) {
	                        if (sampleRoot.parent().property().nameId() == universes.Universe10.MethodBase.properties.queryParameters.name) {
	                        }
	                        else {
	                            sp = true;
	                        }
	                    }
	                    if (ppc == universes.Universe08.Response || ppc == universes.Universe10.Response) {
	                        sp = true;
	                    }
	                }
	            }
	        }
	        if (node.parent().definition().key() == universes.Universe08.BodyLike || sp) {
	            //FIXME MULTIPLE INHERITANCE
	            var sa = this.findParentSchemaOrTypeAttribute(node);
	            if (sa) {
	                var val = sa.value();
	                if (val instanceof hlimpl.StructuredValue) {
	                    return null;
	                }
	                var strVal = ("" + val).trim();
	                var so = null;
	                if (strVal.charAt(0) == "{") {
	                    try {
	                        so = su.getJSONSchema(strVal, new contentprovider.ContentProvider(sa.lowLevel().unit()));
	                    }
	                    catch (e) {
	                        return null;
	                    }
	                }
	                if (strVal.charAt(0) == "<") {
	                    try {
	                        so = su.getXMLSchema(strVal);
	                    }
	                    catch (e) {
	                        return null;
	                    }
	                }
	                if (so) {
	                    return {
	                        validate: function (pObje, cb, strict) {
	                            try {
	                                if (pObje.__$validated) {
	                                    return;
	                                }
	                                if (so instanceof Error) {
	                                    cb.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, so.message, node, !strict));
	                                    return;
	                                }
	                                so.validateObject(pObje);
	                            }
	                            catch (e) {
	                                var illegalRequiredMessageStart = "Cannot assign to read only property '__$validated' of ";
	                                if (e.message && e.message.indexOf(illegalRequiredMessageStart) == 0) {
	                                    var propertyName = e.message.substr(illegalRequiredMessageStart.length, e.message.length - illegalRequiredMessageStart.length);
	                                    var patchedErrorMessage = "Invalid JSON schema. Potentially, required array containing value "
	                                        + propertyName + " has invalid location";
	                                    cb.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, patchedErrorMessage, sa, !strict));
	                                    return;
	                                }
	                                if (e.message == "Object.keys called on non-object") {
	                                    return;
	                                }
	                                cb.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, "Example does not conform to schema:" + e.message, node, !strict));
	                                return;
	                            }
	                            //validate using classical schema;
	                        }
	                    };
	                }
	                else {
	                    if (strVal.length > 0) {
	                        var nodeParent = node.parent();
	                        var grandParent = nodeParent && nodeParent.parent();
	                        var owner = nodeParent && nodeParent.definition() && nodeParent.definition().isAssignableFrom(universes.Universe10.ObjectTypeDeclaration.name) && nodeParent;
	                        owner = owner || (grandParent && grandParent.definition() && grandParent.definition().isAssignableFrom(universes.Universe10.ObjectTypeDeclaration.name) && grandParent);
	                        if (owner) {
	                            return this.typeValidator(owner, node);
	                        }
	                    }
	                }
	            }
	        }
	        return this.getSchemaFromModel(node);
	    };
	    ExampleValidator.prototype.getSchemaFromModel = function (node) {
	        var p = node.parent();
	        // if (node.property().nameId()==universes.Universe10.ExampleSpec.properties.content.name){
	        //     p=p.parent();
	        // }
	        return this.typeValidator(p, node);
	    };
	    ExampleValidator.prototype.typeValidator = function (p, node) {
	        var newVar = {
	            validate: function (pObje, cb, strict) {
	                var pt = p.parsedType();
	                if (pt && !pt.isUnknown()) {
	                    if (typeof pObje === "number" && pt.isString()) {
	                        pObje = "" + pObje;
	                    }
	                    if (typeof pObje === "boolean" && pt.isString()) {
	                        pObje = "" + pObje;
	                    }
	                    if (pt.getExtra("repeat")) {
	                        pObje = [pObje];
	                    }
	                    var validateObject = pt.validate(pObje, true);
	                    if (!validateObject.isOk()) {
	                        validateObject.getErrors().forEach(function (e) { return cb.accept(createIssue(hl.IssueCode.ILLEGAL_PROPERTY_VALUE, e.getMessage(), node, !strict)); });
	                    }
	                }
	            }
	        };
	        return newVar;
	    };
	    ;
	    ExampleValidator.prototype.toObject = function (h, v, cb) {
	        var res = v.lowLevel().dumpToObject(true);
	        this.testDublication(h, v.lowLevel(), cb);
	        if (res["example"]) {
	            return res["example"];
	        }
	        if (res["content"]) {
	            return res["content"];
	        }
	    };
	    ExampleValidator.prototype.testDublication = function (h, v, cb) {
	        var _this = this;
	        var map = {};
	        v.children().forEach(function (x) {
	            if (x.key()) {
	                if (map[x.key()]) {
	                    cb.accept(createIssue(hl.IssueCode.KEY_SHOULD_BE_UNIQUE_INTHISCONTEXT, "Keys should be unique", new hlimpl.BasicASTNode(x, h.parent())));
	                }
	                map[x.key()] = x;
	            }
	            _this.testDublication(h, x, cb);
	        });
	    };
	    ExampleValidator.prototype.parseObject = function (node, cb, strictValidation) {
	        var pObj = null;
	        var vl = node.value();
	        var mediaType = getMediaType(node);
	        if (vl instanceof hlimpl.StructuredValue) {
	            //validate in context of type/schema
	            pObj = this.toObject(node, vl, cb);
	        }
	        else {
	            if (mediaType) {
	                if (isJson(mediaType)) {
	                    try {
	                        pObj = JSON.parse(vl);
	                    }
	                    catch (e) {
	                        cb.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, "Can not parse JSON:" + e.message, node, !strictValidation));
	                        return;
	                    }
	                }
	                if (isXML(mediaType)) {
	                    try {
	                        pObj = xmlutil(vl);
	                    }
	                    catch (e) {
	                        cb.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, "Can not parse XML:" + e.message, node, !strictValidation));
	                        return;
	                    }
	                }
	            }
	            else {
	                try {
	                    if (vl && vl.length > 0 && (vl.trim().charAt(0) == '[' || vl.trim().charAt(0) == '{' || vl.trim().charAt(0) == '<')) {
	                        pObj = JSON.parse(vl);
	                    }
	                    else {
	                        if (vl == "true") {
	                            return true;
	                        }
	                        else if (vl == "false") {
	                            return false;
	                        }
	                        else {
	                            var n = parseFloat(vl);
	                            if (!isNaN(n)) {
	                                return n;
	                            }
	                        }
	                        return vl;
	                    }
	                }
	                catch (e) {
	                    if (vl.trim().indexOf("<") == 0) {
	                        try {
	                            pObj = xmlutil(vl);
	                        }
	                        catch (e) {
	                            cb.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, "Can not parse XML:" + e.message, node, !strictValidation));
	                            return;
	                        }
	                    }
	                    else {
	                        //cb.accept(createIssue(hl.IssueCode.INVALID_VALUE_SCHEMA, "Can not parse JSON:" + e.message, node, !strictValidation));
	                        return vl;
	                    }
	                }
	            }
	        }
	        return pObj;
	    };
	    ExampleValidator.prototype.isStrict = function (node) {
	        var strictValidation = false;
	        var strict = node.parent().attr("strict");
	        if (strict) {
	            if (strict.value() == 'true') {
	                strictValidation = true;
	            }
	        }
	        return strictValidation;
	    };
	    return ExampleValidator;
	}());
	exports.ExampleValidator = ExampleValidator;
	var toReadableName = function (template, toLowerCase, pluralize_) {
	    var templateName = changeCase.sentence(template);
	    if (!toLowerCase) {
	        templateName = changeCase.ucFirst(templateName);
	    }
	    if (pluralize_) {
	        templateName = pluralize.plural(templateName);
	    }
	    return templateName;
	};
	var OptionalPropertiesValidator = (function () {
	    function OptionalPropertiesValidator() {
	    }
	    OptionalPropertiesValidator.prototype.validate = function (node, v) {
	        if (node.isAttr()) {
	            if (!node.optional()) {
	                return;
	            }
	            var attr = node;
	            var prop = attr.property();
	            if (prop.isMultiValue() || prop.range().isArray()) {
	                return;
	            }
	            if (!prop.isFromParentKey()) {
	                var template = typeOfContainingTemplate(attr.parent());
	                if (template) {
	                    if (prop.isValueProperty()) {
	                        var templateNamePlural = toReadableName(template, true, true);
	                        var message = "Optional scalar properties are not allowed in "
	                            + templateNamePlural + " and their descendants: " + attr.name() + "?";
	                        var issue = createIssue(hl.IssueCode.INVALID_PROPERTY, message, attr, false);
	                        v.accept(issue);
	                    }
	                }
	            }
	        }
	        else if (node.isElement()) {
	            var aNode = node;
	            var prop = aNode.property();
	            var allowsQuestion = aNode.allowsQuestion();
	            if (!allowsQuestion) {
	                var propName = prop ? toReadableName(prop.nameId(), true, true) : 'API root';
	                aNode.optionalProperties().forEach(function (x) {
	                    aNode.children().forEach(function (y) {
	                        var message = "Optional properties are not allowed in "
	                            + propName + ": " + y.lowLevel().key() + "?";
	                        var issue = createIssue(hl.IssueCode.INVALID_PROPERTY, message, node, false);
	                        v.accept(issue);
	                    });
	                });
	            }
	            var def = node.asElement().definition();
	            if (node.optional() && def.universe().version() == "RAML10") {
	                var prop = node.property();
	                var isParam = universeHelpers.isQueryParametersProperty(prop)
	                    || universeHelpers.isUriParametersProperty(prop)
	                    || universeHelpers.isHeadersProperty(prop);
	                if (!universeHelpers.isMethodType(def) && !(universeHelpers.isTypeDeclarationType(def) && isParam)) {
	                    var issue = createIssue(hl.IssueCode.MISSED_CONTEXT_REQUIREMENT, "Only method nodes can be optional", node, false);
	                    v.accept(issue);
	                }
	            }
	        }
	    };
	    return OptionalPropertiesValidator;
	}());
	var UriParametersValidator = (function () {
	    function UriParametersValidator() {
	    }
	    UriParametersValidator.prototype.validate = function (node, v) {
	        var def = node.definition();
	        var baseUriPropName = universes.Universe10.Api.properties.baseUri.name;
	        var baseUriParamsPropName = universes.Universe10.Api.properties.baseUriParameters.name;
	        var uriPropName = universes.Universe10.Resource.properties.relativeUri.name;
	        var uriParamsPropName = universes.Universe10.ResourceBase.properties.uriParameters.name;
	        if (universeHelpers.isApiSibling(def)) {
	            this.inspectParameters(node, v, baseUriPropName, baseUriParamsPropName);
	        }
	        else if (universeHelpers.isResourceType(def)) {
	            var rootNode = node.root();
	            this.inspectParameters(node, v, baseUriPropName, baseUriParamsPropName, rootNode);
	            this.inspectParameters(node, v, uriPropName, uriParamsPropName);
	        }
	        else if (universeHelpers.isResourceTypeType(def)) {
	            var rootNode = node.root();
	            this.inspectParameters(node, v, baseUriPropName, baseUriParamsPropName, rootNode);
	        }
	    };
	    UriParametersValidator.prototype.inspectParameters = function (node, v, uriPropName, paramsPropName, rootNode) {
	        rootNode = rootNode || node;
	        var uriValue = '';
	        var uriAttr = rootNode.attr(uriPropName);
	        if (uriAttr) {
	            uriValue = uriAttr.value();
	            if (!uriValue) {
	                uriValue = '';
	            }
	        }
	        var paramElements = node.elementsOfKind(paramsPropName);
	        paramElements.forEach(function (x) {
	            var nameAttr = x.attr(universes.Universe10.TypeDeclaration.properties.name.name);
	            if (nameAttr) {
	                var name = nameAttr.value();
	                if (name != null) {
	                    if (uriValue.indexOf('{' + name + '}') < 0) {
	                        if (universeHelpers.isResourceTypeType(node.definition())) {
	                            if (name.indexOf('<<') >= 0) {
	                                return;
	                            }
	                        }
	                        var propNameReadable = pluralize.singular(changeCase.sentence(paramsPropName));
	                        var message = changeCase.ucFirst(propNameReadable) + " unused";
	                        var issue = createIssue(hl.IssueCode.ILLEGAL_PROPERTY_VALUE, message, x, false);
	                        v.accept(issue);
	                    }
	                }
	            }
	        });
	    };
	    return UriParametersValidator;
	}());
	var TemplateCyclesDetector = (function () {
	    function TemplateCyclesDetector() {
	        this.nameProperty = universes.Universe10.ResourceType.properties.name.name;
	    }
	    TemplateCyclesDetector.prototype.validate = function (node, v) {
	        var definition = node.definition();
	        if (!(universeHelpers.isLibraryBaseSibling(definition) || universeHelpers.isApiType(definition))) {
	            return;
	        }
	        var resourceTypesProp = universes.Universe10.LibraryBase.properties.resourceTypes.name;
	        var typeProp = universes.Universe10.ResourceBase.properties.type.name;
	        var traitsProp = universes.Universe10.LibraryBase.properties.traits.name;
	        var isProp = universes.Universe10.MethodBase.properties.is.name;
	        var allResourceTypes = search.globalDeclarations(node)
	            .filter(function (x) { return universeHelpers.isResourceTypeType(x.definition()); });
	        var alltraits = search.globalDeclarations(node)
	            .filter(function (x) { return universeHelpers.isTraitType(x.definition()); });
	        this.checkCycles(allResourceTypes, typeProp, v);
	        this.checkCycles(alltraits, isProp, v);
	    };
	    TemplateCyclesDetector.prototype.checkCycles = function (templates, propName, v) {
	        var _this = this;
	        var templatesMap = {};
	        templates.forEach(function (x) {
	            var name = _this.templateName(x);
	            templatesMap[name] = x;
	        });
	        var templatesWithCycle = {};
	        templates.forEach(function (template) {
	            var name = _this.templateName(template);
	            if (templatesWithCycle[name]) {
	                //skip checking templates which are already known to have cycles in definition;
	                return;
	            }
	            _this.findCyclesInDefinition(template, propName, templatesMap).forEach(function (cycle) {
	                //mark templates which have cycles in definitions
	                cycle.forEach(function (x) { return templatesWithCycle[x] = true; });
	                cycle = cycle.reverse();
	                var message = toReadableName(template.definition().nameId())
	                    + " definition contains cycle: " + cycle.join(" -> ");
	                var issue = createIssue(hl.IssueCode.ILLEGAL_PROPERTY_VALUE, message, template, false);
	                v.accept(issue);
	            });
	        });
	    };
	    TemplateCyclesDetector.prototype.templateName = function (node) {
	        var nameAttribute = node.attr(this.nameProperty);
	        if (!nameAttribute) {
	            return null;
	        }
	        return nameAttribute.value();
	    };
	    TemplateCyclesDetector.prototype.findCyclesInDefinition = function (node, propName, templatesMap, occuredTemplates) {
	        if (occuredTemplates === void 0) { occuredTemplates = {}; }
	        var name = this.templateName(node);
	        if (occuredTemplates[name]) {
	            return [[name]];
	        }
	        var nextOccuredTemplates = {};
	        Object.keys(occuredTemplates).forEach(function (x) { return nextOccuredTemplates[x] = occuredTemplates[x]; });
	        nextOccuredTemplates[name] = true;
	        var occuredCycles = [];
	        var templatesRefs = node.attributes(propName);
	        for (var i = 0; i < templatesRefs.length; i++) {
	            var ref = templatesRefs[i];
	            var val = ref.value();
	            if (val) {
	                var refName = typeof (val) == 'string' ? val : val.valueName();
	                var template = templatesMap[refName];
	                if (template != null) {
	                    var newCycles = this.findCyclesInDefinition(template, propName, templatesMap, nextOccuredTemplates);
	                    newCycles.forEach(function (x) { return occuredCycles.push(x); });
	                }
	            }
	        }
	        occuredCycles.forEach(function (x) { return x.push(name); });
	        return occuredCycles;
	    };
	    return TemplateCyclesDetector;
	}());
	function isJson(s) {
	    return s.indexOf("json") != -1;
	}
	exports.isJson = isJson;
	function isXML(s) {
	    return s.indexOf("xml") != -1;
	}
	exports.isXML = isXML;
	function getMediaType(node) {
	    var vl = getMediaType2(node);
	    if (vl == 'body') {
	        var rootMedia = node.root().attr("mediaType");
	        if (rootMedia) {
	            return rootMedia.value();
	        }
	        return null;
	    }
	    return vl;
	}
	exports.getMediaType = getMediaType;
	function getMediaType2(node) {
	    if (node.parent()) {
	        var pc = node.parent().definition();
	        if (pc.key() == universes.Universe08.BodyLike) {
	            return node.parent().name();
	        }
	        if (node.parent().parent()) {
	            var ppc = node.parent().parent().definition().key();
	            if (ppc == universes.Universe08.Response || ppc == universes.Universe10.Response) {
	                if (node.parent().property().nameId() == universes.Universe08.Response.properties.headers.name) {
	                    return null;
	                }
	                return node.parent().name();
	            }
	            if (ppc == universes.Universe08.Method || ppc == universes.Universe10.Method) {
	                if (node.parent().property().nameId() == universes.Universe10.MethodBase.properties.queryParameters.name
	                    || node.parent().property().nameId() == universes.Universe10.MethodBase.properties.headers.name) {
	                    return null;
	                }
	                return node.parent().name();
	            }
	        }
	    }
	    return null;
	}
	var localError = function (node, c, w, message, p, prop) {
	    var contents = node.lowLevel().unit() && node.lowLevel().unit().contents();
	    var contentLength = contents && contents.length;
	    var st = node.lowLevel().start();
	    var et = node.lowLevel().end();
	    if (contentLength && contentLength < et) {
	        et = contentLength - 1;
	    }
	    if (node.lowLevel().key() && node.lowLevel().keyStart()) {
	        var ks = node.lowLevel().keyStart();
	        if (ks > 0) {
	            st = ks;
	        }
	        var ke = node.lowLevel().keyEnd();
	        if (ke > 0) {
	            et = ke;
	        }
	    }
	    if (et < st) {
	        et = st + 1;
	        //this happens for empty APIs, when we basically have nothing to parse
	        if (node.isElement()) {
	            var definition = node.definition();
	            if (universeHelpers.isApiType(definition)) {
	                st = contentLength == 0 ? 0 : contentLength - 1;
	                et = st;
	            }
	        }
	    }
	    if (prop && !prop.getAdapter(services.RAMLPropertyService).isMerged() && node.parent() == null) {
	        var nm = _.find(node.lowLevel().children(), function (x) { return x.key() == prop.nameId(); });
	        if (nm) {
	            var ks = nm.keyStart();
	            var ke = nm.keyEnd();
	            if (ks > 0 && ke > ks) {
	                st = ks;
	                et = ke;
	            }
	        }
	    }
	    return {
	        code: c,
	        isWarning: w,
	        message: message,
	        node: node,
	        start: st,
	        end: et,
	        path: p ? (node.lowLevel().unit() ? node.lowLevel().unit().path() : "") : null,
	        extras: [],
	        unit: node ? node.lowLevel().unit() : null
	    };
	};
	var localLowLevelError = function (node, highLevelAnchor, issueCode, isWarning, message, path) {
	    var contents = node.unit() && node.unit().contents();
	    var contentLength = contents && contents.length;
	    var st = node.start();
	    var et = node.end();
	    if (contentLength && contentLength >= et) {
	        et = contentLength - 1;
	    }
	    if (node.key() && node.keyStart()) {
	        var ks = node.keyStart();
	        if (ks > 0) {
	            st = ks;
	        }
	        var ke = node.keyEnd();
	        if (ke > 0) {
	            et = ke;
	        }
	    }
	    return {
	        code: issueCode,
	        isWarning: isWarning,
	        message: message,
	        node: highLevelAnchor,
	        start: st,
	        end: et,
	        path: path ? (node.unit() ? node.unit().path() : "") : null,
	        extras: [],
	        unit: node ? node.unit() : null
	    };
	};
	function createIssue(c, message, node, w) {
	    if (w === void 0) { w = false; }
	    //console.log(node.name()+node.lowLevel().start()+":"+node.id());
	    var original = null;
	    var pr = null;
	    if (node.lowLevel() instanceof proxy.LowLevelProxyNode) {
	        var proxyNode = node.lowLevel();
	        while (!proxyNode.primaryNode()) {
	            if (!original) {
	                original = localError(node, c, w, message, true, pr);
	            }
	            node = node.parent();
	            proxyNode = node.lowLevel();
	        }
	    }
	    if (node) {
	        pr = node.property();
	        if (node.lowLevel().unit() != node.root().lowLevel().unit()) {
	            original = localError(node, c, w, message, true, pr);
	            var v = node.lowLevel().unit();
	            if (v) {
	            }
	            while (node.lowLevel().unit() != node.root().lowLevel().unit()) {
	                pr = node.property();
	                node = node.parent();
	            }
	        }
	    }
	    if (original) {
	        if (node.property() && node.property().nameId() == universes.Universe10.FragmentDeclaration.properties.uses.name && node.parent() != null) {
	            pr = node.property(); //FIXME there should be other cases
	            node = node.parent();
	        }
	    }
	    var error = localError(node, c, w, message, false, pr);
	    if (original) {
	        error.extras.push(original);
	    }
	    //console.log(error.start+":"+error.end)
	    return error;
	}
	exports.createIssue = createIssue;
	function createLLIssue(issueCode, message, node, rootCalculationAnchor, isWarning) {
	    if (isWarning === void 0) { isWarning = false; }
	    var original = null;
	    if (node) {
	        if (rootCalculationAnchor.lowLevel().unit() != rootCalculationAnchor.root().lowLevel().unit()) {
	            original = localLowLevelError(node, rootCalculationAnchor, issueCode, isWarning, message, true);
	            var v = rootCalculationAnchor.lowLevel().unit();
	            if (v) {
	                message = message + " " + v.path();
	            }
	            while (rootCalculationAnchor.lowLevel().unit() != rootCalculationAnchor.root().lowLevel().unit()) {
	                rootCalculationAnchor = rootCalculationAnchor.parent();
	            }
	        }
	    }
	    if (original) {
	        if (rootCalculationAnchor.property() && rootCalculationAnchor.property().nameId()
	            == universes.Universe10.FragmentDeclaration.properties.uses.name && rootCalculationAnchor.parent() != null) {
	            rootCalculationAnchor = rootCalculationAnchor.parent();
	        }
	    }
	    var error = localLowLevelError(node, rootCalculationAnchor, issueCode, isWarning, message, false);
	    if (original) {
	        error.extras.push(original);
	    }
	    //console.log(error.start+":"+error.end)
	    return error;
	}
	exports.createLLIssue = createLLIssue;
	function validateResponseString(v) {
	    if (v.length != 3) {
	        return new Error("Status code should be 3 digits number with optional 'x' as wildcards");
	    }
	    for (var i = 0; i < v.length; i++) {
	        var c = v[i];
	        if (!_.find(['0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'x', 'X'], function (x) { return x == c; })) {
	            return new Error("Status code should be 3 digits number with optional 'x' as wildcards");
	        }
	    }
	    return null;
	}
	exports.validateResponseString = validateResponseString;
	//# sourceMappingURL=linter.js.map

/***/ },
/* 26 */
/***/ function(module, exports, __webpack_require__) {

	/// <reference path="../../../typings/main.d.ts" />
	"use strict";
	var defs = __webpack_require__(33);
	var yaml = __webpack_require__(70);
	var _ = __webpack_require__(61);
	var def = defs;
	var hlimpl = __webpack_require__(16);
	var proxy = __webpack_require__(37);
	var search = __webpack_require__(27);
	var universes = __webpack_require__(30);
	var universeHelpers = __webpack_require__(14);
	var services = defs;
	var KeyMatcher = (function () {
	    function KeyMatcher(_props) {
	        this._props = _props;
	        this.parentValue = _.find(_props, function (x) { return x.isFromParentValue(); });
	        this.parentKey = _.find(_props, function (x) { return x.isFromParentKey(); });
	        this.canBeValue = _.find(_props, function (x) { return x.canBeValue(); });
	    }
	    KeyMatcher.prototype.add = function (p) {
	        this._props.push(p);
	    };
	    KeyMatcher.prototype.match = function (key) {
	        var _this = this;
	        var _res = null;
	        var lastPref = "";
	        this._props.forEach(function (p) {
	            if (p.getAdapter(services.RAMLPropertyService).isSystem()) {
	                return;
	            }
	            if (p != _this.parentValue && p != _this.parentKey && p.matchKey(key)) {
	                if (p.keyPrefix() != null) {
	                    if (p.keyPrefix().length >= lastPref.length) {
	                        lastPref = p.keyPrefix();
	                        _res = p;
	                    }
	                }
	                else {
	                    _res = p;
	                    lastPref = p.nameId();
	                }
	            }
	        });
	        return _res;
	    };
	    return KeyMatcher;
	}());
	function getAllOptions(c, deep) {
	    if (deep === void 0) { deep = 0; }
	    if (deep > 20) {
	        return [];
	    }
	    try {
	        var result = [];
	        var tp = c.leftType();
	        if (tp) {
	            result.push(tp);
	        }
	        var r = c.rightType();
	        if (r) {
	            if (r.hasUnionInHierarchy()) {
	                var options = getAllOptions(r.unionInHierarchy(), deep + 1);
	                result = result.concat(options);
	            }
	            else {
	                result.push(r);
	            }
	        }
	        return result;
	    }
	    finally {
	    }
	}
	var ad = 0;
	var BasicNodeBuilder = (function () {
	    function BasicNodeBuilder() {
	        this.shouldDescriminate = false;
	    }
	    BasicNodeBuilder.prototype.process = function (node, childrenToAdopt) {
	        var _this = this;
	        var nn = node.lowLevel();
	        var cv = node;
	        cv._mergedChildren = null;
	        var cha = nn._node ? nn._node : nn;
	        try {
	            if (cha['currentChildren']) {
	                return cha['currentChildren'];
	            }
	            if (!node.definition()) {
	                return;
	            }
	            if (node.parent() == null && (!this.shouldDescriminate)) {
	                this.shouldDescriminate = true;
	                try {
	                    var children = this.process(node, childrenToAdopt);
	                    var ts = node;
	                    ts._children = children;
	                    var t = doDescrimination(node);
	                    if (t) {
	                        ts.patchType(t);
	                    }
	                    var children = this.process(node, childrenToAdopt);
	                    ts._children = children;
	                }
	                finally {
	                    this.shouldDescriminate = false;
	                }
	            }
	            if (node.definition().hasUnionInHierarchy()) {
	                if (true &&
	                    (node.parent() && node.property().nameId() == universes.Universe10.LibraryBase.properties.annotations.name)) {
	                    var optins = getAllOptions(node.definition().unionInHierarchy());
	                    var actualResult = null;
	                    var bestResult = null;
	                    var bestType = null;
	                    var bestCount = 1000;
	                    var llnode = node;
	                    optins.forEach(function (x) {
	                        if (!actualResult) {
	                            //TODO ADD UNION + Descriminator
	                            if (!(x).hasUnionInHierarchy()) {
	                                var tp = llnode.patchType(x);
	                                if (ad == 0) {
	                                    ad++;
	                                    try {
	                                        var result = _this.process(node, childrenToAdopt);
	                                        var uc = 0;
	                                        for (var i = 0; i < result.length; i++) {
	                                            if (result[i].isUnknown()) {
	                                                uc++;
	                                            }
	                                        }
	                                        if (uc == 0) {
	                                            actualResult = result;
	                                        }
	                                        if (bestCount > uc) {
	                                            bestCount = uc;
	                                            bestResult = result;
	                                            bestType = x;
	                                        }
	                                    }
	                                    finally {
	                                        ad--;
	                                    }
	                                }
	                            }
	                        }
	                    });
	                    if (actualResult) {
	                        llnode.patchType(bestType);
	                        return actualResult;
	                    }
	                    if (bestResult) {
	                        llnode.patchType(bestType);
	                    }
	                }
	            }
	            var km = new KeyMatcher(node.definition().allProperties());
	            if (node.parent() == null || node.lowLevel().includePath()) {
	                var u = node.definition().universe();
	                if (u.version() == "RAML10") {
	                    if (!node.definition().property("uses")) {
	                        u.type("FragmentDeclaration").allProperties().forEach(function (x) { return km.add(x); });
	                    }
	                }
	            }
	            var aNode = node;
	            var allowsQuestion = aNode._allowQuestion || node.definition().getAdapter(services.RAMLService).getAllowQuestion();
	            var res = [];
	            //cha['currentChildren']=res;
	            if (km.parentKey) {
	                if (node.lowLevel().key()) {
	                    var keyAttr = new hlimpl.ASTPropImpl(node.lowLevel(), node, km.parentKey.range(), km.parentKey, true);
	                    res.push(keyAttr);
	                    var isDefaultMediaType = node.property()
	                        && universeHelpers.isBodyProperty(node.property())
	                        && node.lowLevel().key() == node.property().nameId();
	                    if (isDefaultMediaType) {
	                        var isInsideTraitOrResourceType = isInTtraitOrResourceType(aNode);
	                        if (!isInsideTraitOrResourceType && aNode._computedKey) {
	                            keyAttr.overrideValue(aNode._computedKey);
	                        }
	                    }
	                }
	                if (node.lowLevel().valueKind() === yaml.Kind.SEQ) {
	                    var error = new hlimpl.BasicASTNode(node.lowLevel(), aNode);
	                    error.errorMessage = "" + node.definition().nameId() + " definition should be a map";
	                    res.push(error);
	                    return res;
	                }
	            }
	            if (node.lowLevel().value()) {
	                if (km.parentValue) {
	                    res.push(new hlimpl.ASTPropImpl(node.lowLevel(), node, km.parentValue.range(), km.parentValue));
	                }
	                else if (km.canBeValue) {
	                    var s = node.lowLevel().value();
	                    if (typeof s == 'string' && s.trim().length > 0) {
	                        //if (km.canBeValue.nameId()==universes.Universe10.Resource.properties.signature.name){
	                        //      if (s.trim().charAt(0)=='('){
	                        //          //TODO BETTER DECITION current one prevents completion from working correctly
	                        //          //in few other cases
	                        //          res.push(new hlimpl.ASTPropImpl(node.lowLevel(), node, km.canBeValue.range(), km.canBeValue));
	                        //      }
	                        //}
	                        //else {
	                        res.push(new hlimpl.ASTPropImpl(node.lowLevel(), node, km.canBeValue.range(), km.canBeValue));
	                    }
	                }
	            }
	            else {
	            }
	            aNode._children = res;
	            if (!aNode.definition().getAdapter(services.RAMLService).isUserDefined()) {
	                if (aNode.definition().key() == universes.Universe08.Api || aNode.definition().key() == universes.Universe10.Api) {
	                    var uses = childrenToAdopt.filter(function (x) { return x.key() == "uses"; });
	                    res = this.processChildren(uses, aNode, res, allowsQuestion, km);
	                    var types = childrenToAdopt.filter(function (x) { return x.key() == "types"; });
	                    res = this.processChildren(types, aNode, res, allowsQuestion, km);
	                    var other = childrenToAdopt.filter(function (x) { return (x.key() != "types" && x.key() != "uses"); });
	                    res = this.processChildren(other, aNode, res, allowsQuestion, km);
	                }
	                else {
	                    res = this.processChildren(childrenToAdopt, aNode, res, allowsQuestion, km);
	                }
	            }
	            else {
	                res = this.processChildren(childrenToAdopt, aNode, res, allowsQuestion, km);
	            }
	            aNode._children = res;
	            return res;
	        }
	        finally {
	        }
	    };
	    BasicNodeBuilder.prototype.isTypeDeclarationShortcut = function (node, property) {
	        var isTypeDeclarationType = universeHelpers.isTypeProperty(property);
	        var isTypeDeclaration = node.definition() && universeHelpers.isTypeDeclarationTypeOrDescendant(node.definition());
	        if (isTypeDeclaration && isTypeDeclarationType && node.lowLevel() && node.lowLevel().valueKind() === yaml.Kind.SEQ) {
	            return true;
	        }
	        return false;
	    };
	    BasicNodeBuilder.prototype.processChildren = function (childrenToAdopt, aNode, res, allowsQuestion, km) {
	        var _this = this;
	        var typeDeclarationName = universes.Universe10.TypeDeclaration.name;
	        var typePropertyName = universes.Universe10.TypeDeclaration.properties.type.name;
	        if (aNode.definition() && aNode.definition().isAssignableFrom(typeDeclarationName) && aNode.lowLevel() && (km.canBeValue && km.canBeValue.nameId() === typePropertyName) && aNode.lowLevel()._node && aNode.lowLevel()._node.value && aNode.lowLevel()._node.value.kind === yaml.Kind.SEQ) {
	            childrenToAdopt.forEach(function (child) {
	                var property = new hlimpl.ASTPropImpl(child, aNode, km.canBeValue.range(), km.canBeValue);
	                res.push(property);
	            });
	            return res;
	        }
	        childrenToAdopt.forEach(function (x) {
	            if (km.canBeValue && _this.isTypeDeclarationShortcut(aNode, km.canBeValue)) {
	                res.push(new hlimpl.ASTPropImpl(x, aNode, km.canBeValue.range(), km.canBeValue));
	                return;
	            }
	            var key = x.key();
	            //if (x.optional()&&!allowsQuestion) {
	            //    return;
	            //}
	            var p = key != null ? km.match(key) : null;
	            if (p != null) {
	                var range = p.range();
	                if (p.isAnnotation() && key != "annotations") {
	                    var pi = new hlimpl.ASTPropImpl(x, aNode, range, p);
	                    res.push(pi);
	                    return;
	                }
	                var um = false;
	                var multyValue = p.isMultiValue();
	                if (range.isArray()) {
	                    multyValue = true;
	                    range = range.array().componentType();
	                    um = true;
	                }
	                else if (range.hasArrayInHierarchy()) {
	                    multyValue = true;
	                    um = true;
	                }
	                //TODO DESCRIMINATORS
	                if (range.hasValueTypeInHierarchy()) {
	                    var ch = x.children();
	                    var seq = (x.valueKind() == yaml.Kind.SEQ);
	                    if ((seq && ch.length > 0 || ch.length > 1) && multyValue) {
	                        var values = [];
	                        ch.forEach(function (y) {
	                            var pi = new hlimpl.ASTPropImpl(y, aNode, range, p);
	                            res.push(pi);
	                            values.push(y.value());
	                        });
	                        if (p.isInherited()) {
	                            aNode.setComputed(p.nameId(), values);
	                        }
	                    }
	                    else {
	                        if (p.isInherited()) {
	                            aNode.setComputed(p.nameId(), x.value());
	                        }
	                        var attrNode = new hlimpl.ASTPropImpl(x, aNode, range, p);
	                        if ((seq || x.valueKind() == yaml.Kind.MAP)) {
	                            var rng = p.range().nameId();
	                            if (!p.getAdapter(services.RAMLPropertyService).isExampleProperty()) {
	                                if (rng == 'StringType') {
	                                    rng = "string";
	                                }
	                                if (rng == 'NumberType') {
	                                    rng = "number";
	                                }
	                                if (rng == 'BooleanType') {
	                                    rng = "boolean";
	                                }
	                                if (rng == "string" || rng == "number" || rng == "boolean") {
	                                    if (!x.isAnnotatedScalar()) {
	                                        attrNode.errorMessage = "property '" + p.groupName() + "' must be a " + rng;
	                                        if (x.children().length == 0 && p.groupName() == "enum") {
	                                            attrNode.errorMessage = "enum is empty";
	                                            if (x.valueKind() == yaml.Kind.MAP) {
	                                                attrNode.errorMessage = "the value of enum must be an array";
	                                            }
	                                        }
	                                    }
	                                }
	                            }
	                        }
	                        res.push(attrNode);
	                    }
	                    //}
	                    return;
	                }
	                else {
	                    var rs = [];
	                    //now we need determine actual type
	                    aNode._children = res;
	                    if (x.value() != null && (typeof x.value() == 'string' || typeof x.value() == 'boolean' || typeof x.value() == 'number')) {
	                        if (("" + x.value()).trim().length > 0) {
	                            var c = p.range();
	                            if (!c.allProperties().some(function (x) {
	                                var srv = x;
	                                if (srv) {
	                                    return srv.canBeValue() && srv.isFromParentValue();
	                                }
	                                return false;
	                            })) {
	                                var bnode = new hlimpl.BasicASTNode(x, aNode);
	                                bnode.getLowLevelEnd = function () {
	                                    return -1;
	                                };
	                                bnode.getLowLevelStart = function () {
	                                    return -1;
	                                };
	                                bnode.knownProperty = p;
	                                res.push(bnode);
	                            }
	                        }
	                    }
	                    if (!p.isMerged()) {
	                        if (multyValue) {
	                            if (p.getAdapter(services.RAMLPropertyService).isEmbedMap()) {
	                                var chld = x.children();
	                                var newChld = [];
	                                var hasSequenceComposition = false;
	                                chld.forEach(function (n) {
	                                    if (n.kind() == yaml.Kind.INCLUDE_REF) {
	                                        if (aNode.universe().version() == "RAML08") {
	                                            n.children().forEach(function (y) {
	                                                var node = new hlimpl.ASTNodeImpl(y, aNode, range, p);
	                                                node._allowQuestion = allowsQuestion;
	                                                rs.push(node);
	                                                hasSequenceComposition = true;
	                                            });
	                                        }
	                                        else {
	                                            newChld.push(n);
	                                        }
	                                    }
	                                    else {
	                                        newChld.push(n);
	                                    }
	                                });
	                                chld = newChld;
	                                if (chld.length == 0) {
	                                    if (p.range().key() == universes.Universe08.ResourceType) {
	                                        if (!hasSequenceComposition) {
	                                            var error = new hlimpl.BasicASTNode(x, aNode);
	                                            error.errorMessage = "property: '" + p.nameId() + "' must be a map";
	                                            res.push(error);
	                                        }
	                                    }
	                                    if (x.valueKind() == yaml.Kind.SCALAR) {
	                                        if (p.range().key() == universes.Universe08.AbstractSecurityScheme) {
	                                            var error = new hlimpl.BasicASTNode(x.parent(), aNode);
	                                            error.errorMessage = "property: '" + p.nameId() + "' must be a map";
	                                            res.push(error);
	                                        }
	                                    }
	                                }
	                                var exit = false;
	                                chld.forEach(function (y) {
	                                    if (exit) {
	                                        return;
	                                    }
	                                    //TODO TRACK GROUP KEY
	                                    var cld = y.children();
	                                    if (!y.key() && cld.length == 1) {
	                                        if (aNode.universe().version() == "RAML10" && !aNode.parent()) {
	                                            var bnode = new hlimpl.BasicASTNode(x, aNode);
	                                            res.push(bnode);
	                                            bnode.needMap = true;
	                                            bnode.knownProperty = p;
	                                            exit = true;
	                                        }
	                                        else {
	                                            var node = new hlimpl.ASTNodeImpl(cld[0], aNode, range, p);
	                                            node._allowQuestion = allowsQuestion;
	                                            rs.push(node);
	                                        }
	                                    }
	                                    else {
	                                        if (aNode.universe().version() == "RAML10") {
	                                            var node = new hlimpl.ASTNodeImpl(y, aNode, range, p);
	                                            node._allowQuestion = allowsQuestion;
	                                            rs.push(node);
	                                        }
	                                        else {
	                                            var bnode = new hlimpl.BasicASTNode(y, aNode);
	                                            res.push(bnode);
	                                            if (y.key()) {
	                                                bnode.needSequence = true;
	                                            }
	                                        }
	                                    }
	                                });
	                            }
	                            else {
	                                var filter = {};
	                                var inherited = [];
	                                if (range instanceof defs.NodeClass) {
	                                    var nc = range;
	                                    if (nc.getAdapter(services.RAMLService).getCanInherit().length > 0) {
	                                        nc.getAdapter(services.RAMLService).getCanInherit().forEach(function (v) {
	                                            var originalValue = aNode.computedValue(v);
	                                            var actualValue = Array.isArray(originalValue) ? originalValue : [originalValue];
	                                            for (var pos = 0; pos < actualValue.length; pos++) {
	                                                var vl = actualValue[pos];
	                                                if (vl && p.nameId() == universes.Universe10.Response.properties.body.name) {
	                                                    var exists = _.find(x.children(), function (x) { return x.key() == vl; });
	                                                    if (true) {
	                                                        //we can create inherited node;
	                                                        var pc = aNode.parent().definition().key();
	                                                        var node = new hlimpl.ASTNodeImpl(x, aNode, range, p);
	                                                        node._computedKey = vl;
	                                                        if (pc == universes.Universe10.MethodBase || pc == universes.Universe08.MethodBase) {
	                                                            node.setComputed("form", "true"); //FIXME
	                                                        }
	                                                        var isInsideTraitOrResourceType = isInTtraitOrResourceType(aNode);
	                                                        var t = descriminate(p, aNode, node);
	                                                        if (t) {
	                                                            if (!isInsideTraitOrResourceType) {
	                                                                t.setName(vl);
	                                                            }
	                                                            node.patchType(t);
	                                                        }
	                                                        var ch = node.children();
	                                                        //this are false unknowns actual unknowns will be reported by parent node
	                                                        node._children = ch.filter(function (x) { return !x.isUnknown(); });
	                                                        node._allowQuestion = allowsQuestion;
	                                                        if (!exists) {
	                                                            inherited.push(node);
	                                                        }
	                                                        node.children().forEach(function (x) {
	                                                            if (x.property().getAdapter(services.RAMLPropertyService).isKey()) {
	                                                                var atr = x;
	                                                                atr._computed = true;
	                                                                return;
	                                                            }
	                                                            if (x.isElement()) {
	                                                                if (!x.property().getAdapter(services.RAMLPropertyService).isMerged()) {
	                                                                    filter[x.property().nameId()] = true;
	                                                                }
	                                                            }
	                                                            if (x.property().isAnnotation()) {
	                                                                var atr = x;
	                                                                var vl = atr.value();
	                                                                var strVal = "";
	                                                                if (vl instanceof hlimpl.StructuredValue) {
	                                                                    strVal = vl.valueName();
	                                                                }
	                                                                else {
	                                                                    strVal = "" + vl;
	                                                                }
	                                                                filter["(" + strVal + ")"] = true;
	                                                            }
	                                                            else {
	                                                                filter[x.name()] = true;
	                                                            }
	                                                        });
	                                                        var ap = node.definition().allProperties();
	                                                        ap.forEach(function (p) {
	                                                            if (p.getAdapter(services.RAMLPropertyService).isKey()) {
	                                                                return;
	                                                            }
	                                                            if (p.getAdapter(services.RAMLPropertyService).isSystem()) {
	                                                                return;
	                                                            }
	                                                            if (node.lowLevel().children().some(function (x) { return x.key() == p.nameId(); })) {
	                                                                filter[p.nameId()] = true;
	                                                            }
	                                                        });
	                                                        node._computed = true;
	                                                    }
	                                                }
	                                            }
	                                        });
	                                    }
	                                }
	                                var parsed = [];
	                                if (x.children().length == 0) {
	                                    if (x.valueKind() == yaml.Kind.SEQ) {
	                                        if (p.range().key() == universes.Universe08.Parameter) {
	                                            var error = new hlimpl.BasicASTNode(x, aNode);
	                                            error.errorMessage = "property: '" + p.nameId() + "' must be a map";
	                                            res.push(error);
	                                        }
	                                    }
	                                }
	                                if (p.nameId() === "documentation" && x.valueKind() !== yaml.Kind.SEQ) {
	                                    if (!aNode.definition().getAdapter(services.RAMLService).isUserDefined()) {
	                                        var error = new hlimpl.BasicASTNode(x, aNode);
	                                        error.errorMessage = "property: '" + p.nameId() + "' should be a sequence";
	                                        res.push(error);
	                                    }
	                                }
	                                else {
	                                    x.children().forEach(function (y) {
	                                        if (filter[y.key()]) {
	                                            return;
	                                        }
	                                        if (y.valueKind() == yaml.Kind.SEQ) {
	                                            y.children().forEach(function (z) {
	                                                var node = new hlimpl.ASTNodeImpl(z, aNode, range, p);
	                                                node._allowQuestion = allowsQuestion;
	                                                node.setNamePatch(y.key());
	                                                parsed.push(node);
	                                            });
	                                            if (y.children().length == 0) {
	                                                var error = new hlimpl.BasicASTNode(y, aNode);
	                                                if (p.range().key() == universes.Universe08.Parameter) {
	                                                    error.errorMessage = "named parameter needs at least one type";
	                                                }
	                                                else {
	                                                    error.errorMessage = "node should have at least one member value";
	                                                }
	                                                res.push(error);
	                                            }
	                                        }
	                                        else {
	                                            var node = new hlimpl.ASTNodeImpl(y, aNode, range, p);
	                                            var dc = p.domain().key();
	                                            if (p.nameId() == "body" && (dc == universes.Universe08.MethodBase || dc == universes.Universe10.MethodBase)) {
	                                                node.setComputed("form", "true"); //FIXME
	                                            }
	                                            node._allowQuestion = allowsQuestion;
	                                            parsed.push(node);
	                                        }
	                                    });
	                                }
	                                if (parsed.length > 0) {
	                                    parsed.forEach(function (x) { return rs.push(x); });
	                                }
	                                else {
	                                    inherited.forEach(function (x) { return rs.push(x); });
	                                }
	                            }
	                        }
	                        else {
	                            //var y=x.children()[0];
	                            rs.push(new hlimpl.ASTNodeImpl(x, aNode, range, p));
	                        }
	                    }
	                    else {
	                        var node = new hlimpl.ASTNodeImpl(x, aNode, range, p);
	                        node._allowQuestion = allowsQuestion;
	                        rs.push(node);
	                    }
	                    aNode._children = aNode._children.concat(rs);
	                    res = res.concat(rs);
	                    rs.forEach(function (x) {
	                        var rt = descriminate(p, aNode, x);
	                        if (rt && rt != x.definition()) {
	                            x.patchType(rt);
	                        }
	                        x._associatedDef = null;
	                        p.childRestrictions().forEach(function (y) {
	                            x.setComputed(y.name, y.value);
	                        });
	                        var def = x.definition();
	                    });
	                }
	            }
	            else {
	                if (!(x instanceof proxy.LowLevelCompositeNode)
	                    || x.primaryNode() != null) {
	                    res.push(new hlimpl.BasicASTNode(x, aNode));
	                }
	            }
	        });
	        return res;
	    };
	    return BasicNodeBuilder;
	}());
	exports.BasicNodeBuilder = BasicNodeBuilder;
	function getType(node, expression) {
	    if (!expression) {
	        return node.definition().universe().type(universes.Universe10.StringTypeDeclaration.name);
	    }
	    var pt = node.parsedType();
	    if (pt.isString()) {
	        return (node.definition().universe().type(universes.Universe10.StringTypeDeclaration.name));
	    }
	    else if (pt.isNumber()) {
	        if (pt.isInteger()) {
	            return (node.definition().universe().type(universes.Universe10.IntegerTypeDeclaration.name));
	        }
	        return (node.definition().universe().type(universes.Universe10.NumberTypeDeclaration.name));
	    }
	    else if (pt.isBoolean()) {
	        return (node.definition().universe().type(universes.Universe10.BooleanTypeDeclaration.name));
	    }
	    else if (pt.isObject()) {
	        return (node.definition().universe().type(universes.Universe10.ObjectTypeDeclaration.name));
	    }
	    else if (pt.isArray()) {
	        return (node.definition().universe().type(universes.Universe10.ArrayTypeDeclaration.name));
	    }
	    else if (pt.isFile()) {
	        return (node.definition().universe().type(universes.Universe10.FileTypeDeclaration.name));
	    }
	    else if (pt.isDateTime()) {
	        return (node.definition().universe().type(universes.Universe10.DateTimeTypeDeclaration.name));
	    }
	    else if (pt.isDateTimeOnly()) {
	        return (node.definition().universe().type(universes.Universe10.DateTimeOnlyTypeDeclaration.name));
	    }
	    else if (pt.isDateOnly()) {
	        return (node.definition().universe().type(universes.Universe10.DateOnlyTypeDeclaration.name));
	    }
	    else if (pt.isTimeOnly()) {
	        return (node.definition().universe().type(universes.Universe10.TimeOnlyTypeDeclaration.name));
	    }
	    if (pt.isUnion()) {
	        return (node.definition().universe().type(universes.Universe10.UnionTypeDeclaration.name));
	    }
	    return (node.definition().universe().type(universes.Universe10.TypeDeclaration.name));
	}
	function desc1(p, parent, x) {
	    var tp = x.attr("type");
	    var value = "";
	    if (tp) {
	        var mn = {};
	        var c = new def.NodeClass(x.name(), x.definition().universe(), "");
	        c.getAdapter(services.RAMLService).setDeclaringNode(x);
	        c._superTypes.push(x.definition().universe().type(universes.Universe10.TypeDeclaration.name));
	        mn[tp.value()] = c;
	        var newType = getType(x, tp.value());
	        if (newType) {
	            if (newType.superTypes().length == 0) {
	                newType._superTypes.push(x.definition().universe().type(universes.Universe10.TypeDeclaration.name));
	            }
	        }
	        return newType;
	    }
	    else {
	        var propertiesName = universes.Universe10.ObjectTypeDeclaration.properties.properties.name;
	        if (p) {
	            if (p.nameId() == "body" || _.find(x.lowLevel().children(), function (x) { return x.key() === propertiesName; })) {
	                return x.definition().universe().type(universes.Universe10.ObjectTypeDeclaration.name);
	            }
	        }
	        else {
	            if (!parent && x.lowLevel() && _.find(x.lowLevel().children(), function (x) { return x.key() === propertiesName; })) {
	                return x.definition().universe().type(universes.Universe10.ObjectTypeDeclaration.name);
	            }
	        }
	        return x.definition().universe().type(universes.Universe10.StringTypeDeclaration.name);
	    }
	}
	function doDescrimination(node) {
	    try {
	        var nodeDefenitionName = node.definition().nameId();
	        var isApi = nodeDefenitionName === universes.Universe10.Api.name || nodeDefenitionName === universes.Universe08.Api.name;
	        if (!isApi && !node.property() && !node.parent() && node.definition().nameId() === hlimpl.getFragmentDefenitionName(node)) {
	            if (node.property() && node.property().nameId() === universes.Universe10.LibraryBase.properties.annotationTypes.name) {
	                return descriminate(null, null, node);
	            }
	            var result = null;
	            var subTypes = node.definition().allSubTypes();
	            subTypes.forEach(function (subType) {
	                if (!result && match(subType, node, null)) {
	                    result = subType;
	                }
	            });
	            return result;
	        }
	    }
	    catch (exception) {
	    }
	    return descriminate(node.property(), node.parent(), node);
	}
	exports.doDescrimination = doDescrimination;
	function descriminate(p, parent, x) {
	    var n = x.lowLevel();
	    if (p) {
	        if (p.nameId() == universes.Universe10.FragmentDeclaration.properties.uses.name &&
	            p.range().nameId() == universes.Universe10.Library.name) {
	        }
	    }
	    var range = p ? p.range().nameId() : x.definition().nameId();
	    if (n._node && n._node['descriminate']) {
	        return null;
	    }
	    if (n._node) {
	        n._node['descriminate'] = 1;
	    }
	    try {
	        if (range == universes.Universe10.TypeDeclaration.name) {
	            var res = desc1(p, parent, x);
	            if (p || (!p && !parent && x.lowLevel())) {
	                if (p && res != null && ((p.nameId() == universes.Universe10.MethodBase.properties.body.name
	                    || p.nameId() == universes.Universe10.Response.properties.headers.name) ||
	                    p.nameId() == universes.Universe10.MethodBase.properties.queryParameters.name)) {
	                    var ares = new defs.UserDefinedClass(x.lowLevel().key(), res.universe(), x, x.lowLevel().unit() ? x.lowLevel().unit().path() : "", "");
	                    ares._superTypes.push(res);
	                    return ares;
	                }
	                if (res != null && universeHelpers.isAnnotationTypeType(x.definition())) {
	                    var annotationType = descriminateAnnotationType(res);
	                    var ares = new defs.UserDefinedClass(x.lowLevel().key(), res.universe(), x, x.lowLevel().unit() ? x.lowLevel().unit().path() : "", "");
	                    ares._superTypes.push(annotationType);
	                    ares._superTypes.push(res);
	                    return ares;
	                }
	            }
	            if (res) {
	                return res;
	            }
	        }
	        //generic case;
	        var rt = null;
	        if (p && parent) {
	            var types = search.findAllSubTypes(p, parent);
	            if (types.length > 0) {
	                types.forEach(function (y) {
	                    if (!rt) {
	                        if (match(y, x, rt)) {
	                            rt = y;
	                        }
	                    }
	                });
	            }
	            return rt;
	        }
	    }
	    finally {
	        if (n._node) {
	            delete n._node['descriminate'];
	        }
	    }
	}
	;
	function descriminateAnnotationType(type) {
	    var arr = [type].concat(type.allSuperTypes());
	    var candidate;
	    for (var i = 0; i < arr.length; i++) {
	        var t = arr[i];
	        if (t.isUserDefined()) {
	            continue;
	        }
	        if (t.isUnion()) {
	            var ut = t;
	            var lt = ut.leftType();
	            var rt = ut.leftType();
	            var lat = descriminateAnnotationType(lt);
	            var rat = descriminateAnnotationType(lt);
	            if (lat.isAssignableFrom(rat.nameId()) && (candidate == null || lat.isAssignableFrom(candidate.nameId()))) {
	                candidate = lat;
	                continue;
	            }
	            if (rat.isAssignableFrom(lat.nameId()) && (candidate == null || rat.isAssignableFrom(candidate.nameId()))) {
	                candidate = rat;
	                continue;
	            }
	            candidate = type.universe().type(universes.Universe10.UnionTypeDeclaration.name);
	            break;
	        }
	        if (t.isArray()) {
	            candidate = type.universe().type(universes.Universe10.ArrayTypeDeclaration.name);
	            break;
	        }
	        var subTypes = t.subTypes();
	        for (var j = 0; j < subTypes.length; j++) {
	            var st = subTypes[j];
	            if (st.isAssignableFrom(universes.Universe10.TypeDeclaration.name)) {
	                if (candidate == null) {
	                    candidate = st;
	                }
	                else if (st.isAssignableFrom(candidate.nameId())) {
	                    candidate = st;
	                }
	            }
	        }
	    }
	    return candidate != null ? candidate : type.universe().type(universes.Universe10.TypeDeclaration.name);
	}
	var isInTtraitOrResourceType = function (aNode) {
	    var isInsideTraitOrResourceType = false;
	    var parent_ = aNode;
	    while (parent_) {
	        var pDef = parent_.definition();
	        if (universeHelpers.isTraitType(pDef)
	            || universeHelpers.isResourceTypeType(pDef)) {
	            isInsideTraitOrResourceType = true;
	            break;
	        }
	        parent_ = parent_.parent();
	    }
	    return isInsideTraitOrResourceType;
	};
	function match(t, r, alreadyFound) {
	    //this.vReqInitied=true;
	    if (r.isAttr() || r.isUnknown()) {
	        return false;
	    }
	    var el = r;
	    var hasSuperType = _.find(t.superTypes(), function (x) {
	        var dp = _.find(x.allProperties(), function (x) { return (x).isDescriminator(); });
	        if (dp) {
	            var a = el.attr(dp.nameId());
	            if (a) {
	                if (a.value() == t.nameId()) {
	                    return true;
	                }
	            }
	        }
	        return false;
	    });
	    if (hasSuperType) {
	        return true;
	    }
	    if (t.valueRequirements().length == 0) {
	        return false;
	    }
	    var matches = true;
	    //descriminating constraint
	    t.valueRequirements().forEach(function (x) {
	        var a = el.attr(x.name);
	        if (a) {
	            if (a.value() == x.value) {
	            }
	            else {
	                if (t.getAdapter(services.RAMLService).getConsumesRefs()) {
	                    var vl = a.value();
	                    var allSubs = [];
	                    t.superTypes().forEach(function (x) { return x.allSubTypes().forEach(function (y) {
	                        allSubs.push(y);
	                    }); });
	                    var allSubNames = [];
	                    _.unique(allSubs).forEach(function (x) {
	                        allSubNames.push(x.nameId());
	                        x.valueRequirements().forEach(function (y) {
	                            allSubNames.push(y.value);
	                        });
	                        x.getAdapter(services.RAMLService).getAliases().forEach(function (y) { return allSubNames.push(y); });
	                    });
	                    if (_.find(allSubNames, function (x) { return x == vl; })) {
	                        matches = false;
	                    }
	                }
	                else {
	                    matches = false;
	                }
	            }
	        }
	        else {
	            var m = t.getAdapter(services.RAMLService).getDefining();
	            var ms = false;
	            m.forEach(function (x) {
	                el.lowLevel().children().forEach(function (y) {
	                    if (y.key() == x) {
	                        ms = true;
	                    }
	                });
	            });
	            if (ms) {
	                matches = true;
	                return;
	            }
	            if (!alreadyFound) {
	                var pr = t.property(x.name);
	                if (pr && pr.defaultValue() == x.value) {
	                }
	                else {
	                    matches = false;
	                }
	            }
	            else {
	                matches = false;
	            }
	        }
	    });
	    return matches;
	}
	//# sourceMappingURL=builder.js.map

/***/ },
/* 27 */
/***/ function(module, exports, __webpack_require__) {

	/// <reference path="../../../typings/main.d.ts" />
	"use strict";
	var defs = __webpack_require__(33);
	var _ = __webpack_require__(61);
	var def = __webpack_require__(33);
	// import high=require("../highLevelAST");
	var hlimpl = __webpack_require__(16);
	var universes = __webpack_require__(30);
	var ramlServices = def;
	exports.declRoot = function (h) {
	    var declRoot = h;
	    while (true) {
	        if (declRoot.definition().key() == universes.Universe10.Library) {
	            break;
	        }
	        var np = declRoot.parent();
	        if (!np) {
	            break;
	        }
	        declRoot = np;
	    }
	    return declRoot;
	};
	function globalDeclarations(h) {
	    var result = [];
	    while (h.parent() != null) {
	        if (h.lowLevel().includePath()) {
	            result = result.concat(findDeclarations(h));
	        }
	        h = h.parent();
	    }
	    result = result.concat(findDeclarations(h));
	    return result;
	}
	exports.globalDeclarations = globalDeclarations;
	function mark(h, rs) {
	    var n = h.lowLevel();
	    n = n._node ? n._node : n;
	    if (n['mark']) {
	        return rs;
	    }
	    n['mark'] = rs;
	    return null;
	}
	function unmark(h) {
	    var n = h.lowLevel();
	    n = n._node ? n._node : n;
	    delete n['mark'];
	}
	function findDeclarations(h) {
	    var rs = [];
	    if (!(h instanceof hlimpl.ASTNodeImpl)) {
	        return rs;
	    }
	    h.elements().forEach(function (x) {
	        if (x.definition().key() == universes.Universe10.UsesDeclaration) {
	            var mm = x.attr("value");
	            if (mm) {
	                var unit = h.root().lowLevel().unit().resolve(mm.value());
	                if (unit != null) {
	                    unit.highLevel().children().forEach(function (x) {
	                        if (x.isElement()) {
	                            rs.push(x.asElement());
	                        }
	                    });
	                }
	            }
	        }
	        else {
	            rs.push(x);
	        }
	    });
	    return rs;
	}
	exports.findDeclarations = findDeclarations;
	function getIndent2(offset, text) {
	    var spaces = "";
	    for (var i = offset - 1; i >= 0; i--) {
	        var c = text.charAt(i);
	        if (c == ' ' || c == '\t') {
	            if (spaces) {
	                spaces += c;
	            }
	            else {
	                spaces = c;
	            }
	        }
	        else if (c == '\r' || c == '\n') {
	            return spaces;
	        }
	    }
	}
	function deepFindNode(n, offset, end, goToOtherUnits, returnAttrs) {
	    if (goToOtherUnits === void 0) { goToOtherUnits = true; }
	    if (returnAttrs === void 0) { returnAttrs = true; }
	    if (n == null) {
	        return null;
	    }
	    if (n.lowLevel()) {
	        //var node:ASTNode=<ASTNode>n;
	        if (n.lowLevel().start() <= offset && n.lowLevel().end() >= end) {
	            if (n instanceof hlimpl.ASTNodeImpl) {
	                var hn = n;
	                var all = goToOtherUnits ? hn.children() : hn.directChildren();
	                for (var i = 0; i < all.length; i++) {
	                    if (!goToOtherUnits && all[i].lowLevel().unit() != n.lowLevel().unit()) {
	                        continue;
	                    }
	                    var node = deepFindNode(all[i], offset, end, goToOtherUnits);
	                    if (node) {
	                        if (!returnAttrs && node instanceof hlimpl.ASTPropImpl) {
	                            node = node.parent();
	                        }
	                        return node;
	                    }
	                }
	                return n;
	            }
	            else if (n instanceof hlimpl.ASTPropImpl) {
	                var attr = n;
	                if (!attr.property().isKey()) {
	                    var vl = attr.value();
	                    if (vl instanceof hlimpl.StructuredValue) {
	                        var st = vl;
	                        var hl = st.toHighLevel2();
	                        if (hl) {
	                            if (!goToOtherUnits && hl.lowLevel().unit() != n.lowLevel().unit()) {
	                                return null;
	                            }
	                        }
	                        var node = deepFindNode(hl, offset, end, goToOtherUnits);
	                        if (node) {
	                            if (!returnAttrs && node instanceof hlimpl.ASTPropImpl) {
	                                node = node.parent();
	                            }
	                            return node;
	                        }
	                    }
	                    if (returnAttrs)
	                        return attr;
	                    else
	                        return attr.parent();
	                }
	                return null;
	            }
	            return null;
	        }
	    }
	    return null;
	}
	exports.deepFindNode = deepFindNode;
	function getValueAt(text, offset) {
	    var sp = -1;
	    for (var i = offset - 1; i >= 0; i--) {
	        var c = text.charAt(i);
	        if (c == '\r' || c == '\n' || c == ' ' || c == '\t' || c == '"' || c == '\'' || c == ':') {
	            sp = i + 1;
	            break;
	        }
	    }
	    var ep = -1;
	    for (var i = offset; i < text.length; i++) {
	        var c = text.charAt(i);
	        if (c == '\r' || c == '\n' || c == ' ' || c == '\t' || c == '"' || c == '\'' || c == ':') {
	            ep = i;
	            break;
	        }
	    }
	    if (sp != -1 && ep != -1) {
	        return text.substring(sp, ep);
	    }
	    return "";
	}
	function extractName(cleaned, offset) {
	    var txt = "";
	    for (var i = offset; i >= 0; i--) {
	        var c = cleaned[i];
	        if (c == ' ' || c == '\r' || c == '\n' || c == '|' || c == '[' || c == ']' || c == ':' || c == '(' || c == ')') {
	            break;
	        }
	        txt = c + txt;
	    }
	    for (var i = offset + 1; i < cleaned.length; i++) {
	        var c = cleaned[i];
	        if (c == ' ' || c == '\r' || c == '\n' || c == '|' || c == '[' || c == ']' || c == ':' || c == '(' || c == ')') {
	            break;
	        }
	        txt = txt + c;
	    }
	    return txt;
	}
	exports.extractName = extractName;
	var searchInTheValue = function (offset, content, attr, hlnode, p) {
	    if (p === void 0) { p = attr.property(); }
	    var targets = referenceTargets(p, hlnode);
	    var txt = extractName(content, offset);
	    var t = _.find(targets, function (x) { return hlimpl.qName(x, hlnode) == txt; });
	    if (t) {
	        //TODO EXTRACT COMMON OPEN NODE FUNC
	        return t;
	    }
	    if (p instanceof defs.UserDefinedProp) {
	        var up = p;
	        return up._node;
	    }
	    return null;
	};
	function findUsages(unit, offset) {
	    var decl = findDeclaration(unit, offset);
	    if (decl) {
	        if (decl instanceof hlimpl.ASTNodeImpl) {
	            var hnode = decl;
	            return { node: hnode, results: hnode.findReferences() };
	        }
	        if (decl instanceof hlimpl.ASTPropImpl) {
	        }
	    }
	    var node = deepFindNode(hlimpl.fromUnit(unit), offset, offset, false);
	    if (node instanceof hlimpl.ASTNodeImpl) {
	        return { node: node, results: node.findReferences() };
	    }
	    if (node instanceof hlimpl.ASTPropImpl) {
	        var prop = node;
	        if (prop.property().canBeValue()) {
	            return { node: prop.parent(), results: prop.parent().findReferences() };
	        }
	    }
	    return { node: null, results: [] };
	}
	exports.findUsages = findUsages;
	function referenceTargets(p0, c) {
	    var p = p0;
	    if (p.getAdapter(ramlServices.RAMLPropertyService).isTypeExpr()) {
	        var definitionNodes = globalDeclarations(c).filter(function (node) {
	            var nc = node.definition().key();
	            if (nc === universes.Universe08.GlobalSchema) {
	                return true;
	            }
	            return node.definition().isAssignableFrom(universes.Universe10.TypeDeclaration.name);
	        });
	        return definitionNodes;
	    }
	    if (p.getAdapter(ramlServices.RAMLPropertyService).isDescriminating()) {
	        var subTypes = nodesDeclaringType(p.range(), c);
	        return subTypes;
	    }
	    if (p.isReference()) {
	        var rt = p.referencesTo();
	        var subTypes = nodesDeclaringType(rt, c);
	        return subTypes;
	    }
	    if (p.range().hasValueTypeInHierarchy()) {
	        var vt = p.range().getAdapter(ramlServices.RAMLService);
	        if (vt.globallyDeclaredBy().length > 0) {
	            var definitionNodes = globalDeclarations(c).filter(function (z) { return _.find(vt.globallyDeclaredBy(), function (x) { return x == z.definition(); }) != null; });
	            return definitionNodes;
	        }
	    }
	    return [];
	}
	exports.referenceTargets = referenceTargets;
	function enumValues(p, c) {
	    if (c) {
	        var rs = [];
	        //TODO FIXME it is very very weird idea but I need to get it working right now
	        if (p.getAdapter(ramlServices.RAMLPropertyService).isTypeExpr()) {
	            var definitionNodes = globalDeclarations(c).filter(function (node) {
	                var nc = node.definition().key();
	                if (nc === universes.Universe08.GlobalSchema) {
	                    return true;
	                }
	                return (node.definition().isAssignableFrom(universes.Universe10.TypeDeclaration.name));
	                //return true;
	            });
	            rs = definitionNodes.map(function (x) { return hlimpl.qName(x, c); });
	            var de = c.definition().universe().type(universes.Universe10.TypeDeclaration.name);
	            if (de) {
	                var subTypes = de.allSubTypes();
	                rs = rs.concat(subTypes.map(function (x) { return (x).getAdapter(ramlServices.RAMLService).descriminatorValue(); }));
	            }
	            return rs;
	        }
	        else {
	            var rangeKey = p.range().key();
	            if (rangeKey == universes.Universe08.SchemaString
	                || rangeKey == universes.Universe10.SchemaString) {
	                if (p.range().universe().version() == "RAML10") {
	                    if (p.range().hasValueTypeInHierarchy()) {
	                        var definitionNodes = globalDeclarations(c).filter(function (node) {
	                            return node.definition().isAssignableFrom(universes.Universe10.TypeDeclaration.name);
	                        });
	                        rs = definitionNodes.map(function (x) { return hlimpl.qName(x, c); });
	                    }
	                }
	            }
	        }
	        if (p.getAdapter(ramlServices.RAMLPropertyService).isDescriminating()) {
	            var subTypes = subTypesWithLocals(p.domain(), c);
	            rs = rs.concat(subTypes.map(function (x) { return (x).getAdapter(ramlServices.RAMLService).descriminatorValue(); }));
	        }
	        else if (p.isReference()) {
	            rs = nodesDeclaringType(p.referencesTo(), c).map(function (x) { return hlimpl.qName(x, c); });
	        }
	        else if (p.range().hasValueTypeInHierarchy()) {
	            var vt = p.range().getAdapter(ramlServices.RAMLService);
	            if (vt.globallyDeclaredBy().length > 0) {
	                var definitionNodes = globalDeclarations(c).filter(function (z) {
	                    return _.find(vt.globallyDeclaredBy(), function (x) { return x == z.definition(); }) != null;
	                });
	                rs = rs.concat(definitionNodes.map(function (x) { return hlimpl.qName(x, c); }));
	            }
	        }
	        if (p.isAllowNull()) {
	            rs.push("null");
	        }
	        if (p.enumOptions()) {
	            rs = rs.concat(p.enumOptions());
	        }
	        return rs;
	    }
	    if (p.enumOptions() && typeof p.enumOptions() == 'string') {
	        return [p.enumOptions() + ""];
	    }
	    return p.enumOptions();
	}
	exports.enumValues = enumValues;
	function getLibraryName(node) {
	    if (node.isElement() && node.asElement().definition().key() != universes.Universe10.Library) {
	        return null;
	    }
	    return node.asElement().attrValue("name");
	}
	function findDeclarationByNode(node, nodePart) {
	    var unit = node.lowLevel().unit();
	    if (!unit) {
	        return null;
	    }
	    var start = node.lowLevel().start();
	    var end = node.lowLevel().end();
	    if (nodePart && nodePart == LocationKind.KEY_COMPLETION) {
	        start = node.lowLevel().keyStart();
	        end = node.lowLevel().keyEnd();
	    }
	    else if (nodePart && nodePart == LocationKind.VALUE_COMPLETION) {
	        start = node.lowLevel().valueStart();
	        end = node.lowLevel().valueEnd();
	    }
	    if (start == -1 || end == -1) {
	        return null;
	    }
	    var offset = Math.floor((start + end) / 2);
	    return findDeclaration(unit, offset, nodePart);
	}
	exports.findDeclarationByNode = findDeclarationByNode;
	function findDeclaration(unit, offset, nodePart) {
	    var node = deepFindNode(hlimpl.fromUnit(unit), offset, offset, false);
	    var result = null;
	    //TODO This should be changed after next refactoring
	    if (node.isElement()) {
	        if (node.asElement().definition().isAssignableFrom(universes.Universe10.TypeDeclaration.name)) {
	            node.asElement().directChildren().forEach(function (x) {
	                if (x.isUnknown()) {
	                    //facets are not in hierarchy now
	                    if (x.getLowLevelStart() < offset && x.getLowLevelEnd() > offset) {
	                        var tp = node.asElement().localType();
	                        tp.allFacets().forEach(function (f) {
	                            if (f.nameId() == x.lowLevel().key()) {
	                                if (f instanceof def.UserDefinedProp) {
	                                    var up = f._node;
	                                    result = up;
	                                }
	                            }
	                        });
	                    }
	                }
	            });
	        }
	    }
	    if (!node.property()) {
	        return node;
	    }
	    if (node.property().nameId() == "example") {
	        var nm = node.parent().localType();
	        node.lowLevel().children().forEach(function (y) {
	            if (y.key() == "example") {
	                y.children().forEach(function (x) {
	                    if (x.start() < offset && x.end() > offset) {
	                        var tp = node.parent().asElement().localType();
	                        tp.allProperties().forEach(function (f) {
	                            if (f.nameId() == x.key()) {
	                                if (f instanceof def.UserDefinedProp) {
	                                    var up = f._node;
	                                    result = up;
	                                }
	                            }
	                        });
	                    }
	                });
	            }
	        });
	    }
	    if (result) {
	        return result;
	    }
	    var kind = nodePart != null ? nodePart : determineCompletionKind(unit.contents(), offset);
	    if (kind == LocationKind.VALUE_COMPLETION) {
	        var hlnode = node;
	        if (node instanceof hlimpl.ASTPropImpl) {
	            var attr = node;
	            if (attr) {
	                if (attr.value()) {
	                    if (attr.value() instanceof hlimpl.StructuredValue) {
	                        var sval = attr.value();
	                        var hlvalue = sval.toHighLevel();
	                        if (hlvalue) {
	                            var newAttr = _.find(hlvalue.attrs(), function (x) { return x.lowLevel().start() < offset && x.lowLevel().end() >= offset; });
	                            if (newAttr) {
	                                return searchInTheValue(offset, unit.contents(), newAttr, hlvalue, attr.property());
	                            }
	                        }
	                    }
	                    else {
	                        return searchInTheValue(offset, unit.contents(), attr, hlnode);
	                    }
	                }
	            }
	        }
	        else {
	            var nodeProperty = hlnode.property();
	            if (nodeProperty) {
	                return searchInTheValue(offset, unit.contents(), null, hlnode, nodeProperty);
	            }
	        }
	    }
	    if (kind == LocationKind.KEY_COMPLETION || kind == LocationKind.SEQUENCE_KEY_COPLETION) {
	        var hlnode = node;
	        var pp = node.property();
	        if (pp instanceof defs.UserDefinedProp) {
	            var up = pp;
	            return up.node();
	        }
	        if (node instanceof hlimpl.ASTNodeImpl) {
	            if (hlnode.definition() instanceof defs.UserDefinedClass) {
	                var uc = hlnode.definition();
	                if (uc.isAssignableFrom("TypeDeclaration")) {
	                    return node;
	                }
	                return uc.getAdapter(ramlServices.RAMLService).getDeclaringNode();
	            }
	        }
	        if (node instanceof hlimpl.ASTPropImpl) {
	            var pr = node;
	            if (isExampleNodeContent(pr)) {
	                var contentType = findExampleContentType(pr);
	                if (contentType) {
	                    var documentationRoot = parseDocumentationContent(pr, contentType);
	                    if (documentationRoot) {
	                        var node = deepFindNode(documentationRoot, offset, offset);
	                        pp = node.property();
	                        if (pp instanceof defs.UserDefinedProp) {
	                            var up = pp;
	                            return up.node();
	                        }
	                        if (node instanceof hlimpl.ASTNodeImpl) {
	                            if (hlnode.definition() instanceof defs.UserDefinedClass) {
	                                var uc = hlnode.definition();
	                                return uc.getAdapter(ramlServices.RAMLService).getDeclaringNode();
	                            }
	                        }
	                    }
	                }
	            }
	        }
	    }
	    if (kind == LocationKind.PATH_COMPLETION) {
	        var inclpath = getValueAt(unit.contents(), offset);
	        if (inclpath) {
	            var ap = unit.resolve(inclpath);
	            return ap;
	        }
	    }
	}
	exports.findDeclaration = findDeclaration;
	function findExampleContentType(node) {
	    var potentialTypeNode = null;
	    if (node.isElement()) {
	        potentialTypeNode = node;
	    }
	    else if (node.isAttr()) {
	        potentialTypeNode = node.parent();
	    }
	    if (!potentialTypeNode.definition().isAssignableFrom(universes.Universe10.TypeDeclaration.name)) {
	        var parent = potentialTypeNode.parent();
	        if (!parent)
	            return null;
	        if (parent.definition().isAssignableFrom(universes.Universe10.TypeDeclaration.name)) {
	            potentialTypeNode = parent;
	        }
	        else {
	            parent = parent.parent();
	            if (parent == null)
	                return null;
	            if (parent.definition().isAssignableFrom(universes.Universe10.TypeDeclaration.name)) {
	                potentialTypeNode = parent;
	            }
	            else {
	                return null;
	            }
	        }
	    }
	    return potentialTypeNode.localType();
	}
	exports.findExampleContentType = findExampleContentType;
	function parseDocumentationContent(attribute, type) {
	    if (!(attribute.value() instanceof hlimpl.StructuredValue)) {
	        return null;
	    }
	    return new hlimpl.ASTNodeImpl(attribute.value().lowLevel(), attribute.parent(), type, attribute.property());
	}
	exports.parseDocumentationContent = parseDocumentationContent;
	function parseStructuredExample(exampleNode, type) {
	    return new hlimpl.ASTNodeImpl(exampleNode.lowLevel(), exampleNode, type, exampleNode.property());
	}
	exports.parseStructuredExample = parseStructuredExample;
	function isExampleNode(node) {
	    return node.definition().key() == universes.Universe10.ExampleSpec;
	}
	exports.isExampleNode = isExampleNode;
	function isExampleNodeContent(node) {
	    var typeExampleName10 = universes.Universe10.TypeDeclaration.properties.example.name;
	    var objectName10 = universes.Universe10.ObjectTypeDeclaration.name;
	    if (!(node instanceof hlimpl.ASTPropImpl)) {
	        return false;
	    }
	    var property = node;
	    var parent = property.parent();
	    var parentProperty = parent && parent.property();
	    var parentPropertyName = parentProperty && parentProperty.nameId();
	    if (typeExampleName10 === property.name() && property.isString()) {
	        if (parent instanceof hlimpl.ASTNodeImpl && parent.definition().isAssignableFrom(objectName10)) {
	            return true;
	        }
	    }
	    return false;
	}
	exports.isExampleNodeContent = isExampleNodeContent;
	function determineCompletionKind(text, offset) {
	    var hasIn = false;
	    var hasSeq = false;
	    var canBeInComment = false;
	    var canBeAnnotation = false;
	    for (var i = offset - 1; i >= 0; i--) {
	        var c = text.charAt(i);
	        if (c == '(') {
	            canBeAnnotation = true;
	        }
	        else if (canBeAnnotation) {
	            if (c == '\r' || c == '\n') {
	                var hasClosing = false;
	                for (var j = offset - 1; j < text.length; j++) {
	                    var ch = text[j];
	                    if (ch == ')') {
	                        hasClosing = true;
	                    }
	                    if (ch == '\r' || ch == "\n") {
	                        break;
	                    }
	                    if (ch == ':') {
	                        canBeAnnotation = false;
	                        break;
	                    }
	                }
	                if (canBeAnnotation && hasClosing) {
	                    return LocationKind.ANNOTATION_COMPLETION;
	                }
	                else {
	                    break;
	                }
	            }
	            if (c == ' ' || c == '\t') {
	                continue;
	            }
	            else {
	                break;
	            }
	        }
	        else {
	            if (c == '\r' || c == '\n') {
	                break;
	            }
	            if (c == ':') {
	                break;
	            }
	        }
	    }
	    for (var i = offset - 1; i >= 0; i--) {
	        var c = text.charAt(i);
	        if (c == '#') {
	            if (i == 0) {
	                return LocationKind.VERSION_COMPLETION;
	            }
	            //subsequent check for include
	            for (var j = i - 1; j >= 0; j--) {
	                var currentChar = text.charAt(j);
	                if (currentChar == '\r' || currentChar == '\n') {
	                    break;
	                }
	                else if (currentChar == '!') {
	                    if (text.indexOf("!include", j) == j) {
	                        return LocationKind.PATH_COMPLETION;
	                    }
	                }
	            }
	            return LocationKind.INCOMMENT;
	        }
	        if (c == ':') {
	            if (hasIn) {
	                return LocationKind.DIRECTIVE_COMPLETION;
	            }
	            return LocationKind.VALUE_COMPLETION;
	        }
	        if (c == '\r' || c == '\n') {
	            //check for multiline literal
	            var insideOfMultiline = false;
	            var ind = getIndent2(offset, text);
	            for (var a = i; a > 0; a--) {
	                c = text.charAt(a);
	                //TODO this can be further improved
	                if (c == ':') {
	                    if (insideOfMultiline) {
	                        var ll = getIndent2(a, text);
	                        if (ll.length < ind.length) {
	                            return LocationKind.VALUE_COMPLETION;
	                        }
	                    }
	                    break;
	                }
	                if (c == '|') {
	                    insideOfMultiline = true;
	                    continue;
	                }
	                if (c == '\r' || c == '\n') {
	                    insideOfMultiline = false;
	                }
	                if (c != ' ' && c != '\t') {
	                    insideOfMultiline = false;
	                }
	            }
	            if (hasSeq) {
	                return LocationKind.SEQUENCE_KEY_COPLETION;
	            }
	            return LocationKind.KEY_COMPLETION;
	        }
	        if (c == '-') {
	            hasSeq = true;
	        }
	        if (c == '!') {
	            if (text.indexOf("!include", i) == i) {
	                return LocationKind.PATH_COMPLETION;
	            }
	            if (text.indexOf("!i", i) == i) {
	                hasIn = true;
	            }
	        }
	    }
	}
	exports.determineCompletionKind = determineCompletionKind;
	(function (LocationKind) {
	    LocationKind[LocationKind["VALUE_COMPLETION"] = 0] = "VALUE_COMPLETION";
	    LocationKind[LocationKind["KEY_COMPLETION"] = 1] = "KEY_COMPLETION";
	    LocationKind[LocationKind["PATH_COMPLETION"] = 2] = "PATH_COMPLETION";
	    LocationKind[LocationKind["DIRECTIVE_COMPLETION"] = 3] = "DIRECTIVE_COMPLETION";
	    LocationKind[LocationKind["VERSION_COMPLETION"] = 4] = "VERSION_COMPLETION";
	    LocationKind[LocationKind["ANNOTATION_COMPLETION"] = 5] = "ANNOTATION_COMPLETION";
	    LocationKind[LocationKind["SEQUENCE_KEY_COPLETION"] = 6] = "SEQUENCE_KEY_COPLETION";
	    LocationKind[LocationKind["INCOMMENT"] = 7] = "INCOMMENT";
	})(exports.LocationKind || (exports.LocationKind = {}));
	var LocationKind = exports.LocationKind;
	function resolveReference(point, path) {
	    if (!path) {
	        return null;
	    }
	    var sp = path.split("/");
	    var result = point;
	    for (var i = 0; i < sp.length; i++) {
	        if (sp[i] == '#') {
	            result = point.unit().ast();
	            continue;
	        }
	        result = _.find(result.children(), function (x) { return x.key() == sp[i]; });
	        if (!result) {
	            return null;
	        }
	    }
	    return result;
	}
	exports.resolveReference = resolveReference;
	/**
	 * return all sub types of given type visible from parent node
	 * @param range
	 * @param parentNode
	 * @returns ITypeDefinition[]
	 */
	function subTypesWithLocals(range, parentNode) {
	    if (range == null) {
	        return [];
	    }
	    var name = range.nameId();
	    parentNode = exports.declRoot(parentNode);
	    var actual = parentNode;
	    if (actual._subTypesCache) {
	        var cached = actual._subTypesCache[name];
	        if (cached) {
	            return cached;
	        }
	    }
	    else {
	        actual._subTypesCache = {};
	    }
	    var result = range.allSubTypes();
	    if (range.getAdapter(ramlServices.RAMLService).getRuntimeExtenders().length > 0 && parentNode) {
	        var decls = globalDeclarations(parentNode);
	        var extenders = range.getAdapter(ramlServices.RAMLService).getRuntimeExtenders();
	        var root = parentNode.root();
	        extenders.forEach(function (x) {
	            var definitionNodes = decls.filter(function (z) {
	                var def = z.definition().allSuperTypes();
	                def.push(z.definition());
	                var rr = (z.definition() == x) || (_.find(def, function (d) { return d == x; }) != null) || (_.find(def, function (d) { return d == range; }) != null);
	                return rr;
	            });
	            result = result.concat(definitionNodes.map(function (x) { return x.localType(); }));
	        });
	    }
	    result = _.unique(result);
	    actual._subTypesCache[name] = result;
	    return result;
	}
	exports.subTypesWithLocals = subTypesWithLocals;
	;
	function subTypesWithName(tname, parentNode, backup) {
	    parentNode = exports.declRoot(parentNode);
	    var decls = globalDeclarations(parentNode);
	    var declNode = _.find(decls, function (x) { return hlimpl.qName(x, parentNode) == tname && x.property() &&
	        (x.property().nameId() == universes.Universe10.LibraryBase.properties.types.name); });
	    return declNode.localType();
	}
	exports.subTypesWithName = subTypesWithName;
	;
	function schemasWithName(tname, parentNode, backup) {
	    parentNode = exports.declRoot(parentNode);
	    var decls = globalDeclarations(parentNode);
	    var declNode = _.find(decls, function (x) { return hlimpl.qName(x, parentNode) == tname && x.property() &&
	        (x.property().nameId() == universes.Universe10.LibraryBase.properties.schemas.name); });
	    return declNode.localType();
	}
	exports.schemasWithName = schemasWithName;
	;
	function nodesDeclaringType(range, n) {
	    var result = [];
	    var extenders = range.getAdapter(ramlServices.RAMLService).getRuntimeExtenders();
	    if (extenders.length > 0 && n) {
	        var root = n;
	        extenders.forEach(function (x) {
	            var definitionNodes = globalDeclarations(root).filter(function (z) { return z.definition().isAssignableFrom(x.nameId()); });
	            result = result.concat(definitionNodes);
	        });
	    }
	    var isElementType = !range.hasValueTypeInHierarchy();
	    if (isElementType && range.getAdapter(ramlServices.RAMLService).isInlinedTemplates() && n) {
	        var root = n;
	        //TODO I did not like it it might be written much better
	        var definitionNodes = globalDeclarations(root).filter(function (z) { return z.definition() == range; });
	        result = result.concat(definitionNodes);
	    }
	    else {
	        var root = n;
	        var q = {};
	        range.allSubTypes().forEach(function (x) { return q[x.nameId()] = true; });
	        q[range.nameId()] = true;
	        var definitionNodes = globalDeclarations(root).filter(function (z) { return q[z.definition().nameId()]; });
	        result = result.concat(definitionNodes);
	    }
	    return result;
	}
	exports.nodesDeclaringType = nodesDeclaringType;
	;
	function findAllSubTypes(p, n) {
	    var range = p.range();
	    return subTypesWithLocals(range, n);
	}
	exports.findAllSubTypes = findAllSubTypes;
	;
	function possibleNodes(p, c) {
	    if (c) {
	        if (p.isDescriminator()) {
	            var range = p.range();
	            var extenders = range.getAdapter(ramlServices.RAMLService).getRuntimeExtenders();
	            if (extenders.length > 0 && c) {
	                var result = [];
	                extenders.forEach(function (x) {
	                    var definitionNodes = globalDeclarations(c).filter(function (z) { return z.definition() == x; });
	                    result = result.concat(definitionNodes);
	                });
	                return result;
	            }
	            return [];
	        }
	        if (p.isReference()) {
	            return nodesDeclaringType(p.referencesTo(), c);
	        }
	        if (p.range().hasValueTypeInHierarchy()) {
	            var vt = p.range().getAdapter(ramlServices.RAMLService);
	            if (vt.globallyDeclaredBy && vt.globallyDeclaredBy().length > 0) {
	                var definitionNodes = globalDeclarations(c).filter(function (z) { return _.find(vt.globallyDeclaredBy(), function (x) { return x == z.definition(); }) != null; });
	                return definitionNodes;
	            }
	        }
	    }
	    return [];
	}
	function allChildren(node) {
	    var res = [];
	    gather(node, res);
	    return res;
	}
	exports.allChildren = allChildren;
	function gather(node, result) {
	    node.children().forEach(function (x) { result.push(x); gather(x, result); });
	}
	var testUsage = function (ck, x, node, result) {
	    var tp = ck.getAdapter(ramlServices.RAMLService).getDeclaringNode();
	    if (tp) {
	        if (node.isSameNode(tp)) {
	            result.push(x);
	            return;
	        }
	    }
	    if (ck.isArray()) {
	        testUsage(ck.array().componentType(), x, node, result);
	    }
	    if (ck.isUnion()) {
	        var uni = ck.union();
	        testUsage(uni.leftType(), x, node, result);
	        testUsage(uni.rightType(), x, node, result);
	    }
	    if (ck.superTypes().some(function (x) { return x.nameId() == node.name(); })) {
	        result.push(x);
	    }
	};
	function refFinder(root, node, result) {
	    root.elements().forEach(function (x) {
	        refFinder(x, node, result);
	        //console.log(x.name())
	        var ck = x.definition();
	        //testUsage(ck, x, node, result);
	    });
	    root.attrs().forEach(function (a) {
	        var pr = a.property();
	        var vl = a.value();
	        //if (pr.isTypeExpr()){
	        //    typeExpression.
	        //}
	        if (pr instanceof defs.UserDefinedProp) {
	            var up = pr.node();
	            if (up == node) {
	                result.push(a);
	            }
	            else if (up.lowLevel().start() == node.lowLevel().start()) {
	                if (up.lowLevel().unit() == node.lowLevel().unit()) {
	                    result.push(a);
	                }
	            }
	        }
	        if (isExampleNodeContent(a)) {
	            var contentType = findExampleContentType(a);
	            if (contentType) {
	                var documentationRoot = parseDocumentationContent(a, contentType);
	                if (documentationRoot) {
	                    refFinder(documentationRoot, node, result);
	                }
	            }
	        }
	        else if (pr.getAdapter(ramlServices.RAMLPropertyService).isTypeExpr() && typeof vl == "string") {
	            var tpa = root.localType();
	            testUsage(tpa, a, node, result);
	            var libraryName = getLibraryName(node);
	            if (libraryName && vl.indexOf(libraryName) != -1) {
	                var referencingLibrary = getLibraryDefiningNode(a);
	                if (referencingLibrary &&
	                    referencingLibrary.lowLevel().start() == node.lowLevel().start()) {
	                    result.push(a);
	                }
	            }
	        }
	        if (pr.isReference() || pr.isDescriminator()) {
	            if (typeof vl == 'string') {
	                var pn = possibleNodes(pr, root);
	                if (_.find(pn, function (x) { return x.name() == vl && x == node; })) {
	                    result.push(a);
	                }
	                var libraryName = getLibraryName(node);
	                if (libraryName && vl.indexOf(libraryName) != -1) {
	                    var referencingLibrary = getLibraryDefiningNode(a);
	                    if (referencingLibrary &&
	                        referencingLibrary.lowLevel().start() == node.lowLevel().start()) {
	                        result.push(a);
	                    }
	                }
	            }
	            else {
	                var st = vl;
	                if (st) {
	                    var vn = st.valueName();
	                    var pn = possibleNodes(pr, root);
	                    if (_.find(pn, function (x) { return x.name() == vn && x == node; })) {
	                        result.push(a);
	                    }
	                    var hnode = st.toHighLevel();
	                    if (hnode) {
	                        refFinder(hnode, node, result);
	                    }
	                    var libraryName = getLibraryName(node);
	                    if (libraryName && vn.indexOf(libraryName) != -1) {
	                        var referencingLibrary = getLibraryDefiningNode(hnode);
	                        if (referencingLibrary &&
	                            referencingLibrary.lowLevel().start() == node.lowLevel().start()) {
	                            result.push(a);
	                        }
	                    }
	                }
	            }
	        }
	        else {
	            var pn = possibleNodes(pr, root);
	            if (_.find(pn, function (x) { return x.name() == vl && x == node; })) {
	                result.push(a);
	            }
	        }
	    });
	}
	exports.refFinder = refFinder;
	/**
	 * Returns library node that definition of the current node is located in, or null
	 * if current node is not defined in a library.
	 */
	function getLibraryDefiningNode(nodeToCheck) {
	    if (!nodeToCheck.lowLevel) {
	        return null;
	    }
	    var lowLevelNode = nodeToCheck.lowLevel();
	    if (!lowLevelNode) {
	        return null;
	    }
	    if (lowLevelNode.key()) {
	        var offset = Math.floor((lowLevelNode.keyEnd() + lowLevelNode.keyStart()) / 2);
	        var result = getLibraryDefiningNodeByOffset(lowLevelNode.unit(), offset);
	        if (result)
	            return result;
	    }
	    if (lowLevelNode.value()) {
	        var offset = Math.floor((lowLevelNode.valueEnd() + lowLevelNode.valueStart()) / 2);
	        var result = getLibraryDefiningNodeByOffset(lowLevelNode.unit(), offset);
	        if (result)
	            return result;
	    }
	    return null;
	}
	function getLibraryDefiningNodeByOffset(unit, offset) {
	    var declaration = findDeclaration(unit, offset);
	    if (declaration && declaration.isElement && declaration.isElement()) {
	        var declarationNode = declaration.asElement();
	        var parent = declarationNode;
	        while (parent) {
	            if (parent.definition().key() == universes.Universe10.Library) {
	                return parent;
	            }
	            parent = parent.parent();
	        }
	    }
	    return null;
	}
	//# sourceMappingURL=search.js.map

/***/ },
/* 28 */
/***/ function(module, exports, __webpack_require__) {

	/**
	 * <p>See <a href="http://raml.org">http://raml.org</a> for more information about RAML.</p>
	 *
	 * <p>This parser is at a beta state of development, as part of the API Workbench development cycle (<a href="http://apiworkbench.com">http://apiworkbench.com</a>).</p>
	 *
	 * <p><a href="https://github.com/raml-org/raml-js-parser-2/blob/master/documentation/GettingStarted.md">Getting Started Guide</a> describes the first steps with the parser.</p>
	 *
	 * <h2>Installation</h2>
	 *
	 * <pre><code>git clone https://github.com/raml-org/raml-js-parser-2
	 *
	 * cd raml-js-parser-2
	 *
	 * npm install
	 *
	 * node test/test.js  //here you should observe JSON representation of XKCD API in your console
	 *
	 * node test/testAsync.js  //same as above but in asynchronous mode
	 * </code></pre>
	 *
	 * <h2>Usage</h2>
	 *
	 * <ul>
	 * <li>For parser usage example refer to <code>test/test.js</code></li>
	 * <li>For asynchrounous usage example refer to <code>test/testAsync.js</code></li>
	 * </ul>
	 **/
	"use strict";
	var __extends = (this && this.__extends) || function (d, b) {
	    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
	    function __() { this.constructor = d; }
	    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
	};
	var stubs = __webpack_require__(17);
	var def = __webpack_require__(33);
	var core = __webpack_require__(50);
	var apiLoader = __webpack_require__(9);
	var helper = __webpack_require__(32);
	var AnnotableImpl = (function (_super) {
	    __extends(AnnotableImpl, _super);
	    function AnnotableImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * Most of RAML model elements may have attached annotations decribing additional meta data about this element
	     **/
	    AnnotableImpl.prototype.annotations = function () {
	        return _super.prototype.attributes.call(this, 'annotations', function (attr) { return new AnnotationRefImpl(attr); });
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    AnnotableImpl.prototype.wrapperClassName = function () { return "AnnotableImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    AnnotableImpl.prototype.kind = function () { return "Annotable"; };
	    /**
	     * @return RAML version of the node
	     **/
	    AnnotableImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    /**
	     * Scalar properties annotations accessor
	     **/
	    AnnotableImpl.prototype.scalarsAnnotations = function () { return new AnnotableScalarsAnnotationsImpl(this.highLevel()); };
	    return AnnotableImpl;
	}(core.BasicNodeImpl));
	exports.AnnotableImpl = AnnotableImpl;
	var ValueTypeImpl = (function (_super) {
	    __extends(ValueTypeImpl, _super);
	    function ValueTypeImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    ValueTypeImpl.prototype.wrapperClassName = function () { return "ValueTypeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    ValueTypeImpl.prototype.kind = function () { return "ValueType"; };
	    /**
	     * @return RAML version of the node
	     **/
	    ValueTypeImpl.prototype.RAMLVersion = function () { return "undefined"; };
	    /**
	     * @return JS representation of the node value
	     **/
	    ValueTypeImpl.prototype.value = function () { return this.attr.value(); };
	    return ValueTypeImpl;
	}(core.AttributeNodeImpl));
	exports.ValueTypeImpl = ValueTypeImpl;
	var StringTypeImpl = (function (_super) {
	    __extends(StringTypeImpl, _super);
	    function StringTypeImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    StringTypeImpl.prototype.wrapperClassName = function () { return "StringTypeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    StringTypeImpl.prototype.kind = function () { return "StringType"; };
	    /**
	     * @return RAML version of the node
	     **/
	    StringTypeImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    /**
	     * @return String representation of the node value
	     **/
	    StringTypeImpl.prototype.value = function () { return this.attr.value(); };
	    return StringTypeImpl;
	}(ValueTypeImpl));
	exports.StringTypeImpl = StringTypeImpl;
	/**
	 * This type currently serves both for absolute and relative urls
	 **/
	var UriTemplateImpl = (function (_super) {
	    __extends(UriTemplateImpl, _super);
	    function UriTemplateImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    UriTemplateImpl.prototype.wrapperClassName = function () { return "UriTemplateImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    UriTemplateImpl.prototype.kind = function () { return "UriTemplate"; };
	    /**
	     * @return RAML version of the node
	     **/
	    UriTemplateImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return UriTemplateImpl;
	}(StringTypeImpl));
	exports.UriTemplateImpl = UriTemplateImpl;
	/**
	 * This  type describes relative uri templates
	 **/
	var RelativeUriStringImpl = (function (_super) {
	    __extends(RelativeUriStringImpl, _super);
	    function RelativeUriStringImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    RelativeUriStringImpl.prototype.wrapperClassName = function () { return "RelativeUriStringImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    RelativeUriStringImpl.prototype.kind = function () { return "RelativeUriString"; };
	    /**
	     * @return RAML version of the node
	     **/
	    RelativeUriStringImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return RelativeUriStringImpl;
	}(UriTemplateImpl));
	exports.RelativeUriStringImpl = RelativeUriStringImpl;
	/**
	 * This  type describes absolute uri templates
	 **/
	var FullUriTemplateStringImpl = (function (_super) {
	    __extends(FullUriTemplateStringImpl, _super);
	    function FullUriTemplateStringImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    FullUriTemplateStringImpl.prototype.wrapperClassName = function () { return "FullUriTemplateStringImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    FullUriTemplateStringImpl.prototype.kind = function () { return "FullUriTemplateString"; };
	    /**
	     * @return RAML version of the node
	     **/
	    FullUriTemplateStringImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return FullUriTemplateStringImpl;
	}(UriTemplateImpl));
	exports.FullUriTemplateStringImpl = FullUriTemplateStringImpl;
	var StatusCodeStringImpl = (function (_super) {
	    __extends(StatusCodeStringImpl, _super);
	    function StatusCodeStringImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    StatusCodeStringImpl.prototype.wrapperClassName = function () { return "StatusCodeStringImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    StatusCodeStringImpl.prototype.kind = function () { return "StatusCodeString"; };
	    /**
	     * @return RAML version of the node
	     **/
	    StatusCodeStringImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return StatusCodeStringImpl;
	}(StringTypeImpl));
	exports.StatusCodeStringImpl = StatusCodeStringImpl;
	/**
	 * This  type describes fixed uris
	 **/
	var FixedUriStringImpl = (function (_super) {
	    __extends(FixedUriStringImpl, _super);
	    function FixedUriStringImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    FixedUriStringImpl.prototype.wrapperClassName = function () { return "FixedUriStringImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    FixedUriStringImpl.prototype.kind = function () { return "FixedUriString"; };
	    /**
	     * @return RAML version of the node
	     **/
	    FixedUriStringImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return FixedUriStringImpl;
	}(StringTypeImpl));
	exports.FixedUriStringImpl = FixedUriStringImpl;
	var ContentTypeImpl = (function (_super) {
	    __extends(ContentTypeImpl, _super);
	    function ContentTypeImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    ContentTypeImpl.prototype.wrapperClassName = function () { return "ContentTypeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    ContentTypeImpl.prototype.kind = function () { return "ContentType"; };
	    /**
	     * @return RAML version of the node
	     **/
	    ContentTypeImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return ContentTypeImpl;
	}(StringTypeImpl));
	exports.ContentTypeImpl = ContentTypeImpl;
	/**
	 * [GitHub Flavored Markdown](https://help.github.com/articles/github-flavored-markdown/)
	 **/
	var MarkdownStringImpl = (function (_super) {
	    __extends(MarkdownStringImpl, _super);
	    function MarkdownStringImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    MarkdownStringImpl.prototype.wrapperClassName = function () { return "MarkdownStringImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    MarkdownStringImpl.prototype.kind = function () { return "MarkdownString"; };
	    /**
	     * @return RAML version of the node
	     **/
	    MarkdownStringImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return MarkdownStringImpl;
	}(StringTypeImpl));
	exports.MarkdownStringImpl = MarkdownStringImpl;
	/**
	 * Schema at this moment only two subtypes are supported (json schema and xsd)
	 **/
	var SchemaStringImpl = (function (_super) {
	    __extends(SchemaStringImpl, _super);
	    function SchemaStringImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    SchemaStringImpl.prototype.wrapperClassName = function () { return "SchemaStringImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    SchemaStringImpl.prototype.kind = function () { return "SchemaString"; };
	    /**
	     * @return RAML version of the node
	     **/
	    SchemaStringImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return SchemaStringImpl;
	}(StringTypeImpl));
	exports.SchemaStringImpl = SchemaStringImpl;
	/**
	 * This sub type of the string represents mime types
	 **/
	var MimeTypeImpl = (function (_super) {
	    __extends(MimeTypeImpl, _super);
	    function MimeTypeImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    MimeTypeImpl.prototype.wrapperClassName = function () { return "MimeTypeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    MimeTypeImpl.prototype.kind = function () { return "MimeType"; };
	    /**
	     * @return RAML version of the node
	     **/
	    MimeTypeImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return MimeTypeImpl;
	}(StringTypeImpl));
	exports.MimeTypeImpl = MimeTypeImpl;
	var AnyTypeImpl = (function (_super) {
	    __extends(AnyTypeImpl, _super);
	    function AnyTypeImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    AnyTypeImpl.prototype.wrapperClassName = function () { return "AnyTypeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    AnyTypeImpl.prototype.kind = function () { return "AnyType"; };
	    /**
	     * @return RAML version of the node
	     **/
	    AnyTypeImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return AnyTypeImpl;
	}(ValueTypeImpl));
	exports.AnyTypeImpl = AnyTypeImpl;
	var NumberTypeImpl = (function (_super) {
	    __extends(NumberTypeImpl, _super);
	    function NumberTypeImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    NumberTypeImpl.prototype.wrapperClassName = function () { return "NumberTypeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    NumberTypeImpl.prototype.kind = function () { return "NumberType"; };
	    /**
	     * @return RAML version of the node
	     **/
	    NumberTypeImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    /**
	     * @return Number representation of the node value
	     **/
	    NumberTypeImpl.prototype.value = function () { return this.attr.value(); };
	    return NumberTypeImpl;
	}(ValueTypeImpl));
	exports.NumberTypeImpl = NumberTypeImpl;
	var IntegerTypeImpl = (function (_super) {
	    __extends(IntegerTypeImpl, _super);
	    function IntegerTypeImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    IntegerTypeImpl.prototype.wrapperClassName = function () { return "IntegerTypeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    IntegerTypeImpl.prototype.kind = function () { return "IntegerType"; };
	    /**
	     * @return RAML version of the node
	     **/
	    IntegerTypeImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return IntegerTypeImpl;
	}(ValueTypeImpl));
	exports.IntegerTypeImpl = IntegerTypeImpl;
	var NullTypeImpl = (function (_super) {
	    __extends(NullTypeImpl, _super);
	    function NullTypeImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    NullTypeImpl.prototype.wrapperClassName = function () { return "NullTypeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    NullTypeImpl.prototype.kind = function () { return "NullType"; };
	    /**
	     * @return RAML version of the node
	     **/
	    NullTypeImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return NullTypeImpl;
	}(ValueTypeImpl));
	exports.NullTypeImpl = NullTypeImpl;
	var TimeOnlyTypeImpl = (function (_super) {
	    __extends(TimeOnlyTypeImpl, _super);
	    function TimeOnlyTypeImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    TimeOnlyTypeImpl.prototype.wrapperClassName = function () { return "TimeOnlyTypeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    TimeOnlyTypeImpl.prototype.kind = function () { return "TimeOnlyType"; };
	    /**
	     * @return RAML version of the node
	     **/
	    TimeOnlyTypeImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return TimeOnlyTypeImpl;
	}(ValueTypeImpl));
	exports.TimeOnlyTypeImpl = TimeOnlyTypeImpl;
	var DateOnlyTypeImpl = (function (_super) {
	    __extends(DateOnlyTypeImpl, _super);
	    function DateOnlyTypeImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    DateOnlyTypeImpl.prototype.wrapperClassName = function () { return "DateOnlyTypeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    DateOnlyTypeImpl.prototype.kind = function () { return "DateOnlyType"; };
	    /**
	     * @return RAML version of the node
	     **/
	    DateOnlyTypeImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return DateOnlyTypeImpl;
	}(ValueTypeImpl));
	exports.DateOnlyTypeImpl = DateOnlyTypeImpl;
	var DateTimeOnlyTypeImpl = (function (_super) {
	    __extends(DateTimeOnlyTypeImpl, _super);
	    function DateTimeOnlyTypeImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    DateTimeOnlyTypeImpl.prototype.wrapperClassName = function () { return "DateTimeOnlyTypeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    DateTimeOnlyTypeImpl.prototype.kind = function () { return "DateTimeOnlyType"; };
	    /**
	     * @return RAML version of the node
	     **/
	    DateTimeOnlyTypeImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return DateTimeOnlyTypeImpl;
	}(ValueTypeImpl));
	exports.DateTimeOnlyTypeImpl = DateTimeOnlyTypeImpl;
	var DateTimeTypeImpl = (function (_super) {
	    __extends(DateTimeTypeImpl, _super);
	    function DateTimeTypeImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    DateTimeTypeImpl.prototype.wrapperClassName = function () { return "DateTimeTypeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    DateTimeTypeImpl.prototype.kind = function () { return "DateTimeType"; };
	    /**
	     * @return RAML version of the node
	     **/
	    DateTimeTypeImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return DateTimeTypeImpl;
	}(ValueTypeImpl));
	exports.DateTimeTypeImpl = DateTimeTypeImpl;
	var FileTypeImpl = (function (_super) {
	    __extends(FileTypeImpl, _super);
	    function FileTypeImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    FileTypeImpl.prototype.wrapperClassName = function () { return "FileTypeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    FileTypeImpl.prototype.kind = function () { return "FileType"; };
	    /**
	     * @return RAML version of the node
	     **/
	    FileTypeImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return FileTypeImpl;
	}(ValueTypeImpl));
	exports.FileTypeImpl = FileTypeImpl;
	var BooleanTypeImpl = (function (_super) {
	    __extends(BooleanTypeImpl, _super);
	    function BooleanTypeImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    BooleanTypeImpl.prototype.wrapperClassName = function () { return "BooleanTypeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    BooleanTypeImpl.prototype.kind = function () { return "BooleanType"; };
	    /**
	     * @return RAML version of the node
	     **/
	    BooleanTypeImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    /**
	     * @return Boolean representation of the node value
	     **/
	    BooleanTypeImpl.prototype.value = function () { return this.attr.value(); };
	    return BooleanTypeImpl;
	}(ValueTypeImpl));
	exports.BooleanTypeImpl = BooleanTypeImpl;
	/**
	 * Elements to which this Annotation can be applied (enum)
	 **/
	var AnnotationTargetImpl = (function (_super) {
	    __extends(AnnotationTargetImpl, _super);
	    function AnnotationTargetImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    AnnotationTargetImpl.prototype.wrapperClassName = function () { return "AnnotationTargetImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    AnnotationTargetImpl.prototype.kind = function () { return "AnnotationTarget"; };
	    /**
	     * @return RAML version of the node
	     **/
	    AnnotationTargetImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return AnnotationTargetImpl;
	}(ValueTypeImpl));
	exports.AnnotationTargetImpl = AnnotationTargetImpl;
	var ReferenceImpl = (function (_super) {
	    __extends(ReferenceImpl, _super);
	    function ReferenceImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    ReferenceImpl.prototype.wrapperClassName = function () { return "ReferenceImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    ReferenceImpl.prototype.kind = function () { return "Reference"; };
	    /**
	     * @return RAML version of the node
	     **/
	    ReferenceImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    /**
	     * @return StructuredValue object representing the node value
	     **/
	    ReferenceImpl.prototype.value = function () { return core.toStructuredValue(this.attr); };
	    ReferenceImpl.prototype.structuredValue = function () {
	        return helper.structuredValue(this);
	    };
	    ReferenceImpl.prototype.name = function () {
	        return helper.referenceName(this);
	    };
	    return ReferenceImpl;
	}(core.AttributeNodeImpl));
	exports.ReferenceImpl = ReferenceImpl;
	var TraitRefImpl = (function (_super) {
	    __extends(TraitRefImpl, _super);
	    function TraitRefImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    TraitRefImpl.prototype.wrapperClassName = function () { return "TraitRefImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    TraitRefImpl.prototype.kind = function () { return "TraitRef"; };
	    /**
	     * @return RAML version of the node
	     **/
	    TraitRefImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    TraitRefImpl.prototype.trait = function () {
	        return helper.referencedTrait(this);
	    };
	    return TraitRefImpl;
	}(ReferenceImpl));
	exports.TraitRefImpl = TraitRefImpl;
	var OperationImpl = (function (_super) {
	    __extends(OperationImpl, _super);
	    function OperationImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createOperation(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * An APIs resources MAY be filtered (to return a subset of results) or altered (such as transforming  a response body from JSON to XML format) by the use of query strings. If the resource or its method supports a query string, the query string MUST be defined by the queryParameters property
	     **/
	    OperationImpl.prototype.queryParameters = function () {
	        return _super.prototype.elements.call(this, 'queryParameters');
	    };
	    /**
	     * Headers that allowed at this position
	     **/
	    OperationImpl.prototype.headers = function () {
	        return _super.prototype.elements.call(this, 'headers');
	    };
	    /**
	     * Specifies the query string needed by this method. Mutually exclusive with queryParameters.
	     **/
	    OperationImpl.prototype.queryString = function () {
	        return _super.prototype.element.call(this, 'queryString');
	    };
	    /**
	     * Information about the expected responses to a request
	     **/
	    OperationImpl.prototype.responses = function () {
	        return _super.prototype.elements.call(this, 'responses');
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    OperationImpl.prototype.wrapperClassName = function () { return "OperationImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    OperationImpl.prototype.kind = function () { return "Operation"; };
	    /**
	     * @return RAML version of the node
	     **/
	    OperationImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return OperationImpl;
	}(AnnotableImpl));
	exports.OperationImpl = OperationImpl;
	var TypeDeclarationImpl = (function (_super) {
	    __extends(TypeDeclarationImpl, _super);
	    function TypeDeclarationImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createTypeDeclaration(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * name of the parameter
	     **/
	    TypeDeclarationImpl.prototype.name = function () {
	        return _super.prototype.attribute.call(this, 'name', this.toString);
	    };
	    /**
	     * @hidden
	     * Set name value
	     **/
	    TypeDeclarationImpl.prototype.setName = function (param) {
	        this.highLevel().attrOrCreate("name").setValue("" + param);
	        return this;
	    };
	    /**
	     * The displayName attribute specifies the type display name. It is a friendly name used only for  display or documentation purposes. If displayName is not specified, it defaults to the element's key (the name of the property itself).
	     **/
	    TypeDeclarationImpl.prototype.displayName = function () {
	        return _super.prototype.attribute.call(this, 'displayName', this.toString);
	    };
	    /**
	     * @hidden
	     * Set displayName value
	     **/
	    TypeDeclarationImpl.prototype.setDisplayName = function (param) {
	        this.highLevel().attrOrCreate("displayName").setValue("" + param);
	        return this;
	    };
	    /**
	     * When extending from a type you can define new facets (which can then be set to concrete values by subtypes).
	     **/
	    TypeDeclarationImpl.prototype.facets = function () {
	        return _super.prototype.elements.call(this, 'facets');
	    };
	    /**
	     * Alias for the equivalent "type" property, for compatibility with RAML 0.8. Deprecated - API definitions should use the "type" property, as the "schema" alias for that property name may be removed in a future RAML version. The "type" property allows for XML and JSON schemas.
	     * @hidden
	     **/
	    TypeDeclarationImpl.prototype.schema_original = function () {
	        return _super.prototype.attributes.call(this, 'schema', this.toString);
	    };
	    /**
	     * @hidden
	     * Set schema value
	     **/
	    TypeDeclarationImpl.prototype.setSchema = function (param) {
	        this.highLevel().attrOrCreate("schema").setValue("" + param);
	        return this;
	    };
	    /**
	     * A base type which the current type extends, or more generally a type expression.
	     * @hidden
	     **/
	    TypeDeclarationImpl.prototype.type_original = function () {
	        return _super.prototype.attributes.call(this, 'type', this.toString);
	    };
	    /**
	     * @hidden
	     * Set type value
	     **/
	    TypeDeclarationImpl.prototype.setType = function (param) {
	        this.highLevel().attrOrCreate("type").setValue("" + param);
	        return this;
	    };
	    /**
	     * Location of the parameter (can not be edited by user)
	     **/
	    TypeDeclarationImpl.prototype.location = function () {
	        return _super.prototype.attribute.call(this, 'location', function (attr) { return new ModelLocationImpl(attr); });
	    };
	    /**
	     * Kind of location
	     **/
	    TypeDeclarationImpl.prototype.locationKind = function () {
	        return _super.prototype.attribute.call(this, 'locationKind', function (attr) { return new LocationKindImpl(attr); });
	    };
	    /**
	     * Provides default value for a property
	     **/
	    TypeDeclarationImpl.prototype["default"] = function () {
	        return _super.prototype.attribute.call(this, 'default', this.toAny);
	    };
	    /**
	     * @hidden
	     * Set default value
	     **/
	    TypeDeclarationImpl.prototype.setDefault = function (param) {
	        this.highLevel().attrOrCreate("default").setValue("" + param);
	        return this;
	    };
	    /**
	     * An example of this type instance represented as string or yaml map/sequence. This can be used, e.g., by documentation generators to generate sample values for an object of this type. Cannot be present if the examples property is present.
	     * @hidden
	     **/
	    TypeDeclarationImpl.prototype.example_original = function () {
	        return _super.prototype.element.call(this, 'example');
	    };
	    /**
	     * An example of this type instance represented as string. This can be used, e.g., by documentation generators to generate sample values for an object of this type. Cannot be present if the example property is present.
	     * @hidden
	     **/
	    TypeDeclarationImpl.prototype.examples_original = function () {
	        return _super.prototype.elements.call(this, 'examples');
	    };
	    /**
	     * The repeat attribute specifies that the parameter can be repeated. If the parameter can be used multiple times, the repeat parameter value MUST be set to 'true'. Otherwise, the default value is 'false' and the parameter may not be repeated.
	     **/
	    TypeDeclarationImpl.prototype.repeat = function () {
	        return _super.prototype.attribute.call(this, 'repeat', this.toBoolean);
	    };
	    /**
	     * @hidden
	     * Set repeat value
	     **/
	    TypeDeclarationImpl.prototype.setRepeat = function (param) {
	        this.highLevel().attrOrCreate("repeat").setValue("" + param);
	        return this;
	    };
	    /**
	     * Sets if property is optional or not
	     **/
	    TypeDeclarationImpl.prototype.required = function () {
	        return _super.prototype.attribute.call(this, 'required', this.toBoolean);
	    };
	    /**
	     * @hidden
	     * Set required value
	     **/
	    TypeDeclarationImpl.prototype.setRequired = function (param) {
	        this.highLevel().attrOrCreate("required").setValue("" + param);
	        return this;
	    };
	    /**
	     * A longer, human-friendly description of the type
	     **/
	    TypeDeclarationImpl.prototype.description = function () {
	        return _super.prototype.attribute.call(this, 'description', function (attr) { return new MarkdownStringImpl(attr); });
	    };
	    TypeDeclarationImpl.prototype.xml = function () {
	        return _super.prototype.element.call(this, 'xml');
	    };
	    /**
	     * Restrictions on where annotations of this type can be applied. If this property is specified, annotations of this type may only be applied on a property corresponding to one of the target names specified as the value of this property.
	     **/
	    TypeDeclarationImpl.prototype.allowedTargets = function () {
	        return _super.prototype.attributes.call(this, 'allowedTargets', function (attr) { return new AnnotationTargetImpl(attr); });
	    };
	    /**
	     * Whether the type represents annotation
	     **/
	    TypeDeclarationImpl.prototype.isAnnotation = function () {
	        return _super.prototype.attribute.call(this, 'isAnnotation', this.toBoolean);
	    };
	    /**
	     * @hidden
	     * Set isAnnotation value
	     **/
	    TypeDeclarationImpl.prototype.setIsAnnotation = function (param) {
	        this.highLevel().attrOrCreate("isAnnotation").setValue("" + param);
	        return this;
	    };
	    /**
	     * Most of RAML model elements may have attached annotations decribing additional meta data about this element
	     **/
	    TypeDeclarationImpl.prototype.annotations = function () {
	        return _super.prototype.attributes.call(this, 'annotations', function (attr) { return new AnnotationRefImpl(attr); });
	    };
	    TypeDeclarationImpl.prototype.uses = function () {
	        return _super.prototype.elements.call(this, 'uses');
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    TypeDeclarationImpl.prototype.wrapperClassName = function () { return "TypeDeclarationImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    TypeDeclarationImpl.prototype.kind = function () { return "TypeDeclaration"; };
	    /**
	     * @return RAML version of the node
	     **/
	    TypeDeclarationImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    /**
	     * Runtime representation of type represented by this AST node
	     **/
	    TypeDeclarationImpl.prototype.runtimeType = function () {
	        return helper.runtimeType(this);
	    };
	    /**
	     * validate an instance against type
	     **/
	    TypeDeclarationImpl.prototype.validateInstance = function (value) {
	        return helper.validateInstance(this, value);
	    };
	    /**
	     * validate an instance against type
	     **/
	    TypeDeclarationImpl.prototype.validateInstanceWithDetailedStatuses = function (value) {
	        return helper.validateInstanceWithDetailedStatuses(this, value);
	    };
	    /**
	     * An example of this type instance represented as string or yaml map/sequence. This can be used, e.g., by documentation generators to generate sample values for an object of this type. Cannot be present if the examples property is present.
	     **/
	    TypeDeclarationImpl.prototype.example = function () {
	        return helper.getTypeExample(this);
	    };
	    /**
	     * An example of this type instance represented as string. This can be used, e.g., by documentation generators to generate sample values for an object of this type. Cannot be present if the example property is present.
	     **/
	    TypeDeclarationImpl.prototype.examples = function () {
	        return helper.getTypeExamples(this);
	    };
	    TypeDeclarationImpl.prototype.fixedFacets = function () {
	        return helper.typeFixedFacets(this);
	    };
	    /**
	     * A base type which the current type extends, or more generally a type expression.
	     **/
	    TypeDeclarationImpl.prototype["type"] = function () {
	        return helper.typeValue(this);
	    };
	    /**
	     * Alias for the equivalent "type" property, for compatibility with RAML 0.8. Deprecated - API definitions should use the "type" property, as the "schema" alias for that property name may be removed in a future RAML version. The "type" property allows for XML and JSON schemas.
	     **/
	    TypeDeclarationImpl.prototype.schema = function () {
	        return helper.schemaValue(this);
	    };
	    /**
	     * Inlined supertype definition.
	     **/
	    TypeDeclarationImpl.prototype.structuredType = function () {
	        return helper.typeStructuredValue(this);
	    };
	    /**
	     * Scalar properties annotations accessor
	     **/
	    TypeDeclarationImpl.prototype.scalarsAnnotations = function () { return new TypeDeclarationScalarsAnnotationsImpl(this.highLevel()); };
	    return TypeDeclarationImpl;
	}(AnnotableImpl));
	exports.TypeDeclarationImpl = TypeDeclarationImpl;
	var ModelLocationImpl = (function () {
	    function ModelLocationImpl(attr) {
	        this.attr = attr;
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    ModelLocationImpl.prototype.wrapperClassName = function () { return "ModelLocationImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    ModelLocationImpl.prototype.kind = function () { return "ModelLocation"; };
	    /**
	     * @return RAML version of the node
	     **/
	    ModelLocationImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return ModelLocationImpl;
	}());
	exports.ModelLocationImpl = ModelLocationImpl;
	var LocationKindImpl = (function () {
	    function LocationKindImpl(attr) {
	        this.attr = attr;
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    LocationKindImpl.prototype.wrapperClassName = function () { return "LocationKindImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    LocationKindImpl.prototype.kind = function () { return "LocationKind"; };
	    /**
	     * @return RAML version of the node
	     **/
	    LocationKindImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return LocationKindImpl;
	}());
	exports.LocationKindImpl = LocationKindImpl;
	var XMLFacetInfoImpl = (function (_super) {
	    __extends(XMLFacetInfoImpl, _super);
	    function XMLFacetInfoImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createXMLFacetInfo(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * If attribute is set to true, a type instance should be serialized as an XML attribute. It can only be true for scalar types.
	     **/
	    XMLFacetInfoImpl.prototype.attribute = function () {
	        return _super.prototype.attribute.call(this, 'attribute', this.toBoolean);
	    };
	    /**
	     * @hidden
	     * Set attribute value
	     **/
	    XMLFacetInfoImpl.prototype.setAttribute = function (param) {
	        this.highLevel().attrOrCreate("attribute").setValue("" + param);
	        return this;
	    };
	    /**
	     * If wrapped is set to true, a type instance should be wrapped in its own XML element. It can not be true for scalar types and it can not be true at the same moment when attribute is true.
	     **/
	    XMLFacetInfoImpl.prototype.wrapped = function () {
	        return _super.prototype.attribute.call(this, 'wrapped', this.toBoolean);
	    };
	    /**
	     * @hidden
	     * Set wrapped value
	     **/
	    XMLFacetInfoImpl.prototype.setWrapped = function (param) {
	        this.highLevel().attrOrCreate("wrapped").setValue("" + param);
	        return this;
	    };
	    /**
	     * Allows to override the name of the XML element or XML attribute in it's XML representation.
	     **/
	    XMLFacetInfoImpl.prototype.name = function () {
	        return _super.prototype.attribute.call(this, 'name', this.toString);
	    };
	    /**
	     * @hidden
	     * Set name value
	     **/
	    XMLFacetInfoImpl.prototype.setName = function (param) {
	        this.highLevel().attrOrCreate("name").setValue("" + param);
	        return this;
	    };
	    /**
	     * Allows to configure the name of the XML namespace.
	     **/
	    XMLFacetInfoImpl.prototype.namespace = function () {
	        return _super.prototype.attribute.call(this, 'namespace', this.toString);
	    };
	    /**
	     * @hidden
	     * Set namespace value
	     **/
	    XMLFacetInfoImpl.prototype.setNamespace = function (param) {
	        this.highLevel().attrOrCreate("namespace").setValue("" + param);
	        return this;
	    };
	    /**
	     * Allows to configure the prefix which will be used during serialization to XML.
	     **/
	    XMLFacetInfoImpl.prototype.prefix = function () {
	        return _super.prototype.attribute.call(this, 'prefix', this.toString);
	    };
	    /**
	     * @hidden
	     * Set prefix value
	     **/
	    XMLFacetInfoImpl.prototype.setPrefix = function (param) {
	        this.highLevel().attrOrCreate("prefix").setValue("" + param);
	        return this;
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    XMLFacetInfoImpl.prototype.wrapperClassName = function () { return "XMLFacetInfoImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    XMLFacetInfoImpl.prototype.kind = function () { return "XMLFacetInfo"; };
	    /**
	     * @return RAML version of the node
	     **/
	    XMLFacetInfoImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    /**
	     * Scalar properties annotations accessor
	     **/
	    XMLFacetInfoImpl.prototype.scalarsAnnotations = function () { return new XMLFacetInfoScalarsAnnotationsImpl(this.highLevel()); };
	    return XMLFacetInfoImpl;
	}(AnnotableImpl));
	exports.XMLFacetInfoImpl = XMLFacetInfoImpl;
	/**
	 * Annotable scalar properties annotations accessor
	 **/
	var AnnotableScalarsAnnotationsImpl = (function () {
	    function AnnotableScalarsAnnotationsImpl(node) {
	        this.node = node;
	    }
	    /**
	     * Annotable.annotations annotations
	     **/
	    AnnotableScalarsAnnotationsImpl.prototype.annotations = function () {
	        var attrs = this.node.attributes("annotations");
	        return attrs.map(function (x) {
	            var annotationAttrs = x.annotations();
	            var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	            return result;
	        });
	    };
	    return AnnotableScalarsAnnotationsImpl;
	}());
	exports.AnnotableScalarsAnnotationsImpl = AnnotableScalarsAnnotationsImpl;
	/**
	 * XMLFacetInfo scalar properties annotations accessor
	 **/
	var XMLFacetInfoScalarsAnnotationsImpl = (function (_super) {
	    __extends(XMLFacetInfoScalarsAnnotationsImpl, _super);
	    function XMLFacetInfoScalarsAnnotationsImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * XMLFacetInfo.attribute annotations
	     **/
	    XMLFacetInfoScalarsAnnotationsImpl.prototype.attribute = function () {
	        var attr = this.node.attr("attribute");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * XMLFacetInfo.wrapped annotations
	     **/
	    XMLFacetInfoScalarsAnnotationsImpl.prototype.wrapped = function () {
	        var attr = this.node.attr("wrapped");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * XMLFacetInfo.name annotations
	     **/
	    XMLFacetInfoScalarsAnnotationsImpl.prototype.name = function () {
	        var attr = this.node.attr("name");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * XMLFacetInfo.namespace annotations
	     **/
	    XMLFacetInfoScalarsAnnotationsImpl.prototype.namespace = function () {
	        var attr = this.node.attr("namespace");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * XMLFacetInfo.prefix annotations
	     **/
	    XMLFacetInfoScalarsAnnotationsImpl.prototype.prefix = function () {
	        var attr = this.node.attr("prefix");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    return XMLFacetInfoScalarsAnnotationsImpl;
	}(AnnotableScalarsAnnotationsImpl));
	exports.XMLFacetInfoScalarsAnnotationsImpl = XMLFacetInfoScalarsAnnotationsImpl;
	var UsesDeclarationImpl = (function (_super) {
	    __extends(UsesDeclarationImpl, _super);
	    function UsesDeclarationImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createUsesDeclaration(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * Name prefix (without dot) used to refer imported declarations
	     **/
	    UsesDeclarationImpl.prototype.key = function () {
	        return _super.prototype.attribute.call(this, 'key', this.toString);
	    };
	    /**
	     * @hidden
	     * Set key value
	     **/
	    UsesDeclarationImpl.prototype.setKey = function (param) {
	        this.highLevel().attrOrCreate("key").setValue("" + param);
	        return this;
	    };
	    /**
	     * Content of the schema
	     **/
	    UsesDeclarationImpl.prototype.value = function () {
	        return _super.prototype.attribute.call(this, 'value', this.toString);
	    };
	    /**
	     * @hidden
	     * Set value value
	     **/
	    UsesDeclarationImpl.prototype.setValue = function (param) {
	        this.highLevel().attrOrCreate("value").setValue("" + param);
	        return this;
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    UsesDeclarationImpl.prototype.wrapperClassName = function () { return "UsesDeclarationImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    UsesDeclarationImpl.prototype.kind = function () { return "UsesDeclaration"; };
	    /**
	     * @return RAML version of the node
	     **/
	    UsesDeclarationImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    /**
	     * Returns the root node of the AST, uses statement refers.
	     **/
	    UsesDeclarationImpl.prototype.ast = function () {
	        return helper.referencedNode(this);
	    };
	    /**
	     * Scalar properties annotations accessor
	     **/
	    UsesDeclarationImpl.prototype.scalarsAnnotations = function () { return new UsesDeclarationScalarsAnnotationsImpl(this.highLevel()); };
	    return UsesDeclarationImpl;
	}(AnnotableImpl));
	exports.UsesDeclarationImpl = UsesDeclarationImpl;
	/**
	 * UsesDeclaration scalar properties annotations accessor
	 **/
	var UsesDeclarationScalarsAnnotationsImpl = (function (_super) {
	    __extends(UsesDeclarationScalarsAnnotationsImpl, _super);
	    function UsesDeclarationScalarsAnnotationsImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * UsesDeclaration.value annotations
	     **/
	    UsesDeclarationScalarsAnnotationsImpl.prototype.value = function () {
	        var attr = this.node.attr("value");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    return UsesDeclarationScalarsAnnotationsImpl;
	}(AnnotableScalarsAnnotationsImpl));
	exports.UsesDeclarationScalarsAnnotationsImpl = UsesDeclarationScalarsAnnotationsImpl;
	var ArrayTypeDeclarationImpl = (function (_super) {
	    __extends(ArrayTypeDeclarationImpl, _super);
	    function ArrayTypeDeclarationImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createArrayTypeDeclaration(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * Should items in array be unique
	     **/
	    ArrayTypeDeclarationImpl.prototype.uniqueItems = function () {
	        return _super.prototype.attribute.call(this, 'uniqueItems', this.toBoolean);
	    };
	    /**
	     * @hidden
	     * Set uniqueItems value
	     **/
	    ArrayTypeDeclarationImpl.prototype.setUniqueItems = function (param) {
	        this.highLevel().attrOrCreate("uniqueItems").setValue("" + param);
	        return this;
	    };
	    /**
	     * Array component type.
	     **/
	    ArrayTypeDeclarationImpl.prototype.items = function () {
	        return _super.prototype.element.call(this, 'items');
	    };
	    /**
	     * Minimum amount of items in array
	     **/
	    ArrayTypeDeclarationImpl.prototype.minItems = function () {
	        return _super.prototype.attribute.call(this, 'minItems', this.toNumber);
	    };
	    /**
	     * @hidden
	     * Set minItems value
	     **/
	    ArrayTypeDeclarationImpl.prototype.setMinItems = function (param) {
	        this.highLevel().attrOrCreate("minItems").setValue("" + param);
	        return this;
	    };
	    /**
	     * Maximum amount of items in array
	     **/
	    ArrayTypeDeclarationImpl.prototype.maxItems = function () {
	        return _super.prototype.attribute.call(this, 'maxItems', this.toNumber);
	    };
	    /**
	     * @hidden
	     * Set maxItems value
	     **/
	    ArrayTypeDeclarationImpl.prototype.setMaxItems = function (param) {
	        this.highLevel().attrOrCreate("maxItems").setValue("" + param);
	        return this;
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    ArrayTypeDeclarationImpl.prototype.wrapperClassName = function () { return "ArrayTypeDeclarationImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    ArrayTypeDeclarationImpl.prototype.kind = function () { return "ArrayTypeDeclaration"; };
	    /**
	     * @return RAML version of the node
	     **/
	    ArrayTypeDeclarationImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    /**
	     * Scalar properties annotations accessor
	     **/
	    ArrayTypeDeclarationImpl.prototype.scalarsAnnotations = function () { return new ArrayTypeDeclarationScalarsAnnotationsImpl(this.highLevel()); };
	    return ArrayTypeDeclarationImpl;
	}(TypeDeclarationImpl));
	exports.ArrayTypeDeclarationImpl = ArrayTypeDeclarationImpl;
	/**
	 * TypeDeclaration scalar properties annotations accessor
	 **/
	var TypeDeclarationScalarsAnnotationsImpl = (function (_super) {
	    __extends(TypeDeclarationScalarsAnnotationsImpl, _super);
	    function TypeDeclarationScalarsAnnotationsImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * TypeDeclaration.displayName annotations
	     **/
	    TypeDeclarationScalarsAnnotationsImpl.prototype.displayName = function () {
	        var attr = this.node.attr("displayName");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * TypeDeclaration.schema annotations
	     **/
	    TypeDeclarationScalarsAnnotationsImpl.prototype.schema = function () {
	        var attrs = this.node.attributes("schema");
	        return attrs.map(function (x) {
	            var annotationAttrs = x.annotations();
	            var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	            return result;
	        });
	    };
	    /**
	     * TypeDeclaration.type annotations
	     **/
	    TypeDeclarationScalarsAnnotationsImpl.prototype["type"] = function () {
	        var attrs = this.node.attributes("type");
	        return attrs.map(function (x) {
	            var annotationAttrs = x.annotations();
	            var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	            return result;
	        });
	    };
	    /**
	     * TypeDeclaration.location annotations
	     **/
	    TypeDeclarationScalarsAnnotationsImpl.prototype.location = function () {
	        var attr = this.node.attr("location");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * TypeDeclaration.locationKind annotations
	     **/
	    TypeDeclarationScalarsAnnotationsImpl.prototype.locationKind = function () {
	        var attr = this.node.attr("locationKind");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * TypeDeclaration.default annotations
	     **/
	    TypeDeclarationScalarsAnnotationsImpl.prototype["default"] = function () {
	        var attr = this.node.attr("default");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * TypeDeclaration.repeat annotations
	     **/
	    TypeDeclarationScalarsAnnotationsImpl.prototype.repeat = function () {
	        var attr = this.node.attr("repeat");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * TypeDeclaration.required annotations
	     **/
	    TypeDeclarationScalarsAnnotationsImpl.prototype.required = function () {
	        var attr = this.node.attr("required");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * TypeDeclaration.description annotations
	     **/
	    TypeDeclarationScalarsAnnotationsImpl.prototype.description = function () {
	        var attr = this.node.attr("description");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * TypeDeclaration.allowedTargets annotations
	     **/
	    TypeDeclarationScalarsAnnotationsImpl.prototype.allowedTargets = function () {
	        var attrs = this.node.attributes("allowedTargets");
	        return attrs.map(function (x) {
	            var annotationAttrs = x.annotations();
	            var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	            return result;
	        });
	    };
	    /**
	     * TypeDeclaration.isAnnotation annotations
	     **/
	    TypeDeclarationScalarsAnnotationsImpl.prototype.isAnnotation = function () {
	        var attr = this.node.attr("isAnnotation");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * TypeDeclaration.annotations annotations
	     **/
	    TypeDeclarationScalarsAnnotationsImpl.prototype.annotations = function () {
	        var attrs = this.node.attributes("annotations");
	        return attrs.map(function (x) {
	            var annotationAttrs = x.annotations();
	            var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	            return result;
	        });
	    };
	    return TypeDeclarationScalarsAnnotationsImpl;
	}(AnnotableScalarsAnnotationsImpl));
	exports.TypeDeclarationScalarsAnnotationsImpl = TypeDeclarationScalarsAnnotationsImpl;
	/**
	 * ArrayTypeDeclaration scalar properties annotations accessor
	 **/
	var ArrayTypeDeclarationScalarsAnnotationsImpl = (function (_super) {
	    __extends(ArrayTypeDeclarationScalarsAnnotationsImpl, _super);
	    function ArrayTypeDeclarationScalarsAnnotationsImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * ArrayTypeDeclaration.uniqueItems annotations
	     **/
	    ArrayTypeDeclarationScalarsAnnotationsImpl.prototype.uniqueItems = function () {
	        var attr = this.node.attr("uniqueItems");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * ArrayTypeDeclaration.minItems annotations
	     **/
	    ArrayTypeDeclarationScalarsAnnotationsImpl.prototype.minItems = function () {
	        var attr = this.node.attr("minItems");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * ArrayTypeDeclaration.maxItems annotations
	     **/
	    ArrayTypeDeclarationScalarsAnnotationsImpl.prototype.maxItems = function () {
	        var attr = this.node.attr("maxItems");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    return ArrayTypeDeclarationScalarsAnnotationsImpl;
	}(TypeDeclarationScalarsAnnotationsImpl));
	exports.ArrayTypeDeclarationScalarsAnnotationsImpl = ArrayTypeDeclarationScalarsAnnotationsImpl;
	var UnionTypeDeclarationImpl = (function (_super) {
	    __extends(UnionTypeDeclarationImpl, _super);
	    function UnionTypeDeclarationImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createUnionTypeDeclaration(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    UnionTypeDeclarationImpl.prototype.wrapperClassName = function () { return "UnionTypeDeclarationImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    UnionTypeDeclarationImpl.prototype.kind = function () { return "UnionTypeDeclaration"; };
	    /**
	     * @return RAML version of the node
	     **/
	    UnionTypeDeclarationImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return UnionTypeDeclarationImpl;
	}(TypeDeclarationImpl));
	exports.UnionTypeDeclarationImpl = UnionTypeDeclarationImpl;
	var ObjectTypeDeclarationImpl = (function (_super) {
	    __extends(ObjectTypeDeclarationImpl, _super);
	    function ObjectTypeDeclarationImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createObjectTypeDeclaration(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * The properties that instances of this type may or must have.
	     **/
	    ObjectTypeDeclarationImpl.prototype.properties = function () {
	        return _super.prototype.elements.call(this, 'properties');
	    };
	    /**
	     * The minimum number of properties allowed for instances of this type.
	     **/
	    ObjectTypeDeclarationImpl.prototype.minProperties = function () {
	        return _super.prototype.attribute.call(this, 'minProperties', this.toNumber);
	    };
	    /**
	     * @hidden
	     * Set minProperties value
	     **/
	    ObjectTypeDeclarationImpl.prototype.setMinProperties = function (param) {
	        this.highLevel().attrOrCreate("minProperties").setValue("" + param);
	        return this;
	    };
	    /**
	     * The maximum number of properties allowed for instances of this type.
	     **/
	    ObjectTypeDeclarationImpl.prototype.maxProperties = function () {
	        return _super.prototype.attribute.call(this, 'maxProperties', this.toNumber);
	    };
	    /**
	     * @hidden
	     * Set maxProperties value
	     **/
	    ObjectTypeDeclarationImpl.prototype.setMaxProperties = function (param) {
	        this.highLevel().attrOrCreate("maxProperties").setValue("" + param);
	        return this;
	    };
	    /**
	     * JSON schema style syntax for declaring maps
	     **/
	    ObjectTypeDeclarationImpl.prototype.additionalProperties = function () {
	        return _super.prototype.element.call(this, 'additionalProperties');
	    };
	    /**
	     * JSON schema style syntax for declaring key restricted maps
	     **/
	    ObjectTypeDeclarationImpl.prototype.patternProperties = function () {
	        return _super.prototype.elements.call(this, 'patternProperties');
	    };
	    /**
	     * Type property name to be used as discriminator, or boolean
	     **/
	    ObjectTypeDeclarationImpl.prototype.discriminator = function () {
	        return _super.prototype.attribute.call(this, 'discriminator', this.toString);
	    };
	    /**
	     * @hidden
	     * Set discriminator value
	     **/
	    ObjectTypeDeclarationImpl.prototype.setDiscriminator = function (param) {
	        this.highLevel().attrOrCreate("discriminator").setValue("" + param);
	        return this;
	    };
	    /**
	     * The value of discriminator for the type.
	     **/
	    ObjectTypeDeclarationImpl.prototype.discriminatorValue = function () {
	        return _super.prototype.attribute.call(this, 'discriminatorValue', this.toString);
	    };
	    /**
	     * @hidden
	     * Set discriminatorValue value
	     **/
	    ObjectTypeDeclarationImpl.prototype.setDiscriminatorValue = function (param) {
	        this.highLevel().attrOrCreate("discriminatorValue").setValue("" + param);
	        return this;
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    ObjectTypeDeclarationImpl.prototype.wrapperClassName = function () { return "ObjectTypeDeclarationImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    ObjectTypeDeclarationImpl.prototype.kind = function () { return "ObjectTypeDeclaration"; };
	    /**
	     * @return RAML version of the node
	     **/
	    ObjectTypeDeclarationImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    /**
	     * Scalar properties annotations accessor
	     **/
	    ObjectTypeDeclarationImpl.prototype.scalarsAnnotations = function () { return new ObjectTypeDeclarationScalarsAnnotationsImpl(this.highLevel()); };
	    return ObjectTypeDeclarationImpl;
	}(TypeDeclarationImpl));
	exports.ObjectTypeDeclarationImpl = ObjectTypeDeclarationImpl;
	/**
	 * ObjectTypeDeclaration scalar properties annotations accessor
	 **/
	var ObjectTypeDeclarationScalarsAnnotationsImpl = (function (_super) {
	    __extends(ObjectTypeDeclarationScalarsAnnotationsImpl, _super);
	    function ObjectTypeDeclarationScalarsAnnotationsImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * ObjectTypeDeclaration.minProperties annotations
	     **/
	    ObjectTypeDeclarationScalarsAnnotationsImpl.prototype.minProperties = function () {
	        var attr = this.node.attr("minProperties");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * ObjectTypeDeclaration.maxProperties annotations
	     **/
	    ObjectTypeDeclarationScalarsAnnotationsImpl.prototype.maxProperties = function () {
	        var attr = this.node.attr("maxProperties");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * ObjectTypeDeclaration.discriminator annotations
	     **/
	    ObjectTypeDeclarationScalarsAnnotationsImpl.prototype.discriminator = function () {
	        var attr = this.node.attr("discriminator");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * ObjectTypeDeclaration.discriminatorValue annotations
	     **/
	    ObjectTypeDeclarationScalarsAnnotationsImpl.prototype.discriminatorValue = function () {
	        var attr = this.node.attr("discriminatorValue");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    return ObjectTypeDeclarationScalarsAnnotationsImpl;
	}(TypeDeclarationScalarsAnnotationsImpl));
	exports.ObjectTypeDeclarationScalarsAnnotationsImpl = ObjectTypeDeclarationScalarsAnnotationsImpl;
	/**
	 * Value must be a string
	 **/
	var StringTypeDeclarationImpl = (function (_super) {
	    __extends(StringTypeDeclarationImpl, _super);
	    function StringTypeDeclarationImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createStringTypeDeclaration(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * Regular expression that this string should path
	     **/
	    StringTypeDeclarationImpl.prototype.pattern = function () {
	        return _super.prototype.attribute.call(this, 'pattern', this.toString);
	    };
	    /**
	     * @hidden
	     * Set pattern value
	     **/
	    StringTypeDeclarationImpl.prototype.setPattern = function (param) {
	        this.highLevel().attrOrCreate("pattern").setValue("" + param);
	        return this;
	    };
	    /**
	     * Minimum length of the string
	     **/
	    StringTypeDeclarationImpl.prototype.minLength = function () {
	        return _super.prototype.attribute.call(this, 'minLength', this.toNumber);
	    };
	    /**
	     * @hidden
	     * Set minLength value
	     **/
	    StringTypeDeclarationImpl.prototype.setMinLength = function (param) {
	        this.highLevel().attrOrCreate("minLength").setValue("" + param);
	        return this;
	    };
	    /**
	     * Maximum length of the string
	     **/
	    StringTypeDeclarationImpl.prototype.maxLength = function () {
	        return _super.prototype.attribute.call(this, 'maxLength', this.toNumber);
	    };
	    /**
	     * @hidden
	     * Set maxLength value
	     **/
	    StringTypeDeclarationImpl.prototype.setMaxLength = function (param) {
	        this.highLevel().attrOrCreate("maxLength").setValue("" + param);
	        return this;
	    };
	    /**
	     * (Optional, applicable only for parameters of type string) The enum attribute provides an enumeration of the parameter's valid values. This MUST be an array. If the enum attribute is defined, API clients and servers MUST verify that a parameter's value matches a value in the enum array. If there is no matching value, the clients and servers MUST treat this as an error.
	     **/
	    StringTypeDeclarationImpl.prototype.enum = function () {
	        return _super.prototype.attributes.call(this, 'enum', this.toString);
	    };
	    /**
	     * @hidden
	     * Set enum value
	     **/
	    StringTypeDeclarationImpl.prototype.setEnum = function (param) {
	        this.highLevel().attrOrCreate("enum").setValue("" + param);
	        return this;
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    StringTypeDeclarationImpl.prototype.wrapperClassName = function () { return "StringTypeDeclarationImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    StringTypeDeclarationImpl.prototype.kind = function () { return "StringTypeDeclaration"; };
	    /**
	     * @return RAML version of the node
	     **/
	    StringTypeDeclarationImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    /**
	     * Scalar properties annotations accessor
	     **/
	    StringTypeDeclarationImpl.prototype.scalarsAnnotations = function () { return new StringTypeDeclarationScalarsAnnotationsImpl(this.highLevel()); };
	    return StringTypeDeclarationImpl;
	}(TypeDeclarationImpl));
	exports.StringTypeDeclarationImpl = StringTypeDeclarationImpl;
	/**
	 * StringTypeDeclaration scalar properties annotations accessor
	 **/
	var StringTypeDeclarationScalarsAnnotationsImpl = (function (_super) {
	    __extends(StringTypeDeclarationScalarsAnnotationsImpl, _super);
	    function StringTypeDeclarationScalarsAnnotationsImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * StringTypeDeclaration.pattern annotations
	     **/
	    StringTypeDeclarationScalarsAnnotationsImpl.prototype.pattern = function () {
	        var attr = this.node.attr("pattern");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * StringTypeDeclaration.minLength annotations
	     **/
	    StringTypeDeclarationScalarsAnnotationsImpl.prototype.minLength = function () {
	        var attr = this.node.attr("minLength");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * StringTypeDeclaration.maxLength annotations
	     **/
	    StringTypeDeclarationScalarsAnnotationsImpl.prototype.maxLength = function () {
	        var attr = this.node.attr("maxLength");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * StringTypeDeclaration.enum annotations
	     **/
	    StringTypeDeclarationScalarsAnnotationsImpl.prototype.enum = function () {
	        var attrs = this.node.attributes("enum");
	        return attrs.map(function (x) {
	            var annotationAttrs = x.annotations();
	            var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	            return result;
	        });
	    };
	    return StringTypeDeclarationScalarsAnnotationsImpl;
	}(TypeDeclarationScalarsAnnotationsImpl));
	exports.StringTypeDeclarationScalarsAnnotationsImpl = StringTypeDeclarationScalarsAnnotationsImpl;
	/**
	 * Value must be a boolean
	 **/
	var BooleanTypeDeclarationImpl = (function (_super) {
	    __extends(BooleanTypeDeclarationImpl, _super);
	    function BooleanTypeDeclarationImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createBooleanTypeDeclaration(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    BooleanTypeDeclarationImpl.prototype.wrapperClassName = function () { return "BooleanTypeDeclarationImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    BooleanTypeDeclarationImpl.prototype.kind = function () { return "BooleanTypeDeclaration"; };
	    /**
	     * @return RAML version of the node
	     **/
	    BooleanTypeDeclarationImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return BooleanTypeDeclarationImpl;
	}(TypeDeclarationImpl));
	exports.BooleanTypeDeclarationImpl = BooleanTypeDeclarationImpl;
	/**
	 * Value MUST be a number. Indicate floating point numbers as defined by YAML.
	 **/
	var NumberTypeDeclarationImpl = (function (_super) {
	    __extends(NumberTypeDeclarationImpl, _super);
	    function NumberTypeDeclarationImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createNumberTypeDeclaration(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * (Optional, applicable only for parameters of type number or integer) The minimum attribute specifies the parameter's minimum value.
	     **/
	    NumberTypeDeclarationImpl.prototype.minimum = function () {
	        return _super.prototype.attribute.call(this, 'minimum', this.toNumber);
	    };
	    /**
	     * @hidden
	     * Set minimum value
	     **/
	    NumberTypeDeclarationImpl.prototype.setMinimum = function (param) {
	        this.highLevel().attrOrCreate("minimum").setValue("" + param);
	        return this;
	    };
	    /**
	     * (Optional, applicable only for parameters of type number or integer) The maximum attribute specifies the parameter's maximum value.
	     **/
	    NumberTypeDeclarationImpl.prototype.maximum = function () {
	        return _super.prototype.attribute.call(this, 'maximum', this.toNumber);
	    };
	    /**
	     * @hidden
	     * Set maximum value
	     **/
	    NumberTypeDeclarationImpl.prototype.setMaximum = function (param) {
	        this.highLevel().attrOrCreate("maximum").setValue("" + param);
	        return this;
	    };
	    /**
	     * (Optional, applicable only for parameters of type string) The enum attribute provides an enumeration of the parameter's valid values. This MUST be an array. If the enum attribute is defined, API clients and servers MUST verify that a parameter's value matches a value in the enum array. If there is no matching value, the clients and servers MUST treat this as an error.
	     **/
	    NumberTypeDeclarationImpl.prototype.enum = function () {
	        return _super.prototype.attributes.call(this, 'enum', this.toString);
	    };
	    /**
	     * @hidden
	     * Set enum value
	     **/
	    NumberTypeDeclarationImpl.prototype.setEnum = function (param) {
	        this.highLevel().attrOrCreate("enum").setValue("" + param);
	        return this;
	    };
	    /**
	     * Value format
	     **/
	    NumberTypeDeclarationImpl.prototype.format = function () {
	        return _super.prototype.attribute.call(this, 'format', this.toString);
	    };
	    /**
	     * @hidden
	     * Set format value
	     **/
	    NumberTypeDeclarationImpl.prototype.setFormat = function (param) {
	        this.highLevel().attrOrCreate("format").setValue("" + param);
	        return this;
	    };
	    /**
	     * A numeric instance is valid against "multipleOf" if the result of the division of the instance by this keyword's value is an integer.
	     **/
	    NumberTypeDeclarationImpl.prototype.multipleOf = function () {
	        return _super.prototype.attribute.call(this, 'multipleOf', this.toNumber);
	    };
	    /**
	     * @hidden
	     * Set multipleOf value
	     **/
	    NumberTypeDeclarationImpl.prototype.setMultipleOf = function (param) {
	        this.highLevel().attrOrCreate("multipleOf").setValue("" + param);
	        return this;
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    NumberTypeDeclarationImpl.prototype.wrapperClassName = function () { return "NumberTypeDeclarationImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    NumberTypeDeclarationImpl.prototype.kind = function () { return "NumberTypeDeclaration"; };
	    /**
	     * @return RAML version of the node
	     **/
	    NumberTypeDeclarationImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    /**
	     * Scalar properties annotations accessor
	     **/
	    NumberTypeDeclarationImpl.prototype.scalarsAnnotations = function () { return new NumberTypeDeclarationScalarsAnnotationsImpl(this.highLevel()); };
	    return NumberTypeDeclarationImpl;
	}(TypeDeclarationImpl));
	exports.NumberTypeDeclarationImpl = NumberTypeDeclarationImpl;
	/**
	 * Value MUST be a integer.
	 **/
	var IntegerTypeDeclarationImpl = (function (_super) {
	    __extends(IntegerTypeDeclarationImpl, _super);
	    function IntegerTypeDeclarationImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createIntegerTypeDeclaration(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * Value format
	     **/
	    IntegerTypeDeclarationImpl.prototype.format = function () {
	        return _super.prototype.attribute.call(this, 'format', this.toString);
	    };
	    /**
	     * @hidden
	     * Set format value
	     **/
	    IntegerTypeDeclarationImpl.prototype.setFormat = function (param) {
	        this.highLevel().attrOrCreate("format").setValue("" + param);
	        return this;
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    IntegerTypeDeclarationImpl.prototype.wrapperClassName = function () { return "IntegerTypeDeclarationImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    IntegerTypeDeclarationImpl.prototype.kind = function () { return "IntegerTypeDeclaration"; };
	    /**
	     * @return RAML version of the node
	     **/
	    IntegerTypeDeclarationImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    /**
	     * Scalar properties annotations accessor
	     **/
	    IntegerTypeDeclarationImpl.prototype.scalarsAnnotations = function () { return new IntegerTypeDeclarationScalarsAnnotationsImpl(this.highLevel()); };
	    return IntegerTypeDeclarationImpl;
	}(NumberTypeDeclarationImpl));
	exports.IntegerTypeDeclarationImpl = IntegerTypeDeclarationImpl;
	/**
	 * NumberTypeDeclaration scalar properties annotations accessor
	 **/
	var NumberTypeDeclarationScalarsAnnotationsImpl = (function (_super) {
	    __extends(NumberTypeDeclarationScalarsAnnotationsImpl, _super);
	    function NumberTypeDeclarationScalarsAnnotationsImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * NumberTypeDeclaration.minimum annotations
	     **/
	    NumberTypeDeclarationScalarsAnnotationsImpl.prototype.minimum = function () {
	        var attr = this.node.attr("minimum");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * NumberTypeDeclaration.maximum annotations
	     **/
	    NumberTypeDeclarationScalarsAnnotationsImpl.prototype.maximum = function () {
	        var attr = this.node.attr("maximum");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * NumberTypeDeclaration.enum annotations
	     **/
	    NumberTypeDeclarationScalarsAnnotationsImpl.prototype.enum = function () {
	        var attrs = this.node.attributes("enum");
	        return attrs.map(function (x) {
	            var annotationAttrs = x.annotations();
	            var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	            return result;
	        });
	    };
	    /**
	     * NumberTypeDeclaration.format annotations
	     **/
	    NumberTypeDeclarationScalarsAnnotationsImpl.prototype.format = function () {
	        var attr = this.node.attr("format");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * NumberTypeDeclaration.multipleOf annotations
	     **/
	    NumberTypeDeclarationScalarsAnnotationsImpl.prototype.multipleOf = function () {
	        var attr = this.node.attr("multipleOf");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    return NumberTypeDeclarationScalarsAnnotationsImpl;
	}(TypeDeclarationScalarsAnnotationsImpl));
	exports.NumberTypeDeclarationScalarsAnnotationsImpl = NumberTypeDeclarationScalarsAnnotationsImpl;
	/**
	 * IntegerTypeDeclaration scalar properties annotations accessor
	 **/
	var IntegerTypeDeclarationScalarsAnnotationsImpl = (function (_super) {
	    __extends(IntegerTypeDeclarationScalarsAnnotationsImpl, _super);
	    function IntegerTypeDeclarationScalarsAnnotationsImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * IntegerTypeDeclaration.format annotations
	     **/
	    IntegerTypeDeclarationScalarsAnnotationsImpl.prototype.format = function () {
	        var attr = this.node.attr("format");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    return IntegerTypeDeclarationScalarsAnnotationsImpl;
	}(NumberTypeDeclarationScalarsAnnotationsImpl));
	exports.IntegerTypeDeclarationScalarsAnnotationsImpl = IntegerTypeDeclarationScalarsAnnotationsImpl;
	/**
	 * the "full-date" notation of RFC3339, namely yyyy-mm-dd (no implications about time or timezone-offset)
	 **/
	var DateOnlyTypeDeclarationImpl = (function (_super) {
	    __extends(DateOnlyTypeDeclarationImpl, _super);
	    function DateOnlyTypeDeclarationImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createDateOnlyTypeDeclaration(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    DateOnlyTypeDeclarationImpl.prototype.wrapperClassName = function () { return "DateOnlyTypeDeclarationImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    DateOnlyTypeDeclarationImpl.prototype.kind = function () { return "DateOnlyTypeDeclaration"; };
	    /**
	     * @return RAML version of the node
	     **/
	    DateOnlyTypeDeclarationImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return DateOnlyTypeDeclarationImpl;
	}(TypeDeclarationImpl));
	exports.DateOnlyTypeDeclarationImpl = DateOnlyTypeDeclarationImpl;
	/**
	 * the "partial-time" notation of RFC3339, namely hh:mm:ss[.ff...] (no implications about date or timezone-offset)
	 **/
	var TimeOnlyTypeDeclarationImpl = (function (_super) {
	    __extends(TimeOnlyTypeDeclarationImpl, _super);
	    function TimeOnlyTypeDeclarationImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createTimeOnlyTypeDeclaration(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    TimeOnlyTypeDeclarationImpl.prototype.wrapperClassName = function () { return "TimeOnlyTypeDeclarationImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    TimeOnlyTypeDeclarationImpl.prototype.kind = function () { return "TimeOnlyTypeDeclaration"; };
	    /**
	     * @return RAML version of the node
	     **/
	    TimeOnlyTypeDeclarationImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return TimeOnlyTypeDeclarationImpl;
	}(TypeDeclarationImpl));
	exports.TimeOnlyTypeDeclarationImpl = TimeOnlyTypeDeclarationImpl;
	/**
	 * combined date-only and time-only with a separator of "T", namely yyyy-mm-ddThh:mm:ss[.ff...] (no implications about timezone-offset)
	 **/
	var DateTimeOnlyTypeDeclarationImpl = (function (_super) {
	    __extends(DateTimeOnlyTypeDeclarationImpl, _super);
	    function DateTimeOnlyTypeDeclarationImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createDateTimeOnlyTypeDeclaration(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    DateTimeOnlyTypeDeclarationImpl.prototype.wrapperClassName = function () { return "DateTimeOnlyTypeDeclarationImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    DateTimeOnlyTypeDeclarationImpl.prototype.kind = function () { return "DateTimeOnlyTypeDeclaration"; };
	    /**
	     * @return RAML version of the node
	     **/
	    DateTimeOnlyTypeDeclarationImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return DateTimeOnlyTypeDeclarationImpl;
	}(TypeDeclarationImpl));
	exports.DateTimeOnlyTypeDeclarationImpl = DateTimeOnlyTypeDeclarationImpl;
	/**
	 * a timestamp, either in the "date-time" notation of RFC3339, if format is omitted or is set to rfc3339, or in the format defined in RFC2616, if format is set to rfc2616.
	 **/
	var DateTimeTypeDeclarationImpl = (function (_super) {
	    __extends(DateTimeTypeDeclarationImpl, _super);
	    function DateTimeTypeDeclarationImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createDateTimeTypeDeclaration(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * Format used for this date time rfc3339 or rfc2616
	     **/
	    DateTimeTypeDeclarationImpl.prototype.format = function () {
	        return _super.prototype.attribute.call(this, 'format', this.toString);
	    };
	    /**
	     * @hidden
	     * Set format value
	     **/
	    DateTimeTypeDeclarationImpl.prototype.setFormat = function (param) {
	        this.highLevel().attrOrCreate("format").setValue("" + param);
	        return this;
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    DateTimeTypeDeclarationImpl.prototype.wrapperClassName = function () { return "DateTimeTypeDeclarationImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    DateTimeTypeDeclarationImpl.prototype.kind = function () { return "DateTimeTypeDeclaration"; };
	    /**
	     * @return RAML version of the node
	     **/
	    DateTimeTypeDeclarationImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    /**
	     * Scalar properties annotations accessor
	     **/
	    DateTimeTypeDeclarationImpl.prototype.scalarsAnnotations = function () { return new DateTimeTypeDeclarationScalarsAnnotationsImpl(this.highLevel()); };
	    return DateTimeTypeDeclarationImpl;
	}(TypeDeclarationImpl));
	exports.DateTimeTypeDeclarationImpl = DateTimeTypeDeclarationImpl;
	/**
	 * DateTimeTypeDeclaration scalar properties annotations accessor
	 **/
	var DateTimeTypeDeclarationScalarsAnnotationsImpl = (function (_super) {
	    __extends(DateTimeTypeDeclarationScalarsAnnotationsImpl, _super);
	    function DateTimeTypeDeclarationScalarsAnnotationsImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * DateTimeTypeDeclaration.format annotations
	     **/
	    DateTimeTypeDeclarationScalarsAnnotationsImpl.prototype.format = function () {
	        var attr = this.node.attr("format");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    return DateTimeTypeDeclarationScalarsAnnotationsImpl;
	}(TypeDeclarationScalarsAnnotationsImpl));
	exports.DateTimeTypeDeclarationScalarsAnnotationsImpl = DateTimeTypeDeclarationScalarsAnnotationsImpl;
	/**
	 * Value MUST be a string representation of a date as defined in RFC2616 Section 3.3, or according to specified date format
	 **/
	var DateTypeDeclarationImpl = (function (_super) {
	    __extends(DateTypeDeclarationImpl, _super);
	    function DateTypeDeclarationImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createDateTypeDeclaration(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    DateTypeDeclarationImpl.prototype.wrapperClassName = function () { return "DateTypeDeclarationImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    DateTypeDeclarationImpl.prototype.kind = function () { return "DateTypeDeclaration"; };
	    /**
	     * @return RAML version of the node
	     **/
	    DateTypeDeclarationImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return DateTypeDeclarationImpl;
	}(TypeDeclarationImpl));
	exports.DateTypeDeclarationImpl = DateTypeDeclarationImpl;
	/**
	 * (Applicable only to Form properties) Value is a file. Client generators SHOULD use this type to handle file uploads correctly.
	 **/
	var FileTypeDeclarationImpl = (function (_super) {
	    __extends(FileTypeDeclarationImpl, _super);
	    function FileTypeDeclarationImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createFileTypeDeclaration(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * It should also include a new property: fileTypes, which should be a list of valid content-type strings for the file. The file type * /* should be a valid value.
	     **/
	    FileTypeDeclarationImpl.prototype.fileTypes = function () {
	        return _super.prototype.attributes.call(this, 'fileTypes', function (attr) { return new ContentTypeImpl(attr); });
	    };
	    /**
	     * The minLength attribute specifies the parameter value's minimum number of bytes.
	     **/
	    FileTypeDeclarationImpl.prototype.minLength = function () {
	        return _super.prototype.attribute.call(this, 'minLength', this.toNumber);
	    };
	    /**
	     * @hidden
	     * Set minLength value
	     **/
	    FileTypeDeclarationImpl.prototype.setMinLength = function (param) {
	        this.highLevel().attrOrCreate("minLength").setValue("" + param);
	        return this;
	    };
	    /**
	     * The maxLength attribute specifies the parameter value's maximum number of bytes.
	     **/
	    FileTypeDeclarationImpl.prototype.maxLength = function () {
	        return _super.prototype.attribute.call(this, 'maxLength', this.toNumber);
	    };
	    /**
	     * @hidden
	     * Set maxLength value
	     **/
	    FileTypeDeclarationImpl.prototype.setMaxLength = function (param) {
	        this.highLevel().attrOrCreate("maxLength").setValue("" + param);
	        return this;
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    FileTypeDeclarationImpl.prototype.wrapperClassName = function () { return "FileTypeDeclarationImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    FileTypeDeclarationImpl.prototype.kind = function () { return "FileTypeDeclaration"; };
	    /**
	     * @return RAML version of the node
	     **/
	    FileTypeDeclarationImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    /**
	     * Scalar properties annotations accessor
	     **/
	    FileTypeDeclarationImpl.prototype.scalarsAnnotations = function () { return new FileTypeDeclarationScalarsAnnotationsImpl(this.highLevel()); };
	    return FileTypeDeclarationImpl;
	}(TypeDeclarationImpl));
	exports.FileTypeDeclarationImpl = FileTypeDeclarationImpl;
	/**
	 * FileTypeDeclaration scalar properties annotations accessor
	 **/
	var FileTypeDeclarationScalarsAnnotationsImpl = (function (_super) {
	    __extends(FileTypeDeclarationScalarsAnnotationsImpl, _super);
	    function FileTypeDeclarationScalarsAnnotationsImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * FileTypeDeclaration.fileTypes annotations
	     **/
	    FileTypeDeclarationScalarsAnnotationsImpl.prototype.fileTypes = function () {
	        var attrs = this.node.attributes("fileTypes");
	        return attrs.map(function (x) {
	            var annotationAttrs = x.annotations();
	            var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	            return result;
	        });
	    };
	    /**
	     * FileTypeDeclaration.minLength annotations
	     **/
	    FileTypeDeclarationScalarsAnnotationsImpl.prototype.minLength = function () {
	        var attr = this.node.attr("minLength");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * FileTypeDeclaration.maxLength annotations
	     **/
	    FileTypeDeclarationScalarsAnnotationsImpl.prototype.maxLength = function () {
	        var attr = this.node.attr("maxLength");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    return FileTypeDeclarationScalarsAnnotationsImpl;
	}(TypeDeclarationScalarsAnnotationsImpl));
	exports.FileTypeDeclarationScalarsAnnotationsImpl = FileTypeDeclarationScalarsAnnotationsImpl;
	var ResponseImpl = (function (_super) {
	    __extends(ResponseImpl, _super);
	    function ResponseImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createResponse(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * Responses MUST be a map of one or more HTTP status codes, where each status code itself is a map that describes that status code.
	     **/
	    ResponseImpl.prototype.code = function () {
	        return _super.prototype.attribute.call(this, 'code', function (attr) { return new StatusCodeStringImpl(attr); });
	    };
	    /**
	     * Detailed information about any response headers returned by this method
	     **/
	    ResponseImpl.prototype.headers = function () {
	        return _super.prototype.elements.call(this, 'headers');
	    };
	    /**
	     * The body of the response: a body declaration
	     **/
	    ResponseImpl.prototype.body = function () {
	        return _super.prototype.elements.call(this, 'body');
	    };
	    /**
	     * A longer, human-friendly description of the response
	     **/
	    ResponseImpl.prototype.description = function () {
	        return _super.prototype.attribute.call(this, 'description', function (attr) { return new MarkdownStringImpl(attr); });
	    };
	    /**
	     * Most of RAML model elements may have attached annotations decribing additional meta data about this element
	     **/
	    ResponseImpl.prototype.annotations = function () {
	        return _super.prototype.attributes.call(this, 'annotations', function (attr) { return new AnnotationRefImpl(attr); });
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    ResponseImpl.prototype.wrapperClassName = function () { return "ResponseImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    ResponseImpl.prototype.kind = function () { return "Response"; };
	    /**
	     * @return RAML version of the node
	     **/
	    ResponseImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    /**
	     * true for codes < 400 and false otherwise
	     **/
	    ResponseImpl.prototype.isOkRange = function () {
	        return helper.isOkRange(this);
	    };
	    /**
	     * Scalar properties annotations accessor
	     **/
	    ResponseImpl.prototype.scalarsAnnotations = function () { return new ResponseScalarsAnnotationsImpl(this.highLevel()); };
	    return ResponseImpl;
	}(AnnotableImpl));
	exports.ResponseImpl = ResponseImpl;
	/**
	 * Response scalar properties annotations accessor
	 **/
	var ResponseScalarsAnnotationsImpl = (function (_super) {
	    __extends(ResponseScalarsAnnotationsImpl, _super);
	    function ResponseScalarsAnnotationsImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * Response.description annotations
	     **/
	    ResponseScalarsAnnotationsImpl.prototype.description = function () {
	        var attr = this.node.attr("description");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * Response.annotations annotations
	     **/
	    ResponseScalarsAnnotationsImpl.prototype.annotations = function () {
	        var attrs = this.node.attributes("annotations");
	        return attrs.map(function (x) {
	            var annotationAttrs = x.annotations();
	            var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	            return result;
	        });
	    };
	    return ResponseScalarsAnnotationsImpl;
	}(AnnotableScalarsAnnotationsImpl));
	exports.ResponseScalarsAnnotationsImpl = ResponseScalarsAnnotationsImpl;
	var SecuritySchemePartImpl = (function (_super) {
	    __extends(SecuritySchemePartImpl, _super);
	    function SecuritySchemePartImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createSecuritySchemePart(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * Annotations to be applied to this security scheme part. Annotations are any property whose key begins with "(" and ends with ")" and whose name (the part between the beginning and ending parentheses) is a declared annotation name.
	     **/
	    SecuritySchemePartImpl.prototype.annotations = function () {
	        return _super.prototype.attributes.call(this, 'annotations', function (attr) { return new AnnotationRefImpl(attr); });
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    SecuritySchemePartImpl.prototype.wrapperClassName = function () { return "SecuritySchemePartImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    SecuritySchemePartImpl.prototype.kind = function () { return "SecuritySchemePart"; };
	    /**
	     * @return RAML version of the node
	     **/
	    SecuritySchemePartImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    /**
	     * Scalar properties annotations accessor
	     **/
	    SecuritySchemePartImpl.prototype.scalarsAnnotations = function () { return new SecuritySchemePartScalarsAnnotationsImpl(this.highLevel()); };
	    return SecuritySchemePartImpl;
	}(OperationImpl));
	exports.SecuritySchemePartImpl = SecuritySchemePartImpl;
	/**
	 * SecuritySchemePart scalar properties annotations accessor
	 **/
	var SecuritySchemePartScalarsAnnotationsImpl = (function (_super) {
	    __extends(SecuritySchemePartScalarsAnnotationsImpl, _super);
	    function SecuritySchemePartScalarsAnnotationsImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * SecuritySchemePart.annotations annotations
	     **/
	    SecuritySchemePartScalarsAnnotationsImpl.prototype.annotations = function () {
	        var attrs = this.node.attributes("annotations");
	        return attrs.map(function (x) {
	            var annotationAttrs = x.annotations();
	            var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	            return result;
	        });
	    };
	    return SecuritySchemePartScalarsAnnotationsImpl;
	}(AnnotableScalarsAnnotationsImpl));
	exports.SecuritySchemePartScalarsAnnotationsImpl = SecuritySchemePartScalarsAnnotationsImpl;
	var MethodBaseImpl = (function (_super) {
	    __extends(MethodBaseImpl, _super);
	    function MethodBaseImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createMethodBase(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * Some method verbs expect the resource to be sent as a request body. For example, to create a resource, the request must include the details of the resource to create. Resources CAN have alternate representations. For example, an API might support both JSON and XML representations. A method's body is defined in the body property as a hashmap, in which the key MUST be a valid media type.
	     **/
	    MethodBaseImpl.prototype.body = function () {
	        return _super.prototype.elements.call(this, 'body');
	    };
	    /**
	     * A method can override the protocols specified in the resource or at the API root, by employing this property.
	     **/
	    MethodBaseImpl.prototype.protocols = function () {
	        return _super.prototype.attributes.call(this, 'protocols', this.toString);
	    };
	    /**
	     * @hidden
	     * Set protocols value
	     **/
	    MethodBaseImpl.prototype.setProtocols = function (param) {
	        this.highLevel().attrOrCreate("protocols").setValue("" + param);
	        return this;
	    };
	    /**
	     * Instantiation of applyed traits
	     **/
	    MethodBaseImpl.prototype.is = function () {
	        return _super.prototype.attributes.call(this, 'is', function (attr) { return new TraitRefImpl(attr); });
	    };
	    /**
	     * securityScheme may also be applied to a resource by using the securedBy key, which is equivalent to applying the securityScheme to all methods that may be declared, explicitly or implicitly, by defining the resourceTypes or traits property for that resource. To indicate that the method may be called without applying any securityScheme, the method may be annotated with the null securityScheme.
	     **/
	    MethodBaseImpl.prototype.securedBy = function () {
	        return _super.prototype.attributes.call(this, 'securedBy', function (attr) { return new SecuritySchemeRefImpl(attr); });
	    };
	    MethodBaseImpl.prototype.description = function () {
	        return _super.prototype.attribute.call(this, 'description', function (attr) { return new MarkdownStringImpl(attr); });
	    };
	    MethodBaseImpl.prototype.displayName = function () {
	        return _super.prototype.attribute.call(this, 'displayName', this.toString);
	    };
	    /**
	     * @hidden
	     * Set displayName value
	     **/
	    MethodBaseImpl.prototype.setDisplayName = function (param) {
	        this.highLevel().attrOrCreate("displayName").setValue("" + param);
	        return this;
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    MethodBaseImpl.prototype.wrapperClassName = function () { return "MethodBaseImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    MethodBaseImpl.prototype.kind = function () { return "MethodBase"; };
	    /**
	     * @return RAML version of the node
	     **/
	    MethodBaseImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    /**
	     * Scalar properties annotations accessor
	     **/
	    MethodBaseImpl.prototype.scalarsAnnotations = function () { return new MethodBaseScalarsAnnotationsImpl(this.highLevel()); };
	    return MethodBaseImpl;
	}(OperationImpl));
	exports.MethodBaseImpl = MethodBaseImpl;
	var SecuritySchemeRefImpl = (function (_super) {
	    __extends(SecuritySchemeRefImpl, _super);
	    function SecuritySchemeRefImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    SecuritySchemeRefImpl.prototype.wrapperClassName = function () { return "SecuritySchemeRefImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    SecuritySchemeRefImpl.prototype.kind = function () { return "SecuritySchemeRef"; };
	    /**
	     * @return RAML version of the node
	     **/
	    SecuritySchemeRefImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    SecuritySchemeRefImpl.prototype.securitySchemeName = function () {
	        return helper.securitySchemeName(this);
	    };
	    SecuritySchemeRefImpl.prototype.securityScheme = function () {
	        return helper.securityScheme(this);
	    };
	    return SecuritySchemeRefImpl;
	}(ReferenceImpl));
	exports.SecuritySchemeRefImpl = SecuritySchemeRefImpl;
	/**
	 * Declares globally referable security scheme definition
	 **/
	var AbstractSecuritySchemeImpl = (function (_super) {
	    __extends(AbstractSecuritySchemeImpl, _super);
	    function AbstractSecuritySchemeImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createAbstractSecurityScheme(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * Name of the security scheme
	     **/
	    AbstractSecuritySchemeImpl.prototype.name = function () {
	        return _super.prototype.attribute.call(this, 'name', this.toString);
	    };
	    /**
	     * @hidden
	     * Set name value
	     **/
	    AbstractSecuritySchemeImpl.prototype.setName = function (param) {
	        this.highLevel().attrOrCreate("name").setValue("" + param);
	        return this;
	    };
	    /**
	     * The securitySchemes property MUST be used to specify an API's security mechanisms, including the required settings and the authentication methods that the API supports. one authentication method is allowed if the API supports them.
	     **/
	    AbstractSecuritySchemeImpl.prototype["type"] = function () {
	        return _super.prototype.attribute.call(this, 'type', this.toString);
	    };
	    /**
	     * @hidden
	     * Set type value
	     **/
	    AbstractSecuritySchemeImpl.prototype.setType = function (param) {
	        this.highLevel().attrOrCreate("type").setValue("" + param);
	        return this;
	    };
	    /**
	     * The description MAY be used to describe a securityScheme.
	     **/
	    AbstractSecuritySchemeImpl.prototype.description = function () {
	        return _super.prototype.attribute.call(this, 'description', function (attr) { return new MarkdownStringImpl(attr); });
	    };
	    /**
	     * A description of the request components related to Security that are determined by the scheme: the headers, query parameters or responses. As a best practice, even for standard security schemes, API designers SHOULD describe these properties of security schemes. Including the security scheme description completes an API documentation.
	     **/
	    AbstractSecuritySchemeImpl.prototype.describedBy = function () {
	        return _super.prototype.element.call(this, 'describedBy');
	    };
	    /**
	     * The displayName attribute specifies the security scheme display name. It is a friendly name used only for  display or documentation purposes. If displayName is not specified, it defaults to the element's key (the name of the property itself).
	     **/
	    AbstractSecuritySchemeImpl.prototype.displayName = function () {
	        return _super.prototype.attribute.call(this, 'displayName', this.toString);
	    };
	    /**
	     * @hidden
	     * Set displayName value
	     **/
	    AbstractSecuritySchemeImpl.prototype.setDisplayName = function (param) {
	        this.highLevel().attrOrCreate("displayName").setValue("" + param);
	        return this;
	    };
	    /**
	     * The settings attribute MAY be used to provide security scheme-specific information. The required attributes vary depending on the type of security scheme is being declared. It describes the minimum set of properties which any processing application MUST provide and validate if it chooses to implement the security scheme. Processing applications MAY choose to recognize other properties for things such as token lifetime, preferred cryptographic algorithms, and more.
	     **/
	    AbstractSecuritySchemeImpl.prototype.settings = function () {
	        return _super.prototype.element.call(this, 'settings');
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    AbstractSecuritySchemeImpl.prototype.wrapperClassName = function () { return "AbstractSecuritySchemeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    AbstractSecuritySchemeImpl.prototype.kind = function () { return "AbstractSecurityScheme"; };
	    /**
	     * @return RAML version of the node
	     **/
	    AbstractSecuritySchemeImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    /**
	     * Scalar properties annotations accessor
	     **/
	    AbstractSecuritySchemeImpl.prototype.scalarsAnnotations = function () { return new AbstractSecuritySchemeScalarsAnnotationsImpl(this.highLevel()); };
	    return AbstractSecuritySchemeImpl;
	}(AnnotableImpl));
	exports.AbstractSecuritySchemeImpl = AbstractSecuritySchemeImpl;
	var SecuritySchemeSettingsImpl = (function (_super) {
	    __extends(SecuritySchemeSettingsImpl, _super);
	    function SecuritySchemeSettingsImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createSecuritySchemeSettings(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    SecuritySchemeSettingsImpl.prototype.wrapperClassName = function () { return "SecuritySchemeSettingsImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    SecuritySchemeSettingsImpl.prototype.kind = function () { return "SecuritySchemeSettings"; };
	    /**
	     * @return RAML version of the node
	     **/
	    SecuritySchemeSettingsImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return SecuritySchemeSettingsImpl;
	}(AnnotableImpl));
	exports.SecuritySchemeSettingsImpl = SecuritySchemeSettingsImpl;
	var OAuth1SecuritySchemeSettingsImpl = (function (_super) {
	    __extends(OAuth1SecuritySchemeSettingsImpl, _super);
	    function OAuth1SecuritySchemeSettingsImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createOAuth1SecuritySchemeSettings(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * The URI of the Temporary Credential Request endpoint as defined in RFC5849 Section 2.1
	     **/
	    OAuth1SecuritySchemeSettingsImpl.prototype.requestTokenUri = function () {
	        return _super.prototype.attribute.call(this, 'requestTokenUri', function (attr) { return new FixedUriStringImpl(attr); });
	    };
	    /**
	     * The URI of the Resource Owner Authorization endpoint as defined in RFC5849 Section 2.2
	     **/
	    OAuth1SecuritySchemeSettingsImpl.prototype.authorizationUri = function () {
	        return _super.prototype.attribute.call(this, 'authorizationUri', function (attr) { return new FixedUriStringImpl(attr); });
	    };
	    /**
	     * The URI of the Token Request endpoint as defined in RFC5849 Section 2.3
	     **/
	    OAuth1SecuritySchemeSettingsImpl.prototype.tokenCredentialsUri = function () {
	        return _super.prototype.attribute.call(this, 'tokenCredentialsUri', function (attr) { return new FixedUriStringImpl(attr); });
	    };
	    /**
	     * List of the signature methods used by the server. Available methods: HMAC-SHA1, RSA-SHA1, PLAINTEXT
	     **/
	    OAuth1SecuritySchemeSettingsImpl.prototype.signatures = function () {
	        return _super.prototype.attributes.call(this, 'signatures', this.toString);
	    };
	    /**
	     * @hidden
	     * Set signatures value
	     **/
	    OAuth1SecuritySchemeSettingsImpl.prototype.setSignatures = function (param) {
	        this.highLevel().attrOrCreate("signatures").setValue("" + param);
	        return this;
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    OAuth1SecuritySchemeSettingsImpl.prototype.wrapperClassName = function () { return "OAuth1SecuritySchemeSettingsImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    OAuth1SecuritySchemeSettingsImpl.prototype.kind = function () { return "OAuth1SecuritySchemeSettings"; };
	    /**
	     * @return RAML version of the node
	     **/
	    OAuth1SecuritySchemeSettingsImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    /**
	     * Scalar properties annotations accessor
	     **/
	    OAuth1SecuritySchemeSettingsImpl.prototype.scalarsAnnotations = function () { return new OAuth1SecuritySchemeSettingsScalarsAnnotationsImpl(this.highLevel()); };
	    return OAuth1SecuritySchemeSettingsImpl;
	}(SecuritySchemeSettingsImpl));
	exports.OAuth1SecuritySchemeSettingsImpl = OAuth1SecuritySchemeSettingsImpl;
	/**
	 * OAuth1SecuritySchemeSettings scalar properties annotations accessor
	 **/
	var OAuth1SecuritySchemeSettingsScalarsAnnotationsImpl = (function (_super) {
	    __extends(OAuth1SecuritySchemeSettingsScalarsAnnotationsImpl, _super);
	    function OAuth1SecuritySchemeSettingsScalarsAnnotationsImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * OAuth1SecuritySchemeSettings.requestTokenUri annotations
	     **/
	    OAuth1SecuritySchemeSettingsScalarsAnnotationsImpl.prototype.requestTokenUri = function () {
	        var attr = this.node.attr("requestTokenUri");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * OAuth1SecuritySchemeSettings.authorizationUri annotations
	     **/
	    OAuth1SecuritySchemeSettingsScalarsAnnotationsImpl.prototype.authorizationUri = function () {
	        var attr = this.node.attr("authorizationUri");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * OAuth1SecuritySchemeSettings.tokenCredentialsUri annotations
	     **/
	    OAuth1SecuritySchemeSettingsScalarsAnnotationsImpl.prototype.tokenCredentialsUri = function () {
	        var attr = this.node.attr("tokenCredentialsUri");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * OAuth1SecuritySchemeSettings.signatures annotations
	     **/
	    OAuth1SecuritySchemeSettingsScalarsAnnotationsImpl.prototype.signatures = function () {
	        var attrs = this.node.attributes("signatures");
	        return attrs.map(function (x) {
	            var annotationAttrs = x.annotations();
	            var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	            return result;
	        });
	    };
	    return OAuth1SecuritySchemeSettingsScalarsAnnotationsImpl;
	}(AnnotableScalarsAnnotationsImpl));
	exports.OAuth1SecuritySchemeSettingsScalarsAnnotationsImpl = OAuth1SecuritySchemeSettingsScalarsAnnotationsImpl;
	var OAuth2SecuritySchemeSettingsImpl = (function (_super) {
	    __extends(OAuth2SecuritySchemeSettingsImpl, _super);
	    function OAuth2SecuritySchemeSettingsImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createOAuth2SecuritySchemeSettings(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * The URI of the Token Endpoint as defined in RFC6749 Section 3.2. Not required forby implicit grant type.
	     **/
	    OAuth2SecuritySchemeSettingsImpl.prototype.accessTokenUri = function () {
	        return _super.prototype.attribute.call(this, 'accessTokenUri', function (attr) { return new FixedUriStringImpl(attr); });
	    };
	    /**
	     * The URI of the Authorization Endpoint as defined in RFC6749 Section 3.1. Required forby authorization_code and implicit grant types.
	     **/
	    OAuth2SecuritySchemeSettingsImpl.prototype.authorizationUri = function () {
	        return _super.prototype.attribute.call(this, 'authorizationUri', function (attr) { return new FixedUriStringImpl(attr); });
	    };
	    /**
	     * A list of the Authorization grants supported by the API as defined in RFC6749 Sections 4.1, 4.2, 4.3 and 4.4, can be any of: authorization_code, password, client_credentials, implicit, or any absolute url.
	     **/
	    OAuth2SecuritySchemeSettingsImpl.prototype.authorizationGrants = function () {
	        return _super.prototype.attributes.call(this, 'authorizationGrants', this.toString);
	    };
	    /**
	     * @hidden
	     * Set authorizationGrants value
	     **/
	    OAuth2SecuritySchemeSettingsImpl.prototype.setAuthorizationGrants = function (param) {
	        this.highLevel().attrOrCreate("authorizationGrants").setValue("" + param);
	        return this;
	    };
	    /**
	     * A list of scopes supported by the security scheme as defined in RFC6749 Section 3.3
	     **/
	    OAuth2SecuritySchemeSettingsImpl.prototype.scopes = function () {
	        return _super.prototype.attributes.call(this, 'scopes', this.toString);
	    };
	    /**
	     * @hidden
	     * Set scopes value
	     **/
	    OAuth2SecuritySchemeSettingsImpl.prototype.setScopes = function (param) {
	        this.highLevel().attrOrCreate("scopes").setValue("" + param);
	        return this;
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    OAuth2SecuritySchemeSettingsImpl.prototype.wrapperClassName = function () { return "OAuth2SecuritySchemeSettingsImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    OAuth2SecuritySchemeSettingsImpl.prototype.kind = function () { return "OAuth2SecuritySchemeSettings"; };
	    /**
	     * @return RAML version of the node
	     **/
	    OAuth2SecuritySchemeSettingsImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    /**
	     * Scalar properties annotations accessor
	     **/
	    OAuth2SecuritySchemeSettingsImpl.prototype.scalarsAnnotations = function () { return new OAuth2SecuritySchemeSettingsScalarsAnnotationsImpl(this.highLevel()); };
	    return OAuth2SecuritySchemeSettingsImpl;
	}(SecuritySchemeSettingsImpl));
	exports.OAuth2SecuritySchemeSettingsImpl = OAuth2SecuritySchemeSettingsImpl;
	/**
	 * OAuth2SecuritySchemeSettings scalar properties annotations accessor
	 **/
	var OAuth2SecuritySchemeSettingsScalarsAnnotationsImpl = (function (_super) {
	    __extends(OAuth2SecuritySchemeSettingsScalarsAnnotationsImpl, _super);
	    function OAuth2SecuritySchemeSettingsScalarsAnnotationsImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * OAuth2SecuritySchemeSettings.accessTokenUri annotations
	     **/
	    OAuth2SecuritySchemeSettingsScalarsAnnotationsImpl.prototype.accessTokenUri = function () {
	        var attr = this.node.attr("accessTokenUri");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * OAuth2SecuritySchemeSettings.authorizationUri annotations
	     **/
	    OAuth2SecuritySchemeSettingsScalarsAnnotationsImpl.prototype.authorizationUri = function () {
	        var attr = this.node.attr("authorizationUri");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * OAuth2SecuritySchemeSettings.authorizationGrants annotations
	     **/
	    OAuth2SecuritySchemeSettingsScalarsAnnotationsImpl.prototype.authorizationGrants = function () {
	        var attrs = this.node.attributes("authorizationGrants");
	        return attrs.map(function (x) {
	            var annotationAttrs = x.annotations();
	            var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	            return result;
	        });
	    };
	    /**
	     * OAuth2SecuritySchemeSettings.scopes annotations
	     **/
	    OAuth2SecuritySchemeSettingsScalarsAnnotationsImpl.prototype.scopes = function () {
	        var attrs = this.node.attributes("scopes");
	        return attrs.map(function (x) {
	            var annotationAttrs = x.annotations();
	            var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	            return result;
	        });
	    };
	    return OAuth2SecuritySchemeSettingsScalarsAnnotationsImpl;
	}(AnnotableScalarsAnnotationsImpl));
	exports.OAuth2SecuritySchemeSettingsScalarsAnnotationsImpl = OAuth2SecuritySchemeSettingsScalarsAnnotationsImpl;
	/**
	 * Declares globally referable security scheme definition
	 **/
	var OAuth2SecuritySchemeImpl = (function (_super) {
	    __extends(OAuth2SecuritySchemeImpl, _super);
	    function OAuth2SecuritySchemeImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createOAuth2SecurityScheme(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    OAuth2SecuritySchemeImpl.prototype.settings = function () {
	        return _super.prototype.element.call(this, 'settings');
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    OAuth2SecuritySchemeImpl.prototype.wrapperClassName = function () { return "OAuth2SecuritySchemeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    OAuth2SecuritySchemeImpl.prototype.kind = function () { return "OAuth2SecurityScheme"; };
	    /**
	     * @return RAML version of the node
	     **/
	    OAuth2SecuritySchemeImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return OAuth2SecuritySchemeImpl;
	}(AbstractSecuritySchemeImpl));
	exports.OAuth2SecuritySchemeImpl = OAuth2SecuritySchemeImpl;
	/**
	 * Declares globally referable security scheme definition
	 **/
	var OAuth1SecuritySchemeImpl = (function (_super) {
	    __extends(OAuth1SecuritySchemeImpl, _super);
	    function OAuth1SecuritySchemeImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createOAuth1SecurityScheme(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    OAuth1SecuritySchemeImpl.prototype.settings = function () {
	        return _super.prototype.element.call(this, 'settings');
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    OAuth1SecuritySchemeImpl.prototype.wrapperClassName = function () { return "OAuth1SecuritySchemeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    OAuth1SecuritySchemeImpl.prototype.kind = function () { return "OAuth1SecurityScheme"; };
	    /**
	     * @return RAML version of the node
	     **/
	    OAuth1SecuritySchemeImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return OAuth1SecuritySchemeImpl;
	}(AbstractSecuritySchemeImpl));
	exports.OAuth1SecuritySchemeImpl = OAuth1SecuritySchemeImpl;
	/**
	 * Declares globally referable security scheme definition
	 **/
	var PassThroughSecuritySchemeImpl = (function (_super) {
	    __extends(PassThroughSecuritySchemeImpl, _super);
	    function PassThroughSecuritySchemeImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createPassThroughSecurityScheme(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    PassThroughSecuritySchemeImpl.prototype.settings = function () {
	        return _super.prototype.element.call(this, 'settings');
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    PassThroughSecuritySchemeImpl.prototype.wrapperClassName = function () { return "PassThroughSecuritySchemeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    PassThroughSecuritySchemeImpl.prototype.kind = function () { return "PassThroughSecurityScheme"; };
	    /**
	     * @return RAML version of the node
	     **/
	    PassThroughSecuritySchemeImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return PassThroughSecuritySchemeImpl;
	}(AbstractSecuritySchemeImpl));
	exports.PassThroughSecuritySchemeImpl = PassThroughSecuritySchemeImpl;
	/**
	 * Declares globally referable security scheme definition
	 **/
	var BasicSecuritySchemeImpl = (function (_super) {
	    __extends(BasicSecuritySchemeImpl, _super);
	    function BasicSecuritySchemeImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createBasicSecurityScheme(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    BasicSecuritySchemeImpl.prototype.wrapperClassName = function () { return "BasicSecuritySchemeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    BasicSecuritySchemeImpl.prototype.kind = function () { return "BasicSecurityScheme"; };
	    /**
	     * @return RAML version of the node
	     **/
	    BasicSecuritySchemeImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return BasicSecuritySchemeImpl;
	}(AbstractSecuritySchemeImpl));
	exports.BasicSecuritySchemeImpl = BasicSecuritySchemeImpl;
	/**
	 * Declares globally referable security scheme definition
	 **/
	var DigestSecuritySchemeImpl = (function (_super) {
	    __extends(DigestSecuritySchemeImpl, _super);
	    function DigestSecuritySchemeImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createDigestSecurityScheme(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    DigestSecuritySchemeImpl.prototype.wrapperClassName = function () { return "DigestSecuritySchemeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    DigestSecuritySchemeImpl.prototype.kind = function () { return "DigestSecurityScheme"; };
	    /**
	     * @return RAML version of the node
	     **/
	    DigestSecuritySchemeImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return DigestSecuritySchemeImpl;
	}(AbstractSecuritySchemeImpl));
	exports.DigestSecuritySchemeImpl = DigestSecuritySchemeImpl;
	/**
	 * Declares globally referable security scheme definition
	 **/
	var CustomSecuritySchemeImpl = (function (_super) {
	    __extends(CustomSecuritySchemeImpl, _super);
	    function CustomSecuritySchemeImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createCustomSecurityScheme(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    CustomSecuritySchemeImpl.prototype.wrapperClassName = function () { return "CustomSecuritySchemeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    CustomSecuritySchemeImpl.prototype.kind = function () { return "CustomSecurityScheme"; };
	    /**
	     * @return RAML version of the node
	     **/
	    CustomSecuritySchemeImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return CustomSecuritySchemeImpl;
	}(AbstractSecuritySchemeImpl));
	exports.CustomSecuritySchemeImpl = CustomSecuritySchemeImpl;
	/**
	 * AbstractSecurityScheme scalar properties annotations accessor
	 **/
	var AbstractSecuritySchemeScalarsAnnotationsImpl = (function (_super) {
	    __extends(AbstractSecuritySchemeScalarsAnnotationsImpl, _super);
	    function AbstractSecuritySchemeScalarsAnnotationsImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * AbstractSecurityScheme.type annotations
	     **/
	    AbstractSecuritySchemeScalarsAnnotationsImpl.prototype["type"] = function () {
	        var attr = this.node.attr("type");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * AbstractSecurityScheme.description annotations
	     **/
	    AbstractSecuritySchemeScalarsAnnotationsImpl.prototype.description = function () {
	        var attr = this.node.attr("description");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * AbstractSecurityScheme.displayName annotations
	     **/
	    AbstractSecuritySchemeScalarsAnnotationsImpl.prototype.displayName = function () {
	        var attr = this.node.attr("displayName");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    return AbstractSecuritySchemeScalarsAnnotationsImpl;
	}(AnnotableScalarsAnnotationsImpl));
	exports.AbstractSecuritySchemeScalarsAnnotationsImpl = AbstractSecuritySchemeScalarsAnnotationsImpl;
	var MethodImpl = (function (_super) {
	    __extends(MethodImpl, _super);
	    function MethodImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createMethod(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * Method that can be called
	     **/
	    MethodImpl.prototype.method = function () {
	        return _super.prototype.attribute.call(this, 'method', this.toString);
	    };
	    /**
	     * @hidden
	     * Set method value
	     **/
	    MethodImpl.prototype.setMethod = function (param) {
	        this.highLevel().attrOrCreate("method").setValue("" + param);
	        return this;
	    };
	    /**
	     * The displayName attribute specifies the method display name. It is a friendly name used only for  display or documentation purposes. If displayName is not specified, it defaults to the element's key (the name of the property itself).
	     **/
	    MethodImpl.prototype.displayName = function () {
	        return _super.prototype.attribute.call(this, 'displayName', this.toString);
	    };
	    /**
	     * @hidden
	     * Set displayName value
	     **/
	    MethodImpl.prototype.setDisplayName = function (param) {
	        this.highLevel().attrOrCreate("displayName").setValue("" + param);
	        return this;
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    MethodImpl.prototype.wrapperClassName = function () { return "MethodImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    MethodImpl.prototype.kind = function () { return "Method"; };
	    /**
	     * @return RAML version of the node
	     **/
	    MethodImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    /**
	     * For methods of Resources returns parent resource. For methods of ResourceTypes returns null.
	     **/
	    MethodImpl.prototype.parentResource = function () {
	        return helper.parentResource(this);
	    };
	    /**
	     * Api owning the resource as a sibling
	     **/
	    MethodImpl.prototype.ownerApi = function () {
	        return helper.ownerApi(this);
	    };
	    /**
	     * For methods of Resources: `{parent Resource relative path} {methodName}`.
	     * For methods of ResourceTypes: `{parent ResourceType name} {methodName}`.
	     * For other methods throws Exception.
	     **/
	    MethodImpl.prototype.methodId = function () {
	        return helper.methodId(this);
	    };
	    /**
	     * Returns security schemes, resource or method is secured with. If no security schemes are set at resource or method level,
	     * returns schemes defined with `securedBy` at API level.
	     * @deprecated
	     **/
	    MethodImpl.prototype.allSecuredBy = function () {
	        return helper.allSecuredBy(this);
	    };
	    /**
	     * Scalar properties annotations accessor
	     **/
	    MethodImpl.prototype.scalarsAnnotations = function () { return new MethodScalarsAnnotationsImpl(this.highLevel()); };
	    return MethodImpl;
	}(MethodBaseImpl));
	exports.MethodImpl = MethodImpl;
	/**
	 * MethodBase scalar properties annotations accessor
	 **/
	var MethodBaseScalarsAnnotationsImpl = (function (_super) {
	    __extends(MethodBaseScalarsAnnotationsImpl, _super);
	    function MethodBaseScalarsAnnotationsImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * MethodBase.protocols annotations
	     **/
	    MethodBaseScalarsAnnotationsImpl.prototype.protocols = function () {
	        var attrs = this.node.attributes("protocols");
	        return attrs.map(function (x) {
	            var annotationAttrs = x.annotations();
	            var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	            return result;
	        });
	    };
	    /**
	     * MethodBase.is annotations
	     **/
	    MethodBaseScalarsAnnotationsImpl.prototype.is = function () {
	        var attrs = this.node.attributes("is");
	        return attrs.map(function (x) {
	            var annotationAttrs = x.annotations();
	            var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	            return result;
	        });
	    };
	    /**
	     * MethodBase.securedBy annotations
	     **/
	    MethodBaseScalarsAnnotationsImpl.prototype.securedBy = function () {
	        var attrs = this.node.attributes("securedBy");
	        return attrs.map(function (x) {
	            var annotationAttrs = x.annotations();
	            var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	            return result;
	        });
	    };
	    /**
	     * MethodBase.description annotations
	     **/
	    MethodBaseScalarsAnnotationsImpl.prototype.description = function () {
	        var attr = this.node.attr("description");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * MethodBase.displayName annotations
	     **/
	    MethodBaseScalarsAnnotationsImpl.prototype.displayName = function () {
	        var attr = this.node.attr("displayName");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    return MethodBaseScalarsAnnotationsImpl;
	}(AnnotableScalarsAnnotationsImpl));
	exports.MethodBaseScalarsAnnotationsImpl = MethodBaseScalarsAnnotationsImpl;
	/**
	 * Method scalar properties annotations accessor
	 **/
	var MethodScalarsAnnotationsImpl = (function (_super) {
	    __extends(MethodScalarsAnnotationsImpl, _super);
	    function MethodScalarsAnnotationsImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * Method.displayName annotations
	     **/
	    MethodScalarsAnnotationsImpl.prototype.displayName = function () {
	        var attr = this.node.attr("displayName");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    return MethodScalarsAnnotationsImpl;
	}(MethodBaseScalarsAnnotationsImpl));
	exports.MethodScalarsAnnotationsImpl = MethodScalarsAnnotationsImpl;
	var TraitImpl = (function (_super) {
	    __extends(TraitImpl, _super);
	    function TraitImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createTrait(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * Name of the trait
	     **/
	    TraitImpl.prototype.name = function () {
	        return _super.prototype.attribute.call(this, 'name', this.toString);
	    };
	    /**
	     * @hidden
	     * Set name value
	     **/
	    TraitImpl.prototype.setName = function (param) {
	        this.highLevel().attrOrCreate("name").setValue("" + param);
	        return this;
	    };
	    /**
	     * Instructions on how and when the trait should be used.
	     **/
	    TraitImpl.prototype.usage = function () {
	        return _super.prototype.attribute.call(this, 'usage', this.toString);
	    };
	    /**
	     * @hidden
	     * Set usage value
	     **/
	    TraitImpl.prototype.setUsage = function (param) {
	        this.highLevel().attrOrCreate("usage").setValue("" + param);
	        return this;
	    };
	    /**
	     * The displayName attribute specifies the trait display name. It is a friendly name used only for  display or documentation purposes. If displayName is not specified, it defaults to the element's key (the name of the property itself).
	     **/
	    TraitImpl.prototype.displayName = function () {
	        return _super.prototype.attribute.call(this, 'displayName', this.toString);
	    };
	    /**
	     * @hidden
	     * Set displayName value
	     **/
	    TraitImpl.prototype.setDisplayName = function (param) {
	        this.highLevel().attrOrCreate("displayName").setValue("" + param);
	        return this;
	    };
	    TraitImpl.prototype.uses = function () {
	        return _super.prototype.elements.call(this, 'uses');
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    TraitImpl.prototype.wrapperClassName = function () { return "TraitImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    TraitImpl.prototype.kind = function () { return "Trait"; };
	    /**
	     * @return RAML version of the node
	     **/
	    TraitImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    TraitImpl.prototype.parametrizedProperties = function () {
	        return helper.getTemplateParametrizedProperties(this);
	    };
	    /**
	     * Scalar properties annotations accessor
	     **/
	    TraitImpl.prototype.scalarsAnnotations = function () { return new TraitScalarsAnnotationsImpl(this.highLevel()); };
	    return TraitImpl;
	}(MethodBaseImpl));
	exports.TraitImpl = TraitImpl;
	/**
	 * Trait scalar properties annotations accessor
	 **/
	var TraitScalarsAnnotationsImpl = (function (_super) {
	    __extends(TraitScalarsAnnotationsImpl, _super);
	    function TraitScalarsAnnotationsImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * Trait.usage annotations
	     **/
	    TraitScalarsAnnotationsImpl.prototype.usage = function () {
	        var attr = this.node.attr("usage");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * Trait.displayName annotations
	     **/
	    TraitScalarsAnnotationsImpl.prototype.displayName = function () {
	        var attr = this.node.attr("displayName");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    return TraitScalarsAnnotationsImpl;
	}(MethodBaseScalarsAnnotationsImpl));
	exports.TraitScalarsAnnotationsImpl = TraitScalarsAnnotationsImpl;
	var ResourceTypeRefImpl = (function (_super) {
	    __extends(ResourceTypeRefImpl, _super);
	    function ResourceTypeRefImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    ResourceTypeRefImpl.prototype.wrapperClassName = function () { return "ResourceTypeRefImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    ResourceTypeRefImpl.prototype.kind = function () { return "ResourceTypeRef"; };
	    /**
	     * @return RAML version of the node
	     **/
	    ResourceTypeRefImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    ResourceTypeRefImpl.prototype.resourceType = function () {
	        return helper.referencedResourceType(this);
	    };
	    return ResourceTypeRefImpl;
	}(ReferenceImpl));
	exports.ResourceTypeRefImpl = ResourceTypeRefImpl;
	var ResourceBaseImpl = (function (_super) {
	    __extends(ResourceBaseImpl, _super);
	    function ResourceBaseImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createResourceBase(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * Methods that are part of this resource type definition
	     **/
	    ResourceBaseImpl.prototype.methods = function () {
	        return _super.prototype.elements.call(this, 'methods');
	    };
	    /**
	     * A list of the traits to apply to all methods declared (implicitly or explicitly) for this resource. Individual methods may override this declaration
	     **/
	    ResourceBaseImpl.prototype.is = function () {
	        return _super.prototype.attributes.call(this, 'is', function (attr) { return new TraitRefImpl(attr); });
	    };
	    /**
	     * The resource type which this resource inherits.
	     **/
	    ResourceBaseImpl.prototype["type"] = function () {
	        return _super.prototype.attribute.call(this, 'type', function (attr) { return new ResourceTypeRefImpl(attr); });
	    };
	    ResourceBaseImpl.prototype.description = function () {
	        return _super.prototype.attribute.call(this, 'description', function (attr) { return new MarkdownStringImpl(attr); });
	    };
	    /**
	     * The security schemes that apply to all methods declared (implicitly or explicitly) for this resource.
	     **/
	    ResourceBaseImpl.prototype.securedBy = function () {
	        return _super.prototype.attributes.call(this, 'securedBy', function (attr) { return new SecuritySchemeRefImpl(attr); });
	    };
	    /**
	     * Detailed information about any URI parameters of this resource
	     * @hidden
	     **/
	    ResourceBaseImpl.prototype.uriParameters_original = function () {
	        return _super.prototype.elements.call(this, 'uriParameters');
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    ResourceBaseImpl.prototype.wrapperClassName = function () { return "ResourceBaseImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    ResourceBaseImpl.prototype.kind = function () { return "ResourceBase"; };
	    /**
	     * @return RAML version of the node
	     **/
	    ResourceBaseImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    /**
	     * Detailed information about any URI parameters of this resource
	     **/
	    ResourceBaseImpl.prototype.uriParameters = function () {
	        return helper.uriParametersPrimary(this);
	    };
	    /**
	     * Retrieve an ordered list of all uri parameters including those which are not described in the `uriParameters` node.
	     * Consider a fragment of RAML specification:
	     * ```yaml
	     * /resource/{objectId}/{propertyId}:
	     * uriParameters:
	     * objectId:
	     * ```
	     * Here `propertyId` uri parameter is not described in the `uriParameters` node,
	     * but it is among Resource.allUriParameters().
	     * @deprecated
	     **/
	    ResourceBaseImpl.prototype.allUriParameters = function () {
	        return helper.uriParameters(this);
	    };
	    /**
	     * Returns security schemes, resource or method is secured with. If no security schemes are set at resource or method level,
	     * returns schemes defined with `securedBy` at API level.
	     * @deprecated
	     **/
	    ResourceBaseImpl.prototype.allSecuredBy = function () {
	        return helper.allSecuredBy(this);
	    };
	    /**
	     * Scalar properties annotations accessor
	     **/
	    ResourceBaseImpl.prototype.scalarsAnnotations = function () { return new ResourceBaseScalarsAnnotationsImpl(this.highLevel()); };
	    return ResourceBaseImpl;
	}(AnnotableImpl));
	exports.ResourceBaseImpl = ResourceBaseImpl;
	var ResourceImpl = (function (_super) {
	    __extends(ResourceImpl, _super);
	    function ResourceImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createResource(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * Relative URL of this resource from the parent resource
	     **/
	    ResourceImpl.prototype.relativeUri = function () {
	        return _super.prototype.attribute.call(this, 'relativeUri', function (attr) { return new RelativeUriStringImpl(attr); });
	    };
	    /**
	     * The displayName attribute specifies the resource display name. It is a friendly name used only for  display or documentation purposes. If displayName is not specified, it defaults to the element's key (the name of the property itself).
	     **/
	    ResourceImpl.prototype.displayName = function () {
	        return _super.prototype.attribute.call(this, 'displayName', this.toString);
	    };
	    /**
	     * @hidden
	     * Set displayName value
	     **/
	    ResourceImpl.prototype.setDisplayName = function (param) {
	        this.highLevel().attrOrCreate("displayName").setValue("" + param);
	        return this;
	    };
	    /**
	     * A nested resource is identified as any property whose name begins with a slash ("/") and is therefore treated as a relative URI.
	     **/
	    ResourceImpl.prototype.resources = function () {
	        return _super.prototype.elements.call(this, 'resources');
	    };
	    /**
	     * A longer, human-friendly description of the resource.
	     **/
	    ResourceImpl.prototype.description = function () {
	        return _super.prototype.attribute.call(this, 'description', function (attr) { return new MarkdownStringImpl(attr); });
	    };
	    /**
	     * Most of RAML model elements may have attached annotations decribing additional meta data about this element
	     **/
	    ResourceImpl.prototype.annotations = function () {
	        return _super.prototype.attributes.call(this, 'annotations', function (attr) { return new AnnotationRefImpl(attr); });
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    ResourceImpl.prototype.wrapperClassName = function () { return "ResourceImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    ResourceImpl.prototype.kind = function () { return "Resource"; };
	    /**
	     * @return RAML version of the node
	     **/
	    ResourceImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    /**
	     * Path relative to API root
	     **/
	    ResourceImpl.prototype.completeRelativeUri = function () {
	        return helper.completeRelativeUri(this);
	    };
	    /**
	     * baseUri of owning Api concatenated with completeRelativeUri
	     **/
	    ResourceImpl.prototype.absoluteUri = function () {
	        return helper.absoluteUri(this);
	    };
	    /**
	     * Parent resource for non top level resources
	     **/
	    ResourceImpl.prototype.parentResource = function () {
	        return helper.parent(this);
	    };
	    /**
	     * Get child resource by its relative path
	     **/
	    ResourceImpl.prototype.childResource = function (relPath) {
	        return helper.childResource(this, relPath);
	    };
	    /**
	     * Get child method by its name
	     **/
	    ResourceImpl.prototype.childMethod = function (method) {
	        return helper.childMethod(this, method);
	    };
	    /**
	     * Api owning the resource as a sibling
	     **/
	    ResourceImpl.prototype.ownerApi = function () {
	        return helper.ownerApi(this);
	    };
	    /**
	     * Retrieve an ordered list of all absolute uri parameters. Returns a union of `Api.baseUriParameters()`
	     * for `Api` owning the `Resource` and `Resource.uriParameters()`.
	     **/
	    ResourceImpl.prototype.absoluteUriParameters = function () {
	        return helper.absoluteUriParameters(this);
	    };
	    /**
	     * Scalar properties annotations accessor
	     **/
	    ResourceImpl.prototype.scalarsAnnotations = function () { return new ResourceScalarsAnnotationsImpl(this.highLevel()); };
	    return ResourceImpl;
	}(ResourceBaseImpl));
	exports.ResourceImpl = ResourceImpl;
	/**
	 * ResourceBase scalar properties annotations accessor
	 **/
	var ResourceBaseScalarsAnnotationsImpl = (function (_super) {
	    __extends(ResourceBaseScalarsAnnotationsImpl, _super);
	    function ResourceBaseScalarsAnnotationsImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * ResourceBase.is annotations
	     **/
	    ResourceBaseScalarsAnnotationsImpl.prototype.is = function () {
	        var attrs = this.node.attributes("is");
	        return attrs.map(function (x) {
	            var annotationAttrs = x.annotations();
	            var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	            return result;
	        });
	    };
	    /**
	     * ResourceBase.type annotations
	     **/
	    ResourceBaseScalarsAnnotationsImpl.prototype["type"] = function () {
	        var attr = this.node.attr("type");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * ResourceBase.description annotations
	     **/
	    ResourceBaseScalarsAnnotationsImpl.prototype.description = function () {
	        var attr = this.node.attr("description");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * ResourceBase.securedBy annotations
	     **/
	    ResourceBaseScalarsAnnotationsImpl.prototype.securedBy = function () {
	        var attrs = this.node.attributes("securedBy");
	        return attrs.map(function (x) {
	            var annotationAttrs = x.annotations();
	            var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	            return result;
	        });
	    };
	    return ResourceBaseScalarsAnnotationsImpl;
	}(AnnotableScalarsAnnotationsImpl));
	exports.ResourceBaseScalarsAnnotationsImpl = ResourceBaseScalarsAnnotationsImpl;
	/**
	 * Resource scalar properties annotations accessor
	 **/
	var ResourceScalarsAnnotationsImpl = (function (_super) {
	    __extends(ResourceScalarsAnnotationsImpl, _super);
	    function ResourceScalarsAnnotationsImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * Resource.displayName annotations
	     **/
	    ResourceScalarsAnnotationsImpl.prototype.displayName = function () {
	        var attr = this.node.attr("displayName");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * Resource.description annotations
	     **/
	    ResourceScalarsAnnotationsImpl.prototype.description = function () {
	        var attr = this.node.attr("description");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * Resource.annotations annotations
	     **/
	    ResourceScalarsAnnotationsImpl.prototype.annotations = function () {
	        var attrs = this.node.attributes("annotations");
	        return attrs.map(function (x) {
	            var annotationAttrs = x.annotations();
	            var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	            return result;
	        });
	    };
	    return ResourceScalarsAnnotationsImpl;
	}(ResourceBaseScalarsAnnotationsImpl));
	exports.ResourceScalarsAnnotationsImpl = ResourceScalarsAnnotationsImpl;
	var ResourceTypeImpl = (function (_super) {
	    __extends(ResourceTypeImpl, _super);
	    function ResourceTypeImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createResourceType(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * The displayName attribute specifies the resource type display name. It is a friendly name used only for  display or documentation purposes. If displayName is not specified, it defaults to the element's key (the name of the property itself).
	     **/
	    ResourceTypeImpl.prototype.displayName = function () {
	        return _super.prototype.attribute.call(this, 'displayName', this.toString);
	    };
	    /**
	     * @hidden
	     * Set displayName value
	     **/
	    ResourceTypeImpl.prototype.setDisplayName = function (param) {
	        this.highLevel().attrOrCreate("displayName").setValue("" + param);
	        return this;
	    };
	    /**
	     * Name of the resource type
	     **/
	    ResourceTypeImpl.prototype.name = function () {
	        return _super.prototype.attribute.call(this, 'name', this.toString);
	    };
	    /**
	     * @hidden
	     * Set name value
	     **/
	    ResourceTypeImpl.prototype.setName = function (param) {
	        this.highLevel().attrOrCreate("name").setValue("" + param);
	        return this;
	    };
	    /**
	     * Instructions on how and when the resource type should be used.
	     **/
	    ResourceTypeImpl.prototype.usage = function () {
	        return _super.prototype.attribute.call(this, 'usage', this.toString);
	    };
	    /**
	     * @hidden
	     * Set usage value
	     **/
	    ResourceTypeImpl.prototype.setUsage = function (param) {
	        this.highLevel().attrOrCreate("usage").setValue("" + param);
	        return this;
	    };
	    ResourceTypeImpl.prototype.uses = function () {
	        return _super.prototype.elements.call(this, 'uses');
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    ResourceTypeImpl.prototype.wrapperClassName = function () { return "ResourceTypeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    ResourceTypeImpl.prototype.kind = function () { return "ResourceType"; };
	    /**
	     * @return RAML version of the node
	     **/
	    ResourceTypeImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    ResourceTypeImpl.prototype.parametrizedProperties = function () {
	        return helper.getTemplateParametrizedProperties(this);
	    };
	    /**
	     * Scalar properties annotations accessor
	     **/
	    ResourceTypeImpl.prototype.scalarsAnnotations = function () { return new ResourceTypeScalarsAnnotationsImpl(this.highLevel()); };
	    return ResourceTypeImpl;
	}(ResourceBaseImpl));
	exports.ResourceTypeImpl = ResourceTypeImpl;
	/**
	 * ResourceType scalar properties annotations accessor
	 **/
	var ResourceTypeScalarsAnnotationsImpl = (function (_super) {
	    __extends(ResourceTypeScalarsAnnotationsImpl, _super);
	    function ResourceTypeScalarsAnnotationsImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * ResourceType.displayName annotations
	     **/
	    ResourceTypeScalarsAnnotationsImpl.prototype.displayName = function () {
	        var attr = this.node.attr("displayName");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * ResourceType.usage annotations
	     **/
	    ResourceTypeScalarsAnnotationsImpl.prototype.usage = function () {
	        var attr = this.node.attr("usage");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    return ResourceTypeScalarsAnnotationsImpl;
	}(ResourceBaseScalarsAnnotationsImpl));
	exports.ResourceTypeScalarsAnnotationsImpl = ResourceTypeScalarsAnnotationsImpl;
	/**
	 * Annotations allow you to attach information to your API
	 **/
	var AnnotationRefImpl = (function (_super) {
	    __extends(AnnotationRefImpl, _super);
	    function AnnotationRefImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    AnnotationRefImpl.prototype.wrapperClassName = function () { return "AnnotationRefImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    AnnotationRefImpl.prototype.kind = function () { return "AnnotationRef"; };
	    /**
	     * @return RAML version of the node
	     **/
	    AnnotationRefImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    AnnotationRefImpl.prototype.annotation = function () {
	        return helper.referencedAnnotation(this);
	    };
	    return AnnotationRefImpl;
	}(ReferenceImpl));
	exports.AnnotationRefImpl = AnnotationRefImpl;
	var DocumentationItemImpl = (function (_super) {
	    __extends(DocumentationItemImpl, _super);
	    function DocumentationItemImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createDocumentationItem(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * Title of documentation section
	     **/
	    DocumentationItemImpl.prototype.title = function () {
	        return _super.prototype.attribute.call(this, 'title', this.toString);
	    };
	    /**
	     * @hidden
	     * Set title value
	     **/
	    DocumentationItemImpl.prototype.setTitle = function (param) {
	        this.highLevel().attrOrCreate("title").setValue("" + param);
	        return this;
	    };
	    /**
	     * Content of documentation section
	     **/
	    DocumentationItemImpl.prototype.content = function () {
	        return _super.prototype.attribute.call(this, 'content', function (attr) { return new MarkdownStringImpl(attr); });
	    };
	    DocumentationItemImpl.prototype.uses = function () {
	        return _super.prototype.elements.call(this, 'uses');
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    DocumentationItemImpl.prototype.wrapperClassName = function () { return "DocumentationItemImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    DocumentationItemImpl.prototype.kind = function () { return "DocumentationItem"; };
	    /**
	     * @return RAML version of the node
	     **/
	    DocumentationItemImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    /**
	     * Scalar properties annotations accessor
	     **/
	    DocumentationItemImpl.prototype.scalarsAnnotations = function () { return new DocumentationItemScalarsAnnotationsImpl(this.highLevel()); };
	    return DocumentationItemImpl;
	}(AnnotableImpl));
	exports.DocumentationItemImpl = DocumentationItemImpl;
	/**
	 * DocumentationItem scalar properties annotations accessor
	 **/
	var DocumentationItemScalarsAnnotationsImpl = (function (_super) {
	    __extends(DocumentationItemScalarsAnnotationsImpl, _super);
	    function DocumentationItemScalarsAnnotationsImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * DocumentationItem.title annotations
	     **/
	    DocumentationItemScalarsAnnotationsImpl.prototype.title = function () {
	        var attr = this.node.attr("title");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * DocumentationItem.content annotations
	     **/
	    DocumentationItemScalarsAnnotationsImpl.prototype.content = function () {
	        var attr = this.node.attr("content");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    return DocumentationItemScalarsAnnotationsImpl;
	}(AnnotableScalarsAnnotationsImpl));
	exports.DocumentationItemScalarsAnnotationsImpl = DocumentationItemScalarsAnnotationsImpl;
	var FragmentDeclarationImpl = (function (_super) {
	    __extends(FragmentDeclarationImpl, _super);
	    function FragmentDeclarationImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createFragmentDeclaration(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    FragmentDeclarationImpl.prototype.uses = function () {
	        return _super.prototype.elements.call(this, 'uses');
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    FragmentDeclarationImpl.prototype.wrapperClassName = function () { return "FragmentDeclarationImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    FragmentDeclarationImpl.prototype.kind = function () { return "FragmentDeclaration"; };
	    /**
	     * @return RAML version of the node
	     **/
	    FragmentDeclarationImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    return FragmentDeclarationImpl;
	}(AnnotableImpl));
	exports.FragmentDeclarationImpl = FragmentDeclarationImpl;
	var LibraryBaseImpl = (function (_super) {
	    __extends(LibraryBaseImpl, _super);
	    function LibraryBaseImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createLibraryBase(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * Alias for the equivalent "types" property, for compatibility with RAML 0.8. Deprecated - API definitions should use the "types" property, as the "schemas" alias for that property name may be removed in a future RAML version. The "types" property allows for XML and JSON schemas.
	     **/
	    LibraryBaseImpl.prototype.schemas = function () {
	        return _super.prototype.elements.call(this, 'schemas');
	    };
	    /**
	     * Declarations of (data) types for use within this API
	     **/
	    LibraryBaseImpl.prototype.types = function () {
	        return _super.prototype.elements.call(this, 'types');
	    };
	    /**
	     * Declarations of traits for use within this API
	     * @hidden
	     **/
	    LibraryBaseImpl.prototype.traits_original = function () {
	        return _super.prototype.elements.call(this, 'traits');
	    };
	    /**
	     * Declarations of resource types for use within this API
	     * @hidden
	     **/
	    LibraryBaseImpl.prototype.resourceTypes_original = function () {
	        return _super.prototype.elements.call(this, 'resourceTypes');
	    };
	    /**
	     * Declarations of annotation types for use by annotations
	     **/
	    LibraryBaseImpl.prototype.annotationTypes = function () {
	        return _super.prototype.elements.call(this, 'annotationTypes');
	    };
	    /**
	     * Declarations of security schemes for use within this API.
	     **/
	    LibraryBaseImpl.prototype.securitySchemes = function () {
	        return _super.prototype.elements.call(this, 'securitySchemes');
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    LibraryBaseImpl.prototype.wrapperClassName = function () { return "LibraryBaseImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    LibraryBaseImpl.prototype.kind = function () { return "LibraryBase"; };
	    /**
	     * @return RAML version of the node
	     **/
	    LibraryBaseImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    /**
	     * Declarations of traits for use within this API
	     **/
	    LibraryBaseImpl.prototype.traits = function () {
	        return helper.traitsPrimary(this);
	    };
	    /**
	     * Retrieve all traits including those defined in libraries
	     * @deprecated
	     **/
	    LibraryBaseImpl.prototype.allTraits = function () {
	        return helper.allTraits(this);
	    };
	    /**
	     * Declarations of resource types for use within this API
	     **/
	    LibraryBaseImpl.prototype.resourceTypes = function () {
	        return helper.resourceTypesPrimary(this);
	    };
	    /**
	     * Retrieve all resource types including those defined in libraries
	     * @deprecated
	     **/
	    LibraryBaseImpl.prototype.allResourceTypes = function () {
	        return helper.allResourceTypes(this);
	    };
	    return LibraryBaseImpl;
	}(FragmentDeclarationImpl));
	exports.LibraryBaseImpl = LibraryBaseImpl;
	var LibraryImpl = (function (_super) {
	    __extends(LibraryImpl, _super);
	    function LibraryImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createLibrary(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * contains description of why library exist
	     **/
	    LibraryImpl.prototype.usage = function () {
	        return _super.prototype.attribute.call(this, 'usage', this.toString);
	    };
	    /**
	     * @hidden
	     * Set usage value
	     **/
	    LibraryImpl.prototype.setUsage = function (param) {
	        this.highLevel().attrOrCreate("usage").setValue("" + param);
	        return this;
	    };
	    /**
	     * Namespace which the library is imported under
	     **/
	    LibraryImpl.prototype.name = function () {
	        return _super.prototype.attribute.call(this, 'name', this.toString);
	    };
	    /**
	     * @hidden
	     * Set name value
	     **/
	    LibraryImpl.prototype.setName = function (param) {
	        this.highLevel().attrOrCreate("name").setValue("" + param);
	        return this;
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    LibraryImpl.prototype.wrapperClassName = function () { return "LibraryImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    LibraryImpl.prototype.kind = function () { return "Library"; };
	    /**
	     * @return RAML version of the node
	     **/
	    LibraryImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    /**
	     * Scalar properties annotations accessor
	     **/
	    LibraryImpl.prototype.scalarsAnnotations = function () { return new LibraryScalarsAnnotationsImpl(this.highLevel()); };
	    return LibraryImpl;
	}(LibraryBaseImpl));
	exports.LibraryImpl = LibraryImpl;
	/**
	 * Library scalar properties annotations accessor
	 **/
	var LibraryScalarsAnnotationsImpl = (function (_super) {
	    __extends(LibraryScalarsAnnotationsImpl, _super);
	    function LibraryScalarsAnnotationsImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * Library.usage annotations
	     **/
	    LibraryScalarsAnnotationsImpl.prototype.usage = function () {
	        var attr = this.node.attr("usage");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    return LibraryScalarsAnnotationsImpl;
	}(AnnotableScalarsAnnotationsImpl));
	exports.LibraryScalarsAnnotationsImpl = LibraryScalarsAnnotationsImpl;
	var ApiImpl = (function (_super) {
	    __extends(ApiImpl, _super);
	    function ApiImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createApi(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * Short plain-text label for the API
	     **/
	    ApiImpl.prototype.title = function () {
	        return _super.prototype.attribute.call(this, 'title', this.toString);
	    };
	    /**
	     * @hidden
	     * Set title value
	     **/
	    ApiImpl.prototype.setTitle = function (param) {
	        this.highLevel().attrOrCreate("title").setValue("" + param);
	        return this;
	    };
	    /**
	     * A longer, human-friendly description of the API
	     **/
	    ApiImpl.prototype.description = function () {
	        return _super.prototype.attribute.call(this, 'description', function (attr) { return new MarkdownStringImpl(attr); });
	    };
	    /**
	     * The version of the API, e.g. 'v1'
	     **/
	    ApiImpl.prototype.version = function () {
	        return _super.prototype.attribute.call(this, 'version', this.toString);
	    };
	    /**
	     * @hidden
	     * Set version value
	     **/
	    ApiImpl.prototype.setVersion = function (param) {
	        this.highLevel().attrOrCreate("version").setValue("" + param);
	        return this;
	    };
	    /**
	     * A URI that's to be used as the base of all the resources' URIs. Often used as the base of the URL of each resource, containing the location of the API. Can be a template URI.
	     **/
	    ApiImpl.prototype.baseUri = function () {
	        return _super.prototype.attribute.call(this, 'baseUri', function (attr) { return new FullUriTemplateStringImpl(attr); });
	    };
	    /**
	     * Named parameters used in the baseUri (template)
	     * @hidden
	     **/
	    ApiImpl.prototype.baseUriParameters_original = function () {
	        return _super.prototype.elements.call(this, 'baseUriParameters');
	    };
	    /**
	     * The protocols supported by the API
	     **/
	    ApiImpl.prototype.protocols = function () {
	        return _super.prototype.attributes.call(this, 'protocols', this.toString);
	    };
	    /**
	     * @hidden
	     * Set protocols value
	     **/
	    ApiImpl.prototype.setProtocols = function (param) {
	        this.highLevel().attrOrCreate("protocols").setValue("" + param);
	        return this;
	    };
	    /**
	     * The default media type to use for request and response bodies (payloads), e.g. "application/json"
	     **/
	    ApiImpl.prototype.mediaType = function () {
	        return _super.prototype.attributes.call(this, 'mediaType', function (attr) { return new MimeTypeImpl(attr); });
	    };
	    /**
	     * The security schemes that apply to every resource and method in the API
	     **/
	    ApiImpl.prototype.securedBy = function () {
	        return _super.prototype.attributes.call(this, 'securedBy', function (attr) { return new SecuritySchemeRefImpl(attr); });
	    };
	    /**
	     * The resources of the API, identified as relative URIs that begin with a slash (/). Every property whose key begins with a slash (/), and is either at the root of the API definition or is the child property of a resource property, is a resource property, e.g.: /users, /{groupId}, etc
	     **/
	    ApiImpl.prototype.resources = function () {
	        return _super.prototype.elements.call(this, 'resources');
	    };
	    /**
	     * Additional overall documentation for the API
	     **/
	    ApiImpl.prototype.documentation = function () {
	        return _super.prototype.elements.call(this, 'documentation');
	    };
	    /**
	     * Most of RAML model elements may have attached annotations decribing additional meta data about this element
	     **/
	    ApiImpl.prototype.annotations = function () {
	        return _super.prototype.attributes.call(this, 'annotations', function (attr) { return new AnnotationRefImpl(attr); });
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    ApiImpl.prototype.wrapperClassName = function () { return "ApiImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    ApiImpl.prototype.kind = function () { return "Api"; };
	    /**
	     * @return RAML version of the node
	     * @hidden
	     **/
	    ApiImpl.prototype.RAMLVersion_original = function () { return "RAML10"; };
	    /**
	     * Equivalent API with traits and resource types expanded
	     **/
	    ApiImpl.prototype.expand = function () {
	        return helper.expandTraitsAndResourceTypes(this);
	    };
	    /**
	     * Get child resource by its relative path
	     **/
	    ApiImpl.prototype.childResource = function (relPath) {
	        return helper.childResource(this, relPath);
	    };
	    /**
	     * Retrieve all resources of the Api
	     **/
	    ApiImpl.prototype.allResources = function () {
	        return helper.allResources(this);
	    };
	    /**
	     * Named parameters used in the baseUri (template)
	     **/
	    ApiImpl.prototype.baseUriParameters = function () {
	        return helper.baseUriParametersPrimary(this);
	    };
	    /**
	     * Retrieve an ordered list of all base uri parameters regardless of whether they are described in `baseUriParameters` or not
	     * Consider a fragment of RAML specification:
	     * ```yaml
	     * version: v1
	     * baseUri: https://{organization}.example.com/{version}/{service}
	     * baseUriParameters:
	     * service:
	     * ```
	     * Here `version` and `organization` are base uri parameters which are not described in the `baseUriParameters` node,
	     * but they are among `Api.allBaseUriParameters()`.
	     * @deprecated
	     **/
	    ApiImpl.prototype.allBaseUriParameters = function () {
	        return helper.baseUriParameters(this);
	    };
	    /**
	     * Protocols used by the API. Returns the `protocols` property value if it is specified.
	     * Otherwise, returns protocol, specified in the base URI.
	     * @deprecated
	     **/
	    ApiImpl.prototype.allProtocols = function () {
	        return helper.allProtocols(this);
	    };
	    /**
	     * @return RAML version of the node
	     **/
	    ApiImpl.prototype.RAMLVersion = function () {
	        return helper.RAMLVersion(this);
	    };
	    /**
	     * Scalar properties annotations accessor
	     **/
	    ApiImpl.prototype.scalarsAnnotations = function () { return new ApiScalarsAnnotationsImpl(this.highLevel()); };
	    return ApiImpl;
	}(LibraryBaseImpl));
	exports.ApiImpl = ApiImpl;
	var OverlayImpl = (function (_super) {
	    __extends(OverlayImpl, _super);
	    function OverlayImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createOverlay(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * contains description of why overlay exist
	     **/
	    OverlayImpl.prototype.usage = function () {
	        return _super.prototype.attribute.call(this, 'usage', this.toString);
	    };
	    /**
	     * @hidden
	     * Set usage value
	     **/
	    OverlayImpl.prototype.setUsage = function (param) {
	        this.highLevel().attrOrCreate("usage").setValue("" + param);
	        return this;
	    };
	    /**
	     * Location of a valid RAML API definition (or overlay or extension), the overlay is applied to.
	     **/
	    OverlayImpl.prototype.extends = function () {
	        return _super.prototype.attribute.call(this, 'extends', this.toString);
	    };
	    /**
	     * @hidden
	     * Set extends value
	     **/
	    OverlayImpl.prototype.setExtends = function (param) {
	        this.highLevel().attrOrCreate("extends").setValue("" + param);
	        return this;
	    };
	    /**
	     * Short plain-text label for the API
	     **/
	    OverlayImpl.prototype.title = function () {
	        return _super.prototype.attribute.call(this, 'title', this.toString);
	    };
	    /**
	     * @hidden
	     * Set title value
	     **/
	    OverlayImpl.prototype.setTitle = function (param) {
	        this.highLevel().attrOrCreate("title").setValue("" + param);
	        return this;
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    OverlayImpl.prototype.wrapperClassName = function () { return "OverlayImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    OverlayImpl.prototype.kind = function () { return "Overlay"; };
	    /**
	     * @return RAML version of the node
	     **/
	    OverlayImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    /**
	     * Scalar properties annotations accessor
	     **/
	    OverlayImpl.prototype.scalarsAnnotations = function () { return new OverlayScalarsAnnotationsImpl(this.highLevel()); };
	    return OverlayImpl;
	}(ApiImpl));
	exports.OverlayImpl = OverlayImpl;
	/**
	 * Api scalar properties annotations accessor
	 **/
	var ApiScalarsAnnotationsImpl = (function (_super) {
	    __extends(ApiScalarsAnnotationsImpl, _super);
	    function ApiScalarsAnnotationsImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * Api.title annotations
	     **/
	    ApiScalarsAnnotationsImpl.prototype.title = function () {
	        var attr = this.node.attr("title");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * Api.description annotations
	     **/
	    ApiScalarsAnnotationsImpl.prototype.description = function () {
	        var attr = this.node.attr("description");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * Api.version annotations
	     **/
	    ApiScalarsAnnotationsImpl.prototype.version = function () {
	        var attr = this.node.attr("version");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * Api.baseUri annotations
	     **/
	    ApiScalarsAnnotationsImpl.prototype.baseUri = function () {
	        var attr = this.node.attr("baseUri");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * Api.protocols annotations
	     **/
	    ApiScalarsAnnotationsImpl.prototype.protocols = function () {
	        var attrs = this.node.attributes("protocols");
	        return attrs.map(function (x) {
	            var annotationAttrs = x.annotations();
	            var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	            return result;
	        });
	    };
	    /**
	     * Api.mediaType annotations
	     **/
	    ApiScalarsAnnotationsImpl.prototype.mediaType = function () {
	        var attrs = this.node.attributes("mediaType");
	        return attrs.map(function (x) {
	            var annotationAttrs = x.annotations();
	            var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	            return result;
	        });
	    };
	    /**
	     * Api.securedBy annotations
	     **/
	    ApiScalarsAnnotationsImpl.prototype.securedBy = function () {
	        var attrs = this.node.attributes("securedBy");
	        return attrs.map(function (x) {
	            var annotationAttrs = x.annotations();
	            var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	            return result;
	        });
	    };
	    /**
	     * Api.annotations annotations
	     **/
	    ApiScalarsAnnotationsImpl.prototype.annotations = function () {
	        var attrs = this.node.attributes("annotations");
	        return attrs.map(function (x) {
	            var annotationAttrs = x.annotations();
	            var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	            return result;
	        });
	    };
	    return ApiScalarsAnnotationsImpl;
	}(AnnotableScalarsAnnotationsImpl));
	exports.ApiScalarsAnnotationsImpl = ApiScalarsAnnotationsImpl;
	/**
	 * Overlay scalar properties annotations accessor
	 **/
	var OverlayScalarsAnnotationsImpl = (function (_super) {
	    __extends(OverlayScalarsAnnotationsImpl, _super);
	    function OverlayScalarsAnnotationsImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * Overlay.usage annotations
	     **/
	    OverlayScalarsAnnotationsImpl.prototype.usage = function () {
	        var attr = this.node.attr("usage");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * Overlay.extends annotations
	     **/
	    OverlayScalarsAnnotationsImpl.prototype.extends = function () {
	        var attr = this.node.attr("extends");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * Overlay.title annotations
	     **/
	    OverlayScalarsAnnotationsImpl.prototype.title = function () {
	        var attr = this.node.attr("title");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    return OverlayScalarsAnnotationsImpl;
	}(ApiScalarsAnnotationsImpl));
	exports.OverlayScalarsAnnotationsImpl = OverlayScalarsAnnotationsImpl;
	var ExtensionImpl = (function (_super) {
	    __extends(ExtensionImpl, _super);
	    function ExtensionImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createExtension(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * contains description of why extension exist
	     **/
	    ExtensionImpl.prototype.usage = function () {
	        return _super.prototype.attribute.call(this, 'usage', this.toString);
	    };
	    /**
	     * @hidden
	     * Set usage value
	     **/
	    ExtensionImpl.prototype.setUsage = function (param) {
	        this.highLevel().attrOrCreate("usage").setValue("" + param);
	        return this;
	    };
	    /**
	     * Location of a valid RAML API definition (or overlay or extension), the extension is applied to
	     **/
	    ExtensionImpl.prototype.extends = function () {
	        return _super.prototype.attribute.call(this, 'extends', this.toString);
	    };
	    /**
	     * @hidden
	     * Set extends value
	     **/
	    ExtensionImpl.prototype.setExtends = function (param) {
	        this.highLevel().attrOrCreate("extends").setValue("" + param);
	        return this;
	    };
	    /**
	     * Short plain-text label for the API
	     **/
	    ExtensionImpl.prototype.title = function () {
	        return _super.prototype.attribute.call(this, 'title', this.toString);
	    };
	    /**
	     * @hidden
	     * Set title value
	     **/
	    ExtensionImpl.prototype.setTitle = function (param) {
	        this.highLevel().attrOrCreate("title").setValue("" + param);
	        return this;
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    ExtensionImpl.prototype.wrapperClassName = function () { return "ExtensionImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    ExtensionImpl.prototype.kind = function () { return "Extension"; };
	    /**
	     * @return RAML version of the node
	     **/
	    ExtensionImpl.prototype.RAMLVersion = function () { return "RAML10"; };
	    /**
	     * Scalar properties annotations accessor
	     **/
	    ExtensionImpl.prototype.scalarsAnnotations = function () { return new ExtensionScalarsAnnotationsImpl(this.highLevel()); };
	    return ExtensionImpl;
	}(ApiImpl));
	exports.ExtensionImpl = ExtensionImpl;
	/**
	 * Extension scalar properties annotations accessor
	 **/
	var ExtensionScalarsAnnotationsImpl = (function (_super) {
	    __extends(ExtensionScalarsAnnotationsImpl, _super);
	    function ExtensionScalarsAnnotationsImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * Extension.usage annotations
	     **/
	    ExtensionScalarsAnnotationsImpl.prototype.usage = function () {
	        var attr = this.node.attr("usage");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * Extension.extends annotations
	     **/
	    ExtensionScalarsAnnotationsImpl.prototype.extends = function () {
	        var attr = this.node.attr("extends");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    /**
	     * Extension.title annotations
	     **/
	    ExtensionScalarsAnnotationsImpl.prototype.title = function () {
	        var attr = this.node.attr("title");
	        if (attr == null) {
	            return [];
	        }
	        var annotationAttrs = attr.annotations();
	        var result = core.attributesToValues(annotationAttrs, function (a) { return new AnnotationRefImpl(a); });
	        return result;
	    };
	    return ExtensionScalarsAnnotationsImpl;
	}(ApiScalarsAnnotationsImpl));
	exports.ExtensionScalarsAnnotationsImpl = ExtensionScalarsAnnotationsImpl;
	/**
	 * @hidden
	 **/
	function createApi(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("Api");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createLibraryBase(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("LibraryBase");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createFragmentDeclaration(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("FragmentDeclaration");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createAnnotable(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("Annotable");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createTypeInstance(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("TypeInstance");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createTypeInstanceProperty(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("TypeInstanceProperty");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createTrait(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("Trait");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createMethodBase(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("MethodBase");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createOperation(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("Operation");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createTypeDeclaration(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("TypeDeclaration");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createExampleSpec(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("ExampleSpec");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createXMLFacetInfo(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("XMLFacetInfo");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createUsesDeclaration(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("UsesDeclaration");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createArrayTypeDeclaration(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("ArrayTypeDeclaration");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createUnionTypeDeclaration(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("UnionTypeDeclaration");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createObjectTypeDeclaration(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("ObjectTypeDeclaration");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createStringTypeDeclaration(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("StringTypeDeclaration");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createBooleanTypeDeclaration(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("BooleanTypeDeclaration");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createNumberTypeDeclaration(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("NumberTypeDeclaration");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createIntegerTypeDeclaration(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("IntegerTypeDeclaration");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createDateOnlyTypeDeclaration(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("DateOnlyTypeDeclaration");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createTimeOnlyTypeDeclaration(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("TimeOnlyTypeDeclaration");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createDateTimeOnlyTypeDeclaration(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("DateTimeOnlyTypeDeclaration");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createDateTimeTypeDeclaration(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("DateTimeTypeDeclaration");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createDateTypeDeclaration(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("DateTypeDeclaration");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createFileTypeDeclaration(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("FileTypeDeclaration");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createResponse(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("Response");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createSecuritySchemePart(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("SecuritySchemePart");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createAbstractSecurityScheme(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("AbstractSecurityScheme");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createSecuritySchemeSettings(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("SecuritySchemeSettings");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createOAuth1SecuritySchemeSettings(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("OAuth1SecuritySchemeSettings");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createOAuth2SecuritySchemeSettings(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("OAuth2SecuritySchemeSettings");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createOAuth2SecurityScheme(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("OAuth2SecurityScheme");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createOAuth1SecurityScheme(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("OAuth1SecurityScheme");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createPassThroughSecurityScheme(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("PassThroughSecurityScheme");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createBasicSecurityScheme(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("BasicSecurityScheme");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createDigestSecurityScheme(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("DigestSecurityScheme");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createCustomSecurityScheme(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("CustomSecurityScheme");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createMethod(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("Method");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createResourceType(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("ResourceType");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createResourceBase(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("ResourceBase");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createResource(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("Resource");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createDocumentationItem(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("DocumentationItem");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createLibrary(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("Library");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createOverlay(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("Overlay");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createExtension(key) {
	    var universe = def.getUniverse("RAML10");
	    var nc = universe.type("Extension");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	function loadApiSync(apiPath, arg1, arg2) {
	    return apiLoader.loadApi(apiPath, arg1, arg2).getOrElse(null);
	}
	exports.loadApiSync = loadApiSync;
	function loadRAMLSync(ramlPath, arg1, arg2) {
	    return apiLoader.loadApi(ramlPath, arg1, arg2).getOrElse(null);
	}
	exports.loadRAMLSync = loadRAMLSync;
	function loadApi(apiPath, arg1, arg2) {
	    return apiLoader.loadApiAsync(apiPath, arg1, arg2);
	}
	exports.loadApi = loadApi;
	function loadRAML(ramlPath, arg1, arg2) {
	    return apiLoader.loadRAMLAsync(ramlPath, arg1, arg2);
	}
	exports.loadRAML = loadRAML;
	/**
	 * Gets AST node by runtime type, if runtime type matches any.
	 * @param runtimeType - runtime type to find the match for
	 */
	function getLanguageElementByRuntimeType(runtimeType) {
	    return apiLoader.getLanguageElementByRuntimeType(runtimeType);
	}
	exports.getLanguageElementByRuntimeType = getLanguageElementByRuntimeType;
	//# sourceMappingURL=raml10parser.js.map

/***/ },
/* 29 */
/***/ function(module, exports, __webpack_require__) {

	/// <reference path="../typings/main.d.ts" />
	"use strict";
	var invariant = __webpack_require__(68);
	var exists = function (v) { return (v != null); };
	var globalEmptyOpt;
	var Opt = (function () {
	    function Opt(_value) {
	        var _this = this;
	        this._value = _value;
	        this._isDefined = false;
	        this._isEmpty = true;
	        this._arr = undefined;
	        this.getOrThrow = function () {
	            invariant(_this._isDefined, 'Opt is empty. Use `Opt#getOrElse` or check `Opt#isDefined`.');
	            return _this._value;
	        };
	        this.value = function () { return _this._value; };
	        this.isDefined = function () { return _this._isDefined; };
	        this.isEmpty = function () { return _this._isEmpty; };
	        this.toArray = function () { return _this._arr || (_this._arr = _this._isDefined ? [_this._value] : []); };
	        this.getOrElse = function (v) { return _this._isDefined ? _this._value : v; };
	        this.getOrElseF = function (v) { return _this._isDefined ? _this._value : v(); };
	        this.map = function (f) { return _this._isEmpty ? Opt.empty() : new Opt(f(_this._value)); };
	        this.flatMap = function (f) { return _this.map(f).getOrElse(Opt.empty()); };
	        this.equals = function (other) {
	            invariant(other instanceof Opt, 'Expected other to be an `Opt`, but got `%s`', typeof other);
	            return (_this._isDefined === other.isDefined()) && (_this._value === other.value());
	        };
	        if (exists(this._value)) {
	            this._isDefined = true;
	            this._isEmpty = false;
	        }
	    }
	    Opt.prototype.forEach = function (fn) {
	        if (this.isDefined()) {
	            fn(this._value);
	        }
	    };
	    /**
	     * You can always create an empty option by hand just by calling new Opt<T>()
	     * but calling this method will return a global instance instead of allocating a new one each time
	     */
	    Opt.empty = function () { return (globalEmptyOpt || (globalEmptyOpt = new Opt())); };
	    return Opt;
	}());
	module.exports = Opt;
	//# sourceMappingURL=Opt.js.map

/***/ },
/* 30 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var ramlDs = __webpack_require__(33);
	module.exports = ramlDs.universesInfo;
	//# sourceMappingURL=universe.js.map

/***/ },
/* 31 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var path = __webpack_require__(15);
	var URL = __webpack_require__(57);
	var util = __webpack_require__(43);
	var resourceRegistry = __webpack_require__(22);
	var ContentProvider = (function () {
	    function ContentProvider(unit) {
	        this.unit = unit;
	    }
	    ContentProvider.prototype.contextPath = function () {
	        if (!this.unit) {
	            return "";
	        }
	        var rootPath = this.unit.absolutePath();
	        return rootPath || "";
	    };
	    ContentProvider.prototype.normalizePath = function (url) {
	        if (!url) {
	            return url;
	        }
	        var result;
	        if (!isWebPath(url)) {
	            result = path.normalize(url);
	        }
	        else {
	            var prefix = url.toLowerCase().indexOf('https') === 0 ? 'https://' : 'http://';
	            result = prefix + path.normalize(url.substring(prefix.length));
	        }
	        return result;
	    };
	    ContentProvider.prototype.content = function (reference) {
	        var absolutePath = this.normalizePath(reference);
	        var unit = this.unit.resolve(absolutePath);
	        if (!unit) {
	            return "";
	        }
	        return unit.contents() || "";
	    };
	    ContentProvider.prototype.contentAsync = function (reference) {
	        var absolutePath = this.normalizePath(reference);
	        var unitPromise = this.unit.resolveAsync(absolutePath);
	        if (!unitPromise) {
	            return Promise.resolve("");
	        }
	        var result = unitPromise.then(function (unit) {
	            return (unit && unit.contents()) || "";
	        });
	        return result;
	    };
	    ContentProvider.prototype.hasAsyncRequests = function () {
	        return resourceRegistry.hasAsyncRequests();
	    };
	    ContentProvider.prototype.resolvePath = function (context, relativePath) {
	        if (!relativePath || !context) {
	            return relativePath;
	        }
	        var result;
	        if (!isWebPath(context)) {
	            result = path.resolve(path.dirname(context), relativePath);
	        }
	        else {
	            result = URL.resolve(context, relativePath);
	        }
	        return result;
	    };
	    ContentProvider.prototype.isAbsolutePath = function (uri) {
	        if (!uri) {
	            return false;
	        }
	        if (isWebPath(uri)) {
	            return true;
	        }
	        return path.isAbsolute(uri);
	    };
	    ContentProvider.prototype.promiseResolve = function (arg) {
	        return Promise.resolve(arg);
	    };
	    return ContentProvider;
	}());
	exports.ContentProvider = ContentProvider;
	function isWebPath(str) {
	    if (str == null)
	        return false;
	    return util.stringStartsWith(str, "http://") || util.stringStartsWith(str, "https://");
	}
	//# sourceMappingURL=contentprovider.js.map

/***/ },
/* 32 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var __extends = (this && this.__extends) || function (d, b) {
	    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
	    function __() { this.constructor = d; }
	    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
	};
	var RamlWrapper = __webpack_require__(12);
	var RamlWrapperImpl = __webpack_require__(28);
	var factory = __webpack_require__(41);
	var core = __webpack_require__(50);
	var ramlPathMatch = __webpack_require__(51);
	var hl = __webpack_require__(10);
	var hlimpl = __webpack_require__(16);
	var linter = __webpack_require__(25);
	var stubs = __webpack_require__(17);
	var defs = __webpack_require__(33);
	var universeDef = __webpack_require__(30);
	var universes = __webpack_require__(30);
	var Opt = __webpack_require__(29);
	var util = __webpack_require__(43);
	var expander = __webpack_require__(24);
	var lowLevelProxy = __webpack_require__(37);
	var search = __webpack_require__(27);
	var ll = __webpack_require__(21);
	var json = __webpack_require__(47);
	var path = __webpack_require__(15);
	var universeHelpers = __webpack_require__(14);
	function resolveType(p) {
	    return p.highLevel().localType();
	}
	exports.resolveType = resolveType;
	//__$helperMethod__ Runtime representation of type represented by this AST node
	function runtimeType(p) {
	    return p.highLevel().localType();
	}
	exports.runtimeType = runtimeType;
	function load(pth) {
	    var m = new ll.Project(path.dirname(pth));
	    var unit = m.unit(path.basename(pth));
	    if (unit) {
	        if (unit.isRAMLUnit()) {
	            return hlimpl.fromUnit(unit).wrapperNode();
	        }
	    }
	    return null;
	}
	exports.load = load;
	//__$helperMethod__ Path relative to API root
	function completeRelativeUri(res) {
	    var uri = '';
	    var parent = res;
	    do {
	        res = parent; //(parent instanceof RamlWrapper.ResourceImpl) ? <RamlWrapper.Resource>parent : null;
	        uri = res.relativeUri().value() + uri;
	        parent = res.parent();
	    } while (parent.definition().key().name == universes.Universe10.Resource.name);
	    return uri;
	}
	exports.completeRelativeUri = completeRelativeUri;
	/**
	 * __$helperMethod__
	 * Equivalent API with traits and resource types expanded
	 * __$meta__={"name":"expand"}
	 */
	function expandTraitsAndResourceTypes(api) {
	    var lowLevelNode = api.highLevel().lowLevel();
	    if (lowLevelNode instanceof lowLevelProxy.LowLevelProxyNode) {
	        return api;
	    }
	    return expander.expandTraitsAndResourceTypes(api);
	}
	exports.expandTraitsAndResourceTypes = expandTraitsAndResourceTypes;
	//__$helperMethod__ baseUri of owning Api concatenated with completeRelativeUri
	function absoluteUri(res) {
	    var uri = '';
	    var parent = res;
	    do {
	        res = parent; //(parent instanceof RamlWrapper.ResourceImpl) ? <RamlWrapper.Resource>parent : null;
	        uri = res.relativeUri().value() + uri;
	        parent = res.parent();
	    } while (parent.definition().key().name == universes.Universe10.Resource.name);
	    uri = uri.replace(/\/\//g, '/');
	    var buri = parent.baseUri();
	    var base = buri ? buri.value() : "";
	    base = base ? base : '';
	    if (util.stringEndsWith(base, '/')) {
	        uri = uri.substring(1);
	    }
	    uri = base + uri;
	    return uri;
	}
	exports.absoluteUri = absoluteUri;
	//__$helperMethod__ validate an instance against type
	function validateInstance(res, value) {
	    return res.runtimeType().validate(value).map(function (x) { return x.getMessage(); });
	    //throw new Error("Fix me");
	}
	exports.validateInstance = validateInstance;
	//__$helperMethod__ validate an instance against type
	function validateInstanceWithDetailedStatuses(res, value) {
	    return res.runtimeType().validate(value);
	}
	exports.validateInstanceWithDetailedStatuses = validateInstanceWithDetailedStatuses;
	/**
	 * __$helperMethod__
	 * Retrieve all traits including those defined in libraries
	 * __$meta__{"name":"traits","override":true}
	 */
	function traitsPrimary(a) {
	    return allTraits(a);
	}
	exports.traitsPrimary = traitsPrimary;
	/**
	 * __$helperMethod__ Retrieve all traits including those defined in libraries
	 * __$meta__{"deprecated":true}
	 */
	function allTraits(a) {
	    return findTemplates(a, function (d) { return universeHelpers.isTraitType(d); });
	}
	exports.allTraits = allTraits;
	/**
	 * __$helperMethod__
	 * Retrieve all resource types including those defined in libraries
	 * __$meta__{"name":"resourceTypes","override":true}
	 */
	function resourceTypesPrimary(a) {
	    return allResourceTypes(a);
	}
	exports.resourceTypesPrimary = resourceTypesPrimary;
	/**
	 * __$helperMethod__ Retrieve all resource types including those defined in libraries
	 * __$meta__{"deprecated":true}
	 */
	function allResourceTypes(a) {
	    return findTemplates(a, function (d) { return universeHelpers.isResourceTypeType(d); });
	}
	exports.allResourceTypes = allResourceTypes;
	function findTemplates(a, filter) {
	    var arr = search.globalDeclarations(a.highLevel()).filter(function (x) { return filter(x.definition()); });
	    var ll = a.highLevel().lowLevel();
	    var nodePath = ll.includePath();
	    if (!nodePath) {
	        nodePath = ll.unit().path();
	    }
	    var topLevelArr = arr.map(function (x) {
	        var topLevelNode;
	        var p = x.lowLevel().unit().path();
	        if (p != nodePath) {
	            topLevelNode = factory.buildWrapperNode(x, false);
	            topLevelNode.meta().setCalculated();
	        }
	        else {
	            topLevelNode = x.wrapperNode();
	        }
	        return topLevelNode;
	    });
	    return topLevelArr;
	}
	;
	function relativeUriSegments(res) {
	    var result = [];
	    var parent = res;
	    do {
	        res = parent; //(parent instanceof RamlWrapper.ResourceImpl) ? <RamlWrapper.Resource>parent : null;
	        result.push(res.relativeUri().value());
	        parent = res.parent();
	    } while (parent.definition().key().name == universes.Universe10.Resource.name);
	    return result.reverse();
	}
	exports.relativeUriSegments = relativeUriSegments;
	//__$helperMethod__ For methods of Resources returns parent resource. For methods of ResourceTypes returns null.
	function parentResource(method) {
	    if (method.parent() instanceof RamlWrapperImpl.ResourceImpl) {
	        return method.parent();
	    }
	    return null;
	}
	exports.parentResource = parentResource;
	/**
	 * __$helperMethod__
	 * Parent resource for non top level resources
	 * __$meta__={"name":"parentResource"}
	 */
	function parent(resource) {
	    var parent = resource.parent();
	    if (parent.definition().key().name == universes.Universe10.Resource.name) {
	        return parent;
	    }
	    return null;
	}
	exports.parent = parent;
	//__$helperMethod__ Get child resource by its relative path
	function childResource(container, relPath) {
	    if (container == null) {
	        return null;
	    }
	    var resources = container.resources();
	    if (!resources) {
	        return null;
	    }
	    resources = resources.filter(function (x) { return x.relativeUri().value() == relPath; });
	    if (resources.length == 0) {
	        return null;
	    }
	    return resources[0];
	}
	exports.childResource = childResource;
	function getResource(container, path) {
	    if (!container) {
	        return null;
	    }
	    var res = null;
	    for (var i = 0; i < path.length; i++) {
	        res = childResource(container, path[i]);
	        if (!res) {
	            return null;
	        }
	        container = res;
	    }
	    return res;
	}
	exports.getResource = getResource;
	//__$helperMethod__ Get child method by its name
	function childMethod(resource, method) {
	    if (!resource) {
	        return null;
	    }
	    return resource.methods().filter(function (x) { return x.method() == method; });
	}
	exports.childMethod = childMethod;
	function getMethod(container, path, method) {
	    var resource = getResource(container, path);
	    if (!resource) {
	        return null;
	    }
	    return childMethod(resource, method);
	}
	exports.getMethod = getMethod;
	function isApi(obj) {
	    return universeHelpers.isApiSibling(obj.definition());
	}
	;
	//__$helperMethod__ Api owning the resource as a sibling
	function ownerApi(method) {
	    var obj = method;
	    while (!isApi(obj)) {
	        obj = obj.parent();
	    }
	    return obj;
	}
	exports.ownerApi = ownerApi;
	/**
	 * __$helperMethod__
	 * For methods of Resources: `{parent Resource relative path} {methodName}`.
	 * For methods of ResourceTypes: `{parent ResourceType name} {methodName}`.
	 * For other methods throws Exception.
	 */
	function methodId(method) {
	    var parent = method.parent();
	    if (parent instanceof RamlWrapperImpl.ResourceImpl) {
	        return completeRelativeUri(parent) + ' ' + method.method().toLowerCase();
	    }
	    else if (parent instanceof RamlWrapperImpl.ResourceTypeImpl) {
	        return parent.name() + ' ' + method.method().toLowerCase();
	    }
	    throw new Error("Method is supposed to be owned by Resource or ResourceType.\nHere the method is owned by " + method.definition().key().name);
	}
	exports.methodId = methodId;
	//__$helperMethod__ true for codes < 400 and false otherwise
	function isOkRange(response) {
	    var str = response.code().value();
	    var err = linter.validateResponseString(str);
	    if (err != null) {
	        return false;
	    }
	    try {
	        if (parseInt(str.charAt(0)) < 4) {
	            return true;
	        }
	    }
	    catch (e) { }
	    return false;
	}
	exports.isOkRange = isOkRange;
	//__$helperMethod__  Retrieve all resources of the Api
	function allResources(api) {
	    var resources = [];
	    var visitor = function (res) {
	        resources.push(res);
	        res.resources().forEach(function (x) { return visitor(x); });
	    };
	    api.resources().forEach(function (x) { return visitor(x); });
	    return resources;
	}
	exports.allResources = allResources;
	function matchUri(apiRootRelativeUri, resource) {
	    var allParameters = {};
	    while (resource != null) {
	        uriParameters(resource).forEach(function (x) { return allParameters[x.name()] = new ParamWrapper(x); });
	        resource = parent(resource);
	    }
	    var result = ramlPathMatch.ramlPathMatch(completeRelativeUri(resource), allParameters, {})(apiRootRelativeUri);
	    if (result) {
	        return new Opt(Object.keys(result.params)
	            .map(function (x) { return new ParamValue(x, result['params'][x]); }));
	    }
	    return Opt.empty();
	}
	exports.matchUri = matchUri;
	var schemaContentChars = ['{', '<'];
	// export function schema(body:RamlWrapper.TypeDeclaration, api:RamlWrapper.Api):Opt<SchemaDef>{
	//
	//     var schemaNode = body.schema();
	//     if(!schemaNode){
	//         return Opt.empty<SchemaDef>();
	//     }
	//     var schemaString = schemaNode;
	//     var isContent:boolean = false;
	//     schemaContentChars.forEach(x=>{try{ isContent = isContent||schemaString.indexOf(x)>=0}catch(e){}});
	//     var schDef:SchemaDef;
	//     if(isContent) {
	//         schDef = new SchemaDef(schemaString);
	//     }
	//     else{
	//         var globalSchemes = api.schemas().filter(x=>x.name()==schemaString);
	//         if(globalSchemes.length>0){
	//             schDef = new SchemaDef(globalSchemes[0].type(),globalSchemes[0].name());
	//         }
	//         else{
	//             return Opt.empty<SchemaDef>();
	//         }
	//     }
	//     return new Opt<SchemaDef>(schDef);
	// }
	/**
	 * __$helperMethod__
	 * Retrieve an ordered list of all uri parameters including those which are not described in the `uriParameters` node.
	 * Consider a fragment of RAML specification:
	 * ```yaml
	 * /resource/{objectId}/{propertyId}:
	 *   uriParameters:
	 *     objectId:
	 * ```
	 * Here `propertyId` uri parameter is not described in the `uriParameters` node,
	 * but it is among Resource.uriParameters().
	 * __$meta__={"name":"uriParameters","override": true}
	 */
	function uriParametersPrimary(resource) {
	    return uriParameters(resource);
	}
	exports.uriParametersPrimary = uriParametersPrimary;
	/**
	 * __$helperMethod__
	 * Retrieve an ordered list of all uri parameters including those which are not described in the `uriParameters` node.
	 * Consider a fragment of RAML specification:
	 * ```yaml
	 * /resource/{objectId}/{propertyId}:
	 *   uriParameters:
	 *     objectId:
	 * ```
	 * Here `propertyId` uri parameter is not described in the `uriParameters` node,
	 * but it is among Resource.allUriParameters().
	 * __$meta__={"name":"allUriParameters","deprecated":true}
	 */
	function uriParameters(resource) {
	    var params = resource.uriParameters_original();
	    if (!(resource instanceof RamlWrapperImpl.ResourceImpl)) {
	        return params;
	    }
	    var uri = resource.relativeUri().value();
	    var propName = universes.Universe10.ResourceBase.properties.uriParameters.name;
	    return extractParams(params, uri, resource, propName);
	}
	exports.uriParameters = uriParameters;
	/**
	 * __$helperMethod__
	 * Retrieve an ordered list of all base uri parameters regardless of whether they are described in `baseUriParameters` or not
	 * Consider a fragment of RAML specification:
	 * ```yaml
	 * version: v1
	 * baseUri: https://{organization}.example.com/{version}/{service}
	 * baseUriParameters:
	 *   service:
	 * ```
	 * Here `version` and `organization` are base uri parameters which are not described in the `baseUriParameters` node,
	 * but they are among `Api.baseUriParameters()`.
	 * __$meta__={"name":"baseUriParameters","override":true}
	 */
	function baseUriParametersPrimary(api) {
	    return baseUriParameters(api);
	}
	exports.baseUriParametersPrimary = baseUriParametersPrimary;
	/**
	 * __$helperMethod__
	 * Retrieve an ordered list of all base uri parameters regardless of whether they are described in `baseUriParameters` or not
	 * Consider a fragment of RAML specification:
	 * ```yaml
	 * version: v1
	 * baseUri: https://{organization}.example.com/{version}/{service}
	 * baseUriParameters:
	 *   service:
	 * ```
	 * Here `version` and `organization` are base uri parameters which are not described in the `baseUriParameters` node,
	 * but they are among `Api.allBaseUriParameters()`.
	 * __$meta__={"name":"allBaseUriParameters","deprecated":true}
	 */
	function baseUriParameters(api) {
	    var uri = api.baseUri() ? api.baseUri().value() : '';
	    var params = api.baseUriParameters_original();
	    var propName = universes.Universe10.Api.properties.baseUriParameters.name;
	    return extractParams(params, uri, api, propName);
	}
	exports.baseUriParameters = baseUriParameters;
	/**
	 * __$helperMethod__
	 * Retrieve an ordered list of all absolute uri parameters. Returns a union of `Api.baseUriParameters()`
	 * for `Api` owning the `Resource` and `Resource.uriParameters()`.
	 */
	function absoluteUriParameters(res) {
	    var params = [];
	    var parent = res;
	    do {
	        res = parent;
	        params = uriParameters(res).concat(params);
	        parent = res.parent();
	    } while (parent.definition().key().name == universes.Universe10.Resource.name);
	    var api = parent;
	    var baseUri = api.baseUri().value();
	    var baseUriParams = api.baseUriParameters();
	    params = baseUriParameters(api).concat(params);
	    return params;
	}
	exports.absoluteUriParameters = absoluteUriParameters;
	/**
	 * _//_$helperMethod__
	 * Protocols used by the API. Returns the `protocols` property value if it is specified.
	 * Otherwise, returns protocol, specified in the base URI.
	 * __$meta__={"name":"protocols","override":true}
	 */
	function protocolsPrimary(api) {
	    return allProtocols(api);
	}
	exports.protocolsPrimary = protocolsPrimary;
	/**
	 * __$helperMethod__
	 * Protocols used by the API. Returns the `protocols` property value if it is specified.
	 * Otherwise, returns protocol, specified in the base URI.
	 * __$meta__{"deprecated":true}
	 */
	function allProtocols(api) {
	    return api.protocols().map(function (x) { return x.toUpperCase(); });
	    //var attributeDefaults = (<RamlWrapper.ApiImpl>api).attributeDefaults();
	    //var result = (<RamlWrapper.ApiImpl>api).protocols_original();
	    //if(result.length!=0||!attributeDefaults){
	    //    return result;
	    //}
	    //var baseUriAttr = api.baseUri();
	    //if(baseUriAttr) {
	    //    var baseUri = baseUriAttr.value();
	    //    if (baseUri) {
	    //        var ind = baseUri.indexOf('://');
	    //        if (ind >= 0) {
	    //            result = [baseUri.substring(0, ind)];
	    //        }
	    //        if(result.length==0){
	    //            result = [ 'HTTP' ];
	    //        }
	    //    }
	    //}
	    //return result;
	}
	exports.allProtocols = allProtocols;
	/**
	 * _//_$helperMethod__
	 * Returns security schemes, resource or method is secured with. If no security schemes are set at resource or method level,
	 * returns schemes defined with `securedBy` at API level.
	 * __$meta__={"name":"securedBy","override":true}
	 */
	function securedByPrimary(resourceOrMethod) {
	    return allSecuredBy(resourceOrMethod);
	}
	exports.securedByPrimary = securedByPrimary;
	/**
	 * __$helperMethod__
	 * Returns security schemes, resource or method is secured with. If no security schemes are set at resource or method level,
	 * returns schemes defined with `securedBy` at API level.
	 * __$meta__{"deprecated":true}
	 */
	function allSecuredBy(resourceOrMethod) {
	    //var currentSecuredBy = (<RamlWrapper.ResourceBaseImpl|RamlWrapper.MethodImpl>resourceOrMethod).securedBy_original();
	    //if (currentSecuredBy && currentSecuredBy.length > 0) {
	    //    return currentSecuredBy;
	    //}
	    //
	    ////instanceof, but have to avoid direct usage of instanceof in JS.
	    //var key = resourceOrMethod.highLevel().definition().key();
	    //if (key == universes.Universe10.Method) {
	    //    var method = (<RamlWrapper.Method>resourceOrMethod);
	    //    var resource = <RamlWrapper.ResourceImpl>method.parentResource();
	    //    if (resource && resource.securedBy_original() && resource.securedBy_original().length > 0) {
	    //        return resource.securedBy_original();
	    //    }
	    //    return method.ownerApi().securedBy();
	    //}
	    //if (key == universes.Universe10.Resource) {
	    //    return (<RamlWrapper.Resource>resourceOrMethod).ownerApi().securedBy();
	    //}
	    return resourceOrMethod.securedBy(); //return currentSecuredBy;
	}
	exports.allSecuredBy = allSecuredBy;
	/**
	 * __$helperMethod__
	 * __$meta__={"primary":true}
	 */
	function securitySchemeName(schemeReference) {
	    var highLevel = schemeReference.highLevel();
	    if (!highLevel)
	        return "";
	    var attributeValue = highLevel.value();
	    if (!attributeValue)
	        return "";
	    return attributeValue.toString();
	}
	exports.securitySchemeName = securitySchemeName;
	/**
	 * __$helperMethod__
	 * __$meta__={"primary":true}
	 */
	function securityScheme(schemeReference) {
	    var highLevel = schemeReference.highLevel();
	    if (!highLevel)
	        return null;
	    var declaration = search.findDeclarationByNode(highLevel, search.LocationKind.VALUE_COMPLETION);
	    if (!declaration)
	        return null;
	    if (!declaration.getKind || declaration.getKind() != hl.NodeKind.NODE) {
	        return null;
	    }
	    var result = declaration.wrapperNode();
	    if (!(result instanceof RamlWrapperImpl.AbstractSecuritySchemeImpl)) {
	        //I do not see how to avoid instanceof here
	        return null;
	    }
	    return result;
	}
	exports.securityScheme = securityScheme;
	/**
	 * __$helperMethod__
	 * __$meta__={"primary":true}
	 */
	function RAMLVersion(api) {
	    return api.highLevel().definition().universe().version();
	}
	exports.RAMLVersion = RAMLVersion;
	/**
	 * __$helperMethod__
	 * __$meta__={"primary":true}
	 */
	function structuredValue(reference) {
	    var hl = reference.value().lowLevel();
	    return new core.TypeInstanceImpl(hl);
	}
	exports.structuredValue = structuredValue;
	/**
	 * __$helperMethod__
	 * __$meta__={"name":"name","primary":true}
	 */
	function referenceName(reference) {
	    var val = reference.highLevel().value();
	    return (typeof val == 'string') || val == null ? val : val.valueName();
	}
	exports.referenceName = referenceName;
	/**
	 * __$helperMethod__
	 * __$meta__={"name":"trait","primary":true}
	 */
	function referencedTrait(ref) {
	    return referencedObject(ref);
	}
	exports.referencedTrait = referencedTrait;
	/**
	 * __$helperMethod__
	 * __$meta__={"name":"annotation","primary":true}
	 */
	function referencedAnnotation(ref) {
	    return referencedObject(ref);
	}
	exports.referencedAnnotation = referencedAnnotation;
	/**
	 * __$helperMethod__
	 * __$meta__={"name":"resourceType","primary":true}
	 */
	function referencedResourceType(ref) {
	    return referencedObject(ref);
	}
	exports.referencedResourceType = referencedResourceType;
	function referencedObject(ref) {
	    var attr = ref.highLevel();
	    var parent = attr.parent();
	    var vn = ref.name();
	    var cands = search.referenceTargets(attr.property(), parent).filter(function (x) { return hlimpl.qName(x, parent) == vn; });
	    if (cands.length == 0) {
	        return null;
	    }
	    return cands[0].wrapperNode();
	}
	function getExpandableExamples(node, isSingle) {
	    if (isSingle === void 0) { isSingle = false; }
	    var runtimeDefinition = node.runtimeDefinition();
	    if (!runtimeDefinition) {
	        return [];
	    }
	    var hlParent = node.highLevel();
	    var property = hlParent.definition().property(isSingle ? "example" : "examples");
	    var universe = defs.getUniverse("RAML10");
	    var definition = universe.type(universeDef.Universe10.ExampleSpec.name);
	    var expandables = runtimeDefinition.examples().filter(function (x) { return !x.isEmpty() && x.isSingle() == isSingle; });
	    return expandables.map(function (x) {
	        var obj = x.asJSON();
	        var llParent = hlParent.lowLevel();
	        var key = x.isSingle() ? "example" : null;
	        var jsonNode = new json.AstNode(llParent.unit(), obj, llParent, null, key);
	        var hlNode = new hlimpl.ASTNodeImpl(jsonNode, hlParent, definition, property);
	        var wrapperAnnotations = [];
	        var annotations = x.annotations();
	        if (annotations) {
	            var aProp = universe.type("Annotable").property("annotations");
	            for (var _i = 0, _a = Object.keys(annotations); _i < _a.length; _i++) {
	                var aName = _a[_i];
	                var aObj = annotations[aName];
	                var aJson = new json.AstNode(llParent.unit(), aObj, jsonNode, null, "(" + aName + ")");
	                var aHlNode = new hlimpl.ASTPropImpl(aJson, hlNode, aProp.range(), aProp);
	                var wAnnotation = new RamlWrapperImpl.AnnotationRefImpl(aHlNode);
	                wrapperAnnotations.push(wAnnotation);
	            }
	        }
	        return new ExampleSpecImpl(hlNode, x, wrapperAnnotations);
	    });
	}
	;
	/**
	 * __$helperMethod__
	 * __$meta__={"name":"example","primary":true}
	 */
	function getTypeExample(td) {
	    var examples = getExpandableExamples(td, true);
	    if (examples.length > 0) {
	        return examples[0];
	    }
	    return null;
	}
	exports.getTypeExample = getTypeExample;
	/**
	 * __$helperMethod__
	 * __$meta__={"name":"examples","primary":true}
	 */
	function getTypeExamples(td) {
	    return getExpandableExamples(td);
	}
	exports.getTypeExamples = getTypeExamples;
	/**
	 * __$helperMethod__
	 * __$meta__={"name":"fixedFacets","primary":true}
	 */
	function typeFixedFacets(td) {
	    var obj = td.runtimeDefinition().getFixedFacets();
	    if (Object.keys(obj).length == 0) {
	        return null;
	    }
	    var node = new json.AstNode(null, obj);
	    return new core.TypeInstanceImpl(node);
	}
	exports.typeFixedFacets = typeFixedFacets;
	/**
	 * __$helperMethod__ A base type which the current type extends, or more generally a type expression.
	 * __$meta__={"name":"type","override":true}
	 */
	function typeValue(typeDeclaration) {
	    var attrs = typeDeclaration.highLevel().attributes(defs.universesInfo.Universe10.TypeDeclaration.properties.type.name);
	    var structuredAttrs = attrs.filter(function (x) { return x.value() instanceof hlimpl.StructuredValue; });
	    if (structuredAttrs.length == 0) {
	        return typeDeclaration.type_original();
	    }
	    var nullify = false;
	    var values = attrs.map(function (x) {
	        var val = x.value();
	        if (typeof (val) == "string") {
	            return val;
	        }
	        else if (val instanceof hlimpl.StructuredValue) {
	            nullify = true;
	        }
	        return val.toString();
	    });
	    if (nullify) {
	        return null;
	    }
	    return values;
	}
	exports.typeValue = typeValue;
	/**
	 * __$helperMethod__ A base type which the current type extends, or more generally a type expression.
	 * __$meta__={"name":"schema","override":true}
	 */
	function schemaValue(typeDeclaration) {
	    var nullify = false;
	    var attrs = typeDeclaration.highLevel().attributes(defs.universesInfo.Universe10.TypeDeclaration.properties.schema.name);
	    if (nullify) {
	        return null;
	    }
	    var structuredAttrs = attrs.filter(function (x) { return x.value() instanceof hlimpl.StructuredValue; });
	    if (structuredAttrs.length == 0) {
	        return typeDeclaration.schema_original();
	    }
	    var values = attrs.map(function (x) {
	        var val = x.value();
	        if (typeof (val) == "string") {
	            return val;
	        }
	        else if (val instanceof hlimpl.StructuredValue) {
	            nullify = true;
	        }
	        return val.toString();
	    });
	    if (nullify) {
	        return null;
	    }
	    return values;
	}
	exports.schemaValue = schemaValue;
	/**
	 * __$helperMethod__ Inlined supertype definition.
	 * __$meta__={"name":"structuredType","primary":true}
	 */
	function typeStructuredValue(typeDeclaration) {
	    var attrs = typeDeclaration.highLevel().attributes(defs.universesInfo.Universe10.TypeDeclaration.properties.type.name);
	    attrs = attrs.concat(typeDeclaration.highLevel().attributes(defs.universesInfo.Universe10.TypeDeclaration.properties.schema.name));
	    var values = attrs.map(function (x) { return x.value(); });
	    for (var _i = 0, values_1 = values; _i < values_1.length; _i++) {
	        var val = values_1[_i];
	        if (val instanceof hlimpl.StructuredValue) {
	            var typeInstance = new core.TypeInstanceImpl(val.lowLevel());
	            return typeInstance;
	        }
	    }
	    return null;
	}
	exports.typeStructuredValue = typeStructuredValue;
	/**
	 * __$helperMethod__
	 * Returns the root node of the AST, uses statement refers.
	 * __$meta__={"name":"ast"}
	 */
	function referencedNode(usesDecl) {
	    var ref = usesDecl.value();
	    var unit = usesDecl.highLevel().lowLevel().unit().resolve(ref);
	    var hlNode = unit.highLevel();
	    var hlElement = hlNode.asElement();
	    if (hlElement) {
	        //we know, only libraries can be referenced from uses
	        var wrapperNode = hlElement.wrapperNode();
	        if (RamlWrapper.isLibrary(wrapperNode)) {
	            wrapperNode.setAttributeDefaults(usesDecl.attributeDefaults());
	            return wrapperNode;
	        }
	        else {
	            return null;
	        }
	    }
	    return null;
	}
	exports.referencedNode = referencedNode;
	function extractParams(params, uri, owner, propName) {
	    var ownerHl = owner.highLevel();
	    var definition = ownerHl.definition();
	    var prop = definition.property(propName);
	    if (!uri) {
	        return [];
	    }
	    var describedParams = {};
	    params.forEach(function (x) {
	        var arr = describedParams[x.name()];
	        if (!arr) {
	            arr = [];
	            describedParams[x.name()] = arr;
	        }
	        arr.push(x);
	    });
	    var allParams = [];
	    var prev = 0;
	    var mentionedParams = {};
	    for (var i = uri.indexOf('{'); i >= 0; i = uri.indexOf('{', prev)) {
	        prev = uri.indexOf('}', ++i);
	        if (prev < 0) {
	            break;
	        }
	        var paramName = uri.substring(i, prev);
	        mentionedParams[paramName] = true;
	        if (describedParams[paramName]) {
	            describedParams[paramName].forEach(function (x) { return allParams.push(x); });
	        }
	        else {
	            var universe = definition.universe();
	            var nc = universe.type(universeDef.Universe10.StringTypeDeclaration.name);
	            var node = stubs.createStubNode(nc, null, paramName);
	            var uriParameter = factory.buildWrapperNode(node);
	            var hlNode = uriParameter.highLevel();
	            hlNode.setParent(ownerHl);
	            uriParameter.meta().setCalculated();
	            uriParameter.setName(paramName);
	            hlNode.patchProp(prop);
	            allParams.push(uriParameter);
	        }
	    }
	    Object.keys(describedParams).filter(function (x) { return !mentionedParams[x]; })
	        .forEach(function (x) { return describedParams[x].forEach(function (y) { return allParams.push(y); }); });
	    return allParams;
	}
	;
	/**
	 * __$helperMethod__
	 * __$meta__={"name":"parametrizedProperties","primary":true}
	 */
	function getTemplateParametrizedProperties(node) {
	    var highLevelNode = node.highLevel();
	    if (highLevelNode == null) {
	        return null;
	    }
	    var lowLevelNode = highLevelNode.lowLevel();
	    if (lowLevelNode == null) {
	        return null;
	    }
	    var children = lowLevelNode.children().filter(function (x) { return x.key().indexOf("<<") >= 0; });
	    if (children.length == 0) {
	        return null;
	    }
	    var result = new core.TypeInstanceImpl(children);
	    return result;
	}
	exports.getTemplateParametrizedProperties = getTemplateParametrizedProperties;
	var SchemaDef = (function () {
	    function SchemaDef(_content, _name) {
	        this._content = _content;
	        this._name = _name;
	    }
	    SchemaDef.prototype.name = function () { return this._name; };
	    SchemaDef.prototype.content = function () { return this._content; };
	    return SchemaDef;
	}());
	exports.SchemaDef = SchemaDef;
	var ParamValue = (function () {
	    function ParamValue(key, value) {
	        this.key = key;
	        this.value = value;
	    }
	    return ParamValue;
	}());
	exports.ParamValue = ParamValue;
	var ParamWrapper = (function () {
	    function ParamWrapper(_param) {
	        this._param = _param;
	        this.description = _param.description() ? _param.description().value() : this.description;
	        this.displayName = _param.displayName();
	        //        this.enum = _param.enum();
	        this.type = _param.type().length > 0 ? _param.type()[0] : "string";
	        this.example = _param.example();
	        this.repeat = _param.repeat();
	        this.required = _param.required();
	        this.default = _param.default();
	    }
	    return ParamWrapper;
	}());
	var ExampleSpecImpl = (function (_super) {
	    __extends(ExampleSpecImpl, _super);
	    function ExampleSpecImpl(hlNode, expandable, _annotations) {
	        _super.call(this, hlNode);
	        this.expandable = expandable;
	        this._annotations = _annotations;
	    }
	    ExampleSpecImpl.prototype.value = function () {
	        if (this.expandable.isJSONString() || this.expandable.isYAML()) {
	            return this.expandable.asJSON();
	        }
	        return this.expandable.original();
	    };
	    ExampleSpecImpl.prototype.structuredValue = function () {
	        var obj = this.value();
	        var llParent = this._node.lowLevel();
	        var key = this.expandable.isSingle() ? "example" : null;
	        var jsonNode = new json.AstNode(llParent.unit(), obj, llParent, null, key);
	        return new core.TypeInstanceImpl(jsonNode);
	    };
	    ExampleSpecImpl.prototype.strict = function () {
	        return this.expandable.strict();
	    };
	    ExampleSpecImpl.prototype.description = function () {
	        var descriptionValue = this.expandable.description();
	        if (descriptionValue == null && descriptionValue !== null) {
	            return null;
	        }
	        var attr = stubs.createAttr(this._node.definition().property(universeDef.Universe10.ExampleSpec.properties.description.name), descriptionValue);
	        var result = new RamlWrapperImpl.MarkdownStringImpl(attr);
	        return result;
	    };
	    ExampleSpecImpl.prototype.name = function () {
	        return this.expandable.name();
	    };
	    ExampleSpecImpl.prototype.displayName = function () {
	        return this.expandable.displayName();
	    };
	    ExampleSpecImpl.prototype.annotations = function () {
	        return this._annotations;
	    };
	    ExampleSpecImpl.prototype.scalarsAnnotations = function () { return {}; };
	    return ExampleSpecImpl;
	}(core.BasicNodeImpl));
	exports.ExampleSpecImpl = ExampleSpecImpl;
	//# sourceMappingURL=wrapperHelper.js.map

/***/ },
/* 33 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var __extends = (this && this.__extends) || function (d, b) {
	    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
	    function __() { this.constructor = d; }
	    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
	};
	exports.rt = __webpack_require__(77);
	var typeSystem = exports.rt.nominalTypes;
	function getSchemaUtils() {
	    return exports.rt.getSchemaUtils();
	}
	exports.getSchemaUtils = getSchemaUtils;
	function registerAdapters(a) {
	    if (a["isUnion"]) {
	        a.addAdapter(new RAMLService(a));
	    }
	    else if (a["range"]) {
	        a.addAdapter(new RAMLPropertyService(a));
	    }
	}
	exports.TOP_LEVEL_EXTRA = exports.rt.TOP_LEVEL_EXTRA;
	exports.DEFINED_IN_TYPES_EXTRA = exports.rt.DEFINED_IN_TYPES_EXTRA;
	exports.USER_DEFINED_EXTRA = exports.rt.USER_DEFINED_EXTRA;
	exports.SOURCE_EXTRA = exports.rt.SOURCE_EXTRA;
	// export function instanceOfHasExtra(instance : any) : instance is rt.IHasExtra {
	//     return rt.instanceOfHasExtra(instance);
	// }
	exports.injector = {
	    inject: function (a) {
	        registerAdapters(a);
	    }
	};
	typeSystem.registerInjector(exports.injector);
	var AbstractType = (function (_super) {
	    __extends(AbstractType, _super);
	    function AbstractType() {
	        _super.apply(this, arguments);
	    }
	    return AbstractType;
	}(typeSystem.AbstractType));
	exports.AbstractType = AbstractType;
	var ValueType = (function (_super) {
	    __extends(ValueType, _super);
	    function ValueType() {
	        _super.apply(this, arguments);
	    }
	    return ValueType;
	}(typeSystem.ValueType));
	exports.ValueType = ValueType;
	var SourceProvider = (function () {
	    function SourceProvider() {
	    }
	    SourceProvider.prototype.getSource = function () {
	        return null;
	    };
	    return SourceProvider;
	}());
	exports.SourceProvider = SourceProvider;
	var EnumType = (function (_super) {
	    __extends(EnumType, _super);
	    function EnumType() {
	        _super.apply(this, arguments);
	        this.values = [];
	    }
	    return EnumType;
	}(ValueType));
	exports.EnumType = EnumType;
	var ReferenceType = (function (_super) {
	    __extends(ReferenceType, _super);
	    function ReferenceType(name, path, referenceTo, _universe) {
	        _super.call(this, name, _universe, path);
	        this.referenceTo = referenceTo;
	    }
	    ReferenceType.prototype.getReferencedType = function () {
	        return this.universe().type(this.referenceTo);
	    };
	    ReferenceType.prototype.hasStructure = function () {
	        return true;
	    };
	    return ReferenceType;
	}(ValueType));
	exports.ReferenceType = ReferenceType;
	var NodeClass = (function (_super) {
	    __extends(NodeClass, _super);
	    function NodeClass(_name, universe, path, _description) {
	        if (_description === void 0) { _description = ""; }
	        _super.call(this, _name, universe, path);
	    }
	    NodeClass.prototype.allProperties = function (v) {
	        if (v === void 0) { v = {}; }
	        return _super.prototype.allProperties.call(this, v);
	    };
	    return NodeClass;
	}(typeSystem.StructuredType));
	exports.NodeClass = NodeClass;
	var UserDefinedClass = (function (_super) {
	    __extends(UserDefinedClass, _super);
	    function UserDefinedClass(name, universe, hl, path, description) {
	        _super.call(this, name, universe, path, description);
	        this.getAdapter(RAMLService).setDeclaringNode(hl);
	    }
	    UserDefinedClass.prototype.key = function () {
	        return null;
	    };
	    UserDefinedClass.prototype.isUserDefined = function () {
	        return true;
	    };
	    UserDefinedClass.prototype.typeId = function () {
	        var rs = this.nameId();
	        var node = this.getAdapter(RAMLService).getDeclaringNode();
	        if (node) {
	            rs = rs + node.lowLevel().start();
	            var unit = node.lowLevel().unit();
	            if (unit) {
	                rs = rs + unit.absolutePath();
	            }
	        }
	        return rs;
	    };
	    UserDefinedClass.prototype.hasValueTypeInHierarchy = function () {
	        if (this._value) {
	            return true;
	        }
	        if (this.isAssignableFrom("ObjectTypeDeclaration")) {
	            return false;
	        }
	        return false;
	    };
	    /**
	     * Returns whether this type contain genuine user defined type in its hierarchy.
	     * Genuine user defined type is a type user intentionally defined and filled with
	     * properties or facets, or having user-defined name as opposed to a synthetic user-defined type.
	     */
	    UserDefinedClass.prototype.isGenuineUserDefinedType = function () {
	        return this.genuineUserDefinedType() != null;
	    };
	    /**
	     * Returns nearest genuine user-define type in the hierarchy.
	     * Genuine user defined type is a type user intentionally defined and filled with
	     * properties or facets, or having user-defined name as opposed to a synthetic user-defined type.
	     */
	    UserDefinedClass.prototype.genuineUserDefinedType = function () {
	        var declaringNode = this.getAdapter(RAMLService).getDeclaringNode();
	        if (!declaringNode) {
	            return null;
	        }
	        return this;
	    };
	    return UserDefinedClass;
	}(NodeClass));
	exports.UserDefinedClass = UserDefinedClass;
	var AnnotationType = (function (_super) {
	    __extends(AnnotationType, _super);
	    function AnnotationType() {
	        _super.apply(this, arguments);
	    }
	    AnnotationType.prototype.allProperties = function (ps) {
	        if (ps === void 0) { ps = {}; }
	        var rs = this.superTypes()[0].allProperties();
	        if (rs.length == 0) {
	            var up = new UserDefinedProp("value");
	            up.withDomain(this);
	            up._node = this.getAdapter(RAMLService).getDeclaringNode();
	            up.withCanBeValue();
	            up.withRequired(false);
	            var tp = this.superTypes()[0];
	            rs = [];
	            up.withRange(up._node.asElement().definition().universe().type("string"));
	            rs.push(up);
	        }
	        return rs;
	    };
	    AnnotationType.prototype.isAnnotationType = function () {
	        return true;
	    };
	    return AnnotationType;
	}(UserDefinedClass));
	exports.AnnotationType = AnnotationType;
	var Universe = (function (_super) {
	    __extends(Universe, _super);
	    function Universe(dec, name, _parent, v) {
	        if (name === void 0) { name = ""; }
	        if (_parent === void 0) { _parent = null; }
	        if (v === void 0) { v = "RAML08"; }
	        _super.call(this, name);
	        this._parent = _parent;
	        this._classes = [];
	        this._uversion = "RAML08";
	        this.aMap = {};
	        this.matchedObjects = dec;
	        this._uversion = v;
	    }
	    Universe.prototype.matched = function () {
	        if (this.matchedObjects) {
	            return this.matchedObjects;
	        }
	        if (this._parent) {
	            return this._parent.matched();
	        }
	    };
	    Universe.prototype.setTopLevel = function (t) {
	        this._topLevel = t;
	    };
	    Universe.prototype.getTopLevel = function () {
	        return this._topLevel;
	    };
	    Universe.prototype.setTypedVersion = function (tv) {
	        this._typedVersion = tv;
	    };
	    Universe.prototype.getTypedVersion = function () {
	        return this._typedVersion;
	    };
	    Universe.prototype.version = function () {
	        return this._uversion;
	    };
	    Universe.prototype.setUniverseVersion = function (version) {
	        this._uversion = version;
	    };
	    Universe.prototype.types = function () {
	        var result = [].concat(this._classes);
	        if (this._parent != null) {
	            result = result.concat(this._parent.types());
	        }
	        return result;
	    };
	    Universe.prototype.type = function (name) {
	        if (this.aMap[name]) {
	            return this.aMap[name];
	        }
	        var tp;
	        for (var i = 0; i < this._classes.length; i++) {
	            if (this._classes[i].nameId() == name) {
	                tp = this._classes[i];
	                break;
	            }
	        }
	        if (tp == null) {
	            if (this._parent) {
	                var tp = this._parent.type(name);
	                if (tp instanceof AbstractType) {
	                    var at = tp;
	                    at._universe = this; //FIXME
	                }
	            }
	        }
	        return tp;
	    };
	    Universe.prototype.register = function (t) {
	        this._classes.push(t);
	        if (t instanceof NodeClass) {
	            this._classes.forEach(function (x) {
	                if (x instanceof NodeClass) {
	                    var nc = x;
	                    if (nc.getAdapter(RAMLService).getExtendedType() == t) {
	                        t.getAdapter(RAMLService).getRuntimeExtenders().push(x);
	                    }
	                }
	            });
	        }
	        return this;
	    };
	    Universe.prototype.registerAlias = function (a, t) {
	        this.aMap[a] = t;
	    };
	    Universe.prototype.unregister = function (t) {
	        this._classes = this._classes.filter(function (x) { return x != t; });
	        var st = t.superTypes();
	        st.forEach(function (x) {
	            var a = x;
	            a._superTypes = a._superTypes.filter(function (x) { return x != t; });
	        });
	        st = t.subTypes();
	        st.forEach(function (x) {
	            var a = x;
	            a._subTypes = a._subTypes.filter(function (x) { return x != t; });
	        });
	        return this;
	    };
	    Universe.prototype.registerSuperClass = function (t0, t1) {
	        var a0 = t0;
	        var a1 = t1;
	        a0._superTypes.push(t1);
	        a1._subTypes.push(t0);
	    };
	    return Universe;
	}(typeSystem.Described));
	exports.Universe = Universe;
	function prop(name, desc, domain, range, custom) {
	    var prop = new Property(name, desc);
	    return prop.withDomain(domain, custom).withRange(range);
	}
	exports.prop = prop;
	var ChildValueConstraint = (function () {
	    function ChildValueConstraint(name, value) {
	        this.name = name;
	        this.value = value;
	    }
	    return ChildValueConstraint;
	}());
	exports.ChildValueConstraint = ChildValueConstraint;
	var Property = (function (_super) {
	    __extends(Property, _super);
	    function Property() {
	        _super.apply(this, arguments);
	        this._isFromParentValue = false;
	        this._isFromParentKey = false;
	        this._key = false;
	        this._declaresFields = false;
	        this._describes = null;
	        this._canBeDuplicator = false;
	        this._allowsNull = false;
	        this._canBeValue = false;
	        this._isInherited = false;
	        this._selfNode = false;
	        this._noDirectParse = false;
	        this._contextReq = [];
	        this.determinesChildValues = [];
	    }
	    Property.prototype.isPrimitive = function () {
	        return this.range().isValueType() && !(this.range() instanceof ReferenceType);
	    };
	    Property.prototype.withNoDirectParse = function () {
	        this._noDirectParse = true;
	    };
	    Property.prototype.isNoDirectParse = function () {
	        return this._noDirectParse;
	    };
	    Property.prototype.withSelfNode = function () {
	        this._selfNode = true;
	    };
	    Property.prototype.isSelfNode = function () {
	        return this._selfNode;
	    };
	    Property.prototype.matchKey = function (k) {
	        if (this._groupName != null) {
	            if (this.isAnnotation()) {
	                if (k.charAt(0) == '(' && k.charAt(k.length - 1) == ')') {
	                    return true;
	                }
	                return false;
	            }
	            return this._groupName == k;
	        }
	        else {
	            return _super.prototype.matchKey.call(this, k);
	        }
	    };
	    Property.prototype.valueDocProvider = function () {
	        return this._vprovider;
	    };
	    Property.prototype.setValueDocProvider = function (v) {
	        this._vprovider = v;
	        return this;
	    };
	    Property.prototype.suggester = function () {
	        return this._suggester;
	    };
	    Property.prototype.setValueSuggester = function (s) {
	        this._suggester = s;
	    };
	    Property.prototype.enumOptions = function () {
	        if (this._enumOptions && typeof this._enumOptions == 'string') {
	            return [this._enumOptions + ""];
	        }
	        return this._enumOptions;
	    };
	    Property.prototype.getOftenKeys = function () {
	        return this._oftenKeys;
	    };
	    Property.prototype.withOftenKeys = function (keys) {
	        this._oftenKeys = keys;
	        return this;
	    };
	    Property.prototype.withCanBeValue = function () {
	        this._canBeValue = true;
	        return this;
	    };
	    Property.prototype.withInherited = function (w) {
	        this._isInherited = w;
	    };
	    Property.prototype.isInherited = function () {
	        return this._isInherited;
	    };
	    Property.prototype.isAllowNull = function () {
	        return this._allowsNull;
	    };
	    Property.prototype.withAllowNull = function () {
	        this._allowsNull = true;
	    };
	    Property.prototype.getCanBeDuplicator = function () {
	        return this._canBeDuplicator;
	    };
	    Property.prototype.canBeValue = function () {
	        return this._canBeValue;
	    };
	    Property.prototype.setCanBeDuplicator = function () {
	        this._canBeDuplicator = true;
	        return true;
	    };
	    Property.prototype.inheritedContextValue = function () {
	        return this._inheritsValueFromContext;
	    };
	    Property.prototype.withInheritedContextValue = function (v) {
	        this._inheritsValueFromContext = v;
	        return this;
	    };
	    Property.prototype.withContextRequirement = function (name, value) {
	        this._contextReq.push({ name: name, value: value });
	    };
	    Property.prototype.getContextRequirements = function () {
	        return this._contextReq;
	    };
	    Property.prototype.withDescribes = function (a) {
	        this._describes = a;
	        return this;
	    };
	    Property.prototype.describesAnnotation = function () {
	        return this._describes != null;
	    };
	    Property.prototype.describedAnnotation = function () {
	        return this._describes;
	    };
	    Property.prototype.isReference = function () {
	        return this.range() instanceof ReferenceType;
	    };
	    Property.prototype.referencesTo = function () {
	        return this.range().getReferencedType();
	    };
	    Property.prototype.newInstanceName = function () {
	        if (this._newInstanceName) {
	            return this._newInstanceName;
	        }
	        return this.range().nameId();
	    };
	    Property.prototype.withThisPropertyDeclaresFields = function (b) {
	        if (b === void 0) { b = true; }
	        this._declaresFields = b;
	        return this;
	    };
	    Property.prototype.isThisPropertyDeclaresTypeFields = function () {
	        return this._declaresFields;
	    };
	    Property.prototype.withNewInstanceName = function (name) {
	        this._newInstanceName = name;
	        return this;
	    };
	    Property.prototype.addChildValueConstraint = function (c) {
	        this.determinesChildValues.push(c);
	    };
	    Property.prototype.getChildValueConstraints = function () {
	        return this.determinesChildValues;
	    };
	    Property.prototype.childRestrictions = function () {
	        return this.determinesChildValues;
	    };
	    Property.prototype.id = function () {
	        if (this._id) {
	            return this._id;
	        }
	        if (!this._groupName) {
	            return null;
	        }
	        if (this.domain().getAdapter(RAMLService).getDeclaringNode()) {
	            return null;
	        }
	        this._id = this._groupName + this.domain().nameId();
	        return this._id;
	    };
	    Property.prototype.isAnnotation = function () {
	        return this._groupName == "annotations" &&
	            this.domain() && !this.domain().isUserDefined();
	    };
	    Property.prototype.withFromParentValue = function (v) {
	        if (v === void 0) { v = true; }
	        this._isFromParentValue = v;
	        return this;
	    };
	    Property.prototype.withFromParentKey = function (v) {
	        if (v === void 0) { v = true; }
	        this._isFromParentKey = v;
	        return this;
	    };
	    Property.prototype.isFromParentKey = function () {
	        return this._isFromParentKey;
	    };
	    Property.prototype.isFromParentValue = function () {
	        return this._isFromParentValue;
	    };
	    Property.prototype.withGroupName = function (gname) {
	        this._groupName = gname;
	        return this;
	    };
	    Property.prototype.unmerge = function () {
	        this._groupName = this.nameId();
	        return this;
	    };
	    Property.prototype.merge = function () {
	        this._groupName = null;
	        return this;
	    };
	    Property.prototype.withKey = function (isKey) {
	        this._key = isKey;
	        return this;
	    };
	    /**
	     * TODO THIS STUFF SHOULD BE MORE ABSTRACT (LATER...)
	     * @param keyShouldStartFrom
	     * @returns {Property}
	     */
	    Property.prototype.isKey = function () {
	        return this._key;
	    };
	    Property.prototype.isMerged = function () {
	        return this._groupName == null;
	    };
	    Property.prototype.groupName = function () {
	        return this._groupName;
	    };
	    Property.prototype.key = function () {
	        //TODO implement that
	        return null;
	    };
	    return Property;
	}(typeSystem.Property));
	exports.Property = Property;
	var UserDefinedProp = (function (_super) {
	    __extends(UserDefinedProp, _super);
	    function UserDefinedProp() {
	        _super.apply(this, arguments);
	    }
	    UserDefinedProp.prototype.withDisplayName = function (name) {
	        this._displayName = name;
	    };
	    UserDefinedProp.prototype.getDisplayName = function () {
	        return this._displayName;
	    };
	    UserDefinedProp.prototype.node = function () {
	        return this._node;
	    };
	    return UserDefinedProp;
	}(Property));
	exports.UserDefinedProp = UserDefinedProp;
	var RAMLPropertyDocumentationService = (function () {
	    function RAMLPropertyDocumentationService() {
	    }
	    RAMLPropertyDocumentationService.prototype.setDocTableName = function (val) {
	        this._documentationTableName = val;
	    };
	    RAMLPropertyDocumentationService.prototype.docTableName = function () {
	        return this._documentationTableName;
	    };
	    RAMLPropertyDocumentationService.prototype.setHidden = function (val) {
	        this._isHidden = val;
	    };
	    RAMLPropertyDocumentationService.prototype.isHidden = function () {
	        return this._isHidden;
	    };
	    RAMLPropertyDocumentationService.prototype.setMarkdownDescription = function (val) {
	        this._markdownDescription = val;
	    };
	    RAMLPropertyDocumentationService.prototype.markdownDescription = function () {
	        return this._markdownDescription;
	    };
	    RAMLPropertyDocumentationService.prototype.setValueDescription = function (val) {
	        this._valueDescription = val;
	    };
	    RAMLPropertyDocumentationService.prototype.valueDescription = function () {
	        return this._valueDescription;
	    };
	    return RAMLPropertyDocumentationService;
	}());
	exports.RAMLPropertyDocumentationService = RAMLPropertyDocumentationService;
	var RAMLPropertyParserService = (function (_super) {
	    __extends(RAMLPropertyParserService, _super);
	    function RAMLPropertyParserService() {
	        _super.apply(this, arguments);
	    }
	    RAMLPropertyParserService.prototype.isSystem = function () {
	        return this._isSystemProperty;
	    };
	    RAMLPropertyParserService.prototype.withSystem = function (s) {
	        this._isSystemProperty = s;
	        return this;
	    };
	    RAMLPropertyParserService.prototype.isEmbedMap = function () {
	        return this._isEmbededMap;
	    };
	    RAMLPropertyParserService.prototype.withEmbedMap = function () {
	        this._isEmbededMap = true;
	        return this;
	    };
	    return RAMLPropertyParserService;
	}(RAMLPropertyDocumentationService));
	exports.RAMLPropertyParserService = RAMLPropertyParserService;
	var RAMLPropertyService = (function (_super) {
	    __extends(RAMLPropertyService, _super);
	    function RAMLPropertyService(_property) {
	        _super.call(this);
	        this._property = _property;
	        this._meta = {};
	        if (!_property) {
	            throw new Error();
	        }
	        _super.call(this);
	    }
	    RAMLPropertyService.prototype.valueDocProvider = function () {
	        return this._property.valueDocProvider();
	    };
	    RAMLPropertyService.prototype.withPropertyGrammarType = function (pt) {
	        this._propertyGrammarType = pt;
	    };
	    RAMLPropertyService.prototype.getPropertyGrammarType = function () {
	        return this._propertyGrammarType;
	    };
	    RAMLPropertyService.prototype.id = function () {
	        return this._property.nameId();
	    };
	    RAMLPropertyService.prototype.range = function () {
	        return this._property.range();
	    };
	    RAMLPropertyService.prototype.domain = function () {
	        return this._property.domain();
	    };
	    RAMLPropertyService.prototype.isAllowNull = function () {
	        return this._property.isAllowNull();
	    };
	    RAMLPropertyService.prototype.referencesTo = function () {
	        return this._property.referencesTo();
	    };
	    RAMLPropertyService.prototype.isReference = function () {
	        return this._property.isReference();
	    };
	    RAMLPropertyService.prototype.nameId = function () {
	        return this._property.nameId();
	    };
	    RAMLPropertyService.prototype.priority = function () {
	        if (this.isKey())
	            return 128;
	        else if (this.isReference())
	            return 64;
	        else if (this.isTypeExpr())
	            return 32;
	        else if (this.nameId() == 'example')
	            return 0;
	        else
	            return -1024;
	    };
	    RAMLPropertyService.prototype.isKey = function () {
	        if (this._property instanceof Property) {
	            return this._property.isKey();
	        }
	        return false;
	    };
	    RAMLPropertyService.prototype.isMerged = function () {
	        if (this._property instanceof Property) {
	            return this._property.isMerged();
	        }
	        return false;
	    };
	    RAMLPropertyService.prototype.isTypeExpr = function () {
	        return this.texpr;
	    };
	    RAMLPropertyService.prototype.isExampleProperty = function () {
	        return this.example;
	    };
	    RAMLPropertyService.prototype.setExample = function (e) {
	        this.example = e;
	    };
	    RAMLPropertyService.prototype.setTypeExpression = function (e) {
	        this.texpr = e;
	    };
	    RAMLPropertyService.prototype.isDescriminating = function () {
	        return this._property.isDescriminator();
	    };
	    RAMLPropertyService.prototype.putMeta = function (key, value) {
	        this._meta[key] = value;
	    };
	    RAMLPropertyService.prototype.meta = function (key) {
	        return this._meta[key];
	    };
	    return RAMLPropertyService;
	}(RAMLPropertyParserService));
	exports.RAMLPropertyService = RAMLPropertyService;
	var RAMLService = (function () {
	    function RAMLService(d) {
	        //!!!
	        this._allowsOptionalProperties = false;
	        this._possibleInterfaces = [];
	        //!!!
	        this._canInherit = [];
	        this._declaredBy = [];
	        //!!!
	        this._aliases = [];
	        //!!!???
	        this._defining = [];
	        this._runtimeExtenders = [];
	        //!!!???
	        this._declaresType = null;
	        //!!!
	        this._isTemplate = false;
	        //!!!
	        this._contextRequirements = [];
	        this._type = d;
	    }
	    RAMLService.prototype.withAllowQuestion = function () {
	        this._allowsOptionalProperties = true;
	    };
	    RAMLService.prototype.getAllowQuestion = function () {
	        return this._allowsOptionalProperties;
	    };
	    RAMLService.prototype.withCanInherit = function (clazz) {
	        this._canInherit.push(clazz);
	    };
	    RAMLService.prototype.getReferenceIs = function () {
	        return this._referenceIs;
	    };
	    RAMLService.prototype.withReferenceIs = function (fname) {
	        this._referenceIs = fname;
	    };
	    RAMLService.prototype.descriminatorValue = function () {
	        if (this.valueRequirements().length == 0) {
	            return this.nameId();
	        }
	        return this.valueRequirements()[0].value;
	    };
	    RAMLService.prototype.getCanInherit = function () {
	        return this._canInherit;
	    };
	    RAMLService.prototype.withAllowAny = function () {
	        this._allowsAnyChildren = true;
	    };
	    RAMLService.prototype.getAllowAny = function () {
	        return this._allowsAnyChildren || this._type.isExternal();
	    };
	    RAMLService.prototype.globallyDeclaredBy = function () {
	        return this._declaredBy;
	    };
	    RAMLService.prototype.setGloballyDeclaredBy = function (c) {
	        this._declaredBy.push(c);
	    };
	    RAMLService.prototype.setDeclaringNode = function (n) {
	        this._node = n;
	    };
	    RAMLService.prototype.nameId = function () {
	        return this._type.nameId();
	    };
	    RAMLService.prototype.universe = function () {
	        return this._type.universe();
	    };
	    RAMLService.prototype.isAssignableFrom = function (name) {
	        return this._type.isAssignableFrom(name);
	    };
	    RAMLService.prototype.setConsumesRefs = function (b) {
	        this._consumesRef = b;
	    };
	    RAMLService.prototype.definingPropertyIsEnough = function (v) {
	        this._defining.push(v);
	    };
	    RAMLService.prototype.getDefining = function () {
	        return this._defining;
	    };
	    RAMLService.prototype.getConsumesRefs = function () {
	        return this._consumesRef;
	    };
	    RAMLService.prototype.addAlias = function (al) {
	        this._aliases.push(al);
	    };
	    RAMLService.prototype.getAliases = function () {
	        return this._aliases;
	    };
	    RAMLService.prototype.valueRequirements = function () {
	        return this._type.valueRequirements();
	    };
	    RAMLService.prototype.isAnnotation = function () {
	        if (this._annotationChecked) {
	            return this._isAnnotation;
	        }
	        this._annotationChecked = true;
	        this._isAnnotation = (this._type.allSuperTypes().some(function (x) { return x.key() && x.key().name == "AnnotationRef"; }));
	        return this._isAnnotation;
	    };
	    RAMLService.prototype.allowValue = function () {
	        if (this._allowsValueSet) {
	            return this._allowsValue;
	        }
	        if (this._type.allProperties().some(function (x) { return x.isFromParentValue() || x.canBeValue(); })) {
	            this._allowsValue = true;
	            this._allowsValueSet = true;
	            return true;
	        }
	        this._allowsValueSet = true;
	        return false;
	    };
	    RAMLService.prototype.key = function () {
	        return this._type.key();
	    };
	    RAMLService.prototype.getRepresentationOf = function () {
	        return this._representationOf;
	    };
	    RAMLService.prototype.getPath = function () {
	        return "";
	    };
	    RAMLService.prototype.isDeclaration = function () {
	        if (this._isTemplate) {
	            return true;
	        }
	        if (this._convertsToGlobal) {
	            return true;
	        }
	        if (this._declaresType) {
	            return true;
	        }
	        if (this.key() && this.key().name === "Library") {
	            return true;
	        }
	        return false;
	    };
	    RAMLService.prototype.isGlobalDeclaration = function () {
	        if (this._actuallyExports) {
	            return true;
	        }
	        if (this._isTemplate) {
	            return true;
	        }
	        if (this._declaresType) {
	            return true;
	        }
	        return false;
	    };
	    RAMLService.prototype.isTypeSystemMember = function () {
	        return this._declaresType != null;
	    };
	    RAMLService.prototype.getExtendedType = function () {
	        return this.universe().type(this._declaresType);
	    };
	    RAMLService.prototype.setInlinedTemplates = function (b) {
	        this._isTemplate = b;
	        return this;
	    };
	    RAMLService.prototype.getRuntimeExtenders = function () {
	        return this._runtimeExtenders;
	    };
	    RAMLService.prototype.isInlinedTemplates = function () {
	        return this._isTemplate;
	    };
	    RAMLService.prototype.setExtendedTypeName = function (name) {
	        this._declaresType = name;
	        var tp = this.universe().type(name);
	        if (tp instanceof NodeClass) {
	            var nc = tp;
	            nc.getAdapter(RAMLService)._runtimeExtenders.push(this._type);
	        }
	    };
	    RAMLService.prototype.getKeyProp = function () {
	        var c = this._type.allProperties();
	        for (var i = 0; i < c.length; i++) {
	            if (c[i].getAdapter(RAMLPropertyService).isKey()) {
	                return c[i];
	            }
	        }
	        return null;
	    };
	    RAMLService.prototype.withActuallyExports = function (pname) {
	        this._actuallyExports = pname;
	    };
	    RAMLService.prototype.withConvertsToGlobal = function (pname) {
	        this._convertsToGlobal = pname;
	    };
	    RAMLService.prototype.getConvertsToGlobal = function () {
	        return this._convertsToGlobal;
	    };
	    RAMLService.prototype.getActuallyExports = function () {
	        return this._actuallyExports;
	    };
	    RAMLService.prototype.isUserDefined = function () {
	        if (this._type instanceof NodeClass) {
	            return this._type.isUserDefined();
	        }
	        if (this._type instanceof AbstractType) {
	            return this._type.isUserDefined();
	        }
	        return false;
	    };
	    RAMLService.prototype.withContextRequirement = function (name, value) {
	        this._contextRequirements.push({ name: name, value: value });
	    };
	    RAMLService.prototype.getContextRequirements = function () {
	        return this._contextRequirements;
	    };
	    RAMLService.prototype.findMembersDeterminer = function () {
	        var c = this._type.allProperties();
	        for (var i = 0; i < c.length; i++) {
	            if (c[i].isThisPropertyDeclaresTypeFields()) {
	                return c[i];
	            }
	        }
	        return null;
	    };
	    RAMLService.prototype.getDeclaringNode = function () {
	        if (this._node)
	            return this._node;
	        else if (this._type) {
	            //if this service have no source registered,
	            //checking if the type has source contributed via extras
	            var sourceNode = this._type.getExtra(exports.SOURCE_EXTRA);
	            if (!sourceNode)
	                return null;
	            if (sourceNode instanceof SourceProvider ||
	                (sourceNode.getSource && typeof (sourceNode.getSource) == "function")) {
	                return sourceNode.getSource();
	            }
	            else {
	                return sourceNode;
	            }
	        }
	        return null;
	    };
	    RAMLService.prototype.registerSupertypes = function (classNames) {
	        var _this = this;
	        var universe = this._type.universe();
	        classNames.forEach(function (x) {
	            var supertype = universe.type(x);
	            if (!supertype) {
	                return;
	            }
	            _this._type.addSuperType(supertype);
	        });
	    };
	    RAMLService.prototype.registerPossibleInterfaces = function (classNames) {
	        var universe = this._type.universe();
	        for (var _i = 0, classNames_1 = classNames; _i < classNames_1.length; _i++) {
	            var x = classNames_1[_i];
	            var supertype = universe.type(x);
	            if (!supertype) {
	                return;
	            }
	            this._possibleInterfaces.push(supertype);
	        }
	    };
	    RAMLService.prototype.possibleInterfaces = function () {
	        return this._possibleInterfaces;
	    };
	    return RAMLService;
	}());
	exports.RAMLService = RAMLService;
	var universes = {};
	var ramlDS = __webpack_require__(52);
	var jsonDefinitions = ramlDS.universeDumps;
	var ts2def = __webpack_require__(53);
	var unDesc = __webpack_require__(54);
	exports.universesInfo = unDesc;
	exports.getUniverse = (function () {
	    var x = function (key) {
	        if (universes[key]) {
	            return universes[key];
	        }
	        var src = jsonDefinitions[key];
	        var universe = ts2def.toDefSystem(src, (key == "RAML08") ? unDesc["Universe08"] : unDesc["Universe10"]);
	        if (universe) {
	            universe.setUniverseVersion(key);
	            universes[key] = universe;
	        }
	        return universe;
	    };
	    x.availableUniverses = function () { return Object.keys(jsonDefinitions); };
	    return x;
	})();
	//# sourceMappingURL=definitionSystem.js.map

/***/ },
/* 34 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var serv = __webpack_require__(33);
	module.exports = serv;
	//# sourceMappingURL=ramlServices.js.map

/***/ },
/* 35 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var ramlDS = __webpack_require__(33);
	module.exports = ramlDS.getUniverse;
	//# sourceMappingURL=universeProvider.js.map

/***/ },
/* 36 */
/***/ function(module, exports, __webpack_require__) {

	module.exports = __WEBPACK_EXTERNAL_MODULE_36__;

/***/ },
/* 37 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var __extends = (this && this.__extends) || function (d, b) {
	    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
	    function __() { this.constructor = d; }
	    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
	};
	var yaml = __webpack_require__(70);
	var json = __webpack_require__(47);
	var stringify = __webpack_require__(62);
	var impl = __webpack_require__(21);
	var universes = __webpack_require__(30);
	var def = __webpack_require__(33);
	var _ = __webpack_require__(61);
	var LowLevelProxyNode = (function () {
	    function LowLevelProxyNode(_parent, _transformer, ramlVersion) {
	        this._parent = _parent;
	        this._transformer = _transformer;
	        this.ramlVersion = ramlVersion;
	    }
	    LowLevelProxyNode.prototype.hasInnerIncludeError = function () {
	        return this._originalNode.hasInnerIncludeError();
	    };
	    LowLevelProxyNode.prototype.keyKind = function () {
	        return this._originalNode.keyKind();
	    };
	    LowLevelProxyNode.prototype.primaryNode = function () {
	        return null;
	    };
	    LowLevelProxyNode.prototype.isAnnotatedScalar = function () {
	        return this._originalNode.isAnnotatedScalar();
	    };
	    LowLevelProxyNode.prototype.actual = function () {
	        if (this._originalNode) {
	            return this._originalNode.actual();
	        }
	        return this;
	    };
	    LowLevelProxyNode.prototype.transformer = function () { return this._transformer; };
	    LowLevelProxyNode.prototype.originalNode = function () {
	        return this._originalNode;
	    };
	    LowLevelProxyNode.prototype.start = function () { return this._originalNode.start(); };
	    LowLevelProxyNode.prototype.end = function () { return this._originalNode.end(); };
	    LowLevelProxyNode.prototype.value = function (toString) {
	        throw new Error('The method must be overridden');
	    };
	    LowLevelProxyNode.prototype.includeErrors = function () { return this._originalNode.includeErrors(); };
	    LowLevelProxyNode.prototype.includePath = function () { return this._originalNode.includePath(); };
	    LowLevelProxyNode.prototype.includeReference = function () { return this._originalNode.includeReference(); };
	    LowLevelProxyNode.prototype.setKeyOverride = function (_key) {
	        this._keyOverride = _key;
	    };
	    LowLevelProxyNode.prototype.key = function () {
	        if (this._keyOverride) {
	            return this._keyOverride;
	        }
	        return this._originalNode.key();
	    };
	    LowLevelProxyNode.prototype.optional = function () {
	        return this.originalNode().optional();
	    };
	    LowLevelProxyNode.prototype.children = function () {
	        throw new Error('The method must be overridden');
	    };
	    LowLevelProxyNode.prototype.parent = function () { return this._parent; };
	    LowLevelProxyNode.prototype.unit = function () { return this._originalNode.unit(); };
	    LowLevelProxyNode.prototype.includeBaseUnit = function () { return this._originalNode.unit(); };
	    LowLevelProxyNode.prototype.anchorId = function () { return this._originalNode.anchorId(); };
	    LowLevelProxyNode.prototype.errors = function () { return this._originalNode.errors(); };
	    LowLevelProxyNode.prototype.anchoredFrom = function () { return this._originalNode.anchoredFrom(); };
	    LowLevelProxyNode.prototype.includedFrom = function () { return this._originalNode.includedFrom(); };
	    LowLevelProxyNode.prototype.visit = function (v) {
	        if (v(this)) {
	            this.children().forEach(function (x) { return x.visit(v); });
	        }
	    };
	    //TODO
	    LowLevelProxyNode.prototype.addChild = function (n) { };
	    //TODO
	    LowLevelProxyNode.prototype.execute = function (cmd) { };
	    //TODO
	    LowLevelProxyNode.prototype.dump = function () { return null; };
	    LowLevelProxyNode.prototype.dumpToObject = function () {
	        var serialized = json.serialize(this);
	        if (this.kind() == yaml.Kind.MAPPING) {
	            var obj = {};
	            obj[this.key()] = serialized;
	            return obj;
	        }
	        return serialized;
	    };
	    LowLevelProxyNode.prototype.keyStart = function () { return this._originalNode.keyStart(); };
	    LowLevelProxyNode.prototype.keyEnd = function () { return this._originalNode.keyEnd(); };
	    LowLevelProxyNode.prototype.valueStart = function () { return this._originalNode.valueStart(); };
	    LowLevelProxyNode.prototype.valueEnd = function () { return this._originalNode.valueEnd(); };
	    LowLevelProxyNode.prototype.isValueLocal = function () { return this._originalNode.isValueLocal(); };
	    LowLevelProxyNode.prototype.kind = function () { return this._originalNode.kind(); };
	    LowLevelProxyNode.prototype.valueKind = function () { return this._originalNode.valueKind(); };
	    LowLevelProxyNode.prototype.show = function (msg) { this._originalNode.show(msg); };
	    LowLevelProxyNode.prototype.setHighLevelParseResult = function (highLevelParseResult) {
	        this._highLevelParseResult = highLevelParseResult;
	    };
	    LowLevelProxyNode.prototype.highLevelParseResult = function () {
	        return this._highLevelParseResult;
	    };
	    LowLevelProxyNode.prototype.setHighLevelNode = function (highLevel) {
	        this._highLevelNode = highLevel;
	    };
	    LowLevelProxyNode.prototype.highLevelNode = function () {
	        if (this._highLevelNode) {
	            return this._highLevelNode;
	        }
	        return this._originalNode.highLevelNode();
	    };
	    LowLevelProxyNode.prototype.text = function (unitText) {
	        throw new Error("not implemented");
	    };
	    LowLevelProxyNode.prototype.copy = function () {
	        throw new Error("not implemented");
	    };
	    LowLevelProxyNode.prototype.markup = function (json) {
	        throw new Error("not implemented");
	    };
	    LowLevelProxyNode.prototype.nodeDefinition = function () {
	        return impl.getDefinitionForLowLevelNode(this);
	    };
	    LowLevelProxyNode.prototype.includesContents = function () {
	        return this._originalNode.includesContents();
	    };
	    return LowLevelProxyNode;
	}());
	exports.LowLevelProxyNode = LowLevelProxyNode;
	var LowLevelCompositeNode = (function (_super) {
	    __extends(LowLevelCompositeNode, _super);
	    function LowLevelCompositeNode(node, parent, transformer, ramlVersion, isPrimary) {
	        if (isPrimary === void 0) { isPrimary = true; }
	        _super.call(this, parent, transformer, ramlVersion);
	        this.isPrimary = isPrimary;
	        //Colliding nodes of the initioal AST
	        this._adoptedNodes = [];
	        var originalParent = this.parent() ? this.parent().originalNode() : null;
	        this._originalNode = new LowLevelValueTransformingNode(node, originalParent, transformer, this.ramlVersion);
	        this._adoptedNodes.push(this._originalNode);
	    }
	    LowLevelCompositeNode.prototype.adoptedNodes = function () {
	        return this._adoptedNodes;
	    };
	    LowLevelCompositeNode.prototype.primaryNode = function () {
	        return this.isPrimary ? this._originalNode : null;
	    };
	    LowLevelCompositeNode.prototype.parent = function () { return this._parent; };
	    LowLevelCompositeNode.prototype.adopt = function (node, transformer) {
	        if (!transformer) {
	            transformer = this._transformer;
	        }
	        var originalParent = this.parent() ? this.parent().originalNode() : null;
	        var tNode = new LowLevelValueTransformingNode(node, originalParent, transformer, this.ramlVersion);
	        this._adoptedNodes.push(tNode);
	        if (this._children) {
	            this._children.forEach(function (x) { return x._parent = null; });
	        }
	        this._children = null;
	        if (this.highLevelNode()) {
	            this.highLevelNode().resetChildren();
	        }
	    };
	    LowLevelCompositeNode.prototype.value = function (toString) {
	        var valuableNodes = this._adoptedNodes.filter(function (x) { return x.value() != null; });
	        if (valuableNodes.length > 0) {
	            return valuableNodes[0].value(toString);
	        }
	        return this._originalNode.value(toString);
	    };
	    LowLevelCompositeNode.prototype.children = function () {
	        var _this = this;
	        if (this._children) {
	            return this._children;
	        }
	        var result = [];
	        var canBeMap = false;
	        var canBeSeq = false;
	        this._adoptedNodes.forEach(function (x) {
	            var adoptedNodeChildren = x.children();
	            if (adoptedNodeChildren && adoptedNodeChildren.length > 0) {
	                canBeSeq = true;
	                if (adoptedNodeChildren[0].key()) {
	                    if (_this.originalNode().valueKind() != yaml.Kind.SEQ) {
	                        canBeMap = true;
	                    }
	                }
	            }
	        });
	        if (canBeMap) {
	            result = this.collectChildrenWithKeys();
	        }
	        else if (canBeSeq) {
	            result = this.collectChildrenWithKeys();
	            var map = {};
	            this._adoptedNodes.forEach(function (x) { return x.children().filter(function (y) { return !y.key(); }).forEach(function (y) {
	                var isPrimary = x == _this.primaryNode();
	                var key = _this.buildKey(y);
	                if (!isPrimary && map[key]) {
	                    //filtering away values with repeating keys
	                    //primary node is not subjected to filtration
	                    return;
	                }
	                map[key] = true;
	                var transformer = x.transformer() ? x.transformer() : _this.transformer();
	                var ch = (y instanceof LowLevelValueTransformingNode)
	                    ? y.originalNode() : y;
	                result.push(new LowLevelCompositeNode(ch, _this, transformer, _this.ramlVersion, isPrimary));
	            }); });
	        }
	        else {
	            result = [];
	        }
	        this._children = result;
	        return result;
	    };
	    LowLevelCompositeNode.prototype.buildKey = function (y) {
	        var obj = json.serialize(y);
	        var def = this.nodeDefinition();
	        if (def && (def.key() == universes.Universe08.TraitRef || def.key() == universes.Universe08.ResourceTypeRef
	            || def.key() == universes.Universe10.TraitRef || def.key() == universes.Universe10.ResourceTypeRef)) {
	            if (typeof obj == 'object') {
	                var keys = Object.keys(obj);
	                if (keys.length > 0) {
	                    obj = keys[0];
	                }
	            }
	        }
	        return stringify(obj);
	    };
	    LowLevelCompositeNode.prototype.collectChildrenWithKeys = function () {
	        var _this = this;
	        var result = [];
	        var m = {};
	        this._adoptedNodes.forEach(function (x) {
	            var isPrimary = x == _this.primaryNode();
	            x.children().forEach(function (y) {
	                var key = y.originalNode().key();
	                if (key && x.transformer()) {
	                    key = x.transformer().transform(key).value;
	                }
	                if (_this.skipKey(key, isPrimary)) {
	                    return;
	                }
	                if (!key) {
	                    return;
	                }
	                var arr = m[key];
	                if (!arr) {
	                    arr = [];
	                    m[key] = arr;
	                }
	                arr.push({ node: y.originalNode(), transformer: x.transformer(), isPrimary: isPrimary });
	            });
	        });
	        var ramlVersion = this.unit().highLevel().root().definition().universe().version();
	        var isResource = this.key() && this.key()[0] == "/";
	        var methodType = def.getUniverse("RAML10").type(universes.Universe10.Method.name);
	        var options = methodType.property(universes.Universe10.Method.properties.method.name).enumOptions();
	        Object.keys(m).forEach(function (key) {
	            var arr = m[key];
	            var allOptional = true;
	            var hasPrimaryChildren = false;
	            var isMethod = options.indexOf(key) >= 0;
	            arr.forEach(function (x) {
	                var isOpt = x.node.optional() &&
	                    (ramlVersion != "RAML10" ||
	                        (isResource && isMethod));
	                allOptional = allOptional && isOpt;
	                hasPrimaryChildren = hasPrimaryChildren || x.isPrimary;
	            });
	            if (hasPrimaryChildren) {
	                var primaryChildren = [];
	                arr.filter(function (x) { return x.isPrimary; }).forEach(function (x) {
	                    var tr = x.transformer ? x.transformer : _this.transformer();
	                    primaryChildren.push(new LowLevelCompositeNode(x.node, _this, tr, _this.ramlVersion, true));
	                });
	                var primaryChild = primaryChildren[0];
	                arr.filter(function (x) { return !x.isPrimary; }).forEach(function (x) {
	                    primaryChild.adopt(x.node, x.transformer);
	                });
	                primaryChildren.forEach(function (x) { return result.push(x); });
	            }
	            else if (!allOptional) {
	                var tr = arr[0].transformer ? arr[0].transformer : _this.transformer();
	                var primaryChild = new LowLevelCompositeNode(arr[0].node, _this, tr, _this.ramlVersion, false);
	                for (var i = 1; i < arr.length; i++) {
	                    primaryChild.adopt(arr[i].node, arr[i].transformer);
	                }
	                result.push(primaryChild);
	            }
	        });
	        return result;
	    };
	    LowLevelCompositeNode.prototype.skipKey = function (key, isPrimary) {
	        if (isPrimary) {
	            return false;
	        }
	        if (this.ramlVersion != 'RAML08') {
	            return false;
	        }
	        var methodDef = universes.Universe08.Method;
	        var resourceDef = universes.Universe08.Resource;
	        //if(key==hasNormalParametersDef.properties.displayName.name
	        //    &&this.highLevelNode().definition().key().name==methodDef.name){
	        //    return true;
	        //}
	        //if(key==resourceDef.properties.displayName.name
	        //    &&this.highLevelNode().definition().key().name==resourceDef.name){
	        //    return true;
	        //}
	        return false;
	    };
	    LowLevelCompositeNode.prototype.valueKind = function () {
	        if (this._originalNode.kind() != yaml.Kind.MAPPING) {
	            return null;
	        }
	        for (var i = 0; i < this._adoptedNodes.length; i++) {
	            var node = this._adoptedNodes[i];
	            var yamlNode = node.originalNode()._node;
	            if (yamlNode && yamlNode.value != null) {
	                return node.valueKind();
	            }
	        }
	        return null;
	    };
	    LowLevelCompositeNode.prototype.includePath = function () {
	        for (var i = 0; i < this._adoptedNodes.length; i++) {
	            var node = this._adoptedNodes[i];
	            var includePath = node.includePath();
	            if (includePath != null) {
	                return includePath;
	            }
	        }
	        return null;
	    };
	    LowLevelCompositeNode.prototype.includeBaseUnit = function () {
	        for (var i = 0; i < this._adoptedNodes.length; i++) {
	            var node = this._adoptedNodes[i];
	            var includePath = node.includePath();
	            if (includePath != null) {
	                return node.unit();
	            }
	        }
	        return _super.prototype.includeBaseUnit.call(this);
	    };
	    LowLevelCompositeNode.prototype.includeReference = function () {
	        for (var i = 0; i < this._adoptedNodes.length; i++) {
	            var node = this._adoptedNodes[i];
	            if (node.value() != null) {
	                return node.includeReference();
	            }
	        }
	        return null;
	    };
	    LowLevelCompositeNode.prototype.optional = function () {
	        return _.all(this._adoptedNodes, function (x) { return x.optional(); });
	    };
	    return LowLevelCompositeNode;
	}(LowLevelProxyNode));
	exports.LowLevelCompositeNode = LowLevelCompositeNode;
	var LowLevelValueTransformingNode = (function (_super) {
	    __extends(LowLevelValueTransformingNode, _super);
	    function LowLevelValueTransformingNode(node, parent, transformer, ramlVersion) {
	        _super.call(this, parent, transformer, ramlVersion);
	        this._originalNode = node;
	    }
	    LowLevelValueTransformingNode.prototype.value = function (toString) {
	        var val = this.originalNode().value(toString);
	        var t = this.transformer();
	        if (t) {
	            var transformationResult = t.transform(val, toString);
	            val = transformationResult.value;
	        }
	        if (val && typeof val === "object") {
	            return new LowLevelValueTransformingNode(val, this._parent, this._transformer, this.ramlVersion);
	        }
	        return val;
	    };
	    LowLevelValueTransformingNode.prototype.children = function () {
	        var _this = this;
	        var childNodes = null;
	        var originalNode = this.originalNode();
	        if (this._transformer != null) {
	            var substitution = this._transformer.children(originalNode);
	            if (substitution != null) {
	                childNodes = substitution;
	            }
	        }
	        if (childNodes == null) {
	            childNodes = originalNode.children();
	        }
	        return childNodes.map(function (x) { return new LowLevelValueTransformingNode(x, _this, _this._transformer, _this.ramlVersion); });
	    };
	    LowLevelValueTransformingNode.prototype.valueKind = function () {
	        var kind = this._transformer && this._transformer.valueKind(this.originalNode());
	        if (kind != null) {
	            return kind;
	        }
	        return _super.prototype.valueKind.call(this);
	    };
	    LowLevelValueTransformingNode.prototype.parent = function () { return this._parent; };
	    LowLevelValueTransformingNode.prototype.key = function () {
	        var key = _super.prototype.key.call(this);
	        if (this.transformer() != null) {
	            return this.transformer().transform(key).value;
	        }
	        return key;
	    };
	    return LowLevelValueTransformingNode;
	}(LowLevelProxyNode));
	exports.LowLevelValueTransformingNode = LowLevelValueTransformingNode;
	//# sourceMappingURL=LowLevelASTProxy.js.map

/***/ },
/* 38 */
/***/ function(module, exports, __webpack_require__) {

	/// <reference path="../../../typings/main.d.ts" />
	"use strict";
	var jsyaml = __webpack_require__(21);
	var defs = __webpack_require__(33);
	var ll = __webpack_require__(11);
	var _ = __webpack_require__(61);
	var yaml = __webpack_require__(70);
	var hlimpl = __webpack_require__(16);
	var universes = __webpack_require__(30);
	var universeHelpers = __webpack_require__(14);
	var services = defs;
	function findLastAttributeIndex(n) {
	    var last = -1;
	    var children = n.lowLevel().children();
	    for (var i = 0; i < children.length; i++) {
	        var node = children[i];
	        if (!node.isMapping())
	            continue;
	        var name = node.asMapping().key.value;
	        var property = n.definition().property(name);
	        if (!property)
	            continue;
	        if (property.isFromParentValue() || property.range().hasValueTypeInHierarchy()) {
	            last = i;
	        }
	    }
	    //console.log('last attr index1: ' + last);
	    return last;
	}
	function findInsertionPointLowLevel(node, llnode, property, attr) {
	    //console.log('LL find insertion: node is attr: ' + attr);
	    var insertionPoint = null;
	    var embed = property && property.getAdapter(services.RAMLPropertyService).isEmbedMap();
	    if (embed && _.find(node.lowLevel().children(), function (x) { return x.key() == property.nameId(); })) {
	        embed = false;
	    }
	    if (attr || embed) {
	        var last = findLastAttribute(node);
	        if (!last) {
	            //insertionPoint = new jsyaml.InsertionPoint(jsyaml.InsertionPointType.START);
	            insertionPoint = jsyaml.InsertionPoint.atStart();
	        }
	        else {
	            insertionPoint = last;
	        }
	    }
	    return insertionPoint;
	}
	function findInsertionPoint(where, node) {
	    //console.log('find insertion point for node (HL): ' + node.property().name() + '; attr: ' + node.isAttr());
	    //console.log('node1: ' + node.lowLevel().text());
	    //always insert attributes at start
	    if (!where.isStub()) {
	        where.clearChildrenCache();
	    }
	    var ch = where.children();
	    var embed = node.property() && node.property().getAdapter(services.RAMLPropertyService).isEmbedMap();
	    if (embed && _.find(where.lowLevel().children(), function (x) { return x.key() == node.property().nameId(); })) {
	        embed = false;
	    }
	    var uh = universeHelpers;
	    if ((node.isAttr() || embed) && !(universeHelpers.isMethodType(where.definition()) && node.property && universeHelpers.isIsProperty(node.property()))) {
	        var toRet = null;
	        for (var i = 0; i < ch.length; i++) {
	            if (!ch[i].isAttr()) {
	                break;
	            }
	            else {
	                toRet = ch[i].lowLevel();
	            }
	        }
	        if (toRet == null) {
	            toRet = where.lowLevel();
	        }
	        return toRet;
	    }
	    else {
	        var pname = node.property().nameId();
	        var cls = where.definition();
	        var props = cls.allProperties();
	        //console.log('class: ' + cls.name());
	        //props.forEach(x=> console.log('  prop: ' + x.name()));
	        var pindex = cls.propertyIndex(pname);
	        if (pindex < 0) {
	            return null;
	        }
	        var llchilds = where.lowLevel().children();
	        //console.log('lookup: ' + pname + ' index: ' + pindex + ' childs: ' + llchilds.length);
	        for (var i = 0; i < llchilds.length; i++) {
	            var llch = llchilds[i];
	            //console.log('  child: ' + llch.kindName());
	            if (!llch.isMapping())
	                continue;
	            var cpnme = llch.asMapping().key.value;
	            var pi = cls.propertyIndex(cpnme);
	            //console.log('  property: ' + cpnme + ' index: ' + pi + ' at pos: ' + i);
	            if (pi > pindex) {
	                //console.log('  property: ' + cpnme + ' - found');
	                var lastok = i - 1;
	                //console.log('lastok: ' + lastok);
	                if (lastok < 0) {
	                    //TODO insert at the very beginning
	                    //console.log('insert to very beginning');
	                    return null;
	                }
	                else {
	                    console.log('insert to node: ' + lastok);
	                    return llchilds[lastok];
	                }
	            }
	            else {
	            }
	        }
	        return null;
	    }
	    //console.log('HL insertion: ' + toRet);
	    //return toRet;
	}
	function removeNodeFrom(source, node) {
	    if (source.isStub()) {
	        if (node instanceof hlimpl.ASTNodeImpl) {
	            var cm = node;
	            if (cm.isInEdit) {
	                return;
	            }
	        }
	        if (!source._children) {
	            return;
	        }
	        source._children = source._children.filter(function (x) { return x != node; });
	        return;
	    }
	    var command = new ll.CompositeCommand();
	    if (node instanceof hlimpl.ASTNodeImpl) {
	        var aNode = node;
	        if (!aNode.property().getAdapter(services.RAMLPropertyService).isMerged()) {
	            if (source.elementsOfKind(aNode.property().nameId()).length == 1) {
	                command.commands.push(ll.removeNode(source.lowLevel(), aNode.lowLevel().parent().parent()));
	            }
	            else {
	                command.commands.push(ll.removeNode(source.lowLevel(), aNode.lowLevel()));
	            }
	        }
	        else {
	            command.commands.push(ll.removeNode(source.lowLevel(), aNode.lowLevel()));
	        }
	    }
	    else {
	        command.commands.push(ll.removeNode(source.lowLevel(), node.lowLevel()));
	    }
	    source.lowLevel().execute(command);
	}
	exports.removeNodeFrom = removeNodeFrom;
	function initEmptyRAMLFile(node) {
	    var llroot = node.lowLevel().root();
	    var command = new ll.CompositeCommand();
	    var newroot = jsyaml.createMap([]);
	    command.commands.push(ll.initRamlFile(node.lowLevel(), newroot));
	    node.lowLevel().execute(command);
	    var root = node.root();
	    //console.log('root: ' + root);
	    root._node = newroot;
	    root.clearChildrenCache();
	}
	exports.initEmptyRAMLFile = initEmptyRAMLFile;
	function setValue(node, value) {
	    if (value == node.value())
	        return;
	    var c = new ll.CompositeCommand();
	    if (typeof value === 'string') {
	        var val = value;
	        //FIXME actually isFromParentKey should be enough in future does not changing it now for safety reasons
	        if (node.property().isFromParentKey() || node.property().isAnnotation()) {
	            if (node.property().isAnnotation()) {
	                val = '(' + val + ')';
	            }
	            c.commands.push(ll.setKey(node.lowLevel(), val));
	        }
	        else {
	            if ((!val || val.length == 0) && !node.isEmbedded()) {
	                c.commands.push(ll.removeNode(node.lowLevel().parent(), node.lowLevel()));
	                node.parent().clearChildrenCache();
	            }
	            else {
	                if (!val)
	                    val = '';
	                c.commands.push(ll.setAttr(node.lowLevel(), val));
	            }
	        }
	    }
	    else {
	        if (node.property().isFromParentKey()) {
	            throw new Error("couldn't set structured value to a key: " + node.property().nameId());
	        }
	        var sval = value;
	        c.commands.push(ll.setAttrStructured(node.lowLevel(), sval));
	    }
	    node.lowLevel().execute(c);
	}
	exports.setValue = setValue;
	function addStringValue(attr, value) {
	    var sc = jsyaml.createScalar(value);
	    var target = attr.lowLevel();
	    //console.log('add to target: ' + target.kindName());
	    if (target.isScalar()) {
	        target = target.parent();
	    }
	    else if (target.isMapping()) {
	    }
	    var command = new ll.CompositeCommand();
	    command.commands.push(ll.insertNode(target, sc, null, true));
	    attr.lowLevel().execute(command);
	    attr.parent().clearChildrenCache();
	}
	exports.addStringValue = addStringValue;
	function addStructuredValue(attr, sv) {
	    //var sc = jsyaml.createScalar(value);
	    var target = attr.lowLevel();
	    //console.log('add to target: ' + target.kindName());
	    if (target.isScalar()) {
	        target = target.parent();
	    }
	    else if (target.isMapping()) {
	        var ln = attr.lowLevel();
	    }
	    var command = new ll.CompositeCommand();
	    command.commands.push(ll.insertNode(target, sv.lowLevel(), null, true));
	    attr.lowLevel().execute(command);
	    attr.parent().clearChildrenCache();
	}
	exports.addStructuredValue = addStructuredValue;
	function removeAttr(attr) {
	    var llparent = attr.lowLevel().parent();
	    if (!attr.property().isMultiValue() && attr.isEmbedded()) {
	        // it's embedded value, need to clean scalar instead
	        //console.log('embedded!');
	        attr.setValue('');
	    }
	    else {
	        var command = new ll.CompositeCommand();
	        command.commands.push(ll.removeNode(llparent, attr.lowLevel()));
	        attr.lowLevel().execute(command);
	        attr.parent().clearChildrenCache();
	    }
	}
	exports.removeAttr = removeAttr;
	function setValues(attr, values) {
	    if (!attr.property().isMultiValue())
	        throw new Error("setValue(string[]) only apply to multi-values properties");
	    var node = attr.parent();
	    if (attr.isEmpty()) {
	    }
	    else {
	        var llnode = node.lowLevel();
	        var attrs = node.attributes(attr.name());
	        attrs.forEach(function (attr) { return attr.remove(); });
	    }
	    if (values.length == 1 && attr.property().isDescriminator()) {
	        node.attrOrCreate(attr.name()).setValue(values[0]);
	    }
	    else {
	        values.forEach(function (val) {
	            return node.attrOrCreate(attr.name()).addValue(val);
	        });
	    }
	}
	exports.setValues = setValues;
	function setKey(node, value) {
	    if (value == node.name())
	        return;
	    var c = new ll.CompositeCommand();
	    c.commands.push(ll.setKey(node.lowLevel(), value));
	    node.lowLevel().execute(c);
	}
	exports.setKey = setKey;
	function createAttr(node, n, v) {
	    var mapping = jsyaml.createMapping(n, v);
	    var map;
	    if (node.definition() && node.definition().isAssignableFrom(universes.Universe10.TypeDeclaration.name)) {
	        if (node.lowLevel() && node.lowLevel().valueKind() === yaml.Kind.SCALAR) {
	            var typePropertyName = universes.Universe10.TypeDeclaration.properties.type.name;
	            var typeMapping = jsyaml.createMapping(typePropertyName, node.lowLevel().value());
	            var command = new ll.CompositeCommand();
	            command.commands.push(ll.setAttr(node.lowLevel(), ""));
	            node.lowLevel().execute(command);
	            command = new ll.CompositeCommand();
	            var insertionPoint = findInsertionPointLowLevel(node, typeMapping, node.definition().property(typePropertyName), true);
	            command.commands.push(ll.insertNode(node.lowLevel(), typeMapping, insertionPoint));
	            node.lowLevel().execute(command);
	        }
	    }
	    //console.log('create attribute: ' + n);
	    if (node.isStub()) {
	        //console.log('create-attr: stub case');
	        var insertionIndex = findLastAttributeIndex(node);
	        //console.log('stub insertion index: ' + insertionIndex);
	        node.lowLevel().addChild(mapping, insertionIndex + 1);
	    }
	    else {
	        //console.log('root: ' + llroot.kindName());
	        if (node.isEmptyRamlFile()) {
	            node.initRamlFile();
	        }
	        //console.log('create-attr: real node case');
	        //node._node.addChild(mapping);
	        //node.clearChildrenCache();
	        var command = new ll.CompositeCommand();
	        var insertionPoint = findInsertionPointLowLevel(node, mapping, node.definition().property(n), true);
	        //command.commands.push(ll.insertNode(node.lowLevel(), mapping, null));
	        //var toseq = node.property().isMultiValue();
	        command.commands.push(ll.insertNode(node.lowLevel(), mapping, insertionPoint));
	        node.lowLevel().execute(command);
	    }
	    node.clearChildrenCache();
	}
	exports.createAttr = createAttr;
	function findLastAttribute(node) {
	    var childs = node.lowLevel().children();
	    var index = findLastAttributeIndex(node);
	    //console.log('last attr index2: ' + index);
	    return (index < 0) ? null : childs[index];
	}
	function addToNode(target, node) {
	    if (!target.isStub() && target.isEmptyRamlFile()) {
	        target.initRamlFile();
	    }
	    var llnode = node.lowLevel();
	    if (!target._children) {
	        target._children = [];
	    }
	    if (!node.property()) {
	        //now we should find correct property;
	        var an = node;
	        var allProps = target.definition().allProperties();
	        var cp = null;
	        allProps.forEach(function (x) {
	            var r = x.range();
	            if (r == an.definition()) {
	                cp = x;
	            }
	            var isOk = _.find(an.definition().allSuperTypes(), function (x) { return x == r; });
	            if (isOk) {
	                cp = x;
	            }
	        });
	        if (!cp) {
	            throw new Error("Unable to find correct child");
	        }
	        else {
	            an.patchProp(cp);
	        }
	    }
	    var insertionPoint = findInsertionPoint(target, node);
	    //console.log('high level op: ' + target.property() + '.add ' + node.property().name());
	    if (insertionPoint) {
	    }
	    //var newLowLevel:ll.ILowLevelASTNode=null;
	    var command = new ll.CompositeCommand();
	    //now we need to understand to which low level node it should go
	    //command.commands.push(ll.insertNode(target.lowLevel(), node.lowLevel()))
	    var insertionTarget = null;
	    if (node.property().getAdapter(services.RAMLPropertyService).isMerged() || node.property().range().hasValueTypeInHierarchy()) {
	        //console.log('CASE 1');
	        //newLowLevel = node.lowLevel();
	        command.commands.push(ll.insertNode(target.lowLevel(), node.lowLevel(), insertionPoint));
	        insertionTarget = target.lowLevel();
	    }
	    else {
	        //console.log('CASE 2');
	        var name = node.property().nameId();
	        var target2 = target.lowLevel();
	        //target.show('TARGET:');
	        //llnode.show('NODE:');
	        var found = target.lowLevel().find(name);
	        insertionTarget = found;
	        if (!found) {
	            //console.log('node not found');
	            var nn = null;
	            //var nn: jsyaml.ASTNode = jsyaml.createSeqNode(name);
	            //var mapping = <yaml.YAMLMapping>nn._actualNode();
	            //var seq: yaml.YAMLSequence = <yaml.YAMLSequence>mapping.value;
	            //if(!seq.items) seq.items = [];
	            //seq.items.push((<jsyaml.ASTNode>node.lowLevel())._actualNode());
	            if (node.property().getAdapter(services.RAMLPropertyService).isEmbedMap()) {
	                var v10 = target.definition().universe().version() == 'RAML10';
	                if (llnode.isValueMap() && v10)
	                    nn = jsyaml.createMapNode(name);
	                else
	                    nn = jsyaml.createSeqNode(name);
	                //console.log('NN: ' + yaml.Kind[nn._actualNode().kind]);
	                nn.addChild(node.lowLevel());
	            }
	            else {
	                nn = jsyaml.createNode(name);
	                nn.addChild(node.lowLevel());
	            }
	            //nn.show('WRAPPED NODE:');
	            //target.show('INSERT WRAPPED NODE TO:');
	            command.commands.push(ll.insertNode(target2, nn, insertionPoint));
	            insertionTarget = target2;
	        }
	        else {
	            //console.log('node found');
	            //found.show('INSERT2: ');
	            if (node.property().getAdapter(services.RAMLPropertyService).isEmbedMap()) {
	                //newLowLevel=node.lowLevel();
	                command.commands.push(ll.insertNode(found, node.lowLevel(), insertionPoint, true));
	            }
	            else {
	                //newLowLevel=node.lowLevel();
	                command.commands.push(ll.insertNode(found, node.lowLevel(), insertionPoint, false));
	            }
	        }
	    }
	    if (target.isStub()) {
	        var insertionIndex = findLastAttributeIndex(target);
	        if (insertionIndex < 0) {
	            target._children.push(node);
	        }
	        else {
	            //TODO behavior should be smarter we are ignoring insertion points now
	            target._children.splice(insertionIndex, 0, node);
	        }
	        command.commands.forEach(function (x) { return insertionTarget.addChild(x.value); });
	        return;
	    }
	    target.lowLevel().execute(command);
	    target._children.push(node);
	    //now we need to add new child to our children;
	    node.setParent(target);
	}
	exports.addToNode = addToNode;
	//# sourceMappingURL=mutators.js.map

/***/ },
/* 39 */
/***/ function(module, exports, __webpack_require__) {

	/// <reference path="../../../typings/main.d.ts" />
	"use strict";
	var __extends = (this && this.__extends) || function (d, b) {
	    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
	    function __() { this.constructor = d; }
	    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
	};
	var defs = __webpack_require__(33);
	var ramlTypes = defs.rt;
	var _ = __webpack_require__(61);
	var universes = __webpack_require__(30);
	var hlimpl = __webpack_require__(16);
	var services = defs;
	var linter = __webpack_require__(25);
	var universeHelpers = __webpack_require__(14);
	ramlTypes.setPropertyConstructor(function (x) {
	    var v = new defs.Property(x);
	    v.unmerge();
	    return v;
	});
	function templateFields(node, d) {
	    var u = node.root().definition().universe();
	    var key = node.lowLevel().key();
	    if (key) {
	        handleValue(key, d, null, true, u);
	    }
	    node.children().forEach(function (x) { return templateFields(x, d); });
	    if (node instanceof hlimpl.ASTPropImpl) {
	        var prop = node;
	        //TODO RECURSIVE PARAMETERS
	        var v = prop.value();
	        if (typeof v == 'string') {
	            var strV = v;
	            handleValue(strV, d, prop, false, u);
	        }
	        else {
	            node.lowLevel().visit(function (x) {
	                if (x.value()) {
	                    var strV = x.value() + "";
	                    handleValue(strV, d, prop, true, u);
	                }
	                return true;
	            });
	        }
	    }
	    else if (node instanceof hlimpl.BasicASTNode) {
	        var v = node.lowLevel().value();
	        if (typeof v == 'string') {
	            var strV = v;
	            handleValue(strV, d, null, false, u);
	        }
	        else {
	            node.lowLevel().visit(function (x) {
	                if (x.value()) {
	                    var strV = x.value() + "";
	                    handleValue(strV, d, null, true, u);
	                }
	                return true;
	            });
	        }
	    }
	}
	var extractUsedParamNames = function (strV) {
	    var parameterUsages = [];
	    var ps = 0;
	    while (true) {
	        var pos = strV.indexOf("<<", ps);
	        if (pos == -1) {
	            break;
	        }
	        var end = strV.indexOf(">>", pos);
	        var isFull = pos == 0 && end == strV.length - 2;
	        var parameterUsage = strV.substring(pos + 2, end);
	        ps = pos + 2;
	        var directiveIndex = parameterUsage.indexOf("|");
	        if (directiveIndex != -1) {
	            parameterUsage = parameterUsage.substring(0, directiveIndex);
	        }
	        parameterUsage = parameterUsage.trim();
	        parameterUsages.push(parameterUsage);
	    }
	    return { parameterUsages: parameterUsages, isFull: isFull };
	};
	var handleValue = function (strV, d, prop, allwaysString, u) {
	    var __ret = extractUsedParamNames(strV);
	    var parameterUsages = __ret.parameterUsages;
	    var isFull = __ret.isFull;
	    var r = (prop) ? prop.property().range() : null;
	    if (prop) {
	        if (prop.property().nameId() == universes.Universe10.TypeDeclaration.properties.type.name ||
	            prop.property().nameId() == universes.Universe10.TypeDeclaration.properties.schema.name) {
	            if (prop.property().domain().key() == universes.Universe10.TypeDeclaration) {
	                r = u.type(universes.Universe10.SchemaString.name);
	            }
	        }
	    }
	    if (!isFull || allwaysString) {
	        r = u.type(universes.Universe10.StringType.name);
	    }
	    else if (r == null && u.version() == "RAML10") {
	        r = u.type(universes.Universe10.AnyType.name);
	    }
	    for (var _i = 0, parameterUsages_1 = parameterUsages; _i < parameterUsages_1.length; _i++) {
	        var parameterUsage = parameterUsages_1[_i];
	        if (linter.RESERVED_TEMPLATE_PARAMETERS[parameterUsage] != null) {
	            //Handling reserved parameter names;
	            continue;
	        }
	        var q = d[parameterUsage];
	        //FIX ME NOT WHOLE TEMPLATES
	        if (q) {
	            q.push({
	                tp: r,
	                attr: prop
	            });
	        }
	        else {
	            d[parameterUsage] = [{
	                    tp: r,
	                    attr: prop
	                }];
	        }
	    }
	};
	function fillParamPaths(node, paramPaths, path) {
	    if (path === void 0) { path = []; }
	    if (node.optional()) {
	        path = path.concat("/");
	    }
	    var v = node.value();
	    if (typeof v == 'string') {
	        var strV = v;
	        var __ret = extractUsedParamNames(strV);
	        var parameterUsages = __ret.parameterUsages;
	        for (var _i = 0, parameterUsages_2 = parameterUsages; _i < parameterUsages_2.length; _i++) {
	            var pu = parameterUsages_2[_i];
	            var paths = paramPaths[pu];
	            if (paths == null) {
	                paths = [];
	                paramPaths[pu] = paths;
	            }
	            paths.push(path);
	        }
	    }
	    else {
	        for (var _a = 0, _b = node.children(); _a < _b.length; _a++) {
	            var ch = _b[_a];
	            fillParamPaths(ch, paramPaths, path.concat(ch.key()));
	        }
	    }
	}
	function fillTemplateType(result, node) {
	    var usages = {};
	    var paramPaths = {};
	    templateFields(node, usages);
	    fillParamPaths(node.lowLevel(), paramPaths);
	    for (var _i = 0, _a = Object.keys(paramPaths); _i < _a.length; _i++) {
	        var pu = _a[_i];
	        paramPaths[pu] = _.unique(paramPaths[pu]);
	    }
	    result.getAdapter(services.RAMLService).setInlinedTemplates(true);
	    Object.keys(usages).forEach(function (x) {
	        var prop = new defs.UserDefinedProp(x);
	        //prop._node=node;
	        prop.withDomain(result);
	        var paths = paramPaths[x];
	        prop.getAdapter(services.RAMLPropertyService).putMeta("templatePaths", paths);
	        var defaultType;
	        if (node.definition().universe().version() == "RAML10") {
	            var hasString = usages[x].filter(function (y) { return universeHelpers.isStringTypeType(y.tp); }).length > 0;
	            defaultType = hasString ? universes.Universe10.StringType.name : universes.Universe10.AnyType.name;
	        }
	        else {
	            defaultType = universes.Universe08.StringType.name;
	        }
	        var tp = _.unique(usages[x].map(function (x) { return x.tp; })).filter(function (x) { return x && x.nameId() != defaultType; });
	        prop.withRange(tp.length == 1 ? tp[0] : node.definition().universe().type(defaultType));
	        prop.withRequired(true);
	        if (usages[x].length > 0) {
	            prop._node = usages[x][0].attr;
	        }
	        if (tp.length == 1 && node.definition().universe().version() == 'RAML10') {
	            if (tp[0].key() == universes.Universe10.SchemaString) {
	                prop.getAdapter(services.RAMLPropertyService).setTypeExpression(true);
	            }
	        }
	        prop.unmerge();
	    });
	    var keyProp = new defs.UserDefinedProp("____key");
	    //prop._node=node;
	    keyProp.withDomain(result);
	    keyProp.withKey(true);
	    keyProp._node = node;
	    keyProp.withFromParentKey(true);
	    keyProp.withRange(node.definition().universe().type(universes.Universe08.StringType.name));
	    return result;
	}
	function fillReferenceType(result, def) {
	    if (def.universe().version() == "RAML08") {
	        result.getAdapter(services.RAMLService).withAllowAny();
	    }
	    var p = def.property(def.getAdapter(services.RAMLService).getReferenceIs());
	    if (p) {
	        p.range().properties().forEach(function (x) {
	            var prop = new defs.Property(x.nameId());
	            prop.unmerge();
	            prop.withDomain(result);
	            prop.withRange(x.range());
	            prop.withMultiValue(x.isMultiValue());
	        });
	    }
	    return result;
	}
	var AnnotationType = (function (_super) {
	    __extends(AnnotationType, _super);
	    function AnnotationType() {
	        _super.apply(this, arguments);
	    }
	    AnnotationType.prototype.allProperties = function (ps) {
	        if (ps === void 0) { ps = {}; }
	        var rs = this.superTypes()[0].allProperties();
	        if (rs.length == 1 && rs[0].nameId() == "annotations") {
	            var up = new defs.UserDefinedProp("value");
	            up.withDomain(this);
	            up._node = this.getAdapter(defs.RAMLService).getDeclaringNode();
	            up.withCanBeValue();
	            up.withRequired(false);
	            var tp = this.superTypes()[0];
	            rs = [];
	            up.withRange(up._node.asElement().definition().universe().type("string"));
	            rs.push(up);
	        }
	        return rs;
	    };
	    AnnotationType.prototype.isAnnotationType = function () {
	        return true;
	    };
	    return AnnotationType;
	}(defs.UserDefinedClass));
	function typeFromNode(node) {
	    if (!node) {
	        return null;
	    }
	    if (node.associatedType()) {
	        return node.associatedType();
	    }
	    var u = node.lowLevel().unit();
	    var upath = u ? u.path() : "";
	    ramlTypes.setPropertyConstructor(function (x) {
	        var v = new defs.UserDefinedProp(x);
	        var rs = node.elementsOfKind("properties").filter(function (y) { return y.name() == x; });
	        if (rs) {
	            v._node = rs[0];
	        }
	        v.unmerge();
	        return v;
	    });
	    try {
	        var def = node.definition();
	        if (node.property() && node.property().nameId() == universes.Universe10.LibraryBase.properties.annotationTypes.name) {
	            //var st=node.definition().getAdapter(services.RAMLService).toRuntime();
	            var result = new AnnotationType(node.name(), node.definition().universe(), node, upath, "");
	            var st = getSimpleType(node);
	            result._superTypes.push(st);
	            if (node.elementsOfKind(universes.Universe10.ObjectTypeDeclaration.properties.properties.name).length == 0) {
	                result.getAdapter(services.RAMLService).withAllowAny();
	            }
	            var extType = def.getAdapter(services.RAMLService).getExtendedType();
	            if (extType) {
	                result._superTypes.push(extType);
	            }
	            return result;
	        }
	        else {
	            var result = new defs.UserDefinedClass(node.name(), node.definition().universe(), node, upath, "");
	        }
	        node.setAssociatedType(result);
	        //result.setDeclaringNode(node);
	        if (def.getAdapter(services.RAMLService).isInlinedTemplates()) {
	            return fillTemplateType(result, node);
	        }
	        else if (def.getAdapter(services.RAMLService).getReferenceIs()) {
	            return fillReferenceType(result, def);
	        }
	        var rs = getSimpleType(node);
	        rs.getAdapter(services.RAMLService).setDeclaringNode(node);
	        node.setAssociatedType(rs);
	    }
	    finally {
	        ramlTypes.setPropertyConstructor(null);
	    }
	    return rs;
	}
	exports.typeFromNode = typeFromNode;
	function getSimpleType(node) {
	    return ramlTypes.toNominal(node.parsedType(), function (x) {
	        var m = node.definition().universe().type(x);
	        if (!m) {
	            var ut = new defs.UserDefinedClass("", node.definition().universe(), node, "", "");
	        }
	        return m;
	    });
	}
	function transform(u) {
	    return function (x) {
	        var m = u.type(x);
	        if (!m) {
	            var ut = new defs.UserDefinedClass("", u, null, "", "");
	        }
	        return m;
	    };
	}
	function convertType(root, t) {
	    var node = _.find(root.elementsOfKind("types"), function (x) { return x.name() == t.name(); });
	    if (node) {
	        ramlTypes.setPropertyConstructor(function (x) {
	            var v = new defs.UserDefinedProp(x);
	            var rs = node.elementsOfKind("properties").filter(function (y) { return y.name() == x; });
	            if (rs && rs.length > 0) {
	                v._node = rs[0];
	            }
	            else {
	                var rs = node.elementsOfKind("facets").filter(function (y) { return y.name() == x; });
	                if (rs && rs.length > 0) {
	                    v._node = rs[0];
	                }
	            }
	            v.unmerge();
	            return v;
	        });
	    }
	    var u = transform(root.definition().universe());
	    return ramlTypes.toNominal(t, u);
	}
	exports.convertType = convertType;
	//# sourceMappingURL=typeBuilder.js.map

/***/ },
/* 40 */
/***/ function(module, exports, __webpack_require__) {

	/// <reference path="../../typings/main.d.ts" />
	"use strict";
	function isMultiLine(s) {
	    return s && s.indexOf('\n') >= 0;
	}
	exports.isMultiLine = isMultiLine;
	function isMultiLineValue(s) {
	    return isMultiLine(s) && s.length > 2 && s[0] == '|' && (s[1] == '\n' || s[1] == '\r' || s[2] == '\n');
	}
	exports.isMultiLineValue = isMultiLineValue;
	function makeMutiLine(s, lev) {
	    var xbuf = '';
	    if (isMultiLine(s)) {
	        xbuf += '|\n';
	        var lines = splitOnLines(s);
	        for (var i = 0; i < lines.length; i++) {
	            xbuf += indent(lev, lines[i]);
	        }
	    }
	    else {
	        xbuf += s;
	    }
	    return xbuf;
	}
	exports.makeMutiLine = makeMutiLine;
	function fromMutiLine(s) {
	    if (!isMultiLineValue(s))
	        return s;
	    var res = null;
	    var lines = splitOnLines(s);
	    for (var i = 1; i < lines.length; i++) {
	        var line = lines[i];
	        var str = line.substring(2);
	        if (!res)
	            res = str;
	        else
	            res += str;
	    }
	    return res;
	}
	exports.fromMutiLine = fromMutiLine;
	function trimStart(s) {
	    if (!s)
	        return s;
	    var pos = 0;
	    while (pos < s.length) {
	        var ch = s[pos];
	        if (ch != '\r' && ch != '\n' && ch != ' ' && ch != '\t')
	            break;
	        pos++;
	    }
	    return s.substring(pos, s.length);
	}
	exports.trimStart = trimStart;
	function indent(lev, str) {
	    if (str === void 0) { str = ''; }
	    var leading = '';
	    //leading += '[' + lev + ']';
	    for (var i = 0; i < lev; i++)
	        leading += '  ';
	    return leading + str;
	}
	exports.indent = indent;
	function print(lev, str) {
	    if (str === void 0) { str = ''; }
	    console.log(indent(lev, str));
	}
	exports.print = print;
	function replaceNewlines(s, rep) {
	    if (rep === void 0) { rep = null; }
	    var res = '';
	    for (var i = 0; i < s.length; i++) {
	        var ch = s[i];
	        if (ch == '\r')
	            ch = rep == null ? '\\r' : rep;
	        if (ch == '\n')
	            ch = rep == null ? '\\n' : rep;
	        res += ch;
	    }
	    return res;
	}
	exports.replaceNewlines = replaceNewlines;
	function trimEnd(s) {
	    var pos = s.length;
	    while (pos > 0) {
	        var ch = s[pos - 1];
	        if (ch != ' ' && ch != '\t' && ch != '\r' && ch != '\n')
	            break;
	        pos--;
	    }
	    return s.substring(0, pos);
	}
	exports.trimEnd = trimEnd;
	function trim(s) {
	    return trimStart(trimEnd(s));
	}
	exports.trim = trim;
	function splitOnLines(text) {
	    var lines = text.match(/^.*((\r\n|\n|\r)|$)/gm);
	    return lines;
	}
	exports.splitOnLines = splitOnLines;
	function startsWith(s, suffix) {
	    if (!s || !suffix || s.length < suffix.length)
	        return false;
	    for (var i = 0; i < suffix.length; i++) {
	        if (s[i] != suffix[i])
	            return false;
	    }
	    return true;
	}
	exports.startsWith = startsWith;
	function endsWith(s, suffix) {
	    if (!s || !suffix || s.length < suffix.length)
	        return false;
	    for (var i = 0; i < suffix.length; i++) {
	        if (s[s.length - 1 - i] != suffix[suffix.length - 1 - i])
	            return false;
	    }
	    return true;
	}
	exports.endsWith = endsWith;
	function capitalize(s) {
	    return s.charAt(0).toUpperCase() + s.slice(1);
	}
	exports.capitalize = capitalize;
	var TextRange = (function () {
	    function TextRange(contents, start, end) {
	        this.contents = contents;
	        this.start = start;
	        this.end = end;
	    }
	    TextRange.prototype.text = function () {
	        return this.contents.substring(this.start, this.end);
	    };
	    TextRange.prototype.startpos = function () { return this.start; };
	    TextRange.prototype.endpos = function () { return this.end; };
	    TextRange.prototype.len = function () { return this.end - this.start; };
	    TextRange.prototype.unitText = function () { return this.contents; };
	    TextRange.prototype.withStart = function (start) {
	        return new TextRange(this.contents, start, this.end);
	    };
	    TextRange.prototype.withEnd = function (end) {
	        return new TextRange(this.contents, this.start, end);
	    };
	    TextRange.prototype.sub = function (start, end) {
	        return this.contents.substring(start, end);
	    };
	    TextRange.prototype.trimStart = function () {
	        var pos = this.start;
	        while (pos < this.contents.length - 1) {
	            var ch = this.contents[pos];
	            if (ch != ' ' && ch != '\t')
	                break;
	            pos++;
	        }
	        return new TextRange(this.contents, pos, this.end);
	    };
	    TextRange.prototype.trimEnd = function () {
	        var pos = this.end;
	        while (pos > 0) {
	            var ch = this.contents[pos - 1];
	            if (ch != ' ' && ch != '\t')
	                break;
	            pos--;
	        }
	        return new TextRange(this.contents, this.start, pos);
	    };
	    TextRange.prototype.extendToStartOfLine = function () {
	        var pos = this.start;
	        while (pos > 0) {
	            var prevchar = this.contents[pos - 1];
	            if (prevchar == '\r' || prevchar == '\n')
	                break;
	            pos--;
	        }
	        return new TextRange(this.contents, pos, this.end);
	    };
	    TextRange.prototype.extendAnyUntilNewLines = function () {
	        var pos = this.end;
	        if (pos > 0) {
	            var last = this.contents[pos - 1];
	            if (last == '\n')
	                return this;
	        }
	        while (pos < this.contents.length - 1) {
	            var nextchar = this.contents[pos];
	            if (nextchar == '\r' || nextchar == '\n')
	                break;
	            pos++;
	        }
	        return new TextRange(this.contents, this.start, pos);
	    };
	    TextRange.prototype.extendSpacesUntilNewLines = function () {
	        var pos = this.end;
	        if (pos > 0) {
	            var last = this.contents[pos - 1];
	            if (last == '\n')
	                return this;
	        }
	        while (pos < this.contents.length - 1) {
	            var nextchar = this.contents[pos];
	            if (nextchar != ' ' || nextchar == '\r' || nextchar == '\n')
	                break;
	            pos++;
	        }
	        return new TextRange(this.contents, this.start, pos);
	    };
	    TextRange.prototype.extendSpaces = function () {
	        var pos = this.end;
	        while (pos < this.contents.length - 1) {
	            var nextchar = this.contents[pos];
	            if (nextchar != ' ')
	                break;
	            pos++;
	        }
	        return new TextRange(this.contents, this.start, pos);
	    };
	    TextRange.prototype.extendSpacesBack = function () {
	        var pos = this.start;
	        while (pos > 0) {
	            var nextchar = this.contents[pos - 1];
	            if (nextchar != ' ')
	                break;
	            pos--;
	        }
	        return new TextRange(this.contents, pos, this.end);
	    };
	    TextRange.prototype.extendCharIfAny = function (ch) {
	        var pos = this.end;
	        if (pos < this.contents.length - 1 && this.contents[pos] == ch) {
	            pos++;
	        }
	        return new TextRange(this.contents, this.start, pos);
	    };
	    TextRange.prototype.extendCharIfAnyBack = function (ch) {
	        var pos = this.start;
	        if (pos > 0 && this.contents[pos - 1] == ch) {
	            pos--;
	        }
	        return new TextRange(this.contents, pos, this.end);
	    };
	    TextRange.prototype.extendToNewlines = function () {
	        var pos = this.end;
	        if (pos > 0) {
	            var last = this.contents[pos - 1];
	            if (last == '\n')
	                return this;
	        }
	        while (pos < this.contents.length - 1) {
	            var nextchar = this.contents[pos];
	            if (nextchar != '\r' && nextchar != '\n')
	                break;
	            pos++;
	        }
	        return new TextRange(this.contents, this.start, pos);
	    };
	    TextRange.prototype.extendUntilNewlinesBack = function () {
	        var pos = this.start;
	        while (pos > 0) {
	            var nextchar = this.contents[pos - 1];
	            if (nextchar == '\r' || nextchar == '\n')
	                break;
	            pos--;
	        }
	        return new TextRange(this.contents, pos, this.end);
	    };
	    TextRange.prototype.reduceNewlinesEnd = function () {
	        var pos = this.end;
	        while (pos > this.start) {
	            var last = this.contents[pos - 1];
	            if (last != '\r' && last != '\n')
	                break;
	            pos--;
	        }
	        return new TextRange(this.contents, this.start, pos);
	    };
	    TextRange.prototype.reduceSpaces = function () {
	        var pos = this.end;
	        while (pos > this.start) {
	            var last = this.contents[pos - 1];
	            if (last != ' ')
	                break;
	            pos--;
	        }
	        return new TextRange(this.contents, this.start, pos);
	    };
	    TextRange.prototype.replace = function (text) {
	        return this.sub(0, this.start) + text + this.sub(this.end, this.unitText().length);
	    };
	    TextRange.prototype.remove = function () {
	        return this.sub(0, this.start) + this.sub(this.end, this.unitText().length);
	    };
	    return TextRange;
	}());
	exports.TextRange = TextRange;
	//# sourceMappingURL=textutil.js.map

/***/ },
/* 41 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var RamlWrapper = __webpack_require__(28);
	/**
	 * @hidden
	 * Build Wrapper node corresponding to the High Level node
	 **/
	function buildWrapperNode(node, setAsTopLevel) {
	    if (setAsTopLevel === void 0) { setAsTopLevel = true; }
	    var definition = node.definition();
	    var nodeClassName = definition.nameId();
	    var wrapperConstructor = classMap[nodeClassName];
	    if (!wrapperConstructor) {
	        var priorities = determineSuperclassesPriorities(definition);
	        var superTypes = definition.allSuperTypes().sort(function (x, y) { return priorities[x.nameId()] - priorities[y.nameId()]; });
	        var wr = null;
	        for (var i = 0; i < superTypes.length; i++) {
	            var superTypeName = superTypes[i].nameId();
	            wrapperConstructor = classMap[superTypeName];
	            if (superTypeName == "DataElement") {
	                wr = superTypeName;
	                //This is only case of nested hierarchy
	                continue;
	            }
	            if (superTypeName == "hl.BasicNode") {
	                //depth first
	                continue;
	            }
	            if (wrapperConstructor) {
	                break;
	            }
	        }
	        if (!wrapperConstructor) {
	            wr = superTypeName;
	        }
	    }
	    if (!wrapperConstructor) {
	        wrapperConstructor = classMap["hl.BasicNode"];
	    }
	    return wrapperConstructor(node, setAsTopLevel);
	}
	exports.buildWrapperNode = buildWrapperNode;
	function determineSuperclassesPriorities(td, priorities, path) {
	    if (priorities === void 0) { priorities = {}; }
	    if (path === void 0) { path = {}; }
	    var typeName = td.nameId();
	    if (path[typeName]) {
	        return;
	    }
	    path[typeName] = true;
	    var rank = (priorities[typeName] != null && priorities[typeName] + 1) || 0;
	    var superTypes = td.superTypes();
	    superTypes.forEach(function (x) {
	        var name = x.nameId();
	        var r = priorities[name];
	        if (r == null || rank > r) {
	            priorities[name] = rank;
	            determineSuperclassesPriorities(x, priorities, path);
	        }
	    });
	    delete path[typeName];
	    return priorities;
	}
	var classMap = {
	    "AbstractSecurityScheme": function (x, y) { return new RamlWrapper.AbstractSecuritySchemeImpl(x, y); },
	    "Annotable": function (x, y) { return new RamlWrapper.AnnotableImpl(x, y); },
	    "AnnotationRef": function (x) { return new RamlWrapper.AnnotationRefImpl(x); },
	    "AnnotationTarget": function (x) { return new RamlWrapper.AnnotationTargetImpl(x); },
	    "AnyType": function (x) { return new RamlWrapper.AnyTypeImpl(x); },
	    "Api": function (x, y) { return new RamlWrapper.ApiImpl(x, y); },
	    "ArrayTypeDeclaration": function (x, y) { return new RamlWrapper.ArrayTypeDeclarationImpl(x, y); },
	    "BasicSecurityScheme": function (x, y) { return new RamlWrapper.BasicSecuritySchemeImpl(x, y); },
	    "BooleanType": function (x) { return new RamlWrapper.BooleanTypeImpl(x); },
	    "BooleanTypeDeclaration": function (x, y) { return new RamlWrapper.BooleanTypeDeclarationImpl(x, y); },
	    "ContentType": function (x) { return new RamlWrapper.ContentTypeImpl(x); },
	    "CustomSecurityScheme": function (x, y) { return new RamlWrapper.CustomSecuritySchemeImpl(x, y); },
	    "DateOnlyType": function (x) { return new RamlWrapper.DateOnlyTypeImpl(x); },
	    "DateOnlyTypeDeclaration": function (x, y) { return new RamlWrapper.DateOnlyTypeDeclarationImpl(x, y); },
	    "DateTimeOnlyType": function (x) { return new RamlWrapper.DateTimeOnlyTypeImpl(x); },
	    "DateTimeOnlyTypeDeclaration": function (x, y) { return new RamlWrapper.DateTimeOnlyTypeDeclarationImpl(x, y); },
	    "DateTimeType": function (x) { return new RamlWrapper.DateTimeTypeImpl(x); },
	    "DateTimeTypeDeclaration": function (x, y) { return new RamlWrapper.DateTimeTypeDeclarationImpl(x, y); },
	    "DateTypeDeclaration": function (x, y) { return new RamlWrapper.DateTypeDeclarationImpl(x, y); },
	    "DigestSecurityScheme": function (x, y) { return new RamlWrapper.DigestSecuritySchemeImpl(x, y); },
	    "DocumentationItem": function (x, y) { return new RamlWrapper.DocumentationItemImpl(x, y); },
	    "Extension": function (x, y) { return new RamlWrapper.ExtensionImpl(x, y); },
	    "FileType": function (x) { return new RamlWrapper.FileTypeImpl(x); },
	    "FileTypeDeclaration": function (x, y) { return new RamlWrapper.FileTypeDeclarationImpl(x, y); },
	    "FixedUriString": function (x) { return new RamlWrapper.FixedUriStringImpl(x); },
	    "FragmentDeclaration": function (x, y) { return new RamlWrapper.FragmentDeclarationImpl(x, y); },
	    "FullUriTemplateString": function (x) { return new RamlWrapper.FullUriTemplateStringImpl(x); },
	    "IntegerType": function (x) { return new RamlWrapper.IntegerTypeImpl(x); },
	    "IntegerTypeDeclaration": function (x, y) { return new RamlWrapper.IntegerTypeDeclarationImpl(x, y); },
	    "Library": function (x, y) { return new RamlWrapper.LibraryImpl(x, y); },
	    "LibraryBase": function (x, y) { return new RamlWrapper.LibraryBaseImpl(x, y); },
	    "LocationKind": function (x) { return new RamlWrapper.LocationKindImpl(x); },
	    "MarkdownString": function (x) { return new RamlWrapper.MarkdownStringImpl(x); },
	    "Method": function (x, y) { return new RamlWrapper.MethodImpl(x, y); },
	    "MethodBase": function (x, y) { return new RamlWrapper.MethodBaseImpl(x, y); },
	    "MimeType": function (x) { return new RamlWrapper.MimeTypeImpl(x); },
	    "ModelLocation": function (x) { return new RamlWrapper.ModelLocationImpl(x); },
	    "NullType": function (x) { return new RamlWrapper.NullTypeImpl(x); },
	    "NumberType": function (x) { return new RamlWrapper.NumberTypeImpl(x); },
	    "NumberTypeDeclaration": function (x, y) { return new RamlWrapper.NumberTypeDeclarationImpl(x, y); },
	    "OAuth1SecurityScheme": function (x, y) { return new RamlWrapper.OAuth1SecuritySchemeImpl(x, y); },
	    "OAuth1SecuritySchemeSettings": function (x, y) { return new RamlWrapper.OAuth1SecuritySchemeSettingsImpl(x, y); },
	    "OAuth2SecurityScheme": function (x, y) { return new RamlWrapper.OAuth2SecuritySchemeImpl(x, y); },
	    "OAuth2SecuritySchemeSettings": function (x, y) { return new RamlWrapper.OAuth2SecuritySchemeSettingsImpl(x, y); },
	    "ObjectTypeDeclaration": function (x, y) { return new RamlWrapper.ObjectTypeDeclarationImpl(x, y); },
	    "Operation": function (x, y) { return new RamlWrapper.OperationImpl(x, y); },
	    "Overlay": function (x, y) { return new RamlWrapper.OverlayImpl(x, y); },
	    "PassThroughSecurityScheme": function (x, y) { return new RamlWrapper.PassThroughSecuritySchemeImpl(x, y); },
	    "Reference": function (x) { return new RamlWrapper.ReferenceImpl(x); },
	    "RelativeUriString": function (x) { return new RamlWrapper.RelativeUriStringImpl(x); },
	    "Resource": function (x, y) { return new RamlWrapper.ResourceImpl(x, y); },
	    "ResourceBase": function (x, y) { return new RamlWrapper.ResourceBaseImpl(x, y); },
	    "ResourceType": function (x, y) { return new RamlWrapper.ResourceTypeImpl(x, y); },
	    "ResourceTypeRef": function (x) { return new RamlWrapper.ResourceTypeRefImpl(x); },
	    "Response": function (x, y) { return new RamlWrapper.ResponseImpl(x, y); },
	    "SchemaString": function (x) { return new RamlWrapper.SchemaStringImpl(x); },
	    "SecuritySchemePart": function (x, y) { return new RamlWrapper.SecuritySchemePartImpl(x, y); },
	    "SecuritySchemeRef": function (x) { return new RamlWrapper.SecuritySchemeRefImpl(x); },
	    "SecuritySchemeSettings": function (x, y) { return new RamlWrapper.SecuritySchemeSettingsImpl(x, y); },
	    "StatusCodeString": function (x) { return new RamlWrapper.StatusCodeStringImpl(x); },
	    "StringType": function (x) { return new RamlWrapper.StringTypeImpl(x); },
	    "StringTypeDeclaration": function (x, y) { return new RamlWrapper.StringTypeDeclarationImpl(x, y); },
	    "TimeOnlyType": function (x) { return new RamlWrapper.TimeOnlyTypeImpl(x); },
	    "TimeOnlyTypeDeclaration": function (x, y) { return new RamlWrapper.TimeOnlyTypeDeclarationImpl(x, y); },
	    "Trait": function (x, y) { return new RamlWrapper.TraitImpl(x, y); },
	    "TraitRef": function (x) { return new RamlWrapper.TraitRefImpl(x); },
	    "TypeDeclaration": function (x, y) { return new RamlWrapper.TypeDeclarationImpl(x, y); },
	    "UnionTypeDeclaration": function (x, y) { return new RamlWrapper.UnionTypeDeclarationImpl(x, y); },
	    "UriTemplate": function (x) { return new RamlWrapper.UriTemplateImpl(x); },
	    "UsesDeclaration": function (x, y) { return new RamlWrapper.UsesDeclarationImpl(x, y); },
	    "ValueType": function (x) { return new RamlWrapper.ValueTypeImpl(x); },
	    "XMLFacetInfo": function (x, y) { return new RamlWrapper.XMLFacetInfoImpl(x, y); }
	};
	//# sourceMappingURL=raml10factory.js.map

/***/ },
/* 42 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var RamlWrapper = __webpack_require__(45);
	/**
	 * @hidden
	 * Build Wrapper node corresponding to the High Level node
	 **/
	function buildWrapperNode(node, setAsTopLevel) {
	    if (setAsTopLevel === void 0) { setAsTopLevel = true; }
	    var definition = node.definition();
	    var nodeClassName = definition.nameId();
	    var wrapperConstructor = classMap[nodeClassName];
	    if (!wrapperConstructor) {
	        var priorities = determineSuperclassesPriorities(definition);
	        var superTypes = definition.allSuperTypes().sort(function (x, y) { return priorities[x.nameId()] - priorities[y.nameId()]; });
	        var wr = null;
	        for (var i = 0; i < superTypes.length; i++) {
	            var superTypeName = superTypes[i].nameId();
	            wrapperConstructor = classMap[superTypeName];
	            if (superTypeName == "DataElement") {
	                wr = superTypeName;
	                //This is only case of nested hierarchy
	                continue;
	            }
	            if (superTypeName == "hl.BasicNode") {
	                //depth first
	                continue;
	            }
	            if (wrapperConstructor) {
	                break;
	            }
	        }
	        if (!wrapperConstructor) {
	            wr = superTypeName;
	        }
	    }
	    if (!wrapperConstructor) {
	        wrapperConstructor = classMap["hl.BasicNode"];
	    }
	    return wrapperConstructor(node, setAsTopLevel);
	}
	exports.buildWrapperNode = buildWrapperNode;
	function determineSuperclassesPriorities(td, priorities, path) {
	    if (priorities === void 0) { priorities = {}; }
	    if (path === void 0) { path = {}; }
	    var typeName = td.nameId();
	    if (path[typeName]) {
	        return;
	    }
	    path[typeName] = true;
	    var rank = (priorities[typeName] != null && priorities[typeName] + 1) || 0;
	    var superTypes = td.superTypes();
	    superTypes.forEach(function (x) {
	        var name = x.nameId();
	        var r = priorities[name];
	        if (r == null || rank > r) {
	            priorities[name] = rank;
	            determineSuperclassesPriorities(x, priorities, path);
	        }
	    });
	    delete path[typeName];
	    return priorities;
	}
	var classMap = {
	    "AbstractSecurityScheme": function (x, y) { return new RamlWrapper.AbstractSecuritySchemeImpl(x, y); },
	    "AnyType": function (x) { return new RamlWrapper.AnyTypeImpl(x); },
	    "Api": function (x, y) { return new RamlWrapper.ApiImpl(x, y); },
	    "BasicSecurityScheme": function (x, y) { return new RamlWrapper.BasicSecuritySchemeImpl(x, y); },
	    "BodyLike": function (x, y) { return new RamlWrapper.BodyLikeImpl(x, y); },
	    "BooleanType": function (x) { return new RamlWrapper.BooleanTypeImpl(x); },
	    "BooleanTypeDeclaration": function (x, y) { return new RamlWrapper.BooleanTypeDeclarationImpl(x, y); },
	    "CustomSecurityScheme": function (x, y) { return new RamlWrapper.CustomSecuritySchemeImpl(x, y); },
	    "DateTypeDeclaration": function (x, y) { return new RamlWrapper.DateTypeDeclarationImpl(x, y); },
	    "DigestSecurityScheme": function (x, y) { return new RamlWrapper.DigestSecuritySchemeImpl(x, y); },
	    "DocumentationItem": function (x, y) { return new RamlWrapper.DocumentationItemImpl(x, y); },
	    "ExampleString": function (x) { return new RamlWrapper.ExampleStringImpl(x); },
	    "FileTypeDeclaration": function (x, y) { return new RamlWrapper.FileTypeDeclarationImpl(x, y); },
	    "FixedUri": function (x) { return new RamlWrapper.FixedUriImpl(x); },
	    "FullUriTemplateString": function (x) { return new RamlWrapper.FullUriTemplateStringImpl(x); },
	    "GlobalSchema": function (x, y) { return new RamlWrapper.GlobalSchemaImpl(x, y); },
	    "IntegerTypeDeclaration": function (x, y) { return new RamlWrapper.IntegerTypeDeclarationImpl(x, y); },
	    "JSONBody": function (x, y) { return new RamlWrapper.JSONBodyImpl(x, y); },
	    "JSONExample": function (x) { return new RamlWrapper.JSONExampleImpl(x); },
	    "JSonSchemaString": function (x) { return new RamlWrapper.JSonSchemaStringImpl(x); },
	    "MarkdownString": function (x) { return new RamlWrapper.MarkdownStringImpl(x); },
	    "Method": function (x, y) { return new RamlWrapper.MethodImpl(x, y); },
	    "MethodBase": function (x, y) { return new RamlWrapper.MethodBaseImpl(x, y); },
	    "MimeType": function (x) { return new RamlWrapper.MimeTypeImpl(x); },
	    "NumberType": function (x) { return new RamlWrapper.NumberTypeImpl(x); },
	    "NumberTypeDeclaration": function (x, y) { return new RamlWrapper.NumberTypeDeclarationImpl(x, y); },
	    "OAuth1SecurityScheme": function (x, y) { return new RamlWrapper.OAuth1SecuritySchemeImpl(x, y); },
	    "OAuth1SecuritySchemeSettings": function (x, y) { return new RamlWrapper.OAuth1SecuritySchemeSettingsImpl(x, y); },
	    "OAuth2SecurityScheme": function (x, y) { return new RamlWrapper.OAuth2SecuritySchemeImpl(x, y); },
	    "OAuth2SecuritySchemeSettings": function (x, y) { return new RamlWrapper.OAuth2SecuritySchemeSettingsImpl(x, y); },
	    "Parameter": function (x, y) { return new RamlWrapper.ParameterImpl(x, y); },
	    "ParameterLocation": function (x) { return new RamlWrapper.ParameterLocationImpl(x); },
	    "RAMLSimpleElement": function (x, y) { return new RamlWrapper.RAMLSimpleElementImpl(x, y); },
	    "Reference": function (x) { return new RamlWrapper.ReferenceImpl(x); },
	    "RelativeUriString": function (x) { return new RamlWrapper.RelativeUriStringImpl(x); },
	    "Resource": function (x, y) { return new RamlWrapper.ResourceImpl(x, y); },
	    "ResourceType": function (x, y) { return new RamlWrapper.ResourceTypeImpl(x, y); },
	    "ResourceTypeRef": function (x) { return new RamlWrapper.ResourceTypeRefImpl(x); },
	    "Response": function (x, y) { return new RamlWrapper.ResponseImpl(x, y); },
	    "SchemaString": function (x) { return new RamlWrapper.SchemaStringImpl(x); },
	    "SecuritySchemePart": function (x, y) { return new RamlWrapper.SecuritySchemePartImpl(x, y); },
	    "SecuritySchemeRef": function (x) { return new RamlWrapper.SecuritySchemeRefImpl(x); },
	    "SecuritySchemeSettings": function (x, y) { return new RamlWrapper.SecuritySchemeSettingsImpl(x, y); },
	    "StatusCodeString": function (x) { return new RamlWrapper.StatusCodeStringImpl(x); },
	    "StringType": function (x) { return new RamlWrapper.StringTypeImpl(x); },
	    "StringTypeDeclaration": function (x, y) { return new RamlWrapper.StringTypeDeclarationImpl(x, y); },
	    "Trait": function (x, y) { return new RamlWrapper.TraitImpl(x, y); },
	    "TraitRef": function (x) { return new RamlWrapper.TraitRefImpl(x); },
	    "UriTemplate": function (x) { return new RamlWrapper.UriTemplateImpl(x); },
	    "ValueType": function (x) { return new RamlWrapper.ValueTypeImpl(x); },
	    "XMLBody": function (x, y) { return new RamlWrapper.XMLBodyImpl(x, y); },
	    "XMLExample": function (x) { return new RamlWrapper.XMLExampleImpl(x); },
	    "XMLSchemaString": function (x) { return new RamlWrapper.XMLSchemaStringImpl(x); }
	};
	//# sourceMappingURL=raml08factory.js.map

/***/ },
/* 43 */
/***/ function(module, exports, __webpack_require__) {

	/// <reference path="../../typings/main.d.ts" />
	"use strict";
	var _ = __webpack_require__(61);
	var Opt = __webpack_require__(29);
	exports.defined = function (x) { return (x !== null) && (x !== undefined); };
	/**
	 * Arrays of Objects are common in RAML08.
	 * @param x
	 * @returns {{}}
	 */
	function flattenArrayOfObjects(x) {
	    var res = {};
	    x.forEach(function (v) { return Object.keys(v).forEach(function (k) { return res[k] = v[k]; }); });
	    return res;
	}
	exports.flattenArrayOfObjects = flattenArrayOfObjects;
	function find(xs, f) {
	    return new Opt(_.find(xs || [], f));
	}
	exports.find = find;
	exports.isInstance = function (v, C) { return (v instanceof C) ? [v] : []; };
	exports.ifInstanceOf = function (v, C, f) { return (v instanceof C) ? f(v) : null; };
	function toTuples(map) {
	    return Object.keys(map).map(function (k) { return [k, map[k]]; });
	}
	exports.toTuples = toTuples;
	function fromTuples(tuples) {
	    var obj = {};
	    tuples.forEach(function (x) { return obj[x[0]] = x[1]; });
	    return obj;
	}
	exports.fromTuples = fromTuples;
	exports.collectInstancesOf = function (xs, C) { return tap([], function (res) { return xs.forEach(function (v) { return exports.ifInstanceOf(v, C, function (x) { return res.push(x); }); }); }); };
	exports.collectInstancesOfInMap = function (map, C) {
	    return Object.keys(map).map(function (k) { return [k, map[k]]; }).filter(function (x) { return x[1] instanceof C; }).map(function (x) { return x; });
	};
	exports.asArray = function (v) { return exports.defined(v) ? ((v instanceof Array) ? v : [v]) : []; };
	exports.shallowCopy = function (obj) { return tap({}, function (copy) { return Object.keys(obj).forEach(function (k) { return copy[k] = obj[k]; }); }); };
	exports.flatMap = function (xs, f) { return exports.flatten(xs.map(f)); };
	exports.flatten = function (xss) { return Array.prototype.concat.apply([], xss); };
	exports.takeWhile = function (xs, f) { return tap([], function (res) {
	    for (var i = 0; i < xs.length; i++) {
	        if (!f(xs[i]))
	            break;
	        res.push(xs[i]);
	    }
	}); };
	function tap(v, f) {
	    f(v);
	    return v;
	}
	exports.tap = tap;
	function kv(obj, iter) {
	    if (typeof obj === 'object')
	        Object.keys(obj).forEach(function (k) { return iter(k, obj[k]); });
	}
	exports.kv = kv;
	function indexed(objects, key, delKey) {
	    if (delKey === void 0) { delKey = false; }
	    var obj = {};
	    objects.forEach(function (original) {
	        var copy = exports.shallowCopy(original);
	        if (delKey)
	            delete copy[key];
	        obj[original[key]] = copy;
	    });
	    return obj;
	}
	exports.indexed = indexed;
	function stringEndsWith(str, search) {
	    var dif = str.length - search.length;
	    return dif >= 0 && str.lastIndexOf(search) === dif;
	}
	exports.stringEndsWith = stringEndsWith;
	function stringStartsWith(str, search) {
	    return str.length - search.length >= 0 && str.substring(0, search.length) === search;
	}
	exports.stringStartsWith = stringStartsWith;
	function lazypropkeyfilter(k) {
	    return k[k.length - 1] == "_"; // ends with underscore
	}
	exports.lazypropkeyfilter = lazypropkeyfilter;
	function lazyprop(obj, key, func) {
	    var result, ready = false;
	    obj[key] = function () {
	        if (!ready) {
	            ready = true;
	            result = func.apply(obj);
	        }
	        return result;
	    };
	}
	function lazyprops(obj, keyfilter) {
	    if (keyfilter === void 0) { keyfilter = lazypropkeyfilter; }
	    for (var k in obj) {
	        if (keyfilter(k)) {
	            exports.ifInstanceOf(obj[k], Function, function (vf) { return (vf.length === 0) ? lazyprop(obj, k, vf) : null; });
	        }
	    }
	}
	exports.lazyprops = lazyprops;
	function iff(v, f) {
	    if (v !== undefined)
	        f(v);
	}
	exports.iff = iff;
	function isRAMLUrl(str) {
	    if (typeof str !== 'string' || str == '')
	        return false;
	    return stringEndsWith(str, ".raml");
	}
	exports.isRAMLUrl = isRAMLUrl;
	function getAllRequiredExternalModulesFromCode(code) {
	    var match;
	    var mods = [];
	    // both quoting styles
	    var r1 = new RegExp("require\\('([^']+)'\\)", "gi");
	    while (match = r1.exec(code)) {
	        mods.push(match[1]);
	    }
	    var r2 = new RegExp('require\\("([^"]+)"\\)', "gi");
	    while (match = r2.exec(code)) {
	        mods.push(match[1]);
	    }
	    mods = _.unique(mods).filter(function (x) { return x != ""; });
	    mods.sort();
	    return mods;
	}
	exports.getAllRequiredExternalModulesFromCode = getAllRequiredExternalModulesFromCode;
	exports.serial = (function () { var i = 0; return function () { return i++; }; })();
	function isEssential(arg) {
	    return typeof arg !== 'undefined' && arg != null;
	}
	exports.isEssential = isEssential;
	function firstToUpper(q) {
	    if (q.length == 0) {
	        return q;
	    }
	    return q.charAt(0).toUpperCase() + q.substr(1);
	}
	exports.firstToUpper = firstToUpper;
	function updateObject(source, target, addNewFields) {
	    if (addNewFields === void 0) { addNewFields = false; }
	    var keySet = Object.keys(target);
	    if (addNewFields) {
	        var map = {};
	        keySet.forEach(function (x) { return map[x] = true; });
	        Object.keys(source).forEach(function (x) { return map[x] = true; });
	        keySet = Object.keys(map);
	    }
	    keySet.forEach(function (x) {
	        var value = source[x];
	        if (value instanceof Object) {
	            if (!target[x]) {
	                target[x] = {};
	            }
	            updateObject(value, target[x], true);
	        }
	        else if (value != undefined) {
	            target[x] = source[x];
	        }
	    });
	}
	exports.updateObject = updateObject;
	;
	/**
	 * In 'str' replace all occurences of 'map' keys to their values.
	 */
	function replaceMap(str, map) {
	    Object.keys(map).forEach(function (x) { return str = replace(str, x, map[x]); });
	    return str;
	}
	exports.replaceMap = replaceMap;
	/**
	 * Replace all occurences of 'x' in 'str' to 'r' without thinking if 'x' can be passed without
	 * escaping as argument to RegExp constructor
	 */
	function replace(str, x, r) {
	    var result = '';
	    var prev = 0;
	    for (var i = str.indexOf(x); i < str.length && i >= 0; i = str.indexOf(x, prev)) {
	        result += str.substring(prev, i);
	        result += r;
	        prev = i + x.length;
	    }
	    result += str.substring(prev, str.length);
	    return result;
	}
	exports.replace = replace;
	//# sourceMappingURL=index.js.map

/***/ },
/* 44 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var contentprovider = __webpack_require__(31);
	var def = __webpack_require__(33);
	var su = def.getSchemaUtils();
	function isScheme(content) {
	    try {
	        var schemeObject = JSON.parse(content);
	        return schemeObject['$schema'];
	    }
	    catch (exception) {
	        return false;
	    }
	}
	exports.isScheme = isScheme;
	function startDownloadingReferencesAsync(schemaContent, unit) {
	    var schemaObject = su.getJSONSchema(schemaContent, new contentprovider.ContentProvider(unit));
	    var missedReferences = schemaObject.getMissingReferences([]).map(function (reference) { return schemaObject.contentAsync(reference); });
	    if (missedReferences.length === 0) {
	        return Promise.resolve(unit);
	    }
	    var allReferences = Promise.all(missedReferences);
	    var result = getRefs(allReferences, schemaObject);
	    return result.then(function () { return unit; });
	}
	exports.startDownloadingReferencesAsync = startDownloadingReferencesAsync;
	function getReferences(schemaContent, unit) {
	    var schemaObject = su.getJSONSchema(schemaContent, new contentprovider.ContentProvider(unit));
	    return schemaObject.getMissingReferences([], true);
	}
	exports.getReferences = getReferences;
	function getRefs(promise, schemaObject) {
	    return promise.then(function (references) {
	        if (references.length > 0) {
	            var missedRefs = schemaObject.getMissingReferences(references);
	            if (missedRefs.length === 0) {
	                return [];
	            }
	            var promises = [];
	            missedRefs.forEach(function (ref) {
	                promises.push(schemaObject.contentAsync(ref));
	            });
	            return getRefs(Promise.all(promises.concat(references)), schemaObject);
	        }
	        return Promise.resolve([]);
	    });
	}
	//# sourceMappingURL=schemaAsync.js.map

/***/ },
/* 45 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var __extends = (this && this.__extends) || function (d, b) {
	    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
	    function __() { this.constructor = d; }
	    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
	};
	var stubs = __webpack_require__(17);
	var def = __webpack_require__(33);
	var core = __webpack_require__(50);
	var apiLoader = __webpack_require__(9);
	var helper = __webpack_require__(46);
	var ApiImpl = (function (_super) {
	    __extends(ApiImpl, _super);
	    function ApiImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * The title property is a short plain text description of the RESTful API. The value SHOULD be suitable for use as a title for the contained user documentation.
	     **/
	    ApiImpl.prototype.title = function () {
	        return _super.prototype.attribute.call(this, 'title', this.toString);
	    };
	    /**
	     * @hidden
	     * Set title value
	     **/
	    ApiImpl.prototype.setTitle = function (param) {
	        this.highLevel().attrOrCreate("title").setValue("" + param);
	        return this;
	    };
	    /**
	     * If the RAML API definition is targeted to a specific API version, the API definition MUST contain a version property. The version property is OPTIONAL and should not be used if: The API itself is not versioned. The API definition does not change between versions. The API architect can decide whether a change to user documentation elements, but no change to the API's resources, constitutes a version change. The API architect MAY use any versioning scheme so long as version numbers retain the same format. For example, 'v3', 'v3.0', and 'V3' are all allowed, but are not considered to be equal.
	     **/
	    ApiImpl.prototype.version = function () {
	        return _super.prototype.attribute.call(this, 'version', this.toString);
	    };
	    /**
	     * @hidden
	     * Set version value
	     **/
	    ApiImpl.prototype.setVersion = function (param) {
	        this.highLevel().attrOrCreate("version").setValue("" + param);
	        return this;
	    };
	    /**
	     * (Optional during development; Required after implementation) A RESTful API's resources are defined relative to the API's base URI. The use of the baseUri field is OPTIONAL to allow describing APIs that have not yet been implemented. After the API is implemented (even a mock implementation) and can be accessed at a service endpoint, the API definition MUST contain a baseUri property. The baseUri property's value MUST conform to the URI specification RFC2396 or a Level 1 Template URI as defined in RFC6570. The baseUri property SHOULD only be used as a reference value.
	     **/
	    ApiImpl.prototype.baseUri = function () {
	        return _super.prototype.attribute.call(this, 'baseUri', function (attr) { return new FullUriTemplateStringImpl(attr); });
	    };
	    /**
	     * Base uri parameters are named parameters which described template parameters in the base uri
	     * @hidden
	     **/
	    ApiImpl.prototype.baseUriParameters_original = function () {
	        return _super.prototype.elements.call(this, 'baseUriParameters');
	    };
	    /**
	     * URI parameters can be further defined by using the uriParameters property. The use of uriParameters is OPTIONAL. The uriParameters property MUST be a map in which each key MUST be the name of the URI parameter as defined in the baseUri property. The uriParameters CANNOT contain a key named version because it is a reserved URI parameter name. The value of the uriParameters property is itself a map that specifies  the property's attributes as named parameters
	     **/
	    ApiImpl.prototype.uriParameters = function () {
	        return _super.prototype.elements.call(this, 'uriParameters');
	    };
	    /**
	     * A RESTful API can be reached HTTP, HTTPS, or both. The protocols property MAY be used to specify the protocols that an API supports. If the protocols property is not specified, the protocol specified at the baseUri property is used. The protocols property MUST be an array of strings, of values `HTTP` and/or `HTTPS`.
	     **/
	    ApiImpl.prototype.protocols = function () {
	        return _super.prototype.attributes.call(this, 'protocols', this.toString);
	    };
	    /**
	     * @hidden
	     * Set protocols value
	     **/
	    ApiImpl.prototype.setProtocols = function (param) {
	        this.highLevel().attrOrCreate("protocols").setValue("" + param);
	        return this;
	    };
	    /**
	     * (Optional) The media types returned by API responses, and expected from API requests that accept a body, MAY be defaulted by specifying the mediaType property. This property is specified at the root level of the API definition. The property's value MAY be a single string with a valid media type described in the specification.
	     **/
	    ApiImpl.prototype.mediaType = function () {
	        return _super.prototype.attribute.call(this, 'mediaType', function (attr) { return new MimeTypeImpl(attr); });
	    };
	    /**
	     * To better achieve consistency and simplicity, the API definition SHOULD include an OPTIONAL schemas property in the root section. The schemas property specifies collections of schemas that could be used anywhere in the API definition. The value of the schemas property is an array of maps; in each map, the keys are the schema name, and the values are schema definitions. The schema definitions MAY be included inline or by using the RAML !include user-defined data type.
	     **/
	    ApiImpl.prototype.schemas = function () {
	        return _super.prototype.elements.call(this, 'schemas');
	    };
	    /**
	     * Declarations of traits used in this API
	     * @hidden
	     **/
	    ApiImpl.prototype.traits_original = function () {
	        return _super.prototype.elements.call(this, 'traits');
	    };
	    /**
	     * A list of the security schemes to apply to all methods, these must be defined in the securitySchemes declaration.
	     **/
	    ApiImpl.prototype.securedBy = function () {
	        return _super.prototype.attributes.call(this, 'securedBy', function (attr) { return new SecuritySchemeRefImpl(attr); });
	    };
	    /**
	     * Security schemes that can be applied using securedBy
	     **/
	    ApiImpl.prototype.securitySchemes = function () {
	        return _super.prototype.elements.call(this, 'securitySchemes');
	    };
	    /**
	     * Declaration of resource types used in this API
	     * @hidden
	     **/
	    ApiImpl.prototype.resourceTypes_original = function () {
	        return _super.prototype.elements.call(this, 'resourceTypes');
	    };
	    /**
	     * Resources are identified by their relative URI, which MUST begin with a slash (/). A resource defined as a root-level property is called a top-level resource. Its property's key is the resource's URI relative to the baseUri. A resource defined as a child property of another resource is called a nested resource, and its property's key is its URI relative to its parent resource's URI. Every property whose key begins with a slash (/), and is either at the root of the API definition or is the child property of a resource property, is a resource property. The key of a resource, i.e. its relative URI, MAY consist of multiple URI path fragments separated by slashes; e.g. `/bom/items` may indicate the collection of items in a bill of materials as a single resource. However, if the individual URI path fragments are themselves resources, the API definition SHOULD use nested resources to describe this structure; e.g. if `/bom` is itself a resource then `/items` should be a nested resource of `/bom`, while `/bom/items` should not be used.
	     **/
	    ApiImpl.prototype.resources = function () {
	        return _super.prototype.elements.call(this, 'resources');
	    };
	    /**
	     * The API definition can include a variety of documents that serve as a user guides and reference documentation for the API. Such documents can clarify how the API works or provide business context. Documentation-generators MUST include all the sections in an API definition's documentation property in the documentation output, and they MUST preserve the order in which the documentation is declared. To add user documentation to the API, include the documentation property at the root of the API definition. The documentation property MUST be an array of documents. Each document MUST contain title and content attributes, both of which are REQUIRED. If the documentation property is specified, it MUST include at least one document. Documentation-generators MUST process the content field as if it was defined using Markdown.
	     **/
	    ApiImpl.prototype.documentation = function () {
	        return _super.prototype.elements.call(this, 'documentation');
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    ApiImpl.prototype.wrapperClassName = function () { return "ApiImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    ApiImpl.prototype.kind = function () { return "Api"; };
	    /**
	     * @return RAML version of the node
	     * @hidden
	     **/
	    ApiImpl.prototype.RAMLVersion_original = function () { return "RAML08"; };
	    /**
	     * Equivalent API with traits and resource types expanded
	     **/
	    ApiImpl.prototype.expand = function () {
	        return helper.expandTraitsAndResourceTypes(this);
	    };
	    /**
	     * Declarations of traits used in this API
	     **/
	    ApiImpl.prototype.traits = function () {
	        return helper.traitsPrimary(this);
	    };
	    /**
	     * Retrieve all traits including those defined in libraries *
	     * @deprecated
	     **/
	    ApiImpl.prototype.allTraits = function () {
	        return helper.allTraits(this);
	    };
	    /**
	     * Declaration of resource types used in this API
	     **/
	    ApiImpl.prototype.resourceTypes = function () {
	        return helper.resourceTypesPrimary(this);
	    };
	    /**
	     * Retrieve all resource types including those defined in libraries
	     * @deprecated
	     **/
	    ApiImpl.prototype.allResourceTypes = function () {
	        return helper.allResourceTypes(this);
	    };
	    /**
	     * Get child resource by its relative path
	     **/
	    ApiImpl.prototype.childResource = function (relPath) {
	        return helper.childResource(this, relPath);
	    };
	    /**
	     * Retrieve all resources of the Api
	     **/
	    ApiImpl.prototype.allResources = function () {
	        return helper.allResources(this);
	    };
	    /**
	     * Base uri parameters are named parameters which described template parameters in the base uri
	     **/
	    ApiImpl.prototype.baseUriParameters = function () {
	        return helper.baseUriParametersPrimary(this);
	    };
	    /**
	     * Retrieve an ordered list of all base uri parameters regardless of whether they are described in `baseUriParameters` or not
	     * Consider a fragment of RAML specification:
	     * ```yaml
	     * version: v1
	     * baseUri: https://{organization}.example.com/{version}/{service}
	     * baseUriParameters:
	     * service:
	     * ```
	     * Here `version` and `organization` are base uri parameters which are not described in the `baseUriParameters` node,
	     * Thus, they are not among `Api.baseUriParameters()`, but they are among `Api.allBaseUriParameters()`.
	     * @deprecated
	     **/
	    ApiImpl.prototype.allBaseUriParameters = function () {
	        return helper.baseUriParameters(this);
	    };
	    /**
	     * Protocols used by the API. Returns the `protocols` property value if it is specified.
	     * Otherwise, returns protocol, specified in the base URI.
	     * @deprecated
	     **/
	    ApiImpl.prototype.allProtocols = function () {
	        return helper.allProtocols(this);
	    };
	    /**
	     * @return RAML version of the node
	     **/
	    ApiImpl.prototype.RAMLVersion = function () {
	        return helper.RAMLVersion(this);
	    };
	    return ApiImpl;
	}(core.BasicNodeImpl));
	exports.ApiImpl = ApiImpl;
	var ValueTypeImpl = (function (_super) {
	    __extends(ValueTypeImpl, _super);
	    function ValueTypeImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    ValueTypeImpl.prototype.wrapperClassName = function () { return "ValueTypeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    ValueTypeImpl.prototype.kind = function () { return "ValueType"; };
	    /**
	     * @return RAML version of the node
	     **/
	    ValueTypeImpl.prototype.RAMLVersion = function () { return "undefined"; };
	    /**
	     * @return JS representation of the node value
	     **/
	    ValueTypeImpl.prototype.value = function () { return this.attr.value(); };
	    return ValueTypeImpl;
	}(core.AttributeNodeImpl));
	exports.ValueTypeImpl = ValueTypeImpl;
	var AnyTypeImpl = (function (_super) {
	    __extends(AnyTypeImpl, _super);
	    function AnyTypeImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    AnyTypeImpl.prototype.wrapperClassName = function () { return "AnyTypeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    AnyTypeImpl.prototype.kind = function () { return "AnyType"; };
	    /**
	     * @return RAML version of the node
	     **/
	    AnyTypeImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return AnyTypeImpl;
	}(ValueTypeImpl));
	exports.AnyTypeImpl = AnyTypeImpl;
	var NumberTypeImpl = (function (_super) {
	    __extends(NumberTypeImpl, _super);
	    function NumberTypeImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    NumberTypeImpl.prototype.wrapperClassName = function () { return "NumberTypeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    NumberTypeImpl.prototype.kind = function () { return "NumberType"; };
	    /**
	     * @return RAML version of the node
	     **/
	    NumberTypeImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    /**
	     * @return Number representation of the node value
	     **/
	    NumberTypeImpl.prototype.value = function () { return this.attr.value(); };
	    return NumberTypeImpl;
	}(ValueTypeImpl));
	exports.NumberTypeImpl = NumberTypeImpl;
	var BooleanTypeImpl = (function (_super) {
	    __extends(BooleanTypeImpl, _super);
	    function BooleanTypeImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    BooleanTypeImpl.prototype.wrapperClassName = function () { return "BooleanTypeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    BooleanTypeImpl.prototype.kind = function () { return "BooleanType"; };
	    /**
	     * @return RAML version of the node
	     **/
	    BooleanTypeImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    /**
	     * @return Boolean representation of the node value
	     **/
	    BooleanTypeImpl.prototype.value = function () { return this.attr.value(); };
	    return BooleanTypeImpl;
	}(ValueTypeImpl));
	exports.BooleanTypeImpl = BooleanTypeImpl;
	var ReferenceImpl = (function (_super) {
	    __extends(ReferenceImpl, _super);
	    function ReferenceImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    ReferenceImpl.prototype.wrapperClassName = function () { return "ReferenceImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    ReferenceImpl.prototype.kind = function () { return "Reference"; };
	    /**
	     * @return RAML version of the node
	     **/
	    ReferenceImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    /**
	     * @return StructuredValue object representing the node value
	     **/
	    ReferenceImpl.prototype.value = function () { return core.toStructuredValue(this.attr); };
	    ReferenceImpl.prototype.structuredValue = function () {
	        return helper.structuredValue(this);
	    };
	    ReferenceImpl.prototype.name = function () {
	        return helper.referenceName(this);
	    };
	    return ReferenceImpl;
	}(core.AttributeNodeImpl));
	exports.ReferenceImpl = ReferenceImpl;
	var ResourceTypeRefImpl = (function (_super) {
	    __extends(ResourceTypeRefImpl, _super);
	    function ResourceTypeRefImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    ResourceTypeRefImpl.prototype.wrapperClassName = function () { return "ResourceTypeRefImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    ResourceTypeRefImpl.prototype.kind = function () { return "ResourceTypeRef"; };
	    /**
	     * @return RAML version of the node
	     **/
	    ResourceTypeRefImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    ResourceTypeRefImpl.prototype.resourceType = function () {
	        return helper.referencedResourceType(this);
	    };
	    return ResourceTypeRefImpl;
	}(ReferenceImpl));
	exports.ResourceTypeRefImpl = ResourceTypeRefImpl;
	var ResourceTypeImpl = (function (_super) {
	    __extends(ResourceTypeImpl, _super);
	    function ResourceTypeImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * Name of the resource type
	     **/
	    ResourceTypeImpl.prototype.name = function () {
	        return _super.prototype.attribute.call(this, 'name', this.toString);
	    };
	    /**
	     * @hidden
	     * Set name value
	     **/
	    ResourceTypeImpl.prototype.setName = function (param) {
	        this.highLevel().attrOrCreate("name").setValue("" + param);
	        return this;
	    };
	    /**
	     * Instructions on how and when the resource type should be used.
	     **/
	    ResourceTypeImpl.prototype.usage = function () {
	        return _super.prototype.attribute.call(this, 'usage', this.toString);
	    };
	    /**
	     * @hidden
	     * Set usage value
	     **/
	    ResourceTypeImpl.prototype.setUsage = function (param) {
	        this.highLevel().attrOrCreate("usage").setValue("" + param);
	        return this;
	    };
	    /**
	     * Methods that are part of this resource type definition
	     **/
	    ResourceTypeImpl.prototype.methods = function () {
	        return _super.prototype.elements.call(this, 'methods');
	    };
	    /**
	     * Instantiation of applyed traits
	     **/
	    ResourceTypeImpl.prototype.is = function () {
	        return _super.prototype.attributes.call(this, 'is', function (attr) { return new TraitRefImpl(attr); });
	    };
	    /**
	     * Instantiation of applyed resource type
	     **/
	    ResourceTypeImpl.prototype["type"] = function () {
	        return _super.prototype.attribute.call(this, 'type', function (attr) { return new ResourceTypeRefImpl(attr); });
	    };
	    /**
	     * securityScheme may also be applied to a resource by using the securedBy key, which is equivalent to applying the securityScheme to all methods that may be declared, explicitly or implicitly, by defining the resourceTypes or traits property for that resource. To indicate that the method may be called without applying any securityScheme, the method may be annotated with the null securityScheme.
	     **/
	    ResourceTypeImpl.prototype.securedBy = function () {
	        return _super.prototype.attributes.call(this, 'securedBy', function (attr) { return new SecuritySchemeRefImpl(attr); });
	    };
	    /**
	     * Uri parameters of this resource
	     **/
	    ResourceTypeImpl.prototype.uriParameters = function () {
	        return _super.prototype.elements.call(this, 'uriParameters');
	    };
	    /**
	     * An alternate, human-friendly name for the resource type
	     **/
	    ResourceTypeImpl.prototype.displayName = function () {
	        return _super.prototype.attribute.call(this, 'displayName', this.toString);
	    };
	    /**
	     * @hidden
	     * Set displayName value
	     **/
	    ResourceTypeImpl.prototype.setDisplayName = function (param) {
	        this.highLevel().attrOrCreate("displayName").setValue("" + param);
	        return this;
	    };
	    /**
	     * A resource or a method can override a base URI template's values. This is useful to restrict or change the default or parameter selection in the base URI. The baseUriParameters property MAY be used to override any or all parameters defined at the root level baseUriParameters property, as well as base URI parameters not specified at the root level.
	     **/
	    ResourceTypeImpl.prototype.baseUriParameters = function () {
	        return _super.prototype.elements.call(this, 'baseUriParameters');
	    };
	    /**
	     * The description attribute describes the intended use or meaning of the $self. This value MAY be formatted using Markdown.
	     **/
	    ResourceTypeImpl.prototype.description = function () {
	        return _super.prototype.attribute.call(this, 'description', function (attr) { return new MarkdownStringImpl(attr); });
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    ResourceTypeImpl.prototype.wrapperClassName = function () { return "ResourceTypeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    ResourceTypeImpl.prototype.kind = function () { return "ResourceType"; };
	    /**
	     * @return RAML version of the node
	     **/
	    ResourceTypeImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    ResourceTypeImpl.prototype.parametrizedProperties = function () {
	        return helper.getTemplateParametrizedProperties(this);
	    };
	    return ResourceTypeImpl;
	}(core.BasicNodeImpl));
	exports.ResourceTypeImpl = ResourceTypeImpl;
	/**
	 * Method object allows description of http methods
	 **/
	var MethodBaseImpl = (function (_super) {
	    __extends(MethodBaseImpl, _super);
	    function MethodBaseImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * Resource methods MAY have one or more responses. Responses MAY be described using the description property, and MAY include example attributes or schema properties.
	     **/
	    MethodBaseImpl.prototype.responses = function () {
	        return _super.prototype.elements.call(this, 'responses');
	    };
	    /**
	     * Some method verbs expect the resource to be sent as a request body. For example, to create a resource, the request must include the details of the resource to create. Resources CAN have alternate representations. For example, an API might support both JSON and XML representations. A method's body is defined in the body property as a hashmap, in which the key MUST be a valid media type.
	     **/
	    MethodBaseImpl.prototype.body = function () {
	        return _super.prototype.elements.call(this, 'body');
	    };
	    /**
	     * A method can override an API's protocols value for that single method by setting a different value for the fields.
	     **/
	    MethodBaseImpl.prototype.protocols = function () {
	        return _super.prototype.attributes.call(this, 'protocols', this.toString);
	    };
	    /**
	     * @hidden
	     * Set protocols value
	     **/
	    MethodBaseImpl.prototype.setProtocols = function (param) {
	        this.highLevel().attrOrCreate("protocols").setValue("" + param);
	        return this;
	    };
	    /**
	     * A list of the security schemas to apply, these must be defined in the securitySchemes declaration. To indicate that the method may be called without applying any securityScheme, the method may be annotated with the null securityScheme. Security schemas may also be applied to a resource with securedBy, which is equivalent to applying the security schemas to all methods that may be declared, explicitly or implicitly, by defining the resourceTypes or traits property for that resource.
	     **/
	    MethodBaseImpl.prototype.securedBy = function () {
	        return _super.prototype.attributes.call(this, 'securedBy', function (attr) { return new SecuritySchemeRefImpl(attr); });
	    };
	    /**
	     * A resource or a method can override a base URI template's values. This is useful to restrict or change the default or parameter selection in the base URI. The baseUriParameters property MAY be used to override any or all parameters defined at the root level baseUriParameters property, as well as base URI parameters not specified at the root level.
	     **/
	    MethodBaseImpl.prototype.baseUriParameters = function () {
	        return _super.prototype.elements.call(this, 'baseUriParameters');
	    };
	    /**
	     * An APIs resources MAY be filtered (to return a subset of results) or altered (such as transforming a response body from JSON to XML format) by the use of query strings. If the resource or its method supports a query string, the query string MUST be defined by the queryParameters property
	     **/
	    MethodBaseImpl.prototype.queryParameters = function () {
	        return _super.prototype.elements.call(this, 'queryParameters');
	    };
	    /**
	     * Headers that allowed at this position
	     **/
	    MethodBaseImpl.prototype.headers = function () {
	        return _super.prototype.elements.call(this, 'headers');
	    };
	    MethodBaseImpl.prototype.description = function () {
	        return _super.prototype.attribute.call(this, 'description', function (attr) { return new MarkdownStringImpl(attr); });
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    MethodBaseImpl.prototype.wrapperClassName = function () { return "MethodBaseImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    MethodBaseImpl.prototype.kind = function () { return "MethodBase"; };
	    /**
	     * @return RAML version of the node
	     **/
	    MethodBaseImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return MethodBaseImpl;
	}(core.BasicNodeImpl));
	exports.MethodBaseImpl = MethodBaseImpl;
	var ResponseImpl = (function (_super) {
	    __extends(ResponseImpl, _super);
	    function ResponseImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * Responses MUST be a map of one or more HTTP status codes, where each status code itself is a map that describes that status code.
	     **/
	    ResponseImpl.prototype.code = function () {
	        return _super.prototype.attribute.call(this, 'code', function (attr) { return new StatusCodeStringImpl(attr); });
	    };
	    /**
	     * An API's methods may support custom header values in responses. The custom, non-standard HTTP headers MUST be specified by the headers property. API's may include the the placeholder token {?} in a header name to indicate that any number of headers that conform to the specified format can be sent in responses. This is particularly useful for APIs that allow HTTP headers that conform to some naming convention to send arbitrary, custom data.
	     **/
	    ResponseImpl.prototype.headers = function () {
	        return _super.prototype.elements.call(this, 'headers');
	    };
	    /**
	     * Each response MAY contain a body property, which conforms to the same structure as request body properties (see Body). Responses that can return more than one response code MAY therefore have multiple bodies defined. For APIs without a priori knowledge of the response types for their responses, `* /*` MAY be used to indicate that responses that do not matching other defined data types MUST be accepted. Processing applications MUST match the most descriptive media type first if `* /*` is used.
	     **/
	    ResponseImpl.prototype.body = function () {
	        return _super.prototype.elements.call(this, 'body');
	    };
	    /**
	     * The description attribute describes the intended use or meaning of the $self. This value MAY be formatted using Markdown.
	     **/
	    ResponseImpl.prototype.description = function () {
	        return _super.prototype.attribute.call(this, 'description', function (attr) { return new MarkdownStringImpl(attr); });
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    ResponseImpl.prototype.wrapperClassName = function () { return "ResponseImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    ResponseImpl.prototype.kind = function () { return "Response"; };
	    /**
	     * @return RAML version of the node
	     **/
	    ResponseImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    /**
	     * true for codes < 400 and false otherwise
	     **/
	    ResponseImpl.prototype.isOkRange = function () {
	        return helper.isOkRange(this);
	    };
	    return ResponseImpl;
	}(core.BasicNodeImpl));
	exports.ResponseImpl = ResponseImpl;
	var StringTypeImpl = (function (_super) {
	    __extends(StringTypeImpl, _super);
	    function StringTypeImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    StringTypeImpl.prototype.wrapperClassName = function () { return "StringTypeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    StringTypeImpl.prototype.kind = function () { return "StringType"; };
	    /**
	     * @return RAML version of the node
	     **/
	    StringTypeImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    /**
	     * @return String representation of the node value
	     **/
	    StringTypeImpl.prototype.value = function () { return this.attr.value(); };
	    return StringTypeImpl;
	}(ValueTypeImpl));
	exports.StringTypeImpl = StringTypeImpl;
	var StatusCodeStringImpl = (function (_super) {
	    __extends(StatusCodeStringImpl, _super);
	    function StatusCodeStringImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    StatusCodeStringImpl.prototype.wrapperClassName = function () { return "StatusCodeStringImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    StatusCodeStringImpl.prototype.kind = function () { return "StatusCodeString"; };
	    /**
	     * @return RAML version of the node
	     **/
	    StatusCodeStringImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return StatusCodeStringImpl;
	}(StringTypeImpl));
	exports.StatusCodeStringImpl = StatusCodeStringImpl;
	var ParameterImpl = (function (_super) {
	    __extends(ParameterImpl, _super);
	    function ParameterImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * name of the parameter
	     **/
	    ParameterImpl.prototype.name = function () {
	        return _super.prototype.attribute.call(this, 'name', this.toString);
	    };
	    /**
	     * @hidden
	     * Set name value
	     **/
	    ParameterImpl.prototype.setName = function (param) {
	        this.highLevel().attrOrCreate("name").setValue("" + param);
	        return this;
	    };
	    /**
	     * An alternate, human-friendly name for the parameter
	     **/
	    ParameterImpl.prototype.displayName = function () {
	        return _super.prototype.attribute.call(this, 'displayName', this.toString);
	    };
	    /**
	     * @hidden
	     * Set displayName value
	     **/
	    ParameterImpl.prototype.setDisplayName = function (param) {
	        this.highLevel().attrOrCreate("displayName").setValue("" + param);
	        return this;
	    };
	    /**
	     * The type attribute specifies the primitive type of the parameter's resolved value. API clients MUST return/throw an error if the parameter's resolved value does not match the specified type. If type is not specified, it defaults to string.
	     **/
	    ParameterImpl.prototype["type"] = function () {
	        return _super.prototype.attribute.call(this, 'type', this.toString);
	    };
	    /**
	     * @hidden
	     * Set type value
	     **/
	    ParameterImpl.prototype.setType = function (param) {
	        this.highLevel().attrOrCreate("type").setValue("" + param);
	        return this;
	    };
	    /**
	     * Location of the parameter (can not be edited by user)
	     **/
	    ParameterImpl.prototype.location = function () {
	        return _super.prototype.attribute.call(this, 'location', function (attr) { return new ParameterLocationImpl(attr); });
	    };
	    /**
	     * Set to true if parameter is required
	     **/
	    ParameterImpl.prototype.required = function () {
	        return _super.prototype.attribute.call(this, 'required', this.toBoolean);
	    };
	    /**
	     * @hidden
	     * Set required value
	     **/
	    ParameterImpl.prototype.setRequired = function (param) {
	        this.highLevel().attrOrCreate("required").setValue("" + param);
	        return this;
	    };
	    /**
	     * The default attribute specifies the default value to use for the property if the property is omitted or its value is not specified. This SHOULD NOT be interpreted as a requirement for the client to send the default attribute's value if there is no other value to send. Instead, the default attribute's value is the value the server uses if the client does not send a value.
	     **/
	    ParameterImpl.prototype["default"] = function () {
	        return _super.prototype.attribute.call(this, 'default', this.toAny);
	    };
	    /**
	     * @hidden
	     * Set default value
	     **/
	    ParameterImpl.prototype.setDefault = function (param) {
	        this.highLevel().attrOrCreate("default").setValue("" + param);
	        return this;
	    };
	    /**
	     * (Optional) The example attribute shows an example value for the property. This can be used, e.g., by documentation generators to generate sample values for the property.
	     **/
	    ParameterImpl.prototype.example = function () {
	        return _super.prototype.attribute.call(this, 'example', this.toString);
	    };
	    /**
	     * @hidden
	     * Set example value
	     **/
	    ParameterImpl.prototype.setExample = function (param) {
	        this.highLevel().attrOrCreate("example").setValue("" + param);
	        return this;
	    };
	    /**
	     * The repeat attribute specifies that the parameter can be repeated. If the parameter can be used multiple times, the repeat parameter value MUST be set to 'true'. Otherwise, the default value is 'false' and the parameter may not be repeated.
	     **/
	    ParameterImpl.prototype.repeat = function () {
	        return _super.prototype.attribute.call(this, 'repeat', this.toBoolean);
	    };
	    /**
	     * @hidden
	     * Set repeat value
	     **/
	    ParameterImpl.prototype.setRepeat = function (param) {
	        this.highLevel().attrOrCreate("repeat").setValue("" + param);
	        return this;
	    };
	    /**
	     * The description attribute describes the intended use or meaning of the $self. This value MAY be formatted using Markdown.
	     **/
	    ParameterImpl.prototype.description = function () {
	        return _super.prototype.attribute.call(this, 'description', function (attr) { return new MarkdownStringImpl(attr); });
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    ParameterImpl.prototype.wrapperClassName = function () { return "ParameterImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    ParameterImpl.prototype.kind = function () { return "Parameter"; };
	    /**
	     * @return RAML version of the node
	     **/
	    ParameterImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return ParameterImpl;
	}(core.BasicNodeImpl));
	exports.ParameterImpl = ParameterImpl;
	var ParameterLocationImpl = (function () {
	    function ParameterLocationImpl(attr) {
	        this.attr = attr;
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    ParameterLocationImpl.prototype.wrapperClassName = function () { return "ParameterLocationImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    ParameterLocationImpl.prototype.kind = function () { return "ParameterLocation"; };
	    /**
	     * @return RAML version of the node
	     **/
	    ParameterLocationImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return ParameterLocationImpl;
	}());
	exports.ParameterLocationImpl = ParameterLocationImpl;
	/**
	 * Mardown string is a string which can contain markdown as an extension this markdown should support links with RAML Pointers since 1.0
	 **/
	var MarkdownStringImpl = (function (_super) {
	    __extends(MarkdownStringImpl, _super);
	    function MarkdownStringImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    MarkdownStringImpl.prototype.wrapperClassName = function () { return "MarkdownStringImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    MarkdownStringImpl.prototype.kind = function () { return "MarkdownString"; };
	    /**
	     * @return RAML version of the node
	     **/
	    MarkdownStringImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return MarkdownStringImpl;
	}(StringTypeImpl));
	exports.MarkdownStringImpl = MarkdownStringImpl;
	/**
	 * Value must be a string
	 **/
	var StringTypeDeclarationImpl = (function (_super) {
	    __extends(StringTypeDeclarationImpl, _super);
	    function StringTypeDeclarationImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createStringTypeDeclaration(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * (Optional, applicable only for parameters of type string) The pattern attribute is a regular expression that a parameter of type string MUST match. Regular expressions MUST follow the regular expression specification from ECMA 262/Perl 5. The pattern MAY be enclosed in double quotes for readability and clarity.
	     **/
	    StringTypeDeclarationImpl.prototype.pattern = function () {
	        return _super.prototype.attribute.call(this, 'pattern', this.toString);
	    };
	    /**
	     * @hidden
	     * Set pattern value
	     **/
	    StringTypeDeclarationImpl.prototype.setPattern = function (param) {
	        this.highLevel().attrOrCreate("pattern").setValue("" + param);
	        return this;
	    };
	    /**
	     * (Optional, applicable only for parameters of type string) The enum attribute provides an enumeration of the parameter's valid values. This MUST be an array. If the enum attribute is defined, API clients and servers MUST verify that a parameter's value matches a value in the enum array. If there is no matching value, the clients and servers MUST treat this as an error.
	     **/
	    StringTypeDeclarationImpl.prototype.enum = function () {
	        return _super.prototype.attributes.call(this, 'enum', this.toString);
	    };
	    /**
	     * @hidden
	     * Set enum value
	     **/
	    StringTypeDeclarationImpl.prototype.setEnum = function (param) {
	        this.highLevel().attrOrCreate("enum").setValue("" + param);
	        return this;
	    };
	    /**
	     * (Optional, applicable only for parameters of type string) The minLength attribute specifies the parameter value's minimum number of characters.
	     **/
	    StringTypeDeclarationImpl.prototype.minLength = function () {
	        return _super.prototype.attribute.call(this, 'minLength', this.toNumber);
	    };
	    /**
	     * @hidden
	     * Set minLength value
	     **/
	    StringTypeDeclarationImpl.prototype.setMinLength = function (param) {
	        this.highLevel().attrOrCreate("minLength").setValue("" + param);
	        return this;
	    };
	    /**
	     * (Optional, applicable only for parameters of type string) The maxLength attribute specifies the parameter value's maximum number of characters.
	     **/
	    StringTypeDeclarationImpl.prototype.maxLength = function () {
	        return _super.prototype.attribute.call(this, 'maxLength', this.toNumber);
	    };
	    /**
	     * @hidden
	     * Set maxLength value
	     **/
	    StringTypeDeclarationImpl.prototype.setMaxLength = function (param) {
	        this.highLevel().attrOrCreate("maxLength").setValue("" + param);
	        return this;
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    StringTypeDeclarationImpl.prototype.wrapperClassName = function () { return "StringTypeDeclarationImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    StringTypeDeclarationImpl.prototype.kind = function () { return "StringTypeDeclaration"; };
	    /**
	     * @return RAML version of the node
	     **/
	    StringTypeDeclarationImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return StringTypeDeclarationImpl;
	}(ParameterImpl));
	exports.StringTypeDeclarationImpl = StringTypeDeclarationImpl;
	/**
	 * Value must be a boolean
	 **/
	var BooleanTypeDeclarationImpl = (function (_super) {
	    __extends(BooleanTypeDeclarationImpl, _super);
	    function BooleanTypeDeclarationImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createBooleanTypeDeclaration(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    BooleanTypeDeclarationImpl.prototype.wrapperClassName = function () { return "BooleanTypeDeclarationImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    BooleanTypeDeclarationImpl.prototype.kind = function () { return "BooleanTypeDeclaration"; };
	    /**
	     * @return RAML version of the node
	     **/
	    BooleanTypeDeclarationImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return BooleanTypeDeclarationImpl;
	}(ParameterImpl));
	exports.BooleanTypeDeclarationImpl = BooleanTypeDeclarationImpl;
	/**
	 * Value MUST be a number. Indicate floating point numbers as defined by YAML.
	 **/
	var NumberTypeDeclarationImpl = (function (_super) {
	    __extends(NumberTypeDeclarationImpl, _super);
	    function NumberTypeDeclarationImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createNumberTypeDeclaration(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * (Optional, applicable only for parameters of type number or integer) The minimum attribute specifies the parameter's minimum value.
	     **/
	    NumberTypeDeclarationImpl.prototype.minimum = function () {
	        return _super.prototype.attribute.call(this, 'minimum', this.toNumber);
	    };
	    /**
	     * @hidden
	     * Set minimum value
	     **/
	    NumberTypeDeclarationImpl.prototype.setMinimum = function (param) {
	        this.highLevel().attrOrCreate("minimum").setValue("" + param);
	        return this;
	    };
	    /**
	     * (Optional, applicable only for parameters of type number or integer) The maximum attribute specifies the parameter's maximum value.
	     **/
	    NumberTypeDeclarationImpl.prototype.maximum = function () {
	        return _super.prototype.attribute.call(this, 'maximum', this.toNumber);
	    };
	    /**
	     * @hidden
	     * Set maximum value
	     **/
	    NumberTypeDeclarationImpl.prototype.setMaximum = function (param) {
	        this.highLevel().attrOrCreate("maximum").setValue("" + param);
	        return this;
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    NumberTypeDeclarationImpl.prototype.wrapperClassName = function () { return "NumberTypeDeclarationImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    NumberTypeDeclarationImpl.prototype.kind = function () { return "NumberTypeDeclaration"; };
	    /**
	     * @return RAML version of the node
	     **/
	    NumberTypeDeclarationImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return NumberTypeDeclarationImpl;
	}(ParameterImpl));
	exports.NumberTypeDeclarationImpl = NumberTypeDeclarationImpl;
	/**
	 * Value MUST be a integer.
	 **/
	var IntegerTypeDeclarationImpl = (function (_super) {
	    __extends(IntegerTypeDeclarationImpl, _super);
	    function IntegerTypeDeclarationImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createIntegerTypeDeclaration(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    IntegerTypeDeclarationImpl.prototype.wrapperClassName = function () { return "IntegerTypeDeclarationImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    IntegerTypeDeclarationImpl.prototype.kind = function () { return "IntegerTypeDeclaration"; };
	    /**
	     * @return RAML version of the node
	     **/
	    IntegerTypeDeclarationImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return IntegerTypeDeclarationImpl;
	}(NumberTypeDeclarationImpl));
	exports.IntegerTypeDeclarationImpl = IntegerTypeDeclarationImpl;
	/**
	 * Value MUST be a string representation of a date as defined in RFC2616 Section 3.3.
	 **/
	var DateTypeDeclarationImpl = (function (_super) {
	    __extends(DateTypeDeclarationImpl, _super);
	    function DateTypeDeclarationImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createDateTypeDeclaration(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    DateTypeDeclarationImpl.prototype.wrapperClassName = function () { return "DateTypeDeclarationImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    DateTypeDeclarationImpl.prototype.kind = function () { return "DateTypeDeclaration"; };
	    /**
	     * @return RAML version of the node
	     **/
	    DateTypeDeclarationImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return DateTypeDeclarationImpl;
	}(ParameterImpl));
	exports.DateTypeDeclarationImpl = DateTypeDeclarationImpl;
	/**
	 * (Applicable only to Form properties) Value is a file. Client generators SHOULD use this type to handle file uploads correctly.
	 **/
	var FileTypeDeclarationImpl = (function (_super) {
	    __extends(FileTypeDeclarationImpl, _super);
	    function FileTypeDeclarationImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createFileTypeDeclaration(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    FileTypeDeclarationImpl.prototype.wrapperClassName = function () { return "FileTypeDeclarationImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    FileTypeDeclarationImpl.prototype.kind = function () { return "FileTypeDeclaration"; };
	    /**
	     * @return RAML version of the node
	     **/
	    FileTypeDeclarationImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return FileTypeDeclarationImpl;
	}(ParameterImpl));
	exports.FileTypeDeclarationImpl = FileTypeDeclarationImpl;
	var BodyLikeImpl = (function (_super) {
	    __extends(BodyLikeImpl, _super);
	    function BodyLikeImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * Mime type of the request or response body
	     **/
	    BodyLikeImpl.prototype.name = function () {
	        return _super.prototype.attribute.call(this, 'name', this.toString);
	    };
	    /**
	     * @hidden
	     * Set name value
	     **/
	    BodyLikeImpl.prototype.setName = function (param) {
	        this.highLevel().attrOrCreate("name").setValue("" + param);
	        return this;
	    };
	    /**
	     * The structure of a request or response body MAY be further specified by the schema property under the appropriate media type. The schema key CANNOT be specified if a body's media type is application/x-www-form-urlencoded or multipart/form-data. All parsers of RAML MUST be able to interpret JSON Schema and XML Schema. Schema MAY be declared inline or in an external file. However, if the schema is sufficiently large so as to make it difficult for a person to read the API definition, or the schema is reused across multiple APIs or across multiple miles in the same API, the !include user-defined data type SHOULD be used instead of including the content inline. Alternatively, the value of the schema field MAY be the name of a schema specified in the root-level schemas property, or it MAY be declared in an external file and included by using the by using the RAML !include user-defined data type.
	     **/
	    BodyLikeImpl.prototype.schema = function () {
	        return _super.prototype.attribute.call(this, 'schema', function (attr) { return new SchemaStringImpl(attr); });
	    };
	    /**
	     * Documentation generators MUST use body properties' example attributes to generate example invocations.
	     **/
	    BodyLikeImpl.prototype.example = function () {
	        return _super.prototype.attribute.call(this, 'example', function (attr) { return new ExampleStringImpl(attr); });
	    };
	    /**
	     * Web forms REQUIRE special encoding and custom declaration. If the API's media type is either application/x-www-form-urlencoded or multipart/form-data, the formParameters property MUST specify the name-value pairs that the API is expecting. The formParameters property is a map in which the key is the name of the web form parameter, and the value is itself a map the specifies the web form parameter's attributes.
	     **/
	    BodyLikeImpl.prototype.formParameters = function () {
	        return _super.prototype.elements.call(this, 'formParameters');
	    };
	    /**
	     * Human readable description of the body
	     **/
	    BodyLikeImpl.prototype.description = function () {
	        return _super.prototype.attribute.call(this, 'description', function (attr) { return new MarkdownStringImpl(attr); });
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    BodyLikeImpl.prototype.wrapperClassName = function () { return "BodyLikeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    BodyLikeImpl.prototype.kind = function () { return "BodyLike"; };
	    /**
	     * @return RAML version of the node
	     **/
	    BodyLikeImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    BodyLikeImpl.prototype.schemaContent = function () {
	        return helper.schemaContent(this);
	    };
	    return BodyLikeImpl;
	}(core.BasicNodeImpl));
	exports.BodyLikeImpl = BodyLikeImpl;
	/**
	 * Schema at this moment only two subtypes are supported (json schema and xsd)
	 **/
	var SchemaStringImpl = (function (_super) {
	    __extends(SchemaStringImpl, _super);
	    function SchemaStringImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    SchemaStringImpl.prototype.wrapperClassName = function () { return "SchemaStringImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    SchemaStringImpl.prototype.kind = function () { return "SchemaString"; };
	    /**
	     * @return RAML version of the node
	     **/
	    SchemaStringImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return SchemaStringImpl;
	}(StringTypeImpl));
	exports.SchemaStringImpl = SchemaStringImpl;
	/**
	 * JSON schema
	 **/
	var JSonSchemaStringImpl = (function (_super) {
	    __extends(JSonSchemaStringImpl, _super);
	    function JSonSchemaStringImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    JSonSchemaStringImpl.prototype.wrapperClassName = function () { return "JSonSchemaStringImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    JSonSchemaStringImpl.prototype.kind = function () { return "JSonSchemaString"; };
	    /**
	     * @return RAML version of the node
	     **/
	    JSonSchemaStringImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return JSonSchemaStringImpl;
	}(SchemaStringImpl));
	exports.JSonSchemaStringImpl = JSonSchemaStringImpl;
	/**
	 * XSD schema
	 **/
	var XMLSchemaStringImpl = (function (_super) {
	    __extends(XMLSchemaStringImpl, _super);
	    function XMLSchemaStringImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    XMLSchemaStringImpl.prototype.wrapperClassName = function () { return "XMLSchemaStringImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    XMLSchemaStringImpl.prototype.kind = function () { return "XMLSchemaString"; };
	    /**
	     * @return RAML version of the node
	     **/
	    XMLSchemaStringImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return XMLSchemaStringImpl;
	}(SchemaStringImpl));
	exports.XMLSchemaStringImpl = XMLSchemaStringImpl;
	var ExampleStringImpl = (function (_super) {
	    __extends(ExampleStringImpl, _super);
	    function ExampleStringImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    ExampleStringImpl.prototype.wrapperClassName = function () { return "ExampleStringImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    ExampleStringImpl.prototype.kind = function () { return "ExampleString"; };
	    /**
	     * @return RAML version of the node
	     **/
	    ExampleStringImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return ExampleStringImpl;
	}(StringTypeImpl));
	exports.ExampleStringImpl = ExampleStringImpl;
	var JSONExampleImpl = (function (_super) {
	    __extends(JSONExampleImpl, _super);
	    function JSONExampleImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    JSONExampleImpl.prototype.wrapperClassName = function () { return "JSONExampleImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    JSONExampleImpl.prototype.kind = function () { return "JSONExample"; };
	    /**
	     * @return RAML version of the node
	     **/
	    JSONExampleImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return JSONExampleImpl;
	}(ExampleStringImpl));
	exports.JSONExampleImpl = JSONExampleImpl;
	var XMLExampleImpl = (function (_super) {
	    __extends(XMLExampleImpl, _super);
	    function XMLExampleImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    XMLExampleImpl.prototype.wrapperClassName = function () { return "XMLExampleImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    XMLExampleImpl.prototype.kind = function () { return "XMLExample"; };
	    /**
	     * @return RAML version of the node
	     **/
	    XMLExampleImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return XMLExampleImpl;
	}(ExampleStringImpl));
	exports.XMLExampleImpl = XMLExampleImpl;
	/**
	 * Needed to set connection between xml related mime types and xsd schema
	 **/
	var XMLBodyImpl = (function (_super) {
	    __extends(XMLBodyImpl, _super);
	    function XMLBodyImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createXMLBody(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * XSD Schema
	     **/
	    XMLBodyImpl.prototype.schema = function () {
	        return _super.prototype.attribute.call(this, 'schema', function (attr) { return new XMLSchemaStringImpl(attr); });
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    XMLBodyImpl.prototype.wrapperClassName = function () { return "XMLBodyImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    XMLBodyImpl.prototype.kind = function () { return "XMLBody"; };
	    /**
	     * @return RAML version of the node
	     **/
	    XMLBodyImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return XMLBodyImpl;
	}(BodyLikeImpl));
	exports.XMLBodyImpl = XMLBodyImpl;
	/**
	 * Needed to set connection between json related mime types and json schema
	 **/
	var JSONBodyImpl = (function (_super) {
	    __extends(JSONBodyImpl, _super);
	    function JSONBodyImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createJSONBody(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * JSON Schema
	     **/
	    JSONBodyImpl.prototype.schema = function () {
	        return _super.prototype.attribute.call(this, 'schema', function (attr) { return new JSonSchemaStringImpl(attr); });
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    JSONBodyImpl.prototype.wrapperClassName = function () { return "JSONBodyImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    JSONBodyImpl.prototype.kind = function () { return "JSONBody"; };
	    /**
	     * @return RAML version of the node
	     **/
	    JSONBodyImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return JSONBodyImpl;
	}(BodyLikeImpl));
	exports.JSONBodyImpl = JSONBodyImpl;
	var SecuritySchemeRefImpl = (function (_super) {
	    __extends(SecuritySchemeRefImpl, _super);
	    function SecuritySchemeRefImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    SecuritySchemeRefImpl.prototype.wrapperClassName = function () { return "SecuritySchemeRefImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    SecuritySchemeRefImpl.prototype.kind = function () { return "SecuritySchemeRef"; };
	    /**
	     * @return RAML version of the node
	     **/
	    SecuritySchemeRefImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    SecuritySchemeRefImpl.prototype.securitySchemeName = function () {
	        return helper.securitySchemeName(this);
	    };
	    SecuritySchemeRefImpl.prototype.securityScheme = function () {
	        return helper.securityScheme(this);
	    };
	    return SecuritySchemeRefImpl;
	}(ReferenceImpl));
	exports.SecuritySchemeRefImpl = SecuritySchemeRefImpl;
	/**
	 * Declares globally referable security schema definition
	 **/
	var AbstractSecuritySchemeImpl = (function (_super) {
	    __extends(AbstractSecuritySchemeImpl, _super);
	    function AbstractSecuritySchemeImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * Name of the security scheme
	     **/
	    AbstractSecuritySchemeImpl.prototype.name = function () {
	        return _super.prototype.attribute.call(this, 'name', this.toString);
	    };
	    /**
	     * @hidden
	     * Set name value
	     **/
	    AbstractSecuritySchemeImpl.prototype.setName = function (param) {
	        this.highLevel().attrOrCreate("name").setValue("" + param);
	        return this;
	    };
	    /**
	     * The securitySchemes property MUST be used to specify an API's security mechanisms, including the required settings and the authentication methods that the API supports. one authentication method is allowed if the API supports them.
	     **/
	    AbstractSecuritySchemeImpl.prototype["type"] = function () {
	        return _super.prototype.attribute.call(this, 'type', this.toString);
	    };
	    /**
	     * @hidden
	     * Set type value
	     **/
	    AbstractSecuritySchemeImpl.prototype.setType = function (param) {
	        this.highLevel().attrOrCreate("type").setValue("" + param);
	        return this;
	    };
	    /**
	     * The description attribute MAY be used to describe a security schemes property.
	     **/
	    AbstractSecuritySchemeImpl.prototype.description = function () {
	        return _super.prototype.attribute.call(this, 'description', function (attr) { return new MarkdownStringImpl(attr); });
	    };
	    /**
	     * A description of the request components related to Security that are determined by the scheme: the headers, query parameters or responses. As a best practice, even for standard security schemes, API designers SHOULD describe these properties of security schemes. Including the security scheme description completes an API documentation.
	     **/
	    AbstractSecuritySchemeImpl.prototype.describedBy = function () {
	        return _super.prototype.element.call(this, 'describedBy');
	    };
	    /**
	     * The settings attribute MAY be used to provide security scheme-specific information. The required attributes vary depending on the type of security scheme is being declared. It describes the minimum set of properties which any processing application MUST provide and validate if it chooses to implement the security scheme. Processing applications MAY choose to recognize other properties for things such as token lifetime, preferred cryptographic algorithms, and more.
	     **/
	    AbstractSecuritySchemeImpl.prototype.settings = function () {
	        return _super.prototype.element.call(this, 'settings');
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    AbstractSecuritySchemeImpl.prototype.wrapperClassName = function () { return "AbstractSecuritySchemeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    AbstractSecuritySchemeImpl.prototype.kind = function () { return "AbstractSecurityScheme"; };
	    /**
	     * @return RAML version of the node
	     **/
	    AbstractSecuritySchemeImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return AbstractSecuritySchemeImpl;
	}(core.BasicNodeImpl));
	exports.AbstractSecuritySchemeImpl = AbstractSecuritySchemeImpl;
	var SecuritySchemePartImpl = (function (_super) {
	    __extends(SecuritySchemePartImpl, _super);
	    function SecuritySchemePartImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createSecuritySchemePart(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * An alternate, human-friendly name for the security scheme part
	     **/
	    SecuritySchemePartImpl.prototype.displayName = function () {
	        return _super.prototype.attribute.call(this, 'displayName', this.toString);
	    };
	    /**
	     * @hidden
	     * Set displayName value
	     **/
	    SecuritySchemePartImpl.prototype.setDisplayName = function (param) {
	        this.highLevel().attrOrCreate("displayName").setValue("" + param);
	        return this;
	    };
	    /**
	     * Instantiation of applyed traits
	     **/
	    SecuritySchemePartImpl.prototype.is = function () {
	        return _super.prototype.attributes.call(this, 'is', function (attr) { return new TraitRefImpl(attr); });
	    };
	    /**
	     * Headers that allowed at this position
	     **/
	    SecuritySchemePartImpl.prototype.headers = function () {
	        return _super.prototype.elements.call(this, 'headers');
	    };
	    /**
	     * An APIs resources MAY be filtered (to return a subset of results) or altered (such as transforming a response body from JSON to XML format) by the use of query strings. If the resource or its method supports a query string, the query string MUST be defined by the queryParameters property
	     **/
	    SecuritySchemePartImpl.prototype.queryParameters = function () {
	        return _super.prototype.elements.call(this, 'queryParameters');
	    };
	    /**
	     * Optional array of responses, describing the possible responses that could be sent.
	     **/
	    SecuritySchemePartImpl.prototype.responses = function () {
	        return _super.prototype.elements.call(this, 'responses');
	    };
	    /**
	     * A longer, human-friendly description of the security scheme part
	     **/
	    SecuritySchemePartImpl.prototype.description = function () {
	        return _super.prototype.attribute.call(this, 'description', function (attr) { return new MarkdownStringImpl(attr); });
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    SecuritySchemePartImpl.prototype.wrapperClassName = function () { return "SecuritySchemePartImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    SecuritySchemePartImpl.prototype.kind = function () { return "SecuritySchemePart"; };
	    /**
	     * @return RAML version of the node
	     **/
	    SecuritySchemePartImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return SecuritySchemePartImpl;
	}(MethodBaseImpl));
	exports.SecuritySchemePartImpl = SecuritySchemePartImpl;
	var TraitRefImpl = (function (_super) {
	    __extends(TraitRefImpl, _super);
	    function TraitRefImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    TraitRefImpl.prototype.wrapperClassName = function () { return "TraitRefImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    TraitRefImpl.prototype.kind = function () { return "TraitRef"; };
	    /**
	     * @return RAML version of the node
	     **/
	    TraitRefImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    TraitRefImpl.prototype.trait = function () {
	        return helper.referencedTrait(this);
	    };
	    return TraitRefImpl;
	}(ReferenceImpl));
	exports.TraitRefImpl = TraitRefImpl;
	var TraitImpl = (function (_super) {
	    __extends(TraitImpl, _super);
	    function TraitImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createTrait(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * Name of the trait
	     **/
	    TraitImpl.prototype.name = function () {
	        return _super.prototype.attribute.call(this, 'name', this.toString);
	    };
	    /**
	     * @hidden
	     * Set name value
	     **/
	    TraitImpl.prototype.setName = function (param) {
	        this.highLevel().attrOrCreate("name").setValue("" + param);
	        return this;
	    };
	    /**
	     * Instructions on how and when the trait should be used.
	     **/
	    TraitImpl.prototype.usage = function () {
	        return _super.prototype.attribute.call(this, 'usage', this.toString);
	    };
	    /**
	     * @hidden
	     * Set usage value
	     **/
	    TraitImpl.prototype.setUsage = function (param) {
	        this.highLevel().attrOrCreate("usage").setValue("" + param);
	        return this;
	    };
	    /**
	     * An alternate, human-friendly name for the trait
	     **/
	    TraitImpl.prototype.displayName = function () {
	        return _super.prototype.attribute.call(this, 'displayName', this.toString);
	    };
	    /**
	     * @hidden
	     * Set displayName value
	     **/
	    TraitImpl.prototype.setDisplayName = function (param) {
	        this.highLevel().attrOrCreate("displayName").setValue("" + param);
	        return this;
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    TraitImpl.prototype.wrapperClassName = function () { return "TraitImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    TraitImpl.prototype.kind = function () { return "Trait"; };
	    /**
	     * @return RAML version of the node
	     **/
	    TraitImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    TraitImpl.prototype.parametrizedProperties = function () {
	        return helper.getTemplateParametrizedProperties(this);
	    };
	    return TraitImpl;
	}(MethodBaseImpl));
	exports.TraitImpl = TraitImpl;
	var SecuritySchemeSettingsImpl = (function (_super) {
	    __extends(SecuritySchemeSettingsImpl, _super);
	    function SecuritySchemeSettingsImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    SecuritySchemeSettingsImpl.prototype.wrapperClassName = function () { return "SecuritySchemeSettingsImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    SecuritySchemeSettingsImpl.prototype.kind = function () { return "SecuritySchemeSettings"; };
	    /**
	     * @return RAML version of the node
	     **/
	    SecuritySchemeSettingsImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return SecuritySchemeSettingsImpl;
	}(core.BasicNodeImpl));
	exports.SecuritySchemeSettingsImpl = SecuritySchemeSettingsImpl;
	var OAuth1SecuritySchemeSettingsImpl = (function (_super) {
	    __extends(OAuth1SecuritySchemeSettingsImpl, _super);
	    function OAuth1SecuritySchemeSettingsImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createOAuth1SecuritySchemeSettings(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * The URI of the Temporary Credential Request endpoint as defined in RFC5849 Section 2.1
	     **/
	    OAuth1SecuritySchemeSettingsImpl.prototype.requestTokenUri = function () {
	        return _super.prototype.attribute.call(this, 'requestTokenUri', function (attr) { return new FixedUriImpl(attr); });
	    };
	    /**
	     * The URI of the Resource Owner Authorization endpoint as defined in RFC5849 Section 2.2
	     **/
	    OAuth1SecuritySchemeSettingsImpl.prototype.authorizationUri = function () {
	        return _super.prototype.attribute.call(this, 'authorizationUri', function (attr) { return new FixedUriImpl(attr); });
	    };
	    /**
	     * The URI of the Token Request endpoint as defined in RFC5849 Section 2.3
	     **/
	    OAuth1SecuritySchemeSettingsImpl.prototype.tokenCredentialsUri = function () {
	        return _super.prototype.attribute.call(this, 'tokenCredentialsUri', function (attr) { return new FixedUriImpl(attr); });
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    OAuth1SecuritySchemeSettingsImpl.prototype.wrapperClassName = function () { return "OAuth1SecuritySchemeSettingsImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    OAuth1SecuritySchemeSettingsImpl.prototype.kind = function () { return "OAuth1SecuritySchemeSettings"; };
	    /**
	     * @return RAML version of the node
	     **/
	    OAuth1SecuritySchemeSettingsImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return OAuth1SecuritySchemeSettingsImpl;
	}(SecuritySchemeSettingsImpl));
	exports.OAuth1SecuritySchemeSettingsImpl = OAuth1SecuritySchemeSettingsImpl;
	/**
	 * This  type describes fixed uris
	 **/
	var FixedUriImpl = (function (_super) {
	    __extends(FixedUriImpl, _super);
	    function FixedUriImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    FixedUriImpl.prototype.wrapperClassName = function () { return "FixedUriImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    FixedUriImpl.prototype.kind = function () { return "FixedUri"; };
	    /**
	     * @return RAML version of the node
	     **/
	    FixedUriImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return FixedUriImpl;
	}(StringTypeImpl));
	exports.FixedUriImpl = FixedUriImpl;
	var OAuth2SecuritySchemeSettingsImpl = (function (_super) {
	    __extends(OAuth2SecuritySchemeSettingsImpl, _super);
	    function OAuth2SecuritySchemeSettingsImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createOAuth2SecuritySchemeSettings(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * The URI of the Token Endpoint as defined in RFC6749 Section 3.2. Not required forby implicit grant type.
	     **/
	    OAuth2SecuritySchemeSettingsImpl.prototype.accessTokenUri = function () {
	        return _super.prototype.attribute.call(this, 'accessTokenUri', function (attr) { return new FixedUriImpl(attr); });
	    };
	    /**
	     * The URI of the Authorization Endpoint as defined in RFC6749 Section 3.1. Required forby authorization_code and implicit grant types.
	     **/
	    OAuth2SecuritySchemeSettingsImpl.prototype.authorizationUri = function () {
	        return _super.prototype.attribute.call(this, 'authorizationUri', function (attr) { return new FixedUriImpl(attr); });
	    };
	    /**
	     * A list of the Authorization grants supported by the API as defined in RFC6749 Sections 4.1, 4.2, 4.3 and 4.4, can be any of: authorization_code, password, client_credentials, implicit, or refresh_token.
	     **/
	    OAuth2SecuritySchemeSettingsImpl.prototype.authorizationGrants = function () {
	        return _super.prototype.attributes.call(this, 'authorizationGrants', this.toString);
	    };
	    /**
	     * @hidden
	     * Set authorizationGrants value
	     **/
	    OAuth2SecuritySchemeSettingsImpl.prototype.setAuthorizationGrants = function (param) {
	        this.highLevel().attrOrCreate("authorizationGrants").setValue("" + param);
	        return this;
	    };
	    /**
	     * A list of scopes supported by the security scheme as defined in RFC6749 Section 3.3
	     **/
	    OAuth2SecuritySchemeSettingsImpl.prototype.scopes = function () {
	        return _super.prototype.attributes.call(this, 'scopes', this.toString);
	    };
	    /**
	     * @hidden
	     * Set scopes value
	     **/
	    OAuth2SecuritySchemeSettingsImpl.prototype.setScopes = function (param) {
	        this.highLevel().attrOrCreate("scopes").setValue("" + param);
	        return this;
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    OAuth2SecuritySchemeSettingsImpl.prototype.wrapperClassName = function () { return "OAuth2SecuritySchemeSettingsImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    OAuth2SecuritySchemeSettingsImpl.prototype.kind = function () { return "OAuth2SecuritySchemeSettings"; };
	    /**
	     * @return RAML version of the node
	     **/
	    OAuth2SecuritySchemeSettingsImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return OAuth2SecuritySchemeSettingsImpl;
	}(SecuritySchemeSettingsImpl));
	exports.OAuth2SecuritySchemeSettingsImpl = OAuth2SecuritySchemeSettingsImpl;
	/**
	 * Declares globally referable security schema definition
	 **/
	var OAuth2SecuritySchemeImpl = (function (_super) {
	    __extends(OAuth2SecuritySchemeImpl, _super);
	    function OAuth2SecuritySchemeImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createOAuth2SecurityScheme(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    OAuth2SecuritySchemeImpl.prototype.settings = function () {
	        return _super.prototype.element.call(this, 'settings');
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    OAuth2SecuritySchemeImpl.prototype.wrapperClassName = function () { return "OAuth2SecuritySchemeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    OAuth2SecuritySchemeImpl.prototype.kind = function () { return "OAuth2SecurityScheme"; };
	    /**
	     * @return RAML version of the node
	     **/
	    OAuth2SecuritySchemeImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return OAuth2SecuritySchemeImpl;
	}(AbstractSecuritySchemeImpl));
	exports.OAuth2SecuritySchemeImpl = OAuth2SecuritySchemeImpl;
	/**
	 * Declares globally referable security schema definition
	 **/
	var OAuth1SecuritySchemeImpl = (function (_super) {
	    __extends(OAuth1SecuritySchemeImpl, _super);
	    function OAuth1SecuritySchemeImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createOAuth1SecurityScheme(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    OAuth1SecuritySchemeImpl.prototype.settings = function () {
	        return _super.prototype.element.call(this, 'settings');
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    OAuth1SecuritySchemeImpl.prototype.wrapperClassName = function () { return "OAuth1SecuritySchemeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    OAuth1SecuritySchemeImpl.prototype.kind = function () { return "OAuth1SecurityScheme"; };
	    /**
	     * @return RAML version of the node
	     **/
	    OAuth1SecuritySchemeImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return OAuth1SecuritySchemeImpl;
	}(AbstractSecuritySchemeImpl));
	exports.OAuth1SecuritySchemeImpl = OAuth1SecuritySchemeImpl;
	/**
	 * Declares globally referable security schema definition
	 **/
	var BasicSecuritySchemeImpl = (function (_super) {
	    __extends(BasicSecuritySchemeImpl, _super);
	    function BasicSecuritySchemeImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createBasicSecurityScheme(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    BasicSecuritySchemeImpl.prototype.wrapperClassName = function () { return "BasicSecuritySchemeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    BasicSecuritySchemeImpl.prototype.kind = function () { return "BasicSecurityScheme"; };
	    /**
	     * @return RAML version of the node
	     **/
	    BasicSecuritySchemeImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return BasicSecuritySchemeImpl;
	}(AbstractSecuritySchemeImpl));
	exports.BasicSecuritySchemeImpl = BasicSecuritySchemeImpl;
	/**
	 * Declares globally referable security schema definition
	 **/
	var DigestSecuritySchemeImpl = (function (_super) {
	    __extends(DigestSecuritySchemeImpl, _super);
	    function DigestSecuritySchemeImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createDigestSecurityScheme(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    DigestSecuritySchemeImpl.prototype.wrapperClassName = function () { return "DigestSecuritySchemeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    DigestSecuritySchemeImpl.prototype.kind = function () { return "DigestSecurityScheme"; };
	    /**
	     * @return RAML version of the node
	     **/
	    DigestSecuritySchemeImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return DigestSecuritySchemeImpl;
	}(AbstractSecuritySchemeImpl));
	exports.DigestSecuritySchemeImpl = DigestSecuritySchemeImpl;
	/**
	 * Declares globally referable security schema definition
	 **/
	var CustomSecuritySchemeImpl = (function (_super) {
	    __extends(CustomSecuritySchemeImpl, _super);
	    function CustomSecuritySchemeImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createCustomSecurityScheme(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    CustomSecuritySchemeImpl.prototype.wrapperClassName = function () { return "CustomSecuritySchemeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    CustomSecuritySchemeImpl.prototype.kind = function () { return "CustomSecurityScheme"; };
	    /**
	     * @return RAML version of the node
	     **/
	    CustomSecuritySchemeImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return CustomSecuritySchemeImpl;
	}(AbstractSecuritySchemeImpl));
	exports.CustomSecuritySchemeImpl = CustomSecuritySchemeImpl;
	var MethodImpl = (function (_super) {
	    __extends(MethodImpl, _super);
	    function MethodImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createMethod(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * Method that can be called
	     **/
	    MethodImpl.prototype.method = function () {
	        return _super.prototype.attribute.call(this, 'method', this.toString);
	    };
	    /**
	     * @hidden
	     * Set method value
	     **/
	    MethodImpl.prototype.setMethod = function (param) {
	        this.highLevel().attrOrCreate("method").setValue("" + param);
	        return this;
	    };
	    /**
	     * Instantiation of applyed traits
	     **/
	    MethodImpl.prototype.is = function () {
	        return _super.prototype.attributes.call(this, 'is', function (attr) { return new TraitRefImpl(attr); });
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    MethodImpl.prototype.wrapperClassName = function () { return "MethodImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    MethodImpl.prototype.kind = function () { return "Method"; };
	    /**
	     * @return RAML version of the node
	     **/
	    MethodImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    /**
	     * For methods of Resources returns parent resource. For methods of ResourceTypes returns null.
	     **/
	    MethodImpl.prototype.parentResource = function () {
	        return helper.parentResource(this);
	    };
	    /**
	     * Api owning the resource as a sibling
	     **/
	    MethodImpl.prototype.ownerApi = function () {
	        return helper.ownerApi(this);
	    };
	    /**
	     * For methods of Resources: `{parent Resource relative path} {methodName}`.
	     * For methods of ResourceTypes: `{parent ResourceType name} {methodName}`.
	     * For other methods throws Exception.
	     **/
	    MethodImpl.prototype.methodId = function () {
	        return helper.methodId(this);
	    };
	    /**
	     * Returns security schemes, resource or method is secured with. If no security schemes are set at resource or method level,
	     * returns schemes defined with `securedBy` at API level.
	     * @deprecated
	     **/
	    MethodImpl.prototype.allSecuredBy = function () {
	        return helper.allSecuredBy(this);
	    };
	    return MethodImpl;
	}(MethodBaseImpl));
	exports.MethodImpl = MethodImpl;
	/**
	 * This sub type of the string represents mime types
	 **/
	var MimeTypeImpl = (function (_super) {
	    __extends(MimeTypeImpl, _super);
	    function MimeTypeImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    MimeTypeImpl.prototype.wrapperClassName = function () { return "MimeTypeImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    MimeTypeImpl.prototype.kind = function () { return "MimeType"; };
	    /**
	     * @return RAML version of the node
	     **/
	    MimeTypeImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return MimeTypeImpl;
	}(StringTypeImpl));
	exports.MimeTypeImpl = MimeTypeImpl;
	/**
	 * This type currently serves both for absolute and relative urls
	 **/
	var UriTemplateImpl = (function (_super) {
	    __extends(UriTemplateImpl, _super);
	    function UriTemplateImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    UriTemplateImpl.prototype.wrapperClassName = function () { return "UriTemplateImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    UriTemplateImpl.prototype.kind = function () { return "UriTemplate"; };
	    /**
	     * @return RAML version of the node
	     **/
	    UriTemplateImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return UriTemplateImpl;
	}(StringTypeImpl));
	exports.UriTemplateImpl = UriTemplateImpl;
	/**
	 * This  type describes relative uri templates
	 **/
	var RelativeUriStringImpl = (function (_super) {
	    __extends(RelativeUriStringImpl, _super);
	    function RelativeUriStringImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    RelativeUriStringImpl.prototype.wrapperClassName = function () { return "RelativeUriStringImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    RelativeUriStringImpl.prototype.kind = function () { return "RelativeUriString"; };
	    /**
	     * @return RAML version of the node
	     **/
	    RelativeUriStringImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return RelativeUriStringImpl;
	}(UriTemplateImpl));
	exports.RelativeUriStringImpl = RelativeUriStringImpl;
	/**
	 * This  type describes absolute uri templates
	 **/
	var FullUriTemplateStringImpl = (function (_super) {
	    __extends(FullUriTemplateStringImpl, _super);
	    function FullUriTemplateStringImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    FullUriTemplateStringImpl.prototype.wrapperClassName = function () { return "FullUriTemplateStringImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    FullUriTemplateStringImpl.prototype.kind = function () { return "FullUriTemplateString"; };
	    /**
	     * @return RAML version of the node
	     **/
	    FullUriTemplateStringImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return FullUriTemplateStringImpl;
	}(UriTemplateImpl));
	exports.FullUriTemplateStringImpl = FullUriTemplateStringImpl;
	var RAMLSimpleElementImpl = (function (_super) {
	    __extends(RAMLSimpleElementImpl, _super);
	    function RAMLSimpleElementImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    RAMLSimpleElementImpl.prototype.wrapperClassName = function () { return "RAMLSimpleElementImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    RAMLSimpleElementImpl.prototype.kind = function () { return "RAMLSimpleElement"; };
	    /**
	     * @return RAML version of the node
	     **/
	    RAMLSimpleElementImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return RAMLSimpleElementImpl;
	}(core.BasicNodeImpl));
	exports.RAMLSimpleElementImpl = RAMLSimpleElementImpl;
	var DocumentationItemImpl = (function (_super) {
	    __extends(DocumentationItemImpl, _super);
	    function DocumentationItemImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createDocumentationItem(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * title of documentation section
	     **/
	    DocumentationItemImpl.prototype.title = function () {
	        return _super.prototype.attribute.call(this, 'title', this.toString);
	    };
	    /**
	     * @hidden
	     * Set title value
	     **/
	    DocumentationItemImpl.prototype.setTitle = function (param) {
	        this.highLevel().attrOrCreate("title").setValue("" + param);
	        return this;
	    };
	    /**
	     * Content of documentation section
	     **/
	    DocumentationItemImpl.prototype.content = function () {
	        return _super.prototype.attribute.call(this, 'content', function (attr) { return new MarkdownStringImpl(attr); });
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    DocumentationItemImpl.prototype.wrapperClassName = function () { return "DocumentationItemImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    DocumentationItemImpl.prototype.kind = function () { return "DocumentationItem"; };
	    /**
	     * @return RAML version of the node
	     **/
	    DocumentationItemImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return DocumentationItemImpl;
	}(RAMLSimpleElementImpl));
	exports.DocumentationItemImpl = DocumentationItemImpl;
	/**
	 * Content of the schema
	 **/
	var GlobalSchemaImpl = (function (_super) {
	    __extends(GlobalSchemaImpl, _super);
	    function GlobalSchemaImpl(nodeOrKey, setAsTopLevel) {
	        _super.call(this, (typeof nodeOrKey == "string") ? createGlobalSchema(nodeOrKey) : nodeOrKey, setAsTopLevel);
	        this.nodeOrKey = nodeOrKey;
	        this.setAsTopLevel = setAsTopLevel;
	    }
	    /**
	     * Name of the global schema, used to refer on schema content
	     **/
	    GlobalSchemaImpl.prototype.key = function () {
	        return _super.prototype.attribute.call(this, 'key', this.toString);
	    };
	    /**
	     * @hidden
	     * Set key value
	     **/
	    GlobalSchemaImpl.prototype.setKey = function (param) {
	        this.highLevel().attrOrCreate("key").setValue("" + param);
	        return this;
	    };
	    /**
	     * Content of the schema
	     **/
	    GlobalSchemaImpl.prototype.value = function () {
	        return _super.prototype.attribute.call(this, 'value', function (attr) { return new SchemaStringImpl(attr); });
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    GlobalSchemaImpl.prototype.wrapperClassName = function () { return "GlobalSchemaImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    GlobalSchemaImpl.prototype.kind = function () { return "GlobalSchema"; };
	    /**
	     * @return RAML version of the node
	     **/
	    GlobalSchemaImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    return GlobalSchemaImpl;
	}(RAMLSimpleElementImpl));
	exports.GlobalSchemaImpl = GlobalSchemaImpl;
	var ResourceImpl = (function (_super) {
	    __extends(ResourceImpl, _super);
	    function ResourceImpl() {
	        _super.apply(this, arguments);
	    }
	    /**
	     * Relative URL of this resource from the parent resource
	     **/
	    ResourceImpl.prototype.relativeUri = function () {
	        return _super.prototype.attribute.call(this, 'relativeUri', function (attr) { return new RelativeUriStringImpl(attr); });
	    };
	    /**
	     * Instantiation of applyed resource type
	     **/
	    ResourceImpl.prototype["type"] = function () {
	        return _super.prototype.attribute.call(this, 'type', function (attr) { return new ResourceTypeRefImpl(attr); });
	    };
	    /**
	     * Instantiation of applyed traits
	     **/
	    ResourceImpl.prototype.is = function () {
	        return _super.prototype.attributes.call(this, 'is', function (attr) { return new TraitRefImpl(attr); });
	    };
	    /**
	     * securityScheme may also be applied to a resource by using the securedBy key, which is equivalent to applying the securityScheme to all methods that may be declared, explicitly or implicitly, by defining the resourceTypes or traits property for that resource. To indicate that the method may be called without applying any securityScheme, the method may be annotated with the null securityScheme.
	     **/
	    ResourceImpl.prototype.securedBy = function () {
	        return _super.prototype.attributes.call(this, 'securedBy', function (attr) { return new SecuritySchemeRefImpl(attr); });
	    };
	    /**
	     * Uri parameters of this resource
	     * @hidden
	     **/
	    ResourceImpl.prototype.uriParameters_original = function () {
	        return _super.prototype.elements.call(this, 'uriParameters');
	    };
	    /**
	     * Methods that can be called on this resource
	     **/
	    ResourceImpl.prototype.methods = function () {
	        return _super.prototype.elements.call(this, 'methods');
	    };
	    /**
	     * Children resources
	     **/
	    ResourceImpl.prototype.resources = function () {
	        return _super.prototype.elements.call(this, 'resources');
	    };
	    /**
	     * An alternate, human-friendly name for the resource
	     **/
	    ResourceImpl.prototype.displayName = function () {
	        return _super.prototype.attribute.call(this, 'displayName', this.toString);
	    };
	    /**
	     * @hidden
	     * Set displayName value
	     **/
	    ResourceImpl.prototype.setDisplayName = function (param) {
	        this.highLevel().attrOrCreate("displayName").setValue("" + param);
	        return this;
	    };
	    /**
	     * A resource or a method can override a base URI template's values. This is useful to restrict or change the default or parameter selection in the base URI. The baseUriParameters property MAY be used to override any or all parameters defined at the root level baseUriParameters property, as well as base URI parameters not specified at the root level.
	     **/
	    ResourceImpl.prototype.baseUriParameters = function () {
	        return _super.prototype.elements.call(this, 'baseUriParameters');
	    };
	    /**
	     * The description attribute describes the intended use or meaning of the $self. This value MAY be formatted using Markdown.
	     **/
	    ResourceImpl.prototype.description = function () {
	        return _super.prototype.attribute.call(this, 'description', function (attr) { return new MarkdownStringImpl(attr); });
	    };
	    /**
	     * @hidden
	     * @return Actual name of instance class
	     **/
	    ResourceImpl.prototype.wrapperClassName = function () { return "ResourceImpl"; };
	    /**
	     * @return Actual name of instance interface
	     **/
	    ResourceImpl.prototype.kind = function () { return "Resource"; };
	    /**
	     * @return RAML version of the node
	     **/
	    ResourceImpl.prototype.RAMLVersion = function () { return "RAML08"; };
	    /**
	     * Path relative to API root
	     **/
	    ResourceImpl.prototype.completeRelativeUri = function () {
	        return helper.completeRelativeUri(this);
	    };
	    /**
	     * baseUri of owning Api concatenated with completeRelativeUri
	     **/
	    ResourceImpl.prototype.absoluteUri = function () {
	        return helper.absoluteUri(this);
	    };
	    /**
	     * Parent resource for non top level resources
	     **/
	    ResourceImpl.prototype.parentResource = function () {
	        return helper.parent(this);
	    };
	    /**
	     * Get child resource by its relative path
	     **/
	    ResourceImpl.prototype.childResource = function (relPath) {
	        return helper.childResource(this, relPath);
	    };
	    /**
	     * Get child method by its name
	     **/
	    ResourceImpl.prototype.childMethod = function (method) {
	        return helper.childMethod(this, method);
	    };
	    /**
	     * Api owning the resource as a sibling
	     **/
	    ResourceImpl.prototype.ownerApi = function () {
	        return helper.ownerApi(this);
	    };
	    /**
	     * Uri parameters of this resource
	     **/
	    ResourceImpl.prototype.uriParameters = function () {
	        return helper.uriParametersPrimary(this);
	    };
	    /**
	     * Retrieve an ordered list of all uri parameters including those which are not described in the `uriParameters` node.
	     * Consider a fragment of RAML specification:
	     * ```yaml
	     * /resource/{objectId}/{propertyId}:
	     * uriParameters:
	     * objectId:
	     * ```
	     * Here `propertyId` uri parameter is not described in the `uriParameters` node,
	     * Thus, it is not among Resource.uriParameters(), but it is among Resource.allUriParameters().
	     * @deprecated
	     **/
	    ResourceImpl.prototype.allUriParameters = function () {
	        return helper.uriParameters(this);
	    };
	    /**
	     * Retrieve an ordered list of all absolute uri parameters. Returns a union of `Api.allBaseUriParameters()`
	     * for `Api` owning the `Resource` and `Resource.allUriParameters()`.
	     **/
	    ResourceImpl.prototype.absoluteUriParameters = function () {
	        return helper.absoluteUriParameters(this);
	    };
	    /**
	     * Returns security schemes, resource or method is secured with. If no security schemes are set at resource or method level,
	     * returns schemes defined with `securedBy` at API level.
	     * @deprecated
	     **/
	    ResourceImpl.prototype.allSecuredBy = function () {
	        return helper.allSecuredBy(this);
	    };
	    return ResourceImpl;
	}(core.BasicNodeImpl));
	exports.ResourceImpl = ResourceImpl;
	/**
	 * @hidden
	 **/
	function createApi(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("Api");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createTypeInstance(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("TypeInstance");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createTypeInstanceProperty(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("TypeInstanceProperty");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createResourceType(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("ResourceType");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createMethod(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("Method");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createMethodBase(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("MethodBase");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createResponse(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("Response");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createParameter(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("Parameter");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createStringTypeDeclaration(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("StringTypeDeclaration");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createBooleanTypeDeclaration(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("BooleanTypeDeclaration");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createNumberTypeDeclaration(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("NumberTypeDeclaration");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createIntegerTypeDeclaration(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("IntegerTypeDeclaration");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createDateTypeDeclaration(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("DateTypeDeclaration");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createFileTypeDeclaration(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("FileTypeDeclaration");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createBodyLike(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("BodyLike");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createXMLBody(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("XMLBody");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createJSONBody(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("JSONBody");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createAbstractSecurityScheme(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("AbstractSecurityScheme");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createSecuritySchemePart(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("SecuritySchemePart");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createTrait(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("Trait");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createSecuritySchemeSettings(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("SecuritySchemeSettings");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createOAuth1SecuritySchemeSettings(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("OAuth1SecuritySchemeSettings");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createOAuth2SecuritySchemeSettings(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("OAuth2SecuritySchemeSettings");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createOAuth2SecurityScheme(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("OAuth2SecurityScheme");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createOAuth1SecurityScheme(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("OAuth1SecurityScheme");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createBasicSecurityScheme(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("BasicSecurityScheme");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createDigestSecurityScheme(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("DigestSecurityScheme");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createCustomSecurityScheme(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("CustomSecurityScheme");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createGlobalSchema(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("GlobalSchema");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createRAMLSimpleElement(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("RAMLSimpleElement");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createDocumentationItem(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("DocumentationItem");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	/**
	 * @hidden
	 **/
	function createResource(key) {
	    var universe = def.getUniverse("RAML08");
	    var nc = universe.type("Resource");
	    var node = stubs.createStubNode(nc, null, key);
	    return node;
	}
	function loadApiSync(apiPath, arg1, arg2) {
	    return apiLoader.loadApi(apiPath, arg1, arg2).getOrElse(null);
	}
	exports.loadApiSync = loadApiSync;
	function loadRAMLSync(ramlPath, arg1, arg2) {
	    return apiLoader.loadApi(ramlPath, arg1, arg2).getOrElse(null);
	}
	exports.loadRAMLSync = loadRAMLSync;
	function loadApi(apiPath, arg1, arg2) {
	    return apiLoader.loadApiAsync(apiPath, arg1, arg2);
	}
	exports.loadApi = loadApi;
	function loadRAML(ramlPath, arg1, arg2) {
	    return apiLoader.loadRAMLAsync(ramlPath, arg1, arg2);
	}
	exports.loadRAML = loadRAML;
	/**
	 * Gets AST node by runtime type, if runtime type matches any.
	 * @param runtimeType - runtime type to find the match for
	 */
	function getLanguageElementByRuntimeType(runtimeType) {
	    return apiLoader.getLanguageElementByRuntimeType(runtimeType);
	}
	exports.getLanguageElementByRuntimeType = getLanguageElementByRuntimeType;
	//# sourceMappingURL=raml08parser.js.map

/***/ },
/* 46 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var RamlWrapperImpl = __webpack_require__(45);
	var factory = __webpack_require__(42);
	var core = __webpack_require__(50);
	var hl = __webpack_require__(10);
	var hlimpl = __webpack_require__(16);
	var universes = __webpack_require__(30);
	var expander = __webpack_require__(24);
	var lowLevelProxy = __webpack_require__(37);
	var linter = __webpack_require__(25);
	var util = __webpack_require__(43);
	var search = __webpack_require__(27);
	var universeHelpers = __webpack_require__(14);
	var ll = __webpack_require__(21);
	var path = __webpack_require__(15);
	//export function resolveType(p:RamlWrapper.TypeDeclaration):hl.ITypeDefinition{
	//    var tpe=typeexpression.typeFromNode(p.highLevel());
	//    return tpe.toRuntime();
	//}
	function load(pth) {
	    var m = new ll.Project(path.dirname(pth));
	    var unit = m.unit(path.basename(pth));
	    if (unit) {
	        if (unit.isRAMLUnit()) {
	            return hlimpl.fromUnit(unit).wrapperNode();
	        }
	    }
	    return null;
	}
	exports.load = load;
	/**
	 * __$helperMethod__
	 * Equivalent API with traits and resource types expanded
	 * __$meta__={"name":"expand"}
	 **/
	function expandTraitsAndResourceTypes(api) {
	    var lowLevelNode = api.highLevel().lowLevel();
	    if (lowLevelNode instanceof lowLevelProxy.LowLevelProxyNode) {
	        return api;
	    }
	    return expander.expandTraitsAndResourceTypes(api);
	}
	exports.expandTraitsAndResourceTypes = expandTraitsAndResourceTypes;
	//__$helperMethod__ Path relative to API root
	function completeRelativeUri(res) {
	    var uri = '';
	    var parent = res;
	    do {
	        res = parent; //(parent instanceof RamlWrapper.ResourceImpl) ? <RamlWrapper.Resource>parent : null;
	        uri = res.relativeUri().value() + uri;
	        parent = res.parent();
	    } while (parent.definition().key().name == universes.Universe08.Resource.name);
	    return uri;
	}
	exports.completeRelativeUri = completeRelativeUri;
	//__$helperMethod__ baseUri of owning Api concatenated with completeRelativeUri
	function absoluteUri(res) {
	    var uri = '';
	    var parent = res;
	    do {
	        res = parent; //(parent instanceof RamlWrapper.ResourceImpl) ? <RamlWrapper.Resource>parent : null;
	        uri = res.relativeUri().value() + uri;
	        parent = res.parent();
	    } while (parent.definition().key().name == universes.Universe08.Resource.name);
	    uri = uri.replace(/\/\//g, '/');
	    var buri = parent.baseUri();
	    var base = buri ? buri.value() : "";
	    base = base ? base : '';
	    if (util.stringEndsWith(base, '/')) {
	        uri = uri.substring(1);
	    }
	    uri = base + uri;
	    return uri;
	}
	exports.absoluteUri = absoluteUri;
	function qName(c) {
	    return hlimpl.qName(c.highLevel(), c.highLevel().root());
	}
	exports.qName = qName;
	/**
	 * __$helperMethod__
	 * __$meta__{"name":"traits","override":true}
	 **/
	function traitsPrimary(a) {
	    return allTraits(a);
	}
	exports.traitsPrimary = traitsPrimary;
	/**
	 * __$helperMethod__ Retrieve all traits including those defined in libraries *
	 * __$meta__{"deprecated":true}
	 */
	function allTraits(a) {
	    return findTemplates(a, function (d) { return universeHelpers.isTraitType(d); });
	}
	exports.allTraits = allTraits;
	/**
	 *__$helperMethod__
	 *__$meta__{"name":"resourceTypes","override":true}
	 **/
	function resourceTypesPrimary(a) {
	    return allResourceTypes(a);
	}
	exports.resourceTypesPrimary = resourceTypesPrimary;
	/**
	 * __$helperMethod__ Retrieve all resource types including those defined in libraries
	 * __$meta__{"deprecated":true}
	 */
	function allResourceTypes(a) {
	    return findTemplates(a, function (d) { return universeHelpers.isResourceTypeType(d); });
	}
	exports.allResourceTypes = allResourceTypes;
	function findTemplates(a, filter) {
	    var arr = search.globalDeclarations(a.highLevel()).filter(function (x) { return filter(x.definition()); });
	    var ll = a.highLevel().lowLevel();
	    var nodePath = ll.includePath();
	    if (!nodePath) {
	        nodePath = ll.unit().path();
	    }
	    var topLevelArr = arr.map(function (x) {
	        var topLevelNode;
	        var p = x.lowLevel().unit().path();
	        if (p != nodePath) {
	            topLevelNode = factory.buildWrapperNode(x, false);
	            topLevelNode.meta().setCalculated();
	        }
	        else {
	            topLevelNode = x.wrapperNode();
	        }
	        return topLevelNode;
	    });
	    return topLevelArr;
	}
	;
	function relativeUriSegments(res) {
	    var result = [];
	    var parent = res;
	    do {
	        res = parent; //(parent instanceof RamlWrapper.ResourceImpl) ? <RamlWrapper.Resource>parent : null;
	        result.push(res.relativeUri().value());
	        parent = res.parent();
	    } while (parent.definition().key().name == universes.Universe08.Resource.name);
	    return result.reverse();
	}
	exports.relativeUriSegments = relativeUriSegments;
	//__$helperMethod__ For methods of Resources returns parent resource. For methods of ResourceTypes returns null.
	function parentResource(method) {
	    if (method.parent() instanceof RamlWrapperImpl.ResourceImpl) {
	        return method.parent();
	    }
	    return null;
	}
	exports.parentResource = parentResource;
	//__$helperMethod__ Parent resource for non top level resources __$meta__={"name":"parentResource"}
	function parent(resource) {
	    var parent = resource.parent();
	    if (parent.definition().key().name == universes.Universe08.Resource.name) {
	        parent;
	    }
	    return null;
	}
	exports.parent = parent;
	//__$helperMethod__ Get child resource by its relative path
	function childResource(container, relPath) {
	    if (container == null) {
	        return null;
	    }
	    var resources = container.resources();
	    if (!resources) {
	        return null;
	    }
	    resources = resources.filter(function (x) { return x.relativeUri().value() == relPath; });
	    if (resources.length == 0) {
	        return null;
	    }
	    return resources[0];
	}
	exports.childResource = childResource;
	function getResource(container, path) {
	    if (!container) {
	        return null;
	    }
	    var res = null;
	    for (var i = 0; i < path.length; i++) {
	        res = childResource(container, path[i]);
	        if (!res) {
	            return null;
	        }
	        container = res;
	    }
	    return res;
	}
	exports.getResource = getResource;
	//__$helperMethod__ Get child method by its name
	function childMethod(resource, method) {
	    if (!resource) {
	        return null;
	    }
	    return resource.methods().filter(function (x) { return x.method() == method; });
	}
	exports.childMethod = childMethod;
	function getMethod(container, path, method) {
	    var resource = getResource(container, path);
	    if (resource == null) {
	        return null;
	    }
	    return childMethod(resource, method);
	}
	exports.getMethod = getMethod;
	function isApi(obj) {
	    return (obj.definition().key().name == universes.Universe08.Api.name);
	}
	;
	//__$helperMethod__ Api owning the resource as a sibling
	function ownerApi(method) {
	    var obj = method;
	    while (!isApi(obj)) {
	        obj = obj.parent();
	    }
	    return obj;
	}
	exports.ownerApi = ownerApi;
	/**
	 * __$helperMethod__
	 * For methods of Resources: `{parent Resource relative path} {methodName}`.
	 * For methods of ResourceTypes: `{parent ResourceType name} {methodName}`.
	 * For other methods throws Exception.
	 **/
	function methodId(method) {
	    var parent = method.parent();
	    if (parent instanceof RamlWrapperImpl.ResourceImpl) {
	        return completeRelativeUri(parent) + ' ' + method.method().toLowerCase();
	    }
	    else if (parent instanceof RamlWrapperImpl.ResourceTypeImpl) {
	        return parent.name() + ' ' + method.method().toLowerCase();
	    }
	    throw new Error("Method is supposed to be owned by Resource or ResourceType.\nHere the method is owned by " + method.definition().key().name);
	}
	exports.methodId = methodId;
	//__$helperMethod__ true for codes < 400 and false otherwise
	function isOkRange(response) {
	    var str = response.code().value();
	    var err = linter.validateResponseString(str);
	    if (err != null) {
	        return false;
	    }
	    try {
	        if (parseInt(str.charAt(0)) < 4) {
	            return true;
	        }
	    }
	    catch (e) { }
	    return false;
	}
	exports.isOkRange = isOkRange;
	//__$helperMethod__  Retrieve all resources of the Api
	function allResources(api) {
	    var resources = [];
	    var visitor = function (res) {
	        resources.push(res);
	        res.resources().forEach(function (x) { return visitor(x); });
	    };
	    api.resources().forEach(function (x) { return visitor(x); });
	    return resources;
	}
	exports.allResources = allResources;
	//export function matchUri(apiRootRelativeUri:string, resource:RamlWrapper.Resource):Opt<ParamValue[]>{
	//
	//    var allParameters:Raml08Parser.NamedParameterMap = {}
	//    var opt:Opt<RamlWrapper.Resource> = new Opt<RamlWrapper.Resource>(resource);
	//    while(opt.isDefined()){
	//        var res:RamlWrapper.Resource = opt.getOrThrow();
	//        uriParameters(res).forEach(x=>allParameters[x.name()]=new ParamWrapper(x));
	//        opt = parent(res);
	//    }
	//    var result = ramlPathMatch(completeRelativeUri(resource), allParameters, {})(apiRootRelativeUri);
	//    if (result) {
	//        return new Opt<ParamValue[]>(Object.keys((<any>result).params)
	//            .map(x=>new ParamValue(x, result['params'][x])));
	//    }
	//    return Opt.empty<ParamValue[]>();
	//}
	var schemaContentChars = ['{', '<'];
	//export function schema(body:RamlWrapper.TypeDeclaration, api:RamlWrapper.Api):Opt<SchemaDef>{
	//
	//    var schemaNode = body.schema();
	//    if(!schemaNode){
	//        return Opt.empty<SchemaDef>();
	//    }
	//    var schemaString = schemaNode;
	//    var isContent:boolean = false;
	//    schemaContentChars.forEach(x=>{try{ isContent = isContent||schemaString.indexOf(x)>=0}catch(e){}});
	//    var schDef:SchemaDef;
	//    if(isContent) {
	//        schDef = new SchemaDef(schemaString);
	//    }
	//    else{
	//        var globalSchemes = api.schemas().filter(x=>x.key()==schemaString);
	//        if(globalSchemes.length>0){
	//            schDef = new SchemaDef(globalSchemes[0].value().value(),globalSchemes[0].key());
	//        }
	//        else{
	//            return Opt.empty<SchemaDef>();
	//        }
	//    }
	//    return new Opt<SchemaDef>(schDef);
	//}
	/**
	 * __$helperMethod__
	 * Retrieve an ordered list of all uri parameters including those which are not described in the `uriParameters` node.
	 * Consider a fragment of RAML specification:
	 * ```yaml
	 * /resource/{objectId}/{propertyId}:
	 *   uriParameters:
	 *     objectId:
	 * ```
	 * Here `propertyId` uri parameter is not described in the `uriParameters` node,
	 * but it is among Resource.uriParameters().
	 * __$meta__={"name":"uriParameters","override": true}
	 **/
	function uriParametersPrimary(resource) {
	    return uriParameters(resource);
	}
	exports.uriParametersPrimary = uriParametersPrimary;
	/**
	 * __$helperMethod__
	 * Retrieve an ordered list of all uri parameters including those which are not described in the `uriParameters` node.
	 * Consider a fragment of RAML specification:
	 * ```yaml
	 * /resource/{objectId}/{propertyId}:
	 *   uriParameters:
	 *     objectId:
	 * ```
	 * Here `propertyId` uri parameter is not described in the `uriParameters` node,
	 * Thus, it is not among Resource.uriParameters(), but it is among Resource.allUriParameters().
	 * __$meta__={"name":"allUriParameters","deprecated":true}
	 **/
	function uriParameters(resource) {
	    var uri = resource.relativeUri().value();
	    var params = resource.uriParameters_original();
	    var propName = universes.Universe08.Resource.properties.uriParameters.name;
	    return extractParams(params, uri, resource, propName);
	}
	exports.uriParameters = uriParameters;
	/**
	 * __$helperMethod__
	 * Retrieve an ordered list of all base uri parameters regardless of whether they are described in `baseUriParameters` or not
	 * Consider a fragment of RAML specification:
	 * ```yaml
	 * version: v1
	 * baseUri: https://{organization}.example.com/{version}/{service}
	 * baseUriParameters:
	 *   service:
	 * ```
	 * Here `version` and `organization` are base uri parameters which are not described in the `baseUriParameters` node,
	 * but they are among `Api.baseUriParameters()`.
	 * __$meta__={"name":"baseUriParameters","override":true}
	 **/
	function baseUriParametersPrimary(api) {
	    return baseUriParameters(api);
	}
	exports.baseUriParametersPrimary = baseUriParametersPrimary;
	/**
	 * __$helperMethod__
	 * Retrieve an ordered list of all base uri parameters regardless of whether they are described in `baseUriParameters` or not
	 * Consider a fragment of RAML specification:
	 * ```yaml
	 * version: v1
	 * baseUri: https://{organization}.example.com/{version}/{service}
	 * baseUriParameters:
	 *   service:
	 * ```
	 * Here `version` and `organization` are base uri parameters which are not described in the `baseUriParameters` node,
	 * Thus, they are not among `Api.baseUriParameters()`, but they are among `Api.allBaseUriParameters()`.
	 * __$meta__={"name":"allBaseUriParameters","deprecated":true}
	 **/
	function baseUriParameters(api) {
	    var uri = api.baseUri() ? api.baseUri().value() : '';
	    var params = api.baseUriParameters_original();
	    var propName = universes.Universe08.Api.properties.baseUriParameters.name;
	    return extractParams(params, uri, api, propName);
	}
	exports.baseUriParameters = baseUriParameters;
	/**
	 * __$helperMethod__
	 * Retrieve an ordered list of all absolute uri parameters. Returns a union of `Api.allBaseUriParameters()`
	 * for `Api` owning the `Resource` and `Resource.allUriParameters()`.
	 **/
	function absoluteUriParameters(res) {
	    var params = [];
	    var parent = res;
	    do {
	        res = parent;
	        params = uriParameters(res).concat(params);
	        parent = res.parent();
	    } while (parent.definition().key().name == universes.Universe10.Resource.name);
	    var api = parent;
	    var baseUri = api.baseUri().value();
	    var baseUriParams = api.baseUriParameters();
	    params = baseUriParameters(api).concat(params);
	    return params;
	}
	exports.absoluteUriParameters = absoluteUriParameters;
	/**
	 * _//_$helperMethod__
	 * Protocols used by the API. Returns the `protocols` property value if it is specified.
	 * Otherwise, returns protocol, specified in the base URI.
	 * __$meta__={"name":"protocols","override":true}
	 **/
	function protocolsPrimary(api) {
	    return allProtocols(api);
	}
	exports.protocolsPrimary = protocolsPrimary;
	/**
	 * __$helperMethod__
	 * Protocols used by the API. Returns the `protocols` property value if it is specified.
	 * Otherwise, returns protocol, specified in the base URI.
	 * __$meta__{"deprecated":true}
	 **/
	function allProtocols(api) {
	    return api.protocols().map(function (x) { return x.toUpperCase(); });
	    //var attributeDefaults = (<RamlWrapper.ApiImpl>api).attributeDefaults();
	    //var result = (<RamlWrapper.ApiImpl>api).protocols_original();
	    //if(result.length!=0||!attributeDefaults){
	    //    return result;
	    //}
	    //var baseUriAttr = api.baseUri();
	    //if(baseUriAttr) {
	    //    var baseUri = baseUriAttr.value();
	    //    if (baseUri) {
	    //        var ind = baseUri.indexOf('://');
	    //        if (ind >= 0) {
	    //            result = [baseUri.substring(0, ind)];
	    //        }
	    //        if(result.length==0){
	    //            result = [ 'HTTP' ];
	    //        }
	    //    }
	    //}
	    //return result;
	}
	exports.allProtocols = allProtocols;
	/**
	 * _//_$helperMethod__
	 * Returns security schemes, resource or method is secured with. If no security schemes are set at resource or method level,
	 * returns schemes defined with `securedBy` at API level.
	 * __$meta__={"name":"securedBy","override":true}
	 **/
	function securedByPrimary(resourceOrMethod) {
	    return allSecuredBy(resourceOrMethod);
	}
	exports.securedByPrimary = securedByPrimary;
	/**
	 * __$helperMethod__
	 * Returns security schemes, resource or method is secured with. If no security schemes are set at resource or method level,
	 * returns schemes defined with `securedBy` at API level.
	 * __$meta__{"deprecated":true}
	 **/
	function allSecuredBy(resourceOrMethod) {
	    //var currentSecuredBy = (<RamlWrapper.ResourceImpl|RamlWrapper.MethodImpl>resourceOrMethod).securedBy_original();
	    //if (currentSecuredBy && currentSecuredBy.length > 0) {
	    //    return currentSecuredBy;
	    //}
	    //
	    ////instanceof, but have to avoid direct usage of instanceof in JS.
	    //if (resourceOrMethod.highLevel().definition().key() == universes.Universe08.Method) {
	    //    var resource = <RamlWrapper.ResourceImpl>(<RamlWrapper.Method>resourceOrMethod).parentResource();
	    //    if (resource && resource.securedBy_original() && resource.securedBy_original().length > 0) {
	    //        return resource.securedBy();
	    //    }
	    //}
	    return resourceOrMethod.securedBy();
	}
	exports.allSecuredBy = allSecuredBy;
	/**
	 * __$helperMethod__
	 * __$meta__={"primary":true}
	 **/
	function securitySchemeName(schemeReference) {
	    var highLevel = schemeReference.highLevel();
	    if (!highLevel)
	        return "";
	    var attributeValue = highLevel.value();
	    if (!attributeValue)
	        return "";
	    return attributeValue.toString();
	}
	exports.securitySchemeName = securitySchemeName;
	/**
	 * __$helperMethod__
	 * __$meta__={"primary":true}
	 **/
	function securityScheme(schemeReference) {
	    var highLevel = schemeReference.highLevel();
	    if (!highLevel)
	        return null;
	    var declaration = search.findDeclarationByNode(highLevel, search.LocationKind.VALUE_COMPLETION);
	    if (!declaration)
	        return null;
	    if (!declaration.getKind || declaration.getKind() != hl.NodeKind.NODE) {
	        return null;
	    }
	    var result = declaration.wrapperNode();
	    if (!(result instanceof RamlWrapperImpl.AbstractSecuritySchemeImpl)) {
	        //I do not see how to avoid instanceof here
	        return null;
	    }
	    return result;
	}
	exports.securityScheme = securityScheme;
	/**
	 * __$helperMethod__
	 * __$meta__={"primary":true}
	 **/
	function RAMLVersion(api) {
	    return api.highLevel().definition().universe().version();
	}
	exports.RAMLVersion = RAMLVersion;
	/**
	 * __$helperMethod__
	 * __$meta__={"primary":true}
	 **/
	function structuredValue(reference) {
	    var hl = reference.value().lowLevel();
	    return new core.TypeInstanceImpl(hl);
	}
	exports.structuredValue = structuredValue;
	/**
	 * __$helperMethod__
	 * __$meta__={"name":"name","primary":true}
	 **/
	function referenceName(reference) {
	    var val = reference.highLevel().value();
	    return (typeof val == 'string') || val == null ? val : val.valueName();
	}
	exports.referenceName = referenceName;
	/**
	 * __$helperMethod__
	 * __$meta__={"name":"trait","primary":true}
	 **/
	function referencedTrait(ref) {
	    return referencedObject(ref);
	}
	exports.referencedTrait = referencedTrait;
	/**
	 * __$helperMethod__
	 * __$meta__={"name":"resourceType","primary":true}
	 **/
	function referencedResourceType(ref) {
	    return referencedObject(ref);
	}
	exports.referencedResourceType = referencedResourceType;
	function referencedObject(ref) {
	    var attr = ref.highLevel();
	    var parent = attr.parent();
	    var vn = ref.name();
	    var cands = search.referenceTargets(attr.property(), parent).filter(function (x) { return hlimpl.qName(x, parent) == vn; });
	    if (cands.length == 0) {
	        return null;
	    }
	    return cands[0].wrapperNode();
	}
	function extractParams(params, uri, owner, propName) {
	    var ownerHl = owner.highLevel();
	    var prop = ownerHl.definition().property(propName);
	    if (!uri) {
	        return [];
	    }
	    var describedParams = {};
	    params.forEach(function (x) {
	        var arr = describedParams[x.name()];
	        if (!arr) {
	            arr = [];
	            describedParams[x.name()] = arr;
	        }
	        arr.push(x);
	    });
	    var allParams = [];
	    var prev = 0;
	    var mentionedParams = {};
	    for (var i = uri.indexOf('{'); i >= 0; i = uri.indexOf('{', prev)) {
	        prev = uri.indexOf('}', ++i);
	        var paramName = uri.substring(i, prev);
	        mentionedParams[paramName] = true;
	        if (describedParams[paramName]) {
	            describedParams[paramName].forEach(function (x) { return allParams.push(x); });
	        }
	        else {
	            var uriParameter = new RamlWrapperImpl.StringTypeDeclarationImpl(paramName);
	            uriParameter.setName(paramName);
	            var hlNode = uriParameter.highLevel();
	            hlNode.setParent(ownerHl);
	            uriParameter.meta().setCalculated();
	            hlNode.patchProp(prop);
	            allParams.push(uriParameter);
	        }
	    }
	    Object.keys(describedParams).filter(function (x) { return !mentionedParams[x]; })
	        .forEach(function (x) { return describedParams[x].forEach(function (y) { return allParams.push(y); }); });
	    return allParams;
	}
	;
	/**
	 * __$helperMethod__
	 * __$meta__={"primary":true}
	 **/
	function schemaContent(bodyDeclaration) {
	    var schemaDecl = bodyDeclaration.schema();
	    if (schemaDecl == null) {
	        return null;
	    }
	    var schemaString = schemaDecl.value();
	    if (!schemaString) {
	        return null;
	    }
	    var schemaAttribute = bodyDeclaration.highLevel().attr(universes.Universe08.BodyLike.properties.schema.name);
	    if (!schemaAttribute) {
	        return schemaString;
	    }
	    var declaration = search.findDeclarationByNode(schemaAttribute, search.LocationKind.VALUE_COMPLETION);
	    if (!declaration)
	        return schemaString;
	    if (!declaration.getKind || declaration.getKind() != hl.NodeKind.NODE) {
	        return schemaString;
	    }
	    //we found the schema declaration and should get its contents
	    if (declaration.definition().key() != universes.Universe08.GlobalSchema) {
	        return schemaString;
	    }
	    var valueAttribute = declaration.attr(universes.Universe08.GlobalSchema.properties.value.name);
	    if (valueAttribute == null) {
	        return null;
	    }
	    return valueAttribute.value();
	}
	exports.schemaContent = schemaContent;
	/**
	 * __$helperMethod__
	 * __$meta__={"name":"parametrizedProperties","primary":true}
	 **/
	function getTemplateParametrizedProperties(node) {
	    var highLevelNode = node.highLevel();
	    if (highLevelNode == null) {
	        return null;
	    }
	    var lowLevelNode = highLevelNode.lowLevel();
	    if (lowLevelNode == null) {
	        return null;
	    }
	    var children = lowLevelNode.children().filter(function (x) { return x.key().indexOf("<<") >= 0; });
	    if (children.length == 0) {
	        return null;
	    }
	    var result = new core.TypeInstanceImpl(children);
	    return result;
	}
	exports.getTemplateParametrizedProperties = getTemplateParametrizedProperties;
	//
	//export class SchemaDef{
	//
	//    constructor(private _content:string, private _name?:string){}
	//
	//    name():string{return this._name}
	//
	//    content(): string{return this._content}
	//}
	//
	//
	//export class ParamValue{
	//    key:string
	//    value:any
	//
	//    constructor(key:string, value:any) {
	//        this.key = key;
	//        this.value = value;
	//    }
	//}
	//
	//
	//class ParamWrapper implements Raml08Parser.BasicNamedParameter{
	//
	//    constructor(private _param:RamlWrapper.TypeDeclaration){
	//
	//        this.description = _param.description() ? _param.description().value() : this.description;
	//
	//        this.displayName = _param.displayName();
	//
	////        this.enum = _param.enum();
	//
	//        this.type = _param.type().length > 0 ? _param.type()[0] : "string";
	//
	//        this.example = _param.example();
	//
	//        this.repeat = _param.repeat();
	//
	//        this.required = _param.required();
	//
	//        this.default = _param.default();
	//    }
	//
	//    description: Raml08Parser.MarkdownString
	//
	//    displayName: string
	//
	//    'enum': any[]
	//
	//    type: string
	//
	//    example: any
	//
	//    repeat: boolean
	//
	//    required: boolean
	//
	//    'default': any
	//
	//}
	//# sourceMappingURL=wrapperHelper08.js.map

/***/ },
/* 47 */
/***/ function(module, exports, __webpack_require__) {

	/// <reference path="../../../typings/main.d.ts" />
	"use strict";
	/**
	 * Created by kor on 05/05/15.
	 */
	var yaml = __webpack_require__(70);
	var lowlevel = __webpack_require__(11);
	var hlimpl = __webpack_require__(16);
	var util = __webpack_require__(43);
	var llImpl = __webpack_require__(21);
	var Error = yaml.YAMLException;
	var CompilationUnit = (function () {
	    function CompilationUnit(_absolutePath, _path, _content, _project, _isTopoLevel, serializeOptions) {
	        if (serializeOptions === void 0) { serializeOptions = {}; }
	        this._absolutePath = _absolutePath;
	        this._path = _path;
	        this._content = _content;
	        this._project = _project;
	        this._isTopoLevel = _isTopoLevel;
	        this.serializeOptions = serializeOptions;
	        this._node = new AstNode(this, JSON.parse(this._content), null, serializeOptions);
	    }
	    CompilationUnit.prototype.highLevel = function () {
	        return hlimpl.fromUnit(this);
	    };
	    CompilationUnit.prototype.absolutePath = function () {
	        return this._absolutePath;
	    };
	    CompilationUnit.prototype.clone = function () {
	        return null;
	    };
	    CompilationUnit.prototype.contents = function () {
	        return this._content;
	    };
	    CompilationUnit.prototype.lexerErrors = function () {
	        return [];
	    };
	    CompilationUnit.prototype.path = function () {
	        return this._content;
	    };
	    CompilationUnit.prototype.isTopLevel = function () {
	        return this._isTopoLevel;
	    };
	    CompilationUnit.prototype.ast = function () {
	        return this._node;
	    };
	    CompilationUnit.prototype.expandedHighLevel = function () {
	        return this.highLevel();
	    };
	    CompilationUnit.prototype.isDirty = function () {
	        return true;
	    };
	    CompilationUnit.prototype.getIncludeNodes = function () {
	        return [];
	    };
	    CompilationUnit.prototype.resolveAsync = function (p) {
	        return null;
	    };
	    CompilationUnit.prototype.isRAMLUnit = function () {
	        return true;
	    };
	    CompilationUnit.prototype.project = function () {
	        return this._project;
	    };
	    CompilationUnit.prototype.updateContent = function (newContent) { };
	    CompilationUnit.prototype.ramlVersion = function () {
	        throw new Error('not implemented');
	    };
	    CompilationUnit.prototype.lineMapper = function () { return new lowlevel.LineMapperImpl(this.contents(), this.absolutePath()); };
	    CompilationUnit.prototype.resolve = function (p) { return null; }; // TODO FIXME 
	    /**
	     * Returns true if this unit is overlay or extension, false otherwise.
	     */
	    CompilationUnit.prototype.isOverlayOrExtension = function () {
	        return false;
	    };
	    /**
	     * Returns master reference if presents, null otherwise.
	     */
	    CompilationUnit.prototype.getMasterReferenceNode = function () {
	        return null;
	    };
	    return CompilationUnit;
	}());
	exports.CompilationUnit = CompilationUnit;
	//export interface IProject{
	//    units():ICompilationUnit[];//returns units with apis in this folder
	//
	//    execute(cmd:CompositeCommand)
	//
	//    executeTextChange(textCommand:TextChangeCommand);//this may result in broken nodes?
	//
	//    addListener(listener:IASTListener);
	//
	//    removeListener(listener:IASTListener)
	//
	//    addTextChangeListener(listener:ITextChangeCommandListener);
	//    removeTextChangeListener(listener:ITextChangeCommandListener);
	//}
	//export interface IASTListener{
	//    (delta:ASTDelta)
	//}
	//
	//export interface ITextChangeCommandListener{
	//    (delta:TextChangeCommand)
	//}
	//export class ASTDelta{
	//    commands:ASTChangeCommand[]
	//}
	//export interface ASTVisitor{
	//    (node:ILowLevelASTNode):boolean
	//}
	var AstNode = (function () {
	    function AstNode(_unit, _object, _parent, options, _key) {
	        var _this = this;
	        if (options === void 0) { options = {}; }
	        this._unit = _unit;
	        this._object = _object;
	        this._parent = _parent;
	        this.options = options;
	        this._key = _key;
	        this._isOptional = false;
	        if (this._object instanceof Object) {
	            Object.keys(this._object).forEach(function (x) {
	                var u = unescapeKey(x, _this.options);
	                if (u != x) {
	                    var val = _this._object[x];
	                    delete _this._object[x];
	                    _this._object[u] = val;
	                }
	            });
	        }
	        if (this._key) {
	            if (util.stringEndsWith(this._key, '?')) {
	                this._isOptional = true;
	                this._key = this._key.substring(0, this._key.length - 1);
	            }
	        }
	    }
	    AstNode.prototype.keyKind = function () {
	        return null;
	    };
	    AstNode.prototype.isAnnotatedScalar = function () {
	        return false;
	    };
	    AstNode.prototype.hasInnerIncludeError = function () {
	        return false;
	    };
	    AstNode.prototype.start = function () { return -1; };
	    AstNode.prototype.end = function () { return -1; };
	    AstNode.prototype.value = function () {
	        return this._object;
	    };
	    AstNode.prototype.actual = function () {
	        return this._object;
	    };
	    AstNode.prototype.includeErrors = function () { return []; };
	    AstNode.prototype.includePath = function () { return null; };
	    AstNode.prototype.includeReference = function () { return null; };
	    AstNode.prototype.key = function () { return this._key; };
	    AstNode.prototype.optional = function () { return this._isOptional; };
	    AstNode.prototype.children = function () {
	        var _this = this;
	        if (!this._object) {
	            return [];
	        }
	        if (Array.isArray(this._object)) {
	            return this._object.map(function (x) { return new AstNode(_this._unit, x, _this, _this.options); });
	        }
	        else if (this._object instanceof Object) {
	            return Object.keys(this._object).map(function (x) { return new AstNode(_this._unit, _this._object[x], _this, _this.options, x); });
	        }
	        else {
	            return [];
	        }
	    };
	    AstNode.prototype.parent = function () { return this._parent; };
	    AstNode.prototype.unit = function () { return this._unit; };
	    AstNode.prototype.includeBaseUnit = function () { return this._unit; };
	    AstNode.prototype.anchorId = function () { return null; };
	    AstNode.prototype.errors = function () { return []; };
	    AstNode.prototype.anchoredFrom = function () { return this; };
	    AstNode.prototype.includedFrom = function () { return this; };
	    AstNode.prototype.visit = function (v) {
	        if (v(this)) {
	            this.children().forEach(function (x) { return x.visit(v); });
	        }
	    };
	    AstNode.prototype.dumpToObject = function () {
	        return this._object;
	    };
	    AstNode.prototype.addChild = function (n) { };
	    AstNode.prototype.execute = function (cmd) { };
	    AstNode.prototype.dump = function () { return JSON.stringify(this._object); };
	    AstNode.prototype.keyStart = function () { return -1; };
	    AstNode.prototype.keyEnd = function () { return -1; };
	    AstNode.prototype.valueStart = function () { return -1; };
	    AstNode.prototype.valueEnd = function () { return -1; };
	    AstNode.prototype.isValueLocal = function () { return true; };
	    AstNode.prototype.kind = function () {
	        if (Array.isArray(this._object)) {
	            return yaml.Kind.SEQ;
	        }
	        else if (this._object instanceof Object) {
	            return yaml.Kind.MAP;
	        }
	        else {
	            return yaml.Kind.SCALAR;
	        }
	    };
	    AstNode.prototype.valueKind = function () { return null; };
	    AstNode.prototype.show = function (msg) { };
	    AstNode.prototype.setHighLevelParseResult = function (highLevelParseResult) {
	        this._highLevelParseResult = highLevelParseResult;
	    };
	    AstNode.prototype.highLevelParseResult = function () {
	        return this._highLevelParseResult;
	    };
	    AstNode.prototype.setHighLevelNode = function (highLevel) {
	        this._highLevelNode = highLevel;
	    };
	    AstNode.prototype.highLevelNode = function () {
	        return this._highLevelNode;
	    };
	    AstNode.prototype.text = function (unitText) {
	        throw new Error("not implemented");
	    };
	    AstNode.prototype.copy = function () {
	        throw new Error("not implemented");
	    };
	    AstNode.prototype.markup = function (json) {
	        throw new Error("not implemented");
	    };
	    AstNode.prototype.nodeDefinition = function () {
	        return llImpl.getDefinitionForLowLevelNode(this);
	    };
	    AstNode.prototype.includesContents = function () {
	        return false;
	    };
	    return AstNode;
	}());
	exports.AstNode = AstNode;
	function serialize(node, options) {
	    if (options === void 0) { options = {}; }
	    if (node.children().length == 0) {
	        if (node.value()) {
	            return node.value();
	        }
	        return '';
	    }
	    if (!node.children()[0].key()) {
	        var arr = [];
	        node.children().forEach(function (x) {
	            arr.push(serialize(x, options));
	        });
	        return arr;
	    }
	    else {
	        var obj = {};
	        node.children().forEach(function (x) {
	            obj[escapeKey(x.key(), options)] = serialize(x, options);
	        });
	        if (options && options.writeErrors) {
	            var errors = collectErrors(node);
	            if (errors != null && errors.length > 0) {
	                obj['__$errors__'] = errors;
	            }
	        }
	        return obj;
	    }
	}
	exports.serialize = serialize;
	function collectErrors(node) {
	    var errors = [].concat(node.errors());
	    node.children().forEach(function (ch) {
	        var children = ch.children();
	        if (children.length == 0) {
	            ch.errors().forEach(function (e) { return errors.push(e); });
	            return;
	        }
	        if (!children[0].key()) {
	            children.forEach(function (x) {
	                if (x.children().length == 0) {
	                    x.errors().forEach(function (e) { return errors.push(e); });
	                }
	            });
	        }
	    });
	    return errors;
	}
	function escapeKey(key, options) {
	    if (!options || !key) {
	        return key;
	    }
	    if (options.escapeNumericKeys && key.replace(/\d/g, '').trim().length == 0) {
	        return '__$EscapedKey$__' + key;
	    }
	    return key;
	}
	function unescapeKey(key, options) {
	    if (!key) {
	        return key;
	    }
	    options = options || {};
	    if (options.escapeNumericKeys
	        && util.stringStartsWith(key, '__$EscapedKey$__')
	        && key.substring('__$EscapedKey$__'.length).replace(/\d/g, '').trim().length == 0) {
	        return key.substring('__$EscapedKey$__'.length);
	    }
	    return key;
	}
	//# sourceMappingURL=json2lowLevel.js.map

/***/ },
/* 48 */
/***/ function(module, exports, __webpack_require__) {

	/// <reference path="../../../typings/main.d.ts" />
	"use strict";
	var hl = __webpack_require__(10);
	var linter = __webpack_require__(25);
	function escapeUri(u) {
	    var ss = "";
	    var level = 0;
	    for (var i = 0; i < u.length; i++) {
	        var c = u.charAt(i);
	        if (level == 0) {
	            ss = ss + c;
	        }
	        if (c == '{') {
	            level++;
	        }
	        if (c == '}') {
	            level--;
	        }
	    }
	    return ss;
	}
	var OverloadingValidator = (function () {
	    function OverloadingValidator() {
	        this.uriToResources = {};
	        this.conflictingUriToResources = {};
	    }
	    OverloadingValidator.prototype.validateApi = function (api, acceptor) {
	        var _this = this;
	        var resources = api.resources();
	        resources.forEach(function (resource) {
	            _this.acceptResource(resource);
	            var subResources = resource.resources();
	            subResources.forEach(function (subResource) { return _this.acceptResource(subResource); });
	        });
	        for (var uri in this.conflictingUriToResources) {
	            var resources = this.conflictingUriToResources[uri];
	            if (resources.length > 1) {
	                //we should be only reporting resources, which have different keys or parent.
	                //otherwise it is handled by the general key validator
	                //thus performing additional filtering
	                var idToSimilarResources = {};
	                resources.forEach(function (resource) {
	                    var highLevel = resource.highLevel();
	                    var complexId = "";
	                    if (highLevel.parent() != null) {
	                        complexId += highLevel.parent().id() + ".";
	                    }
	                    complexId += highLevel.localId();
	                    var resourcesWithId = idToSimilarResources[complexId];
	                    if (resourcesWithId == null) {
	                        resourcesWithId = [];
	                        idToSimilarResources[complexId] = resourcesWithId;
	                    }
	                    resourcesWithId.push(resource);
	                });
	                //var isTemplateOverlap=uri.indexOf('{')!=-1;
	                var ids = Object.keys(idToSimilarResources);
	                if (ids.length > 1) {
	                    //if we have more than a single id of conflicting resources
	                    resources.forEach(function (resource) {
	                        acceptor.accept(linter.createIssue(hl.IssueCode.KEY_SHOULD_BE_UNIQUE_INTHISCONTEXT, "Resources share same URI", resource.highLevel(), false));
	                    });
	                }
	            }
	        }
	    };
	    OverloadingValidator.prototype.acceptResource = function (resource) {
	        var uri = resource.absoluteUri();
	        var resources = this.uriToResources[uri];
	        if (!resources) {
	            resources = [];
	            this.uriToResources[uri] = resources;
	        }
	        resources.push(resource);
	        if (resources.length > 1) {
	            this.conflictingUriToResources[uri] = resources;
	        }
	        //resource.methods().forEach(m=>{
	        //    this.acceptMethod(resource,m);
	        //})
	    };
	    return OverloadingValidator;
	}());
	module.exports = OverloadingValidator;
	//# sourceMappingURL=overloadingValidator.js.map

/***/ },
/* 49 */
/***/ function(module, exports, __webpack_require__) {

	/// <reference path="../../typings/main.d.ts" />
	"use strict";
	var DomParser = __webpack_require__(65);
	function xmlToJson(xml) {
	    // Create the return object
	    var obj = {};
	    if (xml.nodeType == 1) {
	        // do attributes
	        if (xml.attributes.length > 0) {
	            for (var j = 0; j < xml.attributes.length; j++) {
	                var attribute = xml.attributes.item(j);
	                obj["@" + attribute.nodeName] = attribute.nodeValue;
	            }
	        }
	    }
	    else if (xml.nodeType == 3) {
	        obj = xml.nodeValue;
	    }
	    // do children
	    if (xml.hasChildNodes()) {
	        for (var i = 0; i < xml.childNodes.length; i++) {
	            var item = xml.childNodes.item(i);
	            var nodeName = item.nodeName;
	            if (nodeName == undefined) {
	                continue;
	            }
	            if (typeof (obj[nodeName]) == "undefined") {
	                obj[nodeName] = xmlToJson(item);
	            }
	            else {
	                if (typeof (obj[nodeName].push) == "undefined") {
	                    var old = obj[nodeName];
	                    obj[nodeName] = [];
	                    obj[nodeName].push(old);
	                }
	                obj[nodeName].push(xmlToJson(item));
	            }
	        }
	    }
	    return obj;
	}
	;
	function cleanupText(j) {
	    if (typeof j === "object") {
	        for (var p in j) {
	            if (typeof (j[p]) == "object") {
	                for (var k in j[p]) {
	                    if (k == '#text') {
	                        var txt = j[p]['#text'];
	                        if (typeof (txt) != 'string') {
	                            txt = txt.join("");
	                        }
	                        txt = txt.trim();
	                        if (txt.length == 0) {
	                            delete j[p]['#text'];
	                        }
	                    }
	                }
	                cleanupText(j[p]);
	            }
	        }
	    }
	    return j;
	}
	function cleanupJson(j) {
	    if (typeof j === "object") {
	        for (var p in j) {
	            if (typeof (j[p]) == "object") {
	                var keys = Object.keys(j[p]);
	                if (keys.length == 1) {
	                    if (keys[0] == '#text') {
	                        j[p] = j[p]['#text'];
	                    }
	                }
	                cleanupJson(j[p]);
	            }
	        }
	    }
	    return j;
	}
	function parseXML(value) {
	    var v = new DomParser.DOMParser();
	    if (!value || value.trim().indexOf("<<") == 0)
	        return null;
	    var parsed = v.parseFromString(value);
	    return cleanupJson(cleanupText(xmlToJson(parsed)));
	}
	module.exports = parseXML;
	//# sourceMappingURL=xmlutil.js.map

/***/ },
/* 50 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var __extends = (this && this.__extends) || function (d, b) {
	    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
	    function __() { this.constructor = d; }
	    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
	};
	var hlImpl = __webpack_require__(16);
	var jsyaml = __webpack_require__(21);
	var def = __webpack_require__(33);
	var ramlService = def;
	var defaultCalculator = __webpack_require__(71);
	var search = __webpack_require__(27);
	var universeHelpers = __webpack_require__(14);
	var tckDumper = __webpack_require__(72);
	var yaml = __webpack_require__(70);
	var BasicNodeImpl = (function () {
	    /**
	     * @hidden
	     **/
	    function BasicNodeImpl(_node, setAsWrapper) {
	        if (setAsWrapper === void 0) { setAsWrapper = true; }
	        this._node = _node;
	        this._meta = new NodeMetadataImpl(false, false, universeHelpers.isMethodType(this.highLevel().definition()) && this.optional());
	        if (setAsWrapper) {
	            _node.setWrapperNode(this);
	        }
	    }
	    /**
	     * @hidden
	     **/
	    BasicNodeImpl.prototype.wrapperClassName = function () {
	        return 'BasicNodeImpl';
	    };
	    BasicNodeImpl.prototype.kind = function () {
	        return 'BasicNode';
	    };
	    /**
	     * @return Direct ancestor in RAML hierarchy
	     **/
	    BasicNodeImpl.prototype.parent = function () {
	        var parent = this._node.parent();
	        return parent ? parent.wrapperNode() : null;
	    };
	    /**
	     * @hidden
	     * @return Underlying node of the High Level model
	     **/
	    BasicNodeImpl.prototype.highLevel = function () {
	        return this._node;
	    };
	    /**
	     * @hidden
	     **/
	    BasicNodeImpl.prototype.attributes = function (name, constr) {
	        var attrs = this._node.attributes(name);
	        if (!attrs || attrs.length == 0) {
	            var defaultValue = this.getDefaultsCalculator().
	                attributeDefaultIfEnabled(this._node, this._node.definition().property(name));
	            if (defaultValue == null)
	                return [];
	            return Array.isArray(defaultValue) ? defaultValue : [defaultValue];
	        }
	        //TODO not sure if we want to artificially create missing attributes having
	        //default values
	        return attributesToValues(attrs, constr);
	    };
	    /**
	     * @hidden
	     **/
	    BasicNodeImpl.prototype.attribute = function (name, constr) {
	        var attr = this._node.attr(name);
	        if (constr && !(constr == this.toString ||
	            constr == this.toBoolean ||
	            constr == this.toNumber ||
	            constr == this.toAny)) {
	            //we're not putting values directly inside anything, besides the default
	            //convertors for default types we support
	            if (attr == null)
	                return null;
	            return constr(attr);
	        }
	        var attributeValue = attr ? attr.value() : null;
	        if (attributeValue == null) {
	            attributeValue = this.getDefaultsCalculator().
	                attributeDefaultIfEnabled(this._node, this._node.definition().property(name));
	        }
	        if (attributeValue == null)
	            return null;
	        if (constr) {
	            return constr(attributeValue);
	        }
	        else {
	            return attributeValue;
	        }
	    };
	    /**
	     * @hidden
	     **/
	    BasicNodeImpl.prototype.elements = function (name) {
	        var elements = this._node.elementsOfKind(name);
	        if (!elements) {
	            return null;
	        }
	        return elements.map(function (x) { return x.wrapperNode(); });
	    };
	    /**
	     * @hidden
	     **/
	    BasicNodeImpl.prototype.element = function (name) {
	        var element = this._node.element(name);
	        if (!element) {
	            return null;
	        }
	        return element.wrapperNode();
	    };
	    /**
	     * Append node as child
	     * @param node node to be appended
	     **/
	    BasicNodeImpl.prototype.add = function (node) {
	        this.highLevel().add(node.highLevel());
	    };
	    /**
	     * Append node as property value
	     * @param node node to be set as property value
	     * @param prop name of property to set value for
	     **/
	    BasicNodeImpl.prototype.addToProp = function (node, prop) {
	        var hl = node.highLevel();
	        var pr = this.highLevel().definition().property(prop);
	        hl._prop = pr;
	        this.highLevel().add(hl);
	    };
	    /**
	     * Remove node from children set
	     * @param node node to be removed
	     **/
	    BasicNodeImpl.prototype.remove = function (node) {
	        this.highLevel().remove(node.highLevel());
	    };
	    /**
	     * @return YAML string representing the node
	     **/
	    BasicNodeImpl.prototype.dump = function () {
	        return this.highLevel().dump("yaml");
	    };
	    BasicNodeImpl.prototype.toString = function (arg) {
	        var obj;
	        //kind of instanceof for hl.IAttribute without actually calling instanceof
	        if (arg.lowLevel && arg.property) {
	            obj = arg.value();
	        }
	        else {
	            obj = arg;
	        }
	        return obj != null ? obj.toString() : obj;
	    };
	    BasicNodeImpl.prototype.toAny = function (arg) {
	        return arg;
	    };
	    BasicNodeImpl.prototype.toBoolean = function (arg) {
	        var obj;
	        //kind of instanceof for hl.IAttribute without actually calling instanceof
	        if (arg.lowLevel && arg.property) {
	            obj = arg.value();
	        }
	        else {
	            obj = arg;
	        }
	        return obj != null ? obj.toString() == 'true' : obj;
	    };
	    BasicNodeImpl.prototype.toNumber = function (arg) {
	        var obj;
	        //kind of instanceof for hl.IAttribute without actually calling instanceof
	        if (arg.lowLevel && arg.property) {
	            obj = arg.value();
	        }
	        else {
	            obj = arg;
	        }
	        if (!obj) {
	            return obj;
	        }
	        try {
	            var nValue = parseFloat(obj.toString());
	            return nValue;
	        }
	        catch (e) { }
	        return Number.MAX_VALUE;
	    };
	    /**
	     * @return Array of errors
	     **/
	    BasicNodeImpl.prototype.errors = function () {
	        var _this = this;
	        var issues = [];
	        var highLevelErrors = this._node.errors();
	        if (highLevelErrors != null) {
	            issues = issues.concat(highLevelErrors);
	        }
	        var lineMapper = this._node.lowLevel().unit().lineMapper();
	        var result = issues.map(function (x) {
	            var startPoint = null;
	            try {
	                startPoint = lineMapper.position(x.start);
	            }
	            catch (e) {
	                console.warn(e);
	            }
	            var endPoint = null;
	            try {
	                endPoint = lineMapper.position(x.end);
	            }
	            catch (e) {
	                console.warn(e);
	            }
	            var path;
	            if (x.path) {
	                path = x.path;
	            }
	            else if (x.node) {
	                path = x.node.lowLevel().unit().path();
	            }
	            else {
	                path = search.declRoot(_this.highLevel()).lowLevel().unit().path();
	            }
	            return {
	                code: x.code,
	                message: x.message,
	                path: path,
	                start: x.start,
	                end: x.end,
	                line: startPoint.errorMessage ? null : startPoint.line,
	                column: startPoint.errorMessage ? null : startPoint.column,
	                range: [startPoint, endPoint],
	                isWarning: x.isWarning
	            };
	        });
	        return result;
	    };
	    /**
	     * @return object representing class of the node
	     **/
	    BasicNodeImpl.prototype.definition = function () {
	        return this.highLevel().definition();
	    };
	    /**
	     * @return for user class instances returns object representing actual user class
	     **/
	    BasicNodeImpl.prototype.runtimeDefinition = function () {
	        if (universeHelpers.isTypeDeclarationSibling(this.highLevel().definition())) {
	            return this.highLevel().localType();
	        }
	        return null;
	    };
	    BasicNodeImpl.prototype.toJSON = function (serializeOptions) {
	        var oldDefaults = defaultAttributeDefaultsValue;
	        defaultAttributeDefaultsValue = this.attributeDefaults();
	        try {
	            return new tckDumper.TCKDumper(serializeOptions).dump(this);
	        }
	        finally {
	            defaultAttributeDefaultsValue = oldDefaults;
	        }
	    };
	    /**
	     * @return Whether the element is an optional sibling of trait or resource type
	     **/
	    BasicNodeImpl.prototype.optional = function () {
	        var highLevel = this.highLevel();
	        return highLevel != null ? highLevel.optional() : false;
	    };
	    /**
	     * @return For siblings of traits or resource types returns an array of optional properties names.
	     **/
	    BasicNodeImpl.prototype.optionalProperties = function () {
	        if (!this.highLevel()) {
	            return [];
	        }
	        return this.highLevel().optionalProperties();
	    };
	    /**
	     * @hidden
	     **/
	    BasicNodeImpl.prototype.getDefaultsCalculator = function () {
	        if (this.defaultsCalculator) {
	            return this.defaultsCalculator;
	        }
	        if (this.parent()) {
	            this.defaultsCalculator = this.parent().getDefaultsCalculator();
	        }
	        if (!this.defaultsCalculator) {
	            this.defaultsCalculator = new defaultCalculator.AttributeDefaultsCalculator(defaultAttributeDefaultsValue);
	        }
	        return this.defaultsCalculator;
	    };
	    /**
	     * @hidden
	     **/
	    BasicNodeImpl.prototype.setAttributeDefaults = function (attributeDefaults) {
	        this.defaultsCalculator = new defaultCalculator.AttributeDefaultsCalculator(attributeDefaults);
	    };
	    BasicNodeImpl.prototype.attributeDefaults = function () {
	        return this.getDefaultsCalculator() && this.getDefaultsCalculator().isEnabled();
	    };
	    BasicNodeImpl.prototype.meta = function () {
	        return fillElementMeta(this);
	    };
	    BasicNodeImpl.prototype.RAMLVersion = function () {
	        return this.highLevel().definition().universe().version();
	    };
	    return BasicNodeImpl;
	}());
	exports.BasicNodeImpl = BasicNodeImpl;
	var defaultAttributeDefaultsValue = true;
	var AttributeNodeImpl = (function () {
	    function AttributeNodeImpl(attr) {
	        this._meta = new ValueMetadataImpl();
	        this.attr = attr;
	    }
	    /**
	     * @return Underlying High Level attribute node
	     **/
	    AttributeNodeImpl.prototype.highLevel = function () { return this.attr; };
	    /**
	     * @hidden
	     **/
	    AttributeNodeImpl.prototype.wrapperClassName = function () {
	        return 'AttributeNodeImpl';
	    };
	    AttributeNodeImpl.prototype.kind = function () {
	        return 'AttributeNode';
	    };
	    /**
	     * @return Whether the element is an optional sibling of trait or resource type
	     **/
	    AttributeNodeImpl.prototype.optional = function () {
	        var highLevel = this.highLevel();
	        return highLevel != null ? highLevel.optional() : false;
	    };
	    AttributeNodeImpl.prototype.meta = function () {
	        return this._meta;
	    };
	    AttributeNodeImpl.prototype.RAMLVersion = function () {
	        return this.highLevel().definition().universe().version();
	    };
	    AttributeNodeImpl.prototype.parent = function () {
	        var parent = this.attr.parent();
	        return parent ? parent.wrapperNode() : null;
	    };
	    AttributeNodeImpl.prototype.toJSON = function (serializeOptions) {
	        return new tckDumper.TCKDumper(serializeOptions).dump(this);
	    };
	    return AttributeNodeImpl;
	}());
	exports.AttributeNodeImpl = AttributeNodeImpl;
	/**
	 * @hidden
	 **/
	function toStructuredValue(node) {
	    var value = node.value();
	    if (typeof value === 'string' || value == null) {
	        var mockNode = jsyaml.createNode(value);
	        mockNode._actualNode().startPosition = node.lowLevel().valueStart();
	        mockNode._actualNode().endPosition = node.lowLevel().valueEnd();
	        var stv = new hlImpl.StructuredValue(mockNode, node.parent(), node.property());
	        return stv;
	    }
	    else {
	        return value;
	    }
	}
	exports.toStructuredValue = toStructuredValue;
	var TypeInstanceImpl = (function () {
	    function TypeInstanceImpl(nodes) {
	        if (!Array.isArray(nodes)) {
	            this.node = nodes;
	        }
	        else {
	            this.children = nodes;
	        }
	    }
	    TypeInstanceImpl.prototype.properties = function () {
	        return this.getChildren().map(function (x) { return new TypeInstancePropertyImpl(x); });
	    };
	    TypeInstanceImpl.prototype.getChildren = function () {
	        return (this.node && this.node.children()) || this.children;
	    };
	    TypeInstanceImpl.prototype.value = function () {
	        return this.node && this.node.value();
	    };
	    TypeInstanceImpl.prototype.isScalar = function () {
	        if (!this.node) {
	            return false;
	        }
	        if (this.node.children().length != 0) {
	            return false;
	        }
	        var hl = this.node.highLevelNode();
	        if (hl) {
	            var prop = hl.property();
	            var range = prop.range();
	            if (range) {
	                return range.isValueType();
	            }
	        }
	        return true;
	    };
	    TypeInstanceImpl.prototype.toJSON = function () {
	        return new tckDumper.TCKDumper().serializeTypeInstance(this);
	    };
	    return TypeInstanceImpl;
	}());
	exports.TypeInstanceImpl = TypeInstanceImpl;
	var TypeInstancePropertyImpl = (function () {
	    function TypeInstancePropertyImpl(node) {
	        this.node = node;
	    }
	    TypeInstancePropertyImpl.prototype.name = function () {
	        return this.node.key();
	    };
	    TypeInstancePropertyImpl.prototype.value = function () {
	        if (this.isArray()) {
	            var children = this.node.children();
	            return children.length > 0 ? new TypeInstanceImpl(children[0]) : null;
	        }
	        else {
	            return new TypeInstanceImpl(this.node);
	        }
	    };
	    TypeInstancePropertyImpl.prototype.values = function () {
	        return this.isArray()
	            ? this.node.children().map(function (x) { return new TypeInstanceImpl(x); })
	            : [new TypeInstanceImpl(this.node)];
	    };
	    TypeInstancePropertyImpl.prototype.isArray = function () {
	        var children = this.node.children();
	        if (children.length > 0 && children[0].key() == null) {
	            return true;
	        }
	        var hl = this.node.highLevelNode();
	        if (hl) {
	            var prop = hl.property();
	            if (prop) {
	                var range = prop.range();
	                if (range) {
	                    return range.isArray();
	                }
	            }
	        }
	        return this.node.valueKind() == yaml.Kind.SEQ;
	    };
	    return TypeInstancePropertyImpl;
	}());
	exports.TypeInstancePropertyImpl = TypeInstancePropertyImpl;
	var ValueMetadataImpl = (function () {
	    function ValueMetadataImpl(_insertedAsDefault, _calculated, _optional) {
	        if (_insertedAsDefault === void 0) { _insertedAsDefault = false; }
	        if (_calculated === void 0) { _calculated = false; }
	        if (_optional === void 0) { _optional = false; }
	        this._insertedAsDefault = _insertedAsDefault;
	        this._calculated = _calculated;
	        this._optional = _optional;
	    }
	    ValueMetadataImpl.prototype.calculated = function () { return this._calculated; };
	    ValueMetadataImpl.prototype.insertedAsDefault = function () { return this._insertedAsDefault; };
	    ValueMetadataImpl.prototype.setCalculated = function () {
	        this._calculated = true;
	    };
	    ValueMetadataImpl.prototype.setInsertedAsDefault = function () {
	        this._insertedAsDefault = true;
	    };
	    ValueMetadataImpl.prototype.setOptional = function () {
	        this._optional = true;
	    };
	    ValueMetadataImpl.prototype.optional = function () {
	        return this._optional;
	    };
	    ValueMetadataImpl.prototype.isDefault = function () {
	        return !(this._insertedAsDefault || this._calculated || this._optional);
	    };
	    ValueMetadataImpl.prototype.toJSON = function () {
	        var obj = {};
	        if (this._calculated) {
	            obj['calculated'] = true;
	        }
	        if (this._insertedAsDefault) {
	            obj['insertedAsDefault'] = true;
	        }
	        if (this._optional) {
	            obj['optional'] = true;
	        }
	        return obj;
	    };
	    return ValueMetadataImpl;
	}());
	exports.ValueMetadataImpl = ValueMetadataImpl;
	var NodeMetadataImpl = (function (_super) {
	    __extends(NodeMetadataImpl, _super);
	    function NodeMetadataImpl() {
	        _super.apply(this, arguments);
	        this.valuesMeta = {};
	    }
	    NodeMetadataImpl.prototype.primitiveValuesMeta = function () { return this.valuesMeta; };
	    NodeMetadataImpl.prototype.registerInsertedAsDefaultValue = function (propName) {
	        var pMeta = this.valuesMeta[propName];
	        if (pMeta == null) {
	            this.valuesMeta[propName] = new ValueMetadataImpl(true);
	        }
	        else {
	            pMeta.setInsertedAsDefault();
	        }
	    };
	    NodeMetadataImpl.prototype.registerCalculatedValue = function (propName) {
	        var pMeta = this.valuesMeta[propName];
	        if (pMeta == null) {
	            this.valuesMeta[propName] = new ValueMetadataImpl(false, true);
	        }
	        else {
	            pMeta.setCalculated();
	        }
	    };
	    NodeMetadataImpl.prototype.registerOptionalValue = function (propName) {
	        var pMeta = this.valuesMeta[propName];
	        if (pMeta == null) {
	            this.valuesMeta[propName] = new ValueMetadataImpl(false, false, true);
	        }
	        else {
	            pMeta.setOptional();
	        }
	    };
	    NodeMetadataImpl.prototype.resetPrimitiveValuesMeta = function () {
	        this.valuesMeta = {};
	    };
	    NodeMetadataImpl.prototype.isDefault = function () {
	        if (!_super.prototype.isDefault.call(this)) {
	            return false;
	        }
	        return Object.keys(this.valuesMeta).length == 0;
	    };
	    NodeMetadataImpl.prototype.toJSON = function () {
	        var _this = this;
	        var obj = _super.prototype.toJSON.call(this);
	        var valuesObj = {};
	        var propKeys = Object.keys(this.valuesMeta);
	        if (propKeys.length > 0) {
	            propKeys.forEach(function (x) {
	                var childMeta = _this.valuesMeta[x].toJSON();
	                if (Object.keys(childMeta).length > 0) {
	                    valuesObj[x] = childMeta;
	                }
	            });
	            obj['primitiveValuesMeta'] = valuesObj;
	        }
	        return obj;
	    };
	    return NodeMetadataImpl;
	}(ValueMetadataImpl));
	exports.NodeMetadataImpl = NodeMetadataImpl;
	function fillElementMeta(node) {
	    var meta = node._meta;
	    meta.resetPrimitiveValuesMeta();
	    var highLevelNode = node.highLevel();
	    highLevelNode.definition().allProperties().forEach(function (p) {
	        var name = p.nameId();
	        var attrs = highLevelNode.attributes(name);
	        var gotValue = false;
	        var optional = false;
	        attrs.forEach(function (a) {
	            gotValue = gotValue || a.value() != null;
	            optional = optional || a.optional();
	        });
	        if (!gotValue) {
	            var calculator = node.getDefaultsCalculator();
	            var defVal = calculator.attributeDefaultIfEnabled(highLevelNode, p);
	            if (defVal != null) {
	                var insertionKind = calculator.insertionKind(highLevelNode, p);
	                if (insertionKind == defaultCalculator.InsertionKind.CALCULATED) {
	                    meta.registerCalculatedValue(name);
	                }
	                else if (insertionKind == defaultCalculator.InsertionKind.BY_DEFAULT) {
	                    meta.registerInsertedAsDefaultValue(name);
	                }
	            }
	        }
	    });
	    return meta;
	}
	exports.fillElementMeta = fillElementMeta;
	function attributesToValues(attrs, constr) {
	    if (constr) {
	        return attrs.map(function (x) { return constr(x); });
	    }
	    else {
	        return attrs.map(function (x) { return x.value(); });
	    }
	}
	exports.attributesToValues = attributesToValues;
	//# sourceMappingURL=parserCore.js.map

/***/ },
/* 51 */
/***/ function(module, exports, __webpack_require__) {

	/// <reference path="../../typings/main.d.ts" />
	"use strict";
	var ramlSanitize = __webpack_require__(73);
	var ramlValidate = __webpack_require__(74);
	var REGEXP_MATCH = {
	    number: '[-+]?\\d+(?:\\.\\d+)?',
	    integer: '[-+]?\\d+',
	    date: '(?:Mon|Tue|Wed|Thu|Fri|Sat|Sun), \\d{2} (?:Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec) \\d{4} (?:[0-1]\\d|2[0-3]):[0-5]\\d:[0-5]\\d GMT',
	    boolean: '(?:true|false)'
	};
	var ESCAPE_CHARACTERS = /([.*+?=^!:${}()|[\]\/\\])/g;
	var REGEXP_REPLACE = new RegExp([
	    // Match RAML parameters with an optional prefix.
	    '([.\\/])?\\{([^}]+)\\}',
	    // Match any escape characters.
	    ESCAPE_CHARACTERS.source
	].join('|'), 'g');
	function toRegExp(path, parameters, keys, options) {
	    var end = options.end !== false;
	    var strict = options.strict;
	    var flags = '';
	    if (!options.sensitive) {
	        flags += 'i';
	    }
	    var route = path.replace(REGEXP_REPLACE, function (match, prefix, key, escape) {
	        if (escape) {
	            return '\\' + escape;
	        }
	        // Push the current key into the keys array.
	        keys.push({
	            name: key,
	            prefix: prefix || '/'
	        });
	        prefix = prefix ? '\\' + prefix : '';
	        // TODO: Support an array of parameters.
	        var param = parameters[key];
	        var capture = param && REGEXP_MATCH[param.type] || '[^' + (prefix || '\\/') + ']+';
	        var optional = param && param.required === false;
	        if (Array.isArray(param.enum) && param.enum.length) {
	            capture = '(?:' + param.enum.map(function (value) {
	                return String(value).replace(ESCAPE_CHARACTERS, '\\$1');
	            }).join('|') + ')';
	        }
	        return prefix + '(' + capture + ')' + (optional ? '?' : '');
	    });
	    var endsWithSlash = path.charAt(path.length - 1) === '/';
	    // In non-strict mode we allow a slash at the end of match. If the path to
	    // match already ends with a slash, we remove it for consistency. The slash
	    // is valid at the end of a path match, not in the middle. This is important
	    // in non-ending mode, where "/test/" shouldn't match "/test//route".
	    if (!strict) {
	        route = (endsWithSlash ? route.slice(0, -2) : route) + '(?:\\/(?=$))?';
	    }
	    if (end) {
	        route += '$';
	    }
	    else {
	        // In non-ending mode, we need the capturing groups to match as much as
	        // possible by using a positive lookahead to the end or next path segment.
	        route += strict && endsWithSlash ? '' : '(?=\\/|$)';
	    }
	    return new RegExp('^' + route + (end ? '$' : ''), flags);
	}
	function decodeParam(param) {
	    try {
	        return decodeURIComponent(param);
	    }
	    catch (_) {
	        var err = new Error('Failed to decode param "' + param + '"');
	        err.status = 400;
	        throw err;
	    }
	}
	function ramlPathMatch(path, parameters, options) {
	    options = options || {};
	    if (path === '/' && options.end === false) {
	        return truth;
	    }
	    parameters = parameters || {};
	    var keys = [];
	    var re = toRegExp(path, parameters, keys, options);
	    var sanitize = ramlSanitize.sanitize()(parameters);
	    var validate = ramlValidate.validate()(parameters);
	    return function (pathname) {
	        var m = re.exec(pathname);
	        if (!m) {
	            return false;
	        }
	        if (parameters['mediaTypeExtension']) {
	            if (m.length > 1 && !m[m.length - 1]) {
	                var beforeLast = m[m.length - 2];
	                var ind = beforeLast.lastIndexOf('.');
	                if (ind >= 0) {
	                    m[m.length - 2] = beforeLast.substring(0, ind);
	                    m[m.length - 1] = beforeLast.substring(ind);
	                }
	            }
	        }
	        var path = m[0];
	        var params = {};
	        for (var i = 1; i < m.length; i++) {
	            var key = keys[i - 1];
	            var param = m[i];
	            params[key.name] = param == null ? param : decodeParam(param);
	        }
	        params = sanitize(params);
	        if (!validate(params).valid) {
	            return false;
	        }
	        return {
	            path: path,
	            params: params
	        };
	    };
	}
	exports.ramlPathMatch = ramlPathMatch;
	function truth(path) {
	    return { path: '', params: {} };
	}
	// export = ramlPathMatch 
	//# sourceMappingURL=raml-path-match.js.map

/***/ },
/* 52 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	exports.universeDumps = {
	    RAML08: toModule(__webpack_require__(84)),
	    RAML10: toModule(__webpack_require__(85))
	};
	function toModule(arr) {
	    var main = arr[0];
	    var map = {};
	    arr.forEach(function (x) { return map[x['name']] = x; });
	    arr.forEach(function (x) {
	        var imports = x['imports'];
	        Object.keys(imports).forEach(function (y) {
	            var name = imports[y];
	            imports[y] = map[name];
	        });
	    });
	    return main;
	}
	//# sourceMappingURL=index.js.map

/***/ },
/* 53 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var __extends = (this && this.__extends) || function (d, b) {
	    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
	    function __() { this.constructor = d; }
	    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
	};
	/// <reference path="../typings/main.d.ts" />
	var tsModel = __webpack_require__(86);
	var def = __webpack_require__(33);
	var _ = __webpack_require__(83);
	var aHandlers = __webpack_require__(75);
	var services = def;
	var FieldWrapper = (function () {
	    function FieldWrapper(_field, _clazz) {
	        this._field = _field;
	        this._clazz = _clazz;
	    }
	    FieldWrapper.prototype.name = function () {
	        return this._field.name;
	    };
	    FieldWrapper.prototype.range = function () {
	        return this._clazz.getModule().typeFor(this._field.type, this._clazz);
	    };
	    FieldWrapper.prototype.isMultiValue = function () {
	        return this._field.type.typeKind == tsModel.TypeKind.ARRAY;
	    };
	    FieldWrapper.prototype.isKey = function () {
	        return _.find(this._field.annotations, function (x) { return x.name == "MetaModel.key"; }) != null;
	    };
	    FieldWrapper.prototype.isSimpleValue = function () {
	        return _.find(this._field.annotations, function (x) { return x.name == "MetaModel.value"; }) != null;
	    };
	    FieldWrapper.prototype.annotations = function () {
	        return this._field.annotations;
	    };
	    return FieldWrapper;
	}());
	var FieldConstraint = (function () {
	    function FieldConstraint(_field, _clazz) {
	        this._field = _field;
	        this._clazz = _clazz;
	    }
	    FieldConstraint.prototype.name = function () {
	        return this._field.name;
	    };
	    FieldConstraint.prototype.value = function () {
	        return this._field.valueConstraint;
	    };
	    return FieldConstraint;
	}());
	var ClassWrapper = (function () {
	    function ClassWrapper(_clazz, mw) {
	        this._clazz = _clazz;
	        this.mw = mw;
	    }
	    ClassWrapper.prototype.typeMeta = function () {
	        return this._clazz.annotations;
	    };
	    ClassWrapper.prototype.path = function () {
	        return this.mw.path();
	    };
	    ClassWrapper.prototype.getModule = function () {
	        return this.mw;
	    };
	    ClassWrapper.prototype.typeArgs = function () {
	        return this._clazz.typeParameters;
	    };
	    ClassWrapper.prototype.typConstraints = function () {
	        var _this = this;
	        return this._clazz.typeParameterConstraint.map(function (x) {
	            if (x) {
	                return _this.mw.classForName(x);
	            }
	            return null;
	        });
	    };
	    ClassWrapper.prototype.methods = function () {
	        return this._clazz.methods;
	    };
	    ClassWrapper.prototype.name = function () {
	        return this._clazz.name;
	    };
	    ClassWrapper.prototype.members = function () {
	        var _this = this;
	        return this._clazz.fields.filter(function (x) { return x.valueConstraint == null; }).map(function (x) { return new FieldWrapper(x, _this); });
	    };
	    ClassWrapper.prototype.constraints = function () {
	        var _this = this;
	        return this._clazz.fields.filter(function (x) { return x.valueConstraint != null; }).map(function (x) { return new FieldConstraint(x, _this); });
	    };
	    ClassWrapper.prototype.isSubTypeOf = function (of) {
	        if (this == of) {
	            return true;
	        }
	        var _res = false;
	        this.getAllSuperTypes().forEach(function (x) {
	            if (!_res) {
	                _res = _res || x.isSubTypeOf(of);
	            }
	        });
	        return _res;
	    };
	    ClassWrapper.prototype.getExtendsClauses = function () {
	        return this._clazz.extends;
	    };
	    ClassWrapper.prototype.getSuperTypes = function () {
	        var _this = this;
	        var result = [];
	        this._clazz.extends.forEach(function (x) {
	            var tp = _this.mw.classForName(x.typeName);
	            if (tp) {
	                result.push(tp);
	            }
	        });
	        return result;
	    };
	    ClassWrapper.prototype.getAllSuperTypes = function () {
	        var _this = this;
	        var result = [];
	        this._clazz.extends.forEach(function (x) {
	            var tp = _this.mw.classForName(x.typeName);
	            if (tp) {
	                var mm = tp.getAllSuperTypes();
	                result.push(tp);
	                result.concat(mm);
	            }
	        });
	        return _.unique(result);
	    };
	    ClassWrapper.prototype.annotationOverridings = function () { return this._clazz.annotationOverridings; };
	    return ClassWrapper;
	}());
	var AbstractSimpleWrapper = (function () {
	    function AbstractSimpleWrapper() {
	    }
	    AbstractSimpleWrapper.prototype.members = function () {
	        return []; //this._clazz.members.map(x=>new FieldWrapper(x,this))
	    };
	    AbstractSimpleWrapper.prototype.methods = function () { return []; };
	    AbstractSimpleWrapper.prototype.isSubTypeOf = function (of) {
	        return false;
	    };
	    AbstractSimpleWrapper.prototype.getSuperTypes = function () {
	        return [];
	    };
	    AbstractSimpleWrapper.prototype.getAllSuperTypes = function () {
	        return [];
	    };
	    AbstractSimpleWrapper.prototype.name = function () {
	        return null;
	    };
	    AbstractSimpleWrapper.prototype.constraints = function () {
	        return [];
	    };
	    AbstractSimpleWrapper.prototype.typeMeta = function () {
	        return [];
	    };
	    AbstractSimpleWrapper.prototype.getModule = function () {
	        throw new Error("Not implemented");
	    };
	    AbstractSimpleWrapper.prototype.annotationOverridings = function () { return {}; };
	    return AbstractSimpleWrapper;
	}());
	var EnumWrapper = (function (_super) {
	    __extends(EnumWrapper, _super);
	    function EnumWrapper(_clazz, mw) {
	        _super.call(this);
	        this._clazz = _clazz;
	        this.mw = mw;
	    }
	    EnumWrapper.prototype.getModule = function () {
	        return this.mw;
	    };
	    EnumWrapper.prototype.values = function () {
	        return this._clazz.members;
	    };
	    EnumWrapper.prototype.name = function () {
	        return this._clazz.name;
	    };
	    return EnumWrapper;
	}(AbstractSimpleWrapper));
	var UnionWrapper = (function (_super) {
	    __extends(UnionWrapper, _super);
	    function UnionWrapper(_clazz, mw) {
	        _super.call(this);
	        this._clazz = _clazz;
	        this.mw = mw;
	    }
	    UnionWrapper.prototype.elements = function () {
	        return this._clazz;
	    };
	    UnionWrapper.prototype.name = function () {
	        return this._clazz.map(function (x) { return x.name(); }).join("|");
	    };
	    return UnionWrapper;
	}(AbstractSimpleWrapper));
	var ModuleWrapper = (function () {
	    function ModuleWrapper(_univers) {
	        var _this = this;
	        this._univers = _univers;
	        this.name2Class = {};
	        this.namespaceToMod = {};
	        this._classes = [];
	        _univers.classes.forEach(function (x) {
	            var c = new ClassWrapper(x, _this);
	            _this._classes.push(c);
	            _this.name2Class[x.name] = c;
	            if (x.moduleName) {
	                //FIXME
	                _this.name2Class[x.moduleName + "." + x.name] = c;
	            }
	        });
	        _univers.enumDeclarations.forEach(function (x) {
	            var c = new EnumWrapper(x, _this);
	            _this._classes.push(c);
	            _this.name2Class[x.name] = c;
	        });
	    }
	    ModuleWrapper.prototype.typeFor = function (t, ow) {
	        var _this = this;
	        switch (t.typeKind) {
	            case tsModel.TypeKind.BASIC:
	                var bt = t;
	                var typeName = bt.typeName;
	                if (typeName == "string") {
	                    typeName = "StringType";
	                }
	                if (typeName == "number") {
	                    typeName = "NumberType";
	                }
	                if (typeName == "boolean") {
	                    typeName = "BooleanType";
	                }
	                if (typeName == "any") {
	                    typeName = "AnyType";
	                }
	                var ti = _.indexOf(ow.typeArgs(), typeName);
	                if (ti != -1) {
	                    var cnst = ow.typConstraints()[ti];
	                    if (!cnst) {
	                        return this.classForName("ValueType");
	                    }
	                    return cnst;
	                }
	                return this.classForName(typeName);
	            case tsModel.TypeKind.UNION:
	                var ut = t;
	                return new UnionWrapper(ut.options.map(function (x) { return _this.typeFor(x, ow); }), this);
	            case tsModel.TypeKind.ARRAY:
	                var at = t;
	                return this.typeFor(at.base, ow);
	        }
	        return null;
	    };
	    ModuleWrapper.prototype.path = function () {
	        return this._univers.name;
	    };
	    ModuleWrapper.prototype.classForName = function (name, stack) {
	        var _this = this;
	        if (stack === void 0) { stack = {}; }
	        if (!name) {
	            return null;
	        }
	        var result = this.name2Class[name];
	        if (!result && !stack[this.path()]) {
	            stack[this.path()] = this;
	            var nmsp = name.indexOf(".");
	            if (nmsp != -1) {
	                var actualMod = this.namespaceToMod[name.substring(0, nmsp)];
	                if (!actualMod) {
	                    throw new Error();
	                }
	                return actualMod.classForName(name.substring(nmsp + 1), stack);
	            }
	            Object.keys(this.namespaceToMod).forEach(function (x) {
	                if (x != "MetaModel") {
	                    var nm = _this.namespaceToMod[x].classForName(name, stack);
	                    if (nm) {
	                        result = nm;
	                    }
	                }
	            });
	        }
	        return result;
	    };
	    ModuleWrapper.prototype.classes = function () {
	        return this._classes;
	    };
	    return ModuleWrapper;
	}());
	var wrapperToType = function (range, u) {
	    if (range) {
	        var rangeType;
	        if (range instanceof UnionWrapper) {
	            var uw = range;
	            throw new Error("Union type support was removed from definition system");
	        }
	        else {
	            rangeType = u.type(range.name());
	        }
	        return rangeType;
	    }
	    else {
	        return;
	    }
	};
	var registerClasses = function (m, u) {
	    var valueType = m.classForName("ValueType");
	    m.classes().forEach(function (x) {
	        if (x instanceof EnumWrapper) {
	            var et = new def.EnumType(x.name(), u, x.getModule().path());
	            et.values = x.values();
	            u.register(et);
	            return;
	        }
	        if (x.isSubTypeOf(valueType)) {
	            var st = x.getAllSuperTypes();
	            st.push(x);
	            var refTo = null;
	            st.forEach(function (t) {
	                var cs = t.getExtendsClauses();
	                cs.forEach(function (z) {
	                    if (z.typeKind == tsModel.TypeKind.BASIC) {
	                        var bas = z;
	                        if (bas.basicName == 'Reference') {
	                            var of = bas.typeArguments[0];
	                            refTo = of.typeName;
	                            var di = refTo.indexOf('.');
	                            if (di != -1) {
	                                refTo = refTo.substring(di + 1);
	                            }
	                        }
	                    }
	                });
	            });
	            if (refTo) {
	                //console.log("New reference type" + x.name())
	                var ref = new def.ReferenceType(x.name(), x.getModule().path(), refTo, u);
	                ref.setBuiltIn(true);
	                u.register(ref);
	            }
	            else {
	                var vt = new def.ValueType(x.name(), u, x.getModule().path());
	                vt.setBuiltIn(true);
	                u.register(vt);
	            }
	        }
	        else {
	            var gt = new def.NodeClass(x.name(), u, x.getModule().path());
	            gt.setBuiltIn(true);
	            u.register(gt);
	        }
	    });
	};
	var registerHierarchy = function (m, u) {
	    m.classes().forEach(function (x) {
	        x.getSuperTypes().forEach(function (y) {
	            var tp0 = u.type(x.name());
	            var tp1 = u.type(y.name());
	            if (!tp0 || !tp1) {
	                var tp0 = u.type(x.name());
	                var tp1 = u.type(y.name());
	                throw new Error();
	            }
	            u.registerSuperClass(tp0, tp1);
	        });
	    });
	};
	var registerEverything = function (m, u) {
	    m.classes().forEach(function (x) {
	        var tp = u.type(x.name());
	        x.typeMeta().forEach(function (a) {
	            var rangeType = wrapperToType(x, u);
	            aHandlers.handleTypeAnnotation(a, rangeType);
	        });
	        x.members().forEach(function (x) {
	            var range = x.range();
	            var rangeType = wrapperToType(range, u);
	            if (rangeType == null) {
	                console.log(range + ":" + x.name());
	            }
	            var custom = x.annotations().map(function (y) { return y.name; }).indexOf('MetaModel.customHandling') >= 0;
	            createProp(x, tp, rangeType, custom);
	        });
	        Object.keys(x.annotationOverridings()).forEach(function (fName) {
	            var arr = [].concat(x.annotationOverridings()[fName]);
	            var map = {};
	            arr.forEach(function (ann) { return map[ann.name] = true; });
	            var targetField;
	            var stArr = x.getSuperTypes();
	            var stMap = {};
	            for (var i = 0; i < stArr.length; i++) {
	                var st = stArr[i];
	                if (stMap[st.name()]) {
	                    continue;
	                }
	                stMap[st.name()] = true;
	                st.getSuperTypes().forEach(function (sst) { return stArr.push(sst); });
	                var arr1 = st.annotationOverridings()[fName];
	                if (arr1) {
	                    arr1.filter(function (ann) { return !map[ann.name]; }).forEach(function (ann) {
	                        map[ann.name] = true;
	                        arr.push(ann);
	                    });
	                }
	                else {
	                    var stFields = st.members();
	                    for (var j = 0; j < stFields.length; j++) {
	                        var stField = stFields[j];
	                        if (stField.name() == fName) {
	                            targetField = stField;
	                            break;
	                        }
	                    }
	                }
	                if (targetField) {
	                    var arr2 = targetField.annotations();
	                    arr2.filter(function (ann) { return !map[ann.name]; }).forEach(function (ann) {
	                        map[ann.name] = true;
	                        arr.push(ann);
	                    });
	                    break;
	                }
	            }
	            if (!targetField) {
	                return;
	            }
	            var range = targetField.range();
	            var rangeType = wrapperToType(range, u);
	            if (rangeType == null) {
	                console.log(range + ":" + x.name());
	            }
	            createProp(targetField, tp, rangeType, false, arr);
	        });
	        x.methods().forEach(function (x) {
	            var at = tp;
	            //at.addMethod(x.name, x.text);
	            //console.log(x.name);
	            //createMember(x, <def.AbstractType>tp, rangeType)
	        });
	        x.constraints().forEach(function (x) {
	            if (x.value().isCallConstraint) {
	                throw new Error();
	            }
	            var mm = x.value();
	            tp.addRequirement(x.name(), "" + mm.value);
	        });
	    });
	    u.types().forEach(function (x) {
	        var at = x;
	        at.getAdapter(services.RAMLService).getAliases().forEach(function (y) { return u.registerAlias(y, at); });
	    });
	};
	var processModule = function (ts, u, used, declared) {
	    if (ts.name.indexOf("metamodel.ts") != -1) {
	        return; //FIXME
	    }
	    if (declared[ts.name]) {
	        return declared[ts.name];
	    }
	    var m = new ModuleWrapper(ts);
	    used[ts.name] = m;
	    declared[ts.name] = m;
	    Object.keys(ts.imports).forEach(function (x) {
	        var pMod = ts.imports[x];
	        if (used[pMod.name]) {
	            m.namespaceToMod[x] = used[pMod.name];
	            return;
	        }
	        var vMod = processModule(pMod, u, used, declared);
	        m.namespaceToMod[x] = vMod;
	    });
	    used[ts.name] = null;
	    return m;
	};
	function toDefSystem(ts, q) {
	    var u = new def.Universe(q, "");
	    var c = {};
	    processModule(ts, u, {}, c);
	    Object.keys(c).forEach(function (x) {
	        registerClasses(c[x], u);
	    });
	    Object.keys(c).forEach(function (x) {
	        registerHierarchy(c[x], u);
	    });
	    Object.keys(c).forEach(function (x) {
	        registerEverything(c[x], u);
	    });
	    u.types().forEach(function (x) {
	        if (x instanceof def.NodeClass) {
	            var cl = x;
	            cl.properties().forEach(function (y) {
	                var t = y.range();
	                var ap = y;
	                if (!t.hasValueTypeInHierarchy()) {
	                    t.properties().forEach(function (p0) {
	                        if (p0.getAdapter(services.RAMLPropertyService).isKey()) {
	                            var kp = p0.keyPrefix();
	                            if (kp) {
	                                ap.withKeyRestriction(kp);
	                                ap.merge();
	                            }
	                            var eo = p0.enumOptions();
	                            if (eo) {
	                                ap.withEnumOptions(eo);
	                                ap.merge();
	                            }
	                        }
	                    });
	                }
	            });
	            if (cl.getAdapter(services.RAMLService).isGlobalDeclaration()) {
	                if (cl.getAdapter(services.RAMLService).getActuallyExports() && cl.getAdapter(services.RAMLService).getActuallyExports() != "$self") {
	                    var tp = cl.property(cl.getAdapter(services.RAMLService).getActuallyExports()).range();
	                    if (tp.hasValueTypeInHierarchy()) {
	                        var vt = tp.getAdapter(services.RAMLService);
	                        vt.setGloballyDeclaredBy(cl);
	                    }
	                }
	                if (cl.getAdapter(services.RAMLService).getConvertsToGlobal()) {
	                    var tp = u.type(cl.getAdapter(services.RAMLService).getConvertsToGlobal());
	                    if (tp.hasValueTypeInHierarchy()) {
	                        var vt = tp.getAdapter(services.RAMLService);
	                        vt.setGloballyDeclaredBy(cl);
	                    }
	                }
	            }
	        }
	    });
	    return u;
	}
	exports.toDefSystem = toDefSystem;
	var processAnnotations = function (x, p, annotations) {
	    if (!annotations) {
	        annotations = x.annotations();
	    }
	    annotations.forEach(function (x) {
	        var nm = x.name.substring(x.name.lastIndexOf(".") + 1);
	        if (!aHandlers.annotationHandlers[nm]) {
	            console.log("Can not find handler for:");
	        }
	        aHandlers.annotationHandlers[nm](x, p);
	    });
	};
	function createProp(x, clazz, t, custom, annotations) {
	    var p = def.prop(x.name(), "", clazz, t, custom);
	    if (x.isMultiValue()) {
	        p.withMultiValue(true);
	    }
	    p.unmerge();
	    if (!t) {
	        console.log(x.name() + ":" + clazz.nameId() + " has undefined type");
	    }
	    if (!t.hasValueTypeInHierarchy()) {
	        t.properties().forEach(function (p0) {
	            if (p0.getAdapter(services.RAMLPropertyService).isKey()) {
	                var kp = p0.keyPrefix();
	                if (kp) {
	                    p.withKeyRestriction(kp);
	                    p.merge();
	                }
	                var eo = p0.enumOptions();
	                if (eo) {
	                    p.withEnumOptions(eo);
	                    p.merge();
	                }
	            }
	        });
	    }
	    processAnnotations(x, p, annotations);
	}
	//# sourceMappingURL=tsStruct2Def.js.map

/***/ },
/* 54 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var Universes = {
	    "Universe08": {
	        "GlobalSchema": {
	            "name": "GlobalSchema",
	            "properties": {
	                "key": {
	                    "name": "key",
	                    "range": "StringType",
	                    "domain": "GlobalSchema"
	                },
	                "value": {
	                    "name": "value",
	                    "range": "SchemaString",
	                    "domain": "GlobalSchema"
	                }
	            }
	        },
	        "Api": {
	            "name": "Api",
	            "properties": {
	                "title": {
	                    "name": "title",
	                    "range": "StringType",
	                    "domain": "Api"
	                },
	                "version": {
	                    "name": "version",
	                    "range": "StringType",
	                    "domain": "Api"
	                },
	                "baseUri": {
	                    "name": "baseUri",
	                    "range": "FullUriTemplateString",
	                    "domain": "Api"
	                },
	                "baseUriParameters": {
	                    "name": "baseUriParameters",
	                    "range": "Parameter",
	                    "domain": "Api"
	                },
	                "uriParameters": {
	                    "name": "uriParameters",
	                    "range": "Parameter",
	                    "domain": "Api"
	                },
	                "protocols": {
	                    "name": "protocols",
	                    "range": "StringType",
	                    "domain": "Api"
	                },
	                "mediaType": {
	                    "name": "mediaType",
	                    "range": "MimeType",
	                    "domain": "Api"
	                },
	                "schemas": {
	                    "name": "schemas",
	                    "range": "GlobalSchema",
	                    "domain": "Api"
	                },
	                "traits": {
	                    "name": "traits",
	                    "range": "Trait",
	                    "domain": "Api"
	                },
	                "securedBy": {
	                    "name": "securedBy",
	                    "range": "SecuritySchemeRef",
	                    "domain": "Api"
	                },
	                "securitySchemes": {
	                    "name": "securitySchemes",
	                    "range": "AbstractSecurityScheme",
	                    "domain": "Api"
	                },
	                "resourceTypes": {
	                    "name": "resourceTypes",
	                    "range": "ResourceType",
	                    "domain": "Api"
	                },
	                "resources": {
	                    "name": "resources",
	                    "range": "Resource",
	                    "domain": "Api"
	                },
	                "documentation": {
	                    "name": "documentation",
	                    "range": "DocumentationItem",
	                    "domain": "Api"
	                },
	                "RAMLVersion": {
	                    "name": "RAMLVersion"
	                }
	            }
	        },
	        "DocumentationItem": {
	            "name": "DocumentationItem",
	            "properties": {
	                "title": {
	                    "name": "title",
	                    "range": "StringType",
	                    "domain": "DocumentationItem"
	                },
	                "content": {
	                    "name": "content",
	                    "range": "MarkdownString",
	                    "domain": "DocumentationItem"
	                }
	            }
	        },
	        "ValueType": {
	            "name": "ValueType",
	            "properties": {}
	        },
	        "StringType": {
	            "name": "StringType",
	            "properties": {}
	        },
	        "AnyType": {
	            "name": "AnyType",
	            "properties": {}
	        },
	        "NumberType": {
	            "name": "NumberType",
	            "properties": {}
	        },
	        "BooleanType": {
	            "name": "BooleanType",
	            "properties": {}
	        },
	        "Referencable": {
	            "name": "Referencable",
	            "properties": {}
	        },
	        "Reference": {
	            "name": "Reference",
	            "properties": {
	                "structuredValue": {
	                    "name": "structuredValue"
	                },
	                "name": {
	                    "name": "name"
	                }
	            }
	        },
	        "DeclaresDynamicType": {
	            "name": "DeclaresDynamicType",
	            "properties": {}
	        },
	        "UriTemplate": {
	            "name": "UriTemplate",
	            "properties": {}
	        },
	        "RelativeUriString": {
	            "name": "RelativeUriString",
	            "properties": {}
	        },
	        "FullUriTemplateString": {
	            "name": "FullUriTemplateString",
	            "properties": {}
	        },
	        "FixedUri": {
	            "name": "FixedUri",
	            "properties": {}
	        },
	        "MarkdownString": {
	            "name": "MarkdownString",
	            "properties": {}
	        },
	        "SchemaString": {
	            "name": "SchemaString",
	            "properties": {}
	        },
	        "JSonSchemaString": {
	            "name": "JSonSchemaString",
	            "properties": {}
	        },
	        "XMLSchemaString": {
	            "name": "XMLSchemaString",
	            "properties": {}
	        },
	        "ExampleString": {
	            "name": "ExampleString",
	            "properties": {}
	        },
	        "StatusCodeString": {
	            "name": "StatusCodeString",
	            "properties": {}
	        },
	        "JSONExample": {
	            "name": "JSONExample",
	            "properties": {}
	        },
	        "XMLExample": {
	            "name": "XMLExample",
	            "properties": {}
	        },
	        "TypeInstance": {
	            "name": "TypeInstance",
	            "properties": {
	                "properties": {
	                    "name": "properties",
	                    "range": "TypeInstanceProperty",
	                    "domain": "TypeInstance"
	                },
	                "isScalar": {
	                    "name": "isScalar",
	                    "range": "BooleanType",
	                    "domain": "TypeInstance"
	                },
	                "value": {
	                    "name": "value",
	                    "range": "AnyType",
	                    "domain": "TypeInstance"
	                }
	            }
	        },
	        "TypeInstanceProperty": {
	            "name": "TypeInstanceProperty",
	            "properties": {
	                "name": {
	                    "name": "name",
	                    "range": "StringType",
	                    "domain": "TypeInstanceProperty"
	                },
	                "value": {
	                    "name": "value",
	                    "range": "TypeInstance",
	                    "domain": "TypeInstanceProperty"
	                },
	                "values": {
	                    "name": "values",
	                    "range": "TypeInstance",
	                    "domain": "TypeInstanceProperty"
	                },
	                "isArray": {
	                    "name": "isArray",
	                    "range": "BooleanType",
	                    "domain": "TypeInstanceProperty"
	                }
	            }
	        },
	        "RAMLSimpleElement": {
	            "name": "RAMLSimpleElement",
	            "properties": {}
	        },
	        "Parameter": {
	            "name": "Parameter",
	            "properties": {
	                "name": {
	                    "name": "name",
	                    "range": "StringType",
	                    "domain": "Parameter"
	                },
	                "displayName": {
	                    "name": "displayName",
	                    "range": "StringType",
	                    "domain": "Parameter"
	                },
	                "type": {
	                    "name": "type",
	                    "range": "StringType",
	                    "domain": "Parameter"
	                },
	                "location": {
	                    "name": "location",
	                    "range": "ParameterLocation",
	                    "domain": "Parameter"
	                },
	                "required": {
	                    "name": "required",
	                    "range": "BooleanType",
	                    "domain": "Parameter"
	                },
	                "default": {
	                    "name": "default",
	                    "range": "AnyType",
	                    "domain": "Parameter"
	                },
	                "example": {
	                    "name": "example",
	                    "range": "StringType",
	                    "domain": "Parameter"
	                },
	                "repeat": {
	                    "name": "repeat",
	                    "range": "BooleanType",
	                    "domain": "Parameter"
	                },
	                "description": {
	                    "name": "description",
	                    "range": "MarkdownString",
	                    "domain": "Parameter"
	                }
	            }
	        },
	        "StringTypeDeclaration": {
	            "name": "StringTypeDeclaration",
	            "properties": {
	                "name": {
	                    "name": "name",
	                    "range": "StringType",
	                    "domain": "Parameter"
	                },
	                "displayName": {
	                    "name": "displayName",
	                    "range": "StringType",
	                    "domain": "Parameter"
	                },
	                "type": {
	                    "name": "type",
	                    "range": "StringType",
	                    "domain": "Parameter"
	                },
	                "location": {
	                    "name": "location",
	                    "range": "ParameterLocation",
	                    "domain": "Parameter"
	                },
	                "required": {
	                    "name": "required",
	                    "range": "BooleanType",
	                    "domain": "Parameter"
	                },
	                "default": {
	                    "name": "default",
	                    "range": "AnyType",
	                    "domain": "Parameter"
	                },
	                "example": {
	                    "name": "example",
	                    "range": "StringType",
	                    "domain": "Parameter"
	                },
	                "repeat": {
	                    "name": "repeat",
	                    "range": "BooleanType",
	                    "domain": "Parameter"
	                },
	                "description": {
	                    "name": "description",
	                    "range": "MarkdownString",
	                    "domain": "Parameter"
	                },
	                "pattern": {
	                    "name": "pattern",
	                    "range": "StringType",
	                    "domain": "StringTypeDeclaration"
	                },
	                "enum": {
	                    "name": "enum",
	                    "range": "StringType",
	                    "domain": "StringTypeDeclaration"
	                },
	                "minLength": {
	                    "name": "minLength",
	                    "range": "NumberType",
	                    "domain": "StringTypeDeclaration"
	                },
	                "maxLength": {
	                    "name": "maxLength",
	                    "range": "NumberType",
	                    "domain": "StringTypeDeclaration"
	                }
	            }
	        },
	        "BooleanTypeDeclaration": {
	            "name": "BooleanTypeDeclaration",
	            "properties": {
	                "name": {
	                    "name": "name",
	                    "range": "StringType",
	                    "domain": "Parameter"
	                },
	                "displayName": {
	                    "name": "displayName",
	                    "range": "StringType",
	                    "domain": "Parameter"
	                },
	                "type": {
	                    "name": "type",
	                    "range": "StringType",
	                    "domain": "Parameter"
	                },
	                "location": {
	                    "name": "location",
	                    "range": "ParameterLocation",
	                    "domain": "Parameter"
	                },
	                "required": {
	                    "name": "required",
	                    "range": "BooleanType",
	                    "domain": "Parameter"
	                },
	                "default": {
	                    "name": "default",
	                    "range": "AnyType",
	                    "domain": "Parameter"
	                },
	                "example": {
	                    "name": "example",
	                    "range": "StringType",
	                    "domain": "Parameter"
	                },
	                "repeat": {
	                    "name": "repeat",
	                    "range": "BooleanType",
	                    "domain": "Parameter"
	                },
	                "description": {
	                    "name": "description",
	                    "range": "MarkdownString",
	                    "domain": "Parameter"
	                }
	            }
	        },
	        "NumberTypeDeclaration": {
	            "name": "NumberTypeDeclaration",
	            "properties": {
	                "name": {
	                    "name": "name",
	                    "range": "StringType",
	                    "domain": "Parameter"
	                },
	                "displayName": {
	                    "name": "displayName",
	                    "range": "StringType",
	                    "domain": "Parameter"
	                },
	                "type": {
	                    "name": "type",
	                    "range": "StringType",
	                    "domain": "Parameter"
	                },
	                "location": {
	                    "name": "location",
	                    "range": "ParameterLocation",
	                    "domain": "Parameter"
	                },
	                "required": {
	                    "name": "required",
	                    "range": "BooleanType",
	                    "domain": "Parameter"
	                },
	                "default": {
	                    "name": "default",
	                    "range": "AnyType",
	                    "domain": "Parameter"
	                },
	                "example": {
	                    "name": "example",
	                    "range": "StringType",
	                    "domain": "Parameter"
	                },
	                "repeat": {
	                    "name": "repeat",
	                    "range": "BooleanType",
	                    "domain": "Parameter"
	                },
	                "description": {
	                    "name": "description",
	                    "range": "MarkdownString",
	                    "domain": "Parameter"
	                },
	                "minimum": {
	                    "name": "minimum",
	                    "range": "NumberType",
	                    "domain": "NumberTypeDeclaration"
	                },
	                "maximum": {
	                    "name": "maximum",
	                    "range": "NumberType",
	                    "domain": "NumberTypeDeclaration"
	                }
	            }
	        },
	        "IntegerTypeDeclaration": {
	            "name": "IntegerTypeDeclaration",
	            "properties": {
	                "name": {
	                    "name": "name",
	                    "range": "StringType",
	                    "domain": "Parameter"
	                },
	                "displayName": {
	                    "name": "displayName",
	                    "range": "StringType",
	                    "domain": "Parameter"
	                },
	                "type": {
	                    "name": "type",
	                    "range": "StringType",
	                    "domain": "Parameter"
	                },
	                "location": {
	                    "name": "location",
	                    "range": "ParameterLocation",
	                    "domain": "Parameter"
	                },
	                "required": {
	                    "name": "required",
	                    "range": "BooleanType",
	                    "domain": "Parameter"
	                },
	                "default": {
	                    "name": "default",
	                    "range": "AnyType",
	                    "domain": "Parameter"
	                },
	                "example": {
	                    "name": "example",
	                    "range": "StringType",
	                    "domain": "Parameter"
	                },
	                "repeat": {
	                    "name": "repeat",
	                    "range": "BooleanType",
	                    "domain": "Parameter"
	                },
	                "description": {
	                    "name": "description",
	                    "range": "MarkdownString",
	                    "domain": "Parameter"
	                },
	                "minimum": {
	                    "name": "minimum",
	                    "range": "NumberType",
	                    "domain": "NumberTypeDeclaration"
	                },
	                "maximum": {
	                    "name": "maximum",
	                    "range": "NumberType",
	                    "domain": "NumberTypeDeclaration"
	                }
	            }
	        },
	        "DateTypeDeclaration": {
	            "name": "DateTypeDeclaration",
	            "properties": {
	                "name": {
	                    "name": "name",
	                    "range": "StringType",
	                    "domain": "Parameter"
	                },
	                "displayName": {
	                    "name": "displayName",
	                    "range": "StringType",
	                    "domain": "Parameter"
	                },
	                "type": {
	                    "name": "type",
	                    "range": "StringType",
	                    "domain": "Parameter"
	                },
	                "location": {
	                    "name": "location",
	                    "range": "ParameterLocation",
	                    "domain": "Parameter"
	                },
	                "required": {
	                    "name": "required",
	                    "range": "BooleanType",
	                    "domain": "Parameter"
	                },
	                "default": {
	                    "name": "default",
	                    "range": "AnyType",
	                    "domain": "Parameter"
	                },
	                "example": {
	                    "name": "example",
	                    "range": "StringType",
	                    "domain": "Parameter"
	                },
	                "repeat": {
	                    "name": "repeat",
	                    "range": "BooleanType",
	                    "domain": "Parameter"
	                },
	                "description": {
	                    "name": "description",
	                    "range": "MarkdownString",
	                    "domain": "Parameter"
	                }
	            }
	        },
	        "FileTypeDeclaration": {
	            "name": "FileTypeDeclaration",
	            "properties": {
	                "name": {
	                    "name": "name",
	                    "range": "StringType",
	                    "domain": "Parameter"
	                },
	                "displayName": {
	                    "name": "displayName",
	                    "range": "StringType",
	                    "domain": "Parameter"
	                },
	                "type": {
	                    "name": "type",
	                    "range": "StringType",
	                    "domain": "Parameter"
	                },
	                "location": {
	                    "name": "location",
	                    "range": "ParameterLocation",
	                    "domain": "Parameter"
	                },
	                "required": {
	                    "name": "required",
	                    "range": "BooleanType",
	                    "domain": "Parameter"
	                },
	                "default": {
	                    "name": "default",
	                    "range": "AnyType",
	                    "domain": "Parameter"
	                },
	                "example": {
	                    "name": "example",
	                    "range": "StringType",
	                    "domain": "Parameter"
	                },
	                "repeat": {
	                    "name": "repeat",
	                    "range": "BooleanType",
	                    "domain": "Parameter"
	                },
	                "description": {
	                    "name": "description",
	                    "range": "MarkdownString",
	                    "domain": "Parameter"
	                }
	            }
	        },
	        "ParameterLocation": {
	            "name": "ParameterLocation",
	            "properties": {}
	        },
	        "MimeType": {
	            "name": "MimeType",
	            "properties": {}
	        },
	        "BodyLike": {
	            "name": "BodyLike",
	            "properties": {
	                "name": {
	                    "name": "name",
	                    "range": "StringType",
	                    "domain": "BodyLike"
	                },
	                "schema": {
	                    "name": "schema",
	                    "range": "SchemaString",
	                    "domain": "BodyLike"
	                },
	                "example": {
	                    "name": "example",
	                    "range": "ExampleString",
	                    "domain": "BodyLike"
	                },
	                "formParameters": {
	                    "name": "formParameters",
	                    "range": "Parameter",
	                    "domain": "BodyLike"
	                },
	                "description": {
	                    "name": "description",
	                    "range": "MarkdownString",
	                    "domain": "BodyLike"
	                },
	                "schemaContent": {
	                    "name": "schemaContent"
	                }
	            }
	        },
	        "XMLBody": {
	            "name": "XMLBody",
	            "properties": {
	                "name": {
	                    "name": "name",
	                    "range": "StringType",
	                    "domain": "BodyLike"
	                },
	                "schema": {
	                    "name": "schema",
	                    "range": "XMLSchemaString",
	                    "domain": "XMLBody"
	                },
	                "example": {
	                    "name": "example",
	                    "range": "ExampleString",
	                    "domain": "BodyLike"
	                },
	                "formParameters": {
	                    "name": "formParameters",
	                    "range": "Parameter",
	                    "domain": "BodyLike"
	                },
	                "description": {
	                    "name": "description",
	                    "range": "MarkdownString",
	                    "domain": "BodyLike"
	                }
	            }
	        },
	        "JSONBody": {
	            "name": "JSONBody",
	            "properties": {
	                "name": {
	                    "name": "name",
	                    "range": "StringType",
	                    "domain": "BodyLike"
	                },
	                "schema": {
	                    "name": "schema",
	                    "range": "JSonSchemaString",
	                    "domain": "JSONBody"
	                },
	                "example": {
	                    "name": "example",
	                    "range": "ExampleString",
	                    "domain": "BodyLike"
	                },
	                "formParameters": {
	                    "name": "formParameters",
	                    "range": "Parameter",
	                    "domain": "BodyLike"
	                },
	                "description": {
	                    "name": "description",
	                    "range": "MarkdownString",
	                    "domain": "BodyLike"
	                }
	            }
	        },
	        "Response": {
	            "name": "Response",
	            "properties": {
	                "code": {
	                    "name": "code",
	                    "range": "StatusCodeString",
	                    "domain": "Response"
	                },
	                "headers": {
	                    "name": "headers",
	                    "range": "Parameter",
	                    "domain": "Response"
	                },
	                "body": {
	                    "name": "body",
	                    "range": "BodyLike",
	                    "domain": "Response"
	                },
	                "description": {
	                    "name": "description",
	                    "range": "MarkdownString",
	                    "domain": "Response"
	                }
	            }
	        },
	        "Resource": {
	            "name": "Resource",
	            "properties": {
	                "relativeUri": {
	                    "name": "relativeUri",
	                    "range": "RelativeUriString",
	                    "domain": "Resource"
	                },
	                "type": {
	                    "name": "type",
	                    "range": "ResourceTypeRef",
	                    "domain": "Resource"
	                },
	                "is": {
	                    "name": "is",
	                    "range": "TraitRef",
	                    "domain": "Resource"
	                },
	                "securedBy": {
	                    "name": "securedBy",
	                    "range": "SecuritySchemeRef",
	                    "domain": "Resource"
	                },
	                "uriParameters": {
	                    "name": "uriParameters",
	                    "range": "Parameter",
	                    "domain": "Resource"
	                },
	                "methods": {
	                    "name": "methods",
	                    "range": "Method",
	                    "domain": "Resource"
	                },
	                "resources": {
	                    "name": "resources",
	                    "range": "Resource",
	                    "domain": "Resource"
	                },
	                "displayName": {
	                    "name": "displayName",
	                    "range": "StringType",
	                    "domain": "Resource"
	                },
	                "baseUriParameters": {
	                    "name": "baseUriParameters",
	                    "range": "Parameter",
	                    "domain": "Resource"
	                },
	                "description": {
	                    "name": "description",
	                    "range": "MarkdownString",
	                    "domain": "Resource"
	                }
	            }
	        },
	        "ResourceTypeRef": {
	            "name": "ResourceTypeRef",
	            "properties": {
	                "resourceType": {
	                    "name": "resourceType"
	                }
	            }
	        },
	        "ResourceType": {
	            "name": "ResourceType",
	            "properties": {
	                "name": {
	                    "name": "name",
	                    "range": "StringType",
	                    "domain": "ResourceType"
	                },
	                "usage": {
	                    "name": "usage",
	                    "range": "StringType",
	                    "domain": "ResourceType"
	                },
	                "methods": {
	                    "name": "methods",
	                    "range": "Method",
	                    "domain": "ResourceType"
	                },
	                "is": {
	                    "name": "is",
	                    "range": "TraitRef",
	                    "domain": "ResourceType"
	                },
	                "type": {
	                    "name": "type",
	                    "range": "ResourceTypeRef",
	                    "domain": "ResourceType"
	                },
	                "securedBy": {
	                    "name": "securedBy",
	                    "range": "SecuritySchemeRef",
	                    "domain": "ResourceType"
	                },
	                "uriParameters": {
	                    "name": "uriParameters",
	                    "range": "Parameter",
	                    "domain": "ResourceType"
	                },
	                "displayName": {
	                    "name": "displayName",
	                    "range": "StringType",
	                    "domain": "ResourceType"
	                },
	                "baseUriParameters": {
	                    "name": "baseUriParameters",
	                    "range": "Parameter",
	                    "domain": "ResourceType"
	                },
	                "description": {
	                    "name": "description",
	                    "range": "MarkdownString",
	                    "domain": "ResourceType"
	                },
	                "parametrizedProperties": {
	                    "name": "parametrizedProperties"
	                }
	            }
	        },
	        "MethodBase": {
	            "name": "MethodBase",
	            "properties": {
	                "responses": {
	                    "name": "responses",
	                    "range": "Response",
	                    "domain": "MethodBase"
	                },
	                "body": {
	                    "name": "body",
	                    "range": "BodyLike",
	                    "domain": "MethodBase"
	                },
	                "protocols": {
	                    "name": "protocols",
	                    "range": "StringType",
	                    "domain": "MethodBase"
	                },
	                "securedBy": {
	                    "name": "securedBy",
	                    "range": "SecuritySchemeRef",
	                    "domain": "MethodBase"
	                },
	                "baseUriParameters": {
	                    "name": "baseUriParameters",
	                    "range": "Parameter",
	                    "domain": "MethodBase"
	                },
	                "queryParameters": {
	                    "name": "queryParameters",
	                    "range": "Parameter",
	                    "domain": "MethodBase"
	                },
	                "headers": {
	                    "name": "headers",
	                    "range": "Parameter",
	                    "domain": "MethodBase"
	                },
	                "description": {
	                    "name": "description",
	                    "range": "MarkdownString",
	                    "domain": "MethodBase"
	                }
	            }
	        },
	        "Method": {
	            "name": "Method",
	            "properties": {
	                "responses": {
	                    "name": "responses",
	                    "range": "Response",
	                    "domain": "MethodBase"
	                },
	                "body": {
	                    "name": "body",
	                    "range": "BodyLike",
	                    "domain": "MethodBase"
	                },
	                "protocols": {
	                    "name": "protocols",
	                    "range": "StringType",
	                    "domain": "MethodBase"
	                },
	                "securedBy": {
	                    "name": "securedBy",
	                    "range": "SecuritySchemeRef",
	                    "domain": "MethodBase"
	                },
	                "baseUriParameters": {
	                    "name": "baseUriParameters",
	                    "range": "Parameter",
	                    "domain": "MethodBase"
	                },
	                "queryParameters": {
	                    "name": "queryParameters",
	                    "range": "Parameter",
	                    "domain": "MethodBase"
	                },
	                "headers": {
	                    "name": "headers",
	                    "range": "Parameter",
	                    "domain": "MethodBase"
	                },
	                "description": {
	                    "name": "description",
	                    "range": "MarkdownString",
	                    "domain": "MethodBase"
	                },
	                "method": {
	                    "name": "method",
	                    "range": "StringType",
	                    "domain": "Method"
	                },
	                "is": {
	                    "name": "is",
	                    "range": "TraitRef",
	                    "domain": "Method"
	                }
	            }
	        },
	        "Trait": {
	            "name": "Trait",
	            "properties": {
	                "responses": {
	                    "name": "responses",
	                    "range": "Response",
	                    "domain": "MethodBase"
	                },
	                "body": {
	                    "name": "body",
	                    "range": "BodyLike",
	                    "domain": "MethodBase"
	                },
	                "protocols": {
	                    "name": "protocols",
	                    "range": "StringType",
	                    "domain": "MethodBase"
	                },
	                "securedBy": {
	                    "name": "securedBy",
	                    "range": "SecuritySchemeRef",
	                    "domain": "MethodBase"
	                },
	                "baseUriParameters": {
	                    "name": "baseUriParameters",
	                    "range": "Parameter",
	                    "domain": "MethodBase"
	                },
	                "queryParameters": {
	                    "name": "queryParameters",
	                    "range": "Parameter",
	                    "domain": "MethodBase"
	                },
	                "headers": {
	                    "name": "headers",
	                    "range": "Parameter",
	                    "domain": "MethodBase"
	                },
	                "description": {
	                    "name": "description",
	                    "range": "MarkdownString",
	                    "domain": "MethodBase"
	                },
	                "name": {
	                    "name": "name",
	                    "range": "StringType",
	                    "domain": "Trait"
	                },
	                "usage": {
	                    "name": "usage",
	                    "range": "StringType",
	                    "domain": "Trait"
	                },
	                "displayName": {
	                    "name": "displayName",
	                    "range": "StringType",
	                    "domain": "Trait"
	                },
	                "parametrizedProperties": {
	                    "name": "parametrizedProperties"
	                }
	            }
	        },
	        "TraitRef": {
	            "name": "TraitRef",
	            "properties": {
	                "trait": {
	                    "name": "trait"
	                }
	            }
	        },
	        "SecuritySchemePart": {
	            "name": "SecuritySchemePart",
	            "properties": {
	                "responses": {
	                    "name": "responses",
	                    "range": "Response",
	                    "domain": "SecuritySchemePart"
	                },
	                "body": {
	                    "name": "body",
	                    "range": "BodyLike",
	                    "domain": "MethodBase"
	                },
	                "protocols": {
	                    "name": "protocols",
	                    "range": "StringType",
	                    "domain": "MethodBase"
	                },
	                "securedBy": {
	                    "name": "securedBy",
	                    "range": "SecuritySchemeRef",
	                    "domain": "MethodBase"
	                },
	                "baseUriParameters": {
	                    "name": "baseUriParameters",
	                    "range": "Parameter",
	                    "domain": "MethodBase"
	                },
	                "queryParameters": {
	                    "name": "queryParameters",
	                    "range": "Parameter",
	                    "domain": "SecuritySchemePart"
	                },
	                "headers": {
	                    "name": "headers",
	                    "range": "Parameter",
	                    "domain": "SecuritySchemePart"
	                },
	                "description": {
	                    "name": "description",
	                    "range": "MarkdownString",
	                    "domain": "SecuritySchemePart"
	                },
	                "displayName": {
	                    "name": "displayName",
	                    "range": "StringType",
	                    "domain": "SecuritySchemePart"
	                },
	                "is": {
	                    "name": "is",
	                    "range": "TraitRef",
	                    "domain": "SecuritySchemePart"
	                }
	            }
	        },
	        "SecuritySchemeSettings": {
	            "name": "SecuritySchemeSettings",
	            "properties": {}
	        },
	        "AbstractSecurityScheme": {
	            "name": "AbstractSecurityScheme",
	            "properties": {
	                "name": {
	                    "name": "name",
	                    "range": "StringType",
	                    "domain": "AbstractSecurityScheme"
	                },
	                "type": {
	                    "name": "type",
	                    "range": "StringType",
	                    "domain": "AbstractSecurityScheme"
	                },
	                "description": {
	                    "name": "description",
	                    "range": "MarkdownString",
	                    "domain": "AbstractSecurityScheme"
	                },
	                "describedBy": {
	                    "name": "describedBy",
	                    "range": "SecuritySchemePart",
	                    "domain": "AbstractSecurityScheme"
	                },
	                "settings": {
	                    "name": "settings",
	                    "range": "SecuritySchemeSettings",
	                    "domain": "AbstractSecurityScheme"
	                }
	            }
	        },
	        "SecuritySchemeRef": {
	            "name": "SecuritySchemeRef",
	            "properties": {
	                "securitySchemeName": {
	                    "name": "securitySchemeName"
	                },
	                "securityScheme": {
	                    "name": "securityScheme"
	                }
	            }
	        },
	        "OAuth1SecuritySchemeSettings": {
	            "name": "OAuth1SecuritySchemeSettings",
	            "properties": {
	                "requestTokenUri": {
	                    "name": "requestTokenUri",
	                    "range": "FixedUri",
	                    "domain": "OAuth1SecuritySchemeSettings"
	                },
	                "authorizationUri": {
	                    "name": "authorizationUri",
	                    "range": "FixedUri",
	                    "domain": "OAuth1SecuritySchemeSettings"
	                },
	                "tokenCredentialsUri": {
	                    "name": "tokenCredentialsUri",
	                    "range": "FixedUri",
	                    "domain": "OAuth1SecuritySchemeSettings"
	                }
	            }
	        },
	        "OAuth2SecuritySchemeSettings": {
	            "name": "OAuth2SecuritySchemeSettings",
	            "properties": {
	                "accessTokenUri": {
	                    "name": "accessTokenUri",
	                    "range": "FixedUri",
	                    "domain": "OAuth2SecuritySchemeSettings"
	                },
	                "authorizationUri": {
	                    "name": "authorizationUri",
	                    "range": "FixedUri",
	                    "domain": "OAuth2SecuritySchemeSettings"
	                },
	                "authorizationGrants": {
	                    "name": "authorizationGrants",
	                    "range": "StringType",
	                    "domain": "OAuth2SecuritySchemeSettings"
	                },
	                "scopes": {
	                    "name": "scopes",
	                    "range": "StringType",
	                    "domain": "OAuth2SecuritySchemeSettings"
	                }
	            }
	        },
	        "OAuth2SecurityScheme": {
	            "name": "OAuth2SecurityScheme",
	            "properties": {
	                "name": {
	                    "name": "name",
	                    "range": "StringType",
	                    "domain": "AbstractSecurityScheme"
	                },
	                "type": {
	                    "name": "type",
	                    "range": "StringType",
	                    "domain": "AbstractSecurityScheme"
	                },
	                "description": {
	                    "name": "description",
	                    "range": "MarkdownString",
	                    "domain": "AbstractSecurityScheme"
	                },
	                "describedBy": {
	                    "name": "describedBy",
	                    "range": "SecuritySchemePart",
	                    "domain": "AbstractSecurityScheme"
	                },
	                "settings": {
	                    "name": "settings",
	                    "range": "OAuth2SecuritySchemeSettings",
	                    "domain": "OAuth2SecurityScheme"
	                }
	            }
	        },
	        "OAuth1SecurityScheme": {
	            "name": "OAuth1SecurityScheme",
	            "properties": {
	                "name": {
	                    "name": "name",
	                    "range": "StringType",
	                    "domain": "AbstractSecurityScheme"
	                },
	                "type": {
	                    "name": "type",
	                    "range": "StringType",
	                    "domain": "AbstractSecurityScheme"
	                },
	                "description": {
	                    "name": "description",
	                    "range": "MarkdownString",
	                    "domain": "AbstractSecurityScheme"
	                },
	                "describedBy": {
	                    "name": "describedBy",
	                    "range": "SecuritySchemePart",
	                    "domain": "AbstractSecurityScheme"
	                },
	                "settings": {
	                    "name": "settings",
	                    "range": "OAuth1SecuritySchemeSettings",
	                    "domain": "OAuth1SecurityScheme"
	                }
	            }
	        },
	        "BasicSecurityScheme": {
	            "name": "BasicSecurityScheme",
	            "properties": {
	                "name": {
	                    "name": "name",
	                    "range": "StringType",
	                    "domain": "AbstractSecurityScheme"
	                },
	                "type": {
	                    "name": "type",
	                    "range": "StringType",
	                    "domain": "AbstractSecurityScheme"
	                },
	                "description": {
	                    "name": "description",
	                    "range": "MarkdownString",
	                    "domain": "AbstractSecurityScheme"
	                },
	                "describedBy": {
	                    "name": "describedBy",
	                    "range": "SecuritySchemePart",
	                    "domain": "AbstractSecurityScheme"
	                },
	                "settings": {
	                    "name": "settings",
	                    "range": "SecuritySchemeSettings",
	                    "domain": "AbstractSecurityScheme"
	                }
	            }
	        },
	        "DigestSecurityScheme": {
	            "name": "DigestSecurityScheme",
	            "properties": {
	                "name": {
	                    "name": "name",
	                    "range": "StringType",
	                    "domain": "AbstractSecurityScheme"
	                },
	                "type": {
	                    "name": "type",
	                    "range": "StringType",
	                    "domain": "AbstractSecurityScheme"
	                },
	                "description": {
	                    "name": "description",
	                    "range": "MarkdownString",
	                    "domain": "AbstractSecurityScheme"
	                },
	                "describedBy": {
	                    "name": "describedBy",
	                    "range": "SecuritySchemePart",
	                    "domain": "AbstractSecurityScheme"
	                },
	                "settings": {
	                    "name": "settings",
	                    "range": "SecuritySchemeSettings",
	                    "domain": "AbstractSecurityScheme"
	                }
	            }
	        },
	        "CustomSecurityScheme": {
	            "name": "CustomSecurityScheme",
	            "properties": {
	                "name": {
	                    "name": "name",
	                    "range": "StringType",
	                    "domain": "AbstractSecurityScheme"
	                },
	                "type": {
	                    "name": "type",
	                    "range": "StringType",
	                    "domain": "AbstractSecurityScheme"
	                },
	                "description": {
	                    "name": "description",
	                    "range": "MarkdownString",
	                    "domain": "AbstractSecurityScheme"
	                },
	                "describedBy": {
	                    "name": "describedBy",
	                    "range": "SecuritySchemePart",
	                    "domain": "AbstractSecurityScheme"
	                },
	                "settings": {
	                    "name": "settings",
	                    "range": "SecuritySchemeSettings",
	                    "domain": "AbstractSecurityScheme"
	                }
	            }
	        }
	    },
	    "Universe10": {
	        "Library": {
	            "name": "Library",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "uses": {
	                    "name": "uses"
	                },
	                "schemas": {
	                    "name": "schemas"
	                },
	                "types": {
	                    "name": "types"
	                },
	                "traits": {
	                    "name": "traits"
	                },
	                "resourceTypes": {
	                    "name": "resourceTypes"
	                },
	                "annotationTypes": {
	                    "name": "annotationTypes"
	                },
	                "securitySchemes": {
	                    "name": "securitySchemes"
	                },
	                "usage": {
	                    "name": "usage"
	                },
	                "name": {
	                    "name": "name"
	                }
	            }
	        },
	        "LibraryBase": {
	            "name": "LibraryBase",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "uses": {
	                    "name": "uses"
	                },
	                "schemas": {
	                    "name": "schemas"
	                },
	                "types": {
	                    "name": "types"
	                },
	                "traits": {
	                    "name": "traits"
	                },
	                "resourceTypes": {
	                    "name": "resourceTypes"
	                },
	                "annotationTypes": {
	                    "name": "annotationTypes"
	                },
	                "securitySchemes": {
	                    "name": "securitySchemes"
	                }
	            }
	        },
	        "Api": {
	            "name": "Api",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "uses": {
	                    "name": "uses"
	                },
	                "schemas": {
	                    "name": "schemas"
	                },
	                "types": {
	                    "name": "types"
	                },
	                "traits": {
	                    "name": "traits"
	                },
	                "resourceTypes": {
	                    "name": "resourceTypes"
	                },
	                "annotationTypes": {
	                    "name": "annotationTypes"
	                },
	                "securitySchemes": {
	                    "name": "securitySchemes"
	                },
	                "title": {
	                    "name": "title"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "version": {
	                    "name": "version"
	                },
	                "baseUri": {
	                    "name": "baseUri"
	                },
	                "baseUriParameters": {
	                    "name": "baseUriParameters"
	                },
	                "protocols": {
	                    "name": "protocols"
	                },
	                "mediaType": {
	                    "name": "mediaType"
	                },
	                "securedBy": {
	                    "name": "securedBy"
	                },
	                "resources": {
	                    "name": "resources"
	                },
	                "documentation": {
	                    "name": "documentation"
	                },
	                "RAMLVersion": {
	                    "name": "RAMLVersion",
	                    "range": "StringType",
	                    "domain": "Api"
	                }
	            }
	        },
	        "Overlay": {
	            "name": "Overlay",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "uses": {
	                    "name": "uses"
	                },
	                "schemas": {
	                    "name": "schemas"
	                },
	                "types": {
	                    "name": "types"
	                },
	                "traits": {
	                    "name": "traits"
	                },
	                "resourceTypes": {
	                    "name": "resourceTypes"
	                },
	                "annotationTypes": {
	                    "name": "annotationTypes"
	                },
	                "securitySchemes": {
	                    "name": "securitySchemes"
	                },
	                "title": {
	                    "name": "title"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "version": {
	                    "name": "version"
	                },
	                "baseUri": {
	                    "name": "baseUri"
	                },
	                "baseUriParameters": {
	                    "name": "baseUriParameters"
	                },
	                "protocols": {
	                    "name": "protocols"
	                },
	                "mediaType": {
	                    "name": "mediaType"
	                },
	                "securedBy": {
	                    "name": "securedBy"
	                },
	                "resources": {
	                    "name": "resources"
	                },
	                "documentation": {
	                    "name": "documentation"
	                },
	                "usage": {
	                    "name": "usage"
	                },
	                "extends": {
	                    "name": "extends"
	                }
	            }
	        },
	        "Extension": {
	            "name": "Extension",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "uses": {
	                    "name": "uses"
	                },
	                "schemas": {
	                    "name": "schemas"
	                },
	                "types": {
	                    "name": "types"
	                },
	                "traits": {
	                    "name": "traits"
	                },
	                "resourceTypes": {
	                    "name": "resourceTypes"
	                },
	                "annotationTypes": {
	                    "name": "annotationTypes"
	                },
	                "securitySchemes": {
	                    "name": "securitySchemes"
	                },
	                "title": {
	                    "name": "title"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "version": {
	                    "name": "version"
	                },
	                "baseUri": {
	                    "name": "baseUri"
	                },
	                "baseUriParameters": {
	                    "name": "baseUriParameters"
	                },
	                "protocols": {
	                    "name": "protocols"
	                },
	                "mediaType": {
	                    "name": "mediaType"
	                },
	                "securedBy": {
	                    "name": "securedBy"
	                },
	                "resources": {
	                    "name": "resources"
	                },
	                "documentation": {
	                    "name": "documentation"
	                },
	                "usage": {
	                    "name": "usage"
	                },
	                "extends": {
	                    "name": "extends"
	                }
	            }
	        },
	        "UsesDeclaration": {
	            "name": "UsesDeclaration",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "key": {
	                    "name": "key"
	                },
	                "value": {
	                    "name": "value"
	                }
	            }
	        },
	        "FragmentDeclaration": {
	            "name": "FragmentDeclaration",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "uses": {
	                    "name": "uses"
	                }
	            }
	        },
	        "DocumentationItem": {
	            "name": "DocumentationItem",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "title": {
	                    "name": "title"
	                },
	                "content": {
	                    "name": "content"
	                }
	            }
	        },
	        "ValueType": {
	            "name": "ValueType",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                }
	            }
	        },
	        "StringType": {
	            "name": "StringType",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                }
	            }
	        },
	        "AnyType": {
	            "name": "AnyType",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                }
	            }
	        },
	        "NumberType": {
	            "name": "NumberType",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                }
	            }
	        },
	        "IntegerType": {
	            "name": "IntegerType",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                }
	            }
	        },
	        "NullType": {
	            "name": "NullType",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                }
	            }
	        },
	        "TimeOnlyType": {
	            "name": "TimeOnlyType",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                }
	            }
	        },
	        "DateOnlyType": {
	            "name": "DateOnlyType",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                }
	            }
	        },
	        "DateTimeOnlyType": {
	            "name": "DateTimeOnlyType",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                }
	            }
	        },
	        "DateTimeType": {
	            "name": "DateTimeType",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                }
	            }
	        },
	        "FileType": {
	            "name": "FileType",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                }
	            }
	        },
	        "BooleanType": {
	            "name": "BooleanType",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                }
	            }
	        },
	        "Reference": {
	            "name": "Reference",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "structuredValue": {
	                    "name": "structuredValue",
	                    "range": "TypeInstance",
	                    "domain": "Reference"
	                },
	                "name": {
	                    "name": "name",
	                    "range": "StringType",
	                    "domain": "Reference"
	                }
	            }
	        },
	        "UriTemplate": {
	            "name": "UriTemplate",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                }
	            }
	        },
	        "StatusCodeString": {
	            "name": "StatusCodeString",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                }
	            }
	        },
	        "RelativeUriString": {
	            "name": "RelativeUriString",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                }
	            }
	        },
	        "FullUriTemplateString": {
	            "name": "FullUriTemplateString",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                }
	            }
	        },
	        "FixedUriString": {
	            "name": "FixedUriString",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                }
	            }
	        },
	        "ContentType": {
	            "name": "ContentType",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                }
	            }
	        },
	        "MarkdownString": {
	            "name": "MarkdownString",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                }
	            }
	        },
	        "SchemaString": {
	            "name": "SchemaString",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                }
	            }
	        },
	        "ExampleSpec": {
	            "name": "ExampleSpec",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "value": {
	                    "name": "value"
	                },
	                "strict": {
	                    "name": "strict"
	                },
	                "name": {
	                    "name": "name"
	                },
	                "displayName": {
	                    "name": "displayName"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "structuredValue": {
	                    "name": "structuredValue",
	                    "range": "TypeInstance",
	                    "domain": "ExampleSpec"
	                }
	            }
	        },
	        "TypeDeclaration": {
	            "name": "TypeDeclaration",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "name": {
	                    "name": "name"
	                },
	                "displayName": {
	                    "name": "displayName"
	                },
	                "facets": {
	                    "name": "facets"
	                },
	                "schema": {
	                    "name": "schema"
	                },
	                "type": {
	                    "name": "type"
	                },
	                "location": {
	                    "name": "location"
	                },
	                "locationKind": {
	                    "name": "locationKind"
	                },
	                "default": {
	                    "name": "default"
	                },
	                "example": {
	                    "name": "example"
	                },
	                "examples": {
	                    "name": "examples"
	                },
	                "repeat": {
	                    "name": "repeat"
	                },
	                "required": {
	                    "name": "required"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "xml": {
	                    "name": "xml"
	                },
	                "allowedTargets": {
	                    "name": "allowedTargets"
	                },
	                "isAnnotation": {
	                    "name": "isAnnotation"
	                },
	                "fixedFacets": {
	                    "name": "fixedFacets",
	                    "range": "TypeInstance",
	                    "domain": "TypeDeclaration"
	                },
	                "structuredType": {
	                    "name": "structuredType",
	                    "range": "TypeInstance",
	                    "domain": "TypeDeclaration"
	                }
	            }
	        },
	        "XMLFacetInfo": {
	            "name": "XMLFacetInfo",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "attribute": {
	                    "name": "attribute"
	                },
	                "wrapped": {
	                    "name": "wrapped"
	                },
	                "name": {
	                    "name": "name"
	                },
	                "namespace": {
	                    "name": "namespace"
	                },
	                "prefix": {
	                    "name": "prefix"
	                }
	            }
	        },
	        "ArrayTypeDeclaration": {
	            "name": "ArrayTypeDeclaration",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "name": {
	                    "name": "name"
	                },
	                "displayName": {
	                    "name": "displayName"
	                },
	                "facets": {
	                    "name": "facets"
	                },
	                "schema": {
	                    "name": "schema"
	                },
	                "type": {
	                    "name": "type"
	                },
	                "location": {
	                    "name": "location"
	                },
	                "locationKind": {
	                    "name": "locationKind"
	                },
	                "default": {
	                    "name": "default"
	                },
	                "example": {
	                    "name": "example"
	                },
	                "examples": {
	                    "name": "examples"
	                },
	                "repeat": {
	                    "name": "repeat"
	                },
	                "required": {
	                    "name": "required"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "xml": {
	                    "name": "xml"
	                },
	                "allowedTargets": {
	                    "name": "allowedTargets"
	                },
	                "isAnnotation": {
	                    "name": "isAnnotation"
	                },
	                "uniqueItems": {
	                    "name": "uniqueItems"
	                },
	                "items": {
	                    "name": "items"
	                },
	                "minItems": {
	                    "name": "minItems"
	                },
	                "maxItems": {
	                    "name": "maxItems"
	                }
	            }
	        },
	        "UnionTypeDeclaration": {
	            "name": "UnionTypeDeclaration",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "name": {
	                    "name": "name"
	                },
	                "displayName": {
	                    "name": "displayName"
	                },
	                "facets": {
	                    "name": "facets"
	                },
	                "schema": {
	                    "name": "schema"
	                },
	                "type": {
	                    "name": "type"
	                },
	                "location": {
	                    "name": "location"
	                },
	                "locationKind": {
	                    "name": "locationKind"
	                },
	                "default": {
	                    "name": "default"
	                },
	                "example": {
	                    "name": "example"
	                },
	                "examples": {
	                    "name": "examples"
	                },
	                "repeat": {
	                    "name": "repeat"
	                },
	                "required": {
	                    "name": "required"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "xml": {
	                    "name": "xml"
	                },
	                "allowedTargets": {
	                    "name": "allowedTargets"
	                },
	                "isAnnotation": {
	                    "name": "isAnnotation"
	                }
	            }
	        },
	        "ObjectTypeDeclaration": {
	            "name": "ObjectTypeDeclaration",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "name": {
	                    "name": "name"
	                },
	                "displayName": {
	                    "name": "displayName"
	                },
	                "facets": {
	                    "name": "facets"
	                },
	                "schema": {
	                    "name": "schema"
	                },
	                "type": {
	                    "name": "type"
	                },
	                "location": {
	                    "name": "location"
	                },
	                "locationKind": {
	                    "name": "locationKind"
	                },
	                "default": {
	                    "name": "default"
	                },
	                "example": {
	                    "name": "example"
	                },
	                "examples": {
	                    "name": "examples"
	                },
	                "repeat": {
	                    "name": "repeat"
	                },
	                "required": {
	                    "name": "required"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "xml": {
	                    "name": "xml"
	                },
	                "allowedTargets": {
	                    "name": "allowedTargets"
	                },
	                "isAnnotation": {
	                    "name": "isAnnotation"
	                },
	                "properties": {
	                    "name": "properties"
	                },
	                "minProperties": {
	                    "name": "minProperties"
	                },
	                "maxProperties": {
	                    "name": "maxProperties"
	                },
	                "additionalProperties": {
	                    "name": "additionalProperties"
	                },
	                "patternProperties": {
	                    "name": "patternProperties"
	                },
	                "discriminator": {
	                    "name": "discriminator"
	                },
	                "discriminatorValue": {
	                    "name": "discriminatorValue"
	                }
	            }
	        },
	        "StringTypeDeclaration": {
	            "name": "StringTypeDeclaration",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "name": {
	                    "name": "name"
	                },
	                "displayName": {
	                    "name": "displayName"
	                },
	                "facets": {
	                    "name": "facets"
	                },
	                "schema": {
	                    "name": "schema"
	                },
	                "type": {
	                    "name": "type"
	                },
	                "location": {
	                    "name": "location"
	                },
	                "locationKind": {
	                    "name": "locationKind"
	                },
	                "default": {
	                    "name": "default"
	                },
	                "example": {
	                    "name": "example"
	                },
	                "examples": {
	                    "name": "examples"
	                },
	                "repeat": {
	                    "name": "repeat"
	                },
	                "required": {
	                    "name": "required"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "xml": {
	                    "name": "xml"
	                },
	                "allowedTargets": {
	                    "name": "allowedTargets"
	                },
	                "isAnnotation": {
	                    "name": "isAnnotation"
	                },
	                "pattern": {
	                    "name": "pattern"
	                },
	                "minLength": {
	                    "name": "minLength"
	                },
	                "maxLength": {
	                    "name": "maxLength"
	                },
	                "enum": {
	                    "name": "enum"
	                }
	            }
	        },
	        "BooleanTypeDeclaration": {
	            "name": "BooleanTypeDeclaration",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "name": {
	                    "name": "name"
	                },
	                "displayName": {
	                    "name": "displayName"
	                },
	                "facets": {
	                    "name": "facets"
	                },
	                "schema": {
	                    "name": "schema"
	                },
	                "type": {
	                    "name": "type"
	                },
	                "location": {
	                    "name": "location"
	                },
	                "locationKind": {
	                    "name": "locationKind"
	                },
	                "default": {
	                    "name": "default"
	                },
	                "example": {
	                    "name": "example"
	                },
	                "examples": {
	                    "name": "examples"
	                },
	                "repeat": {
	                    "name": "repeat"
	                },
	                "required": {
	                    "name": "required"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "xml": {
	                    "name": "xml"
	                },
	                "allowedTargets": {
	                    "name": "allowedTargets"
	                },
	                "isAnnotation": {
	                    "name": "isAnnotation"
	                }
	            }
	        },
	        "NumberTypeDeclaration": {
	            "name": "NumberTypeDeclaration",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "name": {
	                    "name": "name"
	                },
	                "displayName": {
	                    "name": "displayName"
	                },
	                "facets": {
	                    "name": "facets"
	                },
	                "schema": {
	                    "name": "schema"
	                },
	                "type": {
	                    "name": "type"
	                },
	                "location": {
	                    "name": "location"
	                },
	                "locationKind": {
	                    "name": "locationKind"
	                },
	                "default": {
	                    "name": "default"
	                },
	                "example": {
	                    "name": "example"
	                },
	                "examples": {
	                    "name": "examples"
	                },
	                "repeat": {
	                    "name": "repeat"
	                },
	                "required": {
	                    "name": "required"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "xml": {
	                    "name": "xml"
	                },
	                "allowedTargets": {
	                    "name": "allowedTargets"
	                },
	                "isAnnotation": {
	                    "name": "isAnnotation"
	                },
	                "minimum": {
	                    "name": "minimum"
	                },
	                "maximum": {
	                    "name": "maximum"
	                },
	                "enum": {
	                    "name": "enum"
	                },
	                "format": {
	                    "name": "format"
	                },
	                "multipleOf": {
	                    "name": "multipleOf"
	                }
	            }
	        },
	        "IntegerTypeDeclaration": {
	            "name": "IntegerTypeDeclaration",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "name": {
	                    "name": "name"
	                },
	                "displayName": {
	                    "name": "displayName"
	                },
	                "facets": {
	                    "name": "facets"
	                },
	                "schema": {
	                    "name": "schema"
	                },
	                "type": {
	                    "name": "type"
	                },
	                "location": {
	                    "name": "location"
	                },
	                "locationKind": {
	                    "name": "locationKind"
	                },
	                "default": {
	                    "name": "default"
	                },
	                "example": {
	                    "name": "example"
	                },
	                "examples": {
	                    "name": "examples"
	                },
	                "repeat": {
	                    "name": "repeat"
	                },
	                "required": {
	                    "name": "required"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "xml": {
	                    "name": "xml"
	                },
	                "allowedTargets": {
	                    "name": "allowedTargets"
	                },
	                "isAnnotation": {
	                    "name": "isAnnotation"
	                },
	                "minimum": {
	                    "name": "minimum"
	                },
	                "maximum": {
	                    "name": "maximum"
	                },
	                "enum": {
	                    "name": "enum"
	                },
	                "format": {
	                    "name": "format"
	                },
	                "multipleOf": {
	                    "name": "multipleOf"
	                }
	            }
	        },
	        "DateOnlyTypeDeclaration": {
	            "name": "DateOnlyTypeDeclaration",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "name": {
	                    "name": "name"
	                },
	                "displayName": {
	                    "name": "displayName"
	                },
	                "facets": {
	                    "name": "facets"
	                },
	                "schema": {
	                    "name": "schema"
	                },
	                "type": {
	                    "name": "type"
	                },
	                "location": {
	                    "name": "location"
	                },
	                "locationKind": {
	                    "name": "locationKind"
	                },
	                "default": {
	                    "name": "default"
	                },
	                "example": {
	                    "name": "example"
	                },
	                "examples": {
	                    "name": "examples"
	                },
	                "repeat": {
	                    "name": "repeat"
	                },
	                "required": {
	                    "name": "required"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "xml": {
	                    "name": "xml"
	                },
	                "allowedTargets": {
	                    "name": "allowedTargets"
	                },
	                "isAnnotation": {
	                    "name": "isAnnotation"
	                }
	            }
	        },
	        "TimeOnlyTypeDeclaration": {
	            "name": "TimeOnlyTypeDeclaration",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "name": {
	                    "name": "name"
	                },
	                "displayName": {
	                    "name": "displayName"
	                },
	                "facets": {
	                    "name": "facets"
	                },
	                "schema": {
	                    "name": "schema"
	                },
	                "type": {
	                    "name": "type"
	                },
	                "location": {
	                    "name": "location"
	                },
	                "locationKind": {
	                    "name": "locationKind"
	                },
	                "default": {
	                    "name": "default"
	                },
	                "example": {
	                    "name": "example"
	                },
	                "examples": {
	                    "name": "examples"
	                },
	                "repeat": {
	                    "name": "repeat"
	                },
	                "required": {
	                    "name": "required"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "xml": {
	                    "name": "xml"
	                },
	                "allowedTargets": {
	                    "name": "allowedTargets"
	                },
	                "isAnnotation": {
	                    "name": "isAnnotation"
	                }
	            }
	        },
	        "DateTimeOnlyTypeDeclaration": {
	            "name": "DateTimeOnlyTypeDeclaration",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "name": {
	                    "name": "name"
	                },
	                "displayName": {
	                    "name": "displayName"
	                },
	                "facets": {
	                    "name": "facets"
	                },
	                "schema": {
	                    "name": "schema"
	                },
	                "type": {
	                    "name": "type"
	                },
	                "location": {
	                    "name": "location"
	                },
	                "locationKind": {
	                    "name": "locationKind"
	                },
	                "default": {
	                    "name": "default"
	                },
	                "example": {
	                    "name": "example"
	                },
	                "examples": {
	                    "name": "examples"
	                },
	                "repeat": {
	                    "name": "repeat"
	                },
	                "required": {
	                    "name": "required"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "xml": {
	                    "name": "xml"
	                },
	                "allowedTargets": {
	                    "name": "allowedTargets"
	                },
	                "isAnnotation": {
	                    "name": "isAnnotation"
	                }
	            }
	        },
	        "DateTimeTypeDeclaration": {
	            "name": "DateTimeTypeDeclaration",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "name": {
	                    "name": "name"
	                },
	                "displayName": {
	                    "name": "displayName"
	                },
	                "facets": {
	                    "name": "facets"
	                },
	                "schema": {
	                    "name": "schema"
	                },
	                "type": {
	                    "name": "type"
	                },
	                "location": {
	                    "name": "location"
	                },
	                "locationKind": {
	                    "name": "locationKind"
	                },
	                "default": {
	                    "name": "default"
	                },
	                "example": {
	                    "name": "example"
	                },
	                "examples": {
	                    "name": "examples"
	                },
	                "repeat": {
	                    "name": "repeat"
	                },
	                "required": {
	                    "name": "required"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "xml": {
	                    "name": "xml"
	                },
	                "allowedTargets": {
	                    "name": "allowedTargets"
	                },
	                "isAnnotation": {
	                    "name": "isAnnotation"
	                },
	                "format": {
	                    "name": "format"
	                }
	            }
	        },
	        "DateTypeDeclaration": {
	            "name": "DateTypeDeclaration",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "name": {
	                    "name": "name"
	                },
	                "displayName": {
	                    "name": "displayName"
	                },
	                "facets": {
	                    "name": "facets"
	                },
	                "schema": {
	                    "name": "schema"
	                },
	                "type": {
	                    "name": "type"
	                },
	                "location": {
	                    "name": "location"
	                },
	                "locationKind": {
	                    "name": "locationKind"
	                },
	                "default": {
	                    "name": "default"
	                },
	                "example": {
	                    "name": "example"
	                },
	                "examples": {
	                    "name": "examples"
	                },
	                "repeat": {
	                    "name": "repeat"
	                },
	                "required": {
	                    "name": "required"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "xml": {
	                    "name": "xml"
	                },
	                "allowedTargets": {
	                    "name": "allowedTargets"
	                },
	                "isAnnotation": {
	                    "name": "isAnnotation"
	                }
	            }
	        },
	        "TypeInstance": {
	            "name": "TypeInstance",
	            "properties": {
	                "properties": {
	                    "name": "properties"
	                },
	                "isScalar": {
	                    "name": "isScalar"
	                },
	                "value": {
	                    "name": "value"
	                }
	            }
	        },
	        "TypeInstanceProperty": {
	            "name": "TypeInstanceProperty",
	            "properties": {
	                "name": {
	                    "name": "name"
	                },
	                "value": {
	                    "name": "value"
	                },
	                "values": {
	                    "name": "values"
	                },
	                "isArray": {
	                    "name": "isArray"
	                }
	            }
	        },
	        "ModelLocation": {
	            "name": "ModelLocation",
	            "properties": {}
	        },
	        "LocationKind": {
	            "name": "LocationKind",
	            "properties": {}
	        },
	        "MimeType": {
	            "name": "MimeType",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                }
	            }
	        },
	        "Response": {
	            "name": "Response",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "code": {
	                    "name": "code"
	                },
	                "headers": {
	                    "name": "headers"
	                },
	                "body": {
	                    "name": "body"
	                },
	                "description": {
	                    "name": "description"
	                }
	            }
	        },
	        "Annotable": {
	            "name": "Annotable",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                }
	            }
	        },
	        "AnnotationRef": {
	            "name": "AnnotationRef",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "annotation": {
	                    "name": "annotation",
	                    "range": "TypeDeclaration",
	                    "domain": "AnnotationRef"
	                }
	            }
	        },
	        "AnnotationTarget": {
	            "name": "AnnotationTarget",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                }
	            }
	        },
	        "TraitRef": {
	            "name": "TraitRef",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "trait": {
	                    "name": "trait",
	                    "range": "Trait",
	                    "domain": "TraitRef"
	                }
	            }
	        },
	        "Trait": {
	            "name": "Trait",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "queryParameters": {
	                    "name": "queryParameters"
	                },
	                "headers": {
	                    "name": "headers"
	                },
	                "queryString": {
	                    "name": "queryString"
	                },
	                "responses": {
	                    "name": "responses"
	                },
	                "body": {
	                    "name": "body"
	                },
	                "protocols": {
	                    "name": "protocols"
	                },
	                "is": {
	                    "name": "is"
	                },
	                "securedBy": {
	                    "name": "securedBy"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "displayName": {
	                    "name": "displayName"
	                },
	                "name": {
	                    "name": "name"
	                },
	                "usage": {
	                    "name": "usage"
	                },
	                "parametrizedProperties": {
	                    "name": "parametrizedProperties",
	                    "range": "TypeInstance",
	                    "domain": "Trait"
	                }
	            }
	        },
	        "MethodBase": {
	            "name": "MethodBase",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "queryParameters": {
	                    "name": "queryParameters"
	                },
	                "headers": {
	                    "name": "headers"
	                },
	                "queryString": {
	                    "name": "queryString"
	                },
	                "responses": {
	                    "name": "responses"
	                },
	                "body": {
	                    "name": "body"
	                },
	                "protocols": {
	                    "name": "protocols"
	                },
	                "is": {
	                    "name": "is"
	                },
	                "securedBy": {
	                    "name": "securedBy"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "displayName": {
	                    "name": "displayName"
	                }
	            }
	        },
	        "Method": {
	            "name": "Method",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "queryParameters": {
	                    "name": "queryParameters"
	                },
	                "headers": {
	                    "name": "headers"
	                },
	                "queryString": {
	                    "name": "queryString"
	                },
	                "responses": {
	                    "name": "responses"
	                },
	                "body": {
	                    "name": "body"
	                },
	                "protocols": {
	                    "name": "protocols"
	                },
	                "is": {
	                    "name": "is"
	                },
	                "securedBy": {
	                    "name": "securedBy"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "displayName": {
	                    "name": "displayName"
	                },
	                "method": {
	                    "name": "method"
	                }
	            }
	        },
	        "Operation": {
	            "name": "Operation",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "queryParameters": {
	                    "name": "queryParameters"
	                },
	                "headers": {
	                    "name": "headers"
	                },
	                "queryString": {
	                    "name": "queryString"
	                },
	                "responses": {
	                    "name": "responses"
	                }
	            }
	        },
	        "SecuritySchemePart": {
	            "name": "SecuritySchemePart",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "queryParameters": {
	                    "name": "queryParameters"
	                },
	                "headers": {
	                    "name": "headers"
	                },
	                "queryString": {
	                    "name": "queryString"
	                },
	                "responses": {
	                    "name": "responses"
	                }
	            }
	        },
	        "SecuritySchemeSettings": {
	            "name": "SecuritySchemeSettings",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                }
	            }
	        },
	        "OAuth1SecuritySchemeSettings": {
	            "name": "OAuth1SecuritySchemeSettings",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "requestTokenUri": {
	                    "name": "requestTokenUri"
	                },
	                "authorizationUri": {
	                    "name": "authorizationUri"
	                },
	                "tokenCredentialsUri": {
	                    "name": "tokenCredentialsUri"
	                },
	                "signatures": {
	                    "name": "signatures"
	                }
	            }
	        },
	        "OAuth2SecuritySchemeSettings": {
	            "name": "OAuth2SecuritySchemeSettings",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "accessTokenUri": {
	                    "name": "accessTokenUri"
	                },
	                "authorizationUri": {
	                    "name": "authorizationUri"
	                },
	                "authorizationGrants": {
	                    "name": "authorizationGrants"
	                },
	                "scopes": {
	                    "name": "scopes"
	                }
	            }
	        },
	        "SecuritySchemeRef": {
	            "name": "SecuritySchemeRef",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "securitySchemeName": {
	                    "name": "securitySchemeName",
	                    "range": "StringType",
	                    "domain": "SecuritySchemeRef"
	                },
	                "securityScheme": {
	                    "name": "securityScheme",
	                    "range": "AbstractSecurityScheme",
	                    "domain": "SecuritySchemeRef"
	                }
	            }
	        },
	        "AbstractSecurityScheme": {
	            "name": "AbstractSecurityScheme",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "name": {
	                    "name": "name"
	                },
	                "type": {
	                    "name": "type"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "describedBy": {
	                    "name": "describedBy"
	                },
	                "displayName": {
	                    "name": "displayName"
	                },
	                "settings": {
	                    "name": "settings"
	                }
	            }
	        },
	        "OAuth2SecurityScheme": {
	            "name": "OAuth2SecurityScheme",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "name": {
	                    "name": "name"
	                },
	                "type": {
	                    "name": "type"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "describedBy": {
	                    "name": "describedBy"
	                },
	                "displayName": {
	                    "name": "displayName"
	                },
	                "settings": {
	                    "name": "settings"
	                }
	            }
	        },
	        "OAuth1SecurityScheme": {
	            "name": "OAuth1SecurityScheme",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "name": {
	                    "name": "name"
	                },
	                "type": {
	                    "name": "type"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "describedBy": {
	                    "name": "describedBy"
	                },
	                "displayName": {
	                    "name": "displayName"
	                },
	                "settings": {
	                    "name": "settings"
	                }
	            }
	        },
	        "PassThroughSecurityScheme": {
	            "name": "PassThroughSecurityScheme",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "name": {
	                    "name": "name"
	                },
	                "type": {
	                    "name": "type"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "describedBy": {
	                    "name": "describedBy"
	                },
	                "displayName": {
	                    "name": "displayName"
	                },
	                "settings": {
	                    "name": "settings"
	                }
	            }
	        },
	        "BasicSecurityScheme": {
	            "name": "BasicSecurityScheme",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "name": {
	                    "name": "name"
	                },
	                "type": {
	                    "name": "type"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "describedBy": {
	                    "name": "describedBy"
	                },
	                "displayName": {
	                    "name": "displayName"
	                },
	                "settings": {
	                    "name": "settings"
	                }
	            }
	        },
	        "DigestSecurityScheme": {
	            "name": "DigestSecurityScheme",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "name": {
	                    "name": "name"
	                },
	                "type": {
	                    "name": "type"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "describedBy": {
	                    "name": "describedBy"
	                },
	                "displayName": {
	                    "name": "displayName"
	                },
	                "settings": {
	                    "name": "settings"
	                }
	            }
	        },
	        "CustomSecurityScheme": {
	            "name": "CustomSecurityScheme",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "name": {
	                    "name": "name"
	                },
	                "type": {
	                    "name": "type"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "describedBy": {
	                    "name": "describedBy"
	                },
	                "displayName": {
	                    "name": "displayName"
	                },
	                "settings": {
	                    "name": "settings"
	                }
	            }
	        },
	        "ResourceTypeRef": {
	            "name": "ResourceTypeRef",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "resourceType": {
	                    "name": "resourceType",
	                    "range": "ResourceType",
	                    "domain": "ResourceTypeRef"
	                }
	            }
	        },
	        "ResourceType": {
	            "name": "ResourceType",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "methods": {
	                    "name": "methods"
	                },
	                "is": {
	                    "name": "is"
	                },
	                "type": {
	                    "name": "type"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "securedBy": {
	                    "name": "securedBy"
	                },
	                "uriParameters": {
	                    "name": "uriParameters"
	                },
	                "displayName": {
	                    "name": "displayName"
	                },
	                "name": {
	                    "name": "name"
	                },
	                "usage": {
	                    "name": "usage"
	                },
	                "parametrizedProperties": {
	                    "name": "parametrizedProperties",
	                    "range": "TypeInstance",
	                    "domain": "ResourceType"
	                }
	            }
	        },
	        "ResourceBase": {
	            "name": "ResourceBase",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "methods": {
	                    "name": "methods"
	                },
	                "is": {
	                    "name": "is"
	                },
	                "type": {
	                    "name": "type"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "securedBy": {
	                    "name": "securedBy"
	                },
	                "uriParameters": {
	                    "name": "uriParameters"
	                }
	            }
	        },
	        "Resource": {
	            "name": "Resource",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "methods": {
	                    "name": "methods"
	                },
	                "is": {
	                    "name": "is"
	                },
	                "type": {
	                    "name": "type"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "securedBy": {
	                    "name": "securedBy"
	                },
	                "uriParameters": {
	                    "name": "uriParameters"
	                },
	                "relativeUri": {
	                    "name": "relativeUri"
	                },
	                "displayName": {
	                    "name": "displayName"
	                },
	                "resources": {
	                    "name": "resources"
	                }
	            }
	        },
	        "FileTypeDeclaration": {
	            "name": "FileTypeDeclaration",
	            "properties": {
	                "annotations": {
	                    "name": "annotations"
	                },
	                "name": {
	                    "name": "name"
	                },
	                "displayName": {
	                    "name": "displayName"
	                },
	                "facets": {
	                    "name": "facets"
	                },
	                "schema": {
	                    "name": "schema"
	                },
	                "type": {
	                    "name": "type"
	                },
	                "location": {
	                    "name": "location"
	                },
	                "locationKind": {
	                    "name": "locationKind"
	                },
	                "default": {
	                    "name": "default"
	                },
	                "example": {
	                    "name": "example"
	                },
	                "examples": {
	                    "name": "examples"
	                },
	                "repeat": {
	                    "name": "repeat"
	                },
	                "required": {
	                    "name": "required"
	                },
	                "description": {
	                    "name": "description"
	                },
	                "xml": {
	                    "name": "xml"
	                },
	                "allowedTargets": {
	                    "name": "allowedTargets"
	                },
	                "isAnnotation": {
	                    "name": "isAnnotation"
	                },
	                "fileTypes": {
	                    "name": "fileTypes"
	                },
	                "minLength": {
	                    "name": "minLength"
	                },
	                "maxLength": {
	                    "name": "maxLength"
	                }
	            }
	        }
	    }
	};
	module.exports = Universes;
	//# sourceMappingURL=universe.js.map

/***/ },
/* 55 */
/***/ function(module, exports, __webpack_require__) {

	exports.XMLHttpRequest = XMLHttpRequest;

/***/ },
/* 56 */
/***/ function(module, exports, __webpack_require__) {

	// shim for using process in browser

	var process = module.exports = {};
	var queue = [];
	var draining = false;

	function drainQueue() {
	    if (draining) {
	        return;
	    }
	    draining = true;
	    var currentQueue;
	    var len = queue.length;
	    while(len) {
	        currentQueue = queue;
	        queue = [];
	        var i = -1;
	        while (++i < len) {
	            currentQueue[i]();
	        }
	        len = queue.length;
	    }
	    draining = false;
	}
	process.nextTick = function (fun) {
	    queue.push(fun);
	    if (!draining) {
	        setTimeout(drainQueue, 0);
	    }
	};

	process.title = 'browser';
	process.browser = true;
	process.env = {};
	process.argv = [];
	process.version = ''; // empty string to avoid regexp issues
	process.versions = {};

	function noop() {}

	process.on = noop;
	process.addListener = noop;
	process.once = noop;
	process.off = noop;
	process.removeListener = noop;
	process.removeAllListeners = noop;
	process.emit = noop;

	process.binding = function (name) {
	    throw new Error('process.binding is not supported');
	};

	// TODO(shtylman)
	process.cwd = function () { return '/' };
	process.chdir = function (dir) {
	    throw new Error('process.chdir is not supported');
	};
	process.umask = function() { return 0; };


/***/ },
/* 57 */
/***/ function(module, exports, __webpack_require__) {

	// Copyright Joyent, Inc. and other Node contributors.
	//
	// Permission is hereby granted, free of charge, to any person obtaining a
	// copy of this software and associated documentation files (the
	// "Software"), to deal in the Software without restriction, including
	// without limitation the rights to use, copy, modify, merge, publish,
	// distribute, sublicense, and/or sell copies of the Software, and to permit
	// persons to whom the Software is furnished to do so, subject to the
	// following conditions:
	//
	// The above copyright notice and this permission notice shall be included
	// in all copies or substantial portions of the Software.
	//
	// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
	// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
	// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
	// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
	// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
	// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
	// USE OR OTHER DEALINGS IN THE SOFTWARE.

	var punycode = __webpack_require__(100);

	exports.parse = urlParse;
	exports.resolve = urlResolve;
	exports.resolveObject = urlResolveObject;
	exports.format = urlFormat;

	exports.Url = Url;

	function Url() {
	  this.protocol = null;
	  this.slashes = null;
	  this.auth = null;
	  this.host = null;
	  this.port = null;
	  this.hostname = null;
	  this.hash = null;
	  this.search = null;
	  this.query = null;
	  this.pathname = null;
	  this.path = null;
	  this.href = null;
	}

	// Reference: RFC 3986, RFC 1808, RFC 2396

	// define these here so at least they only have to be
	// compiled once on the first module load.
	var protocolPattern = /^([a-z0-9.+-]+:)/i,
	    portPattern = /:[0-9]*$/,

	    // RFC 2396: characters reserved for delimiting URLs.
	    // We actually just auto-escape these.
	    delims = ['<', '>', '"', '`', ' ', '\r', '\n', '\t'],

	    // RFC 2396: characters not allowed for various reasons.
	    unwise = ['{', '}', '|', '\\', '^', '`'].concat(delims),

	    // Allowed by RFCs, but cause of XSS attacks.  Always escape these.
	    autoEscape = ['\''].concat(unwise),
	    // Characters that are never ever allowed in a hostname.
	    // Note that any invalid chars are also handled, but these
	    // are the ones that are *expected* to be seen, so we fast-path
	    // them.
	    nonHostChars = ['%', '/', '?', ';', '#'].concat(autoEscape),
	    hostEndingChars = ['/', '?', '#'],
	    hostnameMaxLen = 255,
	    hostnamePartPattern = /^[a-z0-9A-Z_-]{0,63}$/,
	    hostnamePartStart = /^([a-z0-9A-Z_-]{0,63})(.*)$/,
	    // protocols that can allow "unsafe" and "unwise" chars.
	    unsafeProtocol = {
	      'javascript': true,
	      'javascript:': true
	    },
	    // protocols that never have a hostname.
	    hostlessProtocol = {
	      'javascript': true,
	      'javascript:': true
	    },
	    // protocols that always contain a // bit.
	    slashedProtocol = {
	      'http': true,
	      'https': true,
	      'ftp': true,
	      'gopher': true,
	      'file': true,
	      'http:': true,
	      'https:': true,
	      'ftp:': true,
	      'gopher:': true,
	      'file:': true
	    },
	    querystring = __webpack_require__(88);

	function urlParse(url, parseQueryString, slashesDenoteHost) {
	  if (url && isObject(url) && url instanceof Url) return url;

	  var u = new Url;
	  u.parse(url, parseQueryString, slashesDenoteHost);
	  return u;
	}

	Url.prototype.parse = function(url, parseQueryString, slashesDenoteHost) {
	  if (!isString(url)) {
	    throw new TypeError("Parameter 'url' must be a string, not " + typeof url);
	  }

	  var rest = url;

	  // trim before proceeding.
	  // This is to support parse stuff like "  http://foo.com  \n"
	  rest = rest.trim();

	  var proto = protocolPattern.exec(rest);
	  if (proto) {
	    proto = proto[0];
	    var lowerProto = proto.toLowerCase();
	    this.protocol = lowerProto;
	    rest = rest.substr(proto.length);
	  }

	  // figure out if it's got a host
	  // user@server is *always* interpreted as a hostname, and url
	  // resolution will treat //foo/bar as host=foo,path=bar because that's
	  // how the browser resolves relative URLs.
	  if (slashesDenoteHost || proto || rest.match(/^\/\/[^@\/]+@[^@\/]+/)) {
	    var slashes = rest.substr(0, 2) === '//';
	    if (slashes && !(proto && hostlessProtocol[proto])) {
	      rest = rest.substr(2);
	      this.slashes = true;
	    }
	  }

	  if (!hostlessProtocol[proto] &&
	      (slashes || (proto && !slashedProtocol[proto]))) {

	    // there's a hostname.
	    // the first instance of /, ?, ;, or # ends the host.
	    //
	    // If there is an @ in the hostname, then non-host chars *are* allowed
	    // to the left of the last @ sign, unless some host-ending character
	    // comes *before* the @-sign.
	    // URLs are obnoxious.
	    //
	    // ex:
	    // http://a@b@c/ => user:a@b host:c
	    // http://a@b?@c => user:a host:c path:/?@c

	    // v0.12 TODO(isaacs): This is not quite how Chrome does things.
	    // Review our test case against browsers more comprehensively.

	    // find the first instance of any hostEndingChars
	    var hostEnd = -1;
	    for (var i = 0; i < hostEndingChars.length; i++) {
	      var hec = rest.indexOf(hostEndingChars[i]);
	      if (hec !== -1 && (hostEnd === -1 || hec < hostEnd))
	        hostEnd = hec;
	    }

	    // at this point, either we have an explicit point where the
	    // auth portion cannot go past, or the last @ char is the decider.
	    var auth, atSign;
	    if (hostEnd === -1) {
	      // atSign can be anywhere.
	      atSign = rest.lastIndexOf('@');
	    } else {
	      // atSign must be in auth portion.
	      // http://a@b/c@d => host:b auth:a path:/c@d
	      atSign = rest.lastIndexOf('@', hostEnd);
	    }

	    // Now we have a portion which is definitely the auth.
	    // Pull that off.
	    if (atSign !== -1) {
	      auth = rest.slice(0, atSign);
	      rest = rest.slice(atSign + 1);
	      this.auth = decodeURIComponent(auth);
	    }

	    // the host is the remaining to the left of the first non-host char
	    hostEnd = -1;
	    for (var i = 0; i < nonHostChars.length; i++) {
	      var hec = rest.indexOf(nonHostChars[i]);
	      if (hec !== -1 && (hostEnd === -1 || hec < hostEnd))
	        hostEnd = hec;
	    }
	    // if we still have not hit it, then the entire thing is a host.
	    if (hostEnd === -1)
	      hostEnd = rest.length;

	    this.host = rest.slice(0, hostEnd);
	    rest = rest.slice(hostEnd);

	    // pull out port.
	    this.parseHost();

	    // we've indicated that there is a hostname,
	    // so even if it's empty, it has to be present.
	    this.hostname = this.hostname || '';

	    // if hostname begins with [ and ends with ]
	    // assume that it's an IPv6 address.
	    var ipv6Hostname = this.hostname[0] === '[' &&
	        this.hostname[this.hostname.length - 1] === ']';

	    // validate a little.
	    if (!ipv6Hostname) {
	      var hostparts = this.hostname.split(/\./);
	      for (var i = 0, l = hostparts.length; i < l; i++) {
	        var part = hostparts[i];
	        if (!part) continue;
	        if (!part.match(hostnamePartPattern)) {
	          var newpart = '';
	          for (var j = 0, k = part.length; j < k; j++) {
	            if (part.charCodeAt(j) > 127) {
	              // we replace non-ASCII char with a temporary placeholder
	              // we need this to make sure size of hostname is not
	              // broken by replacing non-ASCII by nothing
	              newpart += 'x';
	            } else {
	              newpart += part[j];
	            }
	          }
	          // we test again with ASCII char only
	          if (!newpart.match(hostnamePartPattern)) {
	            var validParts = hostparts.slice(0, i);
	            var notHost = hostparts.slice(i + 1);
	            var bit = part.match(hostnamePartStart);
	            if (bit) {
	              validParts.push(bit[1]);
	              notHost.unshift(bit[2]);
	            }
	            if (notHost.length) {
	              rest = '/' + notHost.join('.') + rest;
	            }
	            this.hostname = validParts.join('.');
	            break;
	          }
	        }
	      }
	    }

	    if (this.hostname.length > hostnameMaxLen) {
	      this.hostname = '';
	    } else {
	      // hostnames are always lower case.
	      this.hostname = this.hostname.toLowerCase();
	    }

	    if (!ipv6Hostname) {
	      // IDNA Support: Returns a puny coded representation of "domain".
	      // It only converts the part of the domain name that
	      // has non ASCII characters. I.e. it dosent matter if
	      // you call it with a domain that already is in ASCII.
	      var domainArray = this.hostname.split('.');
	      var newOut = [];
	      for (var i = 0; i < domainArray.length; ++i) {
	        var s = domainArray[i];
	        newOut.push(s.match(/[^A-Za-z0-9_-]/) ?
	            'xn--' + punycode.encode(s) : s);
	      }
	      this.hostname = newOut.join('.');
	    }

	    var p = this.port ? ':' + this.port : '';
	    var h = this.hostname || '';
	    this.host = h + p;
	    this.href += this.host;

	    // strip [ and ] from the hostname
	    // the host field still retains them, though
	    if (ipv6Hostname) {
	      this.hostname = this.hostname.substr(1, this.hostname.length - 2);
	      if (rest[0] !== '/') {
	        rest = '/' + rest;
	      }
	    }
	  }

	  // now rest is set to the post-host stuff.
	  // chop off any delim chars.
	  if (!unsafeProtocol[lowerProto]) {

	    // First, make 100% sure that any "autoEscape" chars get
	    // escaped, even if encodeURIComponent doesn't think they
	    // need to be.
	    for (var i = 0, l = autoEscape.length; i < l; i++) {
	      var ae = autoEscape[i];
	      var esc = encodeURIComponent(ae);
	      if (esc === ae) {
	        esc = escape(ae);
	      }
	      rest = rest.split(ae).join(esc);
	    }
	  }


	  // chop off from the tail first.
	  var hash = rest.indexOf('#');
	  if (hash !== -1) {
	    // got a fragment string.
	    this.hash = rest.substr(hash);
	    rest = rest.slice(0, hash);
	  }
	  var qm = rest.indexOf('?');
	  if (qm !== -1) {
	    this.search = rest.substr(qm);
	    this.query = rest.substr(qm + 1);
	    if (parseQueryString) {
	      this.query = querystring.parse(this.query);
	    }
	    rest = rest.slice(0, qm);
	  } else if (parseQueryString) {
	    // no query string, but parseQueryString still requested
	    this.search = '';
	    this.query = {};
	  }
	  if (rest) this.pathname = rest;
	  if (slashedProtocol[lowerProto] &&
	      this.hostname && !this.pathname) {
	    this.pathname = '/';
	  }

	  //to support http.request
	  if (this.pathname || this.search) {
	    var p = this.pathname || '';
	    var s = this.search || '';
	    this.path = p + s;
	  }

	  // finally, reconstruct the href based on what has been validated.
	  this.href = this.format();
	  return this;
	};

	// format a parsed object into a url string
	function urlFormat(obj) {
	  // ensure it's an object, and not a string url.
	  // If it's an obj, this is a no-op.
	  // this way, you can call url_format() on strings
	  // to clean up potentially wonky urls.
	  if (isString(obj)) obj = urlParse(obj);
	  if (!(obj instanceof Url)) return Url.prototype.format.call(obj);
	  return obj.format();
	}

	Url.prototype.format = function() {
	  var auth = this.auth || '';
	  if (auth) {
	    auth = encodeURIComponent(auth);
	    auth = auth.replace(/%3A/i, ':');
	    auth += '@';
	  }

	  var protocol = this.protocol || '',
	      pathname = this.pathname || '',
	      hash = this.hash || '',
	      host = false,
	      query = '';

	  if (this.host) {
	    host = auth + this.host;
	  } else if (this.hostname) {
	    host = auth + (this.hostname.indexOf(':') === -1 ?
	        this.hostname :
	        '[' + this.hostname + ']');
	    if (this.port) {
	      host += ':' + this.port;
	    }
	  }

	  if (this.query &&
	      isObject(this.query) &&
	      Object.keys(this.query).length) {
	    query = querystring.stringify(this.query);
	  }

	  var search = this.search || (query && ('?' + query)) || '';

	  if (protocol && protocol.substr(-1) !== ':') protocol += ':';

	  // only the slashedProtocols get the //.  Not mailto:, xmpp:, etc.
	  // unless they had them to begin with.
	  if (this.slashes ||
	      (!protocol || slashedProtocol[protocol]) && host !== false) {
	    host = '//' + (host || '');
	    if (pathname && pathname.charAt(0) !== '/') pathname = '/' + pathname;
	  } else if (!host) {
	    host = '';
	  }

	  if (hash && hash.charAt(0) !== '#') hash = '#' + hash;
	  if (search && search.charAt(0) !== '?') search = '?' + search;

	  pathname = pathname.replace(/[?#]/g, function(match) {
	    return encodeURIComponent(match);
	  });
	  search = search.replace('#', '%23');

	  return protocol + host + pathname + search + hash;
	};

	function urlResolve(source, relative) {
	  return urlParse(source, false, true).resolve(relative);
	}

	Url.prototype.resolve = function(relative) {
	  return this.resolveObject(urlParse(relative, false, true)).format();
	};

	function urlResolveObject(source, relative) {
	  if (!source) return relative;
	  return urlParse(source, false, true).resolveObject(relative);
	}

	Url.prototype.resolveObject = function(relative) {
	  if (isString(relative)) {
	    var rel = new Url();
	    rel.parse(relative, false, true);
	    relative = rel;
	  }

	  var result = new Url();
	  Object.keys(this).forEach(function(k) {
	    result[k] = this[k];
	  }, this);

	  // hash is always overridden, no matter what.
	  // even href="" will remove it.
	  result.hash = relative.hash;

	  // if the relative url is empty, then there's nothing left to do here.
	  if (relative.href === '') {
	    result.href = result.format();
	    return result;
	  }

	  // hrefs like //foo/bar always cut to the protocol.
	  if (relative.slashes && !relative.protocol) {
	    // take everything except the protocol from relative
	    Object.keys(relative).forEach(function(k) {
	      if (k !== 'protocol')
	        result[k] = relative[k];
	    });

	    //urlParse appends trailing / to urls like http://www.example.com
	    if (slashedProtocol[result.protocol] &&
	        result.hostname && !result.pathname) {
	      result.path = result.pathname = '/';
	    }

	    result.href = result.format();
	    return result;
	  }

	  if (relative.protocol && relative.protocol !== result.protocol) {
	    // if it's a known url protocol, then changing
	    // the protocol does weird things
	    // first, if it's not file:, then we MUST have a host,
	    // and if there was a path
	    // to begin with, then we MUST have a path.
	    // if it is file:, then the host is dropped,
	    // because that's known to be hostless.
	    // anything else is assumed to be absolute.
	    if (!slashedProtocol[relative.protocol]) {
	      Object.keys(relative).forEach(function(k) {
	        result[k] = relative[k];
	      });
	      result.href = result.format();
	      return result;
	    }

	    result.protocol = relative.protocol;
	    if (!relative.host && !hostlessProtocol[relative.protocol]) {
	      var relPath = (relative.pathname || '').split('/');
	      while (relPath.length && !(relative.host = relPath.shift()));
	      if (!relative.host) relative.host = '';
	      if (!relative.hostname) relative.hostname = '';
	      if (relPath[0] !== '') relPath.unshift('');
	      if (relPath.length < 2) relPath.unshift('');
	      result.pathname = relPath.join('/');
	    } else {
	      result.pathname = relative.pathname;
	    }
	    result.search = relative.search;
	    result.query = relative.query;
	    result.host = relative.host || '';
	    result.auth = relative.auth;
	    result.hostname = relative.hostname || relative.host;
	    result.port = relative.port;
	    // to support http.request
	    if (result.pathname || result.search) {
	      var p = result.pathname || '';
	      var s = result.search || '';
	      result.path = p + s;
	    }
	    result.slashes = result.slashes || relative.slashes;
	    result.href = result.format();
	    return result;
	  }

	  var isSourceAbs = (result.pathname && result.pathname.charAt(0) === '/'),
	      isRelAbs = (
	          relative.host ||
	          relative.pathname && relative.pathname.charAt(0) === '/'
	      ),
	      mustEndAbs = (isRelAbs || isSourceAbs ||
	                    (result.host && relative.pathname)),
	      removeAllDots = mustEndAbs,
	      srcPath = result.pathname && result.pathname.split('/') || [],
	      relPath = relative.pathname && relative.pathname.split('/') || [],
	      psychotic = result.protocol && !slashedProtocol[result.protocol];

	  // if the url is a non-slashed url, then relative
	  // links like ../.. should be able
	  // to crawl up to the hostname, as well.  This is strange.
	  // result.protocol has already been set by now.
	  // Later on, put the first path part into the host field.
	  if (psychotic) {
	    result.hostname = '';
	    result.port = null;
	    if (result.host) {
	      if (srcPath[0] === '') srcPath[0] = result.host;
	      else srcPath.unshift(result.host);
	    }
	    result.host = '';
	    if (relative.protocol) {
	      relative.hostname = null;
	      relative.port = null;
	      if (relative.host) {
	        if (relPath[0] === '') relPath[0] = relative.host;
	        else relPath.unshift(relative.host);
	      }
	      relative.host = null;
	    }
	    mustEndAbs = mustEndAbs && (relPath[0] === '' || srcPath[0] === '');
	  }

	  if (isRelAbs) {
	    // it's absolute.
	    result.host = (relative.host || relative.host === '') ?
	                  relative.host : result.host;
	    result.hostname = (relative.hostname || relative.hostname === '') ?
	                      relative.hostname : result.hostname;
	    result.search = relative.search;
	    result.query = relative.query;
	    srcPath = relPath;
	    // fall through to the dot-handling below.
	  } else if (relPath.length) {
	    // it's relative
	    // throw away the existing file, and take the new path instead.
	    if (!srcPath) srcPath = [];
	    srcPath.pop();
	    srcPath = srcPath.concat(relPath);
	    result.search = relative.search;
	    result.query = relative.query;
	  } else if (!isNullOrUndefined(relative.search)) {
	    // just pull out the search.
	    // like href='?foo'.
	    // Put this after the other two cases because it simplifies the booleans
	    if (psychotic) {
	      result.hostname = result.host = srcPath.shift();
	      //occationaly the auth can get stuck only in host
	      //this especialy happens in cases like
	      //url.resolveObject('mailto:local1@domain1', 'local2@domain2')
	      var authInHost = result.host && result.host.indexOf('@') > 0 ?
	                       result.host.split('@') : false;
	      if (authInHost) {
	        result.auth = authInHost.shift();
	        result.host = result.hostname = authInHost.shift();
	      }
	    }
	    result.search = relative.search;
	    result.query = relative.query;
	    //to support http.request
	    if (!isNull(result.pathname) || !isNull(result.search)) {
	      result.path = (result.pathname ? result.pathname : '') +
	                    (result.search ? result.search : '');
	    }
	    result.href = result.format();
	    return result;
	  }

	  if (!srcPath.length) {
	    // no path at all.  easy.
	    // we've already handled the other stuff above.
	    result.pathname = null;
	    //to support http.request
	    if (result.search) {
	      result.path = '/' + result.search;
	    } else {
	      result.path = null;
	    }
	    result.href = result.format();
	    return result;
	  }

	  // if a url ENDs in . or .., then it must get a trailing slash.
	  // however, if it ends in anything else non-slashy,
	  // then it must NOT get a trailing slash.
	  var last = srcPath.slice(-1)[0];
	  var hasTrailingSlash = (
	      (result.host || relative.host) && (last === '.' || last === '..') ||
	      last === '');

	  // strip single dots, resolve double dots to parent dir
	  // if the path tries to go above the root, `up` ends up > 0
	  var up = 0;
	  for (var i = srcPath.length; i >= 0; i--) {
	    last = srcPath[i];
	    if (last == '.') {
	      srcPath.splice(i, 1);
	    } else if (last === '..') {
	      srcPath.splice(i, 1);
	      up++;
	    } else if (up) {
	      srcPath.splice(i, 1);
	      up--;
	    }
	  }

	  // if the path is allowed to go above the root, restore leading ..s
	  if (!mustEndAbs && !removeAllDots) {
	    for (; up--; up) {
	      srcPath.unshift('..');
	    }
	  }

	  if (mustEndAbs && srcPath[0] !== '' &&
	      (!srcPath[0] || srcPath[0].charAt(0) !== '/')) {
	    srcPath.unshift('');
	  }

	  if (hasTrailingSlash && (srcPath.join('/').substr(-1) !== '/')) {
	    srcPath.push('');
	  }

	  var isAbsolute = srcPath[0] === '' ||
	      (srcPath[0] && srcPath[0].charAt(0) === '/');

	  // put the host back
	  if (psychotic) {
	    result.hostname = result.host = isAbsolute ? '' :
	                                    srcPath.length ? srcPath.shift() : '';
	    //occationaly the auth can get stuck only in host
	    //this especialy happens in cases like
	    //url.resolveObject('mailto:local1@domain1', 'local2@domain2')
	    var authInHost = result.host && result.host.indexOf('@') > 0 ?
	                     result.host.split('@') : false;
	    if (authInHost) {
	      result.auth = authInHost.shift();
	      result.host = result.hostname = authInHost.shift();
	    }
	  }

	  mustEndAbs = mustEndAbs || (result.host && srcPath.length);

	  if (mustEndAbs && !isAbsolute) {
	    srcPath.unshift('');
	  }

	  if (!srcPath.length) {
	    result.pathname = null;
	    result.path = null;
	  } else {
	    result.pathname = srcPath.join('/');
	  }

	  //to support request.http
	  if (!isNull(result.pathname) || !isNull(result.search)) {
	    result.path = (result.pathname ? result.pathname : '') +
	                  (result.search ? result.search : '');
	  }
	  result.auth = relative.auth || result.auth;
	  result.slashes = result.slashes || relative.slashes;
	  result.href = result.format();
	  return result;
	};

	Url.prototype.parseHost = function() {
	  var host = this.host;
	  var port = portPattern.exec(host);
	  if (port) {
	    port = port[0];
	    if (port !== ':') {
	      this.port = port.substr(1);
	    }
	    host = host.substr(0, host.length - port.length);
	  }
	  if (host) this.hostname = host;
	};

	function isString(arg) {
	  return typeof arg === "string";
	}

	function isObject(arg) {
	  return typeof arg === 'object' && arg !== null;
	}

	function isNull(arg) {
	  return arg === null;
	}
	function isNullOrUndefined(arg) {
	  return  arg == null;
	}


/***/ },
/* 58 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	module.exports = Response;

	/**
	 * A response from a web request
	 *
	 * @param {Number} statusCode
	 * @param {Object} headers
	 * @param {Buffer} body
	 * @param {String} url
	 */
	function Response(statusCode, headers, body, url) {
	  if (typeof statusCode !== 'number') {
	    throw new TypeError('statusCode must be a number but was ' + (typeof statusCode));
	  }
	  if (headers === null) {
	    throw new TypeError('headers cannot be null');
	  }
	  if (typeof headers !== 'object') {
	    throw new TypeError('headers must be an object but was ' + (typeof headers));
	  }
	  this.statusCode = statusCode;
	  this.headers = {};
	  for (var key in headers) {
	    this.headers[key.toLowerCase()] = headers[key];
	  }
	  this.body = body;
	  this.url = url;
	}

	Response.prototype.getBody = function (encoding) {
	  if (this.statusCode >= 300) {
	    var err = new Error('Server responded with status code '
	                    + this.statusCode + ':\n' + this.body.toString());
	    err.statusCode = this.statusCode;
	    err.headers = this.headers;
	    err.body = this.body;
	    err.url = this.url;
	    throw err;
	  }
	  return encoding ? this.body.toString(encoding) : this.body;
	};


/***/ },
/* 59 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(Buffer) {var Writable = __webpack_require__(101).Writable
	var inherits = __webpack_require__(102)

	if (typeof Uint8Array === 'undefined') {
	  var U8 = __webpack_require__(89).Uint8Array
	} else {
	  var U8 = Uint8Array
	}

	function ConcatStream(opts, cb) {
	  if (!(this instanceof ConcatStream)) return new ConcatStream(opts, cb)

	  if (typeof opts === 'function') {
	    cb = opts
	    opts = {}
	  }
	  if (!opts) opts = {}

	  var encoding = opts.encoding
	  var shouldInferEncoding = false

	  if (!encoding) {
	    shouldInferEncoding = true
	  } else {
	    encoding =  String(encoding).toLowerCase()
	    if (encoding === 'u8' || encoding === 'uint8') {
	      encoding = 'uint8array'
	    }
	  }

	  Writable.call(this, { objectMode: true })

	  this.encoding = encoding
	  this.shouldInferEncoding = shouldInferEncoding

	  if (cb) this.on('finish', function () { cb(this.getBody()) })
	  this.body = []
	}

	module.exports = ConcatStream
	inherits(ConcatStream, Writable)

	ConcatStream.prototype._write = function(chunk, enc, next) {
	  this.body.push(chunk)
	  next()
	}

	ConcatStream.prototype.inferEncoding = function (buff) {
	  var firstBuffer = buff === undefined ? this.body[0] : buff;
	  if (Buffer.isBuffer(firstBuffer)) return 'buffer'
	  if (typeof Uint8Array !== 'undefined' && firstBuffer instanceof Uint8Array) return 'uint8array'
	  if (Array.isArray(firstBuffer)) return 'array'
	  if (typeof firstBuffer === 'string') return 'string'
	  if (Object.prototype.toString.call(firstBuffer) === "[object Object]") return 'object'
	  return 'buffer'
	}

	ConcatStream.prototype.getBody = function () {
	  if (!this.encoding && this.body.length === 0) return []
	  if (this.shouldInferEncoding) this.encoding = this.inferEncoding()
	  if (this.encoding === 'array') return arrayConcat(this.body)
	  if (this.encoding === 'string') return stringConcat(this.body)
	  if (this.encoding === 'buffer') return bufferConcat(this.body)
	  if (this.encoding === 'uint8array') return u8Concat(this.body)
	  return this.body
	}

	var isArray = Array.isArray || function (arr) {
	  return Object.prototype.toString.call(arr) == '[object Array]'
	}

	function isArrayish (arr) {
	  return /Array\]$/.test(Object.prototype.toString.call(arr))
	}

	function stringConcat (parts) {
	  var strings = []
	  var needsToString = false
	  for (var i = 0; i < parts.length; i++) {
	    var p = parts[i]
	    if (typeof p === 'string') {
	      strings.push(p)
	    } else if (Buffer.isBuffer(p)) {
	      strings.push(p)
	    } else {
	      strings.push(Buffer(p))
	    }
	  }
	  if (Buffer.isBuffer(parts[0])) {
	    strings = Buffer.concat(strings)
	    strings = strings.toString('utf8')
	  } else {
	    strings = strings.join('')
	  }
	  return strings
	}

	function bufferConcat (parts) {
	  var bufs = []
	  for (var i = 0; i < parts.length; i++) {
	    var p = parts[i]
	    if (Buffer.isBuffer(p)) {
	      bufs.push(p)
	    } else if (typeof p === 'string' || isArrayish(p)
	    || (p && typeof p.subarray === 'function')) {
	      bufs.push(Buffer(p))
	    } else bufs.push(Buffer(String(p)))
	  }
	  return Buffer.concat(bufs)
	}

	function arrayConcat (parts) {
	  var res = []
	  for (var i = 0; i < parts.length; i++) {
	    res.push.apply(res, parts[i])
	  }
	  return res
	}

	function u8Concat (parts) {
	  var len = 0
	  for (var i = 0; i < parts.length; i++) {
	    if (typeof parts[i] === 'string') {
	      parts[i] = Buffer(parts[i])
	    }
	    len += parts[i].length
	  }
	  var u8 = new U8(len)
	  for (var i = 0, offset = 0; i < parts.length; i++) {
	    var part = parts[i]
	    for (var j = 0; j < part.length; j++) {
	      u8[offset++] = part[j]
	    }
	  }
	  return u8
	}
	
	/* WEBPACK VAR INJECTION */}.call(exports, __webpack_require__(87).Buffer))

/***/ },
/* 60 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(Buffer) {function fromBase64(base64string) {
	  return (
	    base64string
	      .replace(/=/g, '')
	      .replace(/\+/g, '-')
	      .replace(/\//g, '_')
	  );
	}

	function toBase64(base64UrlString) {
	  if (Buffer.isBuffer(base64UrlString))
	    base64UrlString = base64UrlString.toString();

	  var b64str = padString(base64UrlString)
	    .replace(/\-/g, '+')
	    .replace(/_/g, '/');
	  return b64str;
	}

	function padString(string) {
	  var segmentLength = 4;
	  var stringLength = string.length;
	  var diff = string.length % segmentLength;
	  if (!diff)
	    return string;
	  var position = stringLength;
	  var padLength = segmentLength - diff;
	  var paddedStringLength = stringLength + padLength;
	  var buffer = Buffer(paddedStringLength);
	  buffer.write(string);
	  while (padLength--)
	    buffer.write('=', position++);
	  return buffer.toString();
	}

	function decodeBase64Url(base64UrlString, encoding) {
	  return Buffer(toBase64(base64UrlString), 'base64').toString(encoding);
	}

	function base64url(stringOrBuffer, encoding) {
	  return fromBase64(Buffer(stringOrBuffer, encoding).toString('base64'));
	}

	function toBuffer(base64string) {
	  return Buffer(toBase64(base64string), 'base64');
	}

	base64url.toBase64 = toBase64;
	base64url.fromBase64 = fromBase64;
	base64url.decode = decodeBase64Url;
	base64url.encode = base64url;
	base64url.toBuffer = toBuffer;

	module.exports = base64url;
	
	/* WEBPACK VAR INJECTION */}.call(exports, __webpack_require__(87).Buffer))

/***/ },
/* 61 */
/***/ function(module, exports, __webpack_require__) {

	var __WEBPACK_AMD_DEFINE_ARRAY__, __WEBPACK_AMD_DEFINE_RESULT__;//     Underscore.js 1.8.3
	//     http://underscorejs.org
	//     (c) 2009-2015 Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
	//     Underscore may be freely distributed under the MIT license.

	(function() {

	  // Baseline setup
	  // --------------

	  // Establish the root object, `window` in the browser, or `exports` on the server.
	  var root = this;

	  // Save the previous value of the `_` variable.
	  var previousUnderscore = root._;

	  // Save bytes in the minified (but not gzipped) version:
	  var ArrayProto = Array.prototype, ObjProto = Object.prototype, FuncProto = Function.prototype;

	  // Create quick reference variables for speed access to core prototypes.
	  var
	    push             = ArrayProto.push,
	    slice            = ArrayProto.slice,
	    toString         = ObjProto.toString,
	    hasOwnProperty   = ObjProto.hasOwnProperty;

	  // All **ECMAScript 5** native function implementations that we hope to use
	  // are declared here.
	  var
	    nativeIsArray      = Array.isArray,
	    nativeKeys         = Object.keys,
	    nativeBind         = FuncProto.bind,
	    nativeCreate       = Object.create;

	  // Naked function reference for surrogate-prototype-swapping.
	  var Ctor = function(){};

	  // Create a safe reference to the Underscore object for use below.
	  var _ = function(obj) {
	    if (obj instanceof _) return obj;
	    if (!(this instanceof _)) return new _(obj);
	    this._wrapped = obj;
	  };

	  // Export the Underscore object for **Node.js**, with
	  // backwards-compatibility for the old `require()` API. If we're in
	  // the browser, add `_` as a global object.
	  if (true) {
	    if (typeof module !== 'undefined' && module.exports) {
	      exports = module.exports = _;
	    }
	    exports._ = _;
	  } else {
	    root._ = _;
	  }

	  // Current version.
	  _.VERSION = '1.8.3';

	  // Internal function that returns an efficient (for current engines) version
	  // of the passed-in callback, to be repeatedly applied in other Underscore
	  // functions.
	  var optimizeCb = function(func, context, argCount) {
	    if (context === void 0) return func;
	    switch (argCount == null ? 3 : argCount) {
	      case 1: return function(value) {
	        return func.call(context, value);
	      };
	      case 2: return function(value, other) {
	        return func.call(context, value, other);
	      };
	      case 3: return function(value, index, collection) {
	        return func.call(context, value, index, collection);
	      };
	      case 4: return function(accumulator, value, index, collection) {
	        return func.call(context, accumulator, value, index, collection);
	      };
	    }
	    return function() {
	      return func.apply(context, arguments);
	    };
	  };

	  // A mostly-internal function to generate callbacks that can be applied
	  // to each element in a collection, returning the desired result — either
	  // identity, an arbitrary callback, a property matcher, or a property accessor.
	  var cb = function(value, context, argCount) {
	    if (value == null) return _.identity;
	    if (_.isFunction(value)) return optimizeCb(value, context, argCount);
	    if (_.isObject(value)) return _.matcher(value);
	    return _.property(value);
	  };
	  _.iteratee = function(value, context) {
	    return cb(value, context, Infinity);
	  };

	  // An internal function for creating assigner functions.
	  var createAssigner = function(keysFunc, undefinedOnly) {
	    return function(obj) {
	      var length = arguments.length;
	      if (length < 2 || obj == null) return obj;
	      for (var index = 1; index < length; index++) {
	        var source = arguments[index],
	            keys = keysFunc(source),
	            l = keys.length;
	        for (var i = 0; i < l; i++) {
	          var key = keys[i];
	          if (!undefinedOnly || obj[key] === void 0) obj[key] = source[key];
	        }
	      }
	      return obj;
	    };
	  };

	  // An internal function for creating a new object that inherits from another.
	  var baseCreate = function(prototype) {
	    if (!_.isObject(prototype)) return {};
	    if (nativeCreate) return nativeCreate(prototype);
	    Ctor.prototype = prototype;
	    var result = new Ctor;
	    Ctor.prototype = null;
	    return result;
	  };

	  var property = function(key) {
	    return function(obj) {
	      return obj == null ? void 0 : obj[key];
	    };
	  };

	  // Helper for collection methods to determine whether a collection
	  // should be iterated as an array or as an object
	  // Related: http://people.mozilla.org/~jorendorff/es6-draft.html#sec-tolength
	  // Avoids a very nasty iOS 8 JIT bug on ARM-64. #2094
	  var MAX_ARRAY_INDEX = Math.pow(2, 53) - 1;
	  var getLength = property('length');
	  var isArrayLike = function(collection) {
	    var length = getLength(collection);
	    return typeof length == 'number' && length >= 0 && length <= MAX_ARRAY_INDEX;
	  };

	  // Collection Functions
	  // --------------------

	  // The cornerstone, an `each` implementation, aka `forEach`.
	  // Handles raw objects in addition to array-likes. Treats all
	  // sparse array-likes as if they were dense.
	  _.each = _.forEach = function(obj, iteratee, context) {
	    iteratee = optimizeCb(iteratee, context);
	    var i, length;
	    if (isArrayLike(obj)) {
	      for (i = 0, length = obj.length; i < length; i++) {
	        iteratee(obj[i], i, obj);
	      }
	    } else {
	      var keys = _.keys(obj);
	      for (i = 0, length = keys.length; i < length; i++) {
	        iteratee(obj[keys[i]], keys[i], obj);
	      }
	    }
	    return obj;
	  };

	  // Return the results of applying the iteratee to each element.
	  _.map = _.collect = function(obj, iteratee, context) {
	    iteratee = cb(iteratee, context);
	    var keys = !isArrayLike(obj) && _.keys(obj),
	        length = (keys || obj).length,
	        results = Array(length);
	    for (var index = 0; index < length; index++) {
	      var currentKey = keys ? keys[index] : index;
	      results[index] = iteratee(obj[currentKey], currentKey, obj);
	    }
	    return results;
	  };

	  // Create a reducing function iterating left or right.
	  function createReduce(dir) {
	    // Optimized iterator function as using arguments.length
	    // in the main function will deoptimize the, see #1991.
	    function iterator(obj, iteratee, memo, keys, index, length) {
	      for (; index >= 0 && index < length; index += dir) {
	        var currentKey = keys ? keys[index] : index;
	        memo = iteratee(memo, obj[currentKey], currentKey, obj);
	      }
	      return memo;
	    }

	    return function(obj, iteratee, memo, context) {
	      iteratee = optimizeCb(iteratee, context, 4);
	      var keys = !isArrayLike(obj) && _.keys(obj),
	          length = (keys || obj).length,
	          index = dir > 0 ? 0 : length - 1;
	      // Determine the initial value if none is provided.
	      if (arguments.length < 3) {
	        memo = obj[keys ? keys[index] : index];
	        index += dir;
	      }
	      return iterator(obj, iteratee, memo, keys, index, length);
	    };
	  }

	  // **Reduce** builds up a single result from a list of values, aka `inject`,
	  // or `foldl`.
	  _.reduce = _.foldl = _.inject = createReduce(1);

	  // The right-associative version of reduce, also known as `foldr`.
	  _.reduceRight = _.foldr = createReduce(-1);

	  // Return the first value which passes a truth test. Aliased as `detect`.
	  _.find = _.detect = function(obj, predicate, context) {
	    var key;
	    if (isArrayLike(obj)) {
	      key = _.findIndex(obj, predicate, context);
	    } else {
	      key = _.findKey(obj, predicate, context);
	    }
	    if (key !== void 0 && key !== -1) return obj[key];
	  };

	  // Return all the elements that pass a truth test.
	  // Aliased as `select`.
	  _.filter = _.select = function(obj, predicate, context) {
	    var results = [];
	    predicate = cb(predicate, context);
	    _.each(obj, function(value, index, list) {
	      if (predicate(value, index, list)) results.push(value);
	    });
	    return results;
	  };

	  // Return all the elements for which a truth test fails.
	  _.reject = function(obj, predicate, context) {
	    return _.filter(obj, _.negate(cb(predicate)), context);
	  };

	  // Determine whether all of the elements match a truth test.
	  // Aliased as `all`.
	  _.every = _.all = function(obj, predicate, context) {
	    predicate = cb(predicate, context);
	    var keys = !isArrayLike(obj) && _.keys(obj),
	        length = (keys || obj).length;
	    for (var index = 0; index < length; index++) {
	      var currentKey = keys ? keys[index] : index;
	      if (!predicate(obj[currentKey], currentKey, obj)) return false;
	    }
	    return true;
	  };

	  // Determine if at least one element in the object matches a truth test.
	  // Aliased as `any`.
	  _.some = _.any = function(obj, predicate, context) {
	    predicate = cb(predicate, context);
	    var keys = !isArrayLike(obj) && _.keys(obj),
	        length = (keys || obj).length;
	    for (var index = 0; index < length; index++) {
	      var currentKey = keys ? keys[index] : index;
	      if (predicate(obj[currentKey], currentKey, obj)) return true;
	    }
	    return false;
	  };

	  // Determine if the array or object contains a given item (using `===`).
	  // Aliased as `includes` and `include`.
	  _.contains = _.includes = _.include = function(obj, item, fromIndex, guard) {
	    if (!isArrayLike(obj)) obj = _.values(obj);
	    if (typeof fromIndex != 'number' || guard) fromIndex = 0;
	    return _.indexOf(obj, item, fromIndex) >= 0;
	  };

	  // Invoke a method (with arguments) on every item in a collection.
	  _.invoke = function(obj, method) {
	    var args = slice.call(arguments, 2);
	    var isFunc = _.isFunction(method);
	    return _.map(obj, function(value) {
	      var func = isFunc ? method : value[method];
	      return func == null ? func : func.apply(value, args);
	    });
	  };

	  // Convenience version of a common use case of `map`: fetching a property.
	  _.pluck = function(obj, key) {
	    return _.map(obj, _.property(key));
	  };

	  // Convenience version of a common use case of `filter`: selecting only objects
	  // containing specific `key:value` pairs.
	  _.where = function(obj, attrs) {
	    return _.filter(obj, _.matcher(attrs));
	  };

	  // Convenience version of a common use case of `find`: getting the first object
	  // containing specific `key:value` pairs.
	  _.findWhere = function(obj, attrs) {
	    return _.find(obj, _.matcher(attrs));
	  };

	  // Return the maximum element (or element-based computation).
	  _.max = function(obj, iteratee, context) {
	    var result = -Infinity, lastComputed = -Infinity,
	        value, computed;
	    if (iteratee == null && obj != null) {
	      obj = isArrayLike(obj) ? obj : _.values(obj);
	      for (var i = 0, length = obj.length; i < length; i++) {
	        value = obj[i];
	        if (value > result) {
	          result = value;
	        }
	      }
	    } else {
	      iteratee = cb(iteratee, context);
	      _.each(obj, function(value, index, list) {
	        computed = iteratee(value, index, list);
	        if (computed > lastComputed || computed === -Infinity && result === -Infinity) {
	          result = value;
	          lastComputed = computed;
	        }
	      });
	    }
	    return result;
	  };

	  // Return the minimum element (or element-based computation).
	  _.min = function(obj, iteratee, context) {
	    var result = Infinity, lastComputed = Infinity,
	        value, computed;
	    if (iteratee == null && obj != null) {
	      obj = isArrayLike(obj) ? obj : _.values(obj);
	      for (var i = 0, length = obj.length; i < length; i++) {
	        value = obj[i];
	        if (value < result) {
	          result = value;
	        }
	      }
	    } else {
	      iteratee = cb(iteratee, context);
	      _.each(obj, function(value, index, list) {
	        computed = iteratee(value, index, list);
	        if (computed < lastComputed || computed === Infinity && result === Infinity) {
	          result = value;
	          lastComputed = computed;
	        }
	      });
	    }
	    return result;
	  };

	  // Shuffle a collection, using the modern version of the
	  // [Fisher-Yates shuffle](http://en.wikipedia.org/wiki/Fisher–Yates_shuffle).
	  _.shuffle = function(obj) {
	    var set = isArrayLike(obj) ? obj : _.values(obj);
	    var length = set.length;
	    var shuffled = Array(length);
	    for (var index = 0, rand; index < length; index++) {
	      rand = _.random(0, index);
	      if (rand !== index) shuffled[index] = shuffled[rand];
	      shuffled[rand] = set[index];
	    }
	    return shuffled;
	  };

	  // Sample **n** random values from a collection.
	  // If **n** is not specified, returns a single random element.
	  // The internal `guard` argument allows it to work with `map`.
	  _.sample = function(obj, n, guard) {
	    if (n == null || guard) {
	      if (!isArrayLike(obj)) obj = _.values(obj);
	      return obj[_.random(obj.length - 1)];
	    }
	    return _.shuffle(obj).slice(0, Math.max(0, n));
	  };

	  // Sort the object's values by a criterion produced by an iteratee.
	  _.sortBy = function(obj, iteratee, context) {
	    iteratee = cb(iteratee, context);
	    return _.pluck(_.map(obj, function(value, index, list) {
	      return {
	        value: value,
	        index: index,
	        criteria: iteratee(value, index, list)
	      };
	    }).sort(function(left, right) {
	      var a = left.criteria;
	      var b = right.criteria;
	      if (a !== b) {
	        if (a > b || a === void 0) return 1;
	        if (a < b || b === void 0) return -1;
	      }
	      return left.index - right.index;
	    }), 'value');
	  };

	  // An internal function used for aggregate "group by" operations.
	  var group = function(behavior) {
	    return function(obj, iteratee, context) {
	      var result = {};
	      iteratee = cb(iteratee, context);
	      _.each(obj, function(value, index) {
	        var key = iteratee(value, index, obj);
	        behavior(result, value, key);
	      });
	      return result;
	    };
	  };

	  // Groups the object's values by a criterion. Pass either a string attribute
	  // to group by, or a function that returns the criterion.
	  _.groupBy = group(function(result, value, key) {
	    if (_.has(result, key)) result[key].push(value); else result[key] = [value];
	  });

	  // Indexes the object's values by a criterion, similar to `groupBy`, but for
	  // when you know that your index values will be unique.
	  _.indexBy = group(function(result, value, key) {
	    result[key] = value;
	  });

	  // Counts instances of an object that group by a certain criterion. Pass
	  // either a string attribute to count by, or a function that returns the
	  // criterion.
	  _.countBy = group(function(result, value, key) {
	    if (_.has(result, key)) result[key]++; else result[key] = 1;
	  });

	  // Safely create a real, live array from anything iterable.
	  _.toArray = function(obj) {
	    if (!obj) return [];
	    if (_.isArray(obj)) return slice.call(obj);
	    if (isArrayLike(obj)) return _.map(obj, _.identity);
	    return _.values(obj);
	  };

	  // Return the number of elements in an object.
	  _.size = function(obj) {
	    if (obj == null) return 0;
	    return isArrayLike(obj) ? obj.length : _.keys(obj).length;
	  };

	  // Split a collection into two arrays: one whose elements all satisfy the given
	  // predicate, and one whose elements all do not satisfy the predicate.
	  _.partition = function(obj, predicate, context) {
	    predicate = cb(predicate, context);
	    var pass = [], fail = [];
	    _.each(obj, function(value, key, obj) {
	      (predicate(value, key, obj) ? pass : fail).push(value);
	    });
	    return [pass, fail];
	  };

	  // Array Functions
	  // ---------------

	  // Get the first element of an array. Passing **n** will return the first N
	  // values in the array. Aliased as `head` and `take`. The **guard** check
	  // allows it to work with `_.map`.
	  _.first = _.head = _.take = function(array, n, guard) {
	    if (array == null) return void 0;
	    if (n == null || guard) return array[0];
	    return _.initial(array, array.length - n);
	  };

	  // Returns everything but the last entry of the array. Especially useful on
	  // the arguments object. Passing **n** will return all the values in
	  // the array, excluding the last N.
	  _.initial = function(array, n, guard) {
	    return slice.call(array, 0, Math.max(0, array.length - (n == null || guard ? 1 : n)));
	  };

	  // Get the last element of an array. Passing **n** will return the last N
	  // values in the array.
	  _.last = function(array, n, guard) {
	    if (array == null) return void 0;
	    if (n == null || guard) return array[array.length - 1];
	    return _.rest(array, Math.max(0, array.length - n));
	  };

	  // Returns everything but the first entry of the array. Aliased as `tail` and `drop`.
	  // Especially useful on the arguments object. Passing an **n** will return
	  // the rest N values in the array.
	  _.rest = _.tail = _.drop = function(array, n, guard) {
	    return slice.call(array, n == null || guard ? 1 : n);
	  };

	  // Trim out all falsy values from an array.
	  _.compact = function(array) {
	    return _.filter(array, _.identity);
	  };

	  // Internal implementation of a recursive `flatten` function.
	  var flatten = function(input, shallow, strict, startIndex) {
	    var output = [], idx = 0;
	    for (var i = startIndex || 0, length = getLength(input); i < length; i++) {
	      var value = input[i];
	      if (isArrayLike(value) && (_.isArray(value) || _.isArguments(value))) {
	        //flatten current level of array or arguments object
	        if (!shallow) value = flatten(value, shallow, strict);
	        var j = 0, len = value.length;
	        output.length += len;
	        while (j < len) {
	          output[idx++] = value[j++];
	        }
	      } else if (!strict) {
	        output[idx++] = value;
	      }
	    }
	    return output;
	  };

	  // Flatten out an array, either recursively (by default), or just one level.
	  _.flatten = function(array, shallow) {
	    return flatten(array, shallow, false);
	  };

	  // Return a version of the array that does not contain the specified value(s).
	  _.without = function(array) {
	    return _.difference(array, slice.call(arguments, 1));
	  };

	  // Produce a duplicate-free version of the array. If the array has already
	  // been sorted, you have the option of using a faster algorithm.
	  // Aliased as `unique`.
	  _.uniq = _.unique = function(array, isSorted, iteratee, context) {
	    if (!_.isBoolean(isSorted)) {
	      context = iteratee;
	      iteratee = isSorted;
	      isSorted = false;
	    }
	    if (iteratee != null) iteratee = cb(iteratee, context);
	    var result = [];
	    var seen = [];
	    for (var i = 0, length = getLength(array); i < length; i++) {
	      var value = array[i],
	          computed = iteratee ? iteratee(value, i, array) : value;
	      if (isSorted) {
	        if (!i || seen !== computed) result.push(value);
	        seen = computed;
	      } else if (iteratee) {
	        if (!_.contains(seen, computed)) {
	          seen.push(computed);
	          result.push(value);
	        }
	      } else if (!_.contains(result, value)) {
	        result.push(value);
	      }
	    }
	    return result;
	  };

	  // Produce an array that contains the union: each distinct element from all of
	  // the passed-in arrays.
	  _.union = function() {
	    return _.uniq(flatten(arguments, true, true));
	  };

	  // Produce an array that contains every item shared between all the
	  // passed-in arrays.
	  _.intersection = function(array) {
	    var result = [];
	    var argsLength = arguments.length;
	    for (var i = 0, length = getLength(array); i < length; i++) {
	      var item = array[i];
	      if (_.contains(result, item)) continue;
	      for (var j = 1; j < argsLength; j++) {
	        if (!_.contains(arguments[j], item)) break;
	      }
	      if (j === argsLength) result.push(item);
	    }
	    return result;
	  };

	  // Take the difference between one array and a number of other arrays.
	  // Only the elements present in just the first array will remain.
	  _.difference = function(array) {
	    var rest = flatten(arguments, true, true, 1);
	    return _.filter(array, function(value){
	      return !_.contains(rest, value);
	    });
	  };

	  // Zip together multiple lists into a single array -- elements that share
	  // an index go together.
	  _.zip = function() {
	    return _.unzip(arguments);
	  };

	  // Complement of _.zip. Unzip accepts an array of arrays and groups
	  // each array's elements on shared indices
	  _.unzip = function(array) {
	    var length = array && _.max(array, getLength).length || 0;
	    var result = Array(length);

	    for (var index = 0; index < length; index++) {
	      result[index] = _.pluck(array, index);
	    }
	    return result;
	  };

	  // Converts lists into objects. Pass either a single array of `[key, value]`
	  // pairs, or two parallel arrays of the same length -- one of keys, and one of
	  // the corresponding values.
	  _.object = function(list, values) {
	    var result = {};
	    for (var i = 0, length = getLength(list); i < length; i++) {
	      if (values) {
	        result[list[i]] = values[i];
	      } else {
	        result[list[i][0]] = list[i][1];
	      }
	    }
	    return result;
	  };

	  // Generator function to create the findIndex and findLastIndex functions
	  function createPredicateIndexFinder(dir) {
	    return function(array, predicate, context) {
	      predicate = cb(predicate, context);
	      var length = getLength(array);
	      var index = dir > 0 ? 0 : length - 1;
	      for (; index >= 0 && index < length; index += dir) {
	        if (predicate(array[index], index, array)) return index;
	      }
	      return -1;
	    };
	  }

	  // Returns the first index on an array-like that passes a predicate test
	  _.findIndex = createPredicateIndexFinder(1);
	  _.findLastIndex = createPredicateIndexFinder(-1);

	  // Use a comparator function to figure out the smallest index at which
	  // an object should be inserted so as to maintain order. Uses binary search.
	  _.sortedIndex = function(array, obj, iteratee, context) {
	    iteratee = cb(iteratee, context, 1);
	    var value = iteratee(obj);
	    var low = 0, high = getLength(array);
	    while (low < high) {
	      var mid = Math.floor((low + high) / 2);
	      if (iteratee(array[mid]) < value) low = mid + 1; else high = mid;
	    }
	    return low;
	  };

	  // Generator function to create the indexOf and lastIndexOf functions
	  function createIndexFinder(dir, predicateFind, sortedIndex) {
	    return function(array, item, idx) {
	      var i = 0, length = getLength(array);
	      if (typeof idx == 'number') {
	        if (dir > 0) {
	            i = idx >= 0 ? idx : Math.max(idx + length, i);
	        } else {
	            length = idx >= 0 ? Math.min(idx + 1, length) : idx + length + 1;
	        }
	      } else if (sortedIndex && idx && length) {
	        idx = sortedIndex(array, item);
	        return array[idx] === item ? idx : -1;
	      }
	      if (item !== item) {
	        idx = predicateFind(slice.call(array, i, length), _.isNaN);
	        return idx >= 0 ? idx + i : -1;
	      }
	      for (idx = dir > 0 ? i : length - 1; idx >= 0 && idx < length; idx += dir) {
	        if (array[idx] === item) return idx;
	      }
	      return -1;
	    };
	  }

	  // Return the position of the first occurrence of an item in an array,
	  // or -1 if the item is not included in the array.
	  // If the array is large and already in sort order, pass `true`
	  // for **isSorted** to use binary search.
	  _.indexOf = createIndexFinder(1, _.findIndex, _.sortedIndex);
	  _.lastIndexOf = createIndexFinder(-1, _.findLastIndex);

	  // Generate an integer Array containing an arithmetic progression. A port of
	  // the native Python `range()` function. See
	  // [the Python documentation](http://docs.python.org/library/functions.html#range).
	  _.range = function(start, stop, step) {
	    if (stop == null) {
	      stop = start || 0;
	      start = 0;
	    }
	    step = step || 1;

	    var length = Math.max(Math.ceil((stop - start) / step), 0);
	    var range = Array(length);

	    for (var idx = 0; idx < length; idx++, start += step) {
	      range[idx] = start;
	    }

	    return range;
	  };

	  // Function (ahem) Functions
	  // ------------------

	  // Determines whether to execute a function as a constructor
	  // or a normal function with the provided arguments
	  var executeBound = function(sourceFunc, boundFunc, context, callingContext, args) {
	    if (!(callingContext instanceof boundFunc)) return sourceFunc.apply(context, args);
	    var self = baseCreate(sourceFunc.prototype);
	    var result = sourceFunc.apply(self, args);
	    if (_.isObject(result)) return result;
	    return self;
	  };

	  // Create a function bound to a given object (assigning `this`, and arguments,
	  // optionally). Delegates to **ECMAScript 5**'s native `Function.bind` if
	  // available.
	  _.bind = function(func, context) {
	    if (nativeBind && func.bind === nativeBind) return nativeBind.apply(func, slice.call(arguments, 1));
	    if (!_.isFunction(func)) throw new TypeError('Bind must be called on a function');
	    var args = slice.call(arguments, 2);
	    var bound = function() {
	      return executeBound(func, bound, context, this, args.concat(slice.call(arguments)));
	    };
	    return bound;
	  };

	  // Partially apply a function by creating a version that has had some of its
	  // arguments pre-filled, without changing its dynamic `this` context. _ acts
	  // as a placeholder, allowing any combination of arguments to be pre-filled.
	  _.partial = function(func) {
	    var boundArgs = slice.call(arguments, 1);
	    var bound = function() {
	      var position = 0, length = boundArgs.length;
	      var args = Array(length);
	      for (var i = 0; i < length; i++) {
	        args[i] = boundArgs[i] === _ ? arguments[position++] : boundArgs[i];
	      }
	      while (position < arguments.length) args.push(arguments[position++]);
	      return executeBound(func, bound, this, this, args);
	    };
	    return bound;
	  };

	  // Bind a number of an object's methods to that object. Remaining arguments
	  // are the method names to be bound. Useful for ensuring that all callbacks
	  // defined on an object belong to it.
	  _.bindAll = function(obj) {
	    var i, length = arguments.length, key;
	    if (length <= 1) throw new Error('bindAll must be passed function names');
	    for (i = 1; i < length; i++) {
	      key = arguments[i];
	      obj[key] = _.bind(obj[key], obj);
	    }
	    return obj;
	  };

	  // Memoize an expensive function by storing its results.
	  _.memoize = function(func, hasher) {
	    var memoize = function(key) {
	      var cache = memoize.cache;
	      var address = '' + (hasher ? hasher.apply(this, arguments) : key);
	      if (!_.has(cache, address)) cache[address] = func.apply(this, arguments);
	      return cache[address];
	    };
	    memoize.cache = {};
	    return memoize;
	  };

	  // Delays a function for the given number of milliseconds, and then calls
	  // it with the arguments supplied.
	  _.delay = function(func, wait) {
	    var args = slice.call(arguments, 2);
	    return setTimeout(function(){
	      return func.apply(null, args);
	    }, wait);
	  };

	  // Defers a function, scheduling it to run after the current call stack has
	  // cleared.
	  _.defer = _.partial(_.delay, _, 1);

	  // Returns a function, that, when invoked, will only be triggered at most once
	  // during a given window of time. Normally, the throttled function will run
	  // as much as it can, without ever going more than once per `wait` duration;
	  // but if you'd like to disable the execution on the leading edge, pass
	  // `{leading: false}`. To disable execution on the trailing edge, ditto.
	  _.throttle = function(func, wait, options) {
	    var context, args, result;
	    var timeout = null;
	    var previous = 0;
	    if (!options) options = {};
	    var later = function() {
	      previous = options.leading === false ? 0 : _.now();
	      timeout = null;
	      result = func.apply(context, args);
	      if (!timeout) context = args = null;
	    };
	    return function() {
	      var now = _.now();
	      if (!previous && options.leading === false) previous = now;
	      var remaining = wait - (now - previous);
	      context = this;
	      args = arguments;
	      if (remaining <= 0 || remaining > wait) {
	        if (timeout) {
	          clearTimeout(timeout);
	          timeout = null;
	        }
	        previous = now;
	        result = func.apply(context, args);
	        if (!timeout) context = args = null;
	      } else if (!timeout && options.trailing !== false) {
	        timeout = setTimeout(later, remaining);
	      }
	      return result;
	    };
	  };

	  // Returns a function, that, as long as it continues to be invoked, will not
	  // be triggered. The function will be called after it stops being called for
	  // N milliseconds. If `immediate` is passed, trigger the function on the
	  // leading edge, instead of the trailing.
	  _.debounce = function(func, wait, immediate) {
	    var timeout, args, context, timestamp, result;

	    var later = function() {
	      var last = _.now() - timestamp;

	      if (last < wait && last >= 0) {
	        timeout = setTimeout(later, wait - last);
	      } else {
	        timeout = null;
	        if (!immediate) {
	          result = func.apply(context, args);
	          if (!timeout) context = args = null;
	        }
	      }
	    };

	    return function() {
	      context = this;
	      args = arguments;
	      timestamp = _.now();
	      var callNow = immediate && !timeout;
	      if (!timeout) timeout = setTimeout(later, wait);
	      if (callNow) {
	        result = func.apply(context, args);
	        context = args = null;
	      }

	      return result;
	    };
	  };

	  // Returns the first function passed as an argument to the second,
	  // allowing you to adjust arguments, run code before and after, and
	  // conditionally execute the original function.
	  _.wrap = function(func, wrapper) {
	    return _.partial(wrapper, func);
	  };

	  // Returns a negated version of the passed-in predicate.
	  _.negate = function(predicate) {
	    return function() {
	      return !predicate.apply(this, arguments);
	    };
	  };

	  // Returns a function that is the composition of a list of functions, each
	  // consuming the return value of the function that follows.
	  _.compose = function() {
	    var args = arguments;
	    var start = args.length - 1;
	    return function() {
	      var i = start;
	      var result = args[start].apply(this, arguments);
	      while (i--) result = args[i].call(this, result);
	      return result;
	    };
	  };

	  // Returns a function that will only be executed on and after the Nth call.
	  _.after = function(times, func) {
	    return function() {
	      if (--times < 1) {
	        return func.apply(this, arguments);
	      }
	    };
	  };

	  // Returns a function that will only be executed up to (but not including) the Nth call.
	  _.before = function(times, func) {
	    var memo;
	    return function() {
	      if (--times > 0) {
	        memo = func.apply(this, arguments);
	      }
	      if (times <= 1) func = null;
	      return memo;
	    };
	  };

	  // Returns a function that will be executed at most one time, no matter how
	  // often you call it. Useful for lazy initialization.
	  _.once = _.partial(_.before, 2);

	  // Object Functions
	  // ----------------

	  // Keys in IE < 9 that won't be iterated by `for key in ...` and thus missed.
	  var hasEnumBug = !{toString: null}.propertyIsEnumerable('toString');
	  var nonEnumerableProps = ['valueOf', 'isPrototypeOf', 'toString',
	                      'propertyIsEnumerable', 'hasOwnProperty', 'toLocaleString'];

	  function collectNonEnumProps(obj, keys) {
	    var nonEnumIdx = nonEnumerableProps.length;
	    var constructor = obj.constructor;
	    var proto = (_.isFunction(constructor) && constructor.prototype) || ObjProto;

	    // Constructor is a special case.
	    var prop = 'constructor';
	    if (_.has(obj, prop) && !_.contains(keys, prop)) keys.push(prop);

	    while (nonEnumIdx--) {
	      prop = nonEnumerableProps[nonEnumIdx];
	      if (prop in obj && obj[prop] !== proto[prop] && !_.contains(keys, prop)) {
	        keys.push(prop);
	      }
	    }
	  }

	  // Retrieve the names of an object's own properties.
	  // Delegates to **ECMAScript 5**'s native `Object.keys`
	  _.keys = function(obj) {
	    if (!_.isObject(obj)) return [];
	    if (nativeKeys) return nativeKeys(obj);
	    var keys = [];
	    for (var key in obj) if (_.has(obj, key)) keys.push(key);
	    // Ahem, IE < 9.
	    if (hasEnumBug) collectNonEnumProps(obj, keys);
	    return keys;
	  };

	  // Retrieve all the property names of an object.
	  _.allKeys = function(obj) {
	    if (!_.isObject(obj)) return [];
	    var keys = [];
	    for (var key in obj) keys.push(key);
	    // Ahem, IE < 9.
	    if (hasEnumBug) collectNonEnumProps(obj, keys);
	    return keys;
	  };

	  // Retrieve the values of an object's properties.
	  _.values = function(obj) {
	    var keys = _.keys(obj);
	    var length = keys.length;
	    var values = Array(length);
	    for (var i = 0; i < length; i++) {
	      values[i] = obj[keys[i]];
	    }
	    return values;
	  };

	  // Returns the results of applying the iteratee to each element of the object
	  // In contrast to _.map it returns an object
	  _.mapObject = function(obj, iteratee, context) {
	    iteratee = cb(iteratee, context);
	    var keys =  _.keys(obj),
	          length = keys.length,
	          results = {},
	          currentKey;
	      for (var index = 0; index < length; index++) {
	        currentKey = keys[index];
	        results[currentKey] = iteratee(obj[currentKey], currentKey, obj);
	      }
	      return results;
	  };

	  // Convert an object into a list of `[key, value]` pairs.
	  _.pairs = function(obj) {
	    var keys = _.keys(obj);
	    var length = keys.length;
	    var pairs = Array(length);
	    for (var i = 0; i < length; i++) {
	      pairs[i] = [keys[i], obj[keys[i]]];
	    }
	    return pairs;
	  };

	  // Invert the keys and values of an object. The values must be serializable.
	  _.invert = function(obj) {
	    var result = {};
	    var keys = _.keys(obj);
	    for (var i = 0, length = keys.length; i < length; i++) {
	      result[obj[keys[i]]] = keys[i];
	    }
	    return result;
	  };

	  // Return a sorted list of the function names available on the object.
	  // Aliased as `methods`
	  _.functions = _.methods = function(obj) {
	    var names = [];
	    for (var key in obj) {
	      if (_.isFunction(obj[key])) names.push(key);
	    }
	    return names.sort();
	  };

	  // Extend a given object with all the properties in passed-in object(s).
	  _.extend = createAssigner(_.allKeys);

	  // Assigns a given object with all the own properties in the passed-in object(s)
	  // (https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object/assign)
	  _.extendOwn = _.assign = createAssigner(_.keys);

	  // Returns the first key on an object that passes a predicate test
	  _.findKey = function(obj, predicate, context) {
	    predicate = cb(predicate, context);
	    var keys = _.keys(obj), key;
	    for (var i = 0, length = keys.length; i < length; i++) {
	      key = keys[i];
	      if (predicate(obj[key], key, obj)) return key;
	    }
	  };

	  // Return a copy of the object only containing the whitelisted properties.
	  _.pick = function(object, oiteratee, context) {
	    var result = {}, obj = object, iteratee, keys;
	    if (obj == null) return result;
	    if (_.isFunction(oiteratee)) {
	      keys = _.allKeys(obj);
	      iteratee = optimizeCb(oiteratee, context);
	    } else {
	      keys = flatten(arguments, false, false, 1);
	      iteratee = function(value, key, obj) { return key in obj; };
	      obj = Object(obj);
	    }
	    for (var i = 0, length = keys.length; i < length; i++) {
	      var key = keys[i];
	      var value = obj[key];
	      if (iteratee(value, key, obj)) result[key] = value;
	    }
	    return result;
	  };

	   // Return a copy of the object without the blacklisted properties.
	  _.omit = function(obj, iteratee, context) {
	    if (_.isFunction(iteratee)) {
	      iteratee = _.negate(iteratee);
	    } else {
	      var keys = _.map(flatten(arguments, false, false, 1), String);
	      iteratee = function(value, key) {
	        return !_.contains(keys, key);
	      };
	    }
	    return _.pick(obj, iteratee, context);
	  };

	  // Fill in a given object with default properties.
	  _.defaults = createAssigner(_.allKeys, true);

	  // Creates an object that inherits from the given prototype object.
	  // If additional properties are provided then they will be added to the
	  // created object.
	  _.create = function(prototype, props) {
	    var result = baseCreate(prototype);
	    if (props) _.extendOwn(result, props);
	    return result;
	  };

	  // Create a (shallow-cloned) duplicate of an object.
	  _.clone = function(obj) {
	    if (!_.isObject(obj)) return obj;
	    return _.isArray(obj) ? obj.slice() : _.extend({}, obj);
	  };

	  // Invokes interceptor with the obj, and then returns obj.
	  // The primary purpose of this method is to "tap into" a method chain, in
	  // order to perform operations on intermediate results within the chain.
	  _.tap = function(obj, interceptor) {
	    interceptor(obj);
	    return obj;
	  };

	  // Returns whether an object has a given set of `key:value` pairs.
	  _.isMatch = function(object, attrs) {
	    var keys = _.keys(attrs), length = keys.length;
	    if (object == null) return !length;
	    var obj = Object(object);
	    for (var i = 0; i < length; i++) {
	      var key = keys[i];
	      if (attrs[key] !== obj[key] || !(key in obj)) return false;
	    }
	    return true;
	  };


	  // Internal recursive comparison function for `isEqual`.
	  var eq = function(a, b, aStack, bStack) {
	    // Identical objects are equal. `0 === -0`, but they aren't identical.
	    // See the [Harmony `egal` proposal](http://wiki.ecmascript.org/doku.php?id=harmony:egal).
	    if (a === b) return a !== 0 || 1 / a === 1 / b;
	    // A strict comparison is necessary because `null == undefined`.
	    if (a == null || b == null) return a === b;
	    // Unwrap any wrapped objects.
	    if (a instanceof _) a = a._wrapped;
	    if (b instanceof _) b = b._wrapped;
	    // Compare `[[Class]]` names.
	    var className = toString.call(a);
	    if (className !== toString.call(b)) return false;
	    switch (className) {
	      // Strings, numbers, regular expressions, dates, and booleans are compared by value.
	      case '[object RegExp]':
	      // RegExps are coerced to strings for comparison (Note: '' + /a/i === '/a/i')
	      case '[object String]':
	        // Primitives and their corresponding object wrappers are equivalent; thus, `"5"` is
	        // equivalent to `new String("5")`.
	        return '' + a === '' + b;
	      case '[object Number]':
	        // `NaN`s are equivalent, but non-reflexive.
	        // Object(NaN) is equivalent to NaN
	        if (+a !== +a) return +b !== +b;
	        // An `egal` comparison is performed for other numeric values.
	        return +a === 0 ? 1 / +a === 1 / b : +a === +b;
	      case '[object Date]':
	      case '[object Boolean]':
	        // Coerce dates and booleans to numeric primitive values. Dates are compared by their
	        // millisecond representations. Note that invalid dates with millisecond representations
	        // of `NaN` are not equivalent.
	        return +a === +b;
	    }

	    var areArrays = className === '[object Array]';
	    if (!areArrays) {
	      if (typeof a != 'object' || typeof b != 'object') return false;

	      // Objects with different constructors are not equivalent, but `Object`s or `Array`s
	      // from different frames are.
	      var aCtor = a.constructor, bCtor = b.constructor;
	      if (aCtor !== bCtor && !(_.isFunction(aCtor) && aCtor instanceof aCtor &&
	                               _.isFunction(bCtor) && bCtor instanceof bCtor)
	                          && ('constructor' in a && 'constructor' in b)) {
	        return false;
	      }
	    }
	    // Assume equality for cyclic structures. The algorithm for detecting cyclic
	    // structures is adapted from ES 5.1 section 15.12.3, abstract operation `JO`.

	    // Initializing stack of traversed objects.
	    // It's done here since we only need them for objects and arrays comparison.
	    aStack = aStack || [];
	    bStack = bStack || [];
	    var length = aStack.length;
	    while (length--) {
	      // Linear search. Performance is inversely proportional to the number of
	      // unique nested structures.
	      if (aStack[length] === a) return bStack[length] === b;
	    }

	    // Add the first object to the stack of traversed objects.
	    aStack.push(a);
	    bStack.push(b);

	    // Recursively compare objects and arrays.
	    if (areArrays) {
	      // Compare array lengths to determine if a deep comparison is necessary.
	      length = a.length;
	      if (length !== b.length) return false;
	      // Deep compare the contents, ignoring non-numeric properties.
	      while (length--) {
	        if (!eq(a[length], b[length], aStack, bStack)) return false;
	      }
	    } else {
	      // Deep compare objects.
	      var keys = _.keys(a), key;
	      length = keys.length;
	      // Ensure that both objects contain the same number of properties before comparing deep equality.
	      if (_.keys(b).length !== length) return false;
	      while (length--) {
	        // Deep compare each member
	        key = keys[length];
	        if (!(_.has(b, key) && eq(a[key], b[key], aStack, bStack))) return false;
	      }
	    }
	    // Remove the first object from the stack of traversed objects.
	    aStack.pop();
	    bStack.pop();
	    return true;
	  };

	  // Perform a deep comparison to check if two objects are equal.
	  _.isEqual = function(a, b) {
	    return eq(a, b);
	  };

	  // Is a given array, string, or object empty?
	  // An "empty" object has no enumerable own-properties.
	  _.isEmpty = function(obj) {
	    if (obj == null) return true;
	    if (isArrayLike(obj) && (_.isArray(obj) || _.isString(obj) || _.isArguments(obj))) return obj.length === 0;
	    return _.keys(obj).length === 0;
	  };

	  // Is a given value a DOM element?
	  _.isElement = function(obj) {
	    return !!(obj && obj.nodeType === 1);
	  };

	  // Is a given value an array?
	  // Delegates to ECMA5's native Array.isArray
	  _.isArray = nativeIsArray || function(obj) {
	    return toString.call(obj) === '[object Array]';
	  };

	  // Is a given variable an object?
	  _.isObject = function(obj) {
	    var type = typeof obj;
	    return type === 'function' || type === 'object' && !!obj;
	  };

	  // Add some isType methods: isArguments, isFunction, isString, isNumber, isDate, isRegExp, isError.
	  _.each(['Arguments', 'Function', 'String', 'Number', 'Date', 'RegExp', 'Error'], function(name) {
	    _['is' + name] = function(obj) {
	      return toString.call(obj) === '[object ' + name + ']';
	    };
	  });

	  // Define a fallback version of the method in browsers (ahem, IE < 9), where
	  // there isn't any inspectable "Arguments" type.
	  if (!_.isArguments(arguments)) {
	    _.isArguments = function(obj) {
	      return _.has(obj, 'callee');
	    };
	  }

	  // Optimize `isFunction` if appropriate. Work around some typeof bugs in old v8,
	  // IE 11 (#1621), and in Safari 8 (#1929).
	  if (typeof /./ != 'function' && typeof Int8Array != 'object') {
	    _.isFunction = function(obj) {
	      return typeof obj == 'function' || false;
	    };
	  }

	  // Is a given object a finite number?
	  _.isFinite = function(obj) {
	    return isFinite(obj) && !isNaN(parseFloat(obj));
	  };

	  // Is the given value `NaN`? (NaN is the only number which does not equal itself).
	  _.isNaN = function(obj) {
	    return _.isNumber(obj) && obj !== +obj;
	  };

	  // Is a given value a boolean?
	  _.isBoolean = function(obj) {
	    return obj === true || obj === false || toString.call(obj) === '[object Boolean]';
	  };

	  // Is a given value equal to null?
	  _.isNull = function(obj) {
	    return obj === null;
	  };

	  // Is a given variable undefined?
	  _.isUndefined = function(obj) {
	    return obj === void 0;
	  };

	  // Shortcut function for checking if an object has a given property directly
	  // on itself (in other words, not on a prototype).
	  _.has = function(obj, key) {
	    return obj != null && hasOwnProperty.call(obj, key);
	  };

	  // Utility Functions
	  // -----------------

	  // Run Underscore.js in *noConflict* mode, returning the `_` variable to its
	  // previous owner. Returns a reference to the Underscore object.
	  _.noConflict = function() {
	    root._ = previousUnderscore;
	    return this;
	  };

	  // Keep the identity function around for default iteratees.
	  _.identity = function(value) {
	    return value;
	  };

	  // Predicate-generating functions. Often useful outside of Underscore.
	  _.constant = function(value) {
	    return function() {
	      return value;
	    };
	  };

	  _.noop = function(){};

	  _.property = property;

	  // Generates a function for a given object that returns a given property.
	  _.propertyOf = function(obj) {
	    return obj == null ? function(){} : function(key) {
	      return obj[key];
	    };
	  };

	  // Returns a predicate for checking whether an object has a given set of
	  // `key:value` pairs.
	  _.matcher = _.matches = function(attrs) {
	    attrs = _.extendOwn({}, attrs);
	    return function(obj) {
	      return _.isMatch(obj, attrs);
	    };
	  };

	  // Run a function **n** times.
	  _.times = function(n, iteratee, context) {
	    var accum = Array(Math.max(0, n));
	    iteratee = optimizeCb(iteratee, context, 1);
	    for (var i = 0; i < n; i++) accum[i] = iteratee(i);
	    return accum;
	  };

	  // Return a random integer between min and max (inclusive).
	  _.random = function(min, max) {
	    if (max == null) {
	      max = min;
	      min = 0;
	    }
	    return min + Math.floor(Math.random() * (max - min + 1));
	  };

	  // A (possibly faster) way to get the current timestamp as an integer.
	  _.now = Date.now || function() {
	    return new Date().getTime();
	  };

	   // List of HTML entities for escaping.
	  var escapeMap = {
	    '&': '&amp;',
	    '<': '&lt;',
	    '>': '&gt;',
	    '"': '&quot;',
	    "'": '&#x27;',
	    '`': '&#x60;'
	  };
	  var unescapeMap = _.invert(escapeMap);

	  // Functions for escaping and unescaping strings to/from HTML interpolation.
	  var createEscaper = function(map) {
	    var escaper = function(match) {
	      return map[match];
	    };
	    // Regexes for identifying a key that needs to be escaped
	    var source = '(?:' + _.keys(map).join('|') + ')';
	    var testRegexp = RegExp(source);
	    var replaceRegexp = RegExp(source, 'g');
	    return function(string) {
	      string = string == null ? '' : '' + string;
	      return testRegexp.test(string) ? string.replace(replaceRegexp, escaper) : string;
	    };
	  };
	  _.escape = createEscaper(escapeMap);
	  _.unescape = createEscaper(unescapeMap);

	  // If the value of the named `property` is a function then invoke it with the
	  // `object` as context; otherwise, return it.
	  _.result = function(object, property, fallback) {
	    var value = object == null ? void 0 : object[property];
	    if (value === void 0) {
	      value = fallback;
	    }
	    return _.isFunction(value) ? value.call(object) : value;
	  };

	  // Generate a unique integer id (unique within the entire client session).
	  // Useful for temporary DOM ids.
	  var idCounter = 0;
	  _.uniqueId = function(prefix) {
	    var id = ++idCounter + '';
	    return prefix ? prefix + id : id;
	  };

	  // By default, Underscore uses ERB-style template delimiters, change the
	  // following template settings to use alternative delimiters.
	  _.templateSettings = {
	    evaluate    : /<%([\s\S]+?)%>/g,
	    interpolate : /<%=([\s\S]+?)%>/g,
	    escape      : /<%-([\s\S]+?)%>/g
	  };

	  // When customizing `templateSettings`, if you don't want to define an
	  // interpolation, evaluation or escaping regex, we need one that is
	  // guaranteed not to match.
	  var noMatch = /(.)^/;

	  // Certain characters need to be escaped so that they can be put into a
	  // string literal.
	  var escapes = {
	    "'":      "'",
	    '\\':     '\\',
	    '\r':     'r',
	    '\n':     'n',
	    '\u2028': 'u2028',
	    '\u2029': 'u2029'
	  };

	  var escaper = /\\|'|\r|\n|\u2028|\u2029/g;

	  var escapeChar = function(match) {
	    return '\\' + escapes[match];
	  };

	  // JavaScript micro-templating, similar to John Resig's implementation.
	  // Underscore templating handles arbitrary delimiters, preserves whitespace,
	  // and correctly escapes quotes within interpolated code.
	  // NB: `oldSettings` only exists for backwards compatibility.
	  _.template = function(text, settings, oldSettings) {
	    if (!settings && oldSettings) settings = oldSettings;
	    settings = _.defaults({}, settings, _.templateSettings);

	    // Combine delimiters into one regular expression via alternation.
	    var matcher = RegExp([
	      (settings.escape || noMatch).source,
	      (settings.interpolate || noMatch).source,
	      (settings.evaluate || noMatch).source
	    ].join('|') + '|$', 'g');

	    // Compile the template source, escaping string literals appropriately.
	    var index = 0;
	    var source = "__p+='";
	    text.replace(matcher, function(match, escape, interpolate, evaluate, offset) {
	      source += text.slice(index, offset).replace(escaper, escapeChar);
	      index = offset + match.length;

	      if (escape) {
	        source += "'+\n((__t=(" + escape + "))==null?'':_.escape(__t))+\n'";
	      } else if (interpolate) {
	        source += "'+\n((__t=(" + interpolate + "))==null?'':__t)+\n'";
	      } else if (evaluate) {
	        source += "';\n" + evaluate + "\n__p+='";
	      }

	      // Adobe VMs need the match returned to produce the correct offest.
	      return match;
	    });
	    source += "';\n";

	    // If a variable is not specified, place data values in local scope.
	    if (!settings.variable) source = 'with(obj||{}){\n' + source + '}\n';

	    source = "var __t,__p='',__j=Array.prototype.join," +
	      "print=function(){__p+=__j.call(arguments,'');};\n" +
	      source + 'return __p;\n';

	    try {
	      var render = new Function(settings.variable || 'obj', '_', source);
	    } catch (e) {
	      e.source = source;
	      throw e;
	    }

	    var template = function(data) {
	      return render.call(this, data, _);
	    };

	    // Provide the compiled source as a convenience for precompilation.
	    var argument = settings.variable || 'obj';
	    template.source = 'function(' + argument + '){\n' + source + '}';

	    return template;
	  };

	  // Add a "chain" function. Start chaining a wrapped Underscore object.
	  _.chain = function(obj) {
	    var instance = _(obj);
	    instance._chain = true;
	    return instance;
	  };

	  // OOP
	  // ---------------
	  // If Underscore is called as a function, it returns a wrapped object that
	  // can be used OO-style. This wrapper holds altered versions of all the
	  // underscore functions. Wrapped objects may be chained.

	  // Helper function to continue chaining intermediate results.
	  var result = function(instance, obj) {
	    return instance._chain ? _(obj).chain() : obj;
	  };

	  // Add your own custom functions to the Underscore object.
	  _.mixin = function(obj) {
	    _.each(_.functions(obj), function(name) {
	      var func = _[name] = obj[name];
	      _.prototype[name] = function() {
	        var args = [this._wrapped];
	        push.apply(args, arguments);
	        return result(this, func.apply(_, args));
	      };
	    });
	  };

	  // Add all of the Underscore functions to the wrapper object.
	  _.mixin(_);

	  // Add all mutator Array functions to the wrapper.
	  _.each(['pop', 'push', 'reverse', 'shift', 'sort', 'splice', 'unshift'], function(name) {
	    var method = ArrayProto[name];
	    _.prototype[name] = function() {
	      var obj = this._wrapped;
	      method.apply(obj, arguments);
	      if ((name === 'shift' || name === 'splice') && obj.length === 0) delete obj[0];
	      return result(this, obj);
	    };
	  });

	  // Add all accessor Array functions to the wrapper.
	  _.each(['concat', 'join', 'slice'], function(name) {
	    var method = ArrayProto[name];
	    _.prototype[name] = function() {
	      return result(this, method.apply(this._wrapped, arguments));
	    };
	  });

	  // Extracts the result from a wrapped and chained object.
	  _.prototype.value = function() {
	    return this._wrapped;
	  };

	  // Provide unwrapping proxy for some methods used in engine operations
	  // such as arithmetic and JSON stringification.
	  _.prototype.valueOf = _.prototype.toJSON = _.prototype.value;

	  _.prototype.toString = function() {
	    return '' + this._wrapped;
	  };

	  // AMD registration happens at the end for compatibility with AMD loaders
	  // that may not enforce next-turn semantics on modules. Even though general
	  // practice for AMD registration is to be anonymous, underscore registers
	  // as a named module because, like jQuery, it is a base library that is
	  // popular enough to be bundled in a third party lib, but not be part of
	  // an AMD load request. Those cases could generate an error when an
	  // anonymous define() is called outside of a loader request.
	  if (true) {
	    !(__WEBPACK_AMD_DEFINE_ARRAY__ = [], __WEBPACK_AMD_DEFINE_RESULT__ = function() {
	      return _;
	    }.apply(exports, __WEBPACK_AMD_DEFINE_ARRAY__), __WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
	  }
	}.call(this));


/***/ },
/* 62 */
/***/ function(module, exports, __webpack_require__) {

	var json = typeof JSON !== 'undefined' ? JSON : __webpack_require__(103);

	module.exports = function (obj, opts) {
	    if (!opts) opts = {};
	    if (typeof opts === 'function') opts = { cmp: opts };
	    var space = opts.space || '';
	    if (typeof space === 'number') space = Array(space+1).join(' ');
	    var cycles = (typeof opts.cycles === 'boolean') ? opts.cycles : false;
	    var replacer = opts.replacer || function(key, value) { return value; };

	    var cmp = opts.cmp && (function (f) {
	        return function (node) {
	            return function (a, b) {
	                var aobj = { key: a, value: node[a] };
	                var bobj = { key: b, value: node[b] };
	                return f(aobj, bobj);
	            };
	        };
	    })(opts.cmp);

	    var seen = [];
	    return (function stringify (parent, key, node, level) {
	        var indent = space ? ('\n' + new Array(level + 1).join(space)) : '';
	        var colonSeparator = space ? ': ' : ':';

	        if (node && node.toJSON && typeof node.toJSON === 'function') {
	            node = node.toJSON();
	        }

	        node = replacer.call(parent, key, node);

	        if (node === undefined) {
	            return;
	        }
	        if (typeof node !== 'object' || node === null) {
	            return json.stringify(node);
	        }
	        if (isArray(node)) {
	            var out = [];
	            for (var i = 0; i < node.length; i++) {
	                var item = stringify(node, i, node[i], level+1) || json.stringify(null);
	                out.push(indent + space + item);
	            }
	            return '[' + out.join(',') + indent + ']';
	        }
	        else {
	            if (seen.indexOf(node) !== -1) {
	                if (cycles) return json.stringify('__cycle__');
	                throw new TypeError('Converting circular structure to JSON');
	            }
	            else seen.push(node);

	            var keys = objectKeys(node).sort(cmp && cmp(node));
	            var out = [];
	            for (var i = 0; i < keys.length; i++) {
	                var key = keys[i];
	                var value = stringify(node, key, node[key], level+1);

	                if(!value) continue;

	                var keyValue = json.stringify(key)
	                    + colonSeparator
	                    + value;
	                ;
	                out.push(indent + space + keyValue);
	            }
	            seen.splice(seen.indexOf(node), 1);
	            return '{' + out.join(',') + indent + '}';
	        }
	    })({ '': obj }, '', obj, 0);
	};

	var isArray = Array.isArray || function (x) {
	    return {}.toString.call(x) === '[object Array]';
	};

	var objectKeys = Object.keys || function (obj) {
	    var has = Object.prototype.hasOwnProperty || function () { return true };
	    var keys = [];
	    for (var key in obj) {
	        if (has.call(obj, key)) keys.push(key);
	    }
	    return keys;
	};


/***/ },
/* 63 */
/***/ function(module, exports, __webpack_require__) {

	/*!
	 * media-typer
	 * Copyright(c) 2014 Douglas Christopher Wilson
	 * MIT Licensed
	 */

	/**
	 * RegExp to match *( ";" parameter ) in RFC 2616 sec 3.7
	 *
	 * parameter     = token "=" ( token | quoted-string )
	 * token         = 1*<any CHAR except CTLs or separators>
	 * separators    = "(" | ")" | "<" | ">" | "@"
	 *               | "," | ";" | ":" | "\" | <">
	 *               | "/" | "[" | "]" | "?" | "="
	 *               | "{" | "}" | SP | HT
	 * quoted-string = ( <"> *(qdtext | quoted-pair ) <"> )
	 * qdtext        = <any TEXT except <">>
	 * quoted-pair   = "\" CHAR
	 * CHAR          = <any US-ASCII character (octets 0 - 127)>
	 * TEXT          = <any OCTET except CTLs, but including LWS>
	 * LWS           = [CRLF] 1*( SP | HT )
	 * CRLF          = CR LF
	 * CR            = <US-ASCII CR, carriage return (13)>
	 * LF            = <US-ASCII LF, linefeed (10)>
	 * SP            = <US-ASCII SP, space (32)>
	 * SHT           = <US-ASCII HT, horizontal-tab (9)>
	 * CTL           = <any US-ASCII control character (octets 0 - 31) and DEL (127)>
	 * OCTET         = <any 8-bit sequence of data>
	 */
	var paramRegExp = /; *([!#$%&'\*\+\-\.0-9A-Z\^_`a-z\|~]+) *= *("(?:[ !\u0023-\u005b\u005d-\u007e\u0080-\u00ff]|\\[\u0020-\u007e])*"|[!#$%&'\*\+\-\.0-9A-Z\^_`a-z\|~]+) */g;
	var textRegExp = /^[\u0020-\u007e\u0080-\u00ff]+$/
	var tokenRegExp = /^[!#$%&'\*\+\-\.0-9A-Z\^_`a-z\|~]+$/

	/**
	 * RegExp to match quoted-pair in RFC 2616
	 *
	 * quoted-pair = "\" CHAR
	 * CHAR        = <any US-ASCII character (octets 0 - 127)>
	 */
	var qescRegExp = /\\([\u0000-\u007f])/g;

	/**
	 * RegExp to match chars that must be quoted-pair in RFC 2616
	 */
	var quoteRegExp = /([\\"])/g;

	/**
	 * RegExp to match type in RFC 6838
	 *
	 * type-name = restricted-name
	 * subtype-name = restricted-name
	 * restricted-name = restricted-name-first *126restricted-name-chars
	 * restricted-name-first  = ALPHA / DIGIT
	 * restricted-name-chars  = ALPHA / DIGIT / "!" / "#" /
	 *                          "$" / "&" / "-" / "^" / "_"
	 * restricted-name-chars =/ "." ; Characters before first dot always
	 *                              ; specify a facet name
	 * restricted-name-chars =/ "+" ; Characters after last plus always
	 *                              ; specify a structured syntax suffix
	 * ALPHA =  %x41-5A / %x61-7A   ; A-Z / a-z
	 * DIGIT =  %x30-39             ; 0-9
	 */
	var subtypeNameRegExp = /^[A-Za-z0-9][A-Za-z0-9!#$&^_.-]{0,126}$/
	var typeNameRegExp = /^[A-Za-z0-9][A-Za-z0-9!#$&^_-]{0,126}$/
	var typeRegExp = /^ *([A-Za-z0-9][A-Za-z0-9!#$&^_-]{0,126})\/([A-Za-z0-9][A-Za-z0-9!#$&^_.+-]{0,126}) *$/;

	/**
	 * Module exports.
	 */

	exports.format = format
	exports.parse = parse

	/**
	 * Format object to media type.
	 *
	 * @param {object} obj
	 * @return {string}
	 * @api public
	 */

	function format(obj) {
	  if (!obj || typeof obj !== 'object') {
	    throw new TypeError('argument obj is required')
	  }

	  var parameters = obj.parameters
	  var subtype = obj.subtype
	  var suffix = obj.suffix
	  var type = obj.type

	  if (!type || !typeNameRegExp.test(type)) {
	    throw new TypeError('invalid type')
	  }

	  if (!subtype || !subtypeNameRegExp.test(subtype)) {
	    throw new TypeError('invalid subtype')
	  }

	  // format as type/subtype
	  var string = type + '/' + subtype

	  // append +suffix
	  if (suffix) {
	    if (!typeNameRegExp.test(suffix)) {
	      throw new TypeError('invalid suffix')
	    }

	    string += '+' + suffix
	  }

	  // append parameters
	  if (parameters && typeof parameters === 'object') {
	    var param
	    var params = Object.keys(parameters).sort()

	    for (var i = 0; i < params.length; i++) {
	      param = params[i]

	      if (!tokenRegExp.test(param)) {
	        throw new TypeError('invalid parameter name')
	      }

	      string += '; ' + param + '=' + qstring(parameters[param])
	    }
	  }

	  return string
	}

	/**
	 * Parse media type to object.
	 *
	 * @param {string|object} string
	 * @return {Object}
	 * @api public
	 */

	function parse(string) {
	  if (!string) {
	    throw new TypeError('argument string is required')
	  }

	  // support req/res-like objects as argument
	  if (typeof string === 'object') {
	    string = getcontenttype(string)
	  }

	  if (typeof string !== 'string') {
	    throw new TypeError('argument string is required to be a string')
	  }

	  var index = string.indexOf(';')
	  var type = index !== -1
	    ? string.substr(0, index)
	    : string

	  var key
	  var match
	  var obj = splitType(type)
	  var params = {}
	  var value

	  paramRegExp.lastIndex = index

	  while (match = paramRegExp.exec(string)) {
	    if (match.index !== index) {
	      throw new TypeError('invalid parameter format')
	    }

	    index += match[0].length
	    key = match[1].toLowerCase()
	    value = match[2]

	    if (value[0] === '"') {
	      // remove quotes and escapes
	      value = value
	        .substr(1, value.length - 2)
	        .replace(qescRegExp, '$1')
	    }

	    params[key] = value
	  }

	  if (index !== -1 && index !== string.length) {
	    throw new TypeError('invalid parameter format')
	  }

	  obj.parameters = params

	  return obj
	}

	/**
	 * Get content-type from req/res objects.
	 *
	 * @param {object}
	 * @return {Object}
	 * @api private
	 */

	function getcontenttype(obj) {
	  if (typeof obj.getHeader === 'function') {
	    // res-like
	    return obj.getHeader('content-type')
	  }

	  if (typeof obj.headers === 'object') {
	    // req-like
	    return obj.headers && obj.headers['content-type']
	  }
	}

	/**
	 * Quote a string if necessary.
	 *
	 * @param {string} val
	 * @return {string}
	 * @api private
	 */

	function qstring(val) {
	  var str = String(val)

	  // no need to quote tokens
	  if (tokenRegExp.test(str)) {
	    return str
	  }

	  if (str.length > 0 && !textRegExp.test(str)) {
	    throw new TypeError('invalid parameter value')
	  }

	  return '"' + str.replace(quoteRegExp, '\\$1') + '"'
	}

	/**
	 * Simply "type/subtype+siffx" into parts.
	 *
	 * @param {string} string
	 * @return {Object}
	 * @api private
	 */

	function splitType(string) {
	  var match = typeRegExp.exec(string.toLowerCase())

	  if (!match) {
	    throw new TypeError('invalid media type')
	  }

	  var type = match[1]
	  var subtype = match[2]
	  var suffix

	  // suffix after last +
	  var index = subtype.lastIndexOf('+')
	  if (index !== -1) {
	    suffix = subtype.substr(index + 1)
	    subtype = subtype.substr(0, index)
	  }

	  var obj = {
	    type: type,
	    subtype: subtype,
	    suffix: suffix
	  }

	  return obj
	}


/***/ },
/* 64 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	var Promise = __webpack_require__(104);
	var Response = __webpack_require__(58);
	var handleQs = __webpack_require__(82);

	module.exports = doRequest;
	function doRequest(method, url, options, callback) {
	  var result = new Promise(function (resolve, reject) {
	    var xhr = new window.XMLHttpRequest();

	    // check types of arguments

	    if (typeof method !== 'string') {
	      throw new TypeError('The method must be a string.');
	    }
	    if (typeof url !== 'string') {
	      throw new TypeError('The URL/path must be a string.');
	    }
	    if (typeof options === 'function') {
	      callback = options;
	      options = {};
	    }
	    if (options === null || options === undefined) {
	      options = {};
	    }
	    if (typeof options !== 'object') {
	      throw new TypeError('Options must be an object (or null).');
	    }
	    if (typeof callback !== 'function') {
	      callback = undefined;
	    }

	    method = method.toUpperCase();
	    options.headers = options.headers || {};


	    function attempt(n) {
	      doRequest(method, url, {
	        qs: options.qs,
	        headers: options.headers,
	        timeout: options.timeout
	      }).nodeify(function (err, res) {
	        var retry = err || res.statusCode >= 400;
	        if (typeof options.retry === 'function') {
	          retry = options.retry(err, res, n + 1);
	        }
	        if (n >= (options.maxRetries | 5)) {
	          retry = false;
	        }
	        if (retry) {
	          var delay = options.retryDelay;
	          if (typeof options.retryDelay === 'function') {
	            delay = options.retryDelay(err, res, n + 1);
	          }
	          delay = delay || 200;
	          setTimeout(function () {
	            attempt(n + 1);
	          }, delay);
	        } else {
	          if (err) reject(err);
	          else resolve(res);
	        }
	      });
	    }
	    if (options.retry && method === 'GET') {
	      return attempt(0);
	    }

	    // handle cross domain

	    var match;
	    var crossDomain = !!((match = /^([\w-]+:)?\/\/([^\/]+)/.exec(url)) && (match[2] != window.location.host));
	    if (!crossDomain) options.headers['X-Requested-With'] = 'XMLHttpRequest';

	    // handle query string
	    if (options.qs) {
	      url = handleQs(url, options.qs);
	    }

	    // handle json body
	    if (options.json) {
	      options.body = JSON.stringify(options.json);
	      options.headers['Content-Type'] = 'application/json';
	    }

	    if (options.timeout) {
	      xhr.timeout = options.timeout;
	      var start = Date.now();
	      xhr.ontimeout = function () {
	        var duration = Date.now() - start;
	        var err = new Error('Request timed out after ' + duration + 'ms');
	        err.timeout = true;
	        err.duration = duration;
	        reject(err);
	      };
	    }
	    xhr.onreadystatechange = function () {
	      if (xhr.readyState === 4) {
	        var headers = {};
	        xhr.getAllResponseHeaders().split('\r\n').forEach(function (header) {
	          var h = header.split(':');
	          if (h.length > 1) {
	            headers[h[0].toLowerCase()] = h.slice(1).join(':').trim();
	          }
	        });
	        var res = new Response(xhr.status, headers, xhr.responseText);
	        res.url = url;
	        resolve(res);
	      }
	    };

	    // method, url, async
	    xhr.open(method, url, true);

	    for (var name in options.headers) {
	      xhr.setRequestHeader(name, options.headers[name]);
	    }

	    // avoid sending empty string (#319)
	    xhr.send(options.body ? options.body : null);
	  });
	  result.getBody = function () {
	    return result.then(function (res) { return res.getBody(); });
	  };
	  return result.nodeify(callback);
	}


/***/ },
/* 65 */
/***/ function(module, exports, __webpack_require__) {

	function DOMParser(options){
		this.options = options ||{locator:{}};
		
	}
	DOMParser.prototype.parseFromString = function(source,mimeType){	
		var options = this.options;
		var sax =  new XMLReader();
		var domBuilder = options.domBuilder || new DOMHandler();//contentHandler and LexicalHandler
		var errorHandler = options.errorHandler;
		var locator = options.locator;
		var defaultNSMap = options.xmlns||{};
		var entityMap = {'lt':'<','gt':'>','amp':'&','quot':'"','apos':"'"}
		if(locator){
			domBuilder.setDocumentLocator(locator)
		}
		
		sax.errorHandler = buildErrorHandler(errorHandler,domBuilder,locator);
		sax.domBuilder = options.domBuilder || domBuilder;
		if(/\/x?html?$/.test(mimeType)){
			entityMap.nbsp = '\xa0';
			entityMap.copy = '\xa9';
			defaultNSMap['']= 'http://www.w3.org/1999/xhtml';
		}
		defaultNSMap.xml = defaultNSMap.xml || 'http://www.w3.org/XML/1998/namespace';
		if(source){
			sax.parse(source,defaultNSMap,entityMap);
		}else{
			sax.errorHandler.error("invalid document source");
		}
		return domBuilder.document;
	}
	function buildErrorHandler(errorImpl,domBuilder,locator){
		if(!errorImpl){
			if(domBuilder instanceof DOMHandler){
				return domBuilder;
			}
			errorImpl = domBuilder ;
		}
		var errorHandler = {}
		var isCallback = errorImpl instanceof Function;
		locator = locator||{}
		function build(key){
			var fn = errorImpl[key];
			if(!fn && isCallback){
				fn = errorImpl.length == 2?function(msg){errorImpl(key,msg)}:errorImpl;
			}
			errorHandler[key] = fn && function(msg){
				fn('[xmldom '+key+']\t'+msg+_locator(locator));
			}||function(){};
		}
		build('warning');
		build('error');
		build('fatalError');
		return errorHandler;
	}

	//console.log('#\n\n\n\n\n\n\n####')
	/**
	 * +ContentHandler+ErrorHandler
	 * +LexicalHandler+EntityResolver2
	 * -DeclHandler-DTDHandler 
	 * 
	 * DefaultHandler:EntityResolver, DTDHandler, ContentHandler, ErrorHandler
	 * DefaultHandler2:DefaultHandler,LexicalHandler, DeclHandler, EntityResolver2
	 * @link http://www.saxproject.org/apidoc/org/xml/sax/helpers/DefaultHandler.html
	 */
	function DOMHandler() {
	    this.cdata = false;
	}
	function position(locator,node){
		node.lineNumber = locator.lineNumber;
		node.columnNumber = locator.columnNumber;
	}
	/**
	 * @see org.xml.sax.ContentHandler#startDocument
	 * @link http://www.saxproject.org/apidoc/org/xml/sax/ContentHandler.html
	 */ 
	DOMHandler.prototype = {
		startDocument : function() {
	    	this.document = new DOMImplementation().createDocument(null, null, null);
	    	if (this.locator) {
	        	this.document.documentURI = this.locator.systemId;
	    	}
		},
		startElement:function(namespaceURI, localName, qName, attrs) {
			var doc = this.document;
		    var el = doc.createElementNS(namespaceURI, qName||localName);
		    var len = attrs.length;
		    appendElement(this, el);
		    this.currentElement = el;
		    
			this.locator && position(this.locator,el)
		    for (var i = 0 ; i < len; i++) {
		        var namespaceURI = attrs.getURI(i);
		        var value = attrs.getValue(i);
		        var qName = attrs.getQName(i);
				var attr = doc.createAttributeNS(namespaceURI, qName);
				if( attr.getOffset){
					position(attr.getOffset(1),attr)
				}
				attr.value = attr.nodeValue = value;
				el.setAttributeNode(attr)
		    }
		},
		endElement:function(namespaceURI, localName, qName) {
			var current = this.currentElement
		    var tagName = current.tagName;
		    this.currentElement = current.parentNode;
		},
		startPrefixMapping:function(prefix, uri) {
		},
		endPrefixMapping:function(prefix) {
		},
		processingInstruction:function(target, data) {
		    var ins = this.document.createProcessingInstruction(target, data);
		    this.locator && position(this.locator,ins)
		    appendElement(this, ins);
		},
		ignorableWhitespace:function(ch, start, length) {
		},
		characters:function(chars, start, length) {
			chars = _toString.apply(this,arguments)
			//console.log(chars)
			if(this.currentElement && chars){
				if (this.cdata) {
					var charNode = this.document.createCDATASection(chars);
					this.currentElement.appendChild(charNode);
				} else {
					var charNode = this.document.createTextNode(chars);
					this.currentElement.appendChild(charNode);
				}
				this.locator && position(this.locator,charNode)
			}
		},
		skippedEntity:function(name) {
		},
		endDocument:function() {
			this.document.normalize();
		},
		setDocumentLocator:function (locator) {
		    if(this.locator = locator){// && !('lineNumber' in locator)){
		    	locator.lineNumber = 0;
		    }
		},
		//LexicalHandler
		comment:function(chars, start, length) {
			chars = _toString.apply(this,arguments)
		    var comm = this.document.createComment(chars);
		    this.locator && position(this.locator,comm)
		    appendElement(this, comm);
		},
		
		startCDATA:function() {
		    //used in characters() methods
		    this.cdata = true;
		},
		endCDATA:function() {
		    this.cdata = false;
		},
		
		startDTD:function(name, publicId, systemId) {
			var impl = this.document.implementation;
		    if (impl && impl.createDocumentType) {
		        var dt = impl.createDocumentType(name, publicId, systemId);
		        this.locator && position(this.locator,dt)
		        appendElement(this, dt);
		    }
		},
		/**
		 * @see org.xml.sax.ErrorHandler
		 * @link http://www.saxproject.org/apidoc/org/xml/sax/ErrorHandler.html
		 */
		warning:function(error) {
			console.warn('[xmldom warning]\t'+error,_locator(this.locator));
		},
		error:function(error) {
			console.error('[xmldom error]\t'+error,_locator(this.locator));
		},
		fatalError:function(error) {
			console.error('[xmldom fatalError]\t'+error,_locator(this.locator));
		    throw error;
		}
	}
	function _locator(l){
		if(l){
			return '\n@'+(l.systemId ||'')+'#[line:'+l.lineNumber+',col:'+l.columnNumber+']'
		}
	}
	function _toString(chars,start,length){
		if(typeof chars == 'string'){
			return chars.substr(start,length)
		}else{//java sax connect width xmldom on rhino(what about: "? && !(chars instanceof String)")
			if(chars.length >= start+length || start){
				return new java.lang.String(chars,start,length)+'';
			}
			return chars;
		}
	}

	/*
	 * @link http://www.saxproject.org/apidoc/org/xml/sax/ext/LexicalHandler.html
	 * used method of org.xml.sax.ext.LexicalHandler:
	 *  #comment(chars, start, length)
	 *  #startCDATA()
	 *  #endCDATA()
	 *  #startDTD(name, publicId, systemId)
	 *
	 *
	 * IGNORED method of org.xml.sax.ext.LexicalHandler:
	 *  #endDTD()
	 *  #startEntity(name)
	 *  #endEntity(name)
	 *
	 *
	 * @link http://www.saxproject.org/apidoc/org/xml/sax/ext/DeclHandler.html
	 * IGNORED method of org.xml.sax.ext.DeclHandler
	 * 	#attributeDecl(eName, aName, type, mode, value)
	 *  #elementDecl(name, model)
	 *  #externalEntityDecl(name, publicId, systemId)
	 *  #internalEntityDecl(name, value)
	 * @link http://www.saxproject.org/apidoc/org/xml/sax/ext/EntityResolver2.html
	 * IGNORED method of org.xml.sax.EntityResolver2
	 *  #resolveEntity(String name,String publicId,String baseURI,String systemId)
	 *  #resolveEntity(publicId, systemId)
	 *  #getExternalSubset(name, baseURI)
	 * @link http://www.saxproject.org/apidoc/org/xml/sax/DTDHandler.html
	 * IGNORED method of org.xml.sax.DTDHandler
	 *  #notationDecl(name, publicId, systemId) {};
	 *  #unparsedEntityDecl(name, publicId, systemId, notationName) {};
	 */
	"endDTD,startEntity,endEntity,attributeDecl,elementDecl,externalEntityDecl,internalEntityDecl,resolveEntity,getExternalSubset,notationDecl,unparsedEntityDecl".replace(/\w+/g,function(key){
		DOMHandler.prototype[key] = function(){return null}
	})

	/* Private static helpers treated below as private instance methods, so don't need to add these to the public API; we might use a Relator to also get rid of non-standard public properties */
	function appendElement (hander,node) {
	    if (!hander.currentElement) {
	        hander.document.appendChild(node);
	    } else {
	        hander.currentElement.appendChild(node);
	    }
	}//appendChild and setAttributeNS are preformance key

	if(true){
		var XMLReader = __webpack_require__(78).XMLReader;
		var DOMImplementation = exports.DOMImplementation = __webpack_require__(79).DOMImplementation;
		exports.XMLSerializer = __webpack_require__(79).XMLSerializer ;
		exports.DOMParser = DOMParser;
	}


/***/ },
/* 66 */
/***/ function(module, exports, __webpack_require__) {

	var __WEBPACK_AMD_DEFINE_FACTORY__, __WEBPACK_AMD_DEFINE_ARRAY__, __WEBPACK_AMD_DEFINE_RESULT__;// **Github:** https://github.com/zensh/lrucache
	//
	// **License:** MIT

	/* global module, define */
	;(function (root, factory) {
	  'use strict';

	  if (typeof module === 'object' && typeof module.exports === 'object') {
	    module.exports = factory();
	  } else if (true) {
	    !(__WEBPACK_AMD_DEFINE_ARRAY__ = [], __WEBPACK_AMD_DEFINE_FACTORY__ = (factory), __WEBPACK_AMD_DEFINE_RESULT__ = (typeof __WEBPACK_AMD_DEFINE_FACTORY__ === 'function' ? (__WEBPACK_AMD_DEFINE_FACTORY__.apply(exports, __WEBPACK_AMD_DEFINE_ARRAY__)) : __WEBPACK_AMD_DEFINE_FACTORY__), __WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
	  } else {
	    root.LRUCache = factory();
	  }
	}(typeof window === 'object' ? window : this, function () {
	  'use strict';

	  function CacheState(capacity) {
	    this.capacity = capacity > 0 ? +capacity : Number.MAX_VALUE;
	    this.data = Object.create ? Object.create(null) : {};
	    this.hash = Object.create ? Object.create(null) : {};
	    this.linkedList = {
	      length: 0,
	      head: null,
	      end: null
	    };
	  }

	  function LRUCache(capacity) {
	    if (!(this instanceof LRUCache)) return new LRUCache(capacity);
	    this._LRUCacheState = new CacheState(capacity);
	  }

	  var proto = LRUCache.prototype;

	  proto.get = function (key) {
	    var state = this._LRUCacheState;
	    var lruEntry = state.hash[key];
	    if (!lruEntry) return;
	    refresh(state.linkedList, lruEntry);
	    return state.data[key];
	  };

	  proto.set = function (key, value) {
	    var state = this._LRUCacheState;
	    var lruEntry = state.hash[key];
	    if (value === undefined) return this;
	    if (!lruEntry) {
	      state.hash[key] = {key: key};
	      state.linkedList.length += 1;
	      lruEntry = state.hash[key];
	    }
	    refresh(state.linkedList, lruEntry);
	    state.data[key] = value;
	    if (state.linkedList.length > state.capacity) this.remove(state.linkedList.end.key);
	    return this;
	  };

	  proto.update = function (key, parseFn) {
	    var state = this._LRUCacheState;
	    if (this.has(key)) {
	      var data = this.get(key);
	      this.set(key, parseFn(data));
	    }
	    return this;
	  };

	  proto.remove = function (key) {
	    var state = this._LRUCacheState;
	    var lruEntry = state.hash[key];
	    if (!lruEntry) return this;
	    if (lruEntry === state.linkedList.head) state.linkedList.head = lruEntry.p;
	    if (lruEntry === state.linkedList.end) state.linkedList.end = lruEntry.n;
	    link(lruEntry.n, lruEntry.p);
	    delete state.hash[key];
	    delete state.data[key];
	    state.linkedList.length -= 1;
	    return this;
	  };

	  proto.removeAll = function () {
	    this._LRUCacheState = new CacheState(this._LRUCacheState.capacity);
	    return this;
	  };

	  proto.info = function () {
	    var state = this._LRUCacheState;
	    return {
	      capacity: state.capacity,
	      length: state.linkedList.length
	    };
	  };

	  proto.keys = function () {
	    var state = this._LRUCacheState;
	    var keys = [], lruEntry = state.linkedList.head;
	    while (lruEntry) {
	      keys.push(lruEntry.key);
	      lruEntry = lruEntry.p;
	    }
	    return keys;
	  };

	  proto.has = function (key) {
	    return !!this._LRUCacheState.hash[key];
	  };

	  proto.staleKey = function () {
	    return this._LRUCacheState.linkedList.end && this._LRUCacheState.linkedList.end.key;
	  };

	  proto.popStale = function () {
	    var staleKey = this.staleKey();
	    if (!staleKey) return null;
	    var stale = [staleKey, this._LRUCacheState.data[staleKey]];
	    this.remove(staleKey);
	    return stale;
	  };

	  // 更新链表，把get或put方法操作的key提到链表head，即表示最新
	  function refresh(linkedList, entry) {
	    if (entry === linkedList.head) return;
	    if (!linkedList.end) {
	      linkedList.end = entry;
	    } else if (linkedList.end === entry) {
	      linkedList.end = entry.n;
	    }

	    link(entry.n, entry.p);
	    link(entry, linkedList.head);
	    linkedList.head = entry;
	    linkedList.head.n = null;
	  }

	  // 对两个链表对象建立链接，形成一条链
	  function link(nextEntry, prevEntry) {
	    if (nextEntry === prevEntry) return;
	    if (nextEntry) nextEntry.p = prevEntry;
	    if (prevEntry) prevEntry.n = nextEntry;
	  }

	  LRUCache.NAME = 'LRUCache';
	  LRUCache.VERSION = 'v0.2.0';
	  return LRUCache;
	}));


/***/ },
/* 67 */
/***/ function(module, exports, __webpack_require__) {

	/* global define */

	(function (root, pluralize) {
	  /* istanbul ignore else */
	  if (true) {
	    // Node.
	    module.exports = pluralize();
	  } else if (typeof define === 'function' && define.amd) {
	    // AMD, registers as an anonymous module.
	    define(function () {
	      return pluralize();
	    });
	  } else {
	    // Browser global.
	    root.pluralize = pluralize();
	  }
	})(this, function () {
	  // Rule storage - pluralize and singularize need to be run sequentially,
	  // while other rules can be optimized using an object for instant lookups.
	  var pluralRules = [];
	  var singularRules = [];
	  var uncountables = {};
	  var irregularPlurals = {};
	  var irregularSingles = {};

	  /**
	   * Title case a string.
	   *
	   * @param  {string} str
	   * @return {string}
	   */
	  function toTitleCase (str) {
	    return str.charAt(0).toUpperCase() + str.substr(1).toLowerCase();
	  }

	  /**
	   * Sanitize a pluralization rule to a usable regular expression.
	   *
	   * @param  {(RegExp|string)} rule
	   * @return {RegExp}
	   */
	  function sanitizeRule (rule) {
	    if (typeof rule === 'string') {
	      return new RegExp('^' + rule + '$', 'i');
	    }

	    return rule;
	  }

	  /**
	   * Pass in a word token to produce a function that can replicate the case on
	   * another word.
	   *
	   * @param  {string}   word
	   * @param  {string}   token
	   * @return {Function}
	   */
	  function restoreCase (word, token) {
	    // Upper cased words. E.g. "HELLO".
	    if (word === word.toUpperCase()) {
	      return token.toUpperCase();
	    }

	    // Title cased words. E.g. "Title".
	    if (word[0] === word[0].toUpperCase()) {
	      return toTitleCase(token);
	    }

	    // Lower cased words. E.g. "test".
	    return token.toLowerCase();
	  }

	  /**
	   * Interpolate a regexp string.
	   *
	   * @param  {string} str
	   * @param  {Array}  args
	   * @return {string}
	   */
	  function interpolate (str, args) {
	    return str.replace(/\$(\d{1,2})/g, function (match, index) {
	      return args[index] || '';
	    });
	  }

	  /**
	   * Sanitize a word by passing in the word and sanitization rules.
	   *
	   * @param  {String}   token
	   * @param  {String}   word
	   * @param  {Array}    collection
	   * @return {String}
	   */
	  function sanitizeWord (token, word, collection) {
	    // Empty string or doesn't need fixing.
	    if (!token.length || uncountables.hasOwnProperty(token)) {
	      return word;
	    }

	    var len = collection.length;

	    // Iterate over the sanitization rules and use the first one to match.
	    while (len--) {
	      var rule = collection[len];

	      // If the rule passes, return the replacement.
	      if (rule[0].test(word)) {
	        return word.replace(rule[0], function (match, index, word) {
	          var result = interpolate(rule[1], arguments);

	          if (match === '') {
	            return restoreCase(word[index - 1], result);
	          }

	          return restoreCase(match, result);
	        });
	      }
	    }

	    return word;
	  }

	  /**
	   * Replace a word with the updated word.
	   *
	   * @param  {Object}   replaceMap
	   * @param  {Object}   keepMap
	   * @param  {Array}    rules
	   * @return {Function}
	   */
	  function replaceWord (replaceMap, keepMap, rules) {
	    return function (word) {
	      // Get the correct token and case restoration functions.
	      var token = word.toLowerCase();

	      // Check against the keep object map.
	      if (keepMap.hasOwnProperty(token)) {
	        return restoreCase(word, token);
	      }

	      // Check against the replacement map for a direct word replacement.
	      if (replaceMap.hasOwnProperty(token)) {
	        return restoreCase(word, replaceMap[token]);
	      }

	      // Run all the rules against the word.
	      return sanitizeWord(token, word, rules);
	    };
	  }

	  /**
	   * Pluralize or singularize a word based on the passed in count.
	   *
	   * @param  {String}  word
	   * @param  {Number}  count
	   * @param  {Boolean} inclusive
	   * @return {String}
	   */
	  function pluralize (word, count, inclusive) {
	    var pluralized = count === 1
	      ? pluralize.singular(word) : pluralize.plural(word);

	    return (inclusive ? count + ' ' : '') + pluralized;
	  }

	  /**
	   * Pluralize a word.
	   *
	   * @type {Function}
	   */
	  pluralize.plural = replaceWord(
	    irregularSingles, irregularPlurals, pluralRules
	  );

	  /**
	   * Singularize a word.
	   *
	   * @type {Function}
	   */
	  pluralize.singular = replaceWord(
	    irregularPlurals, irregularSingles, singularRules
	  );

	  /**
	   * Add a pluralization rule to the collection.
	   *
	   * @param {(string|RegExp)} rule
	   * @param {string}          replacement
	   */
	  pluralize.addPluralRule = function (rule, replacement) {
	    pluralRules.push([sanitizeRule(rule), replacement]);
	  };

	  /**
	   * Add a singularization rule to the collection.
	   *
	   * @param {(string|RegExp)} rule
	   * @param {string}          replacement
	   */
	  pluralize.addSingularRule = function (rule, replacement) {
	    singularRules.push([sanitizeRule(rule), replacement]);
	  };

	  /**
	   * Add an uncountable word rule.
	   *
	   * @param {(string|RegExp)} word
	   */
	  pluralize.addUncountableRule = function (word) {
	    if (typeof word === 'string') {
	      uncountables[word.toLowerCase()] = true;
	      return;
	    }

	    // Set singular and plural references for the word.
	    pluralize.addPluralRule(word, '$0');
	    pluralize.addSingularRule(word, '$0');
	  };

	  /**
	   * Add an irregular word definition.
	   *
	   * @param {String} single
	   * @param {String} plural
	   */
	  pluralize.addIrregularRule = function (single, plural) {
	    plural = plural.toLowerCase();
	    single = single.toLowerCase();

	    irregularSingles[single] = plural;
	    irregularPlurals[plural] = single;
	  };

	  /**
	   * Irregular rules.
	   */
	  [
	    // Pronouns.
	    ['I', 'we'],
	    ['me', 'us'],
	    ['he', 'they'],
	    ['she', 'they'],
	    ['them', 'them'],
	    ['myself', 'ourselves'],
	    ['yourself', 'yourselves'],
	    ['itself', 'themselves'],
	    ['herself', 'themselves'],
	    ['himself', 'themselves'],
	    ['themself', 'themselves'],
	    ['is', 'are'],
	    ['this', 'these'],
	    ['that', 'those'],
	    // Words ending in with a consonant and `o`.
	    ['echo', 'echoes'],
	    ['dingo', 'dingoes'],
	    ['volcano', 'volcanoes'],
	    ['tornado', 'tornadoes'],
	    ['torpedo', 'torpedoes'],
	    // Ends with `us`.
	    ['genus', 'genera'],
	    ['viscus', 'viscera'],
	    // Ends with `ma`.
	    ['stigma', 'stigmata'],
	    ['stoma', 'stomata'],
	    ['dogma', 'dogmata'],
	    ['lemma', 'lemmata'],
	    ['schema', 'schemata'],
	    ['anathema', 'anathemata'],
	    // Other irregular rules.
	    ['ox', 'oxen'],
	    ['axe', 'axes'],
	    ['die', 'dice'],
	    ['yes', 'yeses'],
	    ['foot', 'feet'],
	    ['eave', 'eaves'],
	    ['goose', 'geese'],
	    ['tooth', 'teeth'],
	    ['quiz', 'quizzes'],
	    ['human', 'humans'],
	    ['proof', 'proofs'],
	    ['carve', 'carves'],
	    ['valve', 'valves'],
	    ['thief', 'thieves'],
	    ['genie', 'genies'],
	    ['groove', 'grooves'],
	    ['pickaxe', 'pickaxes'],
	    ['whiskey', 'whiskies']
	  ].forEach(function (rule) {
	    return pluralize.addIrregularRule(rule[0], rule[1]);
	  });

	  /**
	   * Pluralization rules.
	   */
	  [
	    [/s?$/i, 's'],
	    [/([^aeiou]ese)$/i, '$1'],
	    [/(ax|test)is$/i, '$1es'],
	    [/(alias|[^aou]us|tlas|gas|ris)$/i, '$1es'],
	    [/(e[mn]u)s?$/i, '$1s'],
	    [/([^l]ias|[aeiou]las|[emjzr]as|[iu]am)$/i, '$1'],
	    [/(alumn|syllab|octop|vir|radi|nucle|fung|cact|stimul|termin|bacill|foc|uter|loc|strat)(?:us|i)$/i, '$1i'],
	    [/(alumn|alg|vertebr)(?:a|ae)$/i, '$1ae'],
	    [/(seraph|cherub)(?:im)?$/i, '$1im'],
	    [/(her|at|gr)o$/i, '$1oes'],
	    [/(agend|addend|millenni|dat|extrem|bacteri|desiderat|strat|candelabr|errat|ov|symposi|curricul|automat|quor)(?:a|um)$/i, '$1a'],
	    [/(apheli|hyperbat|periheli|asyndet|noumen|phenomen|criteri|organ|prolegomen|hedr|automat)(?:a|on)$/i, '$1a'],
	    [/sis$/i, 'ses'],
	    [/(?:(kni|wi|li)fe|(ar|l|ea|eo|oa|hoo)f)$/i, '$1$2ves'],
	    [/([^aeiouy]|qu)y$/i, '$1ies'],
	    [/([^ch][ieo][ln])ey$/i, '$1ies'],
	    [/(x|ch|ss|sh|zz)$/i, '$1es'],
	    [/(matr|cod|mur|sil|vert|ind|append)(?:ix|ex)$/i, '$1ices'],
	    [/(m|l)(?:ice|ouse)$/i, '$1ice'],
	    [/(pe)(?:rson|ople)$/i, '$1ople'],
	    [/(child)(?:ren)?$/i, '$1ren'],
	    [/eaux$/i, '$0'],
	    [/m[ae]n$/i, 'men'],
	    ['thou', 'you']
	  ].forEach(function (rule) {
	    return pluralize.addPluralRule(rule[0], rule[1]);
	  });

	  /**
	   * Singularization rules.
	   */
	  [
	    [/s$/i, ''],
	    [/(ss)$/i, '$1'],
	    [/((a)naly|(b)a|(d)iagno|(p)arenthe|(p)rogno|(s)ynop|(t)he)(?:sis|ses)$/i, '$1sis'],
	    [/(^analy)(?:sis|ses)$/i, '$1sis'],
	    [/(wi|kni|(?:after|half|high|low|mid|non|night|[^\w]|^)li)ves$/i, '$1fe'],
	    [/(ar|(?:wo|[ae])l|[eo][ao])ves$/i, '$1f'],
	    [/([^aeiouy]|qu)ies$/i, '$1y'],
	    [/(^[pl]|zomb|^(?:neck)?t|[aeo][lt]|cut)ies$/i, '$1ie'],
	    [/(\b(?:mon|smil))ies$/i, '$1ey'],
	    [/(m|l)ice$/i, '$1ouse'],
	    [/(seraph|cherub)im$/i, '$1'],
	    [/(x|ch|ss|sh|zz|tto|go|cho|alias|[^aou]us|tlas|gas|(?:her|at|gr)o|ris)(?:es)?$/i, '$1'],
	    [/(e[mn]u)s?$/i, '$1'],
	    [/(movie|twelve)s$/i, '$1'],
	    [/(cris|test|diagnos)(?:is|es)$/i, '$1is'],
	    [/(alumn|syllab|octop|vir|radi|nucle|fung|cact|stimul|termin|bacill|foc|uter|loc|strat)(?:us|i)$/i, '$1us'],
	    [/(agend|addend|millenni|dat|extrem|bacteri|desiderat|strat|candelabr|errat|ov|symposi|curricul|quor)a$/i, '$1um'],
	    [/(apheli|hyperbat|periheli|asyndet|noumen|phenomen|criteri|organ|prolegomen|hedr|automat)a$/i, '$1on'],
	    [/(alumn|alg|vertebr)ae$/i, '$1a'],
	    [/(cod|mur|sil|vert|ind)ices$/i, '$1ex'],
	    [/(matr|append)ices$/i, '$1ix'],
	    [/(pe)(rson|ople)$/i, '$1rson'],
	    [/(child)ren$/i, '$1'],
	    [/(eau)x?$/i, '$1'],
	    [/men$/i, 'man']
	  ].forEach(function (rule) {
	    return pluralize.addSingularRule(rule[0], rule[1]);
	  });

	  /**
	   * Uncountable rules.
	   */
	  [
	    // Singular words with no plurals.
	    'advice',
	    'agenda',
	    'bison',
	    'bream',
	    'buffalo',
	    'carp',
	    'chassis',
	    'cod',
	    'cooperation',
	    'corps',
	    'digestion',
	    'debris',
	    'diabetes',
	    'energy',
	    'equipment',
	    'elk',
	    'excretion',
	    'expertise',
	    'flounder',
	    'gallows',
	    'garbage',
	    'graffiti',
	    'headquarters',
	    'health',
	    'herpes',
	    'highjinks',
	    'homework',
	    'information',
	    'jeans',
	    'justice',
	    'kudos',
	    'labour',
	    'machinery',
	    'mackerel',
	    'media',
	    'mews',
	    'moose',
	    'news',
	    'pike',
	    'plankton',
	    'pliers',
	    'pollution',
	    'premises',
	    'rain',
	    'rice',
	    'salmon',
	    'scissors',
	    'series',
	    'sewage',
	    'shambles',
	    'shrimp',
	    'species',
	    'staff',
	    'swine',
	    'trout',
	    'tuna',
	    'whiting',
	    'wildebeest',
	    'wildlife',
	    'you',
	    // Regexes.
	    /pox$/i, // "chickpox", "smallpox"
	    /ois$/i,
	    /deer$/i, // "deer", "reindeer"
	    /fish$/i, // "fish", "blowfish", "angelfish"
	    /sheep$/i,
	    /measles$/i,
	    /[^aeiou]ese$/i // "chinese", "japanese"
	  ].forEach(pluralize.addUncountableRule);

	  return pluralize;
	});


/***/ },
/* 68 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(process) {/**
	 * Copyright 2013-2015, Facebook, Inc.
	 * All rights reserved.
	 *
	 * This source code is licensed under the BSD-style license found in the
	 * LICENSE file in the root directory of this source tree. An additional grant
	 * of patent rights can be found in the PATENTS file in the same directory.
	 */

	'use strict';

	/**
	 * Use invariant() to assert state which your program assumes to be true.
	 *
	 * Provide sprintf-style format (only %s is supported) and arguments
	 * to provide information about what broke and what you were
	 * expecting.
	 *
	 * The invariant message will be stripped in production, but the invariant
	 * will remain to ensure logic does not differ in production.
	 */

	var invariant = function(condition, format, a, b, c, d, e, f) {
	  if (process.env.NODE_ENV !== 'production') {
	    if (format === undefined) {
	      throw new Error('invariant requires an error message argument');
	    }
	  }

	  if (!condition) {
	    var error;
	    if (format === undefined) {
	      error = new Error(
	        'Minified exception occurred; use the non-minified dev environment ' +
	        'for the full error message and additional helpful warnings.'
	      );
	    } else {
	      var args = [a, b, c, d, e, f];
	      var argIndex = 0;
	      error = new Error(
	        format.replace(/%s/g, function() { return args[argIndex++]; })
	      );
	      error.name = 'Invariant Violation';
	    }

	    error.framesToPop = 1; // we don't care about invariant's own frame
	    throw error;
	  }
	};

	module.exports = invariant;
	
	/* WEBPACK VAR INJECTION */}.call(exports, __webpack_require__(56)))

/***/ },
/* 69 */
/***/ function(module, exports, __webpack_require__) {

	exports.dot = exports.dotCase = __webpack_require__(109)
	exports.swap = exports.swapCase = __webpack_require__(110)
	exports.path = exports.pathCase = __webpack_require__(112)
	exports.upper = exports.upperCase = __webpack_require__(111)
	exports.lower = exports.lowerCase = __webpack_require__(113)
	exports.camel = exports.camelCase = __webpack_require__(114)
	exports.snake = exports.snakeCase = __webpack_require__(116)
	exports.title = exports.titleCase = __webpack_require__(117)
	exports.param = exports.paramCase = __webpack_require__(115)
	exports.pascal = exports.pascalCase = __webpack_require__(118)
	exports.constant = exports.constantCase = __webpack_require__(119)
	exports.sentence = exports.sentenceCase = __webpack_require__(120)
	exports.isUpper = exports.isUpperCase = __webpack_require__(121)
	exports.isLower = exports.isLowerCase = __webpack_require__(123)
	exports.ucFirst = exports.upperCaseFirst = __webpack_require__(124)
	exports.lcFirst = exports.lowerCaseFirst = __webpack_require__(125)


/***/ },
/* 70 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var loader = __webpack_require__(80);
	var dumper = __webpack_require__(81);
	var YAMLException = (function () {
	    function YAMLException(reason, mark) {
	        if (mark === void 0) { mark = null; }
	        this.name = 'YAMLException';
	        this.reason = reason;
	        this.mark = mark;
	        this.message = this.toString(false);
	    }
	    YAMLException.prototype.toString = function (compact) {
	        if (compact === void 0) { compact = false; }
	        var result;
	        result = 'JS-YAML: ' + (this.reason || '(unknown reason)');
	        if (!compact && this.mark) {
	            result += ' ' + this.mark.toString();
	        }
	        return result;
	    };
	    return YAMLException;
	}());
	exports.YAMLException = YAMLException;
	(function (Kind) {
	    Kind[Kind["SCALAR"] = 0] = "SCALAR";
	    Kind[Kind["MAPPING"] = 1] = "MAPPING";
	    Kind[Kind["MAP"] = 2] = "MAP";
	    Kind[Kind["SEQ"] = 3] = "SEQ";
	    Kind[Kind["ANCHOR_REF"] = 4] = "ANCHOR_REF";
	    Kind[Kind["INCLUDE_REF"] = 5] = "INCLUDE_REF";
	})(exports.Kind || (exports.Kind = {}));
	var Kind = exports.Kind;
	function newMapping(key, value) {
	    var end = (value ? value.endPosition : key.endPosition + 1);
	    var node = {
	        key: key,
	        value: value,
	        startPosition: key.startPosition,
	        endPosition: end,
	        kind: Kind.MAPPING,
	        parent: null,
	        errors: []
	    };
	    return node;
	}
	exports.newMapping = newMapping;
	function newAnchorRef(key, start, end, value) {
	    return {
	        errors: [],
	        referencesAnchor: key,
	        value: value,
	        startPosition: start,
	        endPosition: end,
	        kind: Kind.ANCHOR_REF,
	        parent: null
	    };
	}
	exports.newAnchorRef = newAnchorRef;
	function newScalar(v) {
	    if (v === void 0) { v = ""; }
	    return {
	        errors: [],
	        startPosition: -1,
	        endPosition: -1,
	        value: v,
	        kind: Kind.SCALAR,
	        parent: null,
	        doubleQuoted: false
	    };
	}
	exports.newScalar = newScalar;
	function newItems() {
	    return {
	        errors: [],
	        startPosition: -1,
	        endPosition: -1,
	        items: [],
	        kind: Kind.SEQ,
	        parent: null
	    };
	}
	exports.newItems = newItems;
	function newSeq() {
	    return newItems();
	}
	exports.newSeq = newSeq;
	function newMap(mappings) {
	    return {
	        errors: [],
	        startPosition: -1,
	        endPosition: -1,
	        mappings: mappings ? mappings : [],
	        kind: Kind.MAP,
	        parent: null
	    };
	}
	exports.newMap = newMap;
	function deprecated(name) {
	    return function () {
	        throw new Error('Function ' + name + ' is deprecated and cannot be used.');
	    };
	}
	exports.load = loader.load;
	exports.loadAll = loader.loadAll;
	exports.safeLoad = loader.safeLoad;
	exports.dump = dumper.dump;
	exports.safeDump = dumper.safeDump;
	//# sourceMappingURL=index.js.map

/***/ },
/* 71 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var def = __webpack_require__(33);
	var universes = __webpack_require__(30);
	var universeHelpers = __webpack_require__(14);
	var services = def;
	var search = __webpack_require__(27);
	var AttributeDefaultsCalculator = (function () {
	    /**
	    /**
	     *
	     * @param enabled - if false, defaults calculator will not return defaults from
	     * attrValueOrDefault method, only original values.
	     * @constructor
	     */
	    function AttributeDefaultsCalculator(enabled) {
	        this.enabled = enabled;
	        this.valueCalculators = [
	            new RequiredPropertyCalculator(),
	            new TypePropertyCalculator(),
	            new DisplayNamePropertyCalculator(),
	            new MediaTypeCalculator(),
	            new SecuredByPropertyCalculator(),
	            new ProtocolsPropertyCalculator(),
	            new VersionParamEnumCalculator()
	        ];
	    }
	    /**
	     * Return attribute default value if defaults calculator is enabled.
	     * If attribute value is null or undefined, returns attribute default.
	     */
	    AttributeDefaultsCalculator.prototype.attributeDefaultIfEnabled = function (node, attributeProperty) {
	        if (!this.enabled)
	            return null;
	        return this.getAttributeDefault(node, attributeProperty);
	    };
	    /**
	     * Returns attribute default.
	     */
	    AttributeDefaultsCalculator.prototype.getAttributeDefault = function (node, attributeProperty) {
	        if (!node || !attributeProperty)
	            return null;
	        try {
	            return this.getAttributeDefault2(attributeProperty, node);
	        }
	        catch (Error) {
	            console.log(Error);
	            return null;
	        }
	    };
	    AttributeDefaultsCalculator.prototype.getWrapperAttributeDefault = function (wrapperNode, attributeName) {
	        var highLevelNode = wrapperNode.highLevel();
	        if (highLevelNode == null)
	            return null;
	        var property = highLevelNode.definition().property(attributeName);
	        if (property == null)
	            return null;
	        return this.getAttributeDefault(highLevelNode, property);
	    };
	    /**
	     * Returns attribute default.
	     * There are so many arguments instead of just providing a single AST node and getting
	     * anything we want from it as sometimes we create fake nodes in helpers and thus
	     * do not have actual high-level nodes at hands.
	     */
	    AttributeDefaultsCalculator.prototype.getAttributeDefault2 = function (attributeProperty, node) {
	        for (var i = 0; i < this.valueCalculators.length; i++) {
	            var calculator = this.valueCalculators[i];
	            if (calculator.matches(attributeProperty, node)) {
	                var value = calculator.calculate(attributeProperty, node);
	                if (value != null) {
	                    return value;
	                }
	            }
	        }
	        //static values defined in definition system via defaultValue, defaultIntegerValue
	        // and defaultBooleanValue annotations.
	        if (attributeProperty.defaultValue() != null) {
	            return attributeProperty.defaultValue();
	        }
	        return null;
	    };
	    AttributeDefaultsCalculator.prototype.isEnabled = function () {
	        return this.enabled;
	    };
	    AttributeDefaultsCalculator.prototype.insertionKind = function (node, attributeProperty) {
	        for (var i = 0; i < this.valueCalculators.length; i++) {
	            var calculator = this.valueCalculators[i];
	            if (calculator.matches(attributeProperty, node)) {
	                return calculator.kind();
	            }
	        }
	        if (attributeProperty.defaultValue() != null) {
	            return InsertionKind.BY_DEFAULT;
	        }
	        return null;
	    };
	    return AttributeDefaultsCalculator;
	}());
	exports.AttributeDefaultsCalculator = AttributeDefaultsCalculator;
	(function (InsertionKind) {
	    InsertionKind[InsertionKind["CALCULATED"] = 0] = "CALCULATED";
	    InsertionKind[InsertionKind["BY_DEFAULT"] = 1] = "BY_DEFAULT";
	})(exports.InsertionKind || (exports.InsertionKind = {}));
	var InsertionKind = exports.InsertionKind;
	var MediaTypeCalculator = (function () {
	    function MediaTypeCalculator() {
	    }
	    MediaTypeCalculator.prototype.calculate = function (attributeProperty, node) {
	        var root = search.declRoot(node);
	        if (root && universeHelpers.isApiSibling(root.definition())) {
	            var defaultMediaTypeAttr = root.attr(universes.Universe10.Api.properties.mediaType.name);
	            if (defaultMediaTypeAttr) {
	                return defaultMediaTypeAttr.value();
	            }
	        }
	        return null;
	    };
	    MediaTypeCalculator.prototype.matches = function (attributeProperty, node) {
	        if (!universeHelpers.isNameProperty(attributeProperty)) {
	            return false;
	        }
	        var nodeDefinition = node.definition();
	        if (!nodeDefinition) {
	            return false;
	        }
	        if (!(universeHelpers.isBodyLikeType(nodeDefinition)
	            || universeHelpers.isTypeDeclarationSibling(nodeDefinition))) {
	            return false;
	        }
	        var parentNode = node.parent();
	        if (parentNode == null) {
	            return false;
	        }
	        var parentDefinition = parentNode.definition();
	        if (parentDefinition == null) {
	            return false;
	        }
	        if (!(universeHelpers.isResponseType(parentDefinition)
	            || universeHelpers.isMethodBaseSibling(parentDefinition))) {
	            return false;
	        }
	        var ancestor = parentNode;
	        while (ancestor) {
	            var aDef = ancestor.definition();
	            if (universeHelpers.isTraitType(aDef)) {
	                return false;
	            }
	            if (universeHelpers.isResourceTypeType(aDef)) {
	                return false;
	            }
	            ancestor = ancestor.parent();
	        }
	        return true;
	    };
	    MediaTypeCalculator.prototype.kind = function () {
	        return InsertionKind.CALCULATED;
	    };
	    return MediaTypeCalculator;
	}());
	var DisplayNamePropertyCalculator = (function () {
	    function DisplayNamePropertyCalculator() {
	    }
	    DisplayNamePropertyCalculator.prototype.calculate = function (attributeProperty, node) {
	        var nodeDefinition = node.definition();
	        if (nodeDefinition == null) {
	            return null;
	        }
	        var adapter = nodeDefinition.getAdapter(services.RAMLService);
	        var keyProperty = adapter.getKeyProp();
	        if (keyProperty != null) {
	            var attributeValue = node.attrValue(keyProperty.nameId());
	            if (attributeValue != null) {
	                return attributeValue;
	            }
	            else {
	                return new AttributeDefaultsCalculator(true).getAttributeDefault(node, keyProperty);
	            }
	        }
	        return null;
	    };
	    DisplayNamePropertyCalculator.prototype.matches = function (attributeProperty, node) {
	        var nodeDefinition = node.definition();
	        if (nodeDefinition == null) {
	            return false;
	        }
	        return (universeHelpers.isTypeDeclarationSibling(nodeDefinition)
	            || nodeDefinition.isAssignableFrom(universes.Universe08.Parameter.name)
	            || universeHelpers.isResourceType(nodeDefinition))
	            && universeHelpers.isDisplayNameProperty(attributeProperty);
	    };
	    DisplayNamePropertyCalculator.prototype.kind = function () {
	        return InsertionKind.CALCULATED;
	    };
	    return DisplayNamePropertyCalculator;
	}());
	var TypePropertyCalculator = (function () {
	    function TypePropertyCalculator() {
	    }
	    TypePropertyCalculator.prototype.calculate = function (attributeProperty, node) {
	        return "object";
	    };
	    TypePropertyCalculator.prototype.matches = function (attributeProperty, node) {
	        return universeHelpers.isTypeProperty(attributeProperty)
	            && node.definition() != null
	            && universeHelpers.isObjectTypeDeclarationSibling(node.definition());
	    };
	    TypePropertyCalculator.prototype.kind = function () {
	        return InsertionKind.BY_DEFAULT;
	    };
	    return TypePropertyCalculator;
	}());
	var RequiredPropertyCalculator = (function () {
	    function RequiredPropertyCalculator() {
	    }
	    RequiredPropertyCalculator.prototype.calculate = function (attributeProperty, node) {
	        var nodeDefinition = node.definition();
	        var nodeProperty = node.property();
	        if (nodeDefinition == null) {
	            return null;
	        }
	        //if node key is ending with question mark, it optional, thus its "required" == false
	        var adapter = nodeDefinition.getAdapter(services.RAMLService);
	        var keyProperty = adapter.getKeyProp();
	        if (keyProperty != null) {
	            var attribute = node.attr(keyProperty.nameId());
	            if (attribute != null && attribute.optional()) {
	                return false;
	            }
	        }
	        if (nodeProperty != null) {
	            //the spec is unclear with regard to this parameter, but for now it looks like:
	            //for query string parameters, form parameters, and request and response headers the default is false
	            //for URI parameters the default is true
	            //for base URI parameters - unclear, but according to old JS parser behavior it looks like the default is true
	            //for all other entities we back drop to what definition system states
	            if (universeHelpers.isHeadersProperty(nodeProperty) ||
	                universeHelpers.isFormParametersProperty(nodeProperty) ||
	                universeHelpers.isQueryParametersProperty(nodeProperty)) {
	                if (attributeProperty.domain().universe().version() == "RAML08") {
	                    return false;
	                }
	                return true;
	            }
	            else if (universeHelpers.isUriParametersProperty(nodeProperty) ||
	                universeHelpers.isBaseUriParametersProperty(nodeProperty)) {
	                return true;
	            }
	        }
	        if (attributeProperty.defaultValue() != null) {
	            return attributeProperty.defaultValue();
	        }
	        return null;
	    };
	    RequiredPropertyCalculator.prototype.matches = function (attributeProperty, node) {
	        return universeHelpers.isRequiredProperty(attributeProperty);
	    };
	    RequiredPropertyCalculator.prototype.kind = function () {
	        return InsertionKind.BY_DEFAULT;
	    };
	    return RequiredPropertyCalculator;
	}());
	var SecuredByPropertyCalculator = (function () {
	    function SecuredByPropertyCalculator() {
	    }
	    SecuredByPropertyCalculator.prototype.calculate = function (attributeProperty, node) {
	        if (universeHelpers.isApiSibling(node.definition())) {
	            return null;
	        }
	        var values;
	        //instanceof, but have to avoid direct usage of instanceof in JS.
	        var definition = node.definition();
	        if (universeHelpers.isMethodType(definition)) {
	            var resource = node.parent();
	            if (resource) {
	                values = resource.wrapperNode().securedBy();
	            }
	        }
	        if (!values || values.length == 0) {
	            while (node != null && !universeHelpers.isApiSibling(node.definition())) {
	                node = node.parent();
	            }
	            if (node) {
	                values = node.wrapperNode().securedBy();
	            }
	        }
	        if (values && values.length > 0) {
	            return values;
	        }
	        return null;
	    };
	    SecuredByPropertyCalculator.prototype.matches = function (attributeProperty, node) {
	        var nodeDefinition = node.definition();
	        if (nodeDefinition == null) {
	            return false;
	        }
	        return universeHelpers.isSecuredByProperty(attributeProperty);
	    };
	    SecuredByPropertyCalculator.prototype.kind = function () {
	        return InsertionKind.CALCULATED;
	    };
	    return SecuredByPropertyCalculator;
	}());
	var ProtocolsPropertyCalculator = (function () {
	    function ProtocolsPropertyCalculator() {
	    }
	    ProtocolsPropertyCalculator.prototype.calculate = function (attributeProperty, node) {
	        while (node != null && !universeHelpers.isApiSibling(node.definition())) {
	            node = node.parent();
	        }
	        var result;
	        var baseUriAttr = node.attr(universes.Universe10.Api.properties.baseUri.name);
	        if (baseUriAttr) {
	            var baseUri = baseUriAttr.value();
	            if (baseUri) {
	                var ind = baseUri.indexOf('://');
	                if (ind >= 0) {
	                    result = [baseUri.substring(0, ind).toUpperCase()];
	                }
	                if (!result) {
	                    result = ['HTTP'];
	                }
	            }
	        }
	        return result;
	    };
	    ProtocolsPropertyCalculator.prototype.matches = function (attributeProperty, node) {
	        if (!universeHelpers.isProtocolsProperty(attributeProperty)) {
	            return false;
	        }
	        var nodeDefinition = node.definition();
	        var hasAppropriateLocation = false;
	        if (universeHelpers.isApiSibling(nodeDefinition)) {
	            hasAppropriateLocation = true;
	        }
	        else if (universeHelpers.isResourceType(nodeDefinition)) {
	            hasAppropriateLocation = true;
	        }
	        else if (universeHelpers.isMethodType(nodeDefinition)) {
	            var parentNode = node.parent();
	            hasAppropriateLocation = parentNode && universeHelpers.isResourceType(parentNode.definition());
	        }
	        return hasAppropriateLocation;
	    };
	    ProtocolsPropertyCalculator.prototype.kind = function () {
	        return InsertionKind.CALCULATED;
	    };
	    return ProtocolsPropertyCalculator;
	}());
	var VersionParamEnumCalculator = (function () {
	    function VersionParamEnumCalculator() {
	    }
	    VersionParamEnumCalculator.prototype.calculate = function (attributeProperty, node) {
	        while (node != null && !universeHelpers.isApiSibling(node.definition())) {
	            node = node.parent();
	        }
	        var versionAttr = node.attr(universes.Universe10.Api.properties.version.name);
	        if (versionAttr) {
	            var versionValue = versionAttr.value();
	            if (versionValue && versionValue.trim()) {
	                return [versionValue];
	            }
	        }
	        return null;
	    };
	    VersionParamEnumCalculator.prototype.matches = function (attributeProperty, node) {
	        if (!universeHelpers.isEnumProperty(attributeProperty)) {
	            return false;
	        }
	        var nodeProperty = node.property();
	        if (!nodeProperty) {
	            return false;
	        }
	        if (!universeHelpers.isBaseUriParametersProperty(nodeProperty)) {
	            return false;
	        }
	        var nameAttr = node.attr(universes.Universe10.TypeDeclaration.properties.name.name);
	        var paramName = nameAttr && nameAttr.value();
	        if (paramName != 'version') {
	            return false;
	        }
	        return true;
	    };
	    VersionParamEnumCalculator.prototype.kind = function () {
	        return InsertionKind.CALCULATED;
	    };
	    return VersionParamEnumCalculator;
	}());
	//# sourceMappingURL=defaultCalculator.js.map

/***/ },
/* 72 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var __extends = (this && this.__extends) || function (d, b) {
	    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
	    function __() { this.constructor = d; }
	    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
	};
	/// <reference path="../../typings/main.d.ts" />
	var universe = __webpack_require__(30);
	var core = __webpack_require__(50);
	var def = __webpack_require__(33);
	var hlImpl = __webpack_require__(16);
	var builder = __webpack_require__(26);
	var universeHelpers = __webpack_require__(14);
	var universes = __webpack_require__(30);
	var RamlWrapper10 = __webpack_require__(12);
	function dump(node, serializeMeta) {
	    if (serializeMeta === void 0) { serializeMeta = true; }
	    return new TCKDumper({
	        rootNodeDetails: true,
	        serializeMetadata: serializeMeta
	    }).dump(node);
	}
	exports.dump = dump;
	var TCKDumper = (function () {
	    function TCKDumper(options) {
	        this.options = options;
	        this.nodeTransformers = [
	            new ResourcesTransformer(),
	            new TypeExampleTransformer(),
	            //new ParametersTransformer(),
	            new TypesTransformer(),
	            //new UsesTransformer(),
	            //new PropertiesTransformer(),
	            //new ExamplesTransformer(),
	            //new ResponsesTransformer(),
	            //new BodiesTransformer(),
	            //new AnnotationsTransformer(),
	            new SecuritySchemesTransformer(),
	            new AnnotationTypesTransformer(),
	            new TemplateParametrizedPropertiesTransformer(),
	            new TraitsTransformer(),
	            new ResourceTypesTransformer(),
	            //new FacetsTransformer(),
	            new SchemasTransformer(),
	            new ProtocolsToUpperCaseTransformer(),
	            new ResourceTypeMethodsToMapTransformer(),
	            new ReferencesTransformer(),
	        ];
	        this.nodePropertyTransformers = [
	            //new ResourcesTransformer(),
	            //new TypeExampleTransformer(),
	            new ParametersTransformer(),
	            //new TypesTransformer(),
	            //new UsesTransformer(),
	            new PropertiesTransformer(),
	            // //new ExamplesTransformer(),
	            new ResponsesTransformer(),
	            new BodiesTransformer(),
	            new AnnotationsTransformer(),
	            //new SecuritySchemesTransformer(),
	            //new AnnotationTypesTransformer(),
	            //new TemplateParametrizedPropertiesTransformer(),
	            //new TraitsTransformer(),
	            //new ResourceTypesTransformer(),
	            new FacetsTransformer(),
	            //new SchemasTransformer(),
	            //new ProtocolsToUpperCaseTransformer(),
	            //new ResourceTypeMethodsToMapTransformer(),
	            //new ReferencesTransformer(),
	            new OneElementArrayTransformer()
	        ];
	        this.ignore = new CompositeObjectPropertyMatcher([
	            new BasicObjectPropertyMatcher(universeHelpers.isResponseType, universeHelpers.isDisplayNameProperty),
	            new BasicObjectPropertyMatcher(universeHelpers.isApiSibling, universeHelpers.isDisplayNameProperty),
	            new BasicObjectPropertyMatcher(universeHelpers.isAnnotationRefTypeOrDescendant, universeHelpers.isAnnotationProperty),
	            new BasicObjectPropertyMatcher(universeHelpers.isSecuritySchemeRefType, universeHelpers.isSecuritySchemeProperty),
	            new BasicObjectPropertyMatcher(universeHelpers.isTraitRefType, universeHelpers.isTraitProperty),
	            new BasicObjectPropertyMatcher(universeHelpers.isResourceTypeRefType, universeHelpers.isResourceTypeProperty),
	            new BasicObjectPropertyMatcher(universeHelpers.isApiSibling, universeHelpers.isRAMLVersionProperty)
	        ]);
	        this.missingProperties = new PropertiesData();
	        this.options = this.options || {};
	        if (this.options.serializeMetadata == null) {
	            this.options.serializeMetadata = true;
	        }
	    }
	    TCKDumper.prototype.printMissingProperties = function () {
	        return this.missingProperties.print();
	    };
	    TCKDumper.prototype.dump = function (node) {
	        var highLevelNode = node.highLevel();
	        var highLevelParent = highLevelNode && highLevelNode.parent();
	        var rootNodeDetails = !highLevelParent && this.options.rootNodeDetails;
	        return this.dumpInternal(node, rootNodeDetails);
	    };
	    TCKDumper.prototype.dumpInternal = function (node, rootNodeDetails) {
	        var _this = this;
	        if (rootNodeDetails === void 0) { rootNodeDetails = false; }
	        if (node == null) {
	            return null;
	        }
	        if (node instanceof core.BasicNodeImpl) {
	            var props = {};
	            var basicNode = node;
	            var definition = basicNode.highLevel().definition();
	            definition.allProperties().filter(function (x) { return !_this.ignore.match(basicNode.definition(), x); }).forEach(function (x) {
	                props[x.nameId()] = x;
	            });
	            definition.allCustomProperties().filter(function (x) { return !_this.ignore.match(basicNode.definition(), x); }).forEach(function (x) {
	                props[x.nameId()] = x;
	            });
	            var obj = this.dumpProperties(props, node);
	            if (props["schema"]) {
	                if (this.options.dumpSchemaContents) {
	                    if (props["schema"].range().key() == universes.Universe08.SchemaString) {
	                        var schemas = basicNode.highLevel().root().elementsOfKind("schemas");
	                        schemas.forEach(function (x) {
	                            if (x.name() == obj["schema"]) {
	                                var vl = x.attr("value");
	                                if (vl) {
	                                    obj["schema"] = vl.value();
	                                    obj["schemaContent"] = vl.value();
	                                }
	                            }
	                        });
	                    }
	                }
	            }
	            this.serializeScalarsAnnotations(obj, basicNode, props);
	            this.serializeMeta(obj, basicNode);
	            if (this.canBeFragment(node)) {
	                if (RamlWrapper10.isFragment(node)) {
	                    var fragment = RamlWrapper10.asFragment(node);
	                    var uses = fragment.uses();
	                    if (uses.length > 0) {
	                        obj["uses"] = uses.map(function (x) { return x.toJSON(); });
	                    }
	                }
	            }
	            this.nodeTransformers.forEach(function (x) {
	                if (x.match(node, node.highLevel().property())) {
	                    obj = x.transform(obj);
	                }
	            });
	            var result = {};
	            if (rootNodeDetails) {
	                if (definition) {
	                    var ramlVersion = definition.universe().version();
	                    result.ramlVersion = ramlVersion;
	                    result.type = definition.nameId();
	                }
	                result.specification = obj;
	                result.errors = this.dumpErrors(basicNode.errors());
	            }
	            else {
	                result = obj;
	            }
	            return result;
	        }
	        else if (node instanceof core.AttributeNodeImpl) {
	            var props = {};
	            var attrNode = node;
	            var definition = attrNode.highLevel().definition();
	            definition.allCustomProperties().filter(function (x) { return !_this.ignore.match(attrNode.highLevel().property().range(), x); }).forEach(function (x) {
	                props[x.nameId()] = x;
	            });
	            var isValueType = attrNode.highLevel().property().range().isValueType();
	            if (isValueType && attrNode['value']) {
	                var val = attrNode['value']();
	                if (typeof val == 'number' || typeof val == 'string' || typeof val == 'boolean') {
	                    return val;
	                }
	            }
	            var obj = this.dumpProperties(props, node);
	            this.nodeTransformers.forEach(function (x) {
	                if (x.match(node, node.highLevel().property())) {
	                    obj = x.transform(obj);
	                }
	            });
	            this.serializeScalarsAnnotations(obj, node, props);
	            this.serializeMeta(obj, attrNode);
	            return obj;
	        }
	        else if (node instanceof core.TypeInstanceImpl) {
	            return this.serializeTypeInstance(node);
	        }
	        else if (node instanceof core.TypeInstancePropertyImpl) {
	            return this.serializeTypeInstanceProperty(node);
	        }
	        return node;
	    };
	    TCKDumper.prototype.canBeFragment = function (node) {
	        var definition = node.definition();
	        var arr = [definition].concat(definition.allSubTypes());
	        var arr1 = arr.filter(function (x) { return x.getAdapter(def.RAMLService).possibleInterfaces()
	            .filter(function (y) { return y.nameId() == def.universesInfo.Universe10.FragmentDeclaration.name; }).length > 0; });
	        return arr1.length > 0;
	    };
	    TCKDumper.prototype.dumpErrors = function (errors) {
	        return errors.map(function (x) {
	            return {
	                "code": x.code,
	                "message": x.message,
	                "path": x.path,
	                "line": x.line,
	                "column": x.column,
	                "position": x.start,
	                "range": x.range
	            };
	        }).sort(function (x, y) {
	            if (x.path != y.path) {
	                return x.path.localeCompare(y.path);
	            }
	            if (x.position != y.position) {
	                return x.position - y.position;
	            }
	            return x.code - y.code;
	        });
	    };
	    TCKDumper.prototype.dumpProperties = function (props, node) {
	        var _this = this;
	        var obj = {};
	        Object.keys(props).forEach(function (propName) {
	            if (!node[propName]) {
	                _this.missingProperties.addProperty(props[propName], node.kind());
	                return;
	            }
	            var property = props[propName];
	            var value = node[propName]();
	            if (value && propName == "structuredType" && typeof value === "object") {
	                value = null;
	                var highLevelNode = node.highLevel();
	                var a = highLevelNode.lowLevel();
	                var tdl = null;
	                a.children().forEach(function (x) {
	                    if (x.key() == "type" || x.key() == "schema") {
	                        var td = highLevelNode.definition().universe().type(universe.Universe10.TypeDeclaration.name);
	                        var hasType = highLevelNode.definition().universe().type(universe.Universe10.LibraryBase.name);
	                        var tNode = new hlImpl.ASTNodeImpl(x, highLevelNode, td, hasType.property(universe.Universe10.LibraryBase.properties.types.name));
	                        tNode.patchType(builder.doDescrimination(tNode));
	                        value = dump(tNode.wrapperNode());
	                        propName = x.key();
	                    }
	                });
	            }
	            if (!value && propName == "type") {
	                return;
	            }
	            if (!value && propName == "schema") {
	                return;
	            }
	            if (node.definition
	                && universeHelpers.isTypeDeclarationSibling(node.definition())
	                && universeHelpers.isTypeProperty(property)) {
	                //custom handling of not adding "type" property to the types having "schema" inside, even though the property actually exist,
	                // thus making "type" and "schema" arrays mutually exclusive in JSON.
	                var schemaValue = node[universe.Universe10.TypeDeclaration.properties.schema.name]();
	                if (schemaValue != null && (!Array.isArray(schemaValue) || schemaValue.length != 0)) {
	                    return;
	                }
	                var highLevelNode = node.highLevel();
	                var a = highLevelNode.lowLevel();
	                var tdl = null;
	                var hasSchema = false;
	                a.children().forEach(function (x) {
	                    if (x.key() == "schema") {
	                        hasSchema = true;
	                        return;
	                    }
	                });
	                if (hasSchema) {
	                    return;
	                }
	            }
	            if (Array.isArray(value)) {
	                var propertyValue = [];
	                for (var _i = 0, value_1 = value; _i < value_1.length; _i++) {
	                    var val = value_1[_i];
	                    var dumped = _this.dumpInternal(val);
	                    if (propName === 'examples' && _this.options && _this.options.dumpXMLRepresentationOfExamples && val.expandable && val.expandable._owner) {
	                        dumped.asXMLString = val.expandable.asXMLString();
	                    }
	                    propertyValue.push(dumped);
	                }
	                if (propertyValue.length == 0 && node instanceof core.BasicNodeImpl && !_this.isDefined(node, propName)) {
	                    return;
	                }
	                for (var _a = 0, _b = _this.nodePropertyTransformers; _a < _b.length; _a++) {
	                    var x = _b[_a];
	                    if (x.match(node, property)) {
	                        propertyValue = x.transform(propertyValue);
	                    }
	                }
	                obj[propName] = propertyValue;
	            }
	            else {
	                var val = _this.dumpInternal(value);
	                if (val == null && node instanceof core.BasicNodeImpl && !_this.isDefined(node, propName)) {
	                    return;
	                }
	                if (node instanceof core.BasicNodeImpl) {
	                    _this.nodePropertyTransformers.forEach(function (x) {
	                        if (x.match(node, property)) {
	                            val = x.transform(val);
	                        }
	                    });
	                }
	                obj[propName] = val;
	                if (propName === 'example' && _this.options && _this.options.dumpXMLRepresentationOfExamples && value.expandable && value.expandable._owner) {
	                    val.asXMLString = value.expandable.asXMLString();
	                }
	            }
	        });
	        return obj;
	    };
	    TCKDumper.prototype.serializeScalarsAnnotations = function (obj, node, props) {
	        var _this = this;
	        if (node["scalarsAnnotations"]) {
	            var val = {};
	            var accessor = node["scalarsAnnotations"]();
	            for (var _i = 0, _a = Object.keys(props); _i < _a.length; _i++) {
	                var propName = _a[_i];
	                if (accessor[propName]) {
	                    var arr = accessor[propName]();
	                    if (arr.length > 0) {
	                        if (Array.isArray(arr[0])) {
	                            var arr1 = [];
	                            arr.forEach(function (x, i) { arr1.push(x.map(function (y) { return _this.dumpInternal(y); })); });
	                            if (arr1.filter(function (x) { return x.length > 0; }).length > 0) {
	                                val[propName] = arr1;
	                            }
	                        }
	                        else {
	                            val[propName] = arr.map(function (x) { return _this.dumpInternal(x); });
	                        }
	                    }
	                }
	            }
	            if (Object.keys(val).length > 0) {
	                obj["scalarsAnnotations"] = val;
	            }
	        }
	    };
	    TCKDumper.prototype.serializeMeta = function (obj, node) {
	        if (!this.options.serializeMetadata) {
	            return;
	        }
	        var meta = node.meta();
	        if (!meta.isDefault()) {
	            obj["__METADATA__"] = meta.toJSON();
	        }
	    };
	    TCKDumper.prototype.serializeTypeInstance = function (inst) {
	        var _this = this;
	        if (inst.isScalar()) {
	            return inst.value();
	        }
	        else {
	            var props = inst.properties();
	            if (props.length == 0) {
	                return null;
	            }
	            var obj = {};
	            props.forEach(function (x) { return obj[x.name()] = _this.serializeTypeInstanceProperty(x); });
	            return obj;
	        }
	    };
	    TCKDumper.prototype.serializeTypeInstanceProperty = function (prop) {
	        var _this = this;
	        if (prop.isArray()) {
	            var values = prop.values();
	            //if(values.length==0){
	            //    return null;
	            //}
	            var arr = [];
	            values.forEach(function (x) { return arr.push(_this.serializeTypeInstance(x)); });
	            return arr;
	        }
	        else {
	            return this.serializeTypeInstance(prop.value());
	        }
	    };
	    TCKDumper.prototype.isDefined = function (node, name) {
	        var hl = node.highLevel();
	        if (hl.elementsOfKind(name).length > 0) {
	            return true;
	        }
	        if (hl.attributes(name).length > 0) {
	            return true;
	        }
	        return false;
	    };
	    return TCKDumper;
	}());
	exports.TCKDumper = TCKDumper;
	var BasicObjectPropertyMatcher = (function () {
	    function BasicObjectPropertyMatcher(typeMatcher, propMatcher) {
	        this.typeMatcher = typeMatcher;
	        this.propMatcher = propMatcher;
	    }
	    BasicObjectPropertyMatcher.prototype.match = function (td, prop) {
	        return (td == null || this.typeMatcher(td)) && ((prop == null) || this.propMatcher(prop));
	    };
	    return BasicObjectPropertyMatcher;
	}());
	var CompositeObjectPropertyMatcher = (function () {
	    function CompositeObjectPropertyMatcher(matchers) {
	        this.matchers = matchers;
	    }
	    CompositeObjectPropertyMatcher.prototype.match = function (td, prop) {
	        var l = this.matchers.length;
	        for (var i = 0; i < l; i++) {
	            if (this.matchers[i].match(td, prop)) {
	                return true;
	            }
	        }
	        return false;
	    };
	    return CompositeObjectPropertyMatcher;
	}());
	var ArrayToMapTransformer = (function () {
	    function ArrayToMapTransformer(matcher, propName) {
	        this.matcher = matcher;
	        this.propName = propName;
	    }
	    ArrayToMapTransformer.prototype.match = function (node, prop) {
	        return this.matcher.match(node.definition(), prop);
	    };
	    ArrayToMapTransformer.prototype.transform = function (value) {
	        var _this = this;
	        if (Array.isArray(value) && value.length > 0 && value[0][this.propName]) {
	            var obj = {};
	            value.forEach(function (x) {
	                var key = x[_this.propName];
	                var previous = obj[key];
	                if (previous) {
	                    if (Array.isArray(previous)) {
	                        previous.push(x);
	                    }
	                    else {
	                        obj[key] = [previous, x];
	                    }
	                }
	                else {
	                    obj[key] = x;
	                }
	            });
	            return obj;
	        }
	        return value;
	    };
	    return ArrayToMapTransformer;
	}());
	var ArrayToMappingsArrayTransformer = (function () {
	    function ArrayToMappingsArrayTransformer(matcher, propName) {
	        this.matcher = matcher;
	        this.propName = propName;
	    }
	    ArrayToMappingsArrayTransformer.prototype.match = function (node, prop) {
	        return this.matcher.match(node.definition ? node.definition() : null, prop);
	    };
	    ArrayToMappingsArrayTransformer.prototype.transform = function (value) {
	        if (Array.isArray(value)) {
	            return value;
	        }
	        else {
	            var obj = {};
	            obj[value[this.propName]] = value;
	            return obj;
	        }
	    };
	    return ArrayToMappingsArrayTransformer;
	}());
	var ParametersTransformer = (function (_super) {
	    __extends(ParametersTransformer, _super);
	    function ParametersTransformer() {
	        _super.call(this, new CompositeObjectPropertyMatcher([
	            new BasicObjectPropertyMatcher(universeHelpers.isApiSibling, universeHelpers.isBaseUriParametersProperty),
	            new BasicObjectPropertyMatcher(universeHelpers.isResourceBaseSibling, universeHelpers.isUriParametersProperty),
	            new BasicObjectPropertyMatcher(universeHelpers.isResourceBaseSibling, universeHelpers.isQueryParametersProperty),
	            new BasicObjectPropertyMatcher(universeHelpers.isTraitType, universeHelpers.isQueryParametersProperty),
	            new BasicObjectPropertyMatcher(universeHelpers.isMethodType, universeHelpers.isQueryParametersProperty),
	            new BasicObjectPropertyMatcher(universeHelpers.isSecuritySchemePartType, universeHelpers.isQueryParametersProperty),
	            new BasicObjectPropertyMatcher(universeHelpers.isTraitType, universeHelpers.isHeadersProperty),
	            new BasicObjectPropertyMatcher(universeHelpers.isMethodType, universeHelpers.isHeadersProperty),
	            new BasicObjectPropertyMatcher(universeHelpers.isSecuritySchemePartType, universeHelpers.isHeadersProperty),
	            new BasicObjectPropertyMatcher(universeHelpers.isBodyLikeType, universeHelpers.isFormParametersProperty)
	        ]), "name");
	    }
	    return ParametersTransformer;
	}(ArrayToMapTransformer));
	var TypesTransformer = (function (_super) {
	    __extends(TypesTransformer, _super);
	    function TypesTransformer() {
	        _super.call(this, new CompositeObjectPropertyMatcher([
	            new BasicObjectPropertyMatcher(universeHelpers.isLibraryBaseSibling, universeHelpers.isTypesProperty),
	            new BasicObjectPropertyMatcher(function (x) { return universeHelpers.isLibraryBaseSibling(x) && universeHelpers.isRAML10Type(x); }, universeHelpers.isSchemasProperty)
	        ]), "name");
	    }
	    TypesTransformer.prototype.match = function (node, prop) {
	        return node.parent() != null && this.matcher.match(node.parent().definition(), prop);
	    };
	    return TypesTransformer;
	}(ArrayToMappingsArrayTransformer));
	var UsesTransformer = (function (_super) {
	    __extends(UsesTransformer, _super);
	    function UsesTransformer() {
	        _super.call(this, new CompositeObjectPropertyMatcher([
	            new BasicObjectPropertyMatcher(universeHelpers.isLibraryBaseSibling, universeHelpers.isUsesProperty)
	        ]), "name");
	    }
	    return UsesTransformer;
	}(ArrayToMapTransformer));
	var PropertiesTransformer = (function (_super) {
	    __extends(PropertiesTransformer, _super);
	    function PropertiesTransformer() {
	        _super.call(this, new CompositeObjectPropertyMatcher([
	            new BasicObjectPropertyMatcher(universeHelpers.isObjectTypeDeclarationSibling, universeHelpers.isPropertiesProperty)
	        ]), "name");
	    }
	    return PropertiesTransformer;
	}(ArrayToMapTransformer));
	var ResponsesTransformer = (function (_super) {
	    __extends(ResponsesTransformer, _super);
	    function ResponsesTransformer() {
	        _super.call(this, new CompositeObjectPropertyMatcher([
	            new BasicObjectPropertyMatcher(universeHelpers.isMethodBaseSibling, universeHelpers.isResponsesProperty)
	        ]), "code");
	    }
	    return ResponsesTransformer;
	}(ArrayToMapTransformer));
	var AnnotationsTransformer = (function (_super) {
	    __extends(AnnotationsTransformer, _super);
	    function AnnotationsTransformer() {
	        _super.call(this, new CompositeObjectPropertyMatcher([
	            new BasicObjectPropertyMatcher(function (x) { return true; }, universeHelpers.isAnnotationsProperty)
	        ]), "name");
	    }
	    return AnnotationsTransformer;
	}(ArrayToMapTransformer));
	var BodiesTransformer = (function (_super) {
	    __extends(BodiesTransformer, _super);
	    function BodiesTransformer() {
	        _super.call(this, new CompositeObjectPropertyMatcher([
	            new BasicObjectPropertyMatcher(universeHelpers.isResponseType, universeHelpers.isBodyProperty),
	            new BasicObjectPropertyMatcher(universeHelpers.isMethodBaseSibling, universeHelpers.isBodyProperty)
	        ]), "name");
	    }
	    return BodiesTransformer;
	}(ArrayToMapTransformer));
	var TraitsTransformer = (function (_super) {
	    __extends(TraitsTransformer, _super);
	    function TraitsTransformer() {
	        _super.call(this, new CompositeObjectPropertyMatcher([
	            new BasicObjectPropertyMatcher(universeHelpers.isTraitType, universeHelpers.isTraitsProperty)
	        ]), "name");
	    }
	    return TraitsTransformer;
	}(ArrayToMappingsArrayTransformer));
	var ResourceTypesTransformer = (function (_super) {
	    __extends(ResourceTypesTransformer, _super);
	    function ResourceTypesTransformer() {
	        _super.call(this, new CompositeObjectPropertyMatcher([
	            new BasicObjectPropertyMatcher(universeHelpers.isResourceTypeType, universeHelpers.isResourceTypesProperty)
	        ]), "name");
	    }
	    ResourceTypesTransformer.prototype.transform = function (value) {
	        var methodsPropertyName = universes.Universe10.ResourceBase.properties.methods.name;
	        if (Array.isArray(value)) {
	            return value;
	        }
	        else {
	            var methods = value[methodsPropertyName];
	            if (methods) {
	                methods.forEach(function (m) {
	                    var keys = Object.keys(m);
	                    if (keys.length > 0) {
	                        var methodName = keys[0];
	                        value[methodName] = m[methodName];
	                    }
	                });
	            }
	            delete value[methodsPropertyName];
	            return _super.prototype.transform.call(this, value);
	        }
	    };
	    return ResourceTypesTransformer;
	}(ArrayToMappingsArrayTransformer));
	var FacetsTransformer = (function (_super) {
	    __extends(FacetsTransformer, _super);
	    function FacetsTransformer() {
	        _super.call(this, new CompositeObjectPropertyMatcher([
	            new BasicObjectPropertyMatcher(universeHelpers.isTypeDeclarationSibling, universeHelpers.isFacetsProperty)
	        ]), "name");
	    }
	    return FacetsTransformer;
	}(ArrayToMapTransformer));
	var SecuritySchemesTransformer = (function (_super) {
	    __extends(SecuritySchemesTransformer, _super);
	    function SecuritySchemesTransformer() {
	        _super.call(this, null, "name");
	    }
	    SecuritySchemesTransformer.prototype.match = function (node, prop) {
	        return prop != null && universeHelpers.isSecuritySchemesProperty(prop);
	    };
	    return SecuritySchemesTransformer;
	}(ArrayToMappingsArrayTransformer));
	var AnnotationTypesTransformer = (function (_super) {
	    __extends(AnnotationTypesTransformer, _super);
	    function AnnotationTypesTransformer() {
	        _super.call(this, new CompositeObjectPropertyMatcher([
	            new BasicObjectPropertyMatcher(universeHelpers.isLibraryBaseSibling, universeHelpers.isAnnotationTypesProperty)
	        ]), "displayName");
	    }
	    AnnotationTypesTransformer.prototype.match = function (node, prop) {
	        return node.parent() != null && this.matcher.match(node.parent().definition(), prop);
	    };
	    return AnnotationTypesTransformer;
	}(ArrayToMappingsArrayTransformer));
	var ResourceTypeMethodsToMapTransformer = (function (_super) {
	    __extends(ResourceTypeMethodsToMapTransformer, _super);
	    function ResourceTypeMethodsToMapTransformer() {
	        _super.call(this, null, "method");
	    }
	    ResourceTypeMethodsToMapTransformer.prototype.match = function (node, prop) {
	        return node.parent() != null
	            && universeHelpers.isResourceTypeType(node.parent().definition())
	            && universeHelpers.isMethodsProperty(prop);
	    };
	    return ResourceTypeMethodsToMapTransformer;
	}(ArrayToMappingsArrayTransformer));
	var exampleNameProp = universe.Universe10.ExampleSpec.properties.name.name;
	var exampleContentProp = universe.Universe10.ExampleSpec.properties.value.name;
	var exampleStructuredContentProp = "structuredContent";
	var ExamplesTransformer = (function () {
	    function ExamplesTransformer() {
	    }
	    ExamplesTransformer.prototype.match = function (node, prop) {
	        return universeHelpers.isExampleSpecType(node.definition());
	    };
	    ExamplesTransformer.prototype.transform = function (value) {
	        var _this = this;
	        if (Array.isArray(value) && value.length > 0) {
	            if (value[0][exampleNameProp]) {
	                var obj = {};
	                value.forEach(function (x) { return obj[x[exampleNameProp]] = _this.getActualExample(x); });
	                return obj;
	            }
	            else {
	                var arr = value.map(function (x) { return _this.getActualExample(x); });
	                return arr;
	            }
	        }
	        else {
	            return value;
	        }
	    };
	    ExamplesTransformer.prototype.getActualExample = function (exampleSpecObj) {
	        if (exampleSpecObj[exampleStructuredContentProp]) {
	            return exampleSpecObj[exampleStructuredContentProp];
	        }
	        return exampleSpecObj[exampleContentProp];
	    };
	    return ExamplesTransformer;
	}());
	var TypeExampleTransformer = (function () {
	    function TypeExampleTransformer() {
	    }
	    TypeExampleTransformer.prototype.match = function (node, prop) {
	        return node.definition && universeHelpers.isTypeDeclarationSibling(node.definition());
	    };
	    TypeExampleTransformer.prototype.transform = function (value) {
	        var isArray = Array.isArray(value);
	        var arr = isArray ? value : [value];
	        arr.forEach(function (x) {
	            var structuredExample = x['example'];
	            if (structuredExample) {
	                x['example'] = structuredExample.value;
	                x['structuredExample'] = structuredExample;
	            }
	        });
	        return isArray ? arr : arr[0];
	    };
	    return TypeExampleTransformer;
	}());
	var SchemasTransformer = (function () {
	    function SchemasTransformer() {
	        this.matcher = new BasicObjectPropertyMatcher(function (x) { return universeHelpers.isApiType(x) && universeHelpers.isRAML08Type(x); }, universeHelpers.isSchemasProperty);
	    }
	    SchemasTransformer.prototype.match = function (node, prop) {
	        return node.parent() != null && this.matcher.match(node.parent().definition(), prop);
	    };
	    SchemasTransformer.prototype.transform = function (value) {
	        if (Array.isArray(value)) {
	            return value;
	        }
	        else {
	            var obj = {};
	            obj[value.key] = value.value;
	            return obj;
	        }
	    };
	    SchemasTransformer.prototype.getActualExample = function (exampleSpecObj) {
	        if (exampleSpecObj[exampleStructuredContentProp]) {
	            return exampleSpecObj[exampleStructuredContentProp];
	        }
	        return exampleSpecObj[exampleContentProp];
	    };
	    return SchemasTransformer;
	}());
	var ProtocolsToUpperCaseTransformer = (function () {
	    function ProtocolsToUpperCaseTransformer() {
	    }
	    ProtocolsToUpperCaseTransformer.prototype.match = function (node, prop) {
	        return prop != null && universeHelpers.isProtocolsProperty(prop);
	    };
	    ProtocolsToUpperCaseTransformer.prototype.transform = function (value) {
	        if (typeof (value) == 'string') {
	            return value.toUpperCase();
	        }
	        else if (Array.isArray(value)) {
	            return value.map(function (x) { return x.toUpperCase(); });
	        }
	        return value;
	    };
	    return ProtocolsToUpperCaseTransformer;
	}());
	var OneElementArrayTransformer = (function () {
	    function OneElementArrayTransformer() {
	        this.usecases = new CompositeObjectPropertyMatcher([
	            new BasicObjectPropertyMatcher(universeHelpers.isApiSibling, universeHelpers.isMediaTypeProperty)
	        ]);
	    }
	    OneElementArrayTransformer.prototype.match = function (node, prop) {
	        return this.usecases.match(node.definition(), prop);
	    };
	    OneElementArrayTransformer.prototype.transform = function (value) {
	        if (Array.isArray(value) && value.length == 1) {
	            return value[0];
	        }
	        return value;
	    };
	    return OneElementArrayTransformer;
	}());
	var ResourcesTransformer = (function () {
	    function ResourcesTransformer() {
	    }
	    ResourcesTransformer.prototype.match = function (node, prop) {
	        return prop != null && universeHelpers.isResourcesProperty(prop);
	    };
	    ResourcesTransformer.prototype.transform = function (value) {
	        if (Array.isArray(value)) {
	            return value;
	        }
	        var relUri = value[universes.Universe10.Resource.properties.relativeUri.name];
	        if (relUri) {
	            var segments = relUri.trim().split("/");
	            while (segments.length > 0 && segments[0].length == 0) {
	                segments.shift();
	            }
	            value["relativeUriPathSegments"] = segments;
	        }
	        return value;
	    };
	    return ResourcesTransformer;
	}());
	var TemplateParametrizedPropertiesTransformer = (function () {
	    function TemplateParametrizedPropertiesTransformer() {
	    }
	    TemplateParametrizedPropertiesTransformer.prototype.match = function (node, prop) {
	        return prop != null && (universeHelpers.isResourceTypesProperty(prop)
	            || universeHelpers.isTraitsProperty(prop));
	    };
	    TemplateParametrizedPropertiesTransformer.prototype.transform = function (value) {
	        if (Array.isArray(value)) {
	            return value;
	        }
	        var propName = universe.Universe10.Trait.properties.parametrizedProperties.name;
	        var parametrizedProps = value[propName];
	        if (parametrizedProps) {
	            Object.keys(parametrizedProps).forEach(function (y) {
	                value[y] = parametrizedProps[y];
	            });
	            delete value[propName];
	        }
	        return value;
	    };
	    return TemplateParametrizedPropertiesTransformer;
	}());
	var ReferencesTransformer = (function () {
	    function ReferencesTransformer() {
	    }
	    ReferencesTransformer.prototype.match = function (node, prop) {
	        return prop != null && (universeHelpers.isSecuredByProperty(prop)
	            || universeHelpers.isIsProperty(prop)
	            || (node.parent() != null && (universeHelpers.isResourceType(node.parent().highLevel().definition())
	                || universeHelpers.isResourceTypeType(node.parent().highLevel().definition()))
	                && universeHelpers.isTypeProperty(prop)));
	    };
	    ReferencesTransformer.prototype.transform = function (value) {
	        if (!value) {
	            return null;
	        }
	        if (Array.isArray(value)) {
	            return value;
	        }
	        return this.toSimpleValue(value);
	    };
	    ReferencesTransformer.prototype.toSimpleValue = function (x) {
	        var name = x['name'];
	        var params = x['structuredValue'];
	        if (params) {
	            var obj = {};
	            obj[name] = params;
	            return obj;
	        }
	        else {
	            return name;
	        }
	    };
	    return ReferencesTransformer;
	}());
	var PropertiesData = (function () {
	    function PropertiesData() {
	        this.map = {};
	    }
	    PropertiesData.prototype.addProperty = function (prop, wrapperKind) {
	        var data = this.map[wrapperKind];
	        if (!data) {
	            data = new TypePropertiesData(wrapperKind);
	            this.map[wrapperKind] = data;
	        }
	        data.addProperty(prop);
	    };
	    PropertiesData.prototype.print = function () {
	        var _this = this;
	        return Object.keys(this.map).map(function (x) { return _this.map[x].print(); }).join('\n') + "\n";
	    };
	    return PropertiesData;
	}());
	var TypePropertiesData = (function () {
	    function TypePropertiesData(typeName) {
	        this.typeName = typeName;
	        this.map = {};
	    }
	    TypePropertiesData.prototype.addProperty = function (prop) {
	        var name = prop.domain().nameId();
	        var data = this.map[name];
	        if (!data) {
	            data = new TypePropertiesData2(name);
	            this.map[name] = data;
	        }
	        data.addProperty(prop);
	    };
	    TypePropertiesData.prototype.print = function () {
	        var _this = this;
	        return this.typeName + ':\n' + Object.keys(this.map).map(function (x) { return '    ' + _this.map[x].print(); }).join('\n');
	    };
	    return TypePropertiesData;
	}());
	var TypePropertiesData2 = (function () {
	    function TypePropertiesData2(typeName) {
	        this.typeName = typeName;
	        this.map = {};
	    }
	    TypePropertiesData2.prototype.addProperty = function (prop) {
	        var name = prop.nameId();
	        this.map[name] = prop;
	    };
	    TypePropertiesData2.prototype.print = function () {
	        return this.typeName + ': ' + Object.keys(this.map).sort().join(', ');
	    };
	    return TypePropertiesData2;
	}());
	//# sourceMappingURL=TCKDumper.js.map

/***/ },
/* 73 */
/***/ function(module, exports, __webpack_require__) {

	/// <reference path="../../typings/main.d.ts" />
	"use strict";
	function isEmpty(value) {
	    return value == null;
	}
	function toString(value) {
	    return isEmpty(value) ? '' : String(value);
	}
	function toBoolean(value) {
	    return [0, false, '', '0', 'false'].indexOf(value) === -1;
	}
	function toNumber(value) {
	    return isFinite(value) ? Number(value) : null;
	}
	function toInteger(value) {
	    return value % 1 === 0 ? Number(value) : null;
	}
	function toDate(value) {
	    return !isNaN(Date.parse(value)) ? new Date(value) : null;
	}
	function toSanitization(parameter, rules, types) {
	    var parameters = Array.isArray(parameter) ? parameter : [parameter];
	    var sanitizations = parameters.map(function (parameter) {
	        var fns = [];
	        var typeSanitization = types[parameter.type];
	        if (typeof typeSanitization === 'function') {
	            fns.push(typeSanitization);
	        }
	        Object.keys(parameter)
	            .filter(function (key) {
	            return key !== 'type' && key !== 'repeat' && key !== 'default';
	        })
	            .forEach(function (key) {
	            var fn = rules[key];
	            if (typeof fn === 'function') {
	                fns.push(fn(parameter[key], key));
	            }
	        });
	        function sanitize(value, key, src) {
	            for (var i = 0; i < fns.length; i++) {
	                var fn = fns[i];
	                var value = fn(value, key, src);
	                if (value != null) {
	                    return value;
	                }
	            }
	            return null;
	        }
	        return function (value, key, src) {
	            if (isEmpty(value)) {
	                if (parameter.default != null) {
	                    return sanitize(parameter.default, key, src);
	                }
	                return parameter.repeat && !parameter.required ? [] : value;
	            }
	            if (parameter.repeat) {
	                var values = Array.isArray(value) ? value : [value];
	                values = values.map(function (value) {
	                    return sanitize(value, key, src);
	                });
	                return values.some(isEmpty) ? null : value;
	            }
	            if (Array.isArray(value)) {
	                if (value.length > 1) {
	                    return null;
	                }
	                value = value[0];
	            }
	            return sanitize(value, key, src);
	        };
	    });
	    return function (value, key, src) {
	        for (var i = 0; i < sanitizations.length; i++) {
	            var sanitization = sanitizations[i];
	            var result = sanitization(value, key, src);
	            if (result != null) {
	                return result;
	            }
	        }
	        return value;
	    };
	}
	function sanitize() {
	    var RULES = {};
	    var TYPES = {
	        string: toString,
	        number: toNumber,
	        integer: toInteger,
	        boolean: toBoolean,
	        date: toDate
	    };
	    function rule(parameter) {
	        return toSanitization(parameter, RULES, TYPES);
	    }
	    var sanitize = function (parameterMap) {
	        if (!parameterMap) {
	            return function () {
	                return {};
	            };
	        }
	        var sanitizations = {};
	        Object.keys(parameterMap).forEach(function (key) {
	            sanitizations[key] = sanitize.rule(parameterMap[key]);
	        });
	        return function (src) {
	            src = src || {};
	            var dest = {};
	            // Iterate the sanitized parameters to get a clean model.
	            Object.keys(sanitizations).forEach(function (key) {
	                var value = src[key];
	                var fn = sanitizations[key];
	                if (Object.prototype.hasOwnProperty.call(src, key)) {
	                    dest[key] = fn(value, key, src);
	                }
	            });
	            return dest;
	        };
	    };
	    var s;
	    s = sanitize;
	    s.rule = rule;
	    s.TYPES = TYPES;
	    s.RULES = RULES;
	    return s;
	}
	exports.sanitize = sanitize;
	// export = sanitize 
	//# sourceMappingURL=raml-sanitize.js.map

/***/ },
/* 74 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(Buffer) {/// <reference path="../../typings/main.d.ts" />
	"use strict";
	var _toString = Object.prototype.toString;
	function isDateType(check) {
	    return _toString.call(check) === '[object Date]' && !isNaN(check.getTime());
	}
	function isBooleanType(check) {
	    return typeof check === 'boolean';
	}
	function isStringType(check) {
	    return typeof check === 'string';
	}
	function isIntegerType(check) {
	    return typeof check === 'number' && check % 1 === 0;
	}
	function isNumberType(check) {
	    return typeof check === 'number' && isFinite(check);
	}
	function isMinimum(min) {
	    return function (check) {
	        return check >= min;
	    };
	}
	function isMaximum(max) {
	    return function (check) {
	        return check <= max;
	    };
	}
	function isMinimumLength(min) {
	    return function (check) {
	        return Buffer.byteLength(check) >= min;
	    };
	}
	function isMaximumLength(max) {
	    return function (check) {
	        return Buffer.byteLength(check) <= max;
	    };
	}
	function isEnum(values) {
	    if (values && values.length != 0) {
	        return function (check) {
	            return values.indexOf(check) > -1;
	        };
	    }
	    else {
	        return function (check) {
	            return true;
	        };
	    }
	}
	function isPattern(pattern) {
	    var regexp = (typeof pattern === 'string') ? new RegExp(pattern) : pattern;
	    return regexp.test.bind(regexp);
	}
	function toValidationResult(valid, key, value, rule, attr) {
	    return {
	        valid: valid,
	        rule: rule,
	        attr: attr,
	        value: value,
	        key: key
	    };
	}
	function toValidationFunction(parameter, rules) {
	    var validations = [];
	    Object.keys(parameter).forEach(function (name) {
	        var rule = rules[name];
	        if (!rule) {
	            return;
	        }
	        var value = parameter[name];
	        validations.push([name, rule(value, name), value]);
	    });
	    return function (value, key, src) {
	        for (var i = 0; i < validations.length; i++) {
	            var validation = validations[i];
	            var name = validation[0];
	            var fn = validation[1];
	            var attr = validation[2];
	            var valid = fn(value, key, src);
	            if (!valid) {
	                return toValidationResult(false, key, value, name, attr);
	            }
	        }
	        return toValidationResult(true, key, value);
	    };
	}
	function toValidation(parameter, rules, types) {
	    var parameters = Array.isArray(parameter) ? parameter : [parameter];
	    var isOptional = !parameters.length;
	    var simpleValidations = [];
	    var repeatValidations = [];
	    parameters.forEach(function (parameter) {
	        var validation = [parameter.type || 'string', toValidationFunction(parameter, rules)];
	        if (!parameter.required) {
	            isOptional = true;
	        }
	        if (parameter.repeat) {
	            repeatValidations.push(validation);
	        }
	        else {
	            simpleValidations.push(validation);
	        }
	    });
	    return function (value, key, src) {
	        if (value == null) {
	            return toValidationResult(isOptional, key, value, 'required', !isOptional);
	        }
	        var isArray = Array.isArray(value);
	        var values = isArray ? value : [value];
	        var validations = isArray ? repeatValidations : simpleValidations;
	        if (!validations.length) {
	            return toValidationResult(false, key, value, 'repeat', !isArray);
	        }
	        var response = null;
	        var originalValue = value;
	        validations.some(function (validation) {
	            var isValidType = values.every(function (value) {
	                var paramType = validation[0];
	                var isValidType = types[paramType] && types[paramType](value, key, src);
	                if (!isValidType) {
	                    response = toValidationResult(false, key, originalValue, 'type', paramType);
	                }
	                return isValidType;
	            });
	            if (!isValidType) {
	                return false;
	            }
	            values.every(function (value) {
	                var fn = validation[1];
	                response = fn(value, key);
	                return response.valid;
	            });
	            return true;
	        });
	        return response;
	    };
	}
	function validate() {
	    var TYPES = {
	        date: isDateType,
	        number: isNumberType,
	        integer: isIntegerType,
	        boolean: isBooleanType,
	        string: isStringType
	    };
	    var RULES = {
	        minimum: isMinimum,
	        maximum: isMaximum,
	        minLength: isMinimumLength,
	        maxLength: isMaximumLength,
	        'enum': isEnum,
	        pattern: isPattern
	    };
	    function rule(parameter) {
	        return toValidation(parameter, RULES, TYPES);
	    }
	    var v;
	    var validate = function (parameterMap) {
	        if (!parameterMap) {
	            return function (check) {
	                return { valid: true, errors: [] };
	            };
	        }
	        var validations = {};
	        Object.keys(parameterMap).forEach(function (key) {
	            validations[key] = rule(parameterMap[key]);
	        });
	        return function (src) {
	            src = src || {};
	            var errors = Object.keys(validations)
	                .map(function (param) {
	                var value = src[param];
	                var fn = validations[param];
	                return fn(value, param, src);
	            })
	                .filter(function (result) {
	                return !result.valid;
	            });
	            return {
	                valid: errors.length === 0,
	                errors: errors
	            };
	        };
	    };
	    v = validate;
	    v.rule = rule;
	    v.TYPES = TYPES;
	    v.RULES = RULES;
	    return v;
	}
	exports.validate = validate;
	// export = validate
	//# sourceMappingURL=raml-validate.js.map
	/* WEBPACK VAR INJECTION */}.call(exports, __webpack_require__(87).Buffer))

/***/ },
/* 75 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var def = __webpack_require__(33);
	var khttp = __webpack_require__(131);
	var _ = __webpack_require__(83);
	var services = def;
	function handleTypeAnnotation(a, rangeType) {
	    if (a.name == 'MetaModel.declaresSubTypeOf') {
	        rangeType.getAdapter(services.RAMLService).setExtendedTypeName(a.arguments[0]);
	    }
	    if (a.name == 'MetaModel.nameAtRuntime') {
	        rangeType.setNameAtRuntime(a.arguments[0]);
	    }
	    if (a.name == 'MetaModel.description') {
	        rangeType.withDescription(a.arguments[0]);
	    }
	    if (a.name == 'MetaModel.inlinedTemplates') {
	        rangeType.getAdapter(services.RAMLService).setInlinedTemplates(true);
	    }
	    if (a.name == 'MetaModel.requireValue') {
	        rangeType.getAdapter(services.RAMLService).withContextRequirement("" + a.arguments[0], "" + a.arguments[1]);
	    }
	    if (a.name == 'MetaModel.referenceIs') {
	        rangeType.getAdapter(services.RAMLService).withReferenceIs("" + a.arguments[0]);
	    }
	    //MetaModel.referenceIs
	    if (a.name == 'MetaModel.actuallyExports') {
	        rangeType.getAdapter(services.RAMLService).withActuallyExports("" + a.arguments[0]);
	    }
	    if (a.name == 'MetaModel.convertsToGlobalOfType') {
	        rangeType.getAdapter(services.RAMLService).withConvertsToGlobal("" + a.arguments[0]);
	    }
	    if (a.name == 'MetaModel.allowAny') {
	        rangeType.getAdapter(services.RAMLService).withAllowAny();
	    }
	    if (a.name == 'MetaModel.allowQuestion') {
	        rangeType.getAdapter(services.RAMLService).withAllowQuestion();
	    }
	    if (a.name == 'MetaModel.alias') {
	        rangeType.getAdapter(services.RAMLService).addAlias("" + a.arguments[0]);
	    }
	    if (a.name == 'MetaModel.consumesRefs') {
	        rangeType.getAdapter(services.RAMLService).setConsumesRefs(true);
	    }
	    if (a.name == 'MetaModel.canInherit') {
	        rangeType.getAdapter(services.RAMLService).withCanInherit("" + a.arguments[0]);
	    }
	    if (a.name == 'MetaModel.definingPropertyIsEnough') {
	        rangeType.getAdapter(services.RAMLService).definingPropertyIsEnough("" + a.arguments[0]);
	    }
	    if (a.name == 'MetaModel.customHandling') {
	        rangeType.setCustom(true);
	    }
	    if (a.name == 'MetaModel.superclasses') {
	        rangeType.getAdapter(services.RAMLService).registerSupertypes(a.arguments[0]);
	    }
	    if (a.name == 'MetaModel.possibleInterfaces') {
	        rangeType.getAdapter(services.RAMLService).registerPossibleInterfaces(a.arguments[0]);
	    }
	}
	exports.handleTypeAnnotation = handleTypeAnnotation;
	exports.annotationHandlers = {
	    key: function (a, f) {
	        f.withFromParentKey();
	        f.withKey(true);
	    },
	    value: function (a, f) {
	        f.withFromParentValue();
	    },
	    canBeValue: function (a, f) {
	        f.withCanBeValue();
	    },
	    unmerged: function (a, f) {
	        f.unmerge();
	    },
	    startFrom: function (a, f) {
	        f.withKeyRestriction(a.arguments[0]);
	        f.merge();
	    },
	    oneOf: function (a, f) {
	        f.withEnumOptions(a.arguments[0]);
	    },
	    oftenKeys: function (a, f) {
	        f.withOftenKeys(a.arguments[0]);
	    },
	    embeddedInMaps: function (a, f) {
	        f.getAdapter(services.RAMLPropertyParserService).withEmbedMap();
	    },
	    system: function (a, f) {
	        f.getAdapter(services.RAMLPropertyParserService).withSystem(true);
	    },
	    required: function (a, f) {
	        if (a.arguments[0] != 'false' && a.arguments[0] !== false) {
	            f.withRequired(true);
	        }
	    },
	    noDirectParse: function (a, f) {
	        if (a.arguments[0] != 'false' && a.arguments[0] !== false) {
	            f.withNoDirectParse();
	        }
	    },
	    setsContextValue: function (a, f) {
	        f.addChildValueConstraint(new def.ChildValueConstraint("" + a.arguments[0], "" + a.arguments[1]));
	        //f.withKeyRestriction(<string>a.arguments[0])
	    },
	    defaultValue: function (a, f) {
	        f.setDefaultVal("" + a.arguments[0]);
	    },
	    defaultIntegerValue: function (a, f) {
	        f.setDefaultIntegerVal(a.arguments[0]);
	    },
	    defaultBooleanValue: function (a, f) {
	        f.setDefaultBooleanVal(a.arguments[0]);
	    },
	    facetId: function (a, f) {
	        if (a.arguments[0] == "minItems") {
	            f.setFacetValidator(function (x, f) {
	                if (x instanceof Array) {
	                    var length = Number.parseInt("" + f.value());
	                    if (length > x.length) {
	                        return "array should contain at least " + f.value() + " items";
	                    }
	                }
	                return null;
	            });
	        }
	        if (a.arguments[0] == "enum") {
	            f.setFacetValidator(function (x, f) {
	                var validateAgainst = x + "";
	                var array = f;
	                try {
	                    if (!array.some(function (x) { return x == validateAgainst; })) {
	                        return "value should be one of :" + array.join(",");
	                    }
	                }
	                catch (e) {
	                    return;
	                }
	                return null;
	            });
	        }
	        if (a.arguments[0] == "maxItems") {
	            f.setFacetValidator(function (x, f) {
	                if (x instanceof Array) {
	                    var length = Number.parseInt("" + f);
	                    if (length < x.length) {
	                        return "array should contain not more then " + f.value() + " items";
	                    }
	                }
	                return null;
	            });
	        }
	        if (a.arguments[0] == "minProperties") {
	            f.setFacetValidator(function (x, f) {
	                if (x instanceof Object) {
	                    var length = Number.parseInt("" + f);
	                    if (length > Object.keys(x).length) {
	                        return "object should contain at least " + f.value() + " properties";
	                    }
	                }
	                return null;
	            });
	        }
	        if (a.arguments[0] == "maxProperties") {
	            f.setFacetValidator(function (x, f) {
	                if (x instanceof Object) {
	                    var length = Number.parseInt("" + f);
	                    if (length < Object.keys(x).length) {
	                        return "object should contain not more then " + f.value() + " properties";
	                    }
	                }
	                return null;
	            });
	        }
	        if (a.arguments[0] == "uniqueItems") {
	            f.setFacetValidator(function (x, f) {
	                if (f instanceof Array) {
	                    var length = _.unique(f).length;
	                    if (length < f.length) {
	                        return "array should contain only unique items";
	                    }
	                }
	                return null;
	            });
	        }
	        if (a.arguments[0] == "minLength") {
	            f.setFacetValidator(function (x, f) {
	                if (typeof x == 'number' || typeof x == 'boolean') {
	                    x = "" + x;
	                }
	                if (typeof x == 'string') {
	                    var length = Number.parseInt("" + f);
	                    if (length > x.length) {
	                        return "string length should be at least " + length;
	                    }
	                }
	                return null;
	            });
	        }
	        if (a.arguments[0] == "maxLength") {
	            f.setFacetValidator(function (x, f) {
	                if (typeof x == 'number' || typeof x == 'boolean') {
	                    x = "" + x;
	                }
	                if (typeof x == 'string') {
	                    var length = Number.parseInt("" + f);
	                    if (length < x.length) {
	                        return "string length should be not more then " + length;
	                    }
	                }
	                return null;
	            });
	        }
	        if (a.arguments[0] == "minimum") {
	            f.setFacetValidator(function (x, f) {
	                if (typeof x == 'string') {
	                    x = parseFloat(x);
	                }
	                if (typeof x == 'number') {
	                    var length = parseFloat(f);
	                    if (length > x) {
	                        return "value should be not less then " + length;
	                    }
	                }
	                return null;
	            });
	        }
	        if (a.arguments[0] == "maximum") {
	            f.setFacetValidator(function (x, f) {
	                if (typeof x == 'string') {
	                    x = parseFloat(x);
	                }
	                if (typeof x == 'number') {
	                    var length = parseFloat(f);
	                    if (length < x) {
	                        return "value should be not more then " + length;
	                    }
	                }
	                return null;
	            });
	        }
	        if (a.arguments[0] == "pattern") {
	            f.setFacetValidator(function (x, f) {
	                if (typeof x == 'number' || typeof x == 'boolean') {
	                    x = "" + x;
	                }
	                if (typeof x == 'string') {
	                    var regExp = new RegExp(f);
	                    if (!regExp.test(x)) {
	                        return "string should match to " + f;
	                    }
	                }
	                return null;
	            });
	        }
	    },
	    extraMetaKey: function (a, f) {
	        if (a.arguments[0] == "statusCodes") {
	            f.withOftenKeys(khttp.statusCodes.map(function (x) { return x.code; }));
	            f.setValueDocProvider(function (name) {
	                var s = _.find(khttp.statusCodes, function (x) { return x.code == name; });
	                if (s) {
	                    return (name + ":" + s.description);
	                }
	                return null;
	            });
	        }
	        if (a.arguments[0] == "headers") {
	            f.setValueSuggester(function (x) {
	                if (x.property()) {
	                    var c = x.property().getChildValueConstraints();
	                    if (_.find(c, function (x) {
	                        return x.name == "location" && x.value == "Params.ParameterLocation.HEADERS";
	                    })) {
	                        return khttp.headers.map(function (x) { return x.header; });
	                    }
	                    if (x.property()) {
	                        if (x.property().nameId() == "headers") {
	                            return khttp.headers.map(function (x) { return x.header; });
	                        }
	                    }
	                }
	                return null;
	            });
	            f.setValueDocProvider(function (name) {
	                var s = _.find(khttp.headers, function (x) { return x.header == name; });
	                if (s) {
	                    return (name + ":" + s.description);
	                }
	                return null;
	            });
	        }
	        if (a.arguments[0] == "methods") {
	            f.setValueDocProvider(function (name) {
	                var s = _.find(khttp.methods, function (x) { return x.method == name.toUpperCase(); });
	                if (s) {
	                    return (name + ":" + s.description);
	                }
	                return null;
	            });
	        }
	    },
	    requireValue: function (a, f) {
	        f.withContextRequirement("" + a.arguments[0], "" + a.arguments[1]);
	        //f.withKeyRestriction(<string>a.arguments[0])
	    },
	    allowMultiple: function (a, f) {
	        f.withMultiValue(true);
	        //f.withKeyRestriction(<string>a.arguments[0])
	    },
	    constraint: function (a, f) {
	        //f.withKeyRestriction(<string>a.arguments[0])
	    },
	    newInstanceName: function (a, f) {
	        f.withNewInstanceName("" + a.arguments[0]);
	        //f.withKeyRestriction(<string>a.arguments[0])
	    },
	    declaringFields: function (a, f) {
	        f.withThisPropertyDeclaresFields();
	        //f.withKeyRestriction(<string>a.arguments[0])
	    },
	    describesAnnotation: function (a, f) {
	        //f.withReferenceParameters();
	        f.withDescribes(a.arguments[0]);
	    },
	    allowNull: function (a, f) {
	        f.withAllowNull();
	    },
	    descriminatingProperty: function (a, f) {
	        //f.withReferenceParameters();
	        f.withDescriminating(true);
	    },
	    description: function (a, f) {
	        f.withDescription("" + a.arguments[0]);
	        //f.withReferenceParameters();
	        //f.withDescriminating(true)
	    },
	    inherited: function (a, f) {
	        f.withInherited(true);
	    },
	    selfNode: function (a, f) {
	        f.withSelfNode();
	    },
	    grammarTokenKind: function (a, f) {
	        f.getAdapter(services.RAMLPropertyService).withPropertyGrammarType("" + a.arguments[0]);
	    },
	    canInherit: function (a, f) {
	        f.withInheritedContextValue("" + a.arguments[0]);
	    },
	    canBeDuplicator: function (a, f) {
	        f.setCanBeDuplicator();
	    },
	    example: function (a, f) {
	        f.getAdapter(services.RAMLPropertyService).setExample(true);
	    },
	    typeExpression: function (a, f) {
	        f.getAdapter(services.RAMLPropertyService).setTypeExpression(true);
	    },
	    hide: function (a, f) {
	        if (a.arguments.length == 0) {
	            f.getAdapter(services.RAMLPropertyDocumentationService).setHidden(true);
	        }
	        else {
	            f.getAdapter(services.RAMLPropertyDocumentationService).setHidden(a.arguments[0]);
	        }
	    },
	    documentationTableLabel: function (a, f) {
	        f.getAdapter(services.RAMLPropertyDocumentationService).setDocTableName("" + a.arguments[0]);
	    },
	    markdownDescription: function (a, f) {
	        f.getAdapter(services.RAMLPropertyDocumentationService).setMarkdownDescription("" + a.arguments[0]);
	    },
	    valueDescription: function (a, f) {
	        f.getAdapter(services.RAMLPropertyDocumentationService).setValueDescription(a.arguments[0] != null ? ("" + a.arguments[0]) : null);
	    },
	    customHandling: function (a, f) {
	    }
	};
	function recordAnnotation(p, a) {
	    exports.annotationHandlers[a.name](a, p);
	}
	exports.recordAnnotation = recordAnnotation;
	//# sourceMappingURL=annotationHandlers.js.map

/***/ },
/* 76 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(global) {(function() {
	  var vm,
	    __slice = [].slice;

	  vm = __webpack_require__(122);

	  exports.allowUnsafeEval = function(fn) {
	    var previousEval;
	    previousEval = global["eval"];
	    try {
	      global["eval"] = function(source) {
	        return vm.runInThisContext(source);
	      };
	      return fn();
	    } finally {
	      global["eval"] = previousEval;
	    }
	  };

	  exports.allowUnsafeNewFunction = function(fn) {
	    var previousFunction;
	    previousFunction = global.Function;
	    try {
	      global.Function = exports.Function;
	      return fn();
	    } finally {
	      global.Function = previousFunction;
	    }
	  };

	  exports.Function = function() {
	    var body, paramList, paramLists, params, _i, _j, _len;
	    paramLists = 2 <= arguments.length ? __slice.call(arguments, 0, _i = arguments.length - 1) : (_i = 0, []), body = arguments[_i++];
	    params = [];
	    for (_j = 0, _len = paramLists.length; _j < _len; _j++) {
	      paramList = paramLists[_j];
	      if (typeof paramList === 'string') {
	        paramList = paramList.split(/\s*,\s*/);
	      }
	      params.push.apply(params, paramList);
	    }
	    return vm.runInThisContext("(function(" + (params.join(', ')) + ") {\n  " + body + "\n})");
	  };

	  exports.Function.prototype = global.Function.prototype;

	}).call(this);
	
	/* WEBPACK VAR INJECTION */}.call(exports, (function() { return this; }())))

/***/ },
/* 77 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var ts = __webpack_require__(90);
	var tsInterfaces = __webpack_require__(91);
	var tc = __webpack_require__(92);
	var fr = __webpack_require__(93);
	var restrictions_1 = __webpack_require__(94);
	var metainfo_1 = __webpack_require__(95);
	var metainfo_2 = __webpack_require__(95);
	var metainfo_3 = __webpack_require__(95);
	var nm = __webpack_require__(96);
	exports.nominalTypes = __webpack_require__(97);
	exports.typeExpressions = __webpack_require__(98);
	var schemaUtil = __webpack_require__(99);
	exports.TOP_LEVEL_EXTRA = tsInterfaces.TOP_LEVEL_EXTRA;
	exports.DEFINED_IN_TYPES_EXTRA = tsInterfaces.DEFINED_IN_TYPES_EXTRA;
	exports.USER_DEFINED_EXTRA = tsInterfaces.USER_DEFINED_EXTRA;
	exports.SOURCE_EXTRA = tsInterfaces.SOURCE_EXTRA;
	// export function instanceOfHasExtra(instance : nominalTypes.ITypeDefinition) : instance is IHasExtra {
	//     returninstance instanceof ts.AbstractType || instance instanceof nominalTypes.AbstractType;
	// }
	function getSchemaUtils() {
	    return schemaUtil;
	}
	exports.getSchemaUtils = getSchemaUtils;
	/**
	 * loads type collection from JSON type definition
	 * @param data
	 * @param registry - optional registry of types which ar already known (does not modified during parse)
	 * @returns {TypeCollection} returns a new instance of type collection with a parsed types
	 */
	function loadTypeCollection(data, registry) {
	    if (registry === void 0) { registry = ts.builtInRegistry(); }
	    return tc.parseJSONTypeCollection(data, registry);
	}
	exports.loadTypeCollection = loadTypeCollection;
	/**
	 * loads type  from JSON type definition
	 * @param data
	 * @returns {ts.AbstractType}
	 */
	function loadType(data) {
	    return tc.parseJSON(null, data, ts.builtInRegistry());
	}
	exports.loadType = loadType;
	/**
	 * parses a type or type collection definition from a JSON structure
	 * @param data
	 * @returns {any}
	 */
	function parse(data) {
	    if (data['types'] || data['annotationTypes']) {
	        return tc.parseJSONTypeCollection(data);
	    }
	    else {
	        return tc.parseJSON(null, data);
	    }
	}
	exports.parse = parse;
	/**
	 * parses a type  from a JSON structure, uses second argument to resolve types
	 * @param data
	 * @returns {any}
	 */
	function parseType(data, collection) {
	    return tc.parseJSON(null, data, collection ? collection.getTypeRegistry() : ts.builtInRegistry());
	}
	exports.parseType = parseType;
	/**
	 * kind of the node
	 */
	(function (NodeKind) {
	    NodeKind[NodeKind["SCALAR"] = 0] = "SCALAR";
	    NodeKind[NodeKind["ARRAY"] = 1] = "ARRAY";
	    NodeKind[NodeKind["MAP"] = 2] = "MAP";
	})(exports.NodeKind || (exports.NodeKind = {}));
	var NodeKind = exports.NodeKind;
	/**
	 * parses type collection definition from a JSON structure
	 * @param data
	 * @returns {any}
	 */
	function parseFromAST(data) {
	    return tc.parseTypeCollection(data, ts.builtInRegistry());
	}
	exports.parseFromAST = parseFromAST;
	/**
	 * parses type collection definition from a JSON structure
	 * @param data
	 * @returns {any}
	 */
	function parseTypeFromAST(name, data, collection, defaultsToAny, annotation, global) {
	    if (defaultsToAny === void 0) { defaultsToAny = false; }
	    if (annotation === void 0) { annotation = false; }
	    if (global === void 0) { global = true; }
	    return tc.parse(name, data, collection ? collection.getTypeRegistry() : ts.builtInRegistry(), defaultsToAny, annotation, global);
	}
	exports.parseTypeFromAST = parseTypeFromAST;
	/**
	 * dumps type or type collection to JSON
	 * @param ts
	 * @returns {IType|ITypeCollection}
	 */
	function dump(ts) {
	    return tc.storeAsJSON(ts);
	}
	exports.dump = dump;
	/**
	 * validates intance against the type definition
	 * @param i - instance to validate
	 * @param t - type definition
	 * @returns {IStatus}
	 */
	function validate(i, t, autoClose) {
	    if (autoClose === void 0) { autoClose = false; }
	    ts.autoCloseFlag = autoClose;
	    try {
	        return t.validate(i, autoClose);
	    }
	    finally {
	        ts.autoCloseFlag = false;
	    }
	}
	exports.validate = validate;
	/***
	 * validates type definition
	 * @param t
	 * @param collection - collection of the types
	 * @returns {IStatus}
	 */
	function validateTypeDefinition(t, collection) {
	    return t.validateType(collection.getAnnotationTypeRegistry());
	}
	exports.validateTypeDefinition = validateTypeDefinition;
	/**
	 * performs automatic classification of instance against a given type
	 * @param i
	 * @param t
	 * @returns {IParsedType}
	 */
	function performAC(i, t) {
	    return t.ac(i);
	}
	exports.performAC = performAC;
	/**
	 * checks if the given type is suitable for automatic classification
	 * @param t
	 * @returns {Status}
	 */
	function checkACStatus(t) {
	    return t.canDoAc();
	}
	exports.checkACStatus = checkACStatus;
	/**
	 * this function allow you to get a list of all built-in facets
	 * @returns {FacetPrototype[]}
	 */
	function builtInFacets() {
	    return fr.getInstance().allPrototypes();
	}
	exports.builtInFacets = builtInFacets;
	/**
	 * returns type registry returning all built in types
	 * @returns {TypeRegistry}
	 */
	function builtInTypes() {
	    return ts.builtInRegistry();
	}
	exports.builtInTypes = builtInTypes;
	/**
	 * creates a new type by deriving it from a list of super types
	 * @returns {IParsedType}
	 */
	function derive(name) {
	    var types = [];
	    for (var _i = 1; _i < arguments.length; _i++) {
	        types[_i - 1] = arguments[_i];
	    }
	    return ts.derive(name, types);
	}
	exports.derive = derive;
	/**
	 * creates a new type by unifying it from a list of possible options
	 * @returns {IParsedType}
	 */
	function unify(name) {
	    var types = [];
	    for (var _i = 1; _i < arguments.length; _i++) {
	        types[_i - 1] = arguments[_i];
	    }
	    return ts.union(name, types);
	}
	exports.unify = unify;
	var TypeConstructor = (function () {
	    function TypeConstructor(target) {
	        this.target = target;
	    }
	    /**
	     * adds property declaration to the type
	     * @param name
	     * @param type
	     * @param optional
	     * @returns {TypeConstructor}
	     */
	    TypeConstructor.prototype.addProperty = function (name, type, optional) {
	        this.target.declareProperty(name, type, optional);
	        return this;
	    };
	    /**
	     * adds pattern property declaration to the type
	     * @param target
	     * @param regexp
	     * @param type
	     * @returns {TypeConstructor}
	     */
	    TypeConstructor.prototype.addPatternProperty = function (target, regexp, type) {
	        this.target.declareMapProperty(name, type);
	        return this;
	    };
	    /**
	     * closes type
	     * @returns {TypeConstructor}
	     */
	    TypeConstructor.prototype.closeType = function () {
	        this.target.addMeta(new restrictions_1.KnownPropertyRestriction(true));
	        return this;
	    };
	    /**
	     * adds annotation to the type
	     * @returns {TypeConstructor}
	     */
	    TypeConstructor.prototype.annotate = function (name, value) {
	        this.target.addMeta(new metainfo_1.Annotation(name, value));
	        return this;
	    };
	    /**
	     * adds custom facet to the type
	     * @returns {TypeConstructor}
	     */
	    TypeConstructor.prototype.customFacet = function (name, value) {
	        this.target.addMeta(new metainfo_2.CustomFacet(name, value));
	        return this;
	    };
	    /**
	     * adds custom facet declaration to the type
	     * @returns {TypeConstructor}
	     */
	    TypeConstructor.prototype.customFacetDeclaration = function (name, value, optional) {
	        if (optional === void 0) { optional = true; }
	        this.target.addMeta(new metainfo_3.FacetDeclaration(name, value, optional));
	        return this;
	    };
	    /**
	     * adds a built-in facet with a given name and value
	     * @param name
	     * @param value
	     * @returns {TypeConstructor}
	     */
	    TypeConstructor.prototype.addSimpleFacet = function (name, value) {
	        this.target.addMeta(fr.getInstance().buildFacet(name, value));
	        return this;
	    };
	    /**
	     * returns a constructed type instance
	     * @returns {IParsedType}
	     */
	    TypeConstructor.prototype.getResult = function () {
	        return this.target;
	    };
	    return TypeConstructor;
	}());
	exports.TypeConstructor = TypeConstructor;
	function setPropertyConstructor(c) {
	    nm.setPropertyConstructor(c);
	}
	exports.setPropertyConstructor = setPropertyConstructor;
	function toNominal(t, bt) {
	    return nm.toNominal(t, bt);
	}
	exports.toNominal = toNominal;
	//# sourceMappingURL=index.js.map

/***/ },
/* 78 */
/***/ function(module, exports, __webpack_require__) {

	//[4]   	NameStartChar	   ::=   	":" | [A-Z] | "_" | [a-z] | [#xC0-#xD6] | [#xD8-#xF6] | [#xF8-#x2FF] | [#x370-#x37D] | [#x37F-#x1FFF] | [#x200C-#x200D] | [#x2070-#x218F] | [#x2C00-#x2FEF] | [#x3001-#xD7FF] | [#xF900-#xFDCF] | [#xFDF0-#xFFFD] | [#x10000-#xEFFFF]
	//[4a]   	NameChar	   ::=   	NameStartChar | "-" | "." | [0-9] | #xB7 | [#x0300-#x036F] | [#x203F-#x2040]
	//[5]   	Name	   ::=   	NameStartChar (NameChar)*
	var nameStartChar = /[A-Z_a-z\xC0-\xD6\xD8-\xF6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD]///\u10000-\uEFFFF
	var nameChar = new RegExp("[\\-\\.0-9"+nameStartChar.source.slice(1,-1)+"\u00B7\u0300-\u036F\\u203F-\u2040]");
	var tagNamePattern = new RegExp('^'+nameStartChar.source+nameChar.source+'*(?:\:'+nameStartChar.source+nameChar.source+'*)?$');
	//var tagNamePattern = /^[a-zA-Z_][\w\-\.]*(?:\:[a-zA-Z_][\w\-\.]*)?$/
	//var handlers = 'resolveEntity,getExternalSubset,characters,endDocument,endElement,endPrefixMapping,ignorableWhitespace,processingInstruction,setDocumentLocator,skippedEntity,startDocument,startElement,startPrefixMapping,notationDecl,unparsedEntityDecl,error,fatalError,warning,attributeDecl,elementDecl,externalEntityDecl,internalEntityDecl,comment,endCDATA,endDTD,endEntity,startCDATA,startDTD,startEntity'.split(',')

	//S_TAG,	S_ATTR,	S_EQ,	S_V
	//S_ATTR_S,	S_E,	S_S,	S_C
	var S_TAG = 0;//tag name offerring
	var S_ATTR = 1;//attr name offerring 
	var S_ATTR_S=2;//attr name end and space offer
	var S_EQ = 3;//=space?
	var S_V = 4;//attr value(no quot value only)
	var S_E = 5;//attr value end and no space(quot end)
	var S_S = 6;//(attr value end || tag end ) && (space offer)
	var S_C = 7;//closed el<el />

	function XMLReader(){
		
	}

	XMLReader.prototype = {
		parse:function(source,defaultNSMap,entityMap){
			var domBuilder = this.domBuilder;
			domBuilder.startDocument();
			_copy(defaultNSMap ,defaultNSMap = {})
			parse(source,defaultNSMap,entityMap,
					domBuilder,this.errorHandler);
			domBuilder.endDocument();
		}
	}
	function parse(source,defaultNSMapCopy,entityMap,domBuilder,errorHandler){
	  function fixedFromCharCode(code) {
			// String.prototype.fromCharCode does not supports
			// > 2 bytes unicode chars directly
			if (code > 0xffff) {
				code -= 0x10000;
				var surrogate1 = 0xd800 + (code >> 10)
					, surrogate2 = 0xdc00 + (code & 0x3ff);

				return String.fromCharCode(surrogate1, surrogate2);
			} else {
				return String.fromCharCode(code);
			}
		}
		function entityReplacer(a){
			var k = a.slice(1,-1);
			if(k in entityMap){
				return entityMap[k]; 
			}else if(k.charAt(0) === '#'){
				return fixedFromCharCode(parseInt(k.substr(1).replace('x','0x')))
			}else{
				errorHandler.error('entity not found:'+a);
				return a;
			}
		}
		function appendText(end){//has some bugs
			if(end>start){
				var xt = source.substring(start,end).replace(/&#?\w+;/g,entityReplacer);
				locator&&position(start);
				domBuilder.characters(xt,0,end-start);
				start = end
			}
		}
		function position(p,m){
			while(p>=lineEnd && (m = linePattern.exec(source))){
				lineStart = m.index;
				lineEnd = lineStart + m[0].length;
				locator.lineNumber++;
				//console.log('line++:',locator,startPos,endPos)
			}
			locator.columnNumber = p-lineStart+1;
		}
		var lineStart = 0;
		var lineEnd = 0;
		var linePattern = /.+(?:\r\n?|\n)|.*$/g
		var locator = domBuilder.locator;
		
		var parseStack = [{currentNSMap:defaultNSMapCopy}]
		var closeMap = {};
		var start = 0;
		while(true){
			try{
				var tagStart = source.indexOf('<',start);
				if(tagStart<0){
					if(!source.substr(start).match(/^\s*$/)){
						var doc = domBuilder.document;
		    			var text = doc.createTextNode(source.substr(start));
		    			doc.appendChild(text);
		    			domBuilder.currentElement = text;
					}
					return;
				}
				if(tagStart>start){
					appendText(tagStart);
				}
				switch(source.charAt(tagStart+1)){
				case '/':
					var end = source.indexOf('>',tagStart+3);
					var tagName = source.substring(tagStart+2,end);
					var config = parseStack.pop();
					var localNSMap = config.localNSMap;
			        if(config.tagName != tagName){
			            errorHandler.fatalError("end tag name: "+tagName+' is not match the current start tagName:'+config.tagName );
			        }
					domBuilder.endElement(config.uri,config.localName,tagName);
					if(localNSMap){
						for(var prefix in localNSMap){
							domBuilder.endPrefixMapping(prefix) ;
						}
					}
					end++;
					break;
					// end elment
				case '?':// <?...?>
					locator&&position(tagStart);
					end = parseInstruction(source,tagStart,domBuilder);
					break;
				case '!':// <!doctype,<![CDATA,<!--
					locator&&position(tagStart);
					end = parseDCC(source,tagStart,domBuilder,errorHandler);
					break;
				default:
				
					locator&&position(tagStart);
					
					var el = new ElementAttributes();
					
					//elStartEnd
					var end = parseElementStartPart(source,tagStart,el,entityReplacer,errorHandler);
					var len = el.length;
					
					if(locator){
						if(len){
							//attribute position fixed
							for(var i = 0;i<len;i++){
								var a = el[i];
								position(a.offset);
								a.offset = copyLocator(locator,{});
							}
						}
						position(end);
					}
					if(!el.closed && fixSelfClosed(source,end,el.tagName,closeMap)){
						el.closed = true;
						if(!entityMap.nbsp){
							errorHandler.warning('unclosed xml attribute');
						}
					}
					appendElement(el,domBuilder,parseStack);
					
					
					if(el.uri === 'http://www.w3.org/1999/xhtml' && !el.closed){
						end = parseHtmlSpecialContent(source,end,el.tagName,entityReplacer,domBuilder)
					}else{
						end++;
					}
				}
			}catch(e){
				errorHandler.error('element parse error: '+e);
				end = -1;
			}
			if(end>start){
				start = end;
			}else{
				//TODO: 这里有可能sax回退，有位置错误风险
				appendText(Math.max(tagStart,start)+1);
			}
		}
	}
	function copyLocator(f,t){
		t.lineNumber = f.lineNumber;
		t.columnNumber = f.columnNumber;
		return t;
	}

	/**
	 * @see #appendElement(source,elStartEnd,el,selfClosed,entityReplacer,domBuilder,parseStack);
	 * @return end of the elementStartPart(end of elementEndPart for selfClosed el)
	 */
	function parseElementStartPart(source,start,el,entityReplacer,errorHandler){
		var attrName;
		var value;
		var p = ++start;
		var s = S_TAG;//status
		while(true){
			var c = source.charAt(p);
			switch(c){
			case '=':
				if(s === S_ATTR){//attrName
					attrName = source.slice(start,p);
					s = S_EQ;
				}else if(s === S_ATTR_S){
					s = S_EQ;
				}else{
					//fatalError: equal must after attrName or space after attrName
					throw new Error('attribute equal must after attrName');
				}
				break;
			case '\'':
			case '"':
				if(s === S_EQ){//equal
					start = p+1;
					p = source.indexOf(c,start)
					if(p>0){
						value = source.slice(start,p).replace(/&#?\w+;/g,entityReplacer);
						el.add(attrName,value,start-1);
						s = S_E;
					}else{
						//fatalError: no end quot match
						throw new Error('attribute value no end \''+c+'\' match');
					}
				}else if(s == S_V){
					value = source.slice(start,p).replace(/&#?\w+;/g,entityReplacer);
					//console.log(attrName,value,start,p)
					el.add(attrName,value,start);
					//console.dir(el)
					errorHandler.warning('attribute "'+attrName+'" missed start quot('+c+')!!');
					start = p+1;
					s = S_E
				}else{
					//fatalError: no equal before
					throw new Error('attribute value must after "="');
				}
				break;
			case '/':
				switch(s){
				case S_TAG:
					el.setTagName(source.slice(start,p));
				case S_E:
				case S_S:
				case S_C:
					s = S_C;
					el.closed = true;
				case S_V:
				case S_ATTR:
				case S_ATTR_S:
					break;
				//case S_EQ:
				default:
					throw new Error("attribute invalid close char('/')")
				}
				break;
			case ''://end document
				//throw new Error('unexpected end of input')
				errorHandler.error('unexpected end of input');
			case '>':
				switch(s){
				case S_TAG:
					el.setTagName(source.slice(start,p));
				case S_E:
				case S_S:
				case S_C:
					break;//normal
				case S_V://Compatible state
				case S_ATTR:
					value = source.slice(start,p);
					if(value.slice(-1) === '/'){
						el.closed  = true;
						value = value.slice(0,-1)
					}
				case S_ATTR_S:
					if(s === S_ATTR_S){
						value = attrName;
					}
					if(s == S_V){
						errorHandler.warning('attribute "'+value+'" missed quot(")!!');
						el.add(attrName,value.replace(/&#?\w+;/g,entityReplacer),start)
					}else{
						errorHandler.warning('attribute "'+value+'" missed value!! "'+value+'" instead!!')
						el.add(value,value,start)
					}
					break;
				case S_EQ:
					throw new Error('attribute value missed!!');
				}
	//			console.log(tagName,tagNamePattern,tagNamePattern.test(tagName))
				return p;
			/*xml space '\x20' | #x9 | #xD | #xA; */
			case '\u0080':
				c = ' ';
			default:
				if(c<= ' '){//space
					switch(s){
					case S_TAG:
						el.setTagName(source.slice(start,p));//tagName
						s = S_S;
						break;
					case S_ATTR:
						attrName = source.slice(start,p)
						s = S_ATTR_S;
						break;
					case S_V:
						var value = source.slice(start,p).replace(/&#?\w+;/g,entityReplacer);
						errorHandler.warning('attribute "'+value+'" missed quot(")!!');
						el.add(attrName,value,start)
					case S_E:
						s = S_S;
						break;
					//case S_S:
					//case S_EQ:
					//case S_ATTR_S:
					//	void();break;
					//case S_C:
						//ignore warning
					}
				}else{//not space
	//S_TAG,	S_ATTR,	S_EQ,	S_V
	//S_ATTR_S,	S_E,	S_S,	S_C
					switch(s){
					//case S_TAG:void();break;
					//case S_ATTR:void();break;
					//case S_V:void();break;
					case S_ATTR_S:
						errorHandler.warning('attribute "'+attrName+'" missed value!! "'+attrName+'" instead!!')
						el.add(attrName,attrName,start);
						start = p;
						s = S_ATTR;
						break;
					case S_E:
						errorHandler.warning('attribute space is required"'+attrName+'"!!')
					case S_S:
						s = S_ATTR;
						start = p;
						break;
					case S_EQ:
						s = S_V;
						start = p;
						break;
					case S_C:
						throw new Error("elements closed character '/' and '>' must be connected to");
					}
				}
			}
			p++;
		}
	}
	/**
	 * @return end of the elementStartPart(end of elementEndPart for selfClosed el)
	 */
	function appendElement(el,domBuilder,parseStack){
		var tagName = el.tagName;
		var localNSMap = null;
		var currentNSMap = parseStack[parseStack.length-1].currentNSMap;
		var i = el.length;
		while(i--){
			var a = el[i];
			var qName = a.qName;
			var value = a.value;
			var nsp = qName.indexOf(':');
			if(nsp>0){
				var prefix = a.prefix = qName.slice(0,nsp);
				var localName = qName.slice(nsp+1);
				var nsPrefix = prefix === 'xmlns' && localName
			}else{
				localName = qName;
				prefix = null
				nsPrefix = qName === 'xmlns' && ''
			}
			//can not set prefix,because prefix !== ''
			a.localName = localName ;
			//prefix == null for no ns prefix attribute 
			if(nsPrefix !== false){//hack!!
				if(localNSMap == null){
					localNSMap = {}
					//console.log(currentNSMap,0)
					_copy(currentNSMap,currentNSMap={})
					//console.log(currentNSMap,1)
				}
				currentNSMap[nsPrefix] = localNSMap[nsPrefix] = value;
				a.uri = 'http://www.w3.org/2000/xmlns/'
				domBuilder.startPrefixMapping(nsPrefix, value) 
			}
		}
		var i = el.length;
		while(i--){
			a = el[i];
			var prefix = a.prefix;
			if(prefix){//no prefix attribute has no namespace
				if(prefix === 'xml'){
					a.uri = 'http://www.w3.org/XML/1998/namespace';
				}if(prefix !== 'xmlns'){
					a.uri = currentNSMap[prefix]
					
					//{console.log('###'+a.qName,domBuilder.locator.systemId+'',currentNSMap,a.uri)}
				}
			}
		}
		var nsp = tagName.indexOf(':');
		if(nsp>0){
			prefix = el.prefix = tagName.slice(0,nsp);
			localName = el.localName = tagName.slice(nsp+1);
		}else{
			prefix = null;//important!!
			localName = el.localName = tagName;
		}
		//no prefix element has default namespace
		var ns = el.uri = currentNSMap[prefix || ''];
		domBuilder.startElement(ns,localName,tagName,el);
		//endPrefixMapping and startPrefixMapping have not any help for dom builder
		//localNSMap = null
		if(el.closed){
			domBuilder.endElement(ns,localName,tagName);
			if(localNSMap){
				for(prefix in localNSMap){
					domBuilder.endPrefixMapping(prefix) 
				}
			}
		}else{
			el.currentNSMap = currentNSMap;
			el.localNSMap = localNSMap;
			parseStack.push(el);
		}
	}
	function parseHtmlSpecialContent(source,elStartEnd,tagName,entityReplacer,domBuilder){
		if(/^(?:script|textarea)$/i.test(tagName)){
			var elEndStart =  source.indexOf('</'+tagName+'>',elStartEnd);
			var text = source.substring(elStartEnd+1,elEndStart);
			if(/[&<]/.test(text)){
				if(/^script$/i.test(tagName)){
					//if(!/\]\]>/.test(text)){
						//lexHandler.startCDATA();
						domBuilder.characters(text,0,text.length);
						//lexHandler.endCDATA();
						return elEndStart;
					//}
				}//}else{//text area
					text = text.replace(/&#?\w+;/g,entityReplacer);
					domBuilder.characters(text,0,text.length);
					return elEndStart;
				//}
				
			}
		}
		return elStartEnd+1;
	}
	function fixSelfClosed(source,elStartEnd,tagName,closeMap){
		//if(tagName in closeMap){
		var pos = closeMap[tagName];
		if(pos == null){
			//console.log(tagName)
			pos = closeMap[tagName] = source.lastIndexOf('</'+tagName+'>')
		}
		return pos<elStartEnd;
		//} 
	}
	function _copy(source,target){
		for(var n in source){target[n] = source[n]}
	}
	function parseDCC(source,start,domBuilder,errorHandler){//sure start with '<!'
		var next= source.charAt(start+2)
		switch(next){
		case '-':
			if(source.charAt(start + 3) === '-'){
				var end = source.indexOf('-->',start+4);
				//append comment source.substring(4,end)//<!--
				if(end>start){
					domBuilder.comment(source,start+4,end-start-4);
					return end+3;
				}else{
					errorHandler.error("Unclosed comment");
					return -1;
				}
			}else{
				//error
				return -1;
			}
		default:
			if(source.substr(start+3,6) == 'CDATA['){
				var end = source.indexOf(']]>',start+9);
				domBuilder.startCDATA();
				domBuilder.characters(source,start+9,end-start-9);
				domBuilder.endCDATA() 
				return end+3;
			}
			//<!DOCTYPE
			//startDTD(java.lang.String name, java.lang.String publicId, java.lang.String systemId) 
			var matchs = split(source,start);
			var len = matchs.length;
			if(len>1 && /!doctype/i.test(matchs[0][0])){
				var name = matchs[1][0];
				var pubid = len>3 && /^public$/i.test(matchs[2][0]) && matchs[3][0]
				var sysid = len>4 && matchs[4][0];
				var lastMatch = matchs[len-1]
				domBuilder.startDTD(name,pubid && pubid.replace(/^(['"])(.*?)\1$/,'$2'),
						sysid && sysid.replace(/^(['"])(.*?)\1$/,'$2'));
				domBuilder.endDTD();
				
				return lastMatch.index+lastMatch[0].length
			}
		}
		return -1;
	}



	function parseInstruction(source,start,domBuilder){
		var end = source.indexOf('?>',start);
		if(end){
			var match = source.substring(start,end).match(/^<\?(\S*)\s*([\s\S]*?)\s*$/);
			if(match){
				var len = match[0].length;
				domBuilder.processingInstruction(match[1], match[2]) ;
				return end+2;
			}else{//error
				return -1;
			}
		}
		return -1;
	}

	/**
	 * @param source
	 */
	function ElementAttributes(source){
		
	}
	ElementAttributes.prototype = {
		setTagName:function(tagName){
			if(!tagNamePattern.test(tagName)){
				throw new Error('invalid tagName:'+tagName)
			}
			this.tagName = tagName
		},
		add:function(qName,value,offset){
			if(!tagNamePattern.test(qName)){
				throw new Error('invalid attribute:'+qName)
			}
			this[this.length++] = {qName:qName,value:value,offset:offset}
		},
		length:0,
		getLocalName:function(i){return this[i].localName},
		getOffset:function(i){return this[i].offset},
		getQName:function(i){return this[i].qName},
		getURI:function(i){return this[i].uri},
		getValue:function(i){return this[i].value}
	//	,getIndex:function(uri, localName)){
	//		if(localName){
	//			
	//		}else{
	//			var qName = uri
	//		}
	//	},
	//	getValue:function(){return this.getValue(this.getIndex.apply(this,arguments))},
	//	getType:function(uri,localName){}
	//	getType:function(i){},
	}




	function _set_proto_(thiz,parent){
		thiz.__proto__ = parent;
		return thiz;
	}
	if(!(_set_proto_({},_set_proto_.prototype) instanceof _set_proto_)){
		_set_proto_ = function(thiz,parent){
			function p(){};
			p.prototype = parent;
			p = new p();
			for(parent in thiz){
				p[parent] = thiz[parent];
			}
			return p;
		}
	}

	function split(source,start){
		var match;
		var buf = [];
		var reg = /'[^']+'|"[^"]+"|[^\s<>\/=]+=?|(\/?\s*>|<)/g;
		reg.lastIndex = start;
		reg.exec(source);//skip <
		while(match = reg.exec(source)){
			buf.push(match);
			if(match[1])return buf;
		}
	}

	if(true){
		exports.XMLReader = XMLReader;
	}



/***/ },
/* 79 */
/***/ function(module, exports, __webpack_require__) {

	/*
	 * DOM Level 2
	 * Object DOMException
	 * @see http://www.w3.org/TR/REC-DOM-Level-1/ecma-script-language-binding.html
	 * @see http://www.w3.org/TR/2000/REC-DOM-Level-2-Core-20001113/ecma-script-binding.html
	 */

	function copy(src,dest){
		for(var p in src){
			dest[p] = src[p];
		}
	}
	/**
	^\w+\.prototype\.([_\w]+)\s*=\s*((?:.*\{\s*?[\r\n][\s\S]*?^})|\S.*?(?=[;\r\n]));?
	^\w+\.prototype\.([_\w]+)\s*=\s*(\S.*?(?=[;\r\n]));?
	 */
	function _extends(Class,Super){
		var pt = Class.prototype;
		if(Object.create){
			var ppt = Object.create(Super.prototype)
			pt.__proto__ = ppt;
		}
		if(!(pt instanceof Super)){
			function t(){};
			t.prototype = Super.prototype;
			t = new t();
			copy(pt,t);
			Class.prototype = pt = t;
		}
		if(pt.constructor != Class){
			if(typeof Class != 'function'){
				console.error("unknow Class:"+Class)
			}
			pt.constructor = Class
		}
	}
	var htmlns = 'http://www.w3.org/1999/xhtml' ;
	// Node Types
	var NodeType = {}
	var ELEMENT_NODE                = NodeType.ELEMENT_NODE                = 1;
	var ATTRIBUTE_NODE              = NodeType.ATTRIBUTE_NODE              = 2;
	var TEXT_NODE                   = NodeType.TEXT_NODE                   = 3;
	var CDATA_SECTION_NODE          = NodeType.CDATA_SECTION_NODE          = 4;
	var ENTITY_REFERENCE_NODE       = NodeType.ENTITY_REFERENCE_NODE       = 5;
	var ENTITY_NODE                 = NodeType.ENTITY_NODE                 = 6;
	var PROCESSING_INSTRUCTION_NODE = NodeType.PROCESSING_INSTRUCTION_NODE = 7;
	var COMMENT_NODE                = NodeType.COMMENT_NODE                = 8;
	var DOCUMENT_NODE               = NodeType.DOCUMENT_NODE               = 9;
	var DOCUMENT_TYPE_NODE          = NodeType.DOCUMENT_TYPE_NODE          = 10;
	var DOCUMENT_FRAGMENT_NODE      = NodeType.DOCUMENT_FRAGMENT_NODE      = 11;
	var NOTATION_NODE               = NodeType.NOTATION_NODE               = 12;

	// ExceptionCode
	var ExceptionCode = {}
	var ExceptionMessage = {};
	var INDEX_SIZE_ERR              = ExceptionCode.INDEX_SIZE_ERR              = ((ExceptionMessage[1]="Index size error"),1);
	var DOMSTRING_SIZE_ERR          = ExceptionCode.DOMSTRING_SIZE_ERR          = ((ExceptionMessage[2]="DOMString size error"),2);
	var HIERARCHY_REQUEST_ERR       = ExceptionCode.HIERARCHY_REQUEST_ERR       = ((ExceptionMessage[3]="Hierarchy request error"),3);
	var WRONG_DOCUMENT_ERR          = ExceptionCode.WRONG_DOCUMENT_ERR          = ((ExceptionMessage[4]="Wrong document"),4);
	var INVALID_CHARACTER_ERR       = ExceptionCode.INVALID_CHARACTER_ERR       = ((ExceptionMessage[5]="Invalid character"),5);
	var NO_DATA_ALLOWED_ERR         = ExceptionCode.NO_DATA_ALLOWED_ERR         = ((ExceptionMessage[6]="No data allowed"),6);
	var NO_MODIFICATION_ALLOWED_ERR = ExceptionCode.NO_MODIFICATION_ALLOWED_ERR = ((ExceptionMessage[7]="No modification allowed"),7);
	var NOT_FOUND_ERR               = ExceptionCode.NOT_FOUND_ERR               = ((ExceptionMessage[8]="Not found"),8);
	var NOT_SUPPORTED_ERR           = ExceptionCode.NOT_SUPPORTED_ERR           = ((ExceptionMessage[9]="Not supported"),9);
	var INUSE_ATTRIBUTE_ERR         = ExceptionCode.INUSE_ATTRIBUTE_ERR         = ((ExceptionMessage[10]="Attribute in use"),10);
	//level2
	var INVALID_STATE_ERR        	= ExceptionCode.INVALID_STATE_ERR        	= ((ExceptionMessage[11]="Invalid state"),11);
	var SYNTAX_ERR               	= ExceptionCode.SYNTAX_ERR               	= ((ExceptionMessage[12]="Syntax error"),12);
	var INVALID_MODIFICATION_ERR 	= ExceptionCode.INVALID_MODIFICATION_ERR 	= ((ExceptionMessage[13]="Invalid modification"),13);
	var NAMESPACE_ERR            	= ExceptionCode.NAMESPACE_ERR           	= ((ExceptionMessage[14]="Invalid namespace"),14);
	var INVALID_ACCESS_ERR       	= ExceptionCode.INVALID_ACCESS_ERR      	= ((ExceptionMessage[15]="Invalid access"),15);


	function DOMException(code, message) {
		if(message instanceof Error){
			var error = message;
		}else{
			error = this;
			Error.call(this, ExceptionMessage[code]);
			this.message = ExceptionMessage[code];
			if(Error.captureStackTrace) Error.captureStackTrace(this, DOMException);
		}
		error.code = code;
		if(message) this.message = this.message + ": " + message;
		return error;
	};
	DOMException.prototype = Error.prototype;
	copy(ExceptionCode,DOMException)
	/**
	 * @see http://www.w3.org/TR/2000/REC-DOM-Level-2-Core-20001113/core.html#ID-536297177
	 * The NodeList interface provides the abstraction of an ordered collection of nodes, without defining or constraining how this collection is implemented. NodeList objects in the DOM are live.
	 * The items in the NodeList are accessible via an integral index, starting from 0.
	 */
	function NodeList() {
	};
	NodeList.prototype = {
		/**
		 * The number of nodes in the list. The range of valid child node indices is 0 to length-1 inclusive.
		 * @standard level1
		 */
		length:0, 
		/**
		 * Returns the indexth item in the collection. If index is greater than or equal to the number of nodes in the list, this returns null.
		 * @standard level1
		 * @param index  unsigned long 
		 *   Index into the collection.
		 * @return Node
		 * 	The node at the indexth position in the NodeList, or null if that is not a valid index. 
		 */
		item: function(index) {
			return this[index] || null;
		},
		toString:function(){
			for(var buf = [], i = 0;i<this.length;i++){
				serializeToString(this[i],buf);
			}
			return buf.join('');
		}
	};
	function LiveNodeList(node,refresh){
		this._node = node;
		this._refresh = refresh
		_updateLiveList(this);
	}
	function _updateLiveList(list){
		var inc = list._node._inc || list._node.ownerDocument._inc;
		if(list._inc != inc){
			var ls = list._refresh(list._node);
			//console.log(ls.length)
			__set__(list,'length',ls.length);
			copy(ls,list);
			list._inc = inc;
		}
	}
	LiveNodeList.prototype.item = function(i){
		_updateLiveList(this);
		return this[i];
	}

	_extends(LiveNodeList,NodeList);
	/**
	 * 
	 * Objects implementing the NamedNodeMap interface are used to represent collections of nodes that can be accessed by name. Note that NamedNodeMap does not inherit from NodeList; NamedNodeMaps are not maintained in any particular order. Objects contained in an object implementing NamedNodeMap may also be accessed by an ordinal index, but this is simply to allow convenient enumeration of the contents of a NamedNodeMap, and does not imply that the DOM specifies an order to these Nodes.
	 * NamedNodeMap objects in the DOM are live.
	 * used for attributes or DocumentType entities 
	 */
	function NamedNodeMap() {
	};

	function _findNodeIndex(list,node){
		var i = list.length;
		while(i--){
			if(list[i] === node){return i}
		}
	}

	function _addNamedNode(el,list,newAttr,oldAttr){
		if(oldAttr){
			list[_findNodeIndex(list,oldAttr)] = newAttr;
		}else{
			list[list.length++] = newAttr;
		}
		if(el){
			newAttr.ownerElement = el;
			var doc = el.ownerDocument;
			if(doc){
				oldAttr && _onRemoveAttribute(doc,el,oldAttr);
				_onAddAttribute(doc,el,newAttr);
			}
		}
	}
	function _removeNamedNode(el,list,attr){
		var i = _findNodeIndex(list,attr);
		if(i>=0){
			var lastIndex = list.length-1
			while(i<lastIndex){
				list[i] = list[++i]
			}
			list.length = lastIndex;
			if(el){
				var doc = el.ownerDocument;
				if(doc){
					_onRemoveAttribute(doc,el,attr);
					attr.ownerElement = null;
				}
			}
		}else{
			throw DOMException(NOT_FOUND_ERR,new Error())
		}
	}
	NamedNodeMap.prototype = {
		length:0,
		item:NodeList.prototype.item,
		getNamedItem: function(key) {
	//		if(key.indexOf(':')>0 || key == 'xmlns'){
	//			return null;
	//		}
			var i = this.length;
			while(i--){
				var attr = this[i];
				if(attr.nodeName == key){
					return attr;
				}
			}
		},
		setNamedItem: function(attr) {
			var el = attr.ownerElement;
			if(el && el!=this._ownerElement){
				throw new DOMException(INUSE_ATTRIBUTE_ERR);
			}
			var oldAttr = this.getNamedItem(attr.nodeName);
			_addNamedNode(this._ownerElement,this,attr,oldAttr);
			return oldAttr;
		},
		/* returns Node */
		setNamedItemNS: function(attr) {// raises: WRONG_DOCUMENT_ERR,NO_MODIFICATION_ALLOWED_ERR,INUSE_ATTRIBUTE_ERR
			var el = attr.ownerElement, oldAttr;
			if(el && el!=this._ownerElement){
				throw new DOMException(INUSE_ATTRIBUTE_ERR);
			}
			oldAttr = this.getNamedItemNS(attr.namespaceURI,attr.localName);
			_addNamedNode(this._ownerElement,this,attr,oldAttr);
			return oldAttr;
		},

		/* returns Node */
		removeNamedItem: function(key) {
			var attr = this.getNamedItem(key);
			_removeNamedNode(this._ownerElement,this,attr);
			return attr;
			
			
		},// raises: NOT_FOUND_ERR,NO_MODIFICATION_ALLOWED_ERR
		
		//for level2
		removeNamedItemNS:function(namespaceURI,localName){
			var attr = this.getNamedItemNS(namespaceURI,localName);
			_removeNamedNode(this._ownerElement,this,attr);
			return attr;
		},
		getNamedItemNS: function(namespaceURI, localName) {
			var i = this.length;
			while(i--){
				var node = this[i];
				if(node.localName == localName && node.namespaceURI == namespaceURI){
					return node;
				}
			}
			return null;
		}
	};
	/**
	 * @see http://www.w3.org/TR/REC-DOM-Level-1/level-one-core.html#ID-102161490
	 */
	function DOMImplementation(/* Object */ features) {
		this._features = {};
		if (features) {
			for (var feature in features) {
				 this._features = features[feature];
			}
		}
	};

	DOMImplementation.prototype = {
		hasFeature: function(/* string */ feature, /* string */ version) {
			var versions = this._features[feature.toLowerCase()];
			if (versions && (!version || version in versions)) {
				return true;
			} else {
				return false;
			}
		},
		// Introduced in DOM Level 2:
		createDocument:function(namespaceURI,  qualifiedName, doctype){// raises:INVALID_CHARACTER_ERR,NAMESPACE_ERR,WRONG_DOCUMENT_ERR
			var doc = new Document();
			doc.implementation = this;
			doc.childNodes = new NodeList();
			doc.doctype = doctype;
			if(doctype){
				doc.appendChild(doctype);
			}
			if(qualifiedName){
				var root = doc.createElementNS(namespaceURI,qualifiedName);
				doc.appendChild(root);
			}
			return doc;
		},
		// Introduced in DOM Level 2:
		createDocumentType:function(qualifiedName, publicId, systemId){// raises:INVALID_CHARACTER_ERR,NAMESPACE_ERR
			var node = new DocumentType();
			node.name = qualifiedName;
			node.nodeName = qualifiedName;
			node.publicId = publicId;
			node.systemId = systemId;
			// Introduced in DOM Level 2:
			//readonly attribute DOMString        internalSubset;
			
			//TODO:..
			//  readonly attribute NamedNodeMap     entities;
			//  readonly attribute NamedNodeMap     notations;
			return node;
		}
	};


	/**
	 * @see http://www.w3.org/TR/2000/REC-DOM-Level-2-Core-20001113/core.html#ID-1950641247
	 */

	function Node() {
	};

	Node.prototype = {
		firstChild : null,
		lastChild : null,
		previousSibling : null,
		nextSibling : null,
		attributes : null,
		parentNode : null,
		childNodes : null,
		ownerDocument : null,
		nodeValue : null,
		namespaceURI : null,
		prefix : null,
		localName : null,
		// Modified in DOM Level 2:
		insertBefore:function(newChild, refChild){//raises 
			return _insertBefore(this,newChild,refChild);
		},
		replaceChild:function(newChild, oldChild){//raises 
			this.insertBefore(newChild,oldChild);
			if(oldChild){
				this.removeChild(oldChild);
			}
		},
		removeChild:function(oldChild){
			return _removeChild(this,oldChild);
		},
		appendChild:function(newChild){
			return this.insertBefore(newChild,null);
		},
		hasChildNodes:function(){
			return this.firstChild != null;
		},
		cloneNode:function(deep){
			return cloneNode(this.ownerDocument||this,this,deep);
		},
		// Modified in DOM Level 2:
		normalize:function(){
			var child = this.firstChild;
			while(child){
				var next = child.nextSibling;
				if(next && next.nodeType == TEXT_NODE && child.nodeType == TEXT_NODE){
					this.removeChild(next);
					child.appendData(next.data);
				}else{
					child.normalize();
					child = next;
				}
			}
		},
	  	// Introduced in DOM Level 2:
		isSupported:function(feature, version){
			return this.ownerDocument.implementation.hasFeature(feature,version);
		},
	    // Introduced in DOM Level 2:
	    hasAttributes:function(){
	    	return this.attributes.length>0;
	    },
	    lookupPrefix:function(namespaceURI){
	    	var el = this;
	    	while(el){
	    		var map = el._nsMap;
	    		//console.dir(map)
	    		if(map){
	    			for(var n in map){
	    				if(map[n] == namespaceURI){
	    					return n;
	    				}
	    			}
	    		}
	    		el = el.nodeType == 2?el.ownerDocument : el.parentNode;
	    	}
	    	return null;
	    },
	    // Introduced in DOM Level 3:
	    lookupNamespaceURI:function(prefix){
	    	var el = this;
	    	while(el){
	    		var map = el._nsMap;
	    		//console.dir(map)
	    		if(map){
	    			if(prefix in map){
	    				return map[prefix] ;
	    			}
	    		}
	    		el = el.nodeType == 2?el.ownerDocument : el.parentNode;
	    	}
	    	return null;
	    },
	    // Introduced in DOM Level 3:
	    isDefaultNamespace:function(namespaceURI){
	    	var prefix = this.lookupPrefix(namespaceURI);
	    	return prefix == null;
	    }
	};


	function _xmlEncoder(c){
		return c == '<' && '&lt;' ||
	         c == '>' && '&gt;' ||
	         c == '&' && '&amp;' ||
	         c == '"' && '&quot;' ||
	         '&#'+c.charCodeAt()+';'
	}


	copy(NodeType,Node);
	copy(NodeType,Node.prototype);

	/**
	 * @param callback return true for continue,false for break
	 * @return boolean true: break visit;
	 */
	function _visitNode(node,callback){
		if(callback(node)){
			return true;
		}
		if(node = node.firstChild){
			do{
				if(_visitNode(node,callback)){return true}
	        }while(node=node.nextSibling)
	    }
	}



	function Document(){
	}
	function _onAddAttribute(doc,el,newAttr){
		doc && doc._inc++;
		var ns = newAttr.namespaceURI ;
		if(ns == 'http://www.w3.org/2000/xmlns/'){
			//update namespace
			el._nsMap[newAttr.prefix?newAttr.localName:''] = newAttr.value
		}
	}
	function _onRemoveAttribute(doc,el,newAttr,remove){
		doc && doc._inc++;
		var ns = newAttr.namespaceURI ;
		if(ns == 'http://www.w3.org/2000/xmlns/'){
			//update namespace
			delete el._nsMap[newAttr.prefix?newAttr.localName:'']
		}
	}
	function _onUpdateChild(doc,el,newChild){
		if(doc && doc._inc){
			doc._inc++;
			//update childNodes
			var cs = el.childNodes;
			if(newChild){
				cs[cs.length++] = newChild;
			}else{
				//console.log(1)
				var child = el.firstChild;
				var i = 0;
				while(child){
					cs[i++] = child;
					child =child.nextSibling;
				}
				cs.length = i;
			}
		}
	}

	/**
	 * attributes;
	 * children;
	 * 
	 * writeable properties:
	 * nodeValue,Attr:value,CharacterData:data
	 * prefix
	 */
	function _removeChild(parentNode,child){
		var previous = child.previousSibling;
		var next = child.nextSibling;
		if(previous){
			previous.nextSibling = next;
		}else{
			parentNode.firstChild = next
		}
		if(next){
			next.previousSibling = previous;
		}else{
			parentNode.lastChild = previous;
		}
		_onUpdateChild(parentNode.ownerDocument,parentNode);
		return child;
	}
	/**
	 * preformance key(refChild == null)
	 */
	function _insertBefore(parentNode,newChild,nextChild){
		var cp = newChild.parentNode;
		if(cp){
			cp.removeChild(newChild);//remove and update
		}
		if(newChild.nodeType === DOCUMENT_FRAGMENT_NODE){
			var newFirst = newChild.firstChild;
			if (newFirst == null) {
				return newChild;
			}
			var newLast = newChild.lastChild;
		}else{
			newFirst = newLast = newChild;
		}
		var pre = nextChild ? nextChild.previousSibling : parentNode.lastChild;

		newFirst.previousSibling = pre;
		newLast.nextSibling = nextChild;
		
		
		if(pre){
			pre.nextSibling = newFirst;
		}else{
			parentNode.firstChild = newFirst;
		}
		if(nextChild == null){
			parentNode.lastChild = newLast;
		}else{
			nextChild.previousSibling = newLast;
		}
		do{
			newFirst.parentNode = parentNode;
		}while(newFirst !== newLast && (newFirst= newFirst.nextSibling))
		_onUpdateChild(parentNode.ownerDocument||parentNode,parentNode);
		//console.log(parentNode.lastChild.nextSibling == null)
		if (newChild.nodeType == DOCUMENT_FRAGMENT_NODE) {
			newChild.firstChild = newChild.lastChild = null;
		}
		return newChild;
	}
	function _appendSingleChild(parentNode,newChild){
		var cp = newChild.parentNode;
		if(cp){
			var pre = parentNode.lastChild;
			cp.removeChild(newChild);//remove and update
			var pre = parentNode.lastChild;
		}
		var pre = parentNode.lastChild;
		newChild.parentNode = parentNode;
		newChild.previousSibling = pre;
		newChild.nextSibling = null;
		if(pre){
			pre.nextSibling = newChild;
		}else{
			parentNode.firstChild = newChild;
		}
		parentNode.lastChild = newChild;
		_onUpdateChild(parentNode.ownerDocument,parentNode,newChild);
		return newChild;
		//console.log("__aa",parentNode.lastChild.nextSibling == null)
	}
	Document.prototype = {
		//implementation : null,
		nodeName :  '#document',
		nodeType :  DOCUMENT_NODE,
		doctype :  null,
		documentElement :  null,
		_inc : 1,
		
		insertBefore :  function(newChild, refChild){//raises 
			if(newChild.nodeType == DOCUMENT_FRAGMENT_NODE){
				var child = newChild.firstChild;
				while(child){
					var next = child.nextSibling;
					this.insertBefore(child,refChild);
					child = next;
				}
				return newChild;
			}
			if(this.documentElement == null && newChild.nodeType == 1){
				this.documentElement = newChild;
			}
			
			return _insertBefore(this,newChild,refChild),(newChild.ownerDocument = this),newChild;
		},
		removeChild :  function(oldChild){
			if(this.documentElement == oldChild){
				this.documentElement = null;
			}
			return _removeChild(this,oldChild);
		},
		// Introduced in DOM Level 2:
		importNode : function(importedNode,deep){
			return importNode(this,importedNode,deep);
		},
		// Introduced in DOM Level 2:
		getElementById :	function(id){
			var rtv = null;
			_visitNode(this.documentElement,function(node){
				if(node.nodeType == 1){
					if(node.getAttribute('id') == id){
						rtv = node;
						return true;
					}
				}
			})
			return rtv;
		},
		
		//document factory method:
		createElement :	function(tagName){
			var node = new Element();
			node.ownerDocument = this;
			node.nodeName = tagName;
			node.tagName = tagName;
			node.childNodes = new NodeList();
			var attrs	= node.attributes = new NamedNodeMap();
			attrs._ownerElement = node;
			return node;
		},
		createDocumentFragment :	function(){
			var node = new DocumentFragment();
			node.ownerDocument = this;
			node.childNodes = new NodeList();
			return node;
		},
		createTextNode :	function(data){
			var node = new Text();
			node.ownerDocument = this;
			node.appendData(data)
			return node;
		},
		createComment :	function(data){
			var node = new Comment();
			node.ownerDocument = this;
			node.appendData(data)
			return node;
		},
		createCDATASection :	function(data){
			var node = new CDATASection();
			node.ownerDocument = this;
			node.appendData(data)
			return node;
		},
		createProcessingInstruction :	function(target,data){
			var node = new ProcessingInstruction();
			node.ownerDocument = this;
			node.tagName = node.target = target;
			node.nodeValue= node.data = data;
			return node;
		},
		createAttribute :	function(name){
			var node = new Attr();
			node.ownerDocument	= this;
			node.name = name;
			node.nodeName	= name;
			node.localName = name;
			node.specified = true;
			return node;
		},
		createEntityReference :	function(name){
			var node = new EntityReference();
			node.ownerDocument	= this;
			node.nodeName	= name;
			return node;
		},
		// Introduced in DOM Level 2:
		createElementNS :	function(namespaceURI,qualifiedName){
			var node = new Element();
			var pl = qualifiedName.split(':');
			var attrs	= node.attributes = new NamedNodeMap();
			node.childNodes = new NodeList();
			node.ownerDocument = this;
			node.nodeName = qualifiedName;
			node.tagName = qualifiedName;
			node.namespaceURI = namespaceURI;
			if(pl.length == 2){
				node.prefix = pl[0];
				node.localName = pl[1];
			}else{
				//el.prefix = null;
				node.localName = qualifiedName;
			}
			attrs._ownerElement = node;
			return node;
		},
		// Introduced in DOM Level 2:
		createAttributeNS :	function(namespaceURI,qualifiedName){
			var node = new Attr();
			var pl = qualifiedName.split(':');
			node.ownerDocument = this;
			node.nodeName = qualifiedName;
			node.name = qualifiedName;
			node.namespaceURI = namespaceURI;
			node.specified = true;
			if(pl.length == 2){
				node.prefix = pl[0];
				node.localName = pl[1];
			}else{
				//el.prefix = null;
				node.localName = qualifiedName;
			}
			return node;
		}
	};
	_extends(Document,Node);


	function Element() {
		this._nsMap = {};
	};
	Element.prototype = {
		nodeType : ELEMENT_NODE,
		hasAttribute : function(name){
			return this.getAttributeNode(name)!=null;
		},
		getAttribute : function(name){
			var attr = this.getAttributeNode(name);
			return attr && attr.value || '';
		},
		getAttributeNode : function(name){
			return this.attributes.getNamedItem(name);
		},
		setAttribute : function(name, value){
			var attr = this.ownerDocument.createAttribute(name);
			attr.value = attr.nodeValue = "" + value;
			this.setAttributeNode(attr)
		},
		removeAttribute : function(name){
			var attr = this.getAttributeNode(name)
			attr && this.removeAttributeNode(attr);
		},
		
		//four real opeartion method
		appendChild:function(newChild){
			if(newChild.nodeType === DOCUMENT_FRAGMENT_NODE){
				return this.insertBefore(newChild,null);
			}else{
				return _appendSingleChild(this,newChild);
			}
		},
		setAttributeNode : function(newAttr){
			return this.attributes.setNamedItem(newAttr);
		},
		setAttributeNodeNS : function(newAttr){
			return this.attributes.setNamedItemNS(newAttr);
		},
		removeAttributeNode : function(oldAttr){
			return this.attributes.removeNamedItem(oldAttr.nodeName);
		},
		//get real attribute name,and remove it by removeAttributeNode
		removeAttributeNS : function(namespaceURI, localName){
			var old = this.getAttributeNodeNS(namespaceURI, localName);
			old && this.removeAttributeNode(old);
		},
		
		hasAttributeNS : function(namespaceURI, localName){
			return this.getAttributeNodeNS(namespaceURI, localName)!=null;
		},
		getAttributeNS : function(namespaceURI, localName){
			var attr = this.getAttributeNodeNS(namespaceURI, localName);
			return attr && attr.value || '';
		},
		setAttributeNS : function(namespaceURI, qualifiedName, value){
			var attr = this.ownerDocument.createAttributeNS(namespaceURI, qualifiedName);
			attr.value = attr.nodeValue = "" + value;
			this.setAttributeNode(attr)
		},
		getAttributeNodeNS : function(namespaceURI, localName){
			return this.attributes.getNamedItemNS(namespaceURI, localName);
		},
		
		getElementsByTagName : function(tagName){
			return new LiveNodeList(this,function(base){
				var ls = [];
				_visitNode(base,function(node){
					if(node !== base && node.nodeType == ELEMENT_NODE && (tagName === '*' || node.tagName == tagName)){
						ls.push(node);
					}
				});
				return ls;
			});
		},
		getElementsByTagNameNS : function(namespaceURI, localName){
			return new LiveNodeList(this,function(base){
				var ls = [];
				_visitNode(base,function(node){
					if(node !== base && node.nodeType === ELEMENT_NODE && (namespaceURI === '*' || node.namespaceURI === namespaceURI) && (localName === '*' || node.localName == localName)){
						ls.push(node);
					}
				});
				return ls;
			});
		}
	};
	Document.prototype.getElementsByTagName = Element.prototype.getElementsByTagName;
	Document.prototype.getElementsByTagNameNS = Element.prototype.getElementsByTagNameNS;


	_extends(Element,Node);
	function Attr() {
	};
	Attr.prototype.nodeType = ATTRIBUTE_NODE;
	_extends(Attr,Node);


	function CharacterData() {
	};
	CharacterData.prototype = {
		data : '',
		substringData : function(offset, count) {
			return this.data.substring(offset, offset+count);
		},
		appendData: function(text) {
			text = this.data+text;
			this.nodeValue = this.data = text;
			this.length = text.length;
		},
		insertData: function(offset,text) {
			this.replaceData(offset,0,text);
		
		},
		appendChild:function(newChild){
			//if(!(newChild instanceof CharacterData)){
				throw new Error(ExceptionMessage[3])
			//}
			return Node.prototype.appendChild.apply(this,arguments)
		},
		deleteData: function(offset, count) {
			this.replaceData(offset,count,"");
		},
		replaceData: function(offset, count, text) {
			var start = this.data.substring(0,offset);
			var end = this.data.substring(offset+count);
			text = start + text + end;
			this.nodeValue = this.data = text;
			this.length = text.length;
		}
	}
	_extends(CharacterData,Node);
	function Text() {
	};
	Text.prototype = {
		nodeName : "#text",
		nodeType : TEXT_NODE,
		splitText : function(offset) {
			var text = this.data;
			var newText = text.substring(offset);
			text = text.substring(0, offset);
			this.data = this.nodeValue = text;
			this.length = text.length;
			var newNode = this.ownerDocument.createTextNode(newText);
			if(this.parentNode){
				this.parentNode.insertBefore(newNode, this.nextSibling);
			}
			return newNode;
		}
	}
	_extends(Text,CharacterData);
	function Comment() {
	};
	Comment.prototype = {
		nodeName : "#comment",
		nodeType : COMMENT_NODE
	}
	_extends(Comment,CharacterData);

	function CDATASection() {
	};
	CDATASection.prototype = {
		nodeName : "#cdata-section",
		nodeType : CDATA_SECTION_NODE
	}
	_extends(CDATASection,CharacterData);


	function DocumentType() {
	};
	DocumentType.prototype.nodeType = DOCUMENT_TYPE_NODE;
	_extends(DocumentType,Node);

	function Notation() {
	};
	Notation.prototype.nodeType = NOTATION_NODE;
	_extends(Notation,Node);

	function Entity() {
	};
	Entity.prototype.nodeType = ENTITY_NODE;
	_extends(Entity,Node);

	function EntityReference() {
	};
	EntityReference.prototype.nodeType = ENTITY_REFERENCE_NODE;
	_extends(EntityReference,Node);

	function DocumentFragment() {
	};
	DocumentFragment.prototype.nodeName =	"#document-fragment";
	DocumentFragment.prototype.nodeType =	DOCUMENT_FRAGMENT_NODE;
	_extends(DocumentFragment,Node);


	function ProcessingInstruction() {
	}
	ProcessingInstruction.prototype.nodeType = PROCESSING_INSTRUCTION_NODE;
	_extends(ProcessingInstruction,Node);
	function XMLSerializer(){}
	XMLSerializer.prototype.serializeToString = function(node,attributeSorter){
		return node.toString(attributeSorter);
	}
	Node.prototype.toString =function(attributeSorter){
		var buf = [];
		serializeToString(this,buf,attributeSorter);
		return buf.join('');
	}
	function serializeToString(node,buf,attributeSorter,isHTML){
		switch(node.nodeType){
		case ELEMENT_NODE:
			var attrs = node.attributes;
			var len = attrs.length;
			var child = node.firstChild;
			var nodeName = node.tagName;
			isHTML =  (htmlns === node.namespaceURI) ||isHTML 
			buf.push('<',nodeName);
			if(attributeSorter){
				buf.sort.apply(attrs, attributeSorter);
			}
			for(var i=0;i<len;i++){
				serializeToString(attrs.item(i),buf,attributeSorter,isHTML);
			}
			if(child || isHTML && !/^(?:meta|link|img|br|hr|input|button)$/i.test(nodeName)){
				buf.push('>');
				//if is cdata child node
				if(isHTML && /^script$/i.test(nodeName)){
					if(child){
						buf.push(child.data);
					}
				}else{
					while(child){
						serializeToString(child,buf,attributeSorter,isHTML);
						child = child.nextSibling;
					}
				}
				buf.push('</',nodeName,'>');
			}else{
				buf.push('/>');
			}
			return;
		case DOCUMENT_NODE:
		case DOCUMENT_FRAGMENT_NODE:
			var child = node.firstChild;
			while(child){
				serializeToString(child,buf,attributeSorter,isHTML);
				child = child.nextSibling;
			}
			return;
		case ATTRIBUTE_NODE:
			return buf.push(' ',node.name,'="',node.value.replace(/[<&"]/g,_xmlEncoder),'"');
		case TEXT_NODE:
			return buf.push(node.data.replace(/[<&]/g,_xmlEncoder));
		case CDATA_SECTION_NODE:
			return buf.push( '<![CDATA[',node.data,']]>');
		case COMMENT_NODE:
			return buf.push( "<!--",node.data,"-->");
		case DOCUMENT_TYPE_NODE:
			var pubid = node.publicId;
			var sysid = node.systemId;
			buf.push('<!DOCTYPE ',node.name);
			if(pubid){
				buf.push(' PUBLIC "',pubid);
				if (sysid && sysid!='.') {
					buf.push( '" "',sysid);
				}
				buf.push('">');
			}else if(sysid && sysid!='.'){
				buf.push(' SYSTEM "',sysid,'">');
			}else{
				var sub = node.internalSubset;
				if(sub){
					buf.push(" [",sub,"]");
				}
				buf.push(">");
			}
			return;
		case PROCESSING_INSTRUCTION_NODE:
			return buf.push( "<?",node.target," ",node.data,"?>");
		case ENTITY_REFERENCE_NODE:
			return buf.push( '&',node.nodeName,';');
		//case ENTITY_NODE:
		//case NOTATION_NODE:
		default:
			buf.push('??',node.nodeName);
		}
	}
	function importNode(doc,node,deep){
		var node2;
		switch (node.nodeType) {
		case ELEMENT_NODE:
			node2 = node.cloneNode(false);
			node2.ownerDocument = doc;
			//var attrs = node2.attributes;
			//var len = attrs.length;
			//for(var i=0;i<len;i++){
				//node2.setAttributeNodeNS(importNode(doc,attrs.item(i),deep));
			//}
		case DOCUMENT_FRAGMENT_NODE:
			break;
		case ATTRIBUTE_NODE:
			deep = true;
			break;
		//case ENTITY_REFERENCE_NODE:
		//case PROCESSING_INSTRUCTION_NODE:
		////case TEXT_NODE:
		//case CDATA_SECTION_NODE:
		//case COMMENT_NODE:
		//	deep = false;
		//	break;
		//case DOCUMENT_NODE:
		//case DOCUMENT_TYPE_NODE:
		//cannot be imported.
		//case ENTITY_NODE:
		//case NOTATION_NODE：
		//can not hit in level3
		//default:throw e;
		}
		if(!node2){
			node2 = node.cloneNode(false);//false
		}
		node2.ownerDocument = doc;
		node2.parentNode = null;
		if(deep){
			var child = node.firstChild;
			while(child){
				node2.appendChild(importNode(doc,child,deep));
				child = child.nextSibling;
			}
		}
		return node2;
	}
	//
	//var _relationMap = {firstChild:1,lastChild:1,previousSibling:1,nextSibling:1,
	//					attributes:1,childNodes:1,parentNode:1,documentElement:1,doctype,};
	function cloneNode(doc,node,deep){
		var node2 = new node.constructor();
		for(var n in node){
			var v = node[n];
			if(typeof v != 'object' ){
				if(v != node2[n]){
					node2[n] = v;
				}
			}
		}
		if(node.childNodes){
			node2.childNodes = new NodeList();
		}
		node2.ownerDocument = doc;
		switch (node2.nodeType) {
		case ELEMENT_NODE:
			var attrs	= node.attributes;
			var attrs2	= node2.attributes = new NamedNodeMap();
			var len = attrs.length
			attrs2._ownerElement = node2;
			for(var i=0;i<len;i++){
				node2.setAttributeNode(cloneNode(doc,attrs.item(i),true));
			}
			break;;
		case ATTRIBUTE_NODE:
			deep = true;
		}
		if(deep){
			var child = node.firstChild;
			while(child){
				node2.appendChild(cloneNode(doc,child,deep));
				child = child.nextSibling;
			}
		}
		return node2;
	}

	function __set__(object,key,value){
		object[key] = value
	}
	//do dynamic
	try{
		if(Object.defineProperty){
			Object.defineProperty(LiveNodeList.prototype,'length',{
				get:function(){
					_updateLiveList(this);
					return this.$$length;
				}
			});
			Object.defineProperty(Node.prototype,'textContent',{
				get:function(){
					return getTextContent(this);
				},
				set:function(data){
					switch(this.nodeType){
					case 1:
					case 11:
						while(this.firstChild){
							this.removeChild(this.firstChild);
						}
						if(data || String(data)){
							this.appendChild(this.ownerDocument.createTextNode(data));
						}
						break;
					default:
						//TODO:
						this.data = data;
						this.value = value;
						this.nodeValue = data;
					}
				}
			})
			
			function getTextContent(node){
				switch(node.nodeType){
				case 1:
				case 11:
					var buf = [];
					node = node.firstChild;
					while(node){
						if(node.nodeType!==7 && node.nodeType !==8){
							buf.push(getTextContent(node));
						}
						node = node.nextSibling;
					}
					return buf.join('');
				default:
					return node.nodeValue;
				}
			}
			__set__ = function(object,key,value){
				//console.log(value)
				object['$$'+key] = value
			}
		}
	}catch(e){//ie8
	}

	if(true){
		exports.DOMImplementation = DOMImplementation;
		exports.XMLSerializer = XMLSerializer;
	}


/***/ },
/* 80 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var ast = __webpack_require__(105);
	'use strict';
	var common = __webpack_require__(106);
	var YAMLException = __webpack_require__(107);
	var Mark = __webpack_require__(108);
	var DEFAULT_SAFE_SCHEMA = __webpack_require__(126);
	var DEFAULT_FULL_SCHEMA = __webpack_require__(127);
	var _hasOwnProperty = Object.prototype.hasOwnProperty;
	var CONTEXT_FLOW_IN = 1;
	var CONTEXT_FLOW_OUT = 2;
	var CONTEXT_BLOCK_IN = 3;
	var CONTEXT_BLOCK_OUT = 4;
	var CHOMPING_CLIP = 1;
	var CHOMPING_STRIP = 2;
	var CHOMPING_KEEP = 3;
	var PATTERN_NON_PRINTABLE = /[\x00-\x08\x0B\x0C\x0E-\x1F\x7F-\x84\x86-\x9F\uD800-\uDFFF\uFFFE\uFFFF]/;
	var PATTERN_NON_ASCII_LINE_BREAKS = /[\x85\u2028\u2029]/;
	var PATTERN_FLOW_INDICATORS = /[,\[\]\{\}]/;
	var PATTERN_TAG_HANDLE = /^(?:!|!!|![a-z\-]+!)$/i;
	var PATTERN_TAG_URI = /^(?:!|[^,\[\]\{\}])(?:%[0-9a-f]{2}|[0-9a-z\-#;\/\?:@&=\+\$,_\.!~\*'\(\)\[\]])*$/i;
	function is_EOL(c) {
	    return (c === 0x0A) || (c === 0x0D);
	}
	function is_WHITE_SPACE(c) {
	    return (c === 0x09) || (c === 0x20);
	}
	function is_WS_OR_EOL(c) {
	    return (c === 0x09) ||
	        (c === 0x20) ||
	        (c === 0x0A) ||
	        (c === 0x0D);
	}
	function is_FLOW_INDICATOR(c) {
	    return 0x2C === c ||
	        0x5B === c ||
	        0x5D === c ||
	        0x7B === c ||
	        0x7D === c;
	}
	function fromHexCode(c) {
	    var lc;
	    if ((0x30 <= c) && (c <= 0x39)) {
	        return c - 0x30;
	    }
	    lc = c | 0x20;
	    if ((0x61 <= lc) && (lc <= 0x66)) {
	        return lc - 0x61 + 10;
	    }
	    return -1;
	}
	function escapedHexLen(c) {
	    if (c === 0x78) {
	        return 2;
	    }
	    if (c === 0x75) {
	        return 4;
	    }
	    if (c === 0x55) {
	        return 8;
	    }
	    return 0;
	}
	function fromDecimalCode(c) {
	    if ((0x30 <= c) && (c <= 0x39)) {
	        return c - 0x30;
	    }
	    return -1;
	}
	function simpleEscapeSequence(c) {
	    return (c === 0x30) ? '\x00' :
	        (c === 0x61) ? '\x07' :
	            (c === 0x62) ? '\x08' :
	                (c === 0x74) ? '\x09' :
	                    (c === 0x09) ? '\x09' :
	                        (c === 0x6E) ? '\x0A' :
	                            (c === 0x76) ? '\x0B' :
	                                (c === 0x66) ? '\x0C' :
	                                    (c === 0x72) ? '\x0D' :
	                                        (c === 0x65) ? '\x1B' :
	                                            (c === 0x20) ? ' ' :
	                                                (c === 0x22) ? '\x22' :
	                                                    (c === 0x2F) ? '/' :
	                                                        (c === 0x5C) ? '\x5C' :
	                                                            (c === 0x4E) ? '\x85' :
	                                                                (c === 0x5F) ? '\xA0' :
	                                                                    (c === 0x4C) ? '\u2028' :
	                                                                        (c === 0x50) ? '\u2029' : '';
	}
	function charFromCodepoint(c) {
	    if (c <= 0xFFFF) {
	        return String.fromCharCode(c);
	    }
	    return String.fromCharCode(((c - 0x010000) >> 10) + 0xD800, ((c - 0x010000) & 0x03FF) + 0xDC00);
	}
	var simpleEscapeCheck = new Array(256);
	var simpleEscapeMap = new Array(256);
	for (var i = 0; i < 256; i++) {
	    simpleEscapeCheck[i] = simpleEscapeSequence(i) ? 1 : 0;
	    simpleEscapeMap[i] = simpleEscapeSequence(i);
	}
	var State = (function () {
	    function State(input, options) {
	        this.errorMap = {};
	        this.errors = [];
	        this.input = input;
	        this.filename = options['filename'] || null;
	        this.schema = options['schema'] || DEFAULT_FULL_SCHEMA;
	        this.onWarning = options['onWarning'] || null;
	        this.legacy = options['legacy'] || false;
	        this.implicitTypes = this.schema.compiledImplicit;
	        this.typeMap = this.schema.compiledTypeMap;
	        this.length = input.length;
	        this.position = 0;
	        this.line = 0;
	        this.lineStart = 0;
	        this.lineIndent = 0;
	        this.documents = [];
	    }
	    return State;
	}());
	function generateError(state, message) {
	    return new YAMLException(message, new Mark(state.filename, state.input, state.position, state.line - 1, (state.position - state.lineStart)));
	}
	function throwError(state, message) {
	    var error = generateError(state, message);
	    var hash = error.message + error.mark.position;
	    if (!state.errorMap[hash]) {
	        state.errors.push(error);
	        state.errorMap[hash] = 1;
	    }
	    var or = state.position;
	    while (true) {
	        if (state.position >= state.input.length - 1) {
	            return;
	        }
	        var c = state.input.charAt(state.position);
	        if (c == '\n') {
	            state.position--;
	            if (state.position == or) {
	                state.position += 1;
	            }
	            return;
	        }
	        if (c == '\r') {
	            state.position--;
	            if (state.position == or) {
	                state.position += 1;
	            }
	            return;
	        }
	        state.position++;
	    }
	}
	function throwWarning(state, message) {
	    var error = generateError(state, message);
	    if (state.onWarning) {
	        state.onWarning.call(null, error);
	    }
	    else {
	    }
	}
	var directiveHandlers = {
	    YAML: function handleYamlDirective(state, name, args) {
	        var match, major, minor;
	        if (null !== state.version) {
	            throwError(state, 'duplication of %YAML directive');
	        }
	        if (1 !== args.length) {
	            throwError(state, 'YAML directive accepts exactly one argument');
	        }
	        match = /^([0-9]+)\.([0-9]+)$/.exec(args[0]);
	        if (null === match) {
	            throwError(state, 'ill-formed argument of the YAML directive');
	        }
	        major = parseInt(match[1], 10);
	        minor = parseInt(match[2], 10);
	        if (1 !== major) {
	            throwError(state, 'found incompatible YAML document (version 1.2 is required)');
	        }
	        state.version = args[0];
	        state.checkLineBreaks = (minor < 2);
	        if (2 !== minor) {
	            throwError(state, 'found incompatible YAML document (version 1.2 is required)');
	        }
	    },
	    TAG: function handleTagDirective(state, name, args) {
	        var handle, prefix;
	        if (2 !== args.length) {
	            throwError(state, 'TAG directive accepts exactly two arguments');
	        }
	        handle = args[0];
	        prefix = args[1];
	        if (!PATTERN_TAG_HANDLE.test(handle)) {
	            throwError(state, 'ill-formed tag handle (first argument) of the TAG directive');
	        }
	        if (_hasOwnProperty.call(state.tagMap, handle)) {
	            throwError(state, 'there is a previously declared suffix for "' + handle + '" tag handle');
	        }
	        if (!PATTERN_TAG_URI.test(prefix)) {
	            throwError(state, 'ill-formed tag prefix (second argument) of the TAG directive');
	        }
	        state.tagMap[handle] = prefix;
	    }
	};
	function captureSegment(state, start, end, checkJson) {
	    var _position, _length, _character, _result;
	    var scalar = state.result;
	    if (scalar.startPosition == -1) {
	        scalar.startPosition = start;
	    }
	    if (start < end) {
	        _result = state.input.slice(start, end);
	        if (checkJson) {
	            for (_position = 0, _length = _result.length; _position < _length; _position += 1) {
	                _character = _result.charCodeAt(_position);
	                if (!(0x09 === _character ||
	                    0x20 <= _character && _character <= 0x10FFFF)) {
	                    throwError(state, 'expected valid JSON character');
	                }
	            }
	        }
	        scalar.value += _result;
	        scalar.endPosition = end;
	    }
	}
	function mergeMappings(state, destination, source) {
	    var sourceKeys, key, index, quantity;
	    if (!common.isObject(source)) {
	        throwError(state, 'cannot merge mappings; the provided source object is unacceptable');
	    }
	    sourceKeys = Object.keys(source);
	    for (index = 0, quantity = sourceKeys.length; index < quantity; index += 1) {
	        key = sourceKeys[index];
	        if (!_hasOwnProperty.call(destination, key)) {
	            destination[key] = source[key];
	        }
	    }
	}
	function storeMappingPair(state, _result, keyTag, keyNode, valueNode) {
	    var index, quantity;
	    if (keyNode == null) {
	        return;
	    }
	    if (null === _result) {
	        _result = {
	            startPosition: keyNode.startPosition,
	            endPosition: valueNode.endPosition,
	            parent: null,
	            errors: [],
	            mappings: [], kind: ast.Kind.MAP };
	    }
	    if ('tag:yaml.org,2002:merge' === keyTag) {
	        throw new Error("Should not happen");
	    }
	    else {
	        var mapping = ast.newMapping(keyNode, valueNode);
	        mapping.parent = _result;
	        keyNode.parent = mapping;
	        if (valueNode != null) {
	            valueNode.parent = mapping;
	        }
	        _result.mappings.push(mapping);
	        _result.endPosition = valueNode ? valueNode.endPosition : keyNode.endPosition + 1;
	    }
	    return _result;
	}
	function readLineBreak(state) {
	    var ch;
	    ch = state.input.charCodeAt(state.position);
	    if (0x0A === ch) {
	        state.position++;
	    }
	    else if (0x0D === ch) {
	        state.position++;
	        if (0x0A === state.input.charCodeAt(state.position)) {
	            state.position++;
	        }
	    }
	    else {
	        throwError(state, 'a line break is expected');
	    }
	    state.line += 1;
	    state.lineStart = state.position;
	}
	function skipSeparationSpace(state, allowComments, checkIndent) {
	    var lineBreaks = 0, ch = state.input.charCodeAt(state.position);
	    while (0 !== ch) {
	        while (is_WHITE_SPACE(ch)) {
	            ch = state.input.charCodeAt(++state.position);
	        }
	        if (allowComments && 0x23 === ch) {
	            do {
	                ch = state.input.charCodeAt(++state.position);
	            } while (ch !== 0x0A && ch !== 0x0D && 0 !== ch);
	        }
	        if (is_EOL(ch)) {
	            readLineBreak(state);
	            ch = state.input.charCodeAt(state.position);
	            lineBreaks++;
	            state.lineIndent = 0;
	            while (0x20 === ch) {
	                state.lineIndent++;
	                ch = state.input.charCodeAt(++state.position);
	            }
	        }
	        else {
	            break;
	        }
	    }
	    if (-1 !== checkIndent && 0 !== lineBreaks && state.lineIndent < checkIndent) {
	        throwWarning(state, 'deficient indentation');
	    }
	    return lineBreaks;
	}
	function testDocumentSeparator(state) {
	    var _position = state.position, ch;
	    ch = state.input.charCodeAt(_position);
	    if ((0x2D === ch || 0x2E === ch) &&
	        state.input.charCodeAt(_position + 1) === ch &&
	        state.input.charCodeAt(_position + 2) === ch) {
	        _position += 3;
	        ch = state.input.charCodeAt(_position);
	        if (ch === 0 || is_WS_OR_EOL(ch)) {
	            return true;
	        }
	    }
	    return false;
	}
	function writeFoldedLines(state, scalar, count) {
	    if (1 === count) {
	        scalar.value += ' ';
	    }
	    else if (count > 1) {
	        scalar.value += common.repeat('\n', count - 1);
	    }
	}
	function readPlainScalar(state, nodeIndent, withinFlowCollection) {
	    var preceding, following, captureStart, captureEnd, hasPendingContent, _line, _lineStart, _lineIndent, _kind = state.kind, _result = state.result, ch;
	    var state_result = ast.newScalar();
	    state_result.plainScalar = true;
	    state.result = state_result;
	    ch = state.input.charCodeAt(state.position);
	    if (is_WS_OR_EOL(ch) ||
	        is_FLOW_INDICATOR(ch) ||
	        0x23 === ch ||
	        0x26 === ch ||
	        0x2A === ch ||
	        0x21 === ch ||
	        0x7C === ch ||
	        0x3E === ch ||
	        0x27 === ch ||
	        0x22 === ch ||
	        0x25 === ch ||
	        0x40 === ch ||
	        0x60 === ch) {
	        return false;
	    }
	    if (0x3F === ch || 0x2D === ch) {
	        following = state.input.charCodeAt(state.position + 1);
	        if (is_WS_OR_EOL(following) ||
	            withinFlowCollection && is_FLOW_INDICATOR(following)) {
	            return false;
	        }
	    }
	    state.kind = 'scalar';
	    captureStart = captureEnd = state.position;
	    hasPendingContent = false;
	    while (0 !== ch) {
	        if (0x3A === ch) {
	            following = state.input.charCodeAt(state.position + 1);
	            if (is_WS_OR_EOL(following) ||
	                withinFlowCollection && is_FLOW_INDICATOR(following)) {
	                break;
	            }
	        }
	        else if (0x23 === ch) {
	            preceding = state.input.charCodeAt(state.position - 1);
	            if (is_WS_OR_EOL(preceding)) {
	                break;
	            }
	        }
	        else if ((state.position === state.lineStart && testDocumentSeparator(state)) ||
	            withinFlowCollection && is_FLOW_INDICATOR(ch)) {
	            break;
	        }
	        else if (is_EOL(ch)) {
	            _line = state.line;
	            _lineStart = state.lineStart;
	            _lineIndent = state.lineIndent;
	            skipSeparationSpace(state, false, -1);
	            if (state.lineIndent >= nodeIndent) {
	                hasPendingContent = true;
	                ch = state.input.charCodeAt(state.position);
	                continue;
	            }
	            else {
	                state.position = captureEnd;
	                state.line = _line;
	                state.lineStart = _lineStart;
	                state.lineIndent = _lineIndent;
	                break;
	            }
	        }
	        if (hasPendingContent) {
	            captureSegment(state, captureStart, captureEnd, false);
	            writeFoldedLines(state, state_result, state.line - _line);
	            captureStart = captureEnd = state.position;
	            hasPendingContent = false;
	        }
	        if (!is_WHITE_SPACE(ch)) {
	            captureEnd = state.position + 1;
	        }
	        ch = state.input.charCodeAt(++state.position);
	        if (state.position >= state.input.length) {
	            return false;
	        }
	    }
	    captureSegment(state, captureStart, captureEnd, false);
	    if (state.result.startPosition != -1) {
	        return true;
	    }
	    state.kind = _kind;
	    state.result = _result;
	    return false;
	}
	function readSingleQuotedScalar(state, nodeIndent) {
	    var ch, captureStart, captureEnd;
	    ch = state.input.charCodeAt(state.position);
	    if (0x27 !== ch) {
	        return false;
	    }
	    var scalar = ast.newScalar();
	    state.kind = 'scalar';
	    state.result = scalar;
	    scalar.startPosition = state.position;
	    state.position++;
	    captureStart = captureEnd = state.position;
	    while (0 !== (ch = state.input.charCodeAt(state.position))) {
	        if (0x27 === ch) {
	            captureSegment(state, captureStart, state.position, true);
	            ch = state.input.charCodeAt(++state.position);
	            scalar.endPosition = state.position;
	            if (0x27 === ch) {
	                captureStart = captureEnd = state.position;
	                state.position++;
	            }
	            else {
	                return true;
	            }
	        }
	        else if (is_EOL(ch)) {
	            captureSegment(state, captureStart, captureEnd, true);
	            writeFoldedLines(state, scalar, skipSeparationSpace(state, false, nodeIndent));
	            captureStart = captureEnd = state.position;
	        }
	        else if (state.position === state.lineStart && testDocumentSeparator(state)) {
	            throwError(state, 'unexpected end of the document within a single quoted scalar');
	        }
	        else {
	            state.position++;
	            captureEnd = state.position;
	            scalar.endPosition = state.position;
	        }
	    }
	    throwError(state, 'unexpected end of the stream within a single quoted scalar');
	}
	function readDoubleQuotedScalar(state, nodeIndent) {
	    var captureStart, captureEnd, hexLength, hexResult, tmp, tmpEsc, ch;
	    ch = state.input.charCodeAt(state.position);
	    if (0x22 !== ch) {
	        return false;
	    }
	    state.kind = 'scalar';
	    var scalar = ast.newScalar();
	    scalar.doubleQuoted = true;
	    state.result = scalar;
	    scalar.startPosition = state.position;
	    state.position++;
	    captureStart = captureEnd = state.position;
	    while (0 !== (ch = state.input.charCodeAt(state.position))) {
	        if (0x22 === ch) {
	            captureSegment(state, captureStart, state.position, true);
	            state.position++;
	            scalar.endPosition = state.position;
	            return true;
	        }
	        else if (0x5C === ch) {
	            captureSegment(state, captureStart, state.position, true);
	            ch = state.input.charCodeAt(++state.position);
	            if (is_EOL(ch)) {
	                skipSeparationSpace(state, false, nodeIndent);
	            }
	            else if (ch < 256 && simpleEscapeCheck[ch]) {
	                scalar.value += simpleEscapeMap[ch];
	                state.position++;
	            }
	            else if ((tmp = escapedHexLen(ch)) > 0) {
	                hexLength = tmp;
	                hexResult = 0;
	                for (; hexLength > 0; hexLength--) {
	                    ch = state.input.charCodeAt(++state.position);
	                    if ((tmp = fromHexCode(ch)) >= 0) {
	                        hexResult = (hexResult << 4) + tmp;
	                    }
	                    else {
	                        throwError(state, 'expected hexadecimal character');
	                    }
	                }
	                scalar.value += charFromCodepoint(hexResult);
	                state.position++;
	            }
	            else {
	                throwError(state, 'unknown escape sequence');
	            }
	            captureStart = captureEnd = state.position;
	        }
	        else if (is_EOL(ch)) {
	            captureSegment(state, captureStart, captureEnd, true);
	            writeFoldedLines(state, scalar, skipSeparationSpace(state, false, nodeIndent));
	            captureStart = captureEnd = state.position;
	        }
	        else if (state.position === state.lineStart && testDocumentSeparator(state)) {
	            throwError(state, 'unexpected end of the document within a double quoted scalar');
	        }
	        else {
	            state.position++;
	            captureEnd = state.position;
	        }
	    }
	    throwError(state, 'unexpected end of the stream within a double quoted scalar');
	}
	function readFlowCollection(state, nodeIndent) {
	    var readNext = true, _line, _tag = state.tag, _result, _anchor = state.anchor, following, terminator, isPair, isExplicitPair, isMapping, keyNode, keyTag, valueNode, ch;
	    ch = state.input.charCodeAt(state.position);
	    if (ch === 0x5B) {
	        terminator = 0x5D;
	        isMapping = false;
	        _result = ast.newItems();
	        _result.startPosition = state.position;
	    }
	    else if (ch === 0x7B) {
	        terminator = 0x7D;
	        isMapping = true;
	        _result = ast.newMap();
	        _result.startPosition = state.position;
	    }
	    else {
	        return false;
	    }
	    if (null !== state.anchor) {
	        _result.anchorId = state.anchor;
	        state.anchorMap[state.anchor] = _result;
	    }
	    ch = state.input.charCodeAt(++state.position);
	    while (0 !== ch) {
	        skipSeparationSpace(state, true, nodeIndent);
	        ch = state.input.charCodeAt(state.position);
	        if (ch === terminator) {
	            state.position++;
	            state.tag = _tag;
	            state.anchor = _anchor;
	            state.kind = isMapping ? 'mapping' : 'sequence';
	            state.result = _result;
	            _result.endPosition = state.position;
	            return true;
	        }
	        else if (!readNext) {
	            var p = state.position;
	            throwError(state, 'missed comma between flow collection entries');
	            state.position = p + 1;
	        }
	        keyTag = keyNode = valueNode = null;
	        isPair = isExplicitPair = false;
	        if (0x3F === ch) {
	            following = state.input.charCodeAt(state.position + 1);
	            if (is_WS_OR_EOL(following)) {
	                isPair = isExplicitPair = true;
	                state.position++;
	                skipSeparationSpace(state, true, nodeIndent);
	            }
	        }
	        _line = state.line;
	        composeNode(state, nodeIndent, CONTEXT_FLOW_IN, false, true);
	        keyTag = state.tag;
	        keyNode = state.result;
	        skipSeparationSpace(state, true, nodeIndent);
	        ch = state.input.charCodeAt(state.position);
	        if ((isExplicitPair || state.line === _line) && 0x3A === ch) {
	            isPair = true;
	            ch = state.input.charCodeAt(++state.position);
	            skipSeparationSpace(state, true, nodeIndent);
	            composeNode(state, nodeIndent, CONTEXT_FLOW_IN, false, true);
	            valueNode = state.result;
	        }
	        if (isMapping) {
	            storeMappingPair(state, _result, keyTag, keyNode, valueNode);
	        }
	        else if (isPair) {
	            var mp = storeMappingPair(state, null, keyTag, keyNode, valueNode);
	            mp.parent = _result;
	            _result.items.push(mp);
	        }
	        else {
	            keyNode.parent = _result;
	            _result.items.push(keyNode);
	        }
	        _result.endPosition = state.position + 1;
	        skipSeparationSpace(state, true, nodeIndent);
	        ch = state.input.charCodeAt(state.position);
	        if (0x2C === ch) {
	            readNext = true;
	            ch = state.input.charCodeAt(++state.position);
	        }
	        else {
	            readNext = false;
	        }
	    }
	    throwError(state, 'unexpected end of the stream within a flow collection');
	}
	function readBlockScalar(state, nodeIndent) {
	    var captureStart, folding, chomping = CHOMPING_CLIP, detectedIndent = false, textIndent = nodeIndent, emptyLines = 0, atMoreIndented = false, tmp, ch;
	    ch = state.input.charCodeAt(state.position);
	    if (ch === 0x7C) {
	        folding = false;
	    }
	    else if (ch === 0x3E) {
	        folding = true;
	    }
	    else {
	        return false;
	    }
	    var sc = ast.newScalar();
	    state.kind = 'scalar';
	    state.result = sc;
	    sc.startPosition = state.position;
	    while (0 !== ch) {
	        ch = state.input.charCodeAt(++state.position);
	        if (0x2B === ch || 0x2D === ch) {
	            if (CHOMPING_CLIP === chomping) {
	                chomping = (0x2B === ch) ? CHOMPING_KEEP : CHOMPING_STRIP;
	            }
	            else {
	                throwError(state, 'repeat of a chomping mode identifier');
	            }
	        }
	        else if ((tmp = fromDecimalCode(ch)) >= 0) {
	            if (tmp === 0) {
	                throwError(state, 'bad explicit indentation width of a block scalar; it cannot be less than one');
	            }
	            else if (!detectedIndent) {
	                textIndent = nodeIndent + tmp - 1;
	                detectedIndent = true;
	            }
	            else {
	                throwError(state, 'repeat of an indentation width identifier');
	            }
	        }
	        else {
	            break;
	        }
	    }
	    if (is_WHITE_SPACE(ch)) {
	        do {
	            ch = state.input.charCodeAt(++state.position);
	        } while (is_WHITE_SPACE(ch));
	        if (0x23 === ch) {
	            do {
	                ch = state.input.charCodeAt(++state.position);
	            } while (!is_EOL(ch) && (0 !== ch));
	        }
	    }
	    while (0 !== ch) {
	        readLineBreak(state);
	        state.lineIndent = 0;
	        ch = state.input.charCodeAt(state.position);
	        while ((!detectedIndent || state.lineIndent < textIndent) &&
	            (0x20 === ch)) {
	            state.lineIndent++;
	            ch = state.input.charCodeAt(++state.position);
	        }
	        if (!detectedIndent && state.lineIndent > textIndent) {
	            textIndent = state.lineIndent;
	        }
	        if (is_EOL(ch)) {
	            emptyLines++;
	            continue;
	        }
	        if (state.lineIndent < textIndent) {
	            if (chomping === CHOMPING_KEEP) {
	                sc.value += common.repeat('\n', emptyLines);
	            }
	            else if (chomping === CHOMPING_CLIP) {
	                if (detectedIndent) {
	                    sc.value += '\n';
	                }
	            }
	            break;
	        }
	        if (folding) {
	            if (is_WHITE_SPACE(ch)) {
	                atMoreIndented = true;
	                sc.value += common.repeat('\n', emptyLines + 1);
	            }
	            else if (atMoreIndented) {
	                atMoreIndented = false;
	                sc.value += common.repeat('\n', emptyLines + 1);
	            }
	            else if (0 === emptyLines) {
	                if (detectedIndent) {
	                    sc.value += ' ';
	                }
	            }
	            else {
	                sc.value += common.repeat('\n', emptyLines);
	            }
	        }
	        else if (detectedIndent) {
	            sc.value += common.repeat('\n', emptyLines + 1);
	        }
	        else {
	        }
	        detectedIndent = true;
	        emptyLines = 0;
	        captureStart = state.position;
	        while (!is_EOL(ch) && (0 !== ch)) {
	            ch = state.input.charCodeAt(++state.position);
	        }
	        captureSegment(state, captureStart, state.position, false);
	    }
	    sc.endPosition = state.position;
	    var i = state.position - 1;
	    var needMinus = false;
	    while (true) {
	        var c = state.input[i];
	        if (c == '\r' || c == '\n') {
	            if (needMinus) {
	                i--;
	            }
	            break;
	        }
	        if (c != ' ' && c != '\t') {
	            break;
	        }
	        i--;
	    }
	    sc.endPosition = i;
	    return true;
	}
	function readBlockSequence(state, nodeIndent) {
	    var _line, _tag = state.tag, _anchor = state.anchor, _result = ast.newItems(), following, detected = false, ch;
	    if (null !== state.anchor) {
	        _result.anchorId = state.anchor;
	        state.anchorMap[state.anchor] = _result;
	    }
	    _result.startPosition = state.position;
	    ch = state.input.charCodeAt(state.position);
	    while (0 !== ch) {
	        if (0x2D !== ch) {
	            break;
	        }
	        following = state.input.charCodeAt(state.position + 1);
	        if (!is_WS_OR_EOL(following)) {
	            break;
	        }
	        detected = true;
	        state.position++;
	        if (skipSeparationSpace(state, true, -1)) {
	            if (state.lineIndent <= nodeIndent) {
	                _result.items.push(null);
	                ch = state.input.charCodeAt(state.position);
	                continue;
	            }
	        }
	        _line = state.line;
	        composeNode(state, nodeIndent, CONTEXT_BLOCK_IN, false, true);
	        state.result.parent = _result;
	        _result.items.push(state.result);
	        skipSeparationSpace(state, true, -1);
	        ch = state.input.charCodeAt(state.position);
	        if ((state.line === _line || state.lineIndent > nodeIndent) && (0 !== ch)) {
	            throwError(state, 'bad indentation of a sequence entry');
	        }
	        else if (state.lineIndent < nodeIndent) {
	            break;
	        }
	    }
	    _result.endPosition = state.position;
	    if (detected) {
	        state.tag = _tag;
	        state.anchor = _anchor;
	        state.kind = 'sequence';
	        state.result = _result;
	        _result.endPosition = state.position;
	        return true;
	    }
	    return false;
	}
	function readBlockMapping(state, nodeIndent, flowIndent) {
	    var following, allowCompact, _line, _tag = state.tag, _anchor = state.anchor, _result = ast.newMap(), keyTag = null, keyNode = null, valueNode = null, atExplicitKey = false, detected = false, ch;
	    _result.startPosition = state.position;
	    if (null !== state.anchor) {
	        _result.anchorId = state.anchor;
	        state.anchorMap[state.anchor] = _result;
	    }
	    ch = state.input.charCodeAt(state.position);
	    while (0 !== ch) {
	        following = state.input.charCodeAt(state.position + 1);
	        _line = state.line;
	        if ((0x3F === ch || 0x3A === ch) && is_WS_OR_EOL(following)) {
	            if (0x3F === ch) {
	                if (atExplicitKey) {
	                    storeMappingPair(state, _result, keyTag, keyNode, null);
	                    keyTag = keyNode = valueNode = null;
	                }
	                detected = true;
	                atExplicitKey = true;
	                allowCompact = true;
	            }
	            else if (atExplicitKey) {
	                atExplicitKey = false;
	                allowCompact = true;
	            }
	            else {
	                throwError(state, 'incomplete explicit mapping pair; a key node is missed');
	            }
	            state.position += 1;
	            ch = following;
	        }
	        else if (composeNode(state, flowIndent, CONTEXT_FLOW_OUT, false, true)) {
	            if (state.line === _line) {
	                ch = state.input.charCodeAt(state.position);
	                while (is_WHITE_SPACE(ch)) {
	                    ch = state.input.charCodeAt(++state.position);
	                }
	                if (0x3A === ch) {
	                    ch = state.input.charCodeAt(++state.position);
	                    if (!is_WS_OR_EOL(ch)) {
	                        throwError(state, 'a whitespace character is expected after the key-value separator within a block mapping');
	                    }
	                    if (atExplicitKey) {
	                        storeMappingPair(state, _result, keyTag, keyNode, null);
	                        keyTag = keyNode = valueNode = null;
	                    }
	                    detected = true;
	                    atExplicitKey = false;
	                    allowCompact = false;
	                    keyTag = state.tag;
	                    keyNode = state.result;
	                }
	                else if (detected) {
	                    throwError(state, 'can not read an implicit mapping pair; a colon is missed');
	                }
	                else {
	                    state.tag = _tag;
	                    state.anchor = _anchor;
	                    return true;
	                }
	            }
	            else if (detected) {
	                throwError(state, 'can not read a block mapping entry; a multiline key may not be an implicit key');
	                while (state.position > 0) {
	                    ch = state.input.charCodeAt(--state.position);
	                    if (is_EOL(ch)) {
	                        state.position++;
	                        break;
	                    }
	                }
	            }
	            else {
	                state.tag = _tag;
	                state.anchor = _anchor;
	                return true;
	            }
	        }
	        else {
	            break;
	        }
	        if (state.line === _line || state.lineIndent > nodeIndent) {
	            if (composeNode(state, nodeIndent, CONTEXT_BLOCK_OUT, true, allowCompact)) {
	                if (atExplicitKey) {
	                    keyNode = state.result;
	                }
	                else {
	                    valueNode = state.result;
	                }
	            }
	            if (!atExplicitKey) {
	                storeMappingPair(state, _result, keyTag, keyNode, valueNode);
	                keyTag = keyNode = valueNode = null;
	            }
	            skipSeparationSpace(state, true, -1);
	            ch = state.input.charCodeAt(state.position);
	        }
	        if (state.lineIndent > nodeIndent && (0 !== ch)) {
	            throwError(state, 'bad indentation of a mapping entry');
	        }
	        else if (state.lineIndent < nodeIndent) {
	            break;
	        }
	    }
	    if (atExplicitKey) {
	        storeMappingPair(state, _result, keyTag, keyNode, null);
	    }
	    if (detected) {
	        state.tag = _tag;
	        state.anchor = _anchor;
	        state.kind = 'mapping';
	        state.result = _result;
	    }
	    return detected;
	}
	function readTagProperty(state) {
	    var _position, isVerbatim = false, isNamed = false, tagHandle, tagName, ch;
	    ch = state.input.charCodeAt(state.position);
	    if (0x21 !== ch) {
	        return false;
	    }
	    if (null !== state.tag) {
	        throwError(state, 'duplication of a tag property');
	    }
	    ch = state.input.charCodeAt(++state.position);
	    if (0x3C === ch) {
	        isVerbatim = true;
	        ch = state.input.charCodeAt(++state.position);
	    }
	    else if (0x21 === ch) {
	        isNamed = true;
	        tagHandle = '!!';
	        ch = state.input.charCodeAt(++state.position);
	    }
	    else {
	        tagHandle = '!';
	    }
	    _position = state.position;
	    if (isVerbatim) {
	        do {
	            ch = state.input.charCodeAt(++state.position);
	        } while (0 !== ch && 0x3E !== ch);
	        if (state.position < state.length) {
	            tagName = state.input.slice(_position, state.position);
	            ch = state.input.charCodeAt(++state.position);
	        }
	        else {
	            throwError(state, 'unexpected end of the stream within a verbatim tag');
	        }
	    }
	    else {
	        while (0 !== ch && !is_WS_OR_EOL(ch)) {
	            if (0x21 === ch) {
	                if (!isNamed) {
	                    tagHandle = state.input.slice(_position - 1, state.position + 1);
	                    if (!PATTERN_TAG_HANDLE.test(tagHandle)) {
	                        throwError(state, 'named tag handle cannot contain such characters');
	                    }
	                    isNamed = true;
	                    _position = state.position + 1;
	                }
	                else {
	                    throwError(state, 'tag suffix cannot contain exclamation marks');
	                }
	            }
	            ch = state.input.charCodeAt(++state.position);
	        }
	        tagName = state.input.slice(_position, state.position);
	        if (PATTERN_FLOW_INDICATORS.test(tagName)) {
	            throwError(state, 'tag suffix cannot contain flow indicator characters');
	        }
	    }
	    if (tagName && !PATTERN_TAG_URI.test(tagName)) {
	        throwError(state, 'tag name cannot contain such characters: ' + tagName);
	    }
	    if (isVerbatim) {
	        state.tag = tagName;
	    }
	    else if (_hasOwnProperty.call(state.tagMap, tagHandle)) {
	        state.tag = state.tagMap[tagHandle] + tagName;
	    }
	    else if ('!' === tagHandle) {
	        state.tag = '!' + tagName;
	    }
	    else if ('!!' === tagHandle) {
	        state.tag = 'tag:yaml.org,2002:' + tagName;
	    }
	    else {
	        throwError(state, 'undeclared tag handle "' + tagHandle + '"');
	    }
	    return true;
	}
	function readAnchorProperty(state) {
	    var _position, ch;
	    ch = state.input.charCodeAt(state.position);
	    if (0x26 !== ch) {
	        return false;
	    }
	    if (null !== state.anchor) {
	        throwError(state, 'duplication of an anchor property');
	    }
	    ch = state.input.charCodeAt(++state.position);
	    _position = state.position;
	    while (0 !== ch && !is_WS_OR_EOL(ch) && !is_FLOW_INDICATOR(ch)) {
	        ch = state.input.charCodeAt(++state.position);
	    }
	    if (state.position === _position) {
	        throwError(state, 'name of an anchor node must contain at least one character');
	    }
	    state.anchor = state.input.slice(_position, state.position);
	    return true;
	}
	function readAlias(state) {
	    var _position, alias, len = state.length, input = state.input, ch;
	    ch = state.input.charCodeAt(state.position);
	    if (0x2A !== ch) {
	        return false;
	    }
	    ch = state.input.charCodeAt(++state.position);
	    _position = state.position;
	    while (0 !== ch && !is_WS_OR_EOL(ch) && !is_FLOW_INDICATOR(ch)) {
	        ch = state.input.charCodeAt(++state.position);
	    }
	    if (state.position <= _position) {
	        throwError(state, 'name of an alias node must contain at least one character');
	        state.position = _position + 1;
	    }
	    alias = state.input.slice(_position, state.position);
	    if (!state.anchorMap.hasOwnProperty(alias)) {
	        throwError(state, 'unidentified alias "' + alias + '"');
	        if (state.position <= _position) {
	            state.position = _position + 1;
	        }
	    }
	    state.result = ast.newAnchorRef(alias, _position, state.position, state.anchorMap[alias]);
	    skipSeparationSpace(state, true, -1);
	    return true;
	}
	function composeNode(state, parentIndent, nodeContext, allowToSeek, allowCompact) {
	    var allowBlockStyles, allowBlockScalars, allowBlockCollections, indentStatus = 1, atNewLine = false, hasContent = false, typeIndex, typeQuantity, type, flowIndent, blockIndent, _result;
	    state.tag = null;
	    state.anchor = null;
	    state.kind = null;
	    state.result = null;
	    allowBlockStyles = allowBlockScalars = allowBlockCollections =
	        CONTEXT_BLOCK_OUT === nodeContext ||
	            CONTEXT_BLOCK_IN === nodeContext;
	    if (allowToSeek) {
	        if (skipSeparationSpace(state, true, -1)) {
	            atNewLine = true;
	            if (state.lineIndent > parentIndent) {
	                indentStatus = 1;
	            }
	            else if (state.lineIndent === parentIndent) {
	                indentStatus = 0;
	            }
	            else if (state.lineIndent < parentIndent) {
	                indentStatus = -1;
	            }
	        }
	    }
	    if (1 === indentStatus) {
	        while (readTagProperty(state) || readAnchorProperty(state)) {
	            if (skipSeparationSpace(state, true, -1)) {
	                atNewLine = true;
	                allowBlockCollections = allowBlockStyles;
	                if (state.lineIndent > parentIndent) {
	                    indentStatus = 1;
	                }
	                else if (state.lineIndent === parentIndent) {
	                    indentStatus = 0;
	                }
	                else if (state.lineIndent < parentIndent) {
	                    indentStatus = -1;
	                }
	            }
	            else {
	                allowBlockCollections = false;
	            }
	        }
	    }
	    if (allowBlockCollections) {
	        allowBlockCollections = atNewLine || allowCompact;
	    }
	    if (1 === indentStatus || CONTEXT_BLOCK_OUT === nodeContext) {
	        if (CONTEXT_FLOW_IN === nodeContext || CONTEXT_FLOW_OUT === nodeContext) {
	            flowIndent = parentIndent;
	        }
	        else {
	            flowIndent = parentIndent + 1;
	        }
	        blockIndent = state.position - state.lineStart;
	        if (1 === indentStatus) {
	            if (allowBlockCollections &&
	                (readBlockSequence(state, blockIndent) ||
	                    readBlockMapping(state, blockIndent, flowIndent)) ||
	                readFlowCollection(state, flowIndent)) {
	                hasContent = true;
	            }
	            else {
	                if ((allowBlockScalars && readBlockScalar(state, flowIndent)) ||
	                    readSingleQuotedScalar(state, flowIndent) ||
	                    readDoubleQuotedScalar(state, flowIndent)) {
	                    hasContent = true;
	                }
	                else if (readAlias(state)) {
	                    hasContent = true;
	                    if (null !== state.tag || null !== state.anchor) {
	                        throwError(state, 'alias node should not have any properties');
	                    }
	                }
	                else if (readPlainScalar(state, flowIndent, CONTEXT_FLOW_IN === nodeContext)) {
	                    hasContent = true;
	                    if (null === state.tag) {
	                        state.tag = '?';
	                    }
	                }
	                if (null !== state.anchor) {
	                    state.anchorMap[state.anchor] = state.result;
	                    state.result.anchorId = state.anchor;
	                }
	            }
	        }
	        else if (0 === indentStatus) {
	            hasContent = allowBlockCollections && readBlockSequence(state, blockIndent);
	        }
	    }
	    if (null !== state.tag && '!' !== state.tag) {
	        if (state.tag == "!include") {
	            if (!state.result) {
	                state.result = ast.newScalar();
	                state.result.startPosition = state.position;
	                state.result.endPosition = state.position;
	                throwError(state, "!include without value");
	            }
	            state.result.kind = ast.Kind.INCLUDE_REF;
	        }
	        else if ('?' === state.tag) {
	            for (typeIndex = 0, typeQuantity = state.implicitTypes.length; typeIndex < typeQuantity; typeIndex += 1) {
	                type = state.implicitTypes[typeIndex];
	                var vl = state.result['value'];
	                if (type.resolve(vl)) {
	                    state.result.valueObject = type.construct(state.result['value']);
	                    state.tag = type.tag;
	                    if (null !== state.anchor) {
	                        state.result.anchorId = state.anchor;
	                        state.anchorMap[state.anchor] = state.result;
	                    }
	                    break;
	                }
	            }
	        }
	        else if (_hasOwnProperty.call(state.typeMap, state.tag)) {
	            type = state.typeMap[state.tag];
	            if (null !== state.result && type.kind !== state.kind) {
	                throwError(state, 'unacceptable node kind for !<' + state.tag + '> tag; it should be "' + type.kind + '", not "' + state.kind + '"');
	            }
	            if (!type.resolve(state.result)) {
	                throwError(state, 'cannot resolve a node with !<' + state.tag + '> explicit tag');
	            }
	            else {
	                state.result = type.construct(state.result);
	                if (null !== state.anchor) {
	                    state.result.anchorId = state.anchor;
	                    state.anchorMap[state.anchor] = state.result;
	                }
	            }
	        }
	        else {
	            throwWarning(state, 'unknown tag !<' + state.tag + '>');
	        }
	    }
	    return null !== state.tag || null !== state.anchor || hasContent;
	}
	function readDocument(state) {
	    var documentStart = state.position, _position, directiveName, directiveArgs, hasDirectives = false, ch;
	    state.version = null;
	    state.checkLineBreaks = state.legacy;
	    state.tagMap = {};
	    state.anchorMap = {};
	    while (0 !== (ch = state.input.charCodeAt(state.position))) {
	        skipSeparationSpace(state, true, -1);
	        ch = state.input.charCodeAt(state.position);
	        if (state.lineIndent > 0 || 0x25 !== ch) {
	            break;
	        }
	        hasDirectives = true;
	        ch = state.input.charCodeAt(++state.position);
	        _position = state.position;
	        while (0 !== ch && !is_WS_OR_EOL(ch)) {
	            ch = state.input.charCodeAt(++state.position);
	        }
	        directiveName = state.input.slice(_position, state.position);
	        directiveArgs = [];
	        if (directiveName.length < 1) {
	            throwError(state, 'directive name must not be less than one character in length');
	        }
	        while (0 !== ch) {
	            while (is_WHITE_SPACE(ch)) {
	                ch = state.input.charCodeAt(++state.position);
	            }
	            if (0x23 === ch) {
	                do {
	                    ch = state.input.charCodeAt(++state.position);
	                } while (0 !== ch && !is_EOL(ch));
	                break;
	            }
	            if (is_EOL(ch)) {
	                break;
	            }
	            _position = state.position;
	            while (0 !== ch && !is_WS_OR_EOL(ch)) {
	                ch = state.input.charCodeAt(++state.position);
	            }
	            directiveArgs.push(state.input.slice(_position, state.position));
	        }
	        if (0 !== ch) {
	            readLineBreak(state);
	        }
	        if (_hasOwnProperty.call(directiveHandlers, directiveName)) {
	            directiveHandlers[directiveName](state, directiveName, directiveArgs);
	        }
	        else {
	            throwWarning(state, 'unknown document directive "' + directiveName + '"');
	            state.position++;
	        }
	    }
	    skipSeparationSpace(state, true, -1);
	    if (0 === state.lineIndent &&
	        0x2D === state.input.charCodeAt(state.position) &&
	        0x2D === state.input.charCodeAt(state.position + 1) &&
	        0x2D === state.input.charCodeAt(state.position + 2)) {
	        state.position += 3;
	        skipSeparationSpace(state, true, -1);
	    }
	    else if (hasDirectives) {
	        throwError(state, 'directives end mark is expected');
	    }
	    composeNode(state, state.lineIndent - 1, CONTEXT_BLOCK_OUT, false, true);
	    skipSeparationSpace(state, true, -1);
	    if (state.checkLineBreaks &&
	        PATTERN_NON_ASCII_LINE_BREAKS.test(state.input.slice(documentStart, state.position))) {
	        throwWarning(state, 'non-ASCII line breaks are interpreted as content');
	    }
	    state.documents.push(state.result);
	    if (state.position === state.lineStart && testDocumentSeparator(state)) {
	        if (0x2E === state.input.charCodeAt(state.position)) {
	            state.position += 3;
	            skipSeparationSpace(state, true, -1);
	        }
	        return;
	    }
	    if (state.position < (state.length - 1)) {
	        throwError(state, 'end of the stream or a document separator is expected');
	    }
	    else {
	        return;
	    }
	}
	function loadDocuments(input, options) {
	    input = String(input);
	    options = options || {};
	    if (input.length !== 0) {
	        if (0x0A !== input.charCodeAt(input.length - 1) &&
	            0x0D !== input.charCodeAt(input.length - 1)) {
	            input += '\n';
	        }
	        if (input.charCodeAt(0) === 0xFEFF) {
	            input = input.slice(1);
	        }
	    }
	    var state = new State(input, options);
	    if (PATTERN_NON_PRINTABLE.test(state.input)) {
	        throwError(state, 'the stream contains non-printable characters');
	    }
	    state.input += '\0';
	    while (0x20 === state.input.charCodeAt(state.position)) {
	        state.lineIndent += 1;
	        state.position += 1;
	    }
	    while (state.position < (state.length - 1)) {
	        var q = state.position;
	        readDocument(state);
	        if (state.position <= q) {
	            for (; state.position < state.length - 1; state.position++) {
	                var c = state.input.charAt(state.position);
	                if (c == '\n') {
	                    break;
	                }
	            }
	        }
	    }
	    state.documents.forEach(function (x) { return x.errors = state.errors; });
	    return state.documents;
	}
	function loadAll(input, iterator, options) {
	    var documents = loadDocuments(input, options), index, length;
	    for (index = 0, length = documents.length; index < length; index += 1) {
	        iterator(documents[index]);
	    }
	}
	exports.loadAll = loadAll;
	function load(input, options) {
	    var documents = loadDocuments(input, options), index, length;
	    if (0 === documents.length) {
	        return undefined;
	    }
	    else if (1 === documents.length) {
	        documents[0].endPosition = input.length;
	        return documents[0];
	    }
	    var e = new YAMLException('expected a single document in the stream, but found more');
	    e.mark = new Mark("", "", 0, 0, 0);
	    e.mark.position = documents[0].endPosition;
	    documents[0].errors.push(e);
	    return documents[0];
	}
	exports.load = load;
	function safeLoadAll(input, output, options) {
	    loadAll(input, output, common.extend({ schema: DEFAULT_SAFE_SCHEMA }, options));
	}
	exports.safeLoadAll = safeLoadAll;
	function safeLoad(input, options) {
	    return load(input, common.extend({ schema: DEFAULT_SAFE_SCHEMA }, options));
	}
	exports.safeLoad = safeLoad;
	module.exports.loadAll = loadAll;
	module.exports.load = load;
	module.exports.safeLoadAll = safeLoadAll;
	module.exports.safeLoad = safeLoad;
	//# sourceMappingURL=loader.js.map

/***/ },
/* 81 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';
	var common = __webpack_require__(106);
	var YAMLException = __webpack_require__(107);
	var DEFAULT_FULL_SCHEMA = __webpack_require__(127);
	var DEFAULT_SAFE_SCHEMA = __webpack_require__(126);
	var _toString = Object.prototype.toString;
	var _hasOwnProperty = Object.prototype.hasOwnProperty;
	var CHAR_TAB = 0x09;
	var CHAR_LINE_FEED = 0x0A;
	var CHAR_CARRIAGE_RETURN = 0x0D;
	var CHAR_SPACE = 0x20;
	var CHAR_EXCLAMATION = 0x21;
	var CHAR_DOUBLE_QUOTE = 0x22;
	var CHAR_SHARP = 0x23;
	var CHAR_PERCENT = 0x25;
	var CHAR_AMPERSAND = 0x26;
	var CHAR_SINGLE_QUOTE = 0x27;
	var CHAR_ASTERISK = 0x2A;
	var CHAR_COMMA = 0x2C;
	var CHAR_MINUS = 0x2D;
	var CHAR_COLON = 0x3A;
	var CHAR_GREATER_THAN = 0x3E;
	var CHAR_QUESTION = 0x3F;
	var CHAR_COMMERCIAL_AT = 0x40;
	var CHAR_LEFT_SQUARE_BRACKET = 0x5B;
	var CHAR_RIGHT_SQUARE_BRACKET = 0x5D;
	var CHAR_GRAVE_ACCENT = 0x60;
	var CHAR_LEFT_CURLY_BRACKET = 0x7B;
	var CHAR_VERTICAL_LINE = 0x7C;
	var CHAR_RIGHT_CURLY_BRACKET = 0x7D;
	var ESCAPE_SEQUENCES = {};
	ESCAPE_SEQUENCES[0x00] = '\\0';
	ESCAPE_SEQUENCES[0x07] = '\\a';
	ESCAPE_SEQUENCES[0x08] = '\\b';
	ESCAPE_SEQUENCES[0x09] = '\\t';
	ESCAPE_SEQUENCES[0x0A] = '\\n';
	ESCAPE_SEQUENCES[0x0B] = '\\v';
	ESCAPE_SEQUENCES[0x0C] = '\\f';
	ESCAPE_SEQUENCES[0x0D] = '\\r';
	ESCAPE_SEQUENCES[0x1B] = '\\e';
	ESCAPE_SEQUENCES[0x22] = '\\"';
	ESCAPE_SEQUENCES[0x5C] = '\\\\';
	ESCAPE_SEQUENCES[0x85] = '\\N';
	ESCAPE_SEQUENCES[0xA0] = '\\_';
	ESCAPE_SEQUENCES[0x2028] = '\\L';
	ESCAPE_SEQUENCES[0x2029] = '\\P';
	var DEPRECATED_BOOLEANS_SYNTAX = [
	    'y', 'Y', 'yes', 'Yes', 'YES', 'on', 'On', 'ON',
	    'n', 'N', 'no', 'No', 'NO', 'off', 'Off', 'OFF'
	];
	function compileStyleMap(schema, map) {
	    var result, keys, index, length, tag, style, type;
	    if (null === map) {
	        return {};
	    }
	    result = {};
	    keys = Object.keys(map);
	    for (index = 0, length = keys.length; index < length; index += 1) {
	        tag = keys[index];
	        style = String(map[tag]);
	        if ('!!' === tag.slice(0, 2)) {
	            tag = 'tag:yaml.org,2002:' + tag.slice(2);
	        }
	        type = schema.compiledTypeMap[tag];
	        if (type && _hasOwnProperty.call(type.styleAliases, style)) {
	            style = type.styleAliases[style];
	        }
	        result[tag] = style;
	    }
	    return result;
	}
	function encodeHex(character) {
	    var string, handle, length;
	    string = character.toString(16).toUpperCase();
	    if (character <= 0xFF) {
	        handle = 'x';
	        length = 2;
	    }
	    else if (character <= 0xFFFF) {
	        handle = 'u';
	        length = 4;
	    }
	    else if (character <= 0xFFFFFFFF) {
	        handle = 'U';
	        length = 8;
	    }
	    else {
	        throw new YAMLException('code point within a string may not be greater than 0xFFFFFFFF');
	    }
	    return '\\' + handle + common.repeat('0', length - string.length) + string;
	}
	function State(options) {
	    this.schema = options['schema'] || DEFAULT_FULL_SCHEMA;
	    this.indent = Math.max(1, (options['indent'] || 2));
	    this.skipInvalid = options['skipInvalid'] || false;
	    this.flowLevel = (common.isNothing(options['flowLevel']) ? -1 : options['flowLevel']);
	    this.styleMap = compileStyleMap(this.schema, options['styles'] || null);
	    this.implicitTypes = this.schema.compiledImplicit;
	    this.explicitTypes = this.schema.compiledExplicit;
	    this.tag = null;
	    this.result = '';
	    this.duplicates = [];
	    this.usedDuplicates = null;
	}
	function indentString(string, spaces) {
	    var ind = common.repeat(' ', spaces), position = 0, next = -1, result = '', line, length = string.length;
	    while (position < length) {
	        next = string.indexOf('\n', position);
	        if (next === -1) {
	            line = string.slice(position);
	            position = length;
	        }
	        else {
	            line = string.slice(position, next + 1);
	            position = next + 1;
	        }
	        if (line.length && line !== '\n') {
	            result += ind;
	        }
	        result += line;
	    }
	    return result;
	}
	function generateNextLine(state, level) {
	    return '\n' + common.repeat(' ', state.indent * level);
	}
	function testImplicitResolving(state, str) {
	    var index, length, type;
	    for (index = 0, length = state.implicitTypes.length; index < length; index += 1) {
	        type = state.implicitTypes[index];
	        if (type.resolve(str)) {
	            return true;
	        }
	    }
	    return false;
	}
	function StringBuilder(source) {
	    this.source = source;
	    this.result = '';
	    this.checkpoint = 0;
	}
	StringBuilder.prototype.takeUpTo = function (position) {
	    var er;
	    if (position < this.checkpoint) {
	        er = new Error('position should be > checkpoint');
	        er.position = position;
	        er.checkpoint = this.checkpoint;
	        throw er;
	    }
	    this.result += this.source.slice(this.checkpoint, position);
	    this.checkpoint = position;
	    return this;
	};
	StringBuilder.prototype.escapeChar = function () {
	    var character, esc;
	    character = this.source.charCodeAt(this.checkpoint);
	    esc = ESCAPE_SEQUENCES[character] || encodeHex(character);
	    this.result += esc;
	    this.checkpoint += 1;
	    return this;
	};
	StringBuilder.prototype.finish = function () {
	    if (this.source.length > this.checkpoint) {
	        this.takeUpTo(this.source.length);
	    }
	};
	function writeScalar(state, object, level) {
	    var simple, first, spaceWrap, folded, literal, single, double, sawLineFeed, linePosition, longestLine, indent, max, character, position, escapeSeq, hexEsc, previous, lineLength, modifier, trailingLineBreaks, result;
	    if (0 === object.length) {
	        state.dump = "''";
	        return;
	    }
	    if (object.indexOf("!include") == 0) {
	        state.dump = "" + object;
	        return;
	    }
	    if (object.indexOf("!$$$novalue") == 0) {
	        state.dump = "";
	        return;
	    }
	    if (-1 !== DEPRECATED_BOOLEANS_SYNTAX.indexOf(object)) {
	        state.dump = "'" + object + "'";
	        return;
	    }
	    simple = true;
	    first = object.length ? object.charCodeAt(0) : 0;
	    spaceWrap = (CHAR_SPACE === first ||
	        CHAR_SPACE === object.charCodeAt(object.length - 1));
	    if (CHAR_MINUS === first ||
	        CHAR_QUESTION === first ||
	        CHAR_COMMERCIAL_AT === first ||
	        CHAR_GRAVE_ACCENT === first) {
	        simple = false;
	    }
	    if (spaceWrap) {
	        simple = false;
	        folded = false;
	        literal = false;
	    }
	    else {
	        folded = true;
	        literal = true;
	    }
	    single = true;
	    double = new StringBuilder(object);
	    sawLineFeed = false;
	    linePosition = 0;
	    longestLine = 0;
	    indent = state.indent * level;
	    max = 80;
	    if (indent < 40) {
	        max -= indent;
	    }
	    else {
	        max = 40;
	    }
	    for (position = 0; position < object.length; position++) {
	        character = object.charCodeAt(position);
	        if (simple) {
	            if (!simpleChar(character)) {
	                simple = false;
	            }
	            else {
	                continue;
	            }
	        }
	        if (single && character === CHAR_SINGLE_QUOTE) {
	            single = false;
	        }
	        escapeSeq = ESCAPE_SEQUENCES[character];
	        hexEsc = needsHexEscape(character);
	        if (!escapeSeq && !hexEsc) {
	            continue;
	        }
	        if (character !== CHAR_LINE_FEED &&
	            character !== CHAR_DOUBLE_QUOTE &&
	            character !== CHAR_SINGLE_QUOTE) {
	            folded = false;
	            literal = false;
	        }
	        else if (character === CHAR_LINE_FEED) {
	            sawLineFeed = true;
	            single = false;
	            if (position > 0) {
	                previous = object.charCodeAt(position - 1);
	                if (previous === CHAR_SPACE) {
	                    literal = false;
	                    folded = false;
	                }
	            }
	            if (folded) {
	                lineLength = position - linePosition;
	                linePosition = position;
	                if (lineLength > longestLine) {
	                    longestLine = lineLength;
	                }
	            }
	        }
	        if (character !== CHAR_DOUBLE_QUOTE) {
	            single = false;
	        }
	        double.takeUpTo(position);
	        double.escapeChar();
	    }
	    if (simple && testImplicitResolving(state, object)) {
	        simple = false;
	    }
	    modifier = '';
	    if (folded || literal) {
	        trailingLineBreaks = 0;
	        if (object.charCodeAt(object.length - 1) === CHAR_LINE_FEED) {
	            trailingLineBreaks += 1;
	            if (object.charCodeAt(object.length - 2) === CHAR_LINE_FEED) {
	                trailingLineBreaks += 1;
	            }
	        }
	        if (trailingLineBreaks === 0) {
	            modifier = '-';
	        }
	        else if (trailingLineBreaks === 2) {
	            modifier = '+';
	        }
	    }
	    if (literal && longestLine < max) {
	        folded = false;
	    }
	    if (!sawLineFeed) {
	        literal = false;
	    }
	    if (simple) {
	        state.dump = object;
	    }
	    else if (single) {
	        state.dump = '\'' + object + '\'';
	    }
	    else if (folded) {
	        result = fold(object, max);
	        state.dump = '>' + modifier + '\n' + indentString(result, indent);
	    }
	    else if (literal) {
	        if (!modifier) {
	            object = object.replace(/\n$/, '');
	        }
	        state.dump = '|' + modifier + '\n' + indentString(object, indent);
	    }
	    else if (double) {
	        double.finish();
	        state.dump = '"' + double.result + '"';
	    }
	    else {
	        throw new Error('Failed to dump scalar value');
	    }
	    return;
	}
	function fold(object, max) {
	    var result = '', position = 0, length = object.length, trailing = /\n+$/.exec(object), newLine;
	    if (trailing) {
	        length = trailing.index + 1;
	    }
	    while (position < length) {
	        newLine = object.indexOf('\n', position);
	        if (newLine > length || newLine === -1) {
	            if (result) {
	                result += '\n\n';
	            }
	            result += foldLine(object.slice(position, length), max);
	            position = length;
	        }
	        else {
	            if (result) {
	                result += '\n\n';
	            }
	            result += foldLine(object.slice(position, newLine), max);
	            position = newLine + 1;
	        }
	    }
	    if (trailing && trailing[0] !== '\n') {
	        result += trailing[0];
	    }
	    return result;
	}
	function foldLine(line, max) {
	    if (line === '') {
	        return line;
	    }
	    var foldRe = /[^\s] [^\s]/g, result = '', prevMatch = 0, foldStart = 0, match = foldRe.exec(line), index, foldEnd, folded;
	    while (match) {
	        index = match.index;
	        if (index - foldStart > max) {
	            if (prevMatch !== foldStart) {
	                foldEnd = prevMatch;
	            }
	            else {
	                foldEnd = index;
	            }
	            if (result) {
	                result += '\n';
	            }
	            folded = line.slice(foldStart, foldEnd);
	            result += folded;
	            foldStart = foldEnd + 1;
	        }
	        prevMatch = index + 1;
	        match = foldRe.exec(line);
	    }
	    if (result) {
	        result += '\n';
	    }
	    if (foldStart !== prevMatch && line.length - foldStart > max) {
	        result += line.slice(foldStart, prevMatch) + '\n' +
	            line.slice(prevMatch + 1);
	    }
	    else {
	        result += line.slice(foldStart);
	    }
	    return result;
	}
	function simpleChar(character) {
	    return CHAR_TAB !== character &&
	        CHAR_LINE_FEED !== character &&
	        CHAR_CARRIAGE_RETURN !== character &&
	        CHAR_COMMA !== character &&
	        CHAR_LEFT_SQUARE_BRACKET !== character &&
	        CHAR_RIGHT_SQUARE_BRACKET !== character &&
	        CHAR_LEFT_CURLY_BRACKET !== character &&
	        CHAR_RIGHT_CURLY_BRACKET !== character &&
	        CHAR_SHARP !== character &&
	        CHAR_AMPERSAND !== character &&
	        CHAR_ASTERISK !== character &&
	        CHAR_EXCLAMATION !== character &&
	        CHAR_VERTICAL_LINE !== character &&
	        CHAR_GREATER_THAN !== character &&
	        CHAR_SINGLE_QUOTE !== character &&
	        CHAR_DOUBLE_QUOTE !== character &&
	        CHAR_PERCENT !== character &&
	        CHAR_COLON !== character &&
	        !ESCAPE_SEQUENCES[character] &&
	        !needsHexEscape(character);
	}
	function needsHexEscape(character) {
	    return !((0x00020 <= character && character <= 0x00007E) ||
	        (0x00085 === character) ||
	        (0x000A0 <= character && character <= 0x00D7FF) ||
	        (0x0E000 <= character && character <= 0x00FFFD) ||
	        (0x10000 <= character && character <= 0x10FFFF));
	}
	function writeFlowSequence(state, level, object) {
	    var _result = '', _tag = state.tag, index, length;
	    for (index = 0, length = object.length; index < length; index += 1) {
	        if (writeNode(state, level, object[index], false, false)) {
	            if (0 !== index) {
	                _result += ', ';
	            }
	            _result += state.dump;
	        }
	    }
	    state.tag = _tag;
	    state.dump = '[' + _result + ']';
	}
	function writeBlockSequence(state, level, object, compact) {
	    var _result = '', _tag = state.tag, index, length;
	    for (index = 0, length = object.length; index < length; index += 1) {
	        if (writeNode(state, level + 1, object[index], true, true)) {
	            if (!compact || 0 !== index) {
	                _result += generateNextLine(state, level);
	            }
	            _result += '- ' + state.dump;
	        }
	    }
	    state.tag = _tag;
	    state.dump = _result || '[]';
	}
	function writeFlowMapping(state, level, object) {
	    var _result = '', _tag = state.tag, objectKeyList = Object.keys(object), index, length, objectKey, objectValue, pairBuffer;
	    for (index = 0, length = objectKeyList.length; index < length; index += 1) {
	        pairBuffer = '';
	        if (0 !== index) {
	            pairBuffer += ', ';
	        }
	        objectKey = objectKeyList[index];
	        objectValue = object[objectKey];
	        if (!writeNode(state, level, objectKey, false, false)) {
	            continue;
	        }
	        if (state.dump.length > 1024) {
	            pairBuffer += '? ';
	        }
	        pairBuffer += state.dump + ': ';
	        if (!writeNode(state, level, objectValue, false, false)) {
	            continue;
	        }
	        pairBuffer += state.dump;
	        _result += pairBuffer;
	    }
	    state.tag = _tag;
	    state.dump = '{' + _result + '}';
	}
	function writeBlockMapping(state, level, object, compact) {
	    var _result = '', _tag = state.tag, objectKeyList = Object.keys(object), index, length, objectKey, objectValue, explicitPair, pairBuffer;
	    for (index = 0, length = objectKeyList.length; index < length; index += 1) {
	        pairBuffer = '';
	        if (!compact || 0 !== index) {
	            pairBuffer += generateNextLine(state, level);
	        }
	        objectKey = objectKeyList[index];
	        objectValue = object[objectKey];
	        if (!writeNode(state, level + 1, objectKey, true, true)) {
	            continue;
	        }
	        explicitPair = (null !== state.tag && '?' !== state.tag) ||
	            (state.dump && state.dump.length > 1024);
	        if (explicitPair) {
	            if (state.dump && CHAR_LINE_FEED === state.dump.charCodeAt(0)) {
	                pairBuffer += '?';
	            }
	            else {
	                pairBuffer += '? ';
	            }
	        }
	        pairBuffer += state.dump;
	        if (explicitPair) {
	            pairBuffer += generateNextLine(state, level);
	        }
	        if (!writeNode(state, level + 1, objectValue, true, explicitPair)) {
	            continue;
	        }
	        if (state.dump && CHAR_LINE_FEED === state.dump.charCodeAt(0)) {
	            pairBuffer += ':';
	        }
	        else {
	            pairBuffer += ': ';
	        }
	        pairBuffer += state.dump;
	        _result += pairBuffer;
	    }
	    state.tag = _tag;
	    state.dump = _result || '{}';
	}
	function detectType(state, object, explicit) {
	    var _result, typeList, index, length, type, style;
	    typeList = explicit ? state.explicitTypes : state.implicitTypes;
	    for (index = 0, length = typeList.length; index < length; index += 1) {
	        type = typeList[index];
	        if ((type.instanceOf || type.predicate) &&
	            (!type.instanceOf || (('object' === typeof object) && (object instanceof type.instanceOf))) &&
	            (!type.predicate || type.predicate(object))) {
	            state.tag = explicit ? type.tag : '?';
	            if (type.represent) {
	                style = state.styleMap[type.tag] || type.defaultStyle;
	                if ('[object Function]' === _toString.call(type.represent)) {
	                    _result = type.represent(object, style);
	                }
	                else if (_hasOwnProperty.call(type.represent, style)) {
	                    _result = type.represent[style](object, style);
	                }
	                else {
	                    throw new YAMLException('!<' + type.tag + '> tag resolver accepts not "' + style + '" style');
	                }
	                state.dump = _result;
	            }
	            return true;
	        }
	    }
	    return false;
	}
	function writeNode(state, level, object, block, compact) {
	    state.tag = null;
	    state.dump = object;
	    if (!detectType(state, object, false)) {
	        detectType(state, object, true);
	    }
	    var type = _toString.call(state.dump);
	    if (block) {
	        block = (0 > state.flowLevel || state.flowLevel > level);
	    }
	    if ((null !== state.tag && '?' !== state.tag) || (2 !== state.indent && level > 0)) {
	        compact = false;
	    }
	    var objectOrArray = '[object Object]' === type || '[object Array]' === type, duplicateIndex, duplicate;
	    if (objectOrArray) {
	        duplicateIndex = state.duplicates.indexOf(object);
	        duplicate = duplicateIndex !== -1;
	    }
	    if (duplicate && state.usedDuplicates[duplicateIndex]) {
	        state.dump = '*ref_' + duplicateIndex;
	    }
	    else {
	        if (objectOrArray && duplicate && !state.usedDuplicates[duplicateIndex]) {
	            state.usedDuplicates[duplicateIndex] = true;
	        }
	        if ('[object Object]' === type) {
	            if (block && (0 !== Object.keys(state.dump).length)) {
	                writeBlockMapping(state, level, state.dump, compact);
	                if (duplicate) {
	                    state.dump = '&ref_' + duplicateIndex + (0 === level ? '\n' : '') + state.dump;
	                }
	            }
	            else {
	                writeFlowMapping(state, level, state.dump);
	                if (duplicate) {
	                    state.dump = '&ref_' + duplicateIndex + ' ' + state.dump;
	                }
	            }
	        }
	        else if ('[object Array]' === type) {
	            if (block && (0 !== state.dump.length)) {
	                writeBlockSequence(state, level, state.dump, compact);
	                if (duplicate) {
	                    state.dump = '&ref_' + duplicateIndex + (0 === level ? '\n' : '') + state.dump;
	                }
	            }
	            else {
	                writeFlowSequence(state, level, state.dump);
	                if (duplicate) {
	                    state.dump = '&ref_' + duplicateIndex + ' ' + state.dump;
	                }
	            }
	        }
	        else if ('[object String]' === type) {
	            if ('?' !== state.tag) {
	                writeScalar(state, state.dump, level);
	            }
	        }
	        else {
	            if (state.skipInvalid) {
	                return false;
	            }
	            throw new YAMLException('unacceptable kind of an object to dump ' + type);
	        }
	        if (null !== state.tag && '?' !== state.tag) {
	            state.dump = '!<' + state.tag + '> ' + state.dump;
	        }
	    }
	    return true;
	}
	function getDuplicateReferences(object, state) {
	    var objects = [], duplicatesIndexes = [], index, length;
	    inspectNode(object, objects, duplicatesIndexes);
	    for (index = 0, length = duplicatesIndexes.length; index < length; index += 1) {
	        state.duplicates.push(objects[duplicatesIndexes[index]]);
	    }
	    state.usedDuplicates = new Array(length);
	}
	function inspectNode(object, objects, duplicatesIndexes) {
	    var type = _toString.call(object), objectKeyList, index, length;
	    if (null !== object && 'object' === typeof object) {
	        index = objects.indexOf(object);
	        if (-1 !== index) {
	            if (-1 === duplicatesIndexes.indexOf(index)) {
	                duplicatesIndexes.push(index);
	            }
	        }
	        else {
	            objects.push(object);
	            if (Array.isArray(object)) {
	                for (index = 0, length = object.length; index < length; index += 1) {
	                    inspectNode(object[index], objects, duplicatesIndexes);
	                }
	            }
	            else {
	                objectKeyList = Object.keys(object);
	                for (index = 0, length = objectKeyList.length; index < length; index += 1) {
	                    inspectNode(object[objectKeyList[index]], objects, duplicatesIndexes);
	                }
	            }
	        }
	    }
	}
	function dump(input, options) {
	    options = options || {};
	    var state = new State(options);
	    getDuplicateReferences(input, state);
	    if (writeNode(state, 0, input, true, true)) {
	        return state.dump + '\n';
	    }
	    return '';
	}
	exports.dump = dump;
	function safeDump(input, options) {
	    return dump(input, common.extend({ schema: DEFAULT_SAFE_SCHEMA }, options));
	}
	exports.safeDump = safeDump;
	//# sourceMappingURL=dumper.js.map

/***/ },
/* 82 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	var parse = __webpack_require__(151).parse;
	var stringify = __webpack_require__(151).stringify;

	module.exports = handleQs;
	function handleQs(url, query) {
	  url = url.split('?');
	  var start = url[0];
	  var qs = (url[1] || '').split('#')[0];
	  var end = url[1] && url[1].split('#').length > 1 ? '#' + url[1].split('#')[1] : '';

	  var baseQs = parse(qs);
	  for (var i in query) {
	    baseQs[i] = query[i];
	  }
	  qs = stringify(baseQs);
	  if (qs !== '') {
	    qs = '?' + qs;
	  }
	  return start + qs + end;
	}


/***/ },
/* 83 */
/***/ function(module, exports, __webpack_require__) {

	var __WEBPACK_AMD_DEFINE_ARRAY__, __WEBPACK_AMD_DEFINE_RESULT__;//     Underscore.js 1.8.3
	//     http://underscorejs.org
	//     (c) 2009-2015 Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
	//     Underscore may be freely distributed under the MIT license.

	(function() {

	  // Baseline setup
	  // --------------

	  // Establish the root object, `window` in the browser, or `exports` on the server.
	  var root = this;

	  // Save the previous value of the `_` variable.
	  var previousUnderscore = root._;

	  // Save bytes in the minified (but not gzipped) version:
	  var ArrayProto = Array.prototype, ObjProto = Object.prototype, FuncProto = Function.prototype;

	  // Create quick reference variables for speed access to core prototypes.
	  var
	    push             = ArrayProto.push,
	    slice            = ArrayProto.slice,
	    toString         = ObjProto.toString,
	    hasOwnProperty   = ObjProto.hasOwnProperty;

	  // All **ECMAScript 5** native function implementations that we hope to use
	  // are declared here.
	  var
	    nativeIsArray      = Array.isArray,
	    nativeKeys         = Object.keys,
	    nativeBind         = FuncProto.bind,
	    nativeCreate       = Object.create;

	  // Naked function reference for surrogate-prototype-swapping.
	  var Ctor = function(){};

	  // Create a safe reference to the Underscore object for use below.
	  var _ = function(obj) {
	    if (obj instanceof _) return obj;
	    if (!(this instanceof _)) return new _(obj);
	    this._wrapped = obj;
	  };

	  // Export the Underscore object for **Node.js**, with
	  // backwards-compatibility for the old `require()` API. If we're in
	  // the browser, add `_` as a global object.
	  if (true) {
	    if (typeof module !== 'undefined' && module.exports) {
	      exports = module.exports = _;
	    }
	    exports._ = _;
	  } else {
	    root._ = _;
	  }

	  // Current version.
	  _.VERSION = '1.8.3';

	  // Internal function that returns an efficient (for current engines) version
	  // of the passed-in callback, to be repeatedly applied in other Underscore
	  // functions.
	  var optimizeCb = function(func, context, argCount) {
	    if (context === void 0) return func;
	    switch (argCount == null ? 3 : argCount) {
	      case 1: return function(value) {
	        return func.call(context, value);
	      };
	      case 2: return function(value, other) {
	        return func.call(context, value, other);
	      };
	      case 3: return function(value, index, collection) {
	        return func.call(context, value, index, collection);
	      };
	      case 4: return function(accumulator, value, index, collection) {
	        return func.call(context, accumulator, value, index, collection);
	      };
	    }
	    return function() {
	      return func.apply(context, arguments);
	    };
	  };

	  // A mostly-internal function to generate callbacks that can be applied
	  // to each element in a collection, returning the desired result — either
	  // identity, an arbitrary callback, a property matcher, or a property accessor.
	  var cb = function(value, context, argCount) {
	    if (value == null) return _.identity;
	    if (_.isFunction(value)) return optimizeCb(value, context, argCount);
	    if (_.isObject(value)) return _.matcher(value);
	    return _.property(value);
	  };
	  _.iteratee = function(value, context) {
	    return cb(value, context, Infinity);
	  };

	  // An internal function for creating assigner functions.
	  var createAssigner = function(keysFunc, undefinedOnly) {
	    return function(obj) {
	      var length = arguments.length;
	      if (length < 2 || obj == null) return obj;
	      for (var index = 1; index < length; index++) {
	        var source = arguments[index],
	            keys = keysFunc(source),
	            l = keys.length;
	        for (var i = 0; i < l; i++) {
	          var key = keys[i];
	          if (!undefinedOnly || obj[key] === void 0) obj[key] = source[key];
	        }
	      }
	      return obj;
	    };
	  };

	  // An internal function for creating a new object that inherits from another.
	  var baseCreate = function(prototype) {
	    if (!_.isObject(prototype)) return {};
	    if (nativeCreate) return nativeCreate(prototype);
	    Ctor.prototype = prototype;
	    var result = new Ctor;
	    Ctor.prototype = null;
	    return result;
	  };

	  var property = function(key) {
	    return function(obj) {
	      return obj == null ? void 0 : obj[key];
	    };
	  };

	  // Helper for collection methods to determine whether a collection
	  // should be iterated as an array or as an object
	  // Related: http://people.mozilla.org/~jorendorff/es6-draft.html#sec-tolength
	  // Avoids a very nasty iOS 8 JIT bug on ARM-64. #2094
	  var MAX_ARRAY_INDEX = Math.pow(2, 53) - 1;
	  var getLength = property('length');
	  var isArrayLike = function(collection) {
	    var length = getLength(collection);
	    return typeof length == 'number' && length >= 0 && length <= MAX_ARRAY_INDEX;
	  };

	  // Collection Functions
	  // --------------------

	  // The cornerstone, an `each` implementation, aka `forEach`.
	  // Handles raw objects in addition to array-likes. Treats all
	  // sparse array-likes as if they were dense.
	  _.each = _.forEach = function(obj, iteratee, context) {
	    iteratee = optimizeCb(iteratee, context);
	    var i, length;
	    if (isArrayLike(obj)) {
	      for (i = 0, length = obj.length; i < length; i++) {
	        iteratee(obj[i], i, obj);
	      }
	    } else {
	      var keys = _.keys(obj);
	      for (i = 0, length = keys.length; i < length; i++) {
	        iteratee(obj[keys[i]], keys[i], obj);
	      }
	    }
	    return obj;
	  };

	  // Return the results of applying the iteratee to each element.
	  _.map = _.collect = function(obj, iteratee, context) {
	    iteratee = cb(iteratee, context);
	    var keys = !isArrayLike(obj) && _.keys(obj),
	        length = (keys || obj).length,
	        results = Array(length);
	    for (var index = 0; index < length; index++) {
	      var currentKey = keys ? keys[index] : index;
	      results[index] = iteratee(obj[currentKey], currentKey, obj);
	    }
	    return results;
	  };

	  // Create a reducing function iterating left or right.
	  function createReduce(dir) {
	    // Optimized iterator function as using arguments.length
	    // in the main function will deoptimize the, see #1991.
	    function iterator(obj, iteratee, memo, keys, index, length) {
	      for (; index >= 0 && index < length; index += dir) {
	        var currentKey = keys ? keys[index] : index;
	        memo = iteratee(memo, obj[currentKey], currentKey, obj);
	      }
	      return memo;
	    }

	    return function(obj, iteratee, memo, context) {
	      iteratee = optimizeCb(iteratee, context, 4);
	      var keys = !isArrayLike(obj) && _.keys(obj),
	          length = (keys || obj).length,
	          index = dir > 0 ? 0 : length - 1;
	      // Determine the initial value if none is provided.
	      if (arguments.length < 3) {
	        memo = obj[keys ? keys[index] : index];
	        index += dir;
	      }
	      return iterator(obj, iteratee, memo, keys, index, length);
	    };
	  }

	  // **Reduce** builds up a single result from a list of values, aka `inject`,
	  // or `foldl`.
	  _.reduce = _.foldl = _.inject = createReduce(1);

	  // The right-associative version of reduce, also known as `foldr`.
	  _.reduceRight = _.foldr = createReduce(-1);

	  // Return the first value which passes a truth test. Aliased as `detect`.
	  _.find = _.detect = function(obj, predicate, context) {
	    var key;
	    if (isArrayLike(obj)) {
	      key = _.findIndex(obj, predicate, context);
	    } else {
	      key = _.findKey(obj, predicate, context);
	    }
	    if (key !== void 0 && key !== -1) return obj[key];
	  };

	  // Return all the elements that pass a truth test.
	  // Aliased as `select`.
	  _.filter = _.select = function(obj, predicate, context) {
	    var results = [];
	    predicate = cb(predicate, context);
	    _.each(obj, function(value, index, list) {
	      if (predicate(value, index, list)) results.push(value);
	    });
	    return results;
	  };

	  // Return all the elements for which a truth test fails.
	  _.reject = function(obj, predicate, context) {
	    return _.filter(obj, _.negate(cb(predicate)), context);
	  };

	  // Determine whether all of the elements match a truth test.
	  // Aliased as `all`.
	  _.every = _.all = function(obj, predicate, context) {
	    predicate = cb(predicate, context);
	    var keys = !isArrayLike(obj) && _.keys(obj),
	        length = (keys || obj).length;
	    for (var index = 0; index < length; index++) {
	      var currentKey = keys ? keys[index] : index;
	      if (!predicate(obj[currentKey], currentKey, obj)) return false;
	    }
	    return true;
	  };

	  // Determine if at least one element in the object matches a truth test.
	  // Aliased as `any`.
	  _.some = _.any = function(obj, predicate, context) {
	    predicate = cb(predicate, context);
	    var keys = !isArrayLike(obj) && _.keys(obj),
	        length = (keys || obj).length;
	    for (var index = 0; index < length; index++) {
	      var currentKey = keys ? keys[index] : index;
	      if (predicate(obj[currentKey], currentKey, obj)) return true;
	    }
	    return false;
	  };

	  // Determine if the array or object contains a given item (using `===`).
	  // Aliased as `includes` and `include`.
	  _.contains = _.includes = _.include = function(obj, item, fromIndex, guard) {
	    if (!isArrayLike(obj)) obj = _.values(obj);
	    if (typeof fromIndex != 'number' || guard) fromIndex = 0;
	    return _.indexOf(obj, item, fromIndex) >= 0;
	  };

	  // Invoke a method (with arguments) on every item in a collection.
	  _.invoke = function(obj, method) {
	    var args = slice.call(arguments, 2);
	    var isFunc = _.isFunction(method);
	    return _.map(obj, function(value) {
	      var func = isFunc ? method : value[method];
	      return func == null ? func : func.apply(value, args);
	    });
	  };

	  // Convenience version of a common use case of `map`: fetching a property.
	  _.pluck = function(obj, key) {
	    return _.map(obj, _.property(key));
	  };

	  // Convenience version of a common use case of `filter`: selecting only objects
	  // containing specific `key:value` pairs.
	  _.where = function(obj, attrs) {
	    return _.filter(obj, _.matcher(attrs));
	  };

	  // Convenience version of a common use case of `find`: getting the first object
	  // containing specific `key:value` pairs.
	  _.findWhere = function(obj, attrs) {
	    return _.find(obj, _.matcher(attrs));
	  };

	  // Return the maximum element (or element-based computation).
	  _.max = function(obj, iteratee, context) {
	    var result = -Infinity, lastComputed = -Infinity,
	        value, computed;
	    if (iteratee == null && obj != null) {
	      obj = isArrayLike(obj) ? obj : _.values(obj);
	      for (var i = 0, length = obj.length; i < length; i++) {
	        value = obj[i];
	        if (value > result) {
	          result = value;
	        }
	      }
	    } else {
	      iteratee = cb(iteratee, context);
	      _.each(obj, function(value, index, list) {
	        computed = iteratee(value, index, list);
	        if (computed > lastComputed || computed === -Infinity && result === -Infinity) {
	          result = value;
	          lastComputed = computed;
	        }
	      });
	    }
	    return result;
	  };

	  // Return the minimum element (or element-based computation).
	  _.min = function(obj, iteratee, context) {
	    var result = Infinity, lastComputed = Infinity,
	        value, computed;
	    if (iteratee == null && obj != null) {
	      obj = isArrayLike(obj) ? obj : _.values(obj);
	      for (var i = 0, length = obj.length; i < length; i++) {
	        value = obj[i];
	        if (value < result) {
	          result = value;
	        }
	      }
	    } else {
	      iteratee = cb(iteratee, context);
	      _.each(obj, function(value, index, list) {
	        computed = iteratee(value, index, list);
	        if (computed < lastComputed || computed === Infinity && result === Infinity) {
	          result = value;
	          lastComputed = computed;
	        }
	      });
	    }
	    return result;
	  };

	  // Shuffle a collection, using the modern version of the
	  // [Fisher-Yates shuffle](http://en.wikipedia.org/wiki/Fisher–Yates_shuffle).
	  _.shuffle = function(obj) {
	    var set = isArrayLike(obj) ? obj : _.values(obj);
	    var length = set.length;
	    var shuffled = Array(length);
	    for (var index = 0, rand; index < length; index++) {
	      rand = _.random(0, index);
	      if (rand !== index) shuffled[index] = shuffled[rand];
	      shuffled[rand] = set[index];
	    }
	    return shuffled;
	  };

	  // Sample **n** random values from a collection.
	  // If **n** is not specified, returns a single random element.
	  // The internal `guard` argument allows it to work with `map`.
	  _.sample = function(obj, n, guard) {
	    if (n == null || guard) {
	      if (!isArrayLike(obj)) obj = _.values(obj);
	      return obj[_.random(obj.length - 1)];
	    }
	    return _.shuffle(obj).slice(0, Math.max(0, n));
	  };

	  // Sort the object's values by a criterion produced by an iteratee.
	  _.sortBy = function(obj, iteratee, context) {
	    iteratee = cb(iteratee, context);
	    return _.pluck(_.map(obj, function(value, index, list) {
	      return {
	        value: value,
	        index: index,
	        criteria: iteratee(value, index, list)
	      };
	    }).sort(function(left, right) {
	      var a = left.criteria;
	      var b = right.criteria;
	      if (a !== b) {
	        if (a > b || a === void 0) return 1;
	        if (a < b || b === void 0) return -1;
	      }
	      return left.index - right.index;
	    }), 'value');
	  };

	  // An internal function used for aggregate "group by" operations.
	  var group = function(behavior) {
	    return function(obj, iteratee, context) {
	      var result = {};
	      iteratee = cb(iteratee, context);
	      _.each(obj, function(value, index) {
	        var key = iteratee(value, index, obj);
	        behavior(result, value, key);
	      });
	      return result;
	    };
	  };

	  // Groups the object's values by a criterion. Pass either a string attribute
	  // to group by, or a function that returns the criterion.
	  _.groupBy = group(function(result, value, key) {
	    if (_.has(result, key)) result[key].push(value); else result[key] = [value];
	  });

	  // Indexes the object's values by a criterion, similar to `groupBy`, but for
	  // when you know that your index values will be unique.
	  _.indexBy = group(function(result, value, key) {
	    result[key] = value;
	  });

	  // Counts instances of an object that group by a certain criterion. Pass
	  // either a string attribute to count by, or a function that returns the
	  // criterion.
	  _.countBy = group(function(result, value, key) {
	    if (_.has(result, key)) result[key]++; else result[key] = 1;
	  });

	  // Safely create a real, live array from anything iterable.
	  _.toArray = function(obj) {
	    if (!obj) return [];
	    if (_.isArray(obj)) return slice.call(obj);
	    if (isArrayLike(obj)) return _.map(obj, _.identity);
	    return _.values(obj);
	  };

	  // Return the number of elements in an object.
	  _.size = function(obj) {
	    if (obj == null) return 0;
	    return isArrayLike(obj) ? obj.length : _.keys(obj).length;
	  };

	  // Split a collection into two arrays: one whose elements all satisfy the given
	  // predicate, and one whose elements all do not satisfy the predicate.
	  _.partition = function(obj, predicate, context) {
	    predicate = cb(predicate, context);
	    var pass = [], fail = [];
	    _.each(obj, function(value, key, obj) {
	      (predicate(value, key, obj) ? pass : fail).push(value);
	    });
	    return [pass, fail];
	  };

	  // Array Functions
	  // ---------------

	  // Get the first element of an array. Passing **n** will return the first N
	  // values in the array. Aliased as `head` and `take`. The **guard** check
	  // allows it to work with `_.map`.
	  _.first = _.head = _.take = function(array, n, guard) {
	    if (array == null) return void 0;
	    if (n == null || guard) return array[0];
	    return _.initial(array, array.length - n);
	  };

	  // Returns everything but the last entry of the array. Especially useful on
	  // the arguments object. Passing **n** will return all the values in
	  // the array, excluding the last N.
	  _.initial = function(array, n, guard) {
	    return slice.call(array, 0, Math.max(0, array.length - (n == null || guard ? 1 : n)));
	  };

	  // Get the last element of an array. Passing **n** will return the last N
	  // values in the array.
	  _.last = function(array, n, guard) {
	    if (array == null) return void 0;
	    if (n == null || guard) return array[array.length - 1];
	    return _.rest(array, Math.max(0, array.length - n));
	  };

	  // Returns everything but the first entry of the array. Aliased as `tail` and `drop`.
	  // Especially useful on the arguments object. Passing an **n** will return
	  // the rest N values in the array.
	  _.rest = _.tail = _.drop = function(array, n, guard) {
	    return slice.call(array, n == null || guard ? 1 : n);
	  };

	  // Trim out all falsy values from an array.
	  _.compact = function(array) {
	    return _.filter(array, _.identity);
	  };

	  // Internal implementation of a recursive `flatten` function.
	  var flatten = function(input, shallow, strict, startIndex) {
	    var output = [], idx = 0;
	    for (var i = startIndex || 0, length = getLength(input); i < length; i++) {
	      var value = input[i];
	      if (isArrayLike(value) && (_.isArray(value) || _.isArguments(value))) {
	        //flatten current level of array or arguments object
	        if (!shallow) value = flatten(value, shallow, strict);
	        var j = 0, len = value.length;
	        output.length += len;
	        while (j < len) {
	          output[idx++] = value[j++];
	        }
	      } else if (!strict) {
	        output[idx++] = value;
	      }
	    }
	    return output;
	  };

	  // Flatten out an array, either recursively (by default), or just one level.
	  _.flatten = function(array, shallow) {
	    return flatten(array, shallow, false);
	  };

	  // Return a version of the array that does not contain the specified value(s).
	  _.without = function(array) {
	    return _.difference(array, slice.call(arguments, 1));
	  };

	  // Produce a duplicate-free version of the array. If the array has already
	  // been sorted, you have the option of using a faster algorithm.
	  // Aliased as `unique`.
	  _.uniq = _.unique = function(array, isSorted, iteratee, context) {
	    if (!_.isBoolean(isSorted)) {
	      context = iteratee;
	      iteratee = isSorted;
	      isSorted = false;
	    }
	    if (iteratee != null) iteratee = cb(iteratee, context);
	    var result = [];
	    var seen = [];
	    for (var i = 0, length = getLength(array); i < length; i++) {
	      var value = array[i],
	          computed = iteratee ? iteratee(value, i, array) : value;
	      if (isSorted) {
	        if (!i || seen !== computed) result.push(value);
	        seen = computed;
	      } else if (iteratee) {
	        if (!_.contains(seen, computed)) {
	          seen.push(computed);
	          result.push(value);
	        }
	      } else if (!_.contains(result, value)) {
	        result.push(value);
	      }
	    }
	    return result;
	  };

	  // Produce an array that contains the union: each distinct element from all of
	  // the passed-in arrays.
	  _.union = function() {
	    return _.uniq(flatten(arguments, true, true));
	  };

	  // Produce an array that contains every item shared between all the
	  // passed-in arrays.
	  _.intersection = function(array) {
	    var result = [];
	    var argsLength = arguments.length;
	    for (var i = 0, length = getLength(array); i < length; i++) {
	      var item = array[i];
	      if (_.contains(result, item)) continue;
	      for (var j = 1; j < argsLength; j++) {
	        if (!_.contains(arguments[j], item)) break;
	      }
	      if (j === argsLength) result.push(item);
	    }
	    return result;
	  };

	  // Take the difference between one array and a number of other arrays.
	  // Only the elements present in just the first array will remain.
	  _.difference = function(array) {
	    var rest = flatten(arguments, true, true, 1);
	    return _.filter(array, function(value){
	      return !_.contains(rest, value);
	    });
	  };

	  // Zip together multiple lists into a single array -- elements that share
	  // an index go together.
	  _.zip = function() {
	    return _.unzip(arguments);
	  };

	  // Complement of _.zip. Unzip accepts an array of arrays and groups
	  // each array's elements on shared indices
	  _.unzip = function(array) {
	    var length = array && _.max(array, getLength).length || 0;
	    var result = Array(length);

	    for (var index = 0; index < length; index++) {
	      result[index] = _.pluck(array, index);
	    }
	    return result;
	  };

	  // Converts lists into objects. Pass either a single array of `[key, value]`
	  // pairs, or two parallel arrays of the same length -- one of keys, and one of
	  // the corresponding values.
	  _.object = function(list, values) {
	    var result = {};
	    for (var i = 0, length = getLength(list); i < length; i++) {
	      if (values) {
	        result[list[i]] = values[i];
	      } else {
	        result[list[i][0]] = list[i][1];
	      }
	    }
	    return result;
	  };

	  // Generator function to create the findIndex and findLastIndex functions
	  function createPredicateIndexFinder(dir) {
	    return function(array, predicate, context) {
	      predicate = cb(predicate, context);
	      var length = getLength(array);
	      var index = dir > 0 ? 0 : length - 1;
	      for (; index >= 0 && index < length; index += dir) {
	        if (predicate(array[index], index, array)) return index;
	      }
	      return -1;
	    };
	  }

	  // Returns the first index on an array-like that passes a predicate test
	  _.findIndex = createPredicateIndexFinder(1);
	  _.findLastIndex = createPredicateIndexFinder(-1);

	  // Use a comparator function to figure out the smallest index at which
	  // an object should be inserted so as to maintain order. Uses binary search.
	  _.sortedIndex = function(array, obj, iteratee, context) {
	    iteratee = cb(iteratee, context, 1);
	    var value = iteratee(obj);
	    var low = 0, high = getLength(array);
	    while (low < high) {
	      var mid = Math.floor((low + high) / 2);
	      if (iteratee(array[mid]) < value) low = mid + 1; else high = mid;
	    }
	    return low;
	  };

	  // Generator function to create the indexOf and lastIndexOf functions
	  function createIndexFinder(dir, predicateFind, sortedIndex) {
	    return function(array, item, idx) {
	      var i = 0, length = getLength(array);
	      if (typeof idx == 'number') {
	        if (dir > 0) {
	            i = idx >= 0 ? idx : Math.max(idx + length, i);
	        } else {
	            length = idx >= 0 ? Math.min(idx + 1, length) : idx + length + 1;
	        }
	      } else if (sortedIndex && idx && length) {
	        idx = sortedIndex(array, item);
	        return array[idx] === item ? idx : -1;
	      }
	      if (item !== item) {
	        idx = predicateFind(slice.call(array, i, length), _.isNaN);
	        return idx >= 0 ? idx + i : -1;
	      }
	      for (idx = dir > 0 ? i : length - 1; idx >= 0 && idx < length; idx += dir) {
	        if (array[idx] === item) return idx;
	      }
	      return -1;
	    };
	  }

	  // Return the position of the first occurrence of an item in an array,
	  // or -1 if the item is not included in the array.
	  // If the array is large and already in sort order, pass `true`
	  // for **isSorted** to use binary search.
	  _.indexOf = createIndexFinder(1, _.findIndex, _.sortedIndex);
	  _.lastIndexOf = createIndexFinder(-1, _.findLastIndex);

	  // Generate an integer Array containing an arithmetic progression. A port of
	  // the native Python `range()` function. See
	  // [the Python documentation](http://docs.python.org/library/functions.html#range).
	  _.range = function(start, stop, step) {
	    if (stop == null) {
	      stop = start || 0;
	      start = 0;
	    }
	    step = step || 1;

	    var length = Math.max(Math.ceil((stop - start) / step), 0);
	    var range = Array(length);

	    for (var idx = 0; idx < length; idx++, start += step) {
	      range[idx] = start;
	    }

	    return range;
	  };

	  // Function (ahem) Functions
	  // ------------------

	  // Determines whether to execute a function as a constructor
	  // or a normal function with the provided arguments
	  var executeBound = function(sourceFunc, boundFunc, context, callingContext, args) {
	    if (!(callingContext instanceof boundFunc)) return sourceFunc.apply(context, args);
	    var self = baseCreate(sourceFunc.prototype);
	    var result = sourceFunc.apply(self, args);
	    if (_.isObject(result)) return result;
	    return self;
	  };

	  // Create a function bound to a given object (assigning `this`, and arguments,
	  // optionally). Delegates to **ECMAScript 5**'s native `Function.bind` if
	  // available.
	  _.bind = function(func, context) {
	    if (nativeBind && func.bind === nativeBind) return nativeBind.apply(func, slice.call(arguments, 1));
	    if (!_.isFunction(func)) throw new TypeError('Bind must be called on a function');
	    var args = slice.call(arguments, 2);
	    var bound = function() {
	      return executeBound(func, bound, context, this, args.concat(slice.call(arguments)));
	    };
	    return bound;
	  };

	  // Partially apply a function by creating a version that has had some of its
	  // arguments pre-filled, without changing its dynamic `this` context. _ acts
	  // as a placeholder, allowing any combination of arguments to be pre-filled.
	  _.partial = function(func) {
	    var boundArgs = slice.call(arguments, 1);
	    var bound = function() {
	      var position = 0, length = boundArgs.length;
	      var args = Array(length);
	      for (var i = 0; i < length; i++) {
	        args[i] = boundArgs[i] === _ ? arguments[position++] : boundArgs[i];
	      }
	      while (position < arguments.length) args.push(arguments[position++]);
	      return executeBound(func, bound, this, this, args);
	    };
	    return bound;
	  };

	  // Bind a number of an object's methods to that object. Remaining arguments
	  // are the method names to be bound. Useful for ensuring that all callbacks
	  // defined on an object belong to it.
	  _.bindAll = function(obj) {
	    var i, length = arguments.length, key;
	    if (length <= 1) throw new Error('bindAll must be passed function names');
	    for (i = 1; i < length; i++) {
	      key = arguments[i];
	      obj[key] = _.bind(obj[key], obj);
	    }
	    return obj;
	  };

	  // Memoize an expensive function by storing its results.
	  _.memoize = function(func, hasher) {
	    var memoize = function(key) {
	      var cache = memoize.cache;
	      var address = '' + (hasher ? hasher.apply(this, arguments) : key);
	      if (!_.has(cache, address)) cache[address] = func.apply(this, arguments);
	      return cache[address];
	    };
	    memoize.cache = {};
	    return memoize;
	  };

	  // Delays a function for the given number of milliseconds, and then calls
	  // it with the arguments supplied.
	  _.delay = function(func, wait) {
	    var args = slice.call(arguments, 2);
	    return setTimeout(function(){
	      return func.apply(null, args);
	    }, wait);
	  };

	  // Defers a function, scheduling it to run after the current call stack has
	  // cleared.
	  _.defer = _.partial(_.delay, _, 1);

	  // Returns a function, that, when invoked, will only be triggered at most once
	  // during a given window of time. Normally, the throttled function will run
	  // as much as it can, without ever going more than once per `wait` duration;
	  // but if you'd like to disable the execution on the leading edge, pass
	  // `{leading: false}`. To disable execution on the trailing edge, ditto.
	  _.throttle = function(func, wait, options) {
	    var context, args, result;
	    var timeout = null;
	    var previous = 0;
	    if (!options) options = {};
	    var later = function() {
	      previous = options.leading === false ? 0 : _.now();
	      timeout = null;
	      result = func.apply(context, args);
	      if (!timeout) context = args = null;
	    };
	    return function() {
	      var now = _.now();
	      if (!previous && options.leading === false) previous = now;
	      var remaining = wait - (now - previous);
	      context = this;
	      args = arguments;
	      if (remaining <= 0 || remaining > wait) {
	        if (timeout) {
	          clearTimeout(timeout);
	          timeout = null;
	        }
	        previous = now;
	        result = func.apply(context, args);
	        if (!timeout) context = args = null;
	      } else if (!timeout && options.trailing !== false) {
	        timeout = setTimeout(later, remaining);
	      }
	      return result;
	    };
	  };

	  // Returns a function, that, as long as it continues to be invoked, will not
	  // be triggered. The function will be called after it stops being called for
	  // N milliseconds. If `immediate` is passed, trigger the function on the
	  // leading edge, instead of the trailing.
	  _.debounce = function(func, wait, immediate) {
	    var timeout, args, context, timestamp, result;

	    var later = function() {
	      var last = _.now() - timestamp;

	      if (last < wait && last >= 0) {
	        timeout = setTimeout(later, wait - last);
	      } else {
	        timeout = null;
	        if (!immediate) {
	          result = func.apply(context, args);
	          if (!timeout) context = args = null;
	        }
	      }
	    };

	    return function() {
	      context = this;
	      args = arguments;
	      timestamp = _.now();
	      var callNow = immediate && !timeout;
	      if (!timeout) timeout = setTimeout(later, wait);
	      if (callNow) {
	        result = func.apply(context, args);
	        context = args = null;
	      }

	      return result;
	    };
	  };

	  // Returns the first function passed as an argument to the second,
	  // allowing you to adjust arguments, run code before and after, and
	  // conditionally execute the original function.
	  _.wrap = function(func, wrapper) {
	    return _.partial(wrapper, func);
	  };

	  // Returns a negated version of the passed-in predicate.
	  _.negate = function(predicate) {
	    return function() {
	      return !predicate.apply(this, arguments);
	    };
	  };

	  // Returns a function that is the composition of a list of functions, each
	  // consuming the return value of the function that follows.
	  _.compose = function() {
	    var args = arguments;
	    var start = args.length - 1;
	    return function() {
	      var i = start;
	      var result = args[start].apply(this, arguments);
	      while (i--) result = args[i].call(this, result);
	      return result;
	    };
	  };

	  // Returns a function that will only be executed on and after the Nth call.
	  _.after = function(times, func) {
	    return function() {
	      if (--times < 1) {
	        return func.apply(this, arguments);
	      }
	    };
	  };

	  // Returns a function that will only be executed up to (but not including) the Nth call.
	  _.before = function(times, func) {
	    var memo;
	    return function() {
	      if (--times > 0) {
	        memo = func.apply(this, arguments);
	      }
	      if (times <= 1) func = null;
	      return memo;
	    };
	  };

	  // Returns a function that will be executed at most one time, no matter how
	  // often you call it. Useful for lazy initialization.
	  _.once = _.partial(_.before, 2);

	  // Object Functions
	  // ----------------

	  // Keys in IE < 9 that won't be iterated by `for key in ...` and thus missed.
	  var hasEnumBug = !{toString: null}.propertyIsEnumerable('toString');
	  var nonEnumerableProps = ['valueOf', 'isPrototypeOf', 'toString',
	                      'propertyIsEnumerable', 'hasOwnProperty', 'toLocaleString'];

	  function collectNonEnumProps(obj, keys) {
	    var nonEnumIdx = nonEnumerableProps.length;
	    var constructor = obj.constructor;
	    var proto = (_.isFunction(constructor) && constructor.prototype) || ObjProto;

	    // Constructor is a special case.
	    var prop = 'constructor';
	    if (_.has(obj, prop) && !_.contains(keys, prop)) keys.push(prop);

	    while (nonEnumIdx--) {
	      prop = nonEnumerableProps[nonEnumIdx];
	      if (prop in obj && obj[prop] !== proto[prop] && !_.contains(keys, prop)) {
	        keys.push(prop);
	      }
	    }
	  }

	  // Retrieve the names of an object's own properties.
	  // Delegates to **ECMAScript 5**'s native `Object.keys`
	  _.keys = function(obj) {
	    if (!_.isObject(obj)) return [];
	    if (nativeKeys) return nativeKeys(obj);
	    var keys = [];
	    for (var key in obj) if (_.has(obj, key)) keys.push(key);
	    // Ahem, IE < 9.
	    if (hasEnumBug) collectNonEnumProps(obj, keys);
	    return keys;
	  };

	  // Retrieve all the property names of an object.
	  _.allKeys = function(obj) {
	    if (!_.isObject(obj)) return [];
	    var keys = [];
	    for (var key in obj) keys.push(key);
	    // Ahem, IE < 9.
	    if (hasEnumBug) collectNonEnumProps(obj, keys);
	    return keys;
	  };

	  // Retrieve the values of an object's properties.
	  _.values = function(obj) {
	    var keys = _.keys(obj);
	    var length = keys.length;
	    var values = Array(length);
	    for (var i = 0; i < length; i++) {
	      values[i] = obj[keys[i]];
	    }
	    return values;
	  };

	  // Returns the results of applying the iteratee to each element of the object
	  // In contrast to _.map it returns an object
	  _.mapObject = function(obj, iteratee, context) {
	    iteratee = cb(iteratee, context);
	    var keys =  _.keys(obj),
	          length = keys.length,
	          results = {},
	          currentKey;
	      for (var index = 0; index < length; index++) {
	        currentKey = keys[index];
	        results[currentKey] = iteratee(obj[currentKey], currentKey, obj);
	      }
	      return results;
	  };

	  // Convert an object into a list of `[key, value]` pairs.
	  _.pairs = function(obj) {
	    var keys = _.keys(obj);
	    var length = keys.length;
	    var pairs = Array(length);
	    for (var i = 0; i < length; i++) {
	      pairs[i] = [keys[i], obj[keys[i]]];
	    }
	    return pairs;
	  };

	  // Invert the keys and values of an object. The values must be serializable.
	  _.invert = function(obj) {
	    var result = {};
	    var keys = _.keys(obj);
	    for (var i = 0, length = keys.length; i < length; i++) {
	      result[obj[keys[i]]] = keys[i];
	    }
	    return result;
	  };

	  // Return a sorted list of the function names available on the object.
	  // Aliased as `methods`
	  _.functions = _.methods = function(obj) {
	    var names = [];
	    for (var key in obj) {
	      if (_.isFunction(obj[key])) names.push(key);
	    }
	    return names.sort();
	  };

	  // Extend a given object with all the properties in passed-in object(s).
	  _.extend = createAssigner(_.allKeys);

	  // Assigns a given object with all the own properties in the passed-in object(s)
	  // (https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object/assign)
	  _.extendOwn = _.assign = createAssigner(_.keys);

	  // Returns the first key on an object that passes a predicate test
	  _.findKey = function(obj, predicate, context) {
	    predicate = cb(predicate, context);
	    var keys = _.keys(obj), key;
	    for (var i = 0, length = keys.length; i < length; i++) {
	      key = keys[i];
	      if (predicate(obj[key], key, obj)) return key;
	    }
	  };

	  // Return a copy of the object only containing the whitelisted properties.
	  _.pick = function(object, oiteratee, context) {
	    var result = {}, obj = object, iteratee, keys;
	    if (obj == null) return result;
	    if (_.isFunction(oiteratee)) {
	      keys = _.allKeys(obj);
	      iteratee = optimizeCb(oiteratee, context);
	    } else {
	      keys = flatten(arguments, false, false, 1);
	      iteratee = function(value, key, obj) { return key in obj; };
	      obj = Object(obj);
	    }
	    for (var i = 0, length = keys.length; i < length; i++) {
	      var key = keys[i];
	      var value = obj[key];
	      if (iteratee(value, key, obj)) result[key] = value;
	    }
	    return result;
	  };

	   // Return a copy of the object without the blacklisted properties.
	  _.omit = function(obj, iteratee, context) {
	    if (_.isFunction(iteratee)) {
	      iteratee = _.negate(iteratee);
	    } else {
	      var keys = _.map(flatten(arguments, false, false, 1), String);
	      iteratee = function(value, key) {
	        return !_.contains(keys, key);
	      };
	    }
	    return _.pick(obj, iteratee, context);
	  };

	  // Fill in a given object with default properties.
	  _.defaults = createAssigner(_.allKeys, true);

	  // Creates an object that inherits from the given prototype object.
	  // If additional properties are provided then they will be added to the
	  // created object.
	  _.create = function(prototype, props) {
	    var result = baseCreate(prototype);
	    if (props) _.extendOwn(result, props);
	    return result;
	  };

	  // Create a (shallow-cloned) duplicate of an object.
	  _.clone = function(obj) {
	    if (!_.isObject(obj)) return obj;
	    return _.isArray(obj) ? obj.slice() : _.extend({}, obj);
	  };

	  // Invokes interceptor with the obj, and then returns obj.
	  // The primary purpose of this method is to "tap into" a method chain, in
	  // order to perform operations on intermediate results within the chain.
	  _.tap = function(obj, interceptor) {
	    interceptor(obj);
	    return obj;
	  };

	  // Returns whether an object has a given set of `key:value` pairs.
	  _.isMatch = function(object, attrs) {
	    var keys = _.keys(attrs), length = keys.length;
	    if (object == null) return !length;
	    var obj = Object(object);
	    for (var i = 0; i < length; i++) {
	      var key = keys[i];
	      if (attrs[key] !== obj[key] || !(key in obj)) return false;
	    }
	    return true;
	  };


	  // Internal recursive comparison function for `isEqual`.
	  var eq = function(a, b, aStack, bStack) {
	    // Identical objects are equal. `0 === -0`, but they aren't identical.
	    // See the [Harmony `egal` proposal](http://wiki.ecmascript.org/doku.php?id=harmony:egal).
	    if (a === b) return a !== 0 || 1 / a === 1 / b;
	    // A strict comparison is necessary because `null == undefined`.
	    if (a == null || b == null) return a === b;
	    // Unwrap any wrapped objects.
	    if (a instanceof _) a = a._wrapped;
	    if (b instanceof _) b = b._wrapped;
	    // Compare `[[Class]]` names.
	    var className = toString.call(a);
	    if (className !== toString.call(b)) return false;
	    switch (className) {
	      // Strings, numbers, regular expressions, dates, and booleans are compared by value.
	      case '[object RegExp]':
	      // RegExps are coerced to strings for comparison (Note: '' + /a/i === '/a/i')
	      case '[object String]':
	        // Primitives and their corresponding object wrappers are equivalent; thus, `"5"` is
	        // equivalent to `new String("5")`.
	        return '' + a === '' + b;
	      case '[object Number]':
	        // `NaN`s are equivalent, but non-reflexive.
	        // Object(NaN) is equivalent to NaN
	        if (+a !== +a) return +b !== +b;
	        // An `egal` comparison is performed for other numeric values.
	        return +a === 0 ? 1 / +a === 1 / b : +a === +b;
	      case '[object Date]':
	      case '[object Boolean]':
	        // Coerce dates and booleans to numeric primitive values. Dates are compared by their
	        // millisecond representations. Note that invalid dates with millisecond representations
	        // of `NaN` are not equivalent.
	        return +a === +b;
	    }

	    var areArrays = className === '[object Array]';
	    if (!areArrays) {
	      if (typeof a != 'object' || typeof b != 'object') return false;

	      // Objects with different constructors are not equivalent, but `Object`s or `Array`s
	      // from different frames are.
	      var aCtor = a.constructor, bCtor = b.constructor;
	      if (aCtor !== bCtor && !(_.isFunction(aCtor) && aCtor instanceof aCtor &&
	                               _.isFunction(bCtor) && bCtor instanceof bCtor)
	                          && ('constructor' in a && 'constructor' in b)) {
	        return false;
	      }
	    }
	    // Assume equality for cyclic structures. The algorithm for detecting cyclic
	    // structures is adapted from ES 5.1 section 15.12.3, abstract operation `JO`.

	    // Initializing stack of traversed objects.
	    // It's done here since we only need them for objects and arrays comparison.
	    aStack = aStack || [];
	    bStack = bStack || [];
	    var length = aStack.length;
	    while (length--) {
	      // Linear search. Performance is inversely proportional to the number of
	      // unique nested structures.
	      if (aStack[length] === a) return bStack[length] === b;
	    }

	    // Add the first object to the stack of traversed objects.
	    aStack.push(a);
	    bStack.push(b);

	    // Recursively compare objects and arrays.
	    if (areArrays) {
	      // Compare array lengths to determine if a deep comparison is necessary.
	      length = a.length;
	      if (length !== b.length) return false;
	      // Deep compare the contents, ignoring non-numeric properties.
	      while (length--) {
	        if (!eq(a[length], b[length], aStack, bStack)) return false;
	      }
	    } else {
	      // Deep compare objects.
	      var keys = _.keys(a), key;
	      length = keys.length;
	      // Ensure that both objects contain the same number of properties before comparing deep equality.
	      if (_.keys(b).length !== length) return false;
	      while (length--) {
	        // Deep compare each member
	        key = keys[length];
	        if (!(_.has(b, key) && eq(a[key], b[key], aStack, bStack))) return false;
	      }
	    }
	    // Remove the first object from the stack of traversed objects.
	    aStack.pop();
	    bStack.pop();
	    return true;
	  };

	  // Perform a deep comparison to check if two objects are equal.
	  _.isEqual = function(a, b) {
	    return eq(a, b);
	  };

	  // Is a given array, string, or object empty?
	  // An "empty" object has no enumerable own-properties.
	  _.isEmpty = function(obj) {
	    if (obj == null) return true;
	    if (isArrayLike(obj) && (_.isArray(obj) || _.isString(obj) || _.isArguments(obj))) return obj.length === 0;
	    return _.keys(obj).length === 0;
	  };

	  // Is a given value a DOM element?
	  _.isElement = function(obj) {
	    return !!(obj && obj.nodeType === 1);
	  };

	  // Is a given value an array?
	  // Delegates to ECMA5's native Array.isArray
	  _.isArray = nativeIsArray || function(obj) {
	    return toString.call(obj) === '[object Array]';
	  };

	  // Is a given variable an object?
	  _.isObject = function(obj) {
	    var type = typeof obj;
	    return type === 'function' || type === 'object' && !!obj;
	  };

	  // Add some isType methods: isArguments, isFunction, isString, isNumber, isDate, isRegExp, isError.
	  _.each(['Arguments', 'Function', 'String', 'Number', 'Date', 'RegExp', 'Error'], function(name) {
	    _['is' + name] = function(obj) {
	      return toString.call(obj) === '[object ' + name + ']';
	    };
	  });

	  // Define a fallback version of the method in browsers (ahem, IE < 9), where
	  // there isn't any inspectable "Arguments" type.
	  if (!_.isArguments(arguments)) {
	    _.isArguments = function(obj) {
	      return _.has(obj, 'callee');
	    };
	  }

	  // Optimize `isFunction` if appropriate. Work around some typeof bugs in old v8,
	  // IE 11 (#1621), and in Safari 8 (#1929).
	  if (typeof /./ != 'function' && typeof Int8Array != 'object') {
	    _.isFunction = function(obj) {
	      return typeof obj == 'function' || false;
	    };
	  }

	  // Is a given object a finite number?
	  _.isFinite = function(obj) {
	    return isFinite(obj) && !isNaN(parseFloat(obj));
	  };

	  // Is the given value `NaN`? (NaN is the only number which does not equal itself).
	  _.isNaN = function(obj) {
	    return _.isNumber(obj) && obj !== +obj;
	  };

	  // Is a given value a boolean?
	  _.isBoolean = function(obj) {
	    return obj === true || obj === false || toString.call(obj) === '[object Boolean]';
	  };

	  // Is a given value equal to null?
	  _.isNull = function(obj) {
	    return obj === null;
	  };

	  // Is a given variable undefined?
	  _.isUndefined = function(obj) {
	    return obj === void 0;
	  };

	  // Shortcut function for checking if an object has a given property directly
	  // on itself (in other words, not on a prototype).
	  _.has = function(obj, key) {
	    return obj != null && hasOwnProperty.call(obj, key);
	  };

	  // Utility Functions
	  // -----------------

	  // Run Underscore.js in *noConflict* mode, returning the `_` variable to its
	  // previous owner. Returns a reference to the Underscore object.
	  _.noConflict = function() {
	    root._ = previousUnderscore;
	    return this;
	  };

	  // Keep the identity function around for default iteratees.
	  _.identity = function(value) {
	    return value;
	  };

	  // Predicate-generating functions. Often useful outside of Underscore.
	  _.constant = function(value) {
	    return function() {
	      return value;
	    };
	  };

	  _.noop = function(){};

	  _.property = property;

	  // Generates a function for a given object that returns a given property.
	  _.propertyOf = function(obj) {
	    return obj == null ? function(){} : function(key) {
	      return obj[key];
	    };
	  };

	  // Returns a predicate for checking whether an object has a given set of
	  // `key:value` pairs.
	  _.matcher = _.matches = function(attrs) {
	    attrs = _.extendOwn({}, attrs);
	    return function(obj) {
	      return _.isMatch(obj, attrs);
	    };
	  };

	  // Run a function **n** times.
	  _.times = function(n, iteratee, context) {
	    var accum = Array(Math.max(0, n));
	    iteratee = optimizeCb(iteratee, context, 1);
	    for (var i = 0; i < n; i++) accum[i] = iteratee(i);
	    return accum;
	  };

	  // Return a random integer between min and max (inclusive).
	  _.random = function(min, max) {
	    if (max == null) {
	      max = min;
	      min = 0;
	    }
	    return min + Math.floor(Math.random() * (max - min + 1));
	  };

	  // A (possibly faster) way to get the current timestamp as an integer.
	  _.now = Date.now || function() {
	    return new Date().getTime();
	  };

	   // List of HTML entities for escaping.
	  var escapeMap = {
	    '&': '&amp;',
	    '<': '&lt;',
	    '>': '&gt;',
	    '"': '&quot;',
	    "'": '&#x27;',
	    '`': '&#x60;'
	  };
	  var unescapeMap = _.invert(escapeMap);

	  // Functions for escaping and unescaping strings to/from HTML interpolation.
	  var createEscaper = function(map) {
	    var escaper = function(match) {
	      return map[match];
	    };
	    // Regexes for identifying a key that needs to be escaped
	    var source = '(?:' + _.keys(map).join('|') + ')';
	    var testRegexp = RegExp(source);
	    var replaceRegexp = RegExp(source, 'g');
	    return function(string) {
	      string = string == null ? '' : '' + string;
	      return testRegexp.test(string) ? string.replace(replaceRegexp, escaper) : string;
	    };
	  };
	  _.escape = createEscaper(escapeMap);
	  _.unescape = createEscaper(unescapeMap);

	  // If the value of the named `property` is a function then invoke it with the
	  // `object` as context; otherwise, return it.
	  _.result = function(object, property, fallback) {
	    var value = object == null ? void 0 : object[property];
	    if (value === void 0) {
	      value = fallback;
	    }
	    return _.isFunction(value) ? value.call(object) : value;
	  };

	  // Generate a unique integer id (unique within the entire client session).
	  // Useful for temporary DOM ids.
	  var idCounter = 0;
	  _.uniqueId = function(prefix) {
	    var id = ++idCounter + '';
	    return prefix ? prefix + id : id;
	  };

	  // By default, Underscore uses ERB-style template delimiters, change the
	  // following template settings to use alternative delimiters.
	  _.templateSettings = {
	    evaluate    : /<%([\s\S]+?)%>/g,
	    interpolate : /<%=([\s\S]+?)%>/g,
	    escape      : /<%-([\s\S]+?)%>/g
	  };

	  // When customizing `templateSettings`, if you don't want to define an
	  // interpolation, evaluation or escaping regex, we need one that is
	  // guaranteed not to match.
	  var noMatch = /(.)^/;

	  // Certain characters need to be escaped so that they can be put into a
	  // string literal.
	  var escapes = {
	    "'":      "'",
	    '\\':     '\\',
	    '\r':     'r',
	    '\n':     'n',
	    '\u2028': 'u2028',
	    '\u2029': 'u2029'
	  };

	  var escaper = /\\|'|\r|\n|\u2028|\u2029/g;

	  var escapeChar = function(match) {
	    return '\\' + escapes[match];
	  };

	  // JavaScript micro-templating, similar to John Resig's implementation.
	  // Underscore templating handles arbitrary delimiters, preserves whitespace,
	  // and correctly escapes quotes within interpolated code.
	  // NB: `oldSettings` only exists for backwards compatibility.
	  _.template = function(text, settings, oldSettings) {
	    if (!settings && oldSettings) settings = oldSettings;
	    settings = _.defaults({}, settings, _.templateSettings);

	    // Combine delimiters into one regular expression via alternation.
	    var matcher = RegExp([
	      (settings.escape || noMatch).source,
	      (settings.interpolate || noMatch).source,
	      (settings.evaluate || noMatch).source
	    ].join('|') + '|$', 'g');

	    // Compile the template source, escaping string literals appropriately.
	    var index = 0;
	    var source = "__p+='";
	    text.replace(matcher, function(match, escape, interpolate, evaluate, offset) {
	      source += text.slice(index, offset).replace(escaper, escapeChar);
	      index = offset + match.length;

	      if (escape) {
	        source += "'+\n((__t=(" + escape + "))==null?'':_.escape(__t))+\n'";
	      } else if (interpolate) {
	        source += "'+\n((__t=(" + interpolate + "))==null?'':__t)+\n'";
	      } else if (evaluate) {
	        source += "';\n" + evaluate + "\n__p+='";
	      }

	      // Adobe VMs need the match returned to produce the correct offest.
	      return match;
	    });
	    source += "';\n";

	    // If a variable is not specified, place data values in local scope.
	    if (!settings.variable) source = 'with(obj||{}){\n' + source + '}\n';

	    source = "var __t,__p='',__j=Array.prototype.join," +
	      "print=function(){__p+=__j.call(arguments,'');};\n" +
	      source + 'return __p;\n';

	    try {
	      var render = new Function(settings.variable || 'obj', '_', source);
	    } catch (e) {
	      e.source = source;
	      throw e;
	    }

	    var template = function(data) {
	      return render.call(this, data, _);
	    };

	    // Provide the compiled source as a convenience for precompilation.
	    var argument = settings.variable || 'obj';
	    template.source = 'function(' + argument + '){\n' + source + '}';

	    return template;
	  };

	  // Add a "chain" function. Start chaining a wrapped Underscore object.
	  _.chain = function(obj) {
	    var instance = _(obj);
	    instance._chain = true;
	    return instance;
	  };

	  // OOP
	  // ---------------
	  // If Underscore is called as a function, it returns a wrapped object that
	  // can be used OO-style. This wrapper holds altered versions of all the
	  // underscore functions. Wrapped objects may be chained.

	  // Helper function to continue chaining intermediate results.
	  var result = function(instance, obj) {
	    return instance._chain ? _(obj).chain() : obj;
	  };

	  // Add your own custom functions to the Underscore object.
	  _.mixin = function(obj) {
	    _.each(_.functions(obj), function(name) {
	      var func = _[name] = obj[name];
	      _.prototype[name] = function() {
	        var args = [this._wrapped];
	        push.apply(args, arguments);
	        return result(this, func.apply(_, args));
	      };
	    });
	  };

	  // Add all of the Underscore functions to the wrapper object.
	  _.mixin(_);

	  // Add all mutator Array functions to the wrapper.
	  _.each(['pop', 'push', 'reverse', 'shift', 'sort', 'splice', 'unshift'], function(name) {
	    var method = ArrayProto[name];
	    _.prototype[name] = function() {
	      var obj = this._wrapped;
	      method.apply(obj, arguments);
	      if ((name === 'shift' || name === 'splice') && obj.length === 0) delete obj[0];
	      return result(this, obj);
	    };
	  });

	  // Add all accessor Array functions to the wrapper.
	  _.each(['concat', 'join', 'slice'], function(name) {
	    var method = ArrayProto[name];
	    _.prototype[name] = function() {
	      return result(this, method.apply(this._wrapped, arguments));
	    };
	  });

	  // Extracts the result from a wrapped and chained object.
	  _.prototype.value = function() {
	    return this._wrapped;
	  };

	  // Provide unwrapping proxy for some methods used in engine operations
	  // such as arithmetic and JSON stringification.
	  _.prototype.valueOf = _.prototype.toJSON = _.prototype.value;

	  _.prototype.toString = function() {
	    return '' + this._wrapped;
	  };

	  // AMD registration happens at the end for compatibility with AMD loaders
	  // that may not enforce next-turn semantics on modules. Even though general
	  // practice for AMD registration is to be anonymous, underscore registers
	  // as a named module because, like jQuery, it is a base library that is
	  // popular enough to be bundled in a third party lib, but not be part of
	  // an AMD load request. Those cases could generate an error when an
	  // anonymous define() is called outside of a loader request.
	  if (true) {
	    !(__WEBPACK_AMD_DEFINE_ARRAY__ = [], __WEBPACK_AMD_DEFINE_RESULT__ = function() {
	      return _;
	    }.apply(exports, __WEBPACK_AMD_DEFINE_ARRAY__), __WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
	  }
	}.call(this));


/***/ },
/* 84 */
/***/ function(module, exports, __webpack_require__) {

	module.exports = [
		{
			"classes": [
				{
					"name": "GlobalSchema",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [
						{
							"typeName": "Referencable",
							"nameSpace": "",
							"basicName": "Referencable",
							"typeKind": 0,
							"typeArguments": [
								{
									"typeName": "Sys.SchemaString",
									"nameSpace": "Sys",
									"basicName": "SchemaString",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"
								}
							],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"
						}
					],
					"fields": [
						{
							"name": "key",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.key",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Name of the global schema, used to refer on schema content"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "value",
							"type": {
								"typeName": "Sys.SchemaString",
								"nameSpace": "Sys",
								"basicName": "SchemaString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Content of the schema"
									]
								},
								{
									"name": "MetaModel.value",
									"arguments": []
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.actuallyExports",
							"arguments": [
								"value"
							]
						},
						{
							"name": "MetaModel.description",
							"arguments": [
								"Content of the schema"
							]
						}
					],
					"extends": [
						{
							"typeName": "RAMLSimpleElement",
							"nameSpace": "",
							"basicName": "RAMLSimpleElement",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"
						}
					],
					"moduleName": "RAMLSpec",
					"annotationOverridings": {}
				},
				{
					"name": "Api",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "title",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.required",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"The title property is a short plain text description of the RESTful API. The value SHOULD be suitable for use as a title for the contained user documentation."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "version",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"If the RAML API definition is targeted to a specific API version, the API definition MUST contain a version property. The version property is OPTIONAL and should not be used if: The API itself is not versioned. The API definition does not change between versions. The API architect can decide whether a change to user documentation elements, but no change to the API's resources, constitutes a version change. The API architect MAY use any versioning scheme so long as version numbers retain the same format. For example, 'v3', 'v3.0', and 'V3' are all allowed, but are not considered to be equal."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "baseUri",
							"type": {
								"typeName": "Sys.FullUriTemplateString",
								"nameSpace": "Sys",
								"basicName": "FullUriTemplateString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"(Optional during development; Required after implementation) A RESTful API's resources are defined relative to the API's base URI. The use of the baseUri field is OPTIONAL to allow describing APIs that have not yet been implemented. After the API is implemented (even a mock implementation) and can be accessed at a service endpoint, the API definition MUST contain a baseUri property. The baseUri property's value MUST conform to the URI specification RFC2396 or a Level 1 Template URI as defined in RFC6570. The baseUri property SHOULD only be used as a reference value."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "baseUriParameters",
							"type": {
								"base": {
									"typeName": "Params.Parameter",
									"nameSpace": "Params",
									"basicName": "Parameter",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"location",
										"Params.ParameterLocation.BURI"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Base uri parameters are named parameters which described template parameters in the base uri"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "uriParameters",
							"type": {
								"base": {
									"typeName": "Params.Parameter",
									"nameSpace": "Params",
									"basicName": "Parameter",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"location",
										"Params.ParameterLocation.BURI"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"URI parameters can be further defined by using the uriParameters property. The use of uriParameters is OPTIONAL. The uriParameters property MUST be a map in which each key MUST be the name of the URI parameter as defined in the baseUri property. The uriParameters CANNOT contain a key named version because it is a reserved URI parameter name. The value of the uriParameters property is itself a map that specifies  the property's attributes as named parameters"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "protocols",
							"type": {
								"base": {
									"typeName": "string",
									"nameSpace": "",
									"basicName": "string",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": null
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.oneOf",
									"arguments": [
										[
											"HTTP",
											"HTTPS"
										]
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"A RESTful API can be reached HTTP, HTTPS, or both. The protocols property MAY be used to specify the protocols that an API supports. If the protocols property is not specified, the protocol specified at the baseUri property is used. The protocols property MUST be an array of strings, of values `HTTP` and/or `HTTPS`."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "mediaType",
							"type": {
								"typeName": "Bodies.MimeType",
								"nameSpace": "Bodies",
								"basicName": "MimeType",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.oftenKeys",
									"arguments": [
										[
											"application/json",
											"application/xml",
											"application/x-www-form-urlencoded",
											"multipart/formdata"
										]
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"(Optional) The media types returned by API responses, and expected from API requests that accept a body, MAY be defaulted by specifying the mediaType property. This property is specified at the root level of the API definition. The property's value MAY be a single string with a valid media type described in the specification."
									]
								},
								{
									"name": "MetaModel.inherited",
									"arguments": []
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "schemas",
							"type": {
								"base": {
									"typeName": "GlobalSchema",
									"nameSpace": "",
									"basicName": "GlobalSchema",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.embeddedInMaps",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"To better achieve consistency and simplicity, the API definition SHOULD include an OPTIONAL schemas property in the root section. The schemas property specifies collections of schemas that could be used anywhere in the API definition. The value of the schemas property is an array of maps; in each map, the keys are the schema name, and the values are schema definitions. The schema definitions MAY be included inline or by using the RAML !include user-defined data type."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "traits",
							"type": {
								"base": {
									"typeName": "Methods.Trait",
									"nameSpace": "Methods",
									"basicName": "Trait",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.embeddedInMaps",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Declarations of traits used in this API"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "securedBy",
							"type": {
								"base": {
									"typeName": "Security.SecuritySchemeRef",
									"nameSpace": "Security",
									"basicName": "SecuritySchemeRef",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.allowNull",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"A list of the security schemes to apply to all methods, these must be defined in the securitySchemes declaration."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "securitySchemes",
							"type": {
								"base": {
									"typeName": "Security.AbstractSecurityScheme",
									"nameSpace": "Security",
									"basicName": "AbstractSecurityScheme",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.embeddedInMaps",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Security schemes that can be applied using securedBy"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "resourceTypes",
							"type": {
								"base": {
									"typeName": "Resources.ResourceType",
									"nameSpace": "Resources",
									"basicName": "ResourceType",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.embeddedInMaps",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Declaration of resource types used in this API"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "resources",
							"type": {
								"base": {
									"typeName": "Resources.Resource",
									"nameSpace": "Resources",
									"basicName": "Resource",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.newInstanceName",
									"arguments": [
										"New Resource"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Resources are identified by their relative URI, which MUST begin with a slash (/). A resource defined as a root-level property is called a top-level resource. Its property's key is the resource's URI relative to the baseUri. A resource defined as a child property of another resource is called a nested resource, and its property's key is its URI relative to its parent resource's URI. Every property whose key begins with a slash (/), and is either at the root of the API definition or is the child property of a resource property, is a resource property. The key of a resource, i.e. its relative URI, MAY consist of multiple URI path fragments separated by slashes; e.g. `/bom/items` may indicate the collection of items in a bill of materials as a single resource. However, if the individual URI path fragments are themselves resources, the API definition SHOULD use nested resources to describe this structure; e.g. if `/bom` is itself a resource then `/items` should be a nested resource of `/bom`, while `/bom/items` should not be used."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "documentation",
							"type": {
								"base": {
									"typeName": "DocumentationItem",
									"nameSpace": "",
									"basicName": "DocumentationItem",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"The API definition can include a variety of documents that serve as a user guides and reference documentation for the API. Such documents can clarify how the API works or provide business context. Documentation-generators MUST include all the sections in an API definition's documentation property in the documentation output, and they MUST preserve the order in which the documentation is declared. To add user documentation to the API, include the documentation property at the root of the API definition. The documentation property MUST be an array of documents. Each document MUST contain title and content attributes, both of which are REQUIRED. If the documentation property is specified, it MUST include at least one document. Documentation-generators MUST process the content field as if it was defined using Markdown."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "RAMLVersion",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.customHandling",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Returns AST node of security scheme, this reference refers to, or null."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [],
					"extends": [],
					"moduleName": "RAMLSpec",
					"annotationOverridings": {}
				},
				{
					"name": "DocumentationItem",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "title",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"title of documentation section"
									]
								},
								{
									"name": "MetaModel.required",
									"arguments": []
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "content",
							"type": {
								"typeName": "Sys.MarkdownString",
								"nameSpace": "Sys",
								"basicName": "MarkdownString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Content of documentation section"
									]
								},
								{
									"name": "MetaModel.required",
									"arguments": []
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [],
					"extends": [
						{
							"typeName": "RAMLSimpleElement",
							"nameSpace": "",
							"basicName": "RAMLSimpleElement",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"
						}
					],
					"moduleName": "RAMLSpec",
					"annotationOverridings": {}
				}
			],
			"aliases": [],
			"enumDeclarations": [],
			"imports": {
				"MetaModel": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",
				"Sys": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts",
				"Params": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/parameters.ts",
				"Common": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/common.ts",
				"Bodies": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts",
				"Resources": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts",
				"Methods": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts",
				"Security": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"
			},
			"name": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/api.ts"
		},
		{
			"classes": [
				{
					"name": "SpecPartMetaData",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": true,
					"annotations": [],
					"extends": [],
					"moduleName": null,
					"annotationOverridings": {}
				}
			],
			"aliases": [],
			"enumDeclarations": [],
			"imports": {},
			"name": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts"
		},
		{
			"classes": [
				{
					"name": "ValueType",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [],
					"extends": [],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "StringType",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.nameAtRuntime",
							"arguments": [
								"string"
							]
						}
					],
					"extends": [
						{
							"typeName": "ValueType",
							"nameSpace": "",
							"basicName": "ValueType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "AnyType",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.nameAtRuntime",
							"arguments": [
								"any"
							]
						}
					],
					"extends": [
						{
							"typeName": "ValueType",
							"nameSpace": "",
							"basicName": "ValueType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "NumberType",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.nameAtRuntime",
							"arguments": [
								"number"
							]
						}
					],
					"extends": [
						{
							"typeName": "ValueType",
							"nameSpace": "",
							"basicName": "ValueType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "BooleanType",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.nameAtRuntime",
							"arguments": [
								"boolean"
							]
						}
					],
					"extends": [
						{
							"typeName": "ValueType",
							"nameSpace": "",
							"basicName": "ValueType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "Referencable",
					"methods": [],
					"typeParameters": [
						"T"
					],
					"typeParameterConstraint": [
						null
					],
					"implements": [],
					"fields": [],
					"isInterface": true,
					"annotations": [],
					"extends": [],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "Reference",
					"methods": [],
					"typeParameters": [
						"T"
					],
					"typeParameterConstraint": [
						null
					],
					"implements": [],
					"fields": [
						{
							"name": "structuredValue",
							"type": {
								"typeName": "TypeInstance",
								"nameSpace": "",
								"basicName": "TypeInstance",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.customHandling",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Returns a structured object if the reference point to one."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "name",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.customHandling",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Returns name of referenced object"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [],
					"extends": [
						{
							"typeName": "ValueType",
							"nameSpace": "",
							"basicName": "ValueType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "DeclaresDynamicType",
					"methods": [],
					"typeParameters": [
						"T"
					],
					"typeParameterConstraint": [
						null
					],
					"implements": [],
					"fields": [],
					"isInterface": true,
					"annotations": [],
					"extends": [
						{
							"typeName": "Referencable",
							"nameSpace": "",
							"basicName": "Referencable",
							"typeKind": 0,
							"typeArguments": [
								{
									"typeName": "T",
									"nameSpace": "",
									"basicName": "T",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"
								}
							],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "UriTemplate",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"This type currently serves both for absolute and relative urls"
							]
						}
					],
					"extends": [
						{
							"typeName": "StringType",
							"nameSpace": "",
							"basicName": "StringType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "RelativeUriString",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"This  type describes relative uri templates"
							]
						}
					],
					"extends": [
						{
							"typeName": "UriTemplate",
							"nameSpace": "",
							"basicName": "UriTemplate",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "FullUriTemplateString",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"This  type describes absolute uri templates"
							]
						}
					],
					"extends": [
						{
							"typeName": "UriTemplate",
							"nameSpace": "",
							"basicName": "UriTemplate",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "FixedUri",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"This  type describes fixed uris"
							]
						}
					],
					"extends": [
						{
							"typeName": "StringType",
							"nameSpace": "",
							"basicName": "StringType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "MarkdownString",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.innerType",
							"arguments": [
								"markdown"
							]
						},
						{
							"name": "MetaModel.description",
							"arguments": [
								"Mardown string is a string which can contain markdown as an extension this markdown should support links with RAML Pointers since 1.0"
							]
						}
					],
					"extends": [
						{
							"typeName": "StringType",
							"nameSpace": "",
							"basicName": "StringType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "SchemaString",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"Schema at this moment only two subtypes are supported (json schema and xsd)"
							]
						}
					],
					"extends": [
						{
							"typeName": "StringType",
							"nameSpace": "",
							"basicName": "StringType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "JSonSchemaString",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.functionalDescriminator",
							"arguments": [
								"this.mediaType&&this.mediaType.isJSON()"
							]
						},
						{
							"name": "MetaModel.description",
							"arguments": [
								"JSON schema"
							]
						}
					],
					"extends": [
						{
							"typeName": "SchemaString",
							"nameSpace": "",
							"basicName": "SchemaString",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "XMLSchemaString",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.innerType",
							"arguments": [
								"xml"
							]
						},
						{
							"name": "MetaModel.description",
							"arguments": [
								"XSD schema"
							]
						}
					],
					"extends": [
						{
							"typeName": "SchemaString",
							"nameSpace": "",
							"basicName": "SchemaString",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "ExampleString",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [],
					"extends": [
						{
							"typeName": "StringType",
							"nameSpace": "",
							"basicName": "StringType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "StatusCodeString",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [],
					"extends": [
						{
							"typeName": "StringType",
							"nameSpace": "",
							"basicName": "StringType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "JSONExample",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.functionalDescriminator",
							"arguments": [
								"this.mediaType.isJSON()"
							]
						}
					],
					"extends": [
						{
							"typeName": "ExampleString",
							"nameSpace": "",
							"basicName": "ExampleString",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "XMLExample",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.functionalDescriminator",
							"arguments": [
								"this.mediaType.isXML()"
							]
						}
					],
					"extends": [
						{
							"typeName": "ExampleString",
							"nameSpace": "",
							"basicName": "ExampleString",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "TypeInstance",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "properties",
							"type": {
								"base": {
									"typeName": "TypeInstanceProperty",
									"nameSpace": "",
									"basicName": "TypeInstanceProperty",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Array of instance properties"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "isScalar",
							"type": {
								"typeName": "boolean",
								"nameSpace": "",
								"basicName": "boolean",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Whether the type is scalar"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "value",
							"type": {
								"typeName": "any",
								"nameSpace": "",
								"basicName": "any",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"For instances of scalar types returns scalar value"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.customHandling",
							"arguments": []
						}
					],
					"extends": [],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "TypeInstanceProperty",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "name",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Property name"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "value",
							"type": {
								"typeName": "TypeInstance",
								"nameSpace": "",
								"basicName": "TypeInstance",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Property value"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "values",
							"type": {
								"base": {
									"typeName": "TypeInstance",
									"nameSpace": "",
									"basicName": "TypeInstance",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Array of values if property value is array"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "isArray",
							"type": {
								"typeName": "boolean",
								"nameSpace": "",
								"basicName": "boolean",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Whether property has array as value"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.customHandling",
							"arguments": []
						}
					],
					"extends": [],
					"moduleName": null,
					"annotationOverridings": {}
				}
			],
			"aliases": [],
			"enumDeclarations": [],
			"imports": {
				"MetaModel": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",
				"Common": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/common.ts"
			},
			"name": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"
		},
		{
			"classes": [
				{
					"name": "RAMLSimpleElement",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [],
					"extends": [],
					"moduleName": null,
					"annotationOverridings": {}
				}
			],
			"aliases": [],
			"enumDeclarations": [],
			"imports": {
				"MetaModel": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",
				"Sys": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts"
			},
			"name": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/common.ts"
		},
		{
			"classes": [
				{
					"name": "Parameter",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "name",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.key",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"name of the parameter"
									]
								},
								{
									"name": "MetaModel.extraMetaKey",
									"arguments": [
										"headers"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "displayName",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"An alternate, human-friendly name for the parameter"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "type",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.defaultValue",
									"arguments": [
										"string"
									]
								},
								{
									"name": "MetaModel.descriminatingProperty",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"The type attribute specifies the primitive type of the parameter's resolved value. API clients MUST return/throw an error if the parameter's resolved value does not match the specified type. If type is not specified, it defaults to string."
									]
								},
								{
									"name": "MetaModel.canBeDuplicator",
									"arguments": []
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "location",
							"type": {
								"typeName": "ParameterLocation",
								"nameSpace": "",
								"basicName": "ParameterLocation",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/parameters.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.system",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Location of the parameter (can not be edited by user)"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "required",
							"type": {
								"typeName": "boolean",
								"nameSpace": "",
								"basicName": "boolean",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Set to true if parameter is required"
									]
								},
								{
									"name": "MetaModel.defaultBooleanValue",
									"arguments": [
										true
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "default",
							"type": {
								"typeName": "any",
								"nameSpace": "",
								"basicName": "any",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"The default attribute specifies the default value to use for the property if the property is omitted or its value is not specified. This SHOULD NOT be interpreted as a requirement for the client to send the default attribute's value if there is no other value to send. Instead, the default attribute's value is the value the server uses if the client does not send a value."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "example",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"(Optional) The example attribute shows an example value for the property. This can be used, e.g., by documentation generators to generate sample values for the property."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "repeat",
							"type": {
								"typeName": "boolean",
								"nameSpace": "",
								"basicName": "boolean",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"The repeat attribute specifies that the parameter can be repeated. If the parameter can be used multiple times, the repeat parameter value MUST be set to 'true'. Otherwise, the default value is 'false' and the parameter may not be repeated."
									]
								},
								{
									"name": "MetaModel.defaultBooleanValue",
									"arguments": [
										false
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "description",
							"type": {
								"typeName": "Sys.MarkdownString",
								"nameSpace": "Sys",
								"basicName": "MarkdownString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/parameters.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"The description attribute describes the intended use or meaning of the $self. This value MAY be formatted using Markdown."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [],
					"extends": [],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "StringTypeDeclaration",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "string"
							},
							"optional": false
						},
						{
							"name": "pattern",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"(Optional, applicable only for parameters of type string) The pattern attribute is a regular expression that a parameter of type string MUST match. Regular expressions MUST follow the regular expression specification from ECMA 262/Perl 5. The pattern MAY be enclosed in double quotes for readability and clarity."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "enum",
							"type": {
								"base": {
									"typeName": "string",
									"nameSpace": "",
									"basicName": "string",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": null
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"(Optional, applicable only for parameters of type string) The enum attribute provides an enumeration of the parameter's valid values. This MUST be an array. If the enum attribute is defined, API clients and servers MUST verify that a parameter's value matches a value in the enum array. If there is no matching value, the clients and servers MUST treat this as an error."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "minLength",
							"type": {
								"typeName": "number",
								"nameSpace": "",
								"basicName": "number",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"(Optional, applicable only for parameters of type string) The minLength attribute specifies the parameter value's minimum number of characters."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "maxLength",
							"type": {
								"typeName": "number",
								"nameSpace": "",
								"basicName": "number",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"(Optional, applicable only for parameters of type string) The maxLength attribute specifies the parameter value's maximum number of characters."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"Value must be a string"
							]
						}
					],
					"extends": [
						{
							"typeName": "Parameter",
							"nameSpace": "",
							"basicName": "Parameter",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/parameters.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "BooleanTypeDeclaration",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "boolean"
							},
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"Value must be a boolean"
							]
						}
					],
					"extends": [
						{
							"typeName": "Parameter",
							"nameSpace": "",
							"basicName": "Parameter",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/parameters.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "NumberTypeDeclaration",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "number"
							},
							"optional": false
						},
						{
							"name": "minimum",
							"type": {
								"typeName": "number",
								"nameSpace": "",
								"basicName": "number",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"(Optional, applicable only for parameters of type number or integer) The minimum attribute specifies the parameter's minimum value."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "maximum",
							"type": {
								"typeName": "number",
								"nameSpace": "",
								"basicName": "number",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"(Optional, applicable only for parameters of type number or integer) The maximum attribute specifies the parameter's maximum value."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"Value MUST be a number. Indicate floating point numbers as defined by YAML."
							]
						}
					],
					"extends": [
						{
							"typeName": "Parameter",
							"nameSpace": "",
							"basicName": "Parameter",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/parameters.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "IntegerTypeDeclaration",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "integer"
							},
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"Value MUST be a integer."
							]
						}
					],
					"extends": [
						{
							"typeName": "NumberTypeDeclaration",
							"nameSpace": "",
							"basicName": "NumberTypeDeclaration",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/parameters.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "DateTypeDeclaration",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "date"
							},
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"Value MUST be a string representation of a date as defined in RFC2616 Section 3.3. "
							]
						}
					],
					"extends": [
						{
							"typeName": "Parameter",
							"nameSpace": "",
							"basicName": "Parameter",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/parameters.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "FileTypeDeclaration",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "file"
							},
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.requireValue",
							"arguments": [
								"location",
								"ParameterLocation.FORM"
							]
						},
						{
							"name": "MetaModel.description",
							"arguments": [
								"(Applicable only to Form properties) Value is a file. Client generators SHOULD use this type to handle file uploads correctly."
							]
						}
					],
					"extends": [
						{
							"typeName": "Parameter",
							"nameSpace": "",
							"basicName": "Parameter",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/parameters.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				}
			],
			"aliases": [],
			"enumDeclarations": [
				{
					"name": "ParameterLocation",
					"members": [
						"QUERY",
						"HEADERS",
						"URI",
						"FORM",
						"BURI"
					]
				}
			],
			"imports": {
				"MetaModel": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",
				"Sys": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts",
				"Common": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/common.ts"
			},
			"name": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/parameters.ts"
		},
		{
			"classes": [
				{
					"name": "MimeType",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"This sub type of the string represents mime types"
							]
						}
					],
					"extends": [
						{
							"typeName": "StringType",
							"nameSpace": "",
							"basicName": "StringType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "BodyLike",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "name",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.key",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Mime type of the request or response body"
									]
								},
								{
									"name": "MetaModel.canInherit",
									"arguments": [
										"mediaType"
									]
								},
								{
									"name": "MetaModel.oftenKeys",
									"arguments": [
										[
											"application/json",
											"application/xml",
											"application/x-www-form-urlencoded",
											"multipart/form-data"
										]
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "schema",
							"type": {
								"typeName": "Sys.SchemaString",
								"nameSpace": "Sys",
								"basicName": "SchemaString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.requireValue",
									"arguments": [
										"this.name.isForm()",
										"false"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"The structure of a request or response body MAY be further specified by the schema property under the appropriate media type. The schema key CANNOT be specified if a body's media type is application/x-www-form-urlencoded or multipart/form-data. All parsers of RAML MUST be able to interpret JSON Schema and XML Schema. Schema MAY be declared inline or in an external file. However, if the schema is sufficiently large so as to make it difficult for a person to read the API definition, or the schema is reused across multiple APIs or across multiple miles in the same API, the !include user-defined data type SHOULD be used instead of including the content inline. Alternatively, the value of the schema field MAY be the name of a schema specified in the root-level schemas property, or it MAY be declared in an external file and included by using the by using the RAML !include user-defined data type."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "example",
							"type": {
								"typeName": "Sys.ExampleString",
								"nameSpace": "Sys",
								"basicName": "ExampleString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Documentation generators MUST use body properties' example attributes to generate example invocations."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "formParameters",
							"type": {
								"base": {
									"typeName": "Params.Parameter",
									"nameSpace": "Params",
									"basicName": "Parameter",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"location",
										"Params.ParameterLocation.FORM"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Web forms REQUIRE special encoding and custom declaration. If the API's media type is either application/x-www-form-urlencoded or multipart/form-data, the formParameters property MUST specify the name-value pairs that the API is expecting. The formParameters property is a map in which the key is the name of the web form parameter, and the value is itself a map the specifies the web form parameter's attributes."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "schemaContent",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.customHandling",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Returns schema content for the cases when schema is inlined, when schema is included, and when schema is a reference."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "description",
							"type": {
								"typeName": "Sys.MarkdownString",
								"nameSpace": "Sys",
								"basicName": "MarkdownString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Human readable description of the body"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.canInherit",
							"arguments": [
								"mediaType"
							]
						}
					],
					"extends": [],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "XMLBody",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "schema",
							"type": {
								"typeName": "Sys.XMLSchemaString",
								"nameSpace": "Sys",
								"basicName": "XMLSchemaString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"XSD Schema"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.functionalDescriminator",
							"arguments": [
								"this.mime.isXML()"
							]
						},
						{
							"name": "MetaModel.description",
							"arguments": [
								"Needed to set connection between xml related mime types and xsd schema"
							]
						}
					],
					"extends": [
						{
							"typeName": "BodyLike",
							"nameSpace": "",
							"basicName": "BodyLike",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "JSONBody",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "schema",
							"type": {
								"typeName": "Sys.JSonSchemaString",
								"nameSpace": "Sys",
								"basicName": "JSonSchemaString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"JSON Schema"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.functionalDescriminator",
							"arguments": [
								"this.mime.isJSON()"
							]
						},
						{
							"name": "MetaModel.description",
							"arguments": [
								"Needed to set connection between json related mime types and json schema"
							]
						}
					],
					"extends": [
						{
							"typeName": "BodyLike",
							"nameSpace": "",
							"basicName": "BodyLike",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "Response",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "code",
							"type": {
								"typeName": "Sys.StatusCodeString",
								"nameSpace": "Sys",
								"basicName": "StatusCodeString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.key",
									"arguments": []
								},
								{
									"name": "MetaModel.extraMetaKey",
									"arguments": [
										"statusCodes"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Responses MUST be a map of one or more HTTP status codes, where each status code itself is a map that describes that status code."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "headers",
							"type": {
								"base": {
									"typeName": "Params.Parameter",
									"nameSpace": "Params",
									"basicName": "Parameter",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"location",
										"Params.ParameterLocation.HEADERS"
									]
								},
								{
									"name": "MetaModel.newInstanceName",
									"arguments": [
										"New Header"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"An API's methods may support custom header values in responses. The custom, non-standard HTTP headers MUST be specified by the headers property. API's may include the the placeholder token {?} in a header name to indicate that any number of headers that conform to the specified format can be sent in responses. This is particularly useful for APIs that allow HTTP headers that conform to some naming convention to send arbitrary, custom data."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "body",
							"type": {
								"base": {
									"typeName": "BodyLike",
									"nameSpace": "",
									"basicName": "BodyLike",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.newInstanceName",
									"arguments": [
										"New Body"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Each response MAY contain a body property, which conforms to the same structure as request body properties (see Body). Responses that can return more than one response code MAY therefore have multiple bodies defined. For APIs without a priori knowledge of the response types for their responses, `*/*` MAY be used to indicate that responses that do not matching other defined data types MUST be accepted. Processing applications MUST match the most descriptive media type first if `*/*` is used."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "description",
							"type": {
								"typeName": "Sys.MarkdownString",
								"nameSpace": "Sys",
								"basicName": "MarkdownString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"The description attribute describes the intended use or meaning of the $self. This value MAY be formatted using Markdown."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [],
					"extends": [],
					"moduleName": null,
					"annotationOverridings": {}
				}
			],
			"aliases": [],
			"enumDeclarations": [],
			"imports": {
				"MetaModel": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",
				"Sys": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts",
				"Params": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/parameters.ts",
				"Common": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/common.ts"
			},
			"name": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts"
		},
		{
			"classes": [
				{
					"name": "Resource",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "relativeUri",
							"type": {
								"typeName": "Sys.RelativeUriString",
								"nameSpace": "Sys",
								"basicName": "RelativeUriString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.key",
									"arguments": []
								},
								{
									"name": "MetaModel.startFrom",
									"arguments": [
										"/"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Relative URL of this resource from the parent resource"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "type",
							"type": {
								"typeName": "ResourceTypeRef",
								"nameSpace": "",
								"basicName": "ResourceTypeRef",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Instantiation of applyed resource type"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "is",
							"type": {
								"base": {
									"typeName": "TraitRef",
									"nameSpace": "",
									"basicName": "TraitRef",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Instantiation of applyed traits"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "securedBy",
							"type": {
								"base": {
									"typeName": "SecuritySchemeRef",
									"nameSpace": "",
									"basicName": "SecuritySchemeRef",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.allowNull",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"securityScheme may also be applied to a resource by using the securedBy key, which is equivalent to applying the securityScheme to all methods that may be declared, explicitly or implicitly, by defining the resourceTypes or traits property for that resource. To indicate that the method may be called without applying any securityScheme, the method may be annotated with the null securityScheme."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "uriParameters",
							"type": {
								"base": {
									"typeName": "Params.Parameter",
									"nameSpace": "Params",
									"basicName": "Parameter",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"fieldOrParam",
										true
									]
								},
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"location",
										"Params.ParameterLocation.URI"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Uri parameters of this resource"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "methods",
							"type": {
								"base": {
									"typeName": "Methods.Method",
									"nameSpace": "Methods",
									"basicName": "Method",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.newInstanceName",
									"arguments": [
										"New Method"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Methods that can be called on this resource"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "resources",
							"type": {
								"base": {
									"typeName": "Resource",
									"nameSpace": "",
									"basicName": "Resource",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.newInstanceName",
									"arguments": [
										"New Resource"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Children resources"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "displayName",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"An alternate, human-friendly name for the resource"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "baseUriParameters",
							"type": {
								"base": {
									"typeName": "Params.Parameter",
									"nameSpace": "Params",
									"basicName": "Parameter",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"fieldOrParam",
										true
									]
								},
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"location",
										"Params.ParameterLocation.BURI"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"A resource or a method can override a base URI template's values. This is useful to restrict or change the default or parameter selection in the base URI. The baseUriParameters property MAY be used to override any or all parameters defined at the root level baseUriParameters property, as well as base URI parameters not specified at the root level."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "description",
							"type": {
								"typeName": "Sys.MarkdownString",
								"nameSpace": "Sys",
								"basicName": "MarkdownString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"The description attribute describes the intended use or meaning of the $self. This value MAY be formatted using Markdown."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [],
					"extends": [],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "ResourceTypeRef",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "resourceType",
							"type": {
								"typeName": "ResourceType",
								"nameSpace": "",
								"basicName": "ResourceType",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.customHandling",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Returns referenced resource type"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [],
					"extends": [
						{
							"typeName": "Reference",
							"nameSpace": "",
							"basicName": "Reference",
							"typeKind": 0,
							"typeArguments": [
								{
									"typeName": "ResourceType",
									"nameSpace": "",
									"basicName": "ResourceType",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"
								}
							],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "ResourceType",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [
						{
							"typeName": "DeclaresDynamicType",
							"nameSpace": "",
							"basicName": "DeclaresDynamicType",
							"typeKind": 0,
							"typeArguments": [
								{
									"typeName": "ResourceType",
									"nameSpace": "",
									"basicName": "ResourceType",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"
								}
							],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"
						}
					],
					"fields": [
						{
							"name": "name",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.key",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Name of the resource type"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "usage",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Instructions on how and when the resource type should be used."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "methods",
							"type": {
								"base": {
									"typeName": "Methods.Method",
									"nameSpace": "Methods",
									"basicName": "Method",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Methods that are part of this resource type definition"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "is",
							"type": {
								"base": {
									"typeName": "Security.TraitRef",
									"nameSpace": "Security",
									"basicName": "TraitRef",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Instantiation of applyed traits"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "type",
							"type": {
								"typeName": "ResourceTypeRef",
								"nameSpace": "",
								"basicName": "ResourceTypeRef",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Instantiation of applyed resource type"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "securedBy",
							"type": {
								"base": {
									"typeName": "Security.SecuritySchemeRef",
									"nameSpace": "Security",
									"basicName": "SecuritySchemeRef",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.allowNull",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"securityScheme may also be applied to a resource by using the securedBy key, which is equivalent to applying the securityScheme to all methods that may be declared, explicitly or implicitly, by defining the resourceTypes or traits property for that resource. To indicate that the method may be called without applying any securityScheme, the method may be annotated with the null securityScheme."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "uriParameters",
							"type": {
								"base": {
									"typeName": "Params.Parameter",
									"nameSpace": "Params",
									"basicName": "Parameter",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"location",
										"Params.ParameterLocation.URI"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Uri parameters of this resource"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "displayName",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"An alternate, human-friendly name for the resource type"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "baseUriParameters",
							"type": {
								"base": {
									"typeName": "Params.Parameter",
									"nameSpace": "Params",
									"basicName": "Parameter",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"fieldOrParam",
										true
									]
								},
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"location",
										"Params.ParameterLocation.BURI"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"A resource or a method can override a base URI template's values. This is useful to restrict or change the default or parameter selection in the base URI. The baseUriParameters property MAY be used to override any or all parameters defined at the root level baseUriParameters property, as well as base URI parameters not specified at the root level."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "parametrizedProperties",
							"type": {
								"typeName": "Sys.TypeInstance",
								"nameSpace": "Sys",
								"basicName": "TypeInstance",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.customHandling",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Returns object representation of parametrized properties of the resource type"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "description",
							"type": {
								"typeName": "Sys.MarkdownString",
								"nameSpace": "Sys",
								"basicName": "MarkdownString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"The description attribute describes the intended use or meaning of the $self. This value MAY be formatted using Markdown."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.inlinedTemplates",
							"arguments": []
						},
						{
							"name": "MetaModel.allowQuestion",
							"arguments": []
						}
					],
					"extends": [],
					"moduleName": null,
					"annotationOverridings": {}
				}
			],
			"aliases": [],
			"enumDeclarations": [],
			"imports": {
				"MetaModel": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",
				"Sys": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts",
				"Params": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/parameters.ts",
				"Bodies": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts",
				"Common": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/common.ts",
				"Methods": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts",
				"Security": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"
			},
			"name": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/resources.ts"
		},
		{
			"classes": [
				{
					"name": "MethodBase",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "responses",
							"type": {
								"base": {
									"typeName": "Bodies.Response",
									"nameSpace": "Bodies",
									"basicName": "Response",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.newInstanceName",
									"arguments": [
										"New Response"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Resource methods MAY have one or more responses. Responses MAY be described using the description property, and MAY include example attributes or schema properties."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "body",
							"type": {
								"base": {
									"typeName": "Bodies.BodyLike",
									"nameSpace": "Bodies",
									"basicName": "BodyLike",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.newInstanceName",
									"arguments": [
										"New Body"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Some method verbs expect the resource to be sent as a request body. For example, to create a resource, the request must include the details of the resource to create. Resources CAN have alternate representations. For example, an API might support both JSON and XML representations. A method's body is defined in the body property as a hashmap, in which the key MUST be a valid media type."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "protocols",
							"type": {
								"base": {
									"typeName": "string",
									"nameSpace": "",
									"basicName": "string",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": null
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.oneOf",
									"arguments": [
										[
											"HTTP",
											"HTTPS"
										]
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"A method can override an API's protocols value for that single method by setting a different value for the fields."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "securedBy",
							"type": {
								"base": {
									"typeName": "SecuritySchemeRef",
									"nameSpace": "",
									"basicName": "SecuritySchemeRef",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.allowNull",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"A list of the security schemas to apply, these must be defined in the securitySchemes declaration. To indicate that the method may be called without applying any securityScheme, the method may be annotated with the null securityScheme. Security schemas may also be applied to a resource with securedBy, which is equivalent to applying the security schemas to all methods that may be declared, explicitly or implicitly, by defining the resourceTypes or traits property for that resource."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "baseUriParameters",
							"type": {
								"base": {
									"typeName": "Params.Parameter",
									"nameSpace": "Params",
									"basicName": "Parameter",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"fieldOrParam",
										true
									]
								},
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"location",
										"Params.ParameterLocation.BURI"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"A resource or a method can override a base URI template's values. This is useful to restrict or change the default or parameter selection in the base URI. The baseUriParameters property MAY be used to override any or all parameters defined at the root level baseUriParameters property, as well as base URI parameters not specified at the root level."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "queryParameters",
							"type": {
								"base": {
									"typeName": "Params.Parameter",
									"nameSpace": "Params",
									"basicName": "Parameter",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"location",
										"ParameterLocation.QUERY"
									]
								},
								{
									"name": "MetaModel.newInstanceName",
									"arguments": [
										"New query parameter"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"An APIs resources MAY be filtered (to return a subset of results) or altered (such as transforming a response body from JSON to XML format) by the use of query strings. If the resource or its method supports a query string, the query string MUST be defined by the queryParameters property"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "headers",
							"type": {
								"base": {
									"typeName": "Params.Parameter",
									"nameSpace": "Params",
									"basicName": "Parameter",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"location",
										"ParameterLocation.HEADERS"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Headers that allowed at this position"
									]
								},
								{
									"name": "MetaModel.newInstanceName",
									"arguments": [
										"New Header"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "description",
							"type": {
								"typeName": "Sys.MarkdownString",
								"nameSpace": "Sys",
								"basicName": "MarkdownString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"
							},
							"annotations": [],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"Method object allows description of http methods"
							]
						}
					],
					"extends": [],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "Method",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "method",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.key",
									"arguments": []
								},
								{
									"name": "MetaModel.extraMetaKey",
									"arguments": [
										"methods"
									]
								},
								{
									"name": "MetaModel.oneOf",
									"arguments": [
										[
											"get",
											"put",
											"post",
											"delete",
											"patch",
											"options",
											"head",
											"trace",
											"connect"
										]
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Method that can be called"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "is",
							"type": {
								"base": {
									"typeName": "TraitRef",
									"nameSpace": "",
									"basicName": "TraitRef",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Instantiation of applyed traits"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [],
					"extends": [
						{
							"typeName": "MethodBase",
							"nameSpace": "",
							"basicName": "MethodBase",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "Trait",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [
						{
							"typeName": "DeclaresDynamicType",
							"nameSpace": "",
							"basicName": "DeclaresDynamicType",
							"typeKind": 0,
							"typeArguments": [
								{
									"typeName": "Trait",
									"nameSpace": "",
									"basicName": "Trait",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"
								}
							],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"
						}
					],
					"fields": [
						{
							"name": "name",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.key",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Name of the trait"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "usage",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Instructions on how and when the trait should be used."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "parametrizedProperties",
							"type": {
								"typeName": "Sys.TypeInstance",
								"nameSpace": "Sys",
								"basicName": "TypeInstance",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.customHandling",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Returns object representation of parametrized properties of the trait"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "displayName",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"An alternate, human-friendly name for the trait"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.inlinedTemplates",
							"arguments": []
						},
						{
							"name": "MetaModel.allowQuestion",
							"arguments": []
						}
					],
					"extends": [
						{
							"typeName": "MethodBase",
							"nameSpace": "",
							"basicName": "MethodBase",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "TraitRef",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "trait",
							"type": {
								"typeName": "Trait",
								"nameSpace": "",
								"basicName": "Trait",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.customHandling",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Returns referenced trait"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [],
					"extends": [
						{
							"typeName": "Reference",
							"nameSpace": "",
							"basicName": "Reference",
							"typeKind": 0,
							"typeArguments": [
								{
									"typeName": "Trait",
									"nameSpace": "",
									"basicName": "Trait",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"
								}
							],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				}
			],
			"aliases": [],
			"enumDeclarations": [],
			"imports": {
				"MetaModel": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",
				"Sys": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts",
				"Params": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/parameters.ts",
				"Bodies": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts",
				"Common": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/common.ts",
				"Security": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"
			},
			"name": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"
		},
		{
			"classes": [
				{
					"name": "SecuritySchemePart",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "displayName",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"An alternate, human-friendly name for the security scheme part"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "is",
							"type": {
								"base": {
									"typeName": "TraitRef",
									"nameSpace": "",
									"basicName": "TraitRef",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Instantiation of applyed traits"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [],
					"extends": [
						{
							"typeName": "MethodBase",
							"nameSpace": "",
							"basicName": "MethodBase",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {
						"headers": [
							{
								"name": "MetaModel.markdownDescription",
								"arguments": [
									"Optional array of headers, documenting the possible headers that could be accepted."
								]
							},
							{
								"name": "MetaModel.valueDescription",
								"arguments": [
									"Object whose property names are the request header names and whose values describe the values."
								]
							}
						],
						"queryParameters": [
							{
								"name": "MetaModel.markdownDescription",
								"arguments": [
									"Query parameters, used by the schema in order to authorize the request. Mutually exclusive with queryString."
								]
							},
							{
								"name": "MetaModel.valueDescription",
								"arguments": [
									"Object whose property names are the query parameter names and whose values describe the values."
								]
							}
						],
						"queryString": [
							{
								"name": "MetaModel.description",
								"arguments": [
									"Specifies the query string, used by the schema in order to authorize the request. Mutually exclusive with queryParameters."
								]
							},
							{
								"name": "MetaModel.valueDescription",
								"arguments": [
									"Type name or type declaration"
								]
							}
						],
						"responses": [
							{
								"name": "MetaModel.description",
								"arguments": [
									"Optional array of responses, describing the possible responses that could be sent."
								]
							}
						],
						"description": [
							{
								"name": "MetaModel.description",
								"arguments": [
									"A longer, human-friendly description of the security scheme part"
								]
							},
							{
								"name": "MetaModel.valueDescription",
								"arguments": [
									"Markdown string"
								]
							}
						]
					}
				},
				{
					"name": "SecuritySchemeSettings",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.allowAny",
							"arguments": []
						}
					],
					"extends": [],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "AbstractSecurityScheme",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [
						{
							"typeName": "Referencable",
							"nameSpace": "",
							"basicName": "Referencable",
							"typeKind": 0,
							"typeArguments": [
								{
									"typeName": "AbstractSecurityScheme",
									"nameSpace": "",
									"basicName": "AbstractSecurityScheme",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"
								}
							],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"
						}
					],
					"fields": [
						{
							"name": "name",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.key",
									"arguments": []
								},
								{
									"name": "MetaModel.startFrom",
									"arguments": [
										""
									]
								},
								{
									"name": "MetaModel.hide",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Name of the security scheme"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "type",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.required",
									"arguments": []
								},
								{
									"name": "MetaModel.oneOf",
									"arguments": [
										[
											"OAuth 1.0",
											"OAuth 2.0",
											"Basic Authentication",
											"DigestSecurityScheme Authentication",
											"x-{other}"
										]
									]
								},
								{
									"name": "MetaModel.descriminatingProperty",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"The securitySchemes property MUST be used to specify an API's security mechanisms, including the required settings and the authentication methods that the API supports. one authentication method is allowed if the API supports them."
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"string<br><br>The value MUST be one of<br>* OAuth 1.0,<br>* OAuth 2.0, <br>* BasicSecurityScheme Authentication<br>* DigestSecurityScheme Authentication<br>* x-&lt;other&gt;"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "description",
							"type": {
								"typeName": "Sys.MarkdownString",
								"nameSpace": "Sys",
								"basicName": "MarkdownString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"The description attribute MAY be used to describe a security schemes property."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "describedBy",
							"type": {
								"typeName": "SecuritySchemePart",
								"nameSpace": "",
								"basicName": "SecuritySchemePart",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"A description of the request components related to Security that are determined by the scheme: the headers, query parameters or responses. As a best practice, even for standard security schemes, API designers SHOULD describe these properties of security schemes. Including the security scheme description completes an API documentation."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "settings",
							"type": {
								"typeName": "SecuritySchemeSettings",
								"nameSpace": "",
								"basicName": "SecuritySchemeSettings",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"The settings attribute MAY be used to provide security scheme-specific information. The required attributes vary depending on the type of security scheme is being declared. It describes the minimum set of properties which any processing application MUST provide and validate if it chooses to implement the security scheme. Processing applications MAY choose to recognize other properties for things such as token lifetime, preferred cryptographic algorithms, and more."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"Declares globally referable security schema definition"
							]
						},
						{
							"name": "MetaModel.actuallyExports",
							"arguments": [
								"$self"
							]
						},
						{
							"name": "MetaModel.referenceIs",
							"arguments": [
								"settings"
							]
						}
					],
					"extends": [],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "SecuritySchemeRef",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "securitySchemeName",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.customHandling",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Returns the name of security scheme, this reference refers to."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "securityScheme",
							"type": {
								"typeName": "AbstractSecurityScheme",
								"nameSpace": "",
								"basicName": "AbstractSecurityScheme",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.customHandling",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Returns AST node of security scheme, this reference refers to, or null."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.allowAny",
							"arguments": []
						}
					],
					"extends": [
						{
							"typeName": "Reference",
							"nameSpace": "",
							"basicName": "Reference",
							"typeKind": 0,
							"typeArguments": [
								{
									"typeName": "AbstractSecurityScheme",
									"nameSpace": "",
									"basicName": "AbstractSecurityScheme",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"
								}
							],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "OAuth1SecuritySchemeSettings",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "requestTokenUri",
							"type": {
								"typeName": "Sys.FixedUri",
								"nameSpace": "Sys",
								"basicName": "FixedUri",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.required",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"The URI of the Temporary Credential Request endpoint as defined in RFC5849 Section 2.1"
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"FixedUriString"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "authorizationUri",
							"type": {
								"typeName": "Sys.FixedUri",
								"nameSpace": "Sys",
								"basicName": "FixedUri",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.required",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"The URI of the Resource Owner Authorization endpoint as defined in RFC5849 Section 2.2"
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"FixedUriString"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "tokenCredentialsUri",
							"type": {
								"typeName": "Sys.FixedUri",
								"nameSpace": "Sys",
								"basicName": "FixedUri",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.required",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"The URI of the Token Request endpoint as defined in RFC5849 Section 2.3"
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"FixedUriString"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.allowAny",
							"arguments": []
						},
						{
							"name": "MetaModel.functionalDescriminator",
							"arguments": [
								"$parent.type=='OAuth 1.0'"
							]
						}
					],
					"extends": [
						{
							"typeName": "SecuritySchemeSettings",
							"nameSpace": "",
							"basicName": "SecuritySchemeSettings",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "OAuth2SecuritySchemeSettings",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "accessTokenUri",
							"type": {
								"typeName": "Sys.FixedUri",
								"nameSpace": "Sys",
								"basicName": "FixedUri",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.required",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"The URI of the Token Endpoint as defined in RFC6749 Section 3.2. Not required forby implicit grant type."
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"FixedUriString"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "authorizationUri",
							"type": {
								"typeName": "Sys.FixedUri",
								"nameSpace": "Sys",
								"basicName": "FixedUri",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.required",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"The URI of the Authorization Endpoint as defined in RFC6749 Section 3.1. Required forby authorization_code and implicit grant types."
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"FixedUriString"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "authorizationGrants",
							"type": {
								"base": {
									"typeName": "string",
									"nameSpace": "",
									"basicName": "string",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": null
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"A list of the Authorization grants supported by the API as defined in RFC6749 Sections 4.1, 4.2, 4.3 and 4.4, can be any of: authorization_code, password, client_credentials, implicit, or refresh_token."
									]
								},
								{
									"name": "MetaModel.markdownDescription",
									"arguments": [
										"A list of the Authorization grants supported by the API as defined in RFC6749 Sections 4.1, 4.2, 4.3 and 4.4, can be any of:<br>* authorization_code<br>* password<br>* client_credentials <br>* implicit<br>* refresh_token."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "scopes",
							"type": {
								"base": {
									"typeName": "string",
									"nameSpace": "",
									"basicName": "string",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": null
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"A list of scopes supported by the security scheme as defined in RFC6749 Section 3.3"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.allowAny",
							"arguments": []
						}
					],
					"extends": [
						{
							"typeName": "SecuritySchemeSettings",
							"nameSpace": "",
							"basicName": "SecuritySchemeSettings",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "OAuth2SecurityScheme",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "OAuth 2.0"
							},
							"optional": false
						},
						{
							"name": "settings",
							"type": {
								"typeName": "OAuth2SecuritySchemeSettings",
								"nameSpace": "",
								"basicName": "OAuth2SecuritySchemeSettings",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"
							},
							"annotations": [],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"Declares globally referable security schema definition"
							]
						},
						{
							"name": "MetaModel.actuallyExports",
							"arguments": [
								"$self"
							]
						},
						{
							"name": "MetaModel.referenceIs",
							"arguments": [
								"settings"
							]
						}
					],
					"extends": [
						{
							"typeName": "AbstractSecurityScheme",
							"nameSpace": "",
							"basicName": "AbstractSecurityScheme",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "OAuth1SecurityScheme",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "OAuth 1.0"
							},
							"optional": false
						},
						{
							"name": "settings",
							"type": {
								"typeName": "OAuth1SecuritySchemeSettings",
								"nameSpace": "",
								"basicName": "OAuth1SecuritySchemeSettings",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"
							},
							"annotations": [],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"Declares globally referable security schema definition"
							]
						},
						{
							"name": "MetaModel.actuallyExports",
							"arguments": [
								"$self"
							]
						},
						{
							"name": "MetaModel.referenceIs",
							"arguments": [
								"settings"
							]
						}
					],
					"extends": [
						{
							"typeName": "AbstractSecurityScheme",
							"nameSpace": "",
							"basicName": "AbstractSecurityScheme",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "BasicSecurityScheme",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "Basic Authentication"
							},
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"Declares globally referable security schema definition"
							]
						},
						{
							"name": "MetaModel.actuallyExports",
							"arguments": [
								"$self"
							]
						},
						{
							"name": "MetaModel.referenceIs",
							"arguments": [
								"settings"
							]
						}
					],
					"extends": [
						{
							"typeName": "AbstractSecurityScheme",
							"nameSpace": "",
							"basicName": "AbstractSecurityScheme",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "DigestSecurityScheme",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "Digest Authentication"
							},
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"Declares globally referable security schema definition"
							]
						},
						{
							"name": "MetaModel.actuallyExports",
							"arguments": [
								"$self"
							]
						},
						{
							"name": "MetaModel.referenceIs",
							"arguments": [
								"settings"
							]
						}
					],
					"extends": [
						{
							"typeName": "AbstractSecurityScheme",
							"nameSpace": "",
							"basicName": "AbstractSecurityScheme",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "CustomSecurityScheme",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "x-{other}"
							},
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"Declares globally referable security schema definition"
							]
						},
						{
							"name": "MetaModel.actuallyExports",
							"arguments": [
								"$self"
							]
						},
						{
							"name": "MetaModel.referenceIs",
							"arguments": [
								"settings"
							]
						}
					],
					"extends": [
						{
							"typeName": "AbstractSecurityScheme",
							"nameSpace": "",
							"basicName": "AbstractSecurityScheme",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				}
			],
			"aliases": [],
			"enumDeclarations": [],
			"imports": {
				"MetaModel": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",
				"Sys": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/systemTypes.ts",
				"Params": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/parameters.ts",
				"Bodies": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/bodies.ts",
				"Common": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/common.ts",
				"Methods": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/methods.ts"
			},
			"name": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-0.8/security.ts"
		}
	];

/***/ },
/* 85 */
/***/ function(module, exports, __webpack_require__) {

	module.exports = [
		{
			"classes": [
				{
					"name": "Library",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "usage",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"contains description of why library exist"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "name",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.key",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Namespace which the library is imported under"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [],
					"extends": [
						{
							"typeName": "LibraryBase",
							"nameSpace": "",
							"basicName": "LibraryBase",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "LibraryBase",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "schemas",
							"type": {
								"base": {
									"typeName": "TypeDeclaration",
									"nameSpace": "",
									"basicName": "TypeDeclaration",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.embeddedInMaps",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Alias for the equivalent \"types\" property, for compatibility with RAML 0.8. Deprecated - API definitions should use the \"types\" property, as the \"schemas\" alias for that property name may be removed in a future RAML version. The \"types\" property allows for XML and JSON schemas."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "types",
							"type": {
								"base": {
									"typeName": "DataModel.TypeDeclaration",
									"nameSpace": "DataModel",
									"basicName": "TypeDeclaration",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.embeddedInMaps",
									"arguments": []
								},
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"locationKind",
										"DataModel.LocationKind.MODELS"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Declarations of (data) types for use within this API"
									]
								},
								{
									"name": "MetaModel.markdownDescription",
									"arguments": [
										"Declarations of (data) types for use within this API."
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"An object whose properties map type names to type declarations; or an array of such objects"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "traits",
							"type": {
								"base": {
									"typeName": "Methods.Trait",
									"nameSpace": "Methods",
									"basicName": "Trait",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.embeddedInMaps",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Declarations of traits used in this API"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Declarations of traits for use within this API"
									]
								},
								{
									"name": "MetaModel.markdownDescription",
									"arguments": [
										"Declarations of traits for use within this API."
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"An object whose properties map trait names to trait declarations; or an array of such objects"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "resourceTypes",
							"type": {
								"base": {
									"typeName": "Resources.ResourceType",
									"nameSpace": "Resources",
									"basicName": "ResourceType",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.embeddedInMaps",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Declaration of resource types used in this API"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Declarations of resource types for use within this API"
									]
								},
								{
									"name": "MetaModel.markdownDescription",
									"arguments": [
										"Declarations of resource types for use within this API."
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"An object whose properties map resource type names to resource type declarations; or an array of such objects"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "annotationTypes",
							"type": {
								"base": {
									"typeName": "DataModel.TypeDeclaration",
									"nameSpace": "DataModel",
									"basicName": "TypeDeclaration",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"decls",
										"true"
									]
								},
								{
									"name": "MetaModel.embeddedInMaps",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Declarations of annotation types for use by annotations"
									]
								},
								{
									"name": "MetaModel.markdownDescription",
									"arguments": [
										"Declarations of annotation types for use by annotations."
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"An object whose properties map annotation type names to annotation type declarations; or an array of such objects"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "securitySchemes",
							"type": {
								"base": {
									"typeName": "Security.AbstractSecurityScheme",
									"nameSpace": "Security",
									"basicName": "AbstractSecurityScheme",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.embeddedInMaps",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Security schemas declarations"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Declarations of security schemes for use within this API."
									]
								},
								{
									"name": "MetaModel.markdownDescription",
									"arguments": [
										"Declarations of security schemes for use within this API."
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"An object whose properties map security scheme names to security scheme declarations; or an array of such objects"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.internalClass",
							"arguments": []
						}
					],
					"extends": [
						{
							"typeName": "FragmentDeclaration",
							"nameSpace": "",
							"basicName": "FragmentDeclaration",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "Api",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "title",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.required",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Short plain-text label for the API"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "description",
							"type": {
								"typeName": "Sys.MarkdownString",
								"nameSpace": "Sys",
								"basicName": "MarkdownString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"A longer, human-friendly description of the API"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "version",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"The version of the API, e.g. 'v1'"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "baseUri",
							"type": {
								"typeName": "Sys.FullUriTemplateString",
								"nameSpace": "Sys",
								"basicName": "FullUriTemplateString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"A URI that's to be used as the base of all the resources' URIs. Often used as the base of the URL of each resource, containing the location of the API. Can be a template URI."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "baseUriParameters",
							"type": {
								"base": {
									"typeName": "DataModel.TypeDeclaration",
									"nameSpace": "DataModel",
									"basicName": "TypeDeclaration",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"location",
										"DataModel.ModelLocation.BURI"
									]
								},
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"locationKind",
										"DataModel.LocationKind.APISTRUCTURE"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Named parameters used in the baseUri (template)"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "protocols",
							"type": {
								"base": {
									"typeName": "string",
									"nameSpace": "",
									"basicName": "string",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": null
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.oneOf",
									"arguments": [
										[
											"HTTP",
											"HTTPS"
										]
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"The protocols supported by the API"
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"Array of strings, with each being \"HTTP\" or \"HTTPS\", case-insensitive"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "mediaType",
							"type": {
								"base": {
									"typeName": "Bodies.MimeType",
									"nameSpace": "Bodies",
									"basicName": "MimeType",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.oftenKeys",
									"arguments": [
										[
											"application/json",
											"application/xml",
											"application/x-www-form-urlencoded",
											"multipart/form-data"
										]
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"The default media type to use for request and response bodies (payloads), e.g. \"application/json\""
									]
								},
								{
									"name": "MetaModel.inherited",
									"arguments": []
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"Media type string"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "securedBy",
							"type": {
								"base": {
									"typeName": "Security.SecuritySchemeRef",
									"nameSpace": "Security",
									"basicName": "SecuritySchemeRef",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"The security schemes that apply to every resource and method in the API"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "resources",
							"type": {
								"base": {
									"typeName": "Resources.Resource",
									"nameSpace": "Resources",
									"basicName": "Resource",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.documentationTableLabel",
									"arguments": [
										"/&lt;relativeUri&gt;"
									]
								},
								{
									"name": "MetaModel.newInstanceName",
									"arguments": [
										"New Resource"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"The resources of the API, identified as relative URIs that begin with a slash (/). Every property whose key begins with a slash (/), and is either at the root of the API definition or is the child property of a resource property, is a resource property, e.g.: /users, /{groupId}, etc"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "documentation",
							"type": {
								"base": {
									"typeName": "DocumentationItem",
									"nameSpace": "",
									"basicName": "DocumentationItem",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Additional overall documentation for the API"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "RAMLVersion",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.customHandling",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Returns RAML version. \"RAML10\" string is returned for RAML 1.0. \"RAML08\" string is returned for RAML 0.8."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [],
					"extends": [
						{
							"typeName": "LibraryBase",
							"nameSpace": "",
							"basicName": "LibraryBase",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {
						"annotations": [
							{
								"name": "MetaModel.markdownDescription",
								"arguments": [
									"Annotations to be applied to this API. Annotations are any property whose key begins with \"(\" and ends with \")\" and whose name (the part between the beginning and ending parentheses) is a declared annotation name."
								]
							}
						]
					}
				},
				{
					"name": "Overlay",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "usage",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"contains description of why overlay exist"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "extends",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.required",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Location of a valid RAML API definition (or overlay or extension), the overlay is applied to."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "title",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Short plain-text label for the API"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [],
					"extends": [
						{
							"typeName": "Api",
							"nameSpace": "",
							"basicName": "Api",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "Extension",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "usage",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"contains description of why extension exist"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "extends",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.required",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Location of a valid RAML API definition (or overlay or extension), the extension is applied to"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "title",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Short plain-text label for the API"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [],
					"extends": [
						{
							"typeName": "Api",
							"nameSpace": "",
							"basicName": "Api",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "UsesDeclaration",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "key",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.key",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Name prefix (without dot) used to refer imported declarations"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "value",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Content of the schema"
									]
								},
								{
									"name": "MetaModel.canBeValue",
									"arguments": []
								},
								{
									"name": "MetaModel.value",
									"arguments": []
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [],
					"extends": [
						{
							"typeName": "Annotable",
							"nameSpace": "",
							"basicName": "Annotable",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "FragmentDeclaration",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "uses",
							"type": {
								"base": {
									"typeName": "UsesDeclaration",
									"nameSpace": "",
									"basicName": "UsesDeclaration",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.embeddedInMaps",
									"arguments": []
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [],
					"extends": [
						{
							"typeName": "Annotable",
							"nameSpace": "",
							"basicName": "Annotable",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "DocumentationItem",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "title",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Title of documentation section"
									]
								},
								{
									"name": "MetaModel.required",
									"arguments": []
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "content",
							"type": {
								"typeName": "Sys.MarkdownString",
								"nameSpace": "Sys",
								"basicName": "MarkdownString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Content of documentation section"
									]
								},
								{
									"name": "MetaModel.required",
									"arguments": []
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.possibleInterfaces",
							"arguments": [
								[
									"FragmentDeclaration"
								]
							]
						}
					],
					"extends": [
						{
							"typeName": "Annotable",
							"nameSpace": "",
							"basicName": "Annotable",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				}
			],
			"aliases": [],
			"enumDeclarations": [],
			"imports": {
				"MetaModel": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",
				"Sys": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts",
				"Methods": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts",
				"Resources": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts",
				"Decls": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/declarations.ts",
				"Params": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/parameters.ts",
				"Common": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/common.ts",
				"Bodies": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/bodies.ts",
				"DataModel": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts",
				"Security": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"
			},
			"name": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/api.ts"
		},
		{
			"classes": [
				{
					"name": "SpecPartMetaData",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": true,
					"annotations": [],
					"extends": [],
					"moduleName": null,
					"annotationOverridings": {}
				}
			],
			"aliases": [],
			"enumDeclarations": [],
			"imports": {},
			"name": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts"
		},
		{
			"classes": [
				{
					"name": "ValueType",
					"methods": [
						{
							"returnType": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"name": "value",
							"start": 170,
							"end": 210,
							"text": "\n\n  value():string {\n    return null\n  }",
							"arguments": []
						}
					],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [],
					"extends": [
						{
							"typeName": "Annotable",
							"nameSpace": "",
							"basicName": "Annotable",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "StringType",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.nameAtRuntime",
							"arguments": [
								"string"
							]
						},
						{
							"name": "MetaModel.alias",
							"arguments": [
								"string"
							]
						}
					],
					"extends": [
						{
							"typeName": "ValueType",
							"nameSpace": "",
							"basicName": "ValueType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "AnyType",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.nameAtRuntime",
							"arguments": [
								"any"
							]
						},
						{
							"name": "MetaModel.alias",
							"arguments": [
								"any"
							]
						}
					],
					"extends": [
						{
							"typeName": "ValueType",
							"nameSpace": "",
							"basicName": "ValueType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "NumberType",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.nameAtRuntime",
							"arguments": [
								"number"
							]
						},
						{
							"name": "MetaModel.alias",
							"arguments": [
								"number"
							]
						}
					],
					"extends": [
						{
							"typeName": "ValueType",
							"nameSpace": "",
							"basicName": "ValueType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "IntegerType",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.nameAtRuntime",
							"arguments": [
								"integer"
							]
						},
						{
							"name": "MetaModel.alias",
							"arguments": [
								"integer"
							]
						}
					],
					"extends": [
						{
							"typeName": "ValueType",
							"nameSpace": "",
							"basicName": "ValueType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "NullType",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.nameAtRuntime",
							"arguments": [
								"null"
							]
						},
						{
							"name": "MetaModel.alias",
							"arguments": [
								"null"
							]
						}
					],
					"extends": [
						{
							"typeName": "ValueType",
							"nameSpace": "",
							"basicName": "ValueType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "TimeOnlyType",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.nameAtRuntime",
							"arguments": [
								"time-only"
							]
						},
						{
							"name": "MetaModel.alias",
							"arguments": [
								"time-only"
							]
						}
					],
					"extends": [
						{
							"typeName": "ValueType",
							"nameSpace": "",
							"basicName": "ValueType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "DateOnlyType",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.nameAtRuntime",
							"arguments": [
								"date-only"
							]
						},
						{
							"name": "MetaModel.alias",
							"arguments": [
								"date-only"
							]
						}
					],
					"extends": [
						{
							"typeName": "ValueType",
							"nameSpace": "",
							"basicName": "ValueType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "DateTimeOnlyType",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.nameAtRuntime",
							"arguments": [
								"datetime-only"
							]
						},
						{
							"name": "MetaModel.alias",
							"arguments": [
								"datetime-only"
							]
						}
					],
					"extends": [
						{
							"typeName": "ValueType",
							"nameSpace": "",
							"basicName": "ValueType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "DateTimeType",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.nameAtRuntime",
							"arguments": [
								"datetime"
							]
						},
						{
							"name": "MetaModel.alias",
							"arguments": [
								"datetime"
							]
						}
					],
					"extends": [
						{
							"typeName": "ValueType",
							"nameSpace": "",
							"basicName": "ValueType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "FileType",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.nameAtRuntime",
							"arguments": [
								"file"
							]
						},
						{
							"name": "MetaModel.alias",
							"arguments": [
								"file"
							]
						}
					],
					"extends": [
						{
							"typeName": "ValueType",
							"nameSpace": "",
							"basicName": "ValueType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "BooleanType",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.nameAtRuntime",
							"arguments": [
								"boolean"
							]
						},
						{
							"name": "MetaModel.alias",
							"arguments": [
								"boolean"
							]
						}
					],
					"extends": [
						{
							"typeName": "ValueType",
							"nameSpace": "",
							"basicName": "ValueType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "Reference",
					"methods": [],
					"typeParameters": [
						"T"
					],
					"typeParameterConstraint": [
						null
					],
					"implements": [],
					"fields": [
						{
							"name": "structuredValue",
							"type": {
								"typeName": "DataModel.TypeInstance",
								"nameSpace": "DataModel",
								"basicName": "TypeInstance",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.customHandling",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Returns a structured object if the reference point to one."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "name",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.customHandling",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Returns name of referenced object"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [],
					"extends": [
						{
							"typeName": "ValueType",
							"nameSpace": "",
							"basicName": "ValueType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "UriTemplate",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"This type currently serves both for absolute and relative urls"
							]
						}
					],
					"extends": [
						{
							"typeName": "StringType",
							"nameSpace": "",
							"basicName": "StringType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "StatusCodeString",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [],
					"extends": [
						{
							"typeName": "StringType",
							"nameSpace": "",
							"basicName": "StringType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "RelativeUriString",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"This  type describes relative uri templates"
							]
						}
					],
					"extends": [
						{
							"typeName": "UriTemplate",
							"nameSpace": "",
							"basicName": "UriTemplate",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "FullUriTemplateString",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"This  type describes absolute uri templates"
							]
						}
					],
					"extends": [
						{
							"typeName": "UriTemplate",
							"nameSpace": "",
							"basicName": "UriTemplate",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "FixedUriString",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"This  type describes fixed uris"
							]
						}
					],
					"extends": [
						{
							"typeName": "StringType",
							"nameSpace": "",
							"basicName": "StringType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "ContentType",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [],
					"extends": [
						{
							"typeName": "StringType",
							"nameSpace": "",
							"basicName": "StringType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "MarkdownString",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.innerType",
							"arguments": [
								"markdown"
							]
						},
						{
							"name": "MetaModel.description",
							"arguments": [
								"[GitHub Flavored Markdown](https://help.github.com/articles/github-flavored-markdown/)"
							]
						}
					],
					"extends": [
						{
							"typeName": "StringType",
							"nameSpace": "",
							"basicName": "StringType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "SchemaString",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"Schema at this moment only two subtypes are supported (json schema and xsd)"
							]
						},
						{
							"name": "MetaModel.alias",
							"arguments": [
								"schema"
							]
						}
					],
					"extends": [
						{
							"typeName": "StringType",
							"nameSpace": "",
							"basicName": "StringType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				}
			],
			"aliases": [],
			"enumDeclarations": [],
			"imports": {
				"MetaModel": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",
				"DataModel": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts",
				"Common": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/common.ts"
			},
			"name": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts"
		},
		{
			"classes": [
				{
					"name": "ExampleSpec",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "value",
							"type": {
								"typeName": "any",
								"nameSpace": "",
								"basicName": "any",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.example",
									"arguments": []
								},
								{
									"name": "MetaModel.selfNode",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"String representation of example"
									]
								},
								{
									"name": "MetaModel.required",
									"arguments": []
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"* Valid value for this type<br>* String representing the serialized version of a valid value"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "structuredValue",
							"type": {
								"typeName": "TypeInstance",
								"nameSpace": "",
								"basicName": "TypeInstance",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.customHandling",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Returns object representation of example, if possible"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "strict",
							"type": {
								"typeName": "boolean",
								"nameSpace": "",
								"basicName": "boolean",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"By default, examples are validated against any type declaration. Set this to false to allow examples that need not validate."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "name",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.key",
									"arguments": []
								},
								{
									"name": "MetaModel.hide",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Example identifier, if specified"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "displayName",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"An alternate, human-friendly name for the example"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "description",
							"type": {
								"typeName": "Sys.MarkdownString",
								"nameSpace": "Sys",
								"basicName": "MarkdownString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"A longer, human-friendly description of the example"
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"markdown string"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.customHandling",
							"arguments": []
						},
						{
							"name": "MetaModel.possibleInterfaces",
							"arguments": [
								"FragmentDeclaration"
							]
						}
					],
					"extends": [
						{
							"typeName": "Annotable",
							"nameSpace": "",
							"basicName": "Annotable",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {
						"annotations": [
							{
								"name": "MetaModel.markdownDescription",
								"arguments": [
									"Annotations to be applied to this example. Annotations are any property whose key begins with \"(\" and ends with \")\" and whose name (the part between the beginning and ending parentheses) is a declared annotation name."
								]
							}
						]
					}
				},
				{
					"name": "TypeDeclaration",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "name",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.key",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"name of the parameter"
									]
								},
								{
									"name": "MetaModel.extraMetaKey",
									"arguments": [
										"headers"
									]
								},
								{
									"name": "MetaModel.hide",
									"arguments": []
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "displayName",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"The displayName attribute specifies the type display name. It is a friendly name used only for  display or documentation purposes. If displayName is not specified, it defaults to the element's key (the name of the property itself)."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "facets",
							"type": {
								"base": {
									"typeName": "TypeDeclaration",
									"nameSpace": "",
									"basicName": "TypeDeclaration",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.declaringFields",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"When extending from a type you can define new facets (which can then be set to concrete values by subtypes)."
									]
								},
								{
									"name": "MetaModel.hide",
									"arguments": []
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "fixedFacets",
							"type": {
								"typeName": "TypeInstance",
								"nameSpace": "",
								"basicName": "TypeInstance",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.customHandling",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Returns facets fixed by the type. Value is an object with properties named after facets fixed. Value of each property is a value of the corresponding facet."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "schema",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.typeExpression",
									"arguments": []
								},
								{
									"name": "MetaModel.allowMultiple",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Alias for the equivalent \"type\" property, for compatibility with RAML 0.8. Deprecated - API definitions should use the \"type\" property, as the \"schema\" alias for that property name may be removed in a future RAML version. The \"type\" property allows for XML and JSON schemas."
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"Single string denoting the base type or type expression"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "type",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.typeExpression",
									"arguments": []
								},
								{
									"name": "MetaModel.allowMultiple",
									"arguments": []
								},
								{
									"name": "MetaModel.canBeValue",
									"arguments": []
								},
								{
									"name": "MetaModel.defaultValue",
									"arguments": [
										"string"
									]
								},
								{
									"name": "MetaModel.descriminatingProperty",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"A base type which the current type extends, or more generally a type expression."
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"string denoting the base type or type expression"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "structuredType",
							"type": {
								"typeName": "TypeInstance",
								"nameSpace": "",
								"basicName": "TypeInstance",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.customHandling",
									"arguments": []
								},
								{
									"name": "MetaModel.typeExpression",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Inlined supertype definition."
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"Inlined supertype definition"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "location",
							"type": {
								"typeName": "ModelLocation",
								"nameSpace": "",
								"basicName": "ModelLocation",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.system",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Location of the parameter (can not be edited by user)"
									]
								},
								{
									"name": "MetaModel.hide",
									"arguments": []
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "locationKind",
							"type": {
								"typeName": "LocationKind",
								"nameSpace": "",
								"basicName": "LocationKind",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.system",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Kind of location"
									]
								},
								{
									"name": "MetaModel.hide",
									"arguments": []
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "default",
							"type": {
								"typeName": "any",
								"nameSpace": "",
								"basicName": "any",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Provides default value for a property"
									]
								},
								{
									"name": "MetaModel.hide",
									"arguments": []
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "example",
							"type": {
								"typeName": "ExampleSpec",
								"nameSpace": "",
								"basicName": "ExampleSpec",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.example",
									"arguments": []
								},
								{
									"name": "MetaModel.selfNode",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"An example of this type instance represented as string or yaml map/sequence. This can be used, e.g., by documentation generators to generate sample values for an object of this type. Cannot be present if the examples property is present."
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"* Valid value for this type<br>* String representing the serialized version of a valid value"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "examples",
							"type": {
								"base": {
									"typeName": "ExampleSpec",
									"nameSpace": "",
									"basicName": "ExampleSpec",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.example",
									"arguments": []
								},
								{
									"name": "MetaModel.selfNode",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"An example of this type instance represented as string. This can be used, e.g., by documentation generators to generate sample values for an object of this type. Cannot be present if the example property is present."
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"* Valid value for this type<br>* String representing the serialized version of a valid value"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "repeat",
							"type": {
								"typeName": "boolean",
								"nameSpace": "",
								"basicName": "boolean",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.requireValue",
									"arguments": [
										"fieldOrParam",
										true
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"The repeat attribute specifies that the parameter can be repeated. If the parameter can be used multiple times, the repeat parameter value MUST be set to 'true'. Otherwise, the default value is 'false' and the parameter may not be repeated."
									]
								},
								{
									"name": "MetaModel.defaultBooleanValue",
									"arguments": [
										false
									]
								},
								{
									"name": "MetaModel.hide",
									"arguments": []
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "required",
							"type": {
								"typeName": "boolean",
								"nameSpace": "",
								"basicName": "boolean",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.requireValue",
									"arguments": [
										"fieldOrParam",
										true
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Sets if property is optional or not"
									]
								},
								{
									"name": "MetaModel.describesAnnotation",
									"arguments": [
										"required"
									]
								},
								{
									"name": "MetaModel.hide",
									"arguments": []
								},
								{
									"name": "MetaModel.defaultBooleanValue",
									"arguments": [
										true
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "description",
							"type": {
								"typeName": "Sys.MarkdownString",
								"nameSpace": "Sys",
								"basicName": "MarkdownString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"A longer, human-friendly description of the type"
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"markdown string"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "xml",
							"type": {
								"typeName": "XMLFacetInfo",
								"nameSpace": "",
								"basicName": "XMLFacetInfo",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
							},
							"annotations": [],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "allowedTargets",
							"type": {
								"base": {
									"typeName": "AnnotationTarget",
									"nameSpace": "",
									"basicName": "AnnotationTarget",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.oneOf",
									"arguments": [
										[
											"API",
											"DocumentationItem",
											"Resource",
											"Method",
											"Response",
											"RequestBody",
											"ResponseBody",
											"TypeDeclaration",
											"NamedExample",
											"ResourceType",
											"Trait",
											"SecurityScheme",
											"SecuritySchemeSettings",
											"AnnotationTypeDeclaration",
											"Library",
											"Overlay",
											"Extension",
											"Scalar"
										]
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Restrictions on where annotations of this type can be applied. If this property is specified, annotations of this type may only be applied on a property corresponding to one of the target names specified as the value of this property."
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"An array, or single, of names allowed target nodes."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "isAnnotation",
							"type": {
								"typeName": "boolean",
								"nameSpace": "",
								"basicName": "boolean",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Whether the type represents annotation"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.convertsToGlobalOfType",
							"arguments": [
								"SchemaString"
							]
						},
						{
							"name": "MetaModel.canInherit",
							"arguments": [
								"mediaType"
							]
						},
						{
							"name": "MetaModel.possibleInterfaces",
							"arguments": [
								[
									"FragmentDeclaration"
								]
							]
						}
					],
					"extends": [
						{
							"typeName": "Annotable",
							"nameSpace": "",
							"basicName": "Annotable",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {
						"annotations": [
							{
								"name": "MetaModel.markdownDescription",
								"arguments": [
									"Annotations to be applied to this type. Annotations are any property whose key begins with \"(\" and ends with \")\" and whose name (the part between the beginning and ending parentheses) is a declared annotation name."
								]
							}
						]
					}
				},
				{
					"name": "XMLFacetInfo",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "attribute",
							"type": {
								"typeName": "boolean",
								"nameSpace": "",
								"basicName": "boolean",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"If attribute is set to true, a type instance should be serialized as an XML attribute. It can only be true for scalar types."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "wrapped",
							"type": {
								"typeName": "boolean",
								"nameSpace": "",
								"basicName": "boolean",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"If wrapped is set to true, a type instance should be wrapped in its own XML element. It can not be true for scalar types and it can not be true at the same moment when attribute is true."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "name",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Allows to override the name of the XML element or XML attribute in it's XML representation."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "namespace",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Allows to configure the name of the XML namespace."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "prefix",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Allows to configure the prefix which will be used during serialization to XML."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [],
					"extends": [
						{
							"typeName": "Annotable",
							"nameSpace": "",
							"basicName": "Annotable",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "ArrayTypeDeclaration",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "array"
							},
							"optional": false
						},
						{
							"name": "uniqueItems",
							"type": {
								"typeName": "boolean",
								"nameSpace": "",
								"basicName": "boolean",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.facetId",
									"arguments": [
										"uniqueItems"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Should items in array be unique"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "items",
							"type": {
								"typeName": "TypeDeclaration",
								"nameSpace": "",
								"basicName": "TypeDeclaration",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Array component type."
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"Inline type declaration or type name."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "minItems",
							"type": {
								"typeName": "number",
								"nameSpace": "",
								"basicName": "number",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.facetId",
									"arguments": [
										"minItems"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Minimum amount of items in array"
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"integer ( >= 0 ). Defaults to 0"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "maxItems",
							"type": {
								"typeName": "number",
								"nameSpace": "",
								"basicName": "number",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.facetId",
									"arguments": [
										"maxItems"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Maximum amount of items in array"
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"integer ( >= 0 ). Defaults to undefined."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.convertsToGlobalOfType",
							"arguments": [
								"SchemaString"
							]
						},
						{
							"name": "MetaModel.alias",
							"arguments": [
								"array"
							]
						},
						{
							"name": "MetaModel.declaresSubTypeOf",
							"arguments": [
								"TypeDeclaration"
							]
						}
					],
					"extends": [
						{
							"typeName": "TypeDeclaration",
							"nameSpace": "",
							"basicName": "TypeDeclaration",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "UnionTypeDeclaration",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "union"
							},
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.convertsToGlobalOfType",
							"arguments": [
								"SchemaString"
							]
						},
						{
							"name": "MetaModel.requireValue",
							"arguments": [
								"locationKind",
								"LocationKind.MODELS"
							]
						},
						{
							"name": "MetaModel.declaresSubTypeOf",
							"arguments": [
								"TypeDeclaration"
							]
						}
					],
					"extends": [
						{
							"typeName": "TypeDeclaration",
							"nameSpace": "",
							"basicName": "TypeDeclaration",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "ObjectTypeDeclaration",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [
								{
									"name": "MetaModel.hide",
									"arguments": []
								}
							],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "object"
							},
							"optional": false
						},
						{
							"name": "properties",
							"type": {
								"base": {
									"typeName": "TypeDeclaration",
									"nameSpace": "",
									"basicName": "TypeDeclaration",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"fieldOrParam",
										true
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"The properties that instances of this type may or must have."
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"An object whose keys are the properties' names and whose values are property declarations."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "minProperties",
							"type": {
								"typeName": "number",
								"nameSpace": "",
								"basicName": "number",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.facetId",
									"arguments": [
										"minProperties"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"The minimum number of properties allowed for instances of this type."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "maxProperties",
							"type": {
								"typeName": "number",
								"nameSpace": "",
								"basicName": "number",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.facetId",
									"arguments": [
										"maxProperties"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"The maximum number of properties allowed for instances of this type."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "additionalProperties",
							"type": {
								"typeName": "TypeDeclaration",
								"nameSpace": "",
								"basicName": "TypeDeclaration",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"JSON schema style syntax for declaring maps"
									]
								},
								{
									"name": "MetaModel.markdownDescription",
									"arguments": [
										"JSON schema style syntax for declaring maps. See [[raml-10-spec-map-types|Map Types]]."
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"Inline type declaration or typename"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "patternProperties",
							"type": {
								"base": {
									"typeName": "TypeDeclaration",
									"nameSpace": "",
									"basicName": "TypeDeclaration",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"JSON schema style syntax for declaring key restricted maps"
									]
								},
								{
									"name": "MetaModel.markdownDescription",
									"arguments": [
										"JSON schema style syntax for declaring key restricted maps. See [[raml-10-spec-map-types|Map Types]]."
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"An object whose properties map regular expressions (which are regarded as defining ranges for property names) to types of properties expressed as Inline type declaration or typename."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "discriminator",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Type property name to be used as discriminator, or boolean"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "discriminatorValue",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"The value of discriminator for the type."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.definingPropertyIsEnough",
							"arguments": [
								"properties"
							]
						},
						{
							"name": "MetaModel.setsContextValue",
							"arguments": [
								"field",
								"true"
							]
						},
						{
							"name": "MetaModel.convertsToGlobalOfType",
							"arguments": [
								"SchemaString"
							]
						},
						{
							"name": "MetaModel.declaresSubTypeOf",
							"arguments": [
								"TypeDeclaration"
							]
						}
					],
					"extends": [
						{
							"typeName": "TypeDeclaration",
							"nameSpace": "",
							"basicName": "TypeDeclaration",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "StringTypeDeclaration",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "string"
							},
							"optional": false
						},
						{
							"name": "pattern",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.facetId",
									"arguments": [
										"pattern"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Regular expression that this string should path"
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"regexp"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "minLength",
							"type": {
								"typeName": "number",
								"nameSpace": "",
								"basicName": "number",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.facetId",
									"arguments": [
										"minLength"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Minimum length of the string"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "maxLength",
							"type": {
								"typeName": "number",
								"nameSpace": "",
								"basicName": "number",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.facetId",
									"arguments": [
										"maxLength"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Maximum length of the string"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "enum",
							"type": {
								"base": {
									"typeName": "string",
									"nameSpace": "",
									"basicName": "string",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": null
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.facetId",
									"arguments": [
										"enum"
									]
								},
								{
									"name": "MetaModel.describesAnnotation",
									"arguments": [
										"oneOf"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"(Optional, applicable only for parameters of type string) The enum attribute provides an enumeration of the parameter's valid values. This MUST be an array. If the enum attribute is defined, API clients and servers MUST verify that a parameter's value matches a value in the enum array. If there is no matching value, the clients and servers MUST treat this as an error."
									]
								},
								{
									"name": "MetaModel.hide",
									"arguments": []
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"Value must be a string"
							]
						},
						{
							"name": "MetaModel.declaresSubTypeOf",
							"arguments": [
								"TypeDeclaration"
							]
						}
					],
					"extends": [
						{
							"typeName": "TypeDeclaration",
							"nameSpace": "",
							"basicName": "TypeDeclaration",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "BooleanTypeDeclaration",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "boolean"
							},
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"Value must be a boolean"
							]
						},
						{
							"name": "MetaModel.declaresSubTypeOf",
							"arguments": [
								"TypeDeclaration"
							]
						}
					],
					"extends": [
						{
							"typeName": "TypeDeclaration",
							"nameSpace": "",
							"basicName": "TypeDeclaration",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "NumberTypeDeclaration",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "number"
							},
							"optional": false
						},
						{
							"name": "minimum",
							"type": {
								"typeName": "number",
								"nameSpace": "",
								"basicName": "number",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.facetId",
									"arguments": [
										"minimum"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"(Optional, applicable only for parameters of type number or integer) The minimum attribute specifies the parameter's minimum value."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "maximum",
							"type": {
								"typeName": "number",
								"nameSpace": "",
								"basicName": "number",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.facetId",
									"arguments": [
										"maximum"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"(Optional, applicable only for parameters of type number or integer) The maximum attribute specifies the parameter's maximum value."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "enum",
							"type": {
								"base": {
									"typeName": "string",
									"nameSpace": "",
									"basicName": "string",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": null
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.facetId",
									"arguments": [
										"enum"
									]
								},
								{
									"name": "MetaModel.describesAnnotation",
									"arguments": [
										"oneOf"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"(Optional, applicable only for parameters of type string) The enum attribute provides an enumeration of the parameter's valid values. This MUST be an array. If the enum attribute is defined, API clients and servers MUST verify that a parameter's value matches a value in the enum array. If there is no matching value, the clients and servers MUST treat this as an error."
									]
								},
								{
									"name": "MetaModel.hide",
									"arguments": []
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "format",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.oneOf",
									"arguments": [
										[
											"int32",
											"int64",
											"int",
											"long",
											"float",
											"double",
											"int16",
											"int8"
										]
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Value format"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "multipleOf",
							"type": {
								"typeName": "number",
								"nameSpace": "",
								"basicName": "number",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"A numeric instance is valid against \"multipleOf\" if the result of the division of the instance by this keyword's value is an integer."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"Value MUST be a number. Indicate floating point numbers as defined by YAML."
							]
						},
						{
							"name": "MetaModel.declaresSubTypeOf",
							"arguments": [
								"TypeDeclaration"
							]
						}
					],
					"extends": [
						{
							"typeName": "TypeDeclaration",
							"nameSpace": "",
							"basicName": "TypeDeclaration",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "IntegerTypeDeclaration",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "integer"
							},
							"optional": false
						},
						{
							"name": "format",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.oneOf",
									"arguments": [
										[
											"int32",
											"int64",
											"int",
											"long",
											"int16",
											"int8"
										]
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Value format"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"Value MUST be a integer."
							]
						},
						{
							"name": "MetaModel.declaresSubTypeOf",
							"arguments": [
								"TypeDeclaration"
							]
						}
					],
					"extends": [
						{
							"typeName": "NumberTypeDeclaration",
							"nameSpace": "",
							"basicName": "NumberTypeDeclaration",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "DateOnlyTypeDeclaration",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "date-only"
							},
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"the \"full-date\" notation of RFC3339, namely yyyy-mm-dd (no implications about time or timezone-offset)"
							]
						},
						{
							"name": "MetaModel.declaresSubTypeOf",
							"arguments": [
								"TypeDeclaration"
							]
						}
					],
					"extends": [
						{
							"typeName": "TypeDeclaration",
							"nameSpace": "",
							"basicName": "TypeDeclaration",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "TimeOnlyTypeDeclaration",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "time-only"
							},
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"the \"partial-time\" notation of RFC3339, namely hh:mm:ss[.ff...] (no implications about date or timezone-offset)"
							]
						},
						{
							"name": "MetaModel.declaresSubTypeOf",
							"arguments": [
								"TypeDeclaration"
							]
						}
					],
					"extends": [
						{
							"typeName": "TypeDeclaration",
							"nameSpace": "",
							"basicName": "TypeDeclaration",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "DateTimeOnlyTypeDeclaration",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "datetime-only"
							},
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"combined date-only and time-only with a separator of \"T\", namely yyyy-mm-ddThh:mm:ss[.ff...] (no implications about timezone-offset)"
							]
						},
						{
							"name": "MetaModel.declaresSubTypeOf",
							"arguments": [
								"TypeDeclaration"
							]
						}
					],
					"extends": [
						{
							"typeName": "TypeDeclaration",
							"nameSpace": "",
							"basicName": "TypeDeclaration",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "DateTimeTypeDeclaration",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "datetime"
							},
							"optional": false
						},
						{
							"name": "format",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.oneOf",
									"arguments": [
										[
											"rfc3339",
											"rfc2616"
										]
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Format used for this date time rfc3339 or rfc2616"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"a timestamp, either in the \"date-time\" notation of RFC3339, if format is omitted or is set to rfc3339, or in the format defined in RFC2616, if format is set to rfc2616."
							]
						},
						{
							"name": "MetaModel.declaresSubTypeOf",
							"arguments": [
								"TypeDeclaration"
							]
						}
					],
					"extends": [
						{
							"typeName": "TypeDeclaration",
							"nameSpace": "",
							"basicName": "TypeDeclaration",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "DateTypeDeclaration",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "date"
							},
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"Value MUST be a string representation of a date as defined in RFC2616 Section 3.3, or according to specified date format"
							]
						},
						{
							"name": "MetaModel.declaresSubTypeOf",
							"arguments": [
								"TypeDeclaration"
							]
						}
					],
					"extends": [
						{
							"typeName": "TypeDeclaration",
							"nameSpace": "",
							"basicName": "TypeDeclaration",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "TypeInstance",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "properties",
							"type": {
								"base": {
									"typeName": "TypeInstanceProperty",
									"nameSpace": "",
									"basicName": "TypeInstanceProperty",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Array of instance properties"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "isScalar",
							"type": {
								"typeName": "boolean",
								"nameSpace": "",
								"basicName": "boolean",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Whether the type is scalar"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "value",
							"type": {
								"typeName": "any",
								"nameSpace": "",
								"basicName": "any",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"For instances of scalar types returns scalar value"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.customHandling",
							"arguments": []
						}
					],
					"extends": [],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "TypeInstanceProperty",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "name",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Property name"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "value",
							"type": {
								"typeName": "TypeInstance",
								"nameSpace": "",
								"basicName": "TypeInstance",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Property value"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "values",
							"type": {
								"base": {
									"typeName": "TypeInstance",
									"nameSpace": "",
									"basicName": "TypeInstance",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Array of values if property value is array"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "isArray",
							"type": {
								"typeName": "boolean",
								"nameSpace": "",
								"basicName": "boolean",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Whether property has array as value"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.customHandling",
							"arguments": []
						}
					],
					"extends": [],
					"moduleName": null,
					"annotationOverridings": {}
				}
			],
			"aliases": [],
			"enumDeclarations": [
				{
					"name": "ModelLocation",
					"members": [
						"QUERY",
						"HEADERS",
						"URI",
						"FORM",
						"BURI",
						"ANNOTATION",
						"MODEL",
						"SECURITYSCHEMATYPE"
					]
				},
				{
					"name": "LocationKind",
					"members": [
						"APISTRUCTURE",
						"DECLARATIONS",
						"MODELS"
					]
				}
			],
			"imports": {
				"MetaModel": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",
				"Sys": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts",
				"Bodies": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/bodies.ts",
				"Common": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/common.ts",
				"Declarations": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/declarations.ts"
			},
			"name": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
		},
		{
			"classes": [
				{
					"name": "MimeType",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"This sub type of the string represents mime types"
							]
						}
					],
					"extends": [
						{
							"typeName": "StringType",
							"nameSpace": "",
							"basicName": "StringType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/bodies.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "Response",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "code",
							"type": {
								"typeName": "Sys.StatusCodeString",
								"nameSpace": "Sys",
								"basicName": "StatusCodeString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/bodies.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.key",
									"arguments": []
								},
								{
									"name": "MetaModel.extraMetaKey",
									"arguments": [
										"statusCodes"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Responses MUST be a map of one or more HTTP status codes, where each status code itself is a map that describes that status code."
									]
								},
								{
									"name": "MetaModel.hide",
									"arguments": []
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "headers",
							"type": {
								"base": {
									"typeName": "DataModel.TypeDeclaration",
									"nameSpace": "DataModel",
									"basicName": "TypeDeclaration",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/bodies.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"fieldOrParam",
										true
									]
								},
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"location",
										"DataModel.ModelLocation.HEADERS"
									]
								},
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"locationKind",
										"DataModel.LocationKind.APISTRUCTURE"
									]
								},
								{
									"name": "MetaModel.newInstanceName",
									"arguments": [
										"New Header"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Detailed information about any response headers returned by this method"
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"Object whose property names are the response header names and whose values describe the values."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "body",
							"type": {
								"base": {
									"typeName": "DataModel.TypeDeclaration",
									"nameSpace": "DataModel",
									"basicName": "TypeDeclaration",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/bodies.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.newInstanceName",
									"arguments": [
										"New Body"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"The body of the response: a body declaration"
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"Object whose properties are either<br>* Media types and whose values are type objects describing the request body for that media type, or<br>* a type object describing the request body for the default media type specified in the root mediaType property."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "description",
							"type": {
								"typeName": "Sys.MarkdownString",
								"nameSpace": "Sys",
								"basicName": "MarkdownString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/bodies.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"A longer, human-friendly description of the response"
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"Markdown string"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [],
					"extends": [
						{
							"typeName": "Annotable",
							"nameSpace": "",
							"basicName": "Annotable",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/bodies.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {
						"displayName": [
							{
								"name": "MetaModel.description",
								"arguments": [
									"An alternate, human-friendly name for the response"
								]
							}
						],
						"annotations": [
							{
								"name": "MetaModel.markdownDescription",
								"arguments": [
									"Annotations to be applied to this response. Annotations are any property whose key begins with \"(\" and ends with \")\" and whose name (the part between the beginning and ending parentheses) is a declared annotation name."
								]
							}
						]
					}
				}
			],
			"aliases": [],
			"enumDeclarations": [],
			"imports": {
				"MetaModel": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",
				"Sys": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts",
				"DataModel": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts",
				"Common": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/common.ts"
			},
			"name": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/bodies.ts"
		},
		{
			"classes": [
				{
					"name": "Annotable",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "annotations",
							"type": {
								"base": {
									"typeName": "Decls.AnnotationRef",
									"nameSpace": "Decls",
									"basicName": "AnnotationRef",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/common.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.noDirectParse",
									"arguments": []
								},
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"locationKind",
										"datamodel.LocationKind.APISTRUCTURE"
									]
								},
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"location",
										"datamodel.ModelLocation.ANNOTATION"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Most of RAML model elements may have attached annotations decribing additional meta data about this element"
									]
								},
								{
									"name": "MetaModel.documentationTableLabel",
									"arguments": [
										"(&lt;annotationName&gt;)"
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"A value corresponding to the declared type of this annotation."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [],
					"extends": [],
					"moduleName": null,
					"annotationOverridings": {}
				}
			],
			"aliases": [],
			"enumDeclarations": [],
			"imports": {
				"MetaModel": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",
				"Sys": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts",
				"Decls": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/declarations.ts"
			},
			"name": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/common.ts"
		},
		{
			"classes": [
				{
					"name": "AnnotationRef",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "annotation",
							"type": {
								"typeName": "DataModel.TypeDeclaration",
								"nameSpace": "DataModel",
								"basicName": "TypeDeclaration",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/declarations.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.customHandling",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Returns referenced annotation"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"Annotations allow you to attach information to your API"
							]
						},
						{
							"name": "MetaModel.tags",
							"arguments": [
								[
									"annotations"
								]
							]
						}
					],
					"extends": [
						{
							"typeName": "Reference",
							"nameSpace": "",
							"basicName": "Reference",
							"typeKind": 0,
							"typeArguments": [
								{
									"typeName": "DataModel.TypeDeclaration",
									"nameSpace": "DataModel",
									"basicName": "TypeDeclaration",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/declarations.ts"
								}
							],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/declarations.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "AnnotationTarget",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"Elements to which this Annotation can be applied (enum)"
							]
						},
						{
							"name": "MetaModel.tags",
							"arguments": [
								[
									"annotations"
								]
							]
						}
					],
					"extends": [
						{
							"typeName": "ValueType",
							"nameSpace": "",
							"basicName": "ValueType",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/declarations.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				}
			],
			"aliases": [],
			"enumDeclarations": [],
			"imports": {
				"MetaModel": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",
				"Sys": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts",
				"DataModel": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts",
				"Common": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/common.ts"
			},
			"name": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/declarations.ts"
		},
		{
			"classes": [
				{
					"name": "TraitRef",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "trait",
							"type": {
								"typeName": "Trait",
								"nameSpace": "",
								"basicName": "Trait",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.customHandling",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Returns referenced trait"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [],
					"extends": [
						{
							"typeName": "Reference",
							"nameSpace": "",
							"basicName": "Reference",
							"typeKind": 0,
							"typeArguments": [
								{
									"typeName": "Trait",
									"nameSpace": "",
									"basicName": "Trait",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"
								}
							],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "Trait",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "name",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.key",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Name of the trait"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "usage",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Instructions on how and when the trait should be used."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "parametrizedProperties",
							"type": {
								"typeName": "DataModel.TypeInstance",
								"nameSpace": "DataModel",
								"basicName": "TypeInstance",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.customHandling",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Returns object representation of parametrized properties of the trait"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.inlinedTemplates",
							"arguments": []
						},
						{
							"name": "MetaModel.allowQuestion",
							"arguments": []
						},
						{
							"name": "MetaModel.possibleInterfaces",
							"arguments": [
								[
									"FragmentDeclaration"
								]
							]
						}
					],
					"extends": [
						{
							"typeName": "MethodBase",
							"nameSpace": "",
							"basicName": "MethodBase",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {
						"displayName": [
							{
								"name": "MetaModel.description",
								"arguments": [
									"The displayName attribute specifies the trait display name. It is a friendly name used only for  display or documentation purposes. If displayName is not specified, it defaults to the element's key (the name of the property itself)."
								]
							}
						]
					}
				},
				{
					"name": "MethodBase",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "body",
							"type": {
								"base": {
									"typeName": "DataModel.TypeDeclaration",
									"nameSpace": "DataModel",
									"basicName": "TypeDeclaration",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.newInstanceName",
									"arguments": [
										"New Body"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Some method verbs expect the resource to be sent as a request body. For example, to create a resource, the request must include the details of the resource to create. Resources CAN have alternate representations. For example, an API might support both JSON and XML representations. A method's body is defined in the body property as a hashmap, in which the key MUST be a valid media type."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "protocols",
							"type": {
								"base": {
									"typeName": "string",
									"nameSpace": "",
									"basicName": "string",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": null
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.oneOf",
									"arguments": [
										[
											"HTTP",
											"HTTPS"
										]
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"A method can override the protocols specified in the resource or at the API root, by employing this property."
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"array of strings of value HTTP or HTTPS, or a single string of such kind, case-insensitive"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "is",
							"type": {
								"base": {
									"typeName": "TraitRef",
									"nameSpace": "",
									"basicName": "TraitRef",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Instantiation of applyed traits"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "securedBy",
							"type": {
								"base": {
									"typeName": "Security.SecuritySchemeRef",
									"nameSpace": "Security",
									"basicName": "SecuritySchemeRef",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.allowNull",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"securityScheme may also be applied to a resource by using the securedBy key, which is equivalent to applying the securityScheme to all methods that may be declared, explicitly or implicitly, by defining the resourceTypes or traits property for that resource. To indicate that the method may be called without applying any securityScheme, the method may be annotated with the null securityScheme."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "description",
							"type": {
								"typeName": "Sys.MarkdownString",
								"nameSpace": "Sys",
								"basicName": "MarkdownString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"
							},
							"annotations": [],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "displayName",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [],
					"extends": [
						{
							"typeName": "Operation",
							"nameSpace": "",
							"basicName": "Operation",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "Method",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "method",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.key",
									"arguments": []
								},
								{
									"name": "MetaModel.extraMetaKey",
									"arguments": [
										"methods"
									]
								},
								{
									"name": "MetaModel.oneOf",
									"arguments": [
										[
											"get",
											"put",
											"post",
											"delete",
											"options",
											"head",
											"patch"
										]
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Method that can be called"
									]
								},
								{
									"name": "MetaModel.hide",
									"arguments": []
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [],
					"extends": [
						{
							"typeName": "MethodBase",
							"nameSpace": "",
							"basicName": "MethodBase",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {
						"displayName": [
							{
								"name": "MetaModel.description",
								"arguments": [
									"The displayName attribute specifies the method display name. It is a friendly name used only for  display or documentation purposes. If displayName is not specified, it defaults to the element's key (the name of the property itself)."
								]
							}
						]
					}
				},
				{
					"name": "Operation",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "queryParameters",
							"type": {
								"base": {
									"typeName": "DataModel.TypeDeclaration",
									"nameSpace": "DataModel",
									"basicName": "TypeDeclaration",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"fieldOrParam",
										true
									]
								},
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"location",
										"DataModel.ModelLocation.QUERY"
									]
								},
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"locationKind",
										"DataModel.LocationKind.APISTRUCTURE"
									]
								},
								{
									"name": "MetaModel.newInstanceName",
									"arguments": [
										"New query parameter"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"An APIs resources MAY be filtered (to return a subset of results) or altered (such as transforming  a response body from JSON to XML format) by the use of query strings. If the resource or its method supports a query string, the query string MUST be defined by the queryParameters property"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "headers",
							"type": {
								"base": {
									"typeName": "DataModel.TypeDeclaration",
									"nameSpace": "DataModel",
									"basicName": "TypeDeclaration",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"fieldOrParam",
										true
									]
								},
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"location",
										"DataModel.ModelLocation.HEADERS"
									]
								},
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"locationKind",
										"DataModel.LocationKind.APISTRUCTURE"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Headers that allowed at this position"
									]
								},
								{
									"name": "MetaModel.newInstanceName",
									"arguments": [
										"New Header"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "queryString",
							"type": {
								"typeName": "DataModel.TypeDeclaration",
								"nameSpace": "DataModel",
								"basicName": "TypeDeclaration",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Specifies the query string needed by this method. Mutually exclusive with queryParameters."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "responses",
							"type": {
								"base": {
									"typeName": "Bodies.Response",
									"nameSpace": "Bodies",
									"basicName": "Response",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"response",
										"true"
									]
								},
								{
									"name": "MetaModel.newInstanceName",
									"arguments": [
										"New Response"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Information about the expected responses to a request"
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"An object whose keys are the HTTP status codes of the responses and whose values describe the responses."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [],
					"extends": [
						{
							"typeName": "Annotable",
							"nameSpace": "",
							"basicName": "Annotable",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				}
			],
			"aliases": [],
			"enumDeclarations": [],
			"imports": {
				"MetaModel": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",
				"Sys": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts",
				"Bodies": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/bodies.ts",
				"DataModel": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts",
				"Security": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"
			},
			"name": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"
		},
		{
			"classes": [
				{
					"name": "SecuritySchemePart",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [],
					"extends": [
						{
							"typeName": "Operation",
							"nameSpace": "",
							"basicName": "Operation",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {
						"annotations": [
							{
								"name": "MetaModel.description",
								"arguments": [
									"Annotations to be applied to this security scheme part. Annotations are any property whose key begins with \"(\" and ends with \")\" and whose name (the part between the beginning and ending parentheses) is a declared annotation name."
								]
							}
						]
					}
				},
				{
					"name": "SecuritySchemeSettings",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.allowAny",
							"arguments": []
						}
					],
					"extends": [
						{
							"typeName": "Annotable",
							"nameSpace": "",
							"basicName": "Annotable",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "OAuth1SecuritySchemeSettings",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "requestTokenUri",
							"type": {
								"typeName": "Sys.FixedUriString",
								"nameSpace": "Sys",
								"basicName": "FixedUriString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.required",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"The URI of the Temporary Credential Request endpoint as defined in RFC5849 Section 2.1"
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"FixedUriString"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "authorizationUri",
							"type": {
								"typeName": "Sys.FixedUriString",
								"nameSpace": "Sys",
								"basicName": "FixedUriString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.required",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"The URI of the Resource Owner Authorization endpoint as defined in RFC5849 Section 2.2"
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"FixedUriString"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "tokenCredentialsUri",
							"type": {
								"typeName": "Sys.FixedUriString",
								"nameSpace": "Sys",
								"basicName": "FixedUriString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.required",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"The URI of the Token Request endpoint as defined in RFC5849 Section 2.3"
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"FixedUriString"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "signatures",
							"type": {
								"base": {
									"typeName": "string",
									"nameSpace": "",
									"basicName": "string",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": null
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.oneOf",
									"arguments": [
										[
											"HMAC-SHA1",
											"RSA-SHA1",
											"PLAINTEXT"
										]
									]
								},
								{
									"name": "MetaModel.hide",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"List of the signature methods used by the server. Available methods: HMAC-SHA1, RSA-SHA1, PLAINTEXT"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.allowAny",
							"arguments": []
						},
						{
							"name": "MetaModel.functionalDescriminator",
							"arguments": [
								"$parent.type=='OAuth 1.0'"
							]
						}
					],
					"extends": [
						{
							"typeName": "SecuritySchemeSettings",
							"nameSpace": "",
							"basicName": "SecuritySchemeSettings",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "OAuth2SecuritySchemeSettings",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "accessTokenUri",
							"type": {
								"typeName": "Sys.FixedUriString",
								"nameSpace": "Sys",
								"basicName": "FixedUriString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.required",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"The URI of the Token Endpoint as defined in RFC6749 Section 3.2. Not required forby implicit grant type."
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"FixedUriString"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "authorizationUri",
							"type": {
								"typeName": "Sys.FixedUriString",
								"nameSpace": "Sys",
								"basicName": "FixedUriString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"The URI of the Authorization Endpoint as defined in RFC6749 Section 3.1. Required forby authorization_code and implicit grant types."
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"FixedUriString"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "authorizationGrants",
							"type": {
								"base": {
									"typeName": "string",
									"nameSpace": "",
									"basicName": "string",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": null
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.required",
									"arguments": []
								},
								{
									"name": "MetaModel.oftenKeys",
									"arguments": [
										[
											"authorization_code",
											"password",
											"client_credentials",
											"implicit"
										]
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"A list of the Authorization grants supported by the API as defined in RFC6749 Sections 4.1, 4.2, 4.3 and 4.4, can be any of: authorization_code, password, client_credentials, implicit, or any absolute url."
									]
								},
								{
									"name": "MetaModel.markdownDescription",
									"arguments": [
										"A list of the Authorization grants supported by the API as defined in RFC6749 Sections 4.1, 4.2, 4.3 and 4.4, can be any of:<br>* authorization_code<br>* password<br>* client_credentials<br>* implicit <br>*  or any absolute url."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "scopes",
							"type": {
								"base": {
									"typeName": "string",
									"nameSpace": "",
									"basicName": "string",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": null
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"A list of scopes supported by the security scheme as defined in RFC6749 Section 3.3"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.allowAny",
							"arguments": []
						}
					],
					"extends": [
						{
							"typeName": "SecuritySchemeSettings",
							"nameSpace": "",
							"basicName": "SecuritySchemeSettings",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "SecuritySchemeRef",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "securitySchemeName",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.customHandling",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Returns the name of security scheme, this reference refers to."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "securityScheme",
							"type": {
								"typeName": "AbstractSecurityScheme",
								"nameSpace": "",
								"basicName": "AbstractSecurityScheme",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.customHandling",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Returns AST node of security scheme, this reference refers to, or null."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [],
					"extends": [
						{
							"typeName": "Reference",
							"nameSpace": "",
							"basicName": "Reference",
							"typeKind": 0,
							"typeArguments": [
								{
									"typeName": "AbstractSecurityScheme",
									"nameSpace": "",
									"basicName": "AbstractSecurityScheme",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"
								}
							],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "AbstractSecurityScheme",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "name",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.key",
									"arguments": []
								},
								{
									"name": "MetaModel.startFrom",
									"arguments": [
										""
									]
								},
								{
									"name": "MetaModel.hide",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Name of the security scheme"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "type",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.required",
									"arguments": []
								},
								{
									"name": "MetaModel.oneOf",
									"arguments": [
										[
											"OAuth 1.0",
											"OAuth 2.0",
											"Basic Authentication",
											"Digest Authentication",
											"Pass Through",
											"x-{other}"
										]
									]
								},
								{
									"name": "MetaModel.descriminatingProperty",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"The securitySchemes property MUST be used to specify an API's security mechanisms, including the required settings and the authentication methods that the API supports. one authentication method is allowed if the API supports them."
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"string<br><br>The value MUST be one of<br>* OAuth 1.0,<br>* OAuth 2.0,<br>* BasicSecurityScheme Authentication<br>* DigestSecurityScheme Authentication<br>* Pass Through<br>* x-&lt;other&gt;"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "description",
							"type": {
								"typeName": "Sys.MarkdownString",
								"nameSpace": "Sys",
								"basicName": "MarkdownString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"The description attribute MAY be used to describe a security schemes property."
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"The description MAY be used to describe a securityScheme."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "describedBy",
							"type": {
								"typeName": "SecuritySchemePart",
								"nameSpace": "",
								"basicName": "SecuritySchemePart",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"A description of the request components related to Security that are determined by the scheme: the headers, query parameters or responses. As a best practice, even for standard security schemes, API designers SHOULD describe these properties of security schemes. Including the security scheme description completes an API documentation."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "displayName",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"The displayName attribute specifies the security scheme display name. It is a friendly name used only for  display or documentation purposes. If displayName is not specified, it defaults to the element's key (the name of the property itself)."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "settings",
							"type": {
								"typeName": "SecuritySchemeSettings",
								"nameSpace": "",
								"basicName": "SecuritySchemeSettings",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"The settings attribute MAY be used to provide security scheme-specific information. The required attributes vary depending on the type of security scheme is being declared. It describes the minimum set of properties which any processing application MUST provide and validate if it chooses to implement the security scheme. Processing applications MAY choose to recognize other properties for things such as token lifetime, preferred cryptographic algorithms, and more."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"Declares globally referable security scheme definition"
							]
						},
						{
							"name": "MetaModel.actuallyExports",
							"arguments": [
								"$self"
							]
						},
						{
							"name": "MetaModel.referenceIs",
							"arguments": [
								"settings"
							]
						}
					],
					"extends": [
						{
							"typeName": "Annotable",
							"nameSpace": "",
							"basicName": "Annotable",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "OAuth2SecurityScheme",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "OAuth 2.0"
							},
							"optional": false
						},
						{
							"name": "settings",
							"type": {
								"typeName": "OAuth2SecuritySchemeSettings",
								"nameSpace": "",
								"basicName": "OAuth2SecuritySchemeSettings",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"
							},
							"annotations": [],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"Declares globally referable security scheme definition"
							]
						},
						{
							"name": "MetaModel.actuallyExports",
							"arguments": [
								"$self"
							]
						},
						{
							"name": "MetaModel.referenceIs",
							"arguments": [
								"settings"
							]
						}
					],
					"extends": [
						{
							"typeName": "AbstractSecurityScheme",
							"nameSpace": "",
							"basicName": "AbstractSecurityScheme",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "OAuth1SecurityScheme",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "OAuth 1.0"
							},
							"optional": false
						},
						{
							"name": "settings",
							"type": {
								"typeName": "OAuth1SecuritySchemeSettings",
								"nameSpace": "",
								"basicName": "OAuth1SecuritySchemeSettings",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"
							},
							"annotations": [],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"Declares globally referable security scheme definition"
							]
						},
						{
							"name": "MetaModel.actuallyExports",
							"arguments": [
								"$self"
							]
						},
						{
							"name": "MetaModel.referenceIs",
							"arguments": [
								"settings"
							]
						}
					],
					"extends": [
						{
							"typeName": "AbstractSecurityScheme",
							"nameSpace": "",
							"basicName": "AbstractSecurityScheme",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "PassThroughSecurityScheme",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "Pass Through"
							},
							"optional": false
						},
						{
							"name": "settings",
							"type": {
								"typeName": "SecuritySchemeSettings",
								"nameSpace": "",
								"basicName": "SecuritySchemeSettings",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"
							},
							"annotations": [],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"Declares globally referable security scheme definition"
							]
						},
						{
							"name": "MetaModel.actuallyExports",
							"arguments": [
								"$self"
							]
						},
						{
							"name": "MetaModel.referenceIs",
							"arguments": [
								"settings"
							]
						}
					],
					"extends": [
						{
							"typeName": "AbstractSecurityScheme",
							"nameSpace": "",
							"basicName": "AbstractSecurityScheme",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "BasicSecurityScheme",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "Basic Authentication"
							},
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"Declares globally referable security scheme definition"
							]
						},
						{
							"name": "MetaModel.actuallyExports",
							"arguments": [
								"$self"
							]
						},
						{
							"name": "MetaModel.referenceIs",
							"arguments": [
								"settings"
							]
						}
					],
					"extends": [
						{
							"typeName": "AbstractSecurityScheme",
							"nameSpace": "",
							"basicName": "AbstractSecurityScheme",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "DigestSecurityScheme",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "Digest Authentication"
							},
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"Declares globally referable security scheme definition"
							]
						},
						{
							"name": "MetaModel.actuallyExports",
							"arguments": [
								"$self"
							]
						},
						{
							"name": "MetaModel.referenceIs",
							"arguments": [
								"settings"
							]
						}
					],
					"extends": [
						{
							"typeName": "AbstractSecurityScheme",
							"nameSpace": "",
							"basicName": "AbstractSecurityScheme",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "CustomSecurityScheme",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "x-{other}"
							},
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"Declares globally referable security scheme definition"
							]
						},
						{
							"name": "MetaModel.actuallyExports",
							"arguments": [
								"$self"
							]
						},
						{
							"name": "MetaModel.referenceIs",
							"arguments": [
								"settings"
							]
						}
					],
					"extends": [
						{
							"typeName": "AbstractSecurityScheme",
							"nameSpace": "",
							"basicName": "AbstractSecurityScheme",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				}
			],
			"aliases": [],
			"enumDeclarations": [],
			"imports": {
				"MetaModel": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",
				"Sys": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts",
				"Methods": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"
			},
			"name": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts"
		},
		{
			"classes": [
				{
					"name": "ResourceTypeRef",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "resourceType",
							"type": {
								"typeName": "ResourceType",
								"nameSpace": "",
								"basicName": "ResourceType",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.customHandling",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Returns referenced resource type"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [],
					"extends": [
						{
							"typeName": "Reference",
							"nameSpace": "",
							"basicName": "Reference",
							"typeKind": 0,
							"typeArguments": [
								{
									"typeName": "ResourceType",
									"nameSpace": "",
									"basicName": "ResourceType",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"
								}
							],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "ResourceType",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "displayName",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"The displayName attribute specifies the resource type display name. It is a friendly name used only for  display or documentation purposes. If displayName is not specified, it defaults to the element's key (the name of the property itself)."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "name",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.key",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Name of the resource type"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "usage",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Instructions on how and when the resource type should be used."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "parametrizedProperties",
							"type": {
								"typeName": "DataModel.TypeInstance",
								"nameSpace": "DataModel",
								"basicName": "TypeInstance",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.customHandling",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Returns object representation of parametrized properties of the resource type"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.inlinedTemplates",
							"arguments": []
						},
						{
							"name": "MetaModel.allowQuestion",
							"arguments": []
						},
						{
							"name": "MetaModel.possibleInterfaces",
							"arguments": [
								[
									"FragmentDeclaration"
								]
							]
						}
					],
					"extends": [
						{
							"typeName": "ResourceBase",
							"nameSpace": "",
							"basicName": "ResourceBase",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "ResourceBase",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "methods",
							"type": {
								"base": {
									"typeName": "Methods.Method",
									"nameSpace": "Methods",
									"basicName": "Method",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"Methods that are part of this resource type definition"
									]
								},
								{
									"name": "MetaModel.markdownDescription",
									"arguments": [
										"The methods available on this resource."
									]
								},
								{
									"name": "MetaModel.documentationTableLabel",
									"arguments": [
										"get?<br>patch?<br>put?<br>post?<br>delete?<br>options?<br>head?"
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"Object describing the method"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "is",
							"type": {
								"base": {
									"typeName": "Methods.TraitRef",
									"nameSpace": "Methods",
									"basicName": "TraitRef",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"A list of the traits to apply to all methods declared (implicitly or explicitly) for this resource. Individual methods may override this declaration"
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"array, which can contain each of the following elements:<br>* name of unparametrized trait <br>* a key-value pair with trait name as key and a map of trait parameters as value<br>* inline trait declaration <br><br>(or a single element of any above kind)"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "type",
							"type": {
								"typeName": "ResourceTypeRef",
								"nameSpace": "",
								"basicName": "ResourceTypeRef",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"The resource type which this resource inherits."
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"one of the following elements:<br>* name of unparametrized resource type<br>* a key-value pair with resource type name as key and a map of its parameters as value<br>* inline resource type declaration"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "description",
							"type": {
								"typeName": "Sys.MarkdownString",
								"nameSpace": "Sys",
								"basicName": "MarkdownString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"
							},
							"annotations": [],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "securedBy",
							"type": {
								"base": {
									"typeName": "Security.SecuritySchemeRef",
									"nameSpace": "Security",
									"basicName": "SecuritySchemeRef",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.allowNull",
									"arguments": []
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"The security schemes that apply to all methods declared (implicitly or explicitly) for this resource."
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"array of security scheme names or a single security scheme name"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "uriParameters",
							"type": {
								"base": {
									"typeName": "DataModel.TypeDeclaration",
									"nameSpace": "DataModel",
									"basicName": "TypeDeclaration",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"location",
										"DataModel.ModelLocation.URI"
									]
								},
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"locationKind",
										"DataModel.LocationKind.APISTRUCTURE"
									]
								},
								{
									"name": "MetaModel.setsContextValue",
									"arguments": [
										"fieldOrParam",
										true
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Detailed information about any URI parameters of this resource"
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"object whose property names are the URI parameter names and whose values describe the values"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [],
					"extends": [
						{
							"typeName": "Annotable",
							"nameSpace": "",
							"basicName": "Annotable",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				},
				{
					"name": "Resource",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "relativeUri",
							"type": {
								"typeName": "Sys.RelativeUriString",
								"nameSpace": "Sys",
								"basicName": "RelativeUriString",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"
							},
							"annotations": [
								{
									"name": "MetaModel.key",
									"arguments": []
								},
								{
									"name": "MetaModel.startFrom",
									"arguments": [
										"/"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"Relative URL of this resource from the parent resource"
									]
								},
								{
									"name": "MetaModel.hide",
									"arguments": []
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "displayName",
							"type": {
								"typeName": "string",
								"nameSpace": "",
								"basicName": "string",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"The displayName attribute specifies the resource display name. It is a friendly name used only for  display or documentation purposes. If displayName is not specified, it defaults to the element's key (the name of the property itself)."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "resources",
							"type": {
								"base": {
									"typeName": "Resource",
									"nameSpace": "",
									"basicName": "Resource",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.newInstanceName",
									"arguments": [
										"New Resource"
									]
								},
								{
									"name": "MetaModel.description",
									"arguments": [
										"A nested resource is identified as any property whose name begins with a slash (\"/\") and is therefore treated as a relative URI."
									]
								},
								{
									"name": "MetaModel.documentationTableLabel",
									"arguments": [
										"/&lt;relativeUri&gt;"
									]
								},
								{
									"name": "MetaModel.valueDescription",
									"arguments": [
										"object describing the nested resource"
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [],
					"extends": [
						{
							"typeName": "ResourceBase",
							"nameSpace": "",
							"basicName": "ResourceBase",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {
						"description": [
							{
								"name": "MetaModel.description",
								"arguments": [
									"A longer, human-friendly description of the resource."
								]
							},
							{
								"name": "MetaModel.valueDescription",
								"arguments": [
									"Markdown string"
								]
							}
						],
						"annotations": [
							{
								"name": "MetaModel.markdownDescription",
								"arguments": [
									"Annotations to be applied to this resource. Annotations are any property whose key begins with \"(\" and ends with \")\" and whose name (the part between the beginning and ending parentheses) is a declared annotation name."
								]
							}
						]
					}
				}
			],
			"aliases": [],
			"enumDeclarations": [],
			"imports": {
				"MetaModel": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",
				"Sys": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts",
				"DataModel": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts",
				"Security": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/security.ts",
				"Methods": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/methods.ts"
			},
			"name": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/resources.ts"
		},
		{
			"classes": [
				{
					"name": "FileTypeDeclaration",
					"methods": [],
					"typeParameters": [],
					"typeParameterConstraint": [],
					"implements": [],
					"fields": [
						{
							"name": "type",
							"type": null,
							"annotations": [],
							"valueConstraint": {
								"isCallConstraint": false,
								"value": "file"
							},
							"optional": false
						},
						{
							"name": "fileTypes",
							"type": {
								"base": {
									"typeName": "Sys.ContentType",
									"nameSpace": "Sys",
									"basicName": "ContentType",
									"typeKind": 0,
									"typeArguments": [],
									"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/parameters.ts"
								},
								"typeKind": 1
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"It should also include a new property: fileTypes, which should be a list of valid content-type strings for the file. The file type */* should be a valid value."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "minLength",
							"type": {
								"typeName": "number",
								"nameSpace": "",
								"basicName": "number",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"The minLength attribute specifies the parameter value's minimum number of bytes."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						},
						{
							"name": "maxLength",
							"type": {
								"typeName": "number",
								"nameSpace": "",
								"basicName": "number",
								"typeKind": 0,
								"typeArguments": [],
								"modulePath": null
							},
							"annotations": [
								{
									"name": "MetaModel.description",
									"arguments": [
										"The maxLength attribute specifies the parameter value's maximum number of bytes."
									]
								}
							],
							"valueConstraint": null,
							"optional": false
						}
					],
					"isInterface": false,
					"annotations": [
						{
							"name": "MetaModel.description",
							"arguments": [
								"(Applicable only to Form properties) Value is a file. Client generators SHOULD use this type to handle file uploads correctly."
							]
						}
					],
					"extends": [
						{
							"typeName": "TypeDeclaration",
							"nameSpace": "",
							"basicName": "TypeDeclaration",
							"typeKind": 0,
							"typeArguments": [],
							"modulePath": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/parameters.ts"
						}
					],
					"moduleName": null,
					"annotationOverridings": {}
				}
			],
			"aliases": [],
			"enumDeclarations": [],
			"imports": {
				"MetaModel": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/metamodel.ts",
				"Sys": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/systemTypes.ts",
				"DataModel": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/datamodel.ts"
			},
			"name": "/Users/munch/work/repositories_official/raml-definition-system/raml-definition/spec-1.0/parameters.ts"
		}
	];

/***/ },
/* 86 */
/***/ function(module, exports, __webpack_require__) {

	/**
	 * Created by kor on 08/05/15.
	 */
	"use strict";
	var ts = __webpack_require__(166);
	exports.tsm = __webpack_require__(128);
	exports.helperMethodExtractor = __webpack_require__(129);
	var fsUtil = __webpack_require__(130);
	var EnumDeclaration = (function () {
	    function EnumDeclaration() {
	    }
	    return EnumDeclaration;
	}());
	exports.EnumDeclaration = EnumDeclaration;
	(function (TypeKind) {
	    TypeKind[TypeKind["BASIC"] = 0] = "BASIC";
	    TypeKind[TypeKind["ARRAY"] = 1] = "ARRAY";
	    TypeKind[TypeKind["UNION"] = 2] = "UNION";
	})(exports.TypeKind || (exports.TypeKind = {}));
	var TypeKind = exports.TypeKind;
	function parse(content) {
	    return ts.createSourceFile("sample.ts", content, ts.ScriptTarget.ES3, true);
	}
	var fld = exports.tsm.Matching.field();
	function classDecl(name, isInteface) {
	    return {
	        name: name,
	        methods: [],
	        typeParameters: [],
	        typeParameterConstraint: [],
	        implements: [],
	        fields: [],
	        isInterface: isInteface,
	        annotations: [],
	        extends: [],
	        moduleName: null,
	        annotationOverridings: {}
	    };
	}
	exports.classDecl = classDecl;
	function parseStruct(content, modules, mpth) {
	    var mod = parse(content);
	    var module = { classes: [], aliases: [], enumDeclarations: [], imports: {}, name: mpth };
	    modules[mpth] = module;
	    var currentModule = null;
	    exports.tsm.Matching.visit(mod, function (x) {
	        if (x.kind == ts.SyntaxKind.ModuleDeclaration) {
	            var cmod = x;
	            currentModule = cmod.name.text;
	        }
	        if (x.kind == ts.SyntaxKind.ImportEqualsDeclaration) {
	            var imp = x;
	            var namespace = imp.name.text;
	            if (namespace == "RamlWrapper") {
	                return;
	            }
	            var path = imp.moduleReference;
	            var literal = path.expression;
	            var importPath = literal.text;
	            var absPath = fsUtil.resolve(fsUtil.dirname(mpth) + "/", importPath) + ".ts";
	            if (!fsUtil.existsSync(absPath)) {
	                throw new Error("Path " + importPath + " resolve to " + absPath + "do not exists");
	            }
	            if (!modules[absPath]) {
	                var cnt = fsUtil.readFileSync(absPath);
	                var mod = parseStruct(cnt, modules, absPath);
	            }
	            module.imports[namespace] = modules[absPath];
	        }
	        if (x.kind == ts.SyntaxKind.TypeAliasDeclaration) {
	            var u = x;
	            if (u.name) {
	                var aliasName = u.name.text;
	                var type = buildType(u.type, mpth);
	                module.aliases.push({ name: aliasName, type: type });
	            }
	        }
	        if (x.kind == ts.SyntaxKind.EnumDeclaration) {
	            var e = x;
	            var members = [];
	            if (e.members) {
	                e.members.forEach(function (y) {
	                    members.push(y['name']['text']);
	                });
	            }
	            if (e.name) {
	                module.enumDeclarations.push({ name: e.name.text, members: members });
	            }
	        }
	        var isInterface = x.kind == ts.SyntaxKind.InterfaceDeclaration;
	        var isClass = x.kind == ts.SyntaxKind.ClassDeclaration;
	        if (!isInterface && !isClass) {
	            return;
	        }
	        var c = x;
	        if (c) {
	            var fields = {};
	            var clazz = classDecl(c.name.text, isInterface);
	            clazz.moduleName = currentModule;
	            module.classes.push(clazz);
	            c.members.forEach(function (x) {
	                if (x.kind == ts.SyntaxKind.MethodDeclaration) {
	                    var md = x;
	                    var method = buildMethod(md, content, mpth);
	                    clazz.methods.push(method);
	                }
	                var field = fld.doMatch(x);
	                if (field) {
	                    var f = buildField(field, mpth);
	                    if (f.name == '$') {
	                        clazz.annotations = f.annotations;
	                    }
	                    else if (f.name.charAt(0) != '$' || f.name == '$ref') {
	                        fields[f.name] = f;
	                        clazz.fields.push(f);
	                    }
	                    else {
	                        var targetField = f.name.substr(1);
	                        var of = fields[targetField];
	                        if (!of) {
	                            if (f.name != '$$') {
	                                //console.log('Overriding annotations for field:'+targetField);
	                                var overridings = clazz.annotationOverridings[targetField];
	                                if (!overridings) {
	                                    overridings = [];
	                                }
	                                clazz.annotationOverridings[targetField] = overridings.concat(f.annotations);
	                            }
	                        }
	                        else {
	                            of.annotations = f.annotations;
	                        }
	                    }
	                }
	            });
	            if (c.typeParameters) {
	                c.typeParameters.forEach(function (x) {
	                    clazz.typeParameters.push(x.name['text']);
	                    if (x.constraint == null) {
	                        clazz.typeParameterConstraint.push(null);
	                    }
	                    else {
	                        clazz.typeParameterConstraint.push(x.constraint['typeName']['text']);
	                    }
	                });
	            }
	            if (c.heritageClauses) {
	                c.heritageClauses.forEach(function (x) {
	                    x.types.forEach(function (y) {
	                        if (x.token == ts.SyntaxKind.ExtendsKeyword) {
	                            clazz.extends.push(buildType(y, mpth));
	                        }
	                        else if (x.token == ts.SyntaxKind.ImplementsKeyword) {
	                            clazz.implements.push(buildType(y, mpth));
	                        }
	                        else {
	                            throw new Error("Unknown token class heritage");
	                        }
	                    });
	                });
	            }
	            return exports.tsm.Matching.SKIP;
	        }
	    });
	    return module;
	}
	exports.parseStruct = parseStruct;
	function buildField(f, path) {
	    return {
	        name: f.name['text'],
	        type: buildType(f.type, path),
	        annotations: f.name['text'].charAt(0) == '$' ? buildInitializer(f.initializer) : [],
	        valueConstraint: f.name['text'].charAt(0) != '$' ? buildConstraint(f.initializer) : null,
	        optional: f.questionToken != null
	    };
	}
	function buildMethod(md, content, path) {
	    var aliasName = md.name.text;
	    var text = content.substring(md.pos, md.end);
	    var params = [];
	    md.parameters.forEach(function (x) {
	        params.push(buildParameter(x, content, path));
	    });
	    var method = {
	        returnType: buildType(md.type, path),
	        name: aliasName,
	        start: md.pos,
	        end: md.end,
	        text: text,
	        arguments: params
	    };
	    return method;
	}
	;
	function buildParameter(f, content, path) {
	    var text = content.substring(f.pos, f.end);
	    return {
	        name: f.name['text'],
	        start: f.pos,
	        end: f.end,
	        text: text,
	        type: buildType(f.type, path)
	    };
	}
	function buildConstraint(e) {
	    if (e == null) {
	        return null;
	    }
	    if (e.kind == ts.SyntaxKind.CallExpression) {
	        return {
	            isCallConstraint: true,
	            value: buildAnnotation(e)
	        };
	    }
	    else {
	        return {
	            isCallConstraint: false,
	            value: parseArg(e)
	        };
	    }
	}
	function buildInitializer(i) {
	    if (i == null) {
	        return [];
	    }
	    if (i.kind == ts.SyntaxKind.ArrayLiteralExpression) {
	        var arr = i;
	        var annotations = [];
	        arr.elements.forEach(function (x) {
	            annotations.push(buildAnnotation(x));
	        });
	        return annotations;
	    }
	    else {
	        throw new Error("Only Array Literals supported now");
	    }
	}
	function buildAnnotation(e) {
	    if (e.kind == ts.SyntaxKind.CallExpression) {
	        var call = e;
	        var name = parseName(call.expression);
	        var a = {
	            name: name,
	            arguments: []
	        };
	        call.arguments.forEach(function (x) {
	            a.arguments.push(parseArg(x));
	        });
	        return a;
	    }
	    else {
	        throw new Error("Only call expressions may be annotations");
	    }
	}
	function parseArg(n) {
	    if (n.kind == ts.SyntaxKind.StringLiteral) {
	        var l = n;
	        return l.text;
	    }
	    if (n.kind == ts.SyntaxKind.NoSubstitutionTemplateLiteral) {
	        var ls = n;
	        return ls.text;
	    }
	    if (n.kind == ts.SyntaxKind.ArrayLiteralExpression) {
	        var arr = n;
	        var annotations = [];
	        arr.elements.forEach(function (x) {
	            annotations.push(parseArg(x));
	        });
	        return annotations;
	    }
	    if (n.kind == ts.SyntaxKind.TrueKeyword) {
	        return true;
	    }
	    if (n.kind == ts.SyntaxKind.PropertyAccessExpression) {
	        var pa = n;
	        return parseArg(pa.expression) + "." + parseArg(pa.name);
	    }
	    if (n.kind == ts.SyntaxKind.Identifier) {
	        var ident = n;
	        return ident.text;
	    }
	    if (n.kind == ts.SyntaxKind.FalseKeyword) {
	        return false;
	    }
	    if (n.kind == ts.SyntaxKind.NumericLiteral) {
	        var nl = n;
	        return Number(nl.text);
	    }
	    if (n.kind == ts.SyntaxKind.BinaryExpression) {
	        var bin = n;
	        if (bin.operatorToken.kind = ts.SyntaxKind.PlusToken) {
	            return parseArg(bin.left) + parseArg(bin.right);
	        }
	    }
	    throw new Error("Unknown value in annotation");
	}
	function parseName(n) {
	    if (n.kind == ts.SyntaxKind.Identifier) {
	        return n['text'];
	    }
	    if (n.kind == ts.SyntaxKind.PropertyAccessExpression) {
	        var m = n;
	        return parseName(m.expression) + "." + parseName(m.name);
	    }
	    throw new Error("Only simple identifiers are supported now");
	}
	function basicType(n, path) {
	    var namespaceIndex = n.indexOf(".");
	    var namespace = namespaceIndex != -1 ? n.substring(0, namespaceIndex) : "";
	    var basicName = namespaceIndex != -1 ? n.substring(namespaceIndex + 1) : n;
	    return { typeName: n, nameSpace: namespace, basicName: basicName, typeKind: TypeKind.BASIC, typeArguments: [], modulePath: path };
	}
	function arrayType(b) {
	    return { base: b, typeKind: TypeKind.ARRAY };
	}
	function unionType(b) {
	    return { options: b, typeKind: TypeKind.UNION };
	}
	function buildType(t, path) {
	    if (t == null) {
	        return null;
	    }
	    if (t.kind == ts.SyntaxKind.StringKeyword) {
	        return basicType("string", null);
	    }
	    if (t.kind == ts.SyntaxKind.NumberKeyword) {
	        return basicType("number", null);
	    }
	    if (t.kind == ts.SyntaxKind.BooleanKeyword) {
	        return basicType("boolean", null);
	    }
	    if (t.kind == ts.SyntaxKind.AnyKeyword) {
	        return basicType("any", null);
	    }
	    if (t.kind == ts.SyntaxKind.TypeReference) {
	        var tr = t;
	        var res = basicType(parseQualified(tr.typeName), path);
	        if (tr.typeArguments) {
	            tr.typeArguments.forEach(function (x) {
	                res.typeArguments.push(buildType(x, path));
	            });
	        }
	        return res;
	    }
	    if (t.kind == ts.SyntaxKind.ArrayType) {
	        var q = t;
	        return arrayType(buildType(q.elementType, path));
	    }
	    if (t.kind == ts.SyntaxKind.UnionType) {
	        var ut = t;
	        return unionType(ut.types.map(function (x) { return buildType(x, path); }));
	    }
	    if (t.kind == ts.SyntaxKind.ExpressionWithTypeArguments) {
	        var tra = t;
	        var res = basicType(parseQualified2(tra.expression), path);
	        if (tra.typeArguments) {
	            tra.typeArguments.forEach(function (x) {
	                res.typeArguments.push(buildType(x, path));
	            });
	        }
	        return res;
	    }
	    throw new Error("Case not supported" + t.kind);
	}
	exports.buildType = buildType;
	function parseQualified2(n) {
	    if (!n.name) {
	        return n.text;
	    }
	    return n.name.text;
	}
	function parseQualified(n) {
	    if (n.kind == ts.SyntaxKind.Identifier) {
	        return n['text'];
	    }
	    else {
	        var q = n;
	        return parseQualified(q.left) + "." + parseQualified(q.right);
	    }
	}
	//# sourceMappingURL=tsStructureParser.js.map

/***/ },
/* 87 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(Buffer, global) {/*!
	 * The buffer module from node.js, for the browser.
	 *
	 * @author   Feross Aboukhadijeh <feross@feross.org> <http://feross.org>
	 * @license  MIT
	 */
	/* eslint-disable no-proto */

	'use strict'

	var base64 = __webpack_require__(170)
	var ieee754 = __webpack_require__(163)
	var isArray = __webpack_require__(164)

	exports.Buffer = Buffer
	exports.SlowBuffer = SlowBuffer
	exports.INSPECT_MAX_BYTES = 50
	Buffer.poolSize = 8192 // not used by this implementation

	var rootParent = {}

	/**
	 * If `Buffer.TYPED_ARRAY_SUPPORT`:
	 *   === true    Use Uint8Array implementation (fastest)
	 *   === false   Use Object implementation (most compatible, even IE6)
	 *
	 * Browsers that support typed arrays are IE 10+, Firefox 4+, Chrome 7+, Safari 5.1+,
	 * Opera 11.6+, iOS 4.2+.
	 *
	 * Due to various browser bugs, sometimes the Object implementation will be used even
	 * when the browser supports typed arrays.
	 *
	 * Note:
	 *
	 *   - Firefox 4-29 lacks support for adding new properties to `Uint8Array` instances,
	 *     See: https://bugzilla.mozilla.org/show_bug.cgi?id=695438.
	 *
	 *   - Safari 5-7 lacks support for changing the `Object.prototype.constructor` property
	 *     on objects.
	 *
	 *   - Chrome 9-10 is missing the `TypedArray.prototype.subarray` function.
	 *
	 *   - IE10 has a broken `TypedArray.prototype.subarray` function which returns arrays of
	 *     incorrect length in some situations.

	 * We detect these buggy browsers and set `Buffer.TYPED_ARRAY_SUPPORT` to `false` so they
	 * get the Object implementation, which is slower but behaves correctly.
	 */
	Buffer.TYPED_ARRAY_SUPPORT = global.TYPED_ARRAY_SUPPORT !== undefined
	  ? global.TYPED_ARRAY_SUPPORT
	  : typedArraySupport()

	function typedArraySupport () {
	  function Bar () {}
	  try {
	    var arr = new Uint8Array(1)
	    arr.foo = function () { return 42 }
	    arr.constructor = Bar
	    return arr.foo() === 42 && // typed array instances can be augmented
	        arr.constructor === Bar && // constructor can be set
	        typeof arr.subarray === 'function' && // chrome 9-10 lack `subarray`
	        arr.subarray(1, 1).byteLength === 0 // ie10 has broken `subarray`
	  } catch (e) {
	    return false
	  }
	}

	function kMaxLength () {
	  return Buffer.TYPED_ARRAY_SUPPORT
	    ? 0x7fffffff
	    : 0x3fffffff
	}

	/**
	 * Class: Buffer
	 * =============
	 *
	 * The Buffer constructor returns instances of `Uint8Array` that are augmented
	 * with function properties for all the node `Buffer` API functions. We use
	 * `Uint8Array` so that square bracket notation works as expected -- it returns
	 * a single octet.
	 *
	 * By augmenting the instances, we can avoid modifying the `Uint8Array`
	 * prototype.
	 */
	function Buffer (arg) {
	  if (!(this instanceof Buffer)) {
	    // Avoid going through an ArgumentsAdaptorTrampoline in the common case.
	    if (arguments.length > 1) return new Buffer(arg, arguments[1])
	    return new Buffer(arg)
	  }

	  if (!Buffer.TYPED_ARRAY_SUPPORT) {
	    this.length = 0
	    this.parent = undefined
	  }

	  // Common case.
	  if (typeof arg === 'number') {
	    return fromNumber(this, arg)
	  }

	  // Slightly less common case.
	  if (typeof arg === 'string') {
	    return fromString(this, arg, arguments.length > 1 ? arguments[1] : 'utf8')
	  }

	  // Unusual.
	  return fromObject(this, arg)
	}

	function fromNumber (that, length) {
	  that = allocate(that, length < 0 ? 0 : checked(length) | 0)
	  if (!Buffer.TYPED_ARRAY_SUPPORT) {
	    for (var i = 0; i < length; i++) {
	      that[i] = 0
	    }
	  }
	  return that
	}

	function fromString (that, string, encoding) {
	  if (typeof encoding !== 'string' || encoding === '') encoding = 'utf8'

	  // Assumption: byteLength() return value is always < kMaxLength.
	  var length = byteLength(string, encoding) | 0
	  that = allocate(that, length)

	  that.write(string, encoding)
	  return that
	}

	function fromObject (that, object) {
	  if (Buffer.isBuffer(object)) return fromBuffer(that, object)

	  if (isArray(object)) return fromArray(that, object)

	  if (object == null) {
	    throw new TypeError('must start with number, buffer, array or string')
	  }

	  if (typeof ArrayBuffer !== 'undefined') {
	    if (object.buffer instanceof ArrayBuffer) {
	      return fromTypedArray(that, object)
	    }
	    if (object instanceof ArrayBuffer) {
	      return fromArrayBuffer(that, object)
	    }
	  }

	  if (object.length) return fromArrayLike(that, object)

	  return fromJsonObject(that, object)
	}

	function fromBuffer (that, buffer) {
	  var length = checked(buffer.length) | 0
	  that = allocate(that, length)
	  buffer.copy(that, 0, 0, length)
	  return that
	}

	function fromArray (that, array) {
	  var length = checked(array.length) | 0
	  that = allocate(that, length)
	  for (var i = 0; i < length; i += 1) {
	    that[i] = array[i] & 255
	  }
	  return that
	}

	// Duplicate of fromArray() to keep fromArray() monomorphic.
	function fromTypedArray (that, array) {
	  var length = checked(array.length) | 0
	  that = allocate(that, length)
	  // Truncating the elements is probably not what people expect from typed
	  // arrays with BYTES_PER_ELEMENT > 1 but it's compatible with the behavior
	  // of the old Buffer constructor.
	  for (var i = 0; i < length; i += 1) {
	    that[i] = array[i] & 255
	  }
	  return that
	}

	function fromArrayBuffer (that, array) {
	  if (Buffer.TYPED_ARRAY_SUPPORT) {
	    // Return an augmented `Uint8Array` instance, for best performance
	    array.byteLength
	    that = Buffer._augment(new Uint8Array(array))
	  } else {
	    // Fallback: Return an object instance of the Buffer class
	    that = fromTypedArray(that, new Uint8Array(array))
	  }
	  return that
	}

	function fromArrayLike (that, array) {
	  var length = checked(array.length) | 0
	  that = allocate(that, length)
	  for (var i = 0; i < length; i += 1) {
	    that[i] = array[i] & 255
	  }
	  return that
	}

	// Deserialize { type: 'Buffer', data: [1,2,3,...] } into a Buffer object.
	// Returns a zero-length buffer for inputs that don't conform to the spec.
	function fromJsonObject (that, object) {
	  var array
	  var length = 0

	  if (object.type === 'Buffer' && isArray(object.data)) {
	    array = object.data
	    length = checked(array.length) | 0
	  }
	  that = allocate(that, length)

	  for (var i = 0; i < length; i += 1) {
	    that[i] = array[i] & 255
	  }
	  return that
	}

	if (Buffer.TYPED_ARRAY_SUPPORT) {
	  Buffer.prototype.__proto__ = Uint8Array.prototype
	  Buffer.__proto__ = Uint8Array
	} else {
	  // pre-set for values that may exist in the future
	  Buffer.prototype.length = undefined
	  Buffer.prototype.parent = undefined
	}

	function allocate (that, length) {
	  if (Buffer.TYPED_ARRAY_SUPPORT) {
	    // Return an augmented `Uint8Array` instance, for best performance
	    that = Buffer._augment(new Uint8Array(length))
	    that.__proto__ = Buffer.prototype
	  } else {
	    // Fallback: Return an object instance of the Buffer class
	    that.length = length
	    that._isBuffer = true
	  }

	  var fromPool = length !== 0 && length <= Buffer.poolSize >>> 1
	  if (fromPool) that.parent = rootParent

	  return that
	}

	function checked (length) {
	  // Note: cannot use `length < kMaxLength` here because that fails when
	  // length is NaN (which is otherwise coerced to zero.)
	  if (length >= kMaxLength()) {
	    throw new RangeError('Attempt to allocate Buffer larger than maximum ' +
	                         'size: 0x' + kMaxLength().toString(16) + ' bytes')
	  }
	  return length | 0
	}

	function SlowBuffer (subject, encoding) {
	  if (!(this instanceof SlowBuffer)) return new SlowBuffer(subject, encoding)

	  var buf = new Buffer(subject, encoding)
	  delete buf.parent
	  return buf
	}

	Buffer.isBuffer = function isBuffer (b) {
	  return !!(b != null && b._isBuffer)
	}

	Buffer.compare = function compare (a, b) {
	  if (!Buffer.isBuffer(a) || !Buffer.isBuffer(b)) {
	    throw new TypeError('Arguments must be Buffers')
	  }

	  if (a === b) return 0

	  var x = a.length
	  var y = b.length

	  var i = 0
	  var len = Math.min(x, y)
	  while (i < len) {
	    if (a[i] !== b[i]) break

	    ++i
	  }

	  if (i !== len) {
	    x = a[i]
	    y = b[i]
	  }

	  if (x < y) return -1
	  if (y < x) return 1
	  return 0
	}

	Buffer.isEncoding = function isEncoding (encoding) {
	  switch (String(encoding).toLowerCase()) {
	    case 'hex':
	    case 'utf8':
	    case 'utf-8':
	    case 'ascii':
	    case 'binary':
	    case 'base64':
	    case 'raw':
	    case 'ucs2':
	    case 'ucs-2':
	    case 'utf16le':
	    case 'utf-16le':
	      return true
	    default:
	      return false
	  }
	}

	Buffer.concat = function concat (list, length) {
	  if (!isArray(list)) throw new TypeError('list argument must be an Array of Buffers.')

	  if (list.length === 0) {
	    return new Buffer(0)
	  }

	  var i
	  if (length === undefined) {
	    length = 0
	    for (i = 0; i < list.length; i++) {
	      length += list[i].length
	    }
	  }

	  var buf = new Buffer(length)
	  var pos = 0
	  for (i = 0; i < list.length; i++) {
	    var item = list[i]
	    item.copy(buf, pos)
	    pos += item.length
	  }
	  return buf
	}

	function byteLength (string, encoding) {
	  if (typeof string !== 'string') string = '' + string

	  var len = string.length
	  if (len === 0) return 0

	  // Use a for loop to avoid recursion
	  var loweredCase = false
	  for (;;) {
	    switch (encoding) {
	      case 'ascii':
	      case 'binary':
	      // Deprecated
	      case 'raw':
	      case 'raws':
	        return len
	      case 'utf8':
	      case 'utf-8':
	        return utf8ToBytes(string).length
	      case 'ucs2':
	      case 'ucs-2':
	      case 'utf16le':
	      case 'utf-16le':
	        return len * 2
	      case 'hex':
	        return len >>> 1
	      case 'base64':
	        return base64ToBytes(string).length
	      default:
	        if (loweredCase) return utf8ToBytes(string).length // assume utf8
	        encoding = ('' + encoding).toLowerCase()
	        loweredCase = true
	    }
	  }
	}
	Buffer.byteLength = byteLength

	function slowToString (encoding, start, end) {
	  var loweredCase = false

	  start = start | 0
	  end = end === undefined || end === Infinity ? this.length : end | 0

	  if (!encoding) encoding = 'utf8'
	  if (start < 0) start = 0
	  if (end > this.length) end = this.length
	  if (end <= start) return ''

	  while (true) {
	    switch (encoding) {
	      case 'hex':
	        return hexSlice(this, start, end)

	      case 'utf8':
	      case 'utf-8':
	        return utf8Slice(this, start, end)

	      case 'ascii':
	        return asciiSlice(this, start, end)

	      case 'binary':
	        return binarySlice(this, start, end)

	      case 'base64':
	        return base64Slice(this, start, end)

	      case 'ucs2':
	      case 'ucs-2':
	      case 'utf16le':
	      case 'utf-16le':
	        return utf16leSlice(this, start, end)

	      default:
	        if (loweredCase) throw new TypeError('Unknown encoding: ' + encoding)
	        encoding = (encoding + '').toLowerCase()
	        loweredCase = true
	    }
	  }
	}

	Buffer.prototype.toString = function toString () {
	  var length = this.length | 0
	  if (length === 0) return ''
	  if (arguments.length === 0) return utf8Slice(this, 0, length)
	  return slowToString.apply(this, arguments)
	}

	Buffer.prototype.equals = function equals (b) {
	  if (!Buffer.isBuffer(b)) throw new TypeError('Argument must be a Buffer')
	  if (this === b) return true
	  return Buffer.compare(this, b) === 0
	}

	Buffer.prototype.inspect = function inspect () {
	  var str = ''
	  var max = exports.INSPECT_MAX_BYTES
	  if (this.length > 0) {
	    str = this.toString('hex', 0, max).match(/.{2}/g).join(' ')
	    if (this.length > max) str += ' ... '
	  }
	  return '<Buffer ' + str + '>'
	}

	Buffer.prototype.compare = function compare (b) {
	  if (!Buffer.isBuffer(b)) throw new TypeError('Argument must be a Buffer')
	  if (this === b) return 0
	  return Buffer.compare(this, b)
	}

	Buffer.prototype.indexOf = function indexOf (val, byteOffset) {
	  if (byteOffset > 0x7fffffff) byteOffset = 0x7fffffff
	  else if (byteOffset < -0x80000000) byteOffset = -0x80000000
	  byteOffset >>= 0

	  if (this.length === 0) return -1
	  if (byteOffset >= this.length) return -1

	  // Negative offsets start from the end of the buffer
	  if (byteOffset < 0) byteOffset = Math.max(this.length + byteOffset, 0)

	  if (typeof val === 'string') {
	    if (val.length === 0) return -1 // special case: looking for empty string always fails
	    return String.prototype.indexOf.call(this, val, byteOffset)
	  }
	  if (Buffer.isBuffer(val)) {
	    return arrayIndexOf(this, val, byteOffset)
	  }
	  if (typeof val === 'number') {
	    if (Buffer.TYPED_ARRAY_SUPPORT && Uint8Array.prototype.indexOf === 'function') {
	      return Uint8Array.prototype.indexOf.call(this, val, byteOffset)
	    }
	    return arrayIndexOf(this, [ val ], byteOffset)
	  }

	  function arrayIndexOf (arr, val, byteOffset) {
	    var foundIndex = -1
	    for (var i = 0; byteOffset + i < arr.length; i++) {
	      if (arr[byteOffset + i] === val[foundIndex === -1 ? 0 : i - foundIndex]) {
	        if (foundIndex === -1) foundIndex = i
	        if (i - foundIndex + 1 === val.length) return byteOffset + foundIndex
	      } else {
	        foundIndex = -1
	      }
	    }
	    return -1
	  }

	  throw new TypeError('val must be string, number or Buffer')
	}

	// `get` is deprecated
	Buffer.prototype.get = function get (offset) {
	  console.log('.get() is deprecated. Access using array indexes instead.')
	  return this.readUInt8(offset)
	}

	// `set` is deprecated
	Buffer.prototype.set = function set (v, offset) {
	  console.log('.set() is deprecated. Access using array indexes instead.')
	  return this.writeUInt8(v, offset)
	}

	function hexWrite (buf, string, offset, length) {
	  offset = Number(offset) || 0
	  var remaining = buf.length - offset
	  if (!length) {
	    length = remaining
	  } else {
	    length = Number(length)
	    if (length > remaining) {
	      length = remaining
	    }
	  }

	  // must be an even number of digits
	  var strLen = string.length
	  if (strLen % 2 !== 0) throw new Error('Invalid hex string')

	  if (length > strLen / 2) {
	    length = strLen / 2
	  }
	  for (var i = 0; i < length; i++) {
	    var parsed = parseInt(string.substr(i * 2, 2), 16)
	    if (isNaN(parsed)) throw new Error('Invalid hex string')
	    buf[offset + i] = parsed
	  }
	  return i
	}

	function utf8Write (buf, string, offset, length) {
	  return blitBuffer(utf8ToBytes(string, buf.length - offset), buf, offset, length)
	}

	function asciiWrite (buf, string, offset, length) {
	  return blitBuffer(asciiToBytes(string), buf, offset, length)
	}

	function binaryWrite (buf, string, offset, length) {
	  return asciiWrite(buf, string, offset, length)
	}

	function base64Write (buf, string, offset, length) {
	  return blitBuffer(base64ToBytes(string), buf, offset, length)
	}

	function ucs2Write (buf, string, offset, length) {
	  return blitBuffer(utf16leToBytes(string, buf.length - offset), buf, offset, length)
	}

	Buffer.prototype.write = function write (string, offset, length, encoding) {
	  // Buffer#write(string)
	  if (offset === undefined) {
	    encoding = 'utf8'
	    length = this.length
	    offset = 0
	  // Buffer#write(string, encoding)
	  } else if (length === undefined && typeof offset === 'string') {
	    encoding = offset
	    length = this.length
	    offset = 0
	  // Buffer#write(string, offset[, length][, encoding])
	  } else if (isFinite(offset)) {
	    offset = offset | 0
	    if (isFinite(length)) {
	      length = length | 0
	      if (encoding === undefined) encoding = 'utf8'
	    } else {
	      encoding = length
	      length = undefined
	    }
	  // legacy write(string, encoding, offset, length) - remove in v0.13
	  } else {
	    var swap = encoding
	    encoding = offset
	    offset = length | 0
	    length = swap
	  }

	  var remaining = this.length - offset
	  if (length === undefined || length > remaining) length = remaining

	  if ((string.length > 0 && (length < 0 || offset < 0)) || offset > this.length) {
	    throw new RangeError('attempt to write outside buffer bounds')
	  }

	  if (!encoding) encoding = 'utf8'

	  var loweredCase = false
	  for (;;) {
	    switch (encoding) {
	      case 'hex':
	        return hexWrite(this, string, offset, length)

	      case 'utf8':
	      case 'utf-8':
	        return utf8Write(this, string, offset, length)

	      case 'ascii':
	        return asciiWrite(this, string, offset, length)

	      case 'binary':
	        return binaryWrite(this, string, offset, length)

	      case 'base64':
	        // Warning: maxLength not taken into account in base64Write
	        return base64Write(this, string, offset, length)

	      case 'ucs2':
	      case 'ucs-2':
	      case 'utf16le':
	      case 'utf-16le':
	        return ucs2Write(this, string, offset, length)

	      default:
	        if (loweredCase) throw new TypeError('Unknown encoding: ' + encoding)
	        encoding = ('' + encoding).toLowerCase()
	        loweredCase = true
	    }
	  }
	}

	Buffer.prototype.toJSON = function toJSON () {
	  return {
	    type: 'Buffer',
	    data: Array.prototype.slice.call(this._arr || this, 0)
	  }
	}

	function base64Slice (buf, start, end) {
	  if (start === 0 && end === buf.length) {
	    return base64.fromByteArray(buf)
	  } else {
	    return base64.fromByteArray(buf.slice(start, end))
	  }
	}

	function utf8Slice (buf, start, end) {
	  end = Math.min(buf.length, end)
	  var res = []

	  var i = start
	  while (i < end) {
	    var firstByte = buf[i]
	    var codePoint = null
	    var bytesPerSequence = (firstByte > 0xEF) ? 4
	      : (firstByte > 0xDF) ? 3
	      : (firstByte > 0xBF) ? 2
	      : 1

	    if (i + bytesPerSequence <= end) {
	      var secondByte, thirdByte, fourthByte, tempCodePoint

	      switch (bytesPerSequence) {
	        case 1:
	          if (firstByte < 0x80) {
	            codePoint = firstByte
	          }
	          break
	        case 2:
	          secondByte = buf[i + 1]
	          if ((secondByte & 0xC0) === 0x80) {
	            tempCodePoint = (firstByte & 0x1F) << 0x6 | (secondByte & 0x3F)
	            if (tempCodePoint > 0x7F) {
	              codePoint = tempCodePoint
	            }
	          }
	          break
	        case 3:
	          secondByte = buf[i + 1]
	          thirdByte = buf[i + 2]
	          if ((secondByte & 0xC0) === 0x80 && (thirdByte & 0xC0) === 0x80) {
	            tempCodePoint = (firstByte & 0xF) << 0xC | (secondByte & 0x3F) << 0x6 | (thirdByte & 0x3F)
	            if (tempCodePoint > 0x7FF && (tempCodePoint < 0xD800 || tempCodePoint > 0xDFFF)) {
	              codePoint = tempCodePoint
	            }
	          }
	          break
	        case 4:
	          secondByte = buf[i + 1]
	          thirdByte = buf[i + 2]
	          fourthByte = buf[i + 3]
	          if ((secondByte & 0xC0) === 0x80 && (thirdByte & 0xC0) === 0x80 && (fourthByte & 0xC0) === 0x80) {
	            tempCodePoint = (firstByte & 0xF) << 0x12 | (secondByte & 0x3F) << 0xC | (thirdByte & 0x3F) << 0x6 | (fourthByte & 0x3F)
	            if (tempCodePoint > 0xFFFF && tempCodePoint < 0x110000) {
	              codePoint = tempCodePoint
	            }
	          }
	      }
	    }

	    if (codePoint === null) {
	      // we did not generate a valid codePoint so insert a
	      // replacement char (U+FFFD) and advance only 1 byte
	      codePoint = 0xFFFD
	      bytesPerSequence = 1
	    } else if (codePoint > 0xFFFF) {
	      // encode to utf16 (surrogate pair dance)
	      codePoint -= 0x10000
	      res.push(codePoint >>> 10 & 0x3FF | 0xD800)
	      codePoint = 0xDC00 | codePoint & 0x3FF
	    }

	    res.push(codePoint)
	    i += bytesPerSequence
	  }

	  return decodeCodePointsArray(res)
	}

	// Based on http://stackoverflow.com/a/22747272/680742, the browser with
	// the lowest limit is Chrome, with 0x10000 args.
	// We go 1 magnitude less, for safety
	var MAX_ARGUMENTS_LENGTH = 0x1000

	function decodeCodePointsArray (codePoints) {
	  var len = codePoints.length
	  if (len <= MAX_ARGUMENTS_LENGTH) {
	    return String.fromCharCode.apply(String, codePoints) // avoid extra slice()
	  }

	  // Decode in chunks to avoid "call stack size exceeded".
	  var res = ''
	  var i = 0
	  while (i < len) {
	    res += String.fromCharCode.apply(
	      String,
	      codePoints.slice(i, i += MAX_ARGUMENTS_LENGTH)
	    )
	  }
	  return res
	}

	function asciiSlice (buf, start, end) {
	  var ret = ''
	  end = Math.min(buf.length, end)

	  for (var i = start; i < end; i++) {
	    ret += String.fromCharCode(buf[i] & 0x7F)
	  }
	  return ret
	}

	function binarySlice (buf, start, end) {
	  var ret = ''
	  end = Math.min(buf.length, end)

	  for (var i = start; i < end; i++) {
	    ret += String.fromCharCode(buf[i])
	  }
	  return ret
	}

	function hexSlice (buf, start, end) {
	  var len = buf.length

	  if (!start || start < 0) start = 0
	  if (!end || end < 0 || end > len) end = len

	  var out = ''
	  for (var i = start; i < end; i++) {
	    out += toHex(buf[i])
	  }
	  return out
	}

	function utf16leSlice (buf, start, end) {
	  var bytes = buf.slice(start, end)
	  var res = ''
	  for (var i = 0; i < bytes.length; i += 2) {
	    res += String.fromCharCode(bytes[i] + bytes[i + 1] * 256)
	  }
	  return res
	}

	Buffer.prototype.slice = function slice (start, end) {
	  var len = this.length
	  start = ~~start
	  end = end === undefined ? len : ~~end

	  if (start < 0) {
	    start += len
	    if (start < 0) start = 0
	  } else if (start > len) {
	    start = len
	  }

	  if (end < 0) {
	    end += len
	    if (end < 0) end = 0
	  } else if (end > len) {
	    end = len
	  }

	  if (end < start) end = start

	  var newBuf
	  if (Buffer.TYPED_ARRAY_SUPPORT) {
	    newBuf = Buffer._augment(this.subarray(start, end))
	  } else {
	    var sliceLen = end - start
	    newBuf = new Buffer(sliceLen, undefined)
	    for (var i = 0; i < sliceLen; i++) {
	      newBuf[i] = this[i + start]
	    }
	  }

	  if (newBuf.length) newBuf.parent = this.parent || this

	  return newBuf
	}

	/*
	 * Need to make sure that buffer isn't trying to write out of bounds.
	 */
	function checkOffset (offset, ext, length) {
	  if ((offset % 1) !== 0 || offset < 0) throw new RangeError('offset is not uint')
	  if (offset + ext > length) throw new RangeError('Trying to access beyond buffer length')
	}

	Buffer.prototype.readUIntLE = function readUIntLE (offset, byteLength, noAssert) {
	  offset = offset | 0
	  byteLength = byteLength | 0
	  if (!noAssert) checkOffset(offset, byteLength, this.length)

	  var val = this[offset]
	  var mul = 1
	  var i = 0
	  while (++i < byteLength && (mul *= 0x100)) {
	    val += this[offset + i] * mul
	  }

	  return val
	}

	Buffer.prototype.readUIntBE = function readUIntBE (offset, byteLength, noAssert) {
	  offset = offset | 0
	  byteLength = byteLength | 0
	  if (!noAssert) {
	    checkOffset(offset, byteLength, this.length)
	  }

	  var val = this[offset + --byteLength]
	  var mul = 1
	  while (byteLength > 0 && (mul *= 0x100)) {
	    val += this[offset + --byteLength] * mul
	  }

	  return val
	}

	Buffer.prototype.readUInt8 = function readUInt8 (offset, noAssert) {
	  if (!noAssert) checkOffset(offset, 1, this.length)
	  return this[offset]
	}

	Buffer.prototype.readUInt16LE = function readUInt16LE (offset, noAssert) {
	  if (!noAssert) checkOffset(offset, 2, this.length)
	  return this[offset] | (this[offset + 1] << 8)
	}

	Buffer.prototype.readUInt16BE = function readUInt16BE (offset, noAssert) {
	  if (!noAssert) checkOffset(offset, 2, this.length)
	  return (this[offset] << 8) | this[offset + 1]
	}

	Buffer.prototype.readUInt32LE = function readUInt32LE (offset, noAssert) {
	  if (!noAssert) checkOffset(offset, 4, this.length)

	  return ((this[offset]) |
	      (this[offset + 1] << 8) |
	      (this[offset + 2] << 16)) +
	      (this[offset + 3] * 0x1000000)
	}

	Buffer.prototype.readUInt32BE = function readUInt32BE (offset, noAssert) {
	  if (!noAssert) checkOffset(offset, 4, this.length)

	  return (this[offset] * 0x1000000) +
	    ((this[offset + 1] << 16) |
	    (this[offset + 2] << 8) |
	    this[offset + 3])
	}

	Buffer.prototype.readIntLE = function readIntLE (offset, byteLength, noAssert) {
	  offset = offset | 0
	  byteLength = byteLength | 0
	  if (!noAssert) checkOffset(offset, byteLength, this.length)

	  var val = this[offset]
	  var mul = 1
	  var i = 0
	  while (++i < byteLength && (mul *= 0x100)) {
	    val += this[offset + i] * mul
	  }
	  mul *= 0x80

	  if (val >= mul) val -= Math.pow(2, 8 * byteLength)

	  return val
	}

	Buffer.prototype.readIntBE = function readIntBE (offset, byteLength, noAssert) {
	  offset = offset | 0
	  byteLength = byteLength | 0
	  if (!noAssert) checkOffset(offset, byteLength, this.length)

	  var i = byteLength
	  var mul = 1
	  var val = this[offset + --i]
	  while (i > 0 && (mul *= 0x100)) {
	    val += this[offset + --i] * mul
	  }
	  mul *= 0x80

	  if (val >= mul) val -= Math.pow(2, 8 * byteLength)

	  return val
	}

	Buffer.prototype.readInt8 = function readInt8 (offset, noAssert) {
	  if (!noAssert) checkOffset(offset, 1, this.length)
	  if (!(this[offset] & 0x80)) return (this[offset])
	  return ((0xff - this[offset] + 1) * -1)
	}

	Buffer.prototype.readInt16LE = function readInt16LE (offset, noAssert) {
	  if (!noAssert) checkOffset(offset, 2, this.length)
	  var val = this[offset] | (this[offset + 1] << 8)
	  return (val & 0x8000) ? val | 0xFFFF0000 : val
	}

	Buffer.prototype.readInt16BE = function readInt16BE (offset, noAssert) {
	  if (!noAssert) checkOffset(offset, 2, this.length)
	  var val = this[offset + 1] | (this[offset] << 8)
	  return (val & 0x8000) ? val | 0xFFFF0000 : val
	}

	Buffer.prototype.readInt32LE = function readInt32LE (offset, noAssert) {
	  if (!noAssert) checkOffset(offset, 4, this.length)

	  return (this[offset]) |
	    (this[offset + 1] << 8) |
	    (this[offset + 2] << 16) |
	    (this[offset + 3] << 24)
	}

	Buffer.prototype.readInt32BE = function readInt32BE (offset, noAssert) {
	  if (!noAssert) checkOffset(offset, 4, this.length)

	  return (this[offset] << 24) |
	    (this[offset + 1] << 16) |
	    (this[offset + 2] << 8) |
	    (this[offset + 3])
	}

	Buffer.prototype.readFloatLE = function readFloatLE (offset, noAssert) {
	  if (!noAssert) checkOffset(offset, 4, this.length)
	  return ieee754.read(this, offset, true, 23, 4)
	}

	Buffer.prototype.readFloatBE = function readFloatBE (offset, noAssert) {
	  if (!noAssert) checkOffset(offset, 4, this.length)
	  return ieee754.read(this, offset, false, 23, 4)
	}

	Buffer.prototype.readDoubleLE = function readDoubleLE (offset, noAssert) {
	  if (!noAssert) checkOffset(offset, 8, this.length)
	  return ieee754.read(this, offset, true, 52, 8)
	}

	Buffer.prototype.readDoubleBE = function readDoubleBE (offset, noAssert) {
	  if (!noAssert) checkOffset(offset, 8, this.length)
	  return ieee754.read(this, offset, false, 52, 8)
	}

	function checkInt (buf, value, offset, ext, max, min) {
	  if (!Buffer.isBuffer(buf)) throw new TypeError('buffer must be a Buffer instance')
	  if (value > max || value < min) throw new RangeError('value is out of bounds')
	  if (offset + ext > buf.length) throw new RangeError('index out of range')
	}

	Buffer.prototype.writeUIntLE = function writeUIntLE (value, offset, byteLength, noAssert) {
	  value = +value
	  offset = offset | 0
	  byteLength = byteLength | 0
	  if (!noAssert) checkInt(this, value, offset, byteLength, Math.pow(2, 8 * byteLength), 0)

	  var mul = 1
	  var i = 0
	  this[offset] = value & 0xFF
	  while (++i < byteLength && (mul *= 0x100)) {
	    this[offset + i] = (value / mul) & 0xFF
	  }

	  return offset + byteLength
	}

	Buffer.prototype.writeUIntBE = function writeUIntBE (value, offset, byteLength, noAssert) {
	  value = +value
	  offset = offset | 0
	  byteLength = byteLength | 0
	  if (!noAssert) checkInt(this, value, offset, byteLength, Math.pow(2, 8 * byteLength), 0)

	  var i = byteLength - 1
	  var mul = 1
	  this[offset + i] = value & 0xFF
	  while (--i >= 0 && (mul *= 0x100)) {
	    this[offset + i] = (value / mul) & 0xFF
	  }

	  return offset + byteLength
	}

	Buffer.prototype.writeUInt8 = function writeUInt8 (value, offset, noAssert) {
	  value = +value
	  offset = offset | 0
	  if (!noAssert) checkInt(this, value, offset, 1, 0xff, 0)
	  if (!Buffer.TYPED_ARRAY_SUPPORT) value = Math.floor(value)
	  this[offset] = (value & 0xff)
	  return offset + 1
	}

	function objectWriteUInt16 (buf, value, offset, littleEndian) {
	  if (value < 0) value = 0xffff + value + 1
	  for (var i = 0, j = Math.min(buf.length - offset, 2); i < j; i++) {
	    buf[offset + i] = (value & (0xff << (8 * (littleEndian ? i : 1 - i)))) >>>
	      (littleEndian ? i : 1 - i) * 8
	  }
	}

	Buffer.prototype.writeUInt16LE = function writeUInt16LE (value, offset, noAssert) {
	  value = +value
	  offset = offset | 0
	  if (!noAssert) checkInt(this, value, offset, 2, 0xffff, 0)
	  if (Buffer.TYPED_ARRAY_SUPPORT) {
	    this[offset] = (value & 0xff)
	    this[offset + 1] = (value >>> 8)
	  } else {
	    objectWriteUInt16(this, value, offset, true)
	  }
	  return offset + 2
	}

	Buffer.prototype.writeUInt16BE = function writeUInt16BE (value, offset, noAssert) {
	  value = +value
	  offset = offset | 0
	  if (!noAssert) checkInt(this, value, offset, 2, 0xffff, 0)
	  if (Buffer.TYPED_ARRAY_SUPPORT) {
	    this[offset] = (value >>> 8)
	    this[offset + 1] = (value & 0xff)
	  } else {
	    objectWriteUInt16(this, value, offset, false)
	  }
	  return offset + 2
	}

	function objectWriteUInt32 (buf, value, offset, littleEndian) {
	  if (value < 0) value = 0xffffffff + value + 1
	  for (var i = 0, j = Math.min(buf.length - offset, 4); i < j; i++) {
	    buf[offset + i] = (value >>> (littleEndian ? i : 3 - i) * 8) & 0xff
	  }
	}

	Buffer.prototype.writeUInt32LE = function writeUInt32LE (value, offset, noAssert) {
	  value = +value
	  offset = offset | 0
	  if (!noAssert) checkInt(this, value, offset, 4, 0xffffffff, 0)
	  if (Buffer.TYPED_ARRAY_SUPPORT) {
	    this[offset + 3] = (value >>> 24)
	    this[offset + 2] = (value >>> 16)
	    this[offset + 1] = (value >>> 8)
	    this[offset] = (value & 0xff)
	  } else {
	    objectWriteUInt32(this, value, offset, true)
	  }
	  return offset + 4
	}

	Buffer.prototype.writeUInt32BE = function writeUInt32BE (value, offset, noAssert) {
	  value = +value
	  offset = offset | 0
	  if (!noAssert) checkInt(this, value, offset, 4, 0xffffffff, 0)
	  if (Buffer.TYPED_ARRAY_SUPPORT) {
	    this[offset] = (value >>> 24)
	    this[offset + 1] = (value >>> 16)
	    this[offset + 2] = (value >>> 8)
	    this[offset + 3] = (value & 0xff)
	  } else {
	    objectWriteUInt32(this, value, offset, false)
	  }
	  return offset + 4
	}

	Buffer.prototype.writeIntLE = function writeIntLE (value, offset, byteLength, noAssert) {
	  value = +value
	  offset = offset | 0
	  if (!noAssert) {
	    var limit = Math.pow(2, 8 * byteLength - 1)

	    checkInt(this, value, offset, byteLength, limit - 1, -limit)
	  }

	  var i = 0
	  var mul = 1
	  var sub = value < 0 ? 1 : 0
	  this[offset] = value & 0xFF
	  while (++i < byteLength && (mul *= 0x100)) {
	    this[offset + i] = ((value / mul) >> 0) - sub & 0xFF
	  }

	  return offset + byteLength
	}

	Buffer.prototype.writeIntBE = function writeIntBE (value, offset, byteLength, noAssert) {
	  value = +value
	  offset = offset | 0
	  if (!noAssert) {
	    var limit = Math.pow(2, 8 * byteLength - 1)

	    checkInt(this, value, offset, byteLength, limit - 1, -limit)
	  }

	  var i = byteLength - 1
	  var mul = 1
	  var sub = value < 0 ? 1 : 0
	  this[offset + i] = value & 0xFF
	  while (--i >= 0 && (mul *= 0x100)) {
	    this[offset + i] = ((value / mul) >> 0) - sub & 0xFF
	  }

	  return offset + byteLength
	}

	Buffer.prototype.writeInt8 = function writeInt8 (value, offset, noAssert) {
	  value = +value
	  offset = offset | 0
	  if (!noAssert) checkInt(this, value, offset, 1, 0x7f, -0x80)
	  if (!Buffer.TYPED_ARRAY_SUPPORT) value = Math.floor(value)
	  if (value < 0) value = 0xff + value + 1
	  this[offset] = (value & 0xff)
	  return offset + 1
	}

	Buffer.prototype.writeInt16LE = function writeInt16LE (value, offset, noAssert) {
	  value = +value
	  offset = offset | 0
	  if (!noAssert) checkInt(this, value, offset, 2, 0x7fff, -0x8000)
	  if (Buffer.TYPED_ARRAY_SUPPORT) {
	    this[offset] = (value & 0xff)
	    this[offset + 1] = (value >>> 8)
	  } else {
	    objectWriteUInt16(this, value, offset, true)
	  }
	  return offset + 2
	}

	Buffer.prototype.writeInt16BE = function writeInt16BE (value, offset, noAssert) {
	  value = +value
	  offset = offset | 0
	  if (!noAssert) checkInt(this, value, offset, 2, 0x7fff, -0x8000)
	  if (Buffer.TYPED_ARRAY_SUPPORT) {
	    this[offset] = (value >>> 8)
	    this[offset + 1] = (value & 0xff)
	  } else {
	    objectWriteUInt16(this, value, offset, false)
	  }
	  return offset + 2
	}

	Buffer.prototype.writeInt32LE = function writeInt32LE (value, offset, noAssert) {
	  value = +value
	  offset = offset | 0
	  if (!noAssert) checkInt(this, value, offset, 4, 0x7fffffff, -0x80000000)
	  if (Buffer.TYPED_ARRAY_SUPPORT) {
	    this[offset] = (value & 0xff)
	    this[offset + 1] = (value >>> 8)
	    this[offset + 2] = (value >>> 16)
	    this[offset + 3] = (value >>> 24)
	  } else {
	    objectWriteUInt32(this, value, offset, true)
	  }
	  return offset + 4
	}

	Buffer.prototype.writeInt32BE = function writeInt32BE (value, offset, noAssert) {
	  value = +value
	  offset = offset | 0
	  if (!noAssert) checkInt(this, value, offset, 4, 0x7fffffff, -0x80000000)
	  if (value < 0) value = 0xffffffff + value + 1
	  if (Buffer.TYPED_ARRAY_SUPPORT) {
	    this[offset] = (value >>> 24)
	    this[offset + 1] = (value >>> 16)
	    this[offset + 2] = (value >>> 8)
	    this[offset + 3] = (value & 0xff)
	  } else {
	    objectWriteUInt32(this, value, offset, false)
	  }
	  return offset + 4
	}

	function checkIEEE754 (buf, value, offset, ext, max, min) {
	  if (value > max || value < min) throw new RangeError('value is out of bounds')
	  if (offset + ext > buf.length) throw new RangeError('index out of range')
	  if (offset < 0) throw new RangeError('index out of range')
	}

	function writeFloat (buf, value, offset, littleEndian, noAssert) {
	  if (!noAssert) {
	    checkIEEE754(buf, value, offset, 4, 3.4028234663852886e+38, -3.4028234663852886e+38)
	  }
	  ieee754.write(buf, value, offset, littleEndian, 23, 4)
	  return offset + 4
	}

	Buffer.prototype.writeFloatLE = function writeFloatLE (value, offset, noAssert) {
	  return writeFloat(this, value, offset, true, noAssert)
	}

	Buffer.prototype.writeFloatBE = function writeFloatBE (value, offset, noAssert) {
	  return writeFloat(this, value, offset, false, noAssert)
	}

	function writeDouble (buf, value, offset, littleEndian, noAssert) {
	  if (!noAssert) {
	    checkIEEE754(buf, value, offset, 8, 1.7976931348623157E+308, -1.7976931348623157E+308)
	  }
	  ieee754.write(buf, value, offset, littleEndian, 52, 8)
	  return offset + 8
	}

	Buffer.prototype.writeDoubleLE = function writeDoubleLE (value, offset, noAssert) {
	  return writeDouble(this, value, offset, true, noAssert)
	}

	Buffer.prototype.writeDoubleBE = function writeDoubleBE (value, offset, noAssert) {
	  return writeDouble(this, value, offset, false, noAssert)
	}

	// copy(targetBuffer, targetStart=0, sourceStart=0, sourceEnd=buffer.length)
	Buffer.prototype.copy = function copy (target, targetStart, start, end) {
	  if (!start) start = 0
	  if (!end && end !== 0) end = this.length
	  if (targetStart >= target.length) targetStart = target.length
	  if (!targetStart) targetStart = 0
	  if (end > 0 && end < start) end = start

	  // Copy 0 bytes; we're done
	  if (end === start) return 0
	  if (target.length === 0 || this.length === 0) return 0

	  // Fatal error conditions
	  if (targetStart < 0) {
	    throw new RangeError('targetStart out of bounds')
	  }
	  if (start < 0 || start >= this.length) throw new RangeError('sourceStart out of bounds')
	  if (end < 0) throw new RangeError('sourceEnd out of bounds')

	  // Are we oob?
	  if (end > this.length) end = this.length
	  if (target.length - targetStart < end - start) {
	    end = target.length - targetStart + start
	  }

	  var len = end - start
	  var i

	  if (this === target && start < targetStart && targetStart < end) {
	    // descending copy from end
	    for (i = len - 1; i >= 0; i--) {
	      target[i + targetStart] = this[i + start]
	    }
	  } else if (len < 1000 || !Buffer.TYPED_ARRAY_SUPPORT) {
	    // ascending copy from start
	    for (i = 0; i < len; i++) {
	      target[i + targetStart] = this[i + start]
	    }
	  } else {
	    target._set(this.subarray(start, start + len), targetStart)
	  }

	  return len
	}

	// fill(value, start=0, end=buffer.length)
	Buffer.prototype.fill = function fill (value, start, end) {
	  if (!value) value = 0
	  if (!start) start = 0
	  if (!end) end = this.length

	  if (end < start) throw new RangeError('end < start')

	  // Fill 0 bytes; we're done
	  if (end === start) return
	  if (this.length === 0) return

	  if (start < 0 || start >= this.length) throw new RangeError('start out of bounds')
	  if (end < 0 || end > this.length) throw new RangeError('end out of bounds')

	  var i
	  if (typeof value === 'number') {
	    for (i = start; i < end; i++) {
	      this[i] = value
	    }
	  } else {
	    var bytes = utf8ToBytes(value.toString())
	    var len = bytes.length
	    for (i = start; i < end; i++) {
	      this[i] = bytes[i % len]
	    }
	  }

	  return this
	}

	/**
	 * Creates a new `ArrayBuffer` with the *copied* memory of the buffer instance.
	 * Added in Node 0.12. Only available in browsers that support ArrayBuffer.
	 */
	Buffer.prototype.toArrayBuffer = function toArrayBuffer () {
	  if (typeof Uint8Array !== 'undefined') {
	    if (Buffer.TYPED_ARRAY_SUPPORT) {
	      return (new Buffer(this)).buffer
	    } else {
	      var buf = new Uint8Array(this.length)
	      for (var i = 0, len = buf.length; i < len; i += 1) {
	        buf[i] = this[i]
	      }
	      return buf.buffer
	    }
	  } else {
	    throw new TypeError('Buffer.toArrayBuffer not supported in this browser')
	  }
	}

	// HELPER FUNCTIONS
	// ================

	var BP = Buffer.prototype

	/**
	 * Augment a Uint8Array *instance* (not the Uint8Array class!) with Buffer methods
	 */
	Buffer._augment = function _augment (arr) {
	  arr.constructor = Buffer
	  arr._isBuffer = true

	  // save reference to original Uint8Array set method before overwriting
	  arr._set = arr.set

	  // deprecated
	  arr.get = BP.get
	  arr.set = BP.set

	  arr.write = BP.write
	  arr.toString = BP.toString
	  arr.toLocaleString = BP.toString
	  arr.toJSON = BP.toJSON
	  arr.equals = BP.equals
	  arr.compare = BP.compare
	  arr.indexOf = BP.indexOf
	  arr.copy = BP.copy
	  arr.slice = BP.slice
	  arr.readUIntLE = BP.readUIntLE
	  arr.readUIntBE = BP.readUIntBE
	  arr.readUInt8 = BP.readUInt8
	  arr.readUInt16LE = BP.readUInt16LE
	  arr.readUInt16BE = BP.readUInt16BE
	  arr.readUInt32LE = BP.readUInt32LE
	  arr.readUInt32BE = BP.readUInt32BE
	  arr.readIntLE = BP.readIntLE
	  arr.readIntBE = BP.readIntBE
	  arr.readInt8 = BP.readInt8
	  arr.readInt16LE = BP.readInt16LE
	  arr.readInt16BE = BP.readInt16BE
	  arr.readInt32LE = BP.readInt32LE
	  arr.readInt32BE = BP.readInt32BE
	  arr.readFloatLE = BP.readFloatLE
	  arr.readFloatBE = BP.readFloatBE
	  arr.readDoubleLE = BP.readDoubleLE
	  arr.readDoubleBE = BP.readDoubleBE
	  arr.writeUInt8 = BP.writeUInt8
	  arr.writeUIntLE = BP.writeUIntLE
	  arr.writeUIntBE = BP.writeUIntBE
	  arr.writeUInt16LE = BP.writeUInt16LE
	  arr.writeUInt16BE = BP.writeUInt16BE
	  arr.writeUInt32LE = BP.writeUInt32LE
	  arr.writeUInt32BE = BP.writeUInt32BE
	  arr.writeIntLE = BP.writeIntLE
	  arr.writeIntBE = BP.writeIntBE
	  arr.writeInt8 = BP.writeInt8
	  arr.writeInt16LE = BP.writeInt16LE
	  arr.writeInt16BE = BP.writeInt16BE
	  arr.writeInt32LE = BP.writeInt32LE
	  arr.writeInt32BE = BP.writeInt32BE
	  arr.writeFloatLE = BP.writeFloatLE
	  arr.writeFloatBE = BP.writeFloatBE
	  arr.writeDoubleLE = BP.writeDoubleLE
	  arr.writeDoubleBE = BP.writeDoubleBE
	  arr.fill = BP.fill
	  arr.inspect = BP.inspect
	  arr.toArrayBuffer = BP.toArrayBuffer

	  return arr
	}

	var INVALID_BASE64_RE = /[^+\/0-9A-Za-z-_]/g

	function base64clean (str) {
	  // Node strips out invalid characters like \n and \t from the string, base64-js does not
	  str = stringtrim(str).replace(INVALID_BASE64_RE, '')
	  // Node converts strings with length < 2 to ''
	  if (str.length < 2) return ''
	  // Node allows for non-padded base64 strings (missing trailing ===), base64-js does not
	  while (str.length % 4 !== 0) {
	    str = str + '='
	  }
	  return str
	}

	function stringtrim (str) {
	  if (str.trim) return str.trim()
	  return str.replace(/^\s+|\s+$/g, '')
	}

	function toHex (n) {
	  if (n < 16) return '0' + n.toString(16)
	  return n.toString(16)
	}

	function utf8ToBytes (string, units) {
	  units = units || Infinity
	  var codePoint
	  var length = string.length
	  var leadSurrogate = null
	  var bytes = []

	  for (var i = 0; i < length; i++) {
	    codePoint = string.charCodeAt(i)

	    // is surrogate component
	    if (codePoint > 0xD7FF && codePoint < 0xE000) {
	      // last char was a lead
	      if (!leadSurrogate) {
	        // no lead yet
	        if (codePoint > 0xDBFF) {
	          // unexpected trail
	          if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD)
	          continue
	        } else if (i + 1 === length) {
	          // unpaired lead
	          if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD)
	          continue
	        }

	        // valid lead
	        leadSurrogate = codePoint

	        continue
	      }

	      // 2 leads in a row
	      if (codePoint < 0xDC00) {
	        if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD)
	        leadSurrogate = codePoint
	        continue
	      }

	      // valid surrogate pair
	      codePoint = (leadSurrogate - 0xD800 << 10 | codePoint - 0xDC00) + 0x10000
	    } else if (leadSurrogate) {
	      // valid bmp char, but last char was a lead
	      if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD)
	    }

	    leadSurrogate = null

	    // encode utf8
	    if (codePoint < 0x80) {
	      if ((units -= 1) < 0) break
	      bytes.push(codePoint)
	    } else if (codePoint < 0x800) {
	      if ((units -= 2) < 0) break
	      bytes.push(
	        codePoint >> 0x6 | 0xC0,
	        codePoint & 0x3F | 0x80
	      )
	    } else if (codePoint < 0x10000) {
	      if ((units -= 3) < 0) break
	      bytes.push(
	        codePoint >> 0xC | 0xE0,
	        codePoint >> 0x6 & 0x3F | 0x80,
	        codePoint & 0x3F | 0x80
	      )
	    } else if (codePoint < 0x110000) {
	      if ((units -= 4) < 0) break
	      bytes.push(
	        codePoint >> 0x12 | 0xF0,
	        codePoint >> 0xC & 0x3F | 0x80,
	        codePoint >> 0x6 & 0x3F | 0x80,
	        codePoint & 0x3F | 0x80
	      )
	    } else {
	      throw new Error('Invalid code point')
	    }
	  }

	  return bytes
	}

	function asciiToBytes (str) {
	  var byteArray = []
	  for (var i = 0; i < str.length; i++) {
	    // Node's code seems to be doing this and not & 0x7F..
	    byteArray.push(str.charCodeAt(i) & 0xFF)
	  }
	  return byteArray
	}

	function utf16leToBytes (str, units) {
	  var c, hi, lo
	  var byteArray = []
	  for (var i = 0; i < str.length; i++) {
	    if ((units -= 2) < 0) break

	    c = str.charCodeAt(i)
	    hi = c >> 8
	    lo = c % 256
	    byteArray.push(lo)
	    byteArray.push(hi)
	  }

	  return byteArray
	}

	function base64ToBytes (str) {
	  return base64.toByteArray(base64clean(str))
	}

	function blitBuffer (src, dst, offset, length) {
	  for (var i = 0; i < length; i++) {
	    if ((i + offset >= dst.length) || (i >= src.length)) break
	    dst[i + offset] = src[i]
	  }
	  return i
	}
	
	/* WEBPACK VAR INJECTION */}.call(exports, __webpack_require__(87).Buffer, (function() { return this; }())))

/***/ },
/* 88 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	exports.decode = exports.parse = __webpack_require__(132);
	exports.encode = exports.stringify = __webpack_require__(133);


/***/ },
/* 89 */
/***/ function(module, exports, __webpack_require__) {

	var undefined = (void 0); // Paranoia

	// Beyond this value, index getters/setters (i.e. array[0], array[1]) are so slow to
	// create, and consume so much memory, that the browser appears frozen.
	var MAX_ARRAY_LENGTH = 1e5;

	// Approximations of internal ECMAScript conversion functions
	var ECMAScript = (function() {
	  // Stash a copy in case other scripts modify these
	  var opts = Object.prototype.toString,
	      ophop = Object.prototype.hasOwnProperty;

	  return {
	    // Class returns internal [[Class]] property, used to avoid cross-frame instanceof issues:
	    Class: function(v) { return opts.call(v).replace(/^\[object *|\]$/g, ''); },
	    HasProperty: function(o, p) { return p in o; },
	    HasOwnProperty: function(o, p) { return ophop.call(o, p); },
	    IsCallable: function(o) { return typeof o === 'function'; },
	    ToInt32: function(v) { return v >> 0; },
	    ToUint32: function(v) { return v >>> 0; }
	  };
	}());

	// Snapshot intrinsics
	var LN2 = Math.LN2,
	    abs = Math.abs,
	    floor = Math.floor,
	    log = Math.log,
	    min = Math.min,
	    pow = Math.pow,
	    round = Math.round;

	// ES5: lock down object properties
	function configureProperties(obj) {
	  if (getOwnPropNames && defineProp) {
	    var props = getOwnPropNames(obj), i;
	    for (i = 0; i < props.length; i += 1) {
	      defineProp(obj, props[i], {
	        value: obj[props[i]],
	        writable: false,
	        enumerable: false,
	        configurable: false
	      });
	    }
	  }
	}

	// emulate ES5 getter/setter API using legacy APIs
	// http://blogs.msdn.com/b/ie/archive/2010/09/07/transitioning-existing-code-to-the-es5-getter-setter-apis.aspx
	// (second clause tests for Object.defineProperty() in IE<9 that only supports extending DOM prototypes, but
	// note that IE<9 does not support __defineGetter__ or __defineSetter__ so it just renders the method harmless)
	var defineProp
	if (Object.defineProperty && (function() {
	      try {
	        Object.defineProperty({}, 'x', {});
	        return true;
	      } catch (e) {
	        return false;
	      }
	    })()) {
	  defineProp = Object.defineProperty;
	} else {
	  defineProp = function(o, p, desc) {
	    if (!o === Object(o)) throw new TypeError("Object.defineProperty called on non-object");
	    if (ECMAScript.HasProperty(desc, 'get') && Object.prototype.__defineGetter__) { Object.prototype.__defineGetter__.call(o, p, desc.get); }
	    if (ECMAScript.HasProperty(desc, 'set') && Object.prototype.__defineSetter__) { Object.prototype.__defineSetter__.call(o, p, desc.set); }
	    if (ECMAScript.HasProperty(desc, 'value')) { o[p] = desc.value; }
	    return o;
	  };
	}

	var getOwnPropNames = Object.getOwnPropertyNames || function (o) {
	  if (o !== Object(o)) throw new TypeError("Object.getOwnPropertyNames called on non-object");
	  var props = [], p;
	  for (p in o) {
	    if (ECMAScript.HasOwnProperty(o, p)) {
	      props.push(p);
	    }
	  }
	  return props;
	};

	// ES5: Make obj[index] an alias for obj._getter(index)/obj._setter(index, value)
	// for index in 0 ... obj.length
	function makeArrayAccessors(obj) {
	  if (!defineProp) { return; }

	  if (obj.length > MAX_ARRAY_LENGTH) throw new RangeError("Array too large for polyfill");

	  function makeArrayAccessor(index) {
	    defineProp(obj, index, {
	      'get': function() { return obj._getter(index); },
	      'set': function(v) { obj._setter(index, v); },
	      enumerable: true,
	      configurable: false
	    });
	  }

	  var i;
	  for (i = 0; i < obj.length; i += 1) {
	    makeArrayAccessor(i);
	  }
	}

	// Internal conversion functions:
	//    pack<Type>()   - take a number (interpreted as Type), output a byte array
	//    unpack<Type>() - take a byte array, output a Type-like number

	function as_signed(value, bits) { var s = 32 - bits; return (value << s) >> s; }
	function as_unsigned(value, bits) { var s = 32 - bits; return (value << s) >>> s; }

	function packI8(n) { return [n & 0xff]; }
	function unpackI8(bytes) { return as_signed(bytes[0], 8); }

	function packU8(n) { return [n & 0xff]; }
	function unpackU8(bytes) { return as_unsigned(bytes[0], 8); }

	function packU8Clamped(n) { n = round(Number(n)); return [n < 0 ? 0 : n > 0xff ? 0xff : n & 0xff]; }

	function packI16(n) { return [(n >> 8) & 0xff, n & 0xff]; }
	function unpackI16(bytes) { return as_signed(bytes[0] << 8 | bytes[1], 16); }

	function packU16(n) { return [(n >> 8) & 0xff, n & 0xff]; }
	function unpackU16(bytes) { return as_unsigned(bytes[0] << 8 | bytes[1], 16); }

	function packI32(n) { return [(n >> 24) & 0xff, (n >> 16) & 0xff, (n >> 8) & 0xff, n & 0xff]; }
	function unpackI32(bytes) { return as_signed(bytes[0] << 24 | bytes[1] << 16 | bytes[2] << 8 | bytes[3], 32); }

	function packU32(n) { return [(n >> 24) & 0xff, (n >> 16) & 0xff, (n >> 8) & 0xff, n & 0xff]; }
	function unpackU32(bytes) { return as_unsigned(bytes[0] << 24 | bytes[1] << 16 | bytes[2] << 8 | bytes[3], 32); }

	function packIEEE754(v, ebits, fbits) {

	  var bias = (1 << (ebits - 1)) - 1,
	      s, e, f, ln,
	      i, bits, str, bytes;

	  function roundToEven(n) {
	    var w = floor(n), f = n - w;
	    if (f < 0.5)
	      return w;
	    if (f > 0.5)
	      return w + 1;
	    return w % 2 ? w + 1 : w;
	  }

	  // Compute sign, exponent, fraction
	  if (v !== v) {
	    // NaN
	    // http://dev.w3.org/2006/webapi/WebIDL/#es-type-mapping
	    e = (1 << ebits) - 1; f = pow(2, fbits - 1); s = 0;
	  } else if (v === Infinity || v === -Infinity) {
	    e = (1 << ebits) - 1; f = 0; s = (v < 0) ? 1 : 0;
	  } else if (v === 0) {
	    e = 0; f = 0; s = (1 / v === -Infinity) ? 1 : 0;
	  } else {
	    s = v < 0;
	    v = abs(v);

	    if (v >= pow(2, 1 - bias)) {
	      e = min(floor(log(v) / LN2), 1023);
	      f = roundToEven(v / pow(2, e) * pow(2, fbits));
	      if (f / pow(2, fbits) >= 2) {
	        e = e + 1;
	        f = 1;
	      }
	      if (e > bias) {
	        // Overflow
	        e = (1 << ebits) - 1;
	        f = 0;
	      } else {
	        // Normalized
	        e = e + bias;
	        f = f - pow(2, fbits);
	      }
	    } else {
	      // Denormalized
	      e = 0;
	      f = roundToEven(v / pow(2, 1 - bias - fbits));
	    }
	  }

	  // Pack sign, exponent, fraction
	  bits = [];
	  for (i = fbits; i; i -= 1) { bits.push(f % 2 ? 1 : 0); f = floor(f / 2); }
	  for (i = ebits; i; i -= 1) { bits.push(e % 2 ? 1 : 0); e = floor(e / 2); }
	  bits.push(s ? 1 : 0);
	  bits.reverse();
	  str = bits.join('');

	  // Bits to bytes
	  bytes = [];
	  while (str.length) {
	    bytes.push(parseInt(str.substring(0, 8), 2));
	    str = str.substring(8);
	  }
	  return bytes;
	}

	function unpackIEEE754(bytes, ebits, fbits) {

	  // Bytes to bits
	  var bits = [], i, j, b, str,
	      bias, s, e, f;

	  for (i = bytes.length; i; i -= 1) {
	    b = bytes[i - 1];
	    for (j = 8; j; j -= 1) {
	      bits.push(b % 2 ? 1 : 0); b = b >> 1;
	    }
	  }
	  bits.reverse();
	  str = bits.join('');

	  // Unpack sign, exponent, fraction
	  bias = (1 << (ebits - 1)) - 1;
	  s = parseInt(str.substring(0, 1), 2) ? -1 : 1;
	  e = parseInt(str.substring(1, 1 + ebits), 2);
	  f = parseInt(str.substring(1 + ebits), 2);

	  // Produce number
	  if (e === (1 << ebits) - 1) {
	    return f !== 0 ? NaN : s * Infinity;
	  } else if (e > 0) {
	    // Normalized
	    return s * pow(2, e - bias) * (1 + f / pow(2, fbits));
	  } else if (f !== 0) {
	    // Denormalized
	    return s * pow(2, -(bias - 1)) * (f / pow(2, fbits));
	  } else {
	    return s < 0 ? -0 : 0;
	  }
	}

	function unpackF64(b) { return unpackIEEE754(b, 11, 52); }
	function packF64(v) { return packIEEE754(v, 11, 52); }
	function unpackF32(b) { return unpackIEEE754(b, 8, 23); }
	function packF32(v) { return packIEEE754(v, 8, 23); }


	//
	// 3 The ArrayBuffer Type
	//

	(function() {

	  /** @constructor */
	  var ArrayBuffer = function ArrayBuffer(length) {
	    length = ECMAScript.ToInt32(length);
	    if (length < 0) throw new RangeError('ArrayBuffer size is not a small enough positive integer');

	    this.byteLength = length;
	    this._bytes = [];
	    this._bytes.length = length;

	    var i;
	    for (i = 0; i < this.byteLength; i += 1) {
	      this._bytes[i] = 0;
	    }

	    configureProperties(this);
	  };

	  exports.ArrayBuffer = exports.ArrayBuffer || ArrayBuffer;

	  //
	  // 4 The ArrayBufferView Type
	  //

	  // NOTE: this constructor is not exported
	  /** @constructor */
	  var ArrayBufferView = function ArrayBufferView() {
	    //this.buffer = null;
	    //this.byteOffset = 0;
	    //this.byteLength = 0;
	  };

	  //
	  // 5 The Typed Array View Types
	  //

	  function makeConstructor(bytesPerElement, pack, unpack) {
	    // Each TypedArray type requires a distinct constructor instance with
	    // identical logic, which this produces.

	    var ctor;
	    ctor = function(buffer, byteOffset, length) {
	      var array, sequence, i, s;

	      if (!arguments.length || typeof arguments[0] === 'number') {
	        // Constructor(unsigned long length)
	        this.length = ECMAScript.ToInt32(arguments[0]);
	        if (length < 0) throw new RangeError('ArrayBufferView size is not a small enough positive integer');

	        this.byteLength = this.length * this.BYTES_PER_ELEMENT;
	        this.buffer = new ArrayBuffer(this.byteLength);
	        this.byteOffset = 0;
	      } else if (typeof arguments[0] === 'object' && arguments[0].constructor === ctor) {
	        // Constructor(TypedArray array)
	        array = arguments[0];

	        this.length = array.length;
	        this.byteLength = this.length * this.BYTES_PER_ELEMENT;
	        this.buffer = new ArrayBuffer(this.byteLength);
	        this.byteOffset = 0;

	        for (i = 0; i < this.length; i += 1) {
	          this._setter(i, array._getter(i));
	        }
	      } else if (typeof arguments[0] === 'object' &&
	                 !(arguments[0] instanceof ArrayBuffer || ECMAScript.Class(arguments[0]) === 'ArrayBuffer')) {
	        // Constructor(sequence<type> array)
	        sequence = arguments[0];

	        this.length = ECMAScript.ToUint32(sequence.length);
	        this.byteLength = this.length * this.BYTES_PER_ELEMENT;
	        this.buffer = new ArrayBuffer(this.byteLength);
	        this.byteOffset = 0;

	        for (i = 0; i < this.length; i += 1) {
	          s = sequence[i];
	          this._setter(i, Number(s));
	        }
	      } else if (typeof arguments[0] === 'object' &&
	                 (arguments[0] instanceof ArrayBuffer || ECMAScript.Class(arguments[0]) === 'ArrayBuffer')) {
	        // Constructor(ArrayBuffer buffer,
	        //             optional unsigned long byteOffset, optional unsigned long length)
	        this.buffer = buffer;

	        this.byteOffset = ECMAScript.ToUint32(byteOffset);
	        if (this.byteOffset > this.buffer.byteLength) {
	          throw new RangeError("byteOffset out of range");
	        }

	        if (this.byteOffset % this.BYTES_PER_ELEMENT) {
	          // The given byteOffset must be a multiple of the element
	          // size of the specific type, otherwise an exception is raised.
	          throw new RangeError("ArrayBuffer length minus the byteOffset is not a multiple of the element size.");
	        }

	        if (arguments.length < 3) {
	          this.byteLength = this.buffer.byteLength - this.byteOffset;

	          if (this.byteLength % this.BYTES_PER_ELEMENT) {
	            throw new RangeError("length of buffer minus byteOffset not a multiple of the element size");
	          }
	          this.length = this.byteLength / this.BYTES_PER_ELEMENT;
	        } else {
	          this.length = ECMAScript.ToUint32(length);
	          this.byteLength = this.length * this.BYTES_PER_ELEMENT;
	        }

	        if ((this.byteOffset + this.byteLength) > this.buffer.byteLength) {
	          throw new RangeError("byteOffset and length reference an area beyond the end of the buffer");
	        }
	      } else {
	        throw new TypeError("Unexpected argument type(s)");
	      }

	      this.constructor = ctor;

	      configureProperties(this);
	      makeArrayAccessors(this);
	    };

	    ctor.prototype = new ArrayBufferView();
	    ctor.prototype.BYTES_PER_ELEMENT = bytesPerElement;
	    ctor.prototype._pack = pack;
	    ctor.prototype._unpack = unpack;
	    ctor.BYTES_PER_ELEMENT = bytesPerElement;

	    // getter type (unsigned long index);
	    ctor.prototype._getter = function(index) {
	      if (arguments.length < 1) throw new SyntaxError("Not enough arguments");

	      index = ECMAScript.ToUint32(index);
	      if (index >= this.length) {
	        return undefined;
	      }

	      var bytes = [], i, o;
	      for (i = 0, o = this.byteOffset + index * this.BYTES_PER_ELEMENT;
	           i < this.BYTES_PER_ELEMENT;
	           i += 1, o += 1) {
	        bytes.push(this.buffer._bytes[o]);
	      }
	      return this._unpack(bytes);
	    };

	    // NONSTANDARD: convenience alias for getter: type get(unsigned long index);
	    ctor.prototype.get = ctor.prototype._getter;

	    // setter void (unsigned long index, type value);
	    ctor.prototype._setter = function(index, value) {
	      if (arguments.length < 2) throw new SyntaxError("Not enough arguments");

	      index = ECMAScript.ToUint32(index);
	      if (index >= this.length) {
	        return undefined;
	      }

	      var bytes = this._pack(value), i, o;
	      for (i = 0, o = this.byteOffset + index * this.BYTES_PER_ELEMENT;
	           i < this.BYTES_PER_ELEMENT;
	           i += 1, o += 1) {
	        this.buffer._bytes[o] = bytes[i];
	      }
	    };

	    // void set(TypedArray array, optional unsigned long offset);
	    // void set(sequence<type> array, optional unsigned long offset);
	    ctor.prototype.set = function(index, value) {
	      if (arguments.length < 1) throw new SyntaxError("Not enough arguments");
	      var array, sequence, offset, len,
	          i, s, d,
	          byteOffset, byteLength, tmp;

	      if (typeof arguments[0] === 'object' && arguments[0].constructor === this.constructor) {
	        // void set(TypedArray array, optional unsigned long offset);
	        array = arguments[0];
	        offset = ECMAScript.ToUint32(arguments[1]);

	        if (offset + array.length > this.length) {
	          throw new RangeError("Offset plus length of array is out of range");
	        }

	        byteOffset = this.byteOffset + offset * this.BYTES_PER_ELEMENT;
	        byteLength = array.length * this.BYTES_PER_ELEMENT;

	        if (array.buffer === this.buffer) {
	          tmp = [];
	          for (i = 0, s = array.byteOffset; i < byteLength; i += 1, s += 1) {
	            tmp[i] = array.buffer._bytes[s];
	          }
	          for (i = 0, d = byteOffset; i < byteLength; i += 1, d += 1) {
	            this.buffer._bytes[d] = tmp[i];
	          }
	        } else {
	          for (i = 0, s = array.byteOffset, d = byteOffset;
	               i < byteLength; i += 1, s += 1, d += 1) {
	            this.buffer._bytes[d] = array.buffer._bytes[s];
	          }
	        }
	      } else if (typeof arguments[0] === 'object' && typeof arguments[0].length !== 'undefined') {
	        // void set(sequence<type> array, optional unsigned long offset);
	        sequence = arguments[0];
	        len = ECMAScript.ToUint32(sequence.length);
	        offset = ECMAScript.ToUint32(arguments[1]);

	        if (offset + len > this.length) {
	          throw new RangeError("Offset plus length of array is out of range");
	        }

	        for (i = 0; i < len; i += 1) {
	          s = sequence[i];
	          this._setter(offset + i, Number(s));
	        }
	      } else {
	        throw new TypeError("Unexpected argument type(s)");
	      }
	    };

	    // TypedArray subarray(long begin, optional long end);
	    ctor.prototype.subarray = function(start, end) {
	      function clamp(v, min, max) { return v < min ? min : v > max ? max : v; }

	      start = ECMAScript.ToInt32(start);
	      end = ECMAScript.ToInt32(end);

	      if (arguments.length < 1) { start = 0; }
	      if (arguments.length < 2) { end = this.length; }

	      if (start < 0) { start = this.length + start; }
	      if (end < 0) { end = this.length + end; }

	      start = clamp(start, 0, this.length);
	      end = clamp(end, 0, this.length);

	      var len = end - start;
	      if (len < 0) {
	        len = 0;
	      }

	      return new this.constructor(
	        this.buffer, this.byteOffset + start * this.BYTES_PER_ELEMENT, len);
	    };

	    return ctor;
	  }

	  var Int8Array = makeConstructor(1, packI8, unpackI8);
	  var Uint8Array = makeConstructor(1, packU8, unpackU8);
	  var Uint8ClampedArray = makeConstructor(1, packU8Clamped, unpackU8);
	  var Int16Array = makeConstructor(2, packI16, unpackI16);
	  var Uint16Array = makeConstructor(2, packU16, unpackU16);
	  var Int32Array = makeConstructor(4, packI32, unpackI32);
	  var Uint32Array = makeConstructor(4, packU32, unpackU32);
	  var Float32Array = makeConstructor(4, packF32, unpackF32);
	  var Float64Array = makeConstructor(8, packF64, unpackF64);

	  exports.Int8Array = exports.Int8Array || Int8Array;
	  exports.Uint8Array = exports.Uint8Array || Uint8Array;
	  exports.Uint8ClampedArray = exports.Uint8ClampedArray || Uint8ClampedArray;
	  exports.Int16Array = exports.Int16Array || Int16Array;
	  exports.Uint16Array = exports.Uint16Array || Uint16Array;
	  exports.Int32Array = exports.Int32Array || Int32Array;
	  exports.Uint32Array = exports.Uint32Array || Uint32Array;
	  exports.Float32Array = exports.Float32Array || Float32Array;
	  exports.Float64Array = exports.Float64Array || Float64Array;
	}());

	//
	// 6 The DataView View Type
	//

	(function() {
	  function r(array, index) {
	    return ECMAScript.IsCallable(array.get) ? array.get(index) : array[index];
	  }

	  var IS_BIG_ENDIAN = (function() {
	    var u16array = new(exports.Uint16Array)([0x1234]),
	        u8array = new(exports.Uint8Array)(u16array.buffer);
	    return r(u8array, 0) === 0x12;
	  }());

	  // Constructor(ArrayBuffer buffer,
	  //             optional unsigned long byteOffset,
	  //             optional unsigned long byteLength)
	  /** @constructor */
	  var DataView = function DataView(buffer, byteOffset, byteLength) {
	    if (arguments.length === 0) {
	      buffer = new exports.ArrayBuffer(0);
	    } else if (!(buffer instanceof exports.ArrayBuffer || ECMAScript.Class(buffer) === 'ArrayBuffer')) {
	      throw new TypeError("TypeError");
	    }

	    this.buffer = buffer || new exports.ArrayBuffer(0);

	    this.byteOffset = ECMAScript.ToUint32(byteOffset);
	    if (this.byteOffset > this.buffer.byteLength) {
	      throw new RangeError("byteOffset out of range");
	    }

	    if (arguments.length < 3) {
	      this.byteLength = this.buffer.byteLength - this.byteOffset;
	    } else {
	      this.byteLength = ECMAScript.ToUint32(byteLength);
	    }

	    if ((this.byteOffset + this.byteLength) > this.buffer.byteLength) {
	      throw new RangeError("byteOffset and length reference an area beyond the end of the buffer");
	    }

	    configureProperties(this);
	  };

	  function makeGetter(arrayType) {
	    return function(byteOffset, littleEndian) {

	      byteOffset = ECMAScript.ToUint32(byteOffset);

	      if (byteOffset + arrayType.BYTES_PER_ELEMENT > this.byteLength) {
	        throw new RangeError("Array index out of range");
	      }
	      byteOffset += this.byteOffset;

	      var uint8Array = new exports.Uint8Array(this.buffer, byteOffset, arrayType.BYTES_PER_ELEMENT),
	          bytes = [], i;
	      for (i = 0; i < arrayType.BYTES_PER_ELEMENT; i += 1) {
	        bytes.push(r(uint8Array, i));
	      }

	      if (Boolean(littleEndian) === Boolean(IS_BIG_ENDIAN)) {
	        bytes.reverse();
	      }

	      return r(new arrayType(new exports.Uint8Array(bytes).buffer), 0);
	    };
	  }

	  DataView.prototype.getUint8 = makeGetter(exports.Uint8Array);
	  DataView.prototype.getInt8 = makeGetter(exports.Int8Array);
	  DataView.prototype.getUint16 = makeGetter(exports.Uint16Array);
	  DataView.prototype.getInt16 = makeGetter(exports.Int16Array);
	  DataView.prototype.getUint32 = makeGetter(exports.Uint32Array);
	  DataView.prototype.getInt32 = makeGetter(exports.Int32Array);
	  DataView.prototype.getFloat32 = makeGetter(exports.Float32Array);
	  DataView.prototype.getFloat64 = makeGetter(exports.Float64Array);

	  function makeSetter(arrayType) {
	    return function(byteOffset, value, littleEndian) {

	      byteOffset = ECMAScript.ToUint32(byteOffset);
	      if (byteOffset + arrayType.BYTES_PER_ELEMENT > this.byteLength) {
	        throw new RangeError("Array index out of range");
	      }

	      // Get bytes
	      var typeArray = new arrayType([value]),
	          byteArray = new exports.Uint8Array(typeArray.buffer),
	          bytes = [], i, byteView;

	      for (i = 0; i < arrayType.BYTES_PER_ELEMENT; i += 1) {
	        bytes.push(r(byteArray, i));
	      }

	      // Flip if necessary
	      if (Boolean(littleEndian) === Boolean(IS_BIG_ENDIAN)) {
	        bytes.reverse();
	      }

	      // Write them
	      byteView = new exports.Uint8Array(this.buffer, byteOffset, arrayType.BYTES_PER_ELEMENT);
	      byteView.set(bytes);
	    };
	  }

	  DataView.prototype.setUint8 = makeSetter(exports.Uint8Array);
	  DataView.prototype.setInt8 = makeSetter(exports.Int8Array);
	  DataView.prototype.setUint16 = makeSetter(exports.Uint16Array);
	  DataView.prototype.setInt16 = makeSetter(exports.Int16Array);
	  DataView.prototype.setUint32 = makeSetter(exports.Uint32Array);
	  DataView.prototype.setInt32 = makeSetter(exports.Int32Array);
	  DataView.prototype.setFloat32 = makeSetter(exports.Float32Array);
	  DataView.prototype.setFloat64 = makeSetter(exports.Float64Array);

	  exports.DataView = exports.DataView || DataView;

	}());


/***/ },
/* 90 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var __extends = (this && this.__extends) || function (d, b) {
	    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
	    function __() { this.constructor = d; }
	    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
	};
	/// <reference path="../typings/main.d.ts" />
	var _ = __webpack_require__(177);
	var su = __webpack_require__(99);
	var tsInterfaces = __webpack_require__(91);
	var Status = (function () {
	    function Status(severity, code, message, source) {
	        this.subStatus = [];
	        this.severity = severity;
	        this.code = code;
	        this.message = message;
	        this.source = source;
	    }
	    Status.prototype.getValidationPath = function () {
	        return this.vp;
	    };
	    Status.prototype.getValidationPathAsString = function () {
	        if (!this.vp) {
	            return "";
	        }
	        var s = "";
	        var c = this.vp;
	        while (c) {
	            s += c.name;
	            if (c.child) {
	                s += '/';
	            }
	            c = c.child;
	        }
	        return s;
	    };
	    Status.prototype.patchPath = function (p) {
	        if (!p) {
	            return null;
	        }
	        else {
	            var c = p;
	            var r = null;
	            var cp = null;
	            while (c) {
	                if (!r) {
	                    r = { name: c.name };
	                    cp = r;
	                    c = c.child;
	                    cp = r;
	                }
	                else {
	                    var news = { name: c.name };
	                    cp.child = news;
	                    c = c.child;
	                    cp = news;
	                }
	            }
	            return r;
	        }
	    };
	    Status.prototype.setValidationPath = function (c) {
	        var _this = this;
	        if (this.vp) {
	            c = this.patchPath(c);
	            var m = c;
	            while (m.child) {
	                m = m.child;
	            }
	            m.child = this.vp;
	            this.vp = c;
	        }
	        else {
	            this.vp = c;
	        }
	        this.subStatus.forEach(function (x) {
	            x.setValidationPath(_this.vp);
	        });
	    };
	    Status.prototype.addSubStatus = function (st, pathName) {
	        if (pathName === void 0) { pathName = null; }
	        if (pathName) {
	            st.setValidationPath({ name: pathName });
	        }
	        this.subStatus.push(st);
	        if (this.severity < st.severity) {
	            this.severity = st.severity;
	            this.message = st.message;
	        }
	    };
	    Status.prototype.getErrors = function () {
	        if (this.isError() || this.isWarning()) {
	            if (this.subStatus.length > 0) {
	                var rs = [];
	                this.subStatus.forEach(function (x) { return rs = rs.concat(x.getErrors()); });
	                return rs;
	            }
	            return [this];
	        }
	        return [];
	    };
	    Status.prototype.getSubStatuses = function () {
	        return this.subStatus;
	    };
	    Status.prototype.getSeverity = function () {
	        return this.severity;
	    };
	    Status.prototype.getMessage = function () {
	        return this.message;
	    };
	    Status.prototype.getSource = function () {
	        return this.source;
	    };
	    Status.prototype.isWarning = function () {
	        return this.severity == Status.WARNING;
	    };
	    Status.prototype.isError = function () {
	        return this.severity == Status.ERROR;
	    };
	    Status.prototype.isOk = function () {
	        return this.severity === Status.OK;
	    };
	    Status.prototype.setSource = function (s) {
	        this.source = s;
	    };
	    Status.prototype.toString = function () {
	        if (this.isOk()) {
	            return "OK";
	        }
	        return this.message;
	    };
	    Status.CODE_CONFLICTING_TYPE_KIND = 4;
	    Status.ERROR = 3;
	    Status.INFO = 1;
	    Status.OK = 0;
	    Status.WARNING = 2;
	    return Status;
	}());
	exports.Status = Status;
	function ok() { return new Status(Status.OK, Status.OK, "", null); }
	exports.ok = ok;
	;
	exports.SCHEMA_AND_TYPE = tsInterfaces.SCHEMA_AND_TYPE_EXTRA;
	exports.GLOBAL = tsInterfaces.GLOBAL_EXTRA;
	exports.TOPLEVEL = tsInterfaces.TOP_LEVEL_EXTRA;
	exports.SOURCE_EXTRA = tsInterfaces.SOURCE_EXTRA;
	function error(message, source) {
	    return new Status(Status.ERROR, 0, message, source);
	}
	exports.error = error;
	var TypeInformation = (function () {
	    function TypeInformation(_inheritable) {
	        this._inheritable = _inheritable;
	    }
	    TypeInformation.prototype.owner = function () {
	        return this._owner;
	    };
	    TypeInformation.prototype.isInheritable = function () {
	        return this._inheritable;
	    };
	    TypeInformation.prototype.validateSelf = function (registry) {
	        return ok();
	    };
	    return TypeInformation;
	}());
	exports.TypeInformation = TypeInformation;
	var stack = null;
	var Constraint = (function (_super) {
	    __extends(Constraint, _super);
	    function Constraint() {
	        _super.call(this, true);
	    }
	    Constraint.prototype.intersect = function (t0, t1) {
	        var nm = t0.id() + "" + t1.id();
	        if (Constraint.intersections.hasOwnProperty(nm)) {
	            return Constraint.intersections[nm];
	        }
	        var is = intersect(nm, [t0, t1]);
	        Constraint.intersections[nm] = is;
	        return is;
	    };
	    Constraint.prototype.release = function (t) {
	        delete Constraint.intersections[t.name()];
	    };
	    Constraint.prototype.nothing = function (c, message) {
	        if (message === void 0) { message = "Conflicting restrictions"; }
	        return new NothingRestrictionWithLocation(stack, message, c);
	    };
	    /**
	     * inner implementation of  compute composed restriction from this and parameter restriction
	     * @param restriction
	     * @return  composed restriction or null;
	     */
	    Constraint.prototype.composeWith = function (r) { return null; };
	    /**
	     * returns optimized restiction or this
	     * @returns {Constraint}
	     */
	    Constraint.prototype.preoptimize = function () {
	        if (stack === null) {
	            stack = new RestrictionStackEntry(null, null, "top");
	        }
	        stack = stack.push(this);
	        try {
	            return this.innerOptimize();
	        }
	        finally {
	            stack = stack.pop();
	        }
	    };
	    Constraint.prototype.innerOptimize = function () {
	        return this;
	    };
	    /**
	     * performs attempt to compute composed restriction from this and parameter restriction
	     * @param restriction
	     * @return  composed restriction or null;
	     */
	    Constraint.prototype.tryCompose = function (r) {
	        if (stack === null) {
	            stack = new RestrictionStackEntry(null, null, "top");
	        }
	        stack = stack.push(this);
	        try {
	            return this.composeWith(r);
	        }
	        finally {
	            stack = stack.pop();
	        }
	    };
	    Constraint.intersections = {};
	    return Constraint;
	}(TypeInformation));
	exports.Constraint = Constraint;
	var restr = __webpack_require__(94);
	var metaInfo = __webpack_require__(95);
	var fr = __webpack_require__(93);
	var restrictions_1 = __webpack_require__(94);
	var metainfo_1 = __webpack_require__(95);
	var metainfo_2 = __webpack_require__(95);
	var restrictions_2 = __webpack_require__(94);
	var restrictions_3 = __webpack_require__(94);
	var exO = __webpack_require__(134);
	var metainfo_3 = __webpack_require__(95);
	var restrictions_4 = __webpack_require__(94);
	var restrictions_5 = __webpack_require__(94);
	exports.autoCloseFlag = false;
	/**
	 * Registry of the types
	 */
	var TypeRegistry = (function () {
	    function TypeRegistry(_parent) {
	        if (_parent === void 0) { _parent = null; }
	        this._parent = _parent;
	        this._types = {};
	        this.typeList = [];
	    }
	    TypeRegistry.prototype.put = function (alias, t) {
	        this._types[alias] = t;
	    };
	    TypeRegistry.prototype.addType = function (t) {
	        if (t.isAnonymous()) {
	            return;
	        }
	        this._types[t.name()] = t;
	        this.typeList.push(t);
	    };
	    TypeRegistry.prototype.get = function (name) {
	        if (this._types.hasOwnProperty(name)) {
	            return this._types[name];
	        }
	        if (this._parent != null) {
	            return this._parent.get(name);
	        }
	        return null;
	    };
	    TypeRegistry.prototype.types = function () {
	        return this.typeList;
	    };
	    return TypeRegistry;
	}());
	exports.TypeRegistry = TypeRegistry;
	var PropertyCyclesValidator = (function () {
	    function PropertyCyclesValidator() {
	    }
	    PropertyCyclesValidator.prototype.getInfos = function (t) {
	        if (t.getExtra("PInfos")) {
	            return t.getExtra("PInfos");
	        }
	        var m = {};
	        t.meta().forEach(function (x) {
	            if (x instanceof restr.HasProperty) {
	                var id = x.value();
	                m[id] = { name: id, type: null };
	            }
	        });
	        t.meta().forEach(function (x) {
	            if (x instanceof restr.PropertyIs) {
	                var id = x.propertyName();
	                if (m[id]) {
	                    m[id].type = x.value();
	                }
	            }
	        });
	        t.putExtra("PInfos", m);
	        return m;
	    };
	    PropertyCyclesValidator.prototype.validate = function (t, visited) {
	        var _this = this;
	        var i = this.getInfos(t);
	        var result = false;
	        Object.keys(i).forEach(function (x) {
	            result = result || _this.validateInfo(i[x], visited);
	        });
	        return result;
	    };
	    PropertyCyclesValidator.prototype.validateInfo = function (t, visited) {
	        var _this = this;
	        if (visited.some(function (y) { return y == t; })) {
	            return true;
	        }
	        else {
	            if (t.type instanceof UnionType) {
	                var ut = t.type;
	                var passing = true;
	                ut.options().forEach(function (o) {
	                    if (!_this.validate(o, [t].concat(visited))) {
	                        passing = false;
	                    }
	                });
	                return passing;
	            }
	            if (t.type.isArray()) {
	            }
	            else {
	                return this.validate(t.type, [t].concat(visited));
	            }
	        }
	    };
	    PropertyCyclesValidator.prototype.validateType = function (t) {
	        var _this = this;
	        var i = this.getInfos(t);
	        var result = [];
	        Object.keys(i).forEach(function (x) {
	            if (_this.validateInfo(i[x], [])) {
	                result.push(x);
	            }
	        });
	        return result;
	    };
	    return PropertyCyclesValidator;
	}());
	var RestrictionsConflict = (function (_super) {
	    __extends(RestrictionsConflict, _super);
	    function RestrictionsConflict(_conflicting, _stack, source) {
	        _super.call(this, Status.ERROR, 0, "Restrictions conflict " + _conflicting + " and " + (_stack != null ? _stack.getRestriction().toString() : ""), source);
	        this._conflicting = _conflicting;
	        this._stack = _stack;
	    }
	    RestrictionsConflict.prototype.getConflictDescription = function () {
	        var rs = "";
	        rs += "Restrictions coflict:\n";
	        rs += this._stack.getRestriction() + " conflicts with " + this._conflicting + "\n";
	        rs += "at\n";
	        rs += this._stack.pop();
	        return rs;
	    };
	    RestrictionsConflict.prototype.getConflicting = function () {
	        return this._conflicting;
	    };
	    RestrictionsConflict.prototype.getStack = function () {
	        return this._stack;
	    };
	    RestrictionsConflict.prototype.toRestriction = function () {
	        return new NothingRestrictionWithLocation(this._stack, this.message, this._conflicting);
	    };
	    return RestrictionsConflict;
	}(Status));
	exports.RestrictionsConflict = RestrictionsConflict;
	var globalId = 0;
	exports.VALIDATED_TYPE = null;
	var AbstractType = (function () {
	    function AbstractType(_name) {
	        this._name = _name;
	        this.metaInfo = [];
	        this._subTypes = [];
	        this.innerid = globalId++;
	        this.extras = {};
	        this._locked = false;
	    }
	    AbstractType.prototype.getExtra = function (name) {
	        return this.extras[name];
	    };
	    AbstractType.prototype.putExtra = function (name, v) {
	        this.extras[name] = v;
	    };
	    AbstractType.prototype.id = function () {
	        return this.innerid;
	    };
	    AbstractType.prototype.knownProperties = function () {
	        return this.metaOfType(restrictions_5.MatchesProperty);
	    };
	    AbstractType.prototype.lock = function () {
	        this._locked = true;
	    };
	    AbstractType.prototype.isLocked = function () {
	        return this._locked;
	    };
	    AbstractType.prototype.allFacets = function () {
	        return this.meta();
	    };
	    AbstractType.prototype.declaredFacets = function () {
	        return this.declaredMeta();
	    };
	    AbstractType.prototype.isSubTypeOf = function (t) {
	        return t === exports.ANY || this === t || this.superTypes().some(function (x) { return x.isSubTypeOf(t); });
	    };
	    AbstractType.prototype.isSuperTypeOf = function (t) {
	        return this === t || this.allSubTypes().indexOf(t) != -1;
	    };
	    AbstractType.prototype.addMeta = function (info) {
	        this.metaInfo.push(info);
	        info._owner = this;
	    };
	    AbstractType.prototype.name = function () {
	        return this._name;
	    };
	    /**
	     * @return directly known sub types of a given type
	     */
	    AbstractType.prototype.subTypes = function () {
	        return this._subTypes;
	    };
	    /**
	     * @return directly known super types of a given type
	     */
	    AbstractType.prototype.superTypes = function () {
	        return [];
	    };
	    AbstractType.prototype.validateType = function (tr) {
	        var _this = this;
	        if (tr === void 0) { tr = builtInRegistry(); }
	        var rs = new Status(Status.OK, 0, "", this);
	        this.validateHierarchy(rs);
	        if (this.getExtra(tsInterfaces.PARSE_ERROR)) {
	            rs.addSubStatus(this.getExtra(tsInterfaces.PARSE_ERROR));
	        }
	        if (rs.isOk()) {
	            rs.addSubStatus(this.checkConfluent());
	            if (this.isExternal()) {
	                var allS = this.allSuperTypes();
	                var mma = allS.filter(function (x) { return x instanceof ExternalType; });
	                if (this instanceof ExternalType) {
	                    mma.push(this);
	                }
	                mma.forEach(function (x) {
	                    if (x.isJSON()) {
	                        try {
	                            su.getJSONSchema(x.schema(), x.getContentProvider && x.getContentProvider());
	                        }
	                        catch (e) {
	                            rs.addSubStatus(new Status(Status.ERROR, 0, e.message, _this));
	                        }
	                    }
	                });
	            }
	            if (rs.isOk()) {
	                this.superTypes().forEach(function (x) {
	                    if (x.isAnonymous()) {
	                        rs.addSubStatus(x.validateType(tr));
	                    }
	                });
	            }
	        }
	        if (this.getExtra(exports.SCHEMA_AND_TYPE)) {
	            rs.addSubStatus(new Status(Status.ERROR, 0, "schema and type are mutually exclusive", this));
	        }
	        if (rs.isOk()) {
	            this.validateMeta(tr).getErrors().forEach(function (x) { return rs.addSubStatus(x); });
	        }
	        //if (this.isPolymorphic()||(this.isUnion())) {
	        //    rs.addSubStatus(this.canDoAc());
	        //}
	        if (this.isObject()) {
	            var required = {};
	            this.restrictions().forEach(function (x) {
	                if (x.owner() != _this) {
	                    if (x instanceof restr.HasProperty) {
	                        required[x.value()] = true;
	                    }
	                }
	            });
	            this.declaredMeta().forEach(function (x) {
	                if (x instanceof restr.HasProperty) {
	                    delete required[x.value()];
	                }
	            });
	            this.declaredMeta().forEach(function (x) {
	                if (x instanceof restr.PropertyIs) {
	                    var pr = x;
	                    if (required.hasOwnProperty(pr.propertyName())) {
	                        rs.addSubStatus(new Status(Status.ERROR, 0, "Can not override required property:" + pr.propertyName() + " to be optional", _this));
	                    }
	                }
	            });
	            var propertyCycles = new PropertyCyclesValidator().validateType(this);
	            if (propertyCycles.length > 0) {
	                propertyCycles.forEach(function (p) {
	                    var st = new Status(Status.ERROR, 0, p + "has cyclic dependency", _this);
	                    st.setValidationPath({ name: p });
	                    rs.addSubStatus(st);
	                });
	            }
	        }
	        return rs;
	    };
	    AbstractType.prototype.validateHierarchy = function (rs) {
	        var _this = this;
	        if (!this.isAnonymous()) {
	            if (this.getExtra(tsInterfaces.TOP_LEVEL_EXTRA) && builtInRegistry().get(this.name())) {
	                rs.addSubStatus(new Status(Status.ERROR, 0, "redefining builtin type:" + this.name(), this));
	            }
	        }
	        if (this.isSubTypeOf(exports.RECURRENT)) {
	            rs.addSubStatus(new Status(Status.ERROR, 0, "recurrent type definition", this), "type");
	        }
	        if (this.isSubTypeOf(exports.UNKNOWN)) {
	            rs.addSubStatus(new Status(Status.ERROR, 0, "inheriting from unknown type", this), "type");
	        }
	        if (this.isUnion()) {
	            var tf = this.typeFamily();
	            if (tf.some(function (x) { return x.isSubTypeOf(exports.RECURRENT); })) {
	                rs.addSubStatus(new Status(Status.ERROR, 0, "recurrent type as an option of union type", this), "type");
	            }
	            if (tf.some(function (x) { return x.isSubTypeOf(exports.UNKNOWN); })) {
	                rs.addSubStatus(new Status(Status.ERROR, 0, "unknown type as an option of union type", this), "type");
	            }
	        }
	        if (this.isArray()) {
	            var fs_1 = this.familyWithArray();
	            var ps = this.getExtra(tsInterfaces.HAS_ITEMS) ? "items" : "type";
	            if ((fs_1.indexOf(this) != -1) || fs_1.some(function (x) { return x === exports.RECURRENT; })) {
	                rs.addSubStatus(new Status(Status.ERROR, 0, "recurrent array type definition", this), ps);
	            }
	            else if (fs_1.some(function (x) { return x === exports.UNKNOWN; })) {
	                rs.addSubStatus(new Status(Status.ERROR, 0, "referring to unknown type " + this.oneMeta(restrictions_3.ComponentShouldBeOfType).value().name() + " as an array component type", this), ps);
	            }
	        }
	        var supers = this.superTypes();
	        var hasExternal = false;
	        var hasNotExternal = false;
	        if (supers.length > 1) {
	            supers.forEach(function (x) {
	                if (x.isExternal()) {
	                    hasExternal = true;
	                }
	                else {
	                    hasNotExternal = true;
	                }
	            });
	        }
	        if (hasExternal && hasNotExternal) {
	            rs.addSubStatus(new Status(Status.ERROR, 0, "It is not allowed to mix RAML types with externals", this), "type");
	        }
	        if (this instanceof UnionType) {
	            var ut = this;
	            ut.options().forEach(function (x) {
	                if (x.isExternal()) {
	                    rs.addSubStatus(new Status(Status.ERROR, 0, "It is not allowed to mix RAML types with externals", _this), "type");
	                }
	            });
	        }
	        if (this.isExternal()) {
	            if (this.getExtra(tsInterfaces.HAS_FACETS)) {
	                var fs = new Status(Status.ERROR, 0, "External types can not declare facet '" + this.getExtra(tsInterfaces.HAS_FACETS) + "'", this);
	                fs.setValidationPath({ name: this.getExtra(tsInterfaces.HAS_FACETS) });
	                rs.addSubStatus(fs);
	            }
	        }
	    };
	    ;
	    AbstractType.prototype.familyWithArray = function () {
	        var ts = this.allSuperTypes();
	        var mn = this.oneMeta(restrictions_3.ComponentShouldBeOfType);
	        if (mn) {
	            var at = mn.value();
	            ts = ts.concat(at.familyWithArray());
	        }
	        return ts;
	    };
	    AbstractType.prototype.validateMeta = function (tr) {
	        var rs = new Status(Status.OK, 0, "", this);
	        this.declaredMeta().forEach(function (x) {
	            x.validateSelf(tr).getErrors().forEach(function (y) { return rs.addSubStatus(y); });
	        });
	        this.validateFacets(rs);
	        return rs;
	    };
	    AbstractType.prototype.validateFacets = function (rs) {
	        var _this = this;
	        var fds = {};
	        var super_facets = {};
	        var rfds = {};
	        this.meta().forEach(function (x) {
	            if (x instanceof metainfo_1.FacetDeclaration) {
	                var fd = x;
	                fds[fd.actualName()] = fd;
	                if (!fd.isOptional()) {
	                    if (fd.owner() !== _this) {
	                        rfds[fd.actualName()] = fd;
	                    }
	                }
	                if (fd.owner() != _this) {
	                    super_facets[fd.actualName()] = fd;
	                }
	            }
	        });
	        this.declaredMeta().forEach(function (x) {
	            if (x instanceof metainfo_1.FacetDeclaration) {
	                var fd = x;
	                if (fd.owner() == _this) {
	                    var an = fd.actualName();
	                    if (super_facets.hasOwnProperty(an)) {
	                        rs.addSubStatus(new Status(Status.ERROR, 0, "facet :" + an + " can not be overriden", _this));
	                    }
	                    var fp = fr.getInstance().facetPrototypeWithName(an);
	                    if (fp && fp.isApplicable(_this) || an == "type" || fd.facetName() == "properties" || an == "schema" || an == "facets" || an == "uses") {
	                        rs.addSubStatus(new Status(Status.ERROR, 0, "built-in facet :" + an + " can not be overriden", _this));
	                    }
	                    if (an.charAt(0) == '(') {
	                        rs.addSubStatus(new Status(Status.ERROR, 0, "facet :" + an + " can not start from '('", _this));
	                    }
	                }
	            }
	        });
	        var knownPropertySet = {};
	        this.meta().forEach(function (x) {
	            if (x instanceof restrictions_2.PropertyIs) {
	                knownPropertySet[x.propId()] = true;
	            }
	        });
	        this.meta().forEach(function (x) {
	            if (x instanceof metainfo_2.CustomFacet) {
	                var cd = x;
	                if (fds.hasOwnProperty(cd.facetName())) {
	                    var ft = fds[cd.facetName()].value();
	                    rs.addSubStatus(ft.validateDirect(cd.value(), false, false));
	                    delete rfds[cd.facetName()];
	                }
	                else {
	                    rs.addSubStatus(new Status(Status.ERROR, 0, "specifying unknown facet:" + cd.facetName(), _this));
	                }
	            }
	            if (x instanceof restrictions_4.MapPropertyIs) {
	                var mm = x;
	                Object.keys(knownPropertySet).forEach(function (c) {
	                    try {
	                        if (c.match(mm.regexpValue())) {
	                            rs.addSubStatus(new Status(Status.ERROR, 0, "map property " + mm.facetName() + " conflicts with property:" + c, _this));
	                        }
	                    }
	                    catch (e) {
	                    }
	                });
	            }
	        });
	        if (Object.getOwnPropertyNames(rfds).length > 0) {
	            rs.addSubStatus(new Status(Status.ERROR, 0, "missing required facets:" + Object.keys(rfds).join(","), this));
	        }
	    };
	    ;
	    AbstractType.prototype.allSuperTypes = function () {
	        var rs = [];
	        this.fillSuperTypes(rs);
	        return rs;
	    };
	    AbstractType.prototype.fillSuperTypes = function (r) {
	        this.superTypes().forEach(function (x) {
	            if (!_.contains(r, x)) {
	                r.push(x);
	                x.fillSuperTypes(r);
	            }
	        });
	    };
	    AbstractType.prototype.allSubTypes = function () {
	        var rs = [];
	        this.fillSubTypes(rs);
	        return rs;
	    };
	    AbstractType.prototype.fillSubTypes = function (r) {
	        this.subTypes().forEach(function (x) {
	            if (!_.contains(r, x)) {
	                r.push(x);
	                x.fillSubTypes(r);
	            }
	        });
	    };
	    AbstractType.prototype.inherit = function (name) {
	        var rs = new InheritedType(name);
	        rs.addSuper(this);
	        return rs;
	    };
	    /**
	     *
	     * @return true if type is an inplace type and has no name
	     */
	    AbstractType.prototype.isAnonymous = function () {
	        return (!this._name) || this._name.length === 0;
	    };
	    /**
	     *
	     * @return true if type has no associated meta information of restrictions
	     */
	    AbstractType.prototype.isEmpty = function () {
	        if (this.metaInfo.length > 1) {
	            return false;
	        }
	        return this.metaInfo.filter(function (x) { return !(x instanceof metainfo_3.NotScalar); }).length == 0;
	    };
	    /**
	     *
	     * @return true if type is an array or extends from an array
	     */
	    AbstractType.prototype.isArray = function () {
	        return this === exports.ARRAY || this.allSuperTypes().indexOf(exports.ARRAY) != -1;
	    };
	    AbstractType.prototype.propertySet = function () {
	        var rs = [];
	        this.meta().forEach(function (x) {
	            if (x instanceof restrictions_2.PropertyIs) {
	                var p = x;
	                rs.push(p.propertyName());
	            }
	        });
	        return _.uniq(rs);
	    };
	    AbstractType.prototype.checkConfluent = function () {
	        if (this.computeConfluent) {
	            return ok();
	        }
	        this.computeConfluent = true;
	        try {
	            var os = restr.optimize(this.restrictions());
	            var ns = _.find(os, function (x) { return x instanceof NothingRestriction; });
	            if (ns) {
	                var lstack = null;
	                var another = null;
	                if (ns instanceof NothingRestrictionWithLocation) {
	                    var nswl = ns;
	                    lstack = nswl.getStack();
	                    another = nswl.another();
	                }
	                var status = new RestrictionsConflict(another, lstack, this);
	                return status;
	            }
	            return ok();
	        }
	        finally {
	            this.computeConfluent = false;
	        }
	    };
	    /**
	     *
	     * @return true if type is object or inherited from object
	     */
	    AbstractType.prototype.isObject = function () {
	        return this == exports.OBJECT || this.allSuperTypes().indexOf(exports.OBJECT) != -1;
	    };
	    /**
	     *
	     * @return true if type is object or inherited from object
	     */
	    AbstractType.prototype.isExternal = function () {
	        return this == exports.EXTERNAL || this.allSuperTypes().indexOf(exports.EXTERNAL) != -1;
	    };
	    /**
	     *
	     * @return true if type is an boolean type or extends from boolean
	     */
	    AbstractType.prototype.isBoolean = function () {
	        return this == exports.BOOLEAN || this.allSuperTypes().indexOf(exports.BOOLEAN) != -1;
	    };
	    /**
	     *
	     * @return true if type is string or inherited from string
	     */
	    AbstractType.prototype.isString = function () {
	        return this == exports.STRING || this.allSuperTypes().indexOf(exports.STRING) != -1;
	    };
	    /**
	     *
	     * @return true if type is number or inherited from number
	     */
	    AbstractType.prototype.isNumber = function () {
	        return this == exports.NUMBER || this.allSuperTypes().indexOf(exports.NUMBER) != -1;
	    };
	    /**
	     *
	     * @return true if type is number or inherited from number
	     */
	    AbstractType.prototype.isFile = function () {
	        return this == exports.FILE || this.allSuperTypes().indexOf(exports.FILE) != -1;
	    };
	    /**
	     *
	     * @return true if type is scalar or inherited from scalar
	     */
	    AbstractType.prototype.isScalar = function () {
	        return this == exports.SCALAR || this.allSuperTypes().indexOf(exports.SCALAR) != -1;
	    };
	    /**
	     * returns true if this type inherits from one of date related types
	     */
	    AbstractType.prototype.isDateTime = function () {
	        return this == exports.DATETIME || this.allSuperTypes().indexOf(exports.DATETIME) != -1;
	    };
	    /**
	     * returns true if this type inherits from one of date related types
	     */
	    AbstractType.prototype.isDateOnly = function () {
	        return this == exports.DATE_ONLY || this.allSuperTypes().indexOf(exports.DATE_ONLY) != -1;
	    };
	    /**
	     * returns true if this type inherits from one of date related types
	     */
	    AbstractType.prototype.isTimeOnly = function () {
	        return this == exports.TIME_ONLY || this.allSuperTypes().indexOf(exports.TIME_ONLY) != -1;
	    };
	    /**
	     * returns true if this type inherits from one of date related types
	     */
	    AbstractType.prototype.isInteger = function () {
	        return this == exports.INTEGER || this.allSuperTypes().indexOf(exports.INTEGER) != -1;
	    };
	    /**
	     * returns true if this type inherits from one of date related types
	     */
	    AbstractType.prototype.isDateTimeOnly = function () {
	        return this == exports.DATETIME_ONLY || this.allSuperTypes().indexOf(exports.DATETIME_ONLY) != -1;
	    };
	    /**
	     *
	     * @return true if type is scalar or inherited from scalar
	     */
	    AbstractType.prototype.isUnknown = function () {
	        return this == exports.UNKNOWN || this.allSuperTypes().indexOf(exports.UNKNOWN) != -1;
	    };
	    /**
	     *
	     * @return true if type is scalar or inherited from scalar
	     */
	    AbstractType.prototype.isRecurrent = function () {
	        return this == exports.RECURRENT || this.allSuperTypes().indexOf(exports.RECURRENT) != -1;
	    };
	    /**
	     *
	     * @return true if type is an built-in type
	     */
	    AbstractType.prototype.isBuiltin = function () {
	        return this.metaInfo.indexOf(BUILT_IN) != -1;
	    };
	    AbstractType.prototype.exampleObject = function () {
	        return exO.example(this);
	    };
	    /**
	     *
	     * @return true if type is an polymorphic type
	     */
	    AbstractType.prototype.isPolymorphic = function () {
	        return this.meta().some(function (x) { return x instanceof Polymorphic; });
	    };
	    /**
	     * @return all restrictions associated with type
	     */
	    AbstractType.prototype.restrictions = function (forValidation) {
	        if (forValidation === void 0) { forValidation = false; }
	        if (this.isUnion()) {
	            var rs = [];
	            this.superTypes().forEach(function (x) {
	                rs = rs.concat(x.restrictions());
	            });
	            rs = rs.concat(this.meta().filter(function (x) { return x instanceof Constraint; }));
	            return rs;
	        }
	        var result = [];
	        var generic = null;
	        this.meta().forEach(function (x) {
	            if (x instanceof Constraint) {
	                if (x instanceof GenericTypeOf && forValidation) {
	                    if (generic) {
	                        return;
	                    }
	                    generic = x;
	                }
	                result.push(x);
	            }
	        });
	        return result;
	    };
	    AbstractType.prototype.customFacets = function () {
	        return this.declaredMeta().filter(function (x) { return x instanceof metaInfo.CustomFacet; });
	    };
	    AbstractType.prototype.allCustomFacets = function () {
	        return this.meta().filter(function (x) { return x instanceof metaInfo.CustomFacet; });
	    };
	    AbstractType.prototype.isUnion = function () {
	        var rs = false;
	        if (this.isBuiltin()) {
	            return false;
	        }
	        this.allSuperTypes().forEach(function (x) { return rs = rs || x instanceof UnionType; });
	        return rs;
	    };
	    /**
	     * return all type information associated with type
	     */
	    AbstractType.prototype.meta = function () {
	        return [].concat(this.metaInfo);
	    };
	    /**
	     * validates object against this type without performing AC
	     */
	    AbstractType.prototype.validateDirect = function (i, autoClose, nullAllowed, path) {
	        var _this = this;
	        if (autoClose === void 0) { autoClose = false; }
	        if (nullAllowed === void 0) { nullAllowed = true; }
	        if (path === void 0) { path = null; }
	        var prevValidated = exports.VALIDATED_TYPE;
	        try {
	            exports.VALIDATED_TYPE = this;
	            var result = new Status(Status.OK, 0, "", this);
	            if (!nullAllowed && (i === null || i === undefined)) {
	                if (!this.nullable) {
	                    return error("object is expected", this);
	                }
	            }
	            this.restrictions(true).forEach(function (x) { return result.addSubStatus(x.check(i, path)); });
	            if ((autoClose || exports.autoCloseFlag) && this.isObject() && (!this.oneMeta(restrictions_1.KnownPropertyRestriction))) {
	                var cp = new restrictions_1.KnownPropertyRestriction(true);
	                cp.patchOwner(this);
	                cp.check(i).getErrors().forEach(function (x) {
	                    var rs = new Status(Status.WARNING, 0, x.getMessage(), _this);
	                    rs.setValidationPath(x.getValidationPath());
	                    result.addSubStatus(rs);
	                });
	            }
	        }
	        finally {
	            exports.VALIDATED_TYPE = prevValidated;
	        }
	        return result;
	    };
	    AbstractType.prototype.validate = function (i, autoClose, nullAllowed) {
	        if (autoClose === void 0) { autoClose = false; }
	        if (nullAllowed === void 0) { nullAllowed = true; }
	        var g = exports.autoCloseFlag;
	        if (!nullAllowed && (i === null || i === undefined)) {
	            if (!this.nullable) {
	                return error("object is expected", this);
	            }
	        }
	        if (autoClose) {
	            exports.autoCloseFlag = true;
	        }
	        try {
	            return this.validateDirect(i, autoClose || g);
	        }
	        finally {
	            exports.autoCloseFlag = g;
	        }
	    };
	    /**
	     * declares a pattern property on this type,
	     * note if type is not inherited from an object type this will move
	     * type to inconsistent state
	     * @param name - regexp
	     * @param type - type of the property
	     * @return
	     */
	    AbstractType.prototype.declareMapProperty = function (name, type) {
	        if (type != null) {
	            this.addMeta(new restr.MapPropertyIs(name, type));
	        }
	        return type;
	    };
	    /**
	     * make this type closed type (no unknown properties any more)
	     */
	    AbstractType.prototype.closeUnknownProperties = function () {
	        this.addMeta(new restrictions_1.KnownPropertyRestriction(true));
	    };
	    AbstractType.prototype.canDoAc = function () {
	        var tf = _.uniq(this.typeFamily());
	        var s = new Status(Status.OK, 0, "", this);
	        for (var i = 0; i < tf.length; i++) {
	            for (var j = 0; j < tf.length; j++) {
	                if (i != j) {
	                    var t0 = tf[i];
	                    var t1 = tf[j];
	                    var ed = this.emptyIntersectionOrDiscriminator(t0, t1);
	                    s.addSubStatus(ed);
	                }
	            }
	        }
	        return s;
	    };
	    AbstractType.prototype.emptyIntersectionOrDiscriminator = function (t0, t1) {
	        if (t1 === t0) {
	            return ok();
	        }
	        if (t1.isScalar() && t0.isScalar()) {
	            return ok();
	        }
	        var it = intersect("", [t0, t1]);
	        var innerCheckConfluent = it.checkConfluent();
	        if (innerCheckConfluent.isOk()) {
	            return this.checkDiscriminator(t0, t1);
	        }
	        return ok();
	    };
	    AbstractType.prototype.checkDiscriminator = function (t1, t2) {
	        var found = new Status(Status.ERROR, 0, "can not discriminate types " + t1.name() + " and " + t2.name() + " without discriminator", this);
	        var oneMeta = t1.oneMeta(metaInfo.Discriminator);
	        var anotherMeta = t2.oneMeta(metaInfo.Discriminator);
	        if (oneMeta != null && anotherMeta != null && oneMeta.value() === (anotherMeta.value())) {
	            var d1 = t1.name();
	            var d2 = t2.name();
	            var dv1 = t1.oneMeta(metaInfo.DiscriminatorValue);
	            if (dv1 != null) {
	                d1 = dv1.value();
	            }
	            var dv2 = t2.oneMeta(metaInfo.DiscriminatorValue);
	            if (dv2 != null) {
	                d2 = dv2.value();
	            }
	            if (d1 !== d2) {
	                return ok();
	            }
	            found = new Status(Status.ERROR, 0, "types" + t1.name() + " and " + t2.name() + " have same discriminator value", this);
	        }
	        return found;
	    };
	    /**
	     * performs automatic classification of the instance
	     * @param obj
	     * @returns {AbstractType}
	     */
	    AbstractType.prototype.ac = function (obj) {
	        if (!this.isPolymorphic() && !this.isUnion()) {
	            return this;
	        }
	        if (this.isBuiltin()) {
	            return this;
	        }
	        var tf = _.uniq(this.typeFamily());
	        if (tf.length == 0) {
	            return exports.NOTHING;
	        }
	        if (this.isScalar()) {
	            if (this.isNumber()) {
	                if (typeof obj == "number") {
	                    return this;
	                }
	                return exports.NOTHING;
	            }
	            if (this.isString()) {
	                if (typeof obj == "string") {
	                    return this;
	                }
	                return exports.NOTHING;
	            }
	            if (this.isBoolean()) {
	                if (typeof obj == "boolean") {
	                    return this;
	                }
	                return exports.NOTHING;
	            }
	            return this;
	        }
	        if (tf.length === 1) {
	            return tf[0];
	        }
	        var options = [];
	        tf.forEach(function (x) {
	            var ds = x.validateDirect(obj, true);
	            if (ds.isOk()) {
	                options.push(x);
	            }
	        });
	        var t = this.discriminate(obj, options);
	        if (!t) {
	            return exports.NOTHING;
	        }
	        return t;
	    };
	    /**
	     * adds new property declaration to this type, note if type is not inherited from an object type this will move
	     * type to inconsistent state
	     * @param name - name of the property
	     * @param type - type of the property
	     * @param optional true if property is optinal
	     * @return the type with property (this)
	     */
	    AbstractType.prototype.declareProperty = function (name, t, optional) {
	        if (!optional) {
	            this.addMeta(new restr.HasProperty(name));
	        }
	        if (t != null) {
	            this.addMeta(new restr.PropertyIs(name, t));
	        }
	        return this;
	    };
	    AbstractType.prototype.discriminate = function (obj, opt) {
	        var newOpts = [].concat(opt);
	        var opts = [].concat(opt);
	        while (newOpts.length > 1) {
	            var found = false;
	            l2: for (var i = 0; i < opts.length; i++) {
	                for (var j = 0; j < opts.length; j++) {
	                    var t0 = opts[i];
	                    var t1 = opts[j];
	                    if (t0 != t1) {
	                        var nt = select(obj, t0, t1);
	                        if (nt === t0) {
	                            opts = opts.filter(function (x) { return x != t1; });
	                            found = true;
	                            break l2;
	                        }
	                        else if (nt === t1) {
	                            opts = opts.filter(function (x) { return x != t0; });
	                            found = true;
	                            break l2;
	                        }
	                        else {
	                            opts = opts.filter(function (x) { return x != t0 && x != t1; });
	                            found = true;
	                            break l2;
	                        }
	                    }
	                }
	            }
	            newOpts = opts;
	        }
	        if (newOpts.length == 1) {
	            return newOpts[0];
	        }
	        return null;
	    };
	    /**
	     * return instance of type information of particular class
	     * @param clazz
	     * @returns {any}
	     */
	    AbstractType.prototype.oneMeta = function (clazz) {
	        return _.find(this.meta(), function (x) { return x instanceof clazz; });
	    };
	    /**
	     * return all instances of meta information of particular class
	     * @param clazz
	     * @returns {any}
	     */
	    AbstractType.prototype.metaOfType = function (clazz) {
	        return this.meta().filter(function (x) { return x instanceof clazz; });
	    };
	    AbstractType.prototype.declaredMeta = function () {
	        return this.metaInfo;
	    };
	    AbstractType.prototype.descValue = function () {
	        var dv = this.oneMeta(metaInfo.DiscriminatorValue);
	        if (dv) {
	            return dv.value();
	        }
	        return this.name();
	    };
	    AbstractType.prototype.isAbstractOrInternal = function () {
	        return this.metaInfo.some(function (x) { return x instanceof Abstract || x instanceof Internal; });
	    };
	    AbstractType.prototype.typeFamily = function () {
	        if (this.isUnion()) {
	            var res = [];
	            this.allSuperTypes().forEach(function (x) {
	                if (x instanceof UnionType) {
	                    var opts = x.allOptions();
	                    for (var i = 0; i < opts.length; i++) {
	                        res = res.concat(opts[i].typeFamily());
	                    }
	                }
	            });
	            return _.unique(res);
	        }
	        var rs = [];
	        if (!this.isAbstractOrInternal()) {
	            rs.push(this);
	        }
	        this.allSubTypes().forEach(function (x) {
	            if (!x.isAbstractOrInternal()) {
	                rs.push(x);
	            }
	        });
	        return _.unique(rs);
	    };
	    return AbstractType;
	}());
	exports.AbstractType = AbstractType;
	var Modifier = (function (_super) {
	    __extends(Modifier, _super);
	    function Modifier() {
	        _super.apply(this, arguments);
	    }
	    Modifier.prototype.requiredType = function () {
	        return exports.ANY;
	    };
	    return Modifier;
	}(TypeInformation));
	exports.Modifier = Modifier;
	var Polymorphic = (function (_super) {
	    __extends(Polymorphic, _super);
	    function Polymorphic() {
	        _super.call(this, true);
	    }
	    Polymorphic.prototype.facetName = function () {
	        return "polymorphic";
	    };
	    Polymorphic.prototype.value = function () {
	        return true;
	    };
	    return Polymorphic;
	}(Modifier));
	exports.Polymorphic = Polymorphic;
	var Abstract = (function (_super) {
	    __extends(Abstract, _super);
	    function Abstract() {
	        _super.call(this, false);
	    }
	    Abstract.prototype.value = function () {
	        return true;
	    };
	    Abstract.prototype.facetName = function () {
	        return "abstract";
	    };
	    return Abstract;
	}(Modifier));
	exports.Abstract = Abstract;
	var Internal = (function (_super) {
	    __extends(Internal, _super);
	    function Internal() {
	        _super.call(this, false);
	    }
	    Internal.prototype.facetName = function () {
	        return "abstract";
	    };
	    Internal.prototype.value = function () {
	        return true;
	    };
	    return Internal;
	}(Modifier));
	exports.Internal = Internal;
	var BuiltIn = (function (_super) {
	    __extends(BuiltIn, _super);
	    function BuiltIn() {
	        _super.call(this, false);
	    }
	    BuiltIn.prototype.facetName = function () {
	        return "builtIn";
	    };
	    BuiltIn.prototype.value = function () {
	        return true;
	    };
	    return BuiltIn;
	}(Modifier));
	var BUILT_IN = new BuiltIn();
	var RootType = (function (_super) {
	    __extends(RootType, _super);
	    function RootType() {
	        _super.apply(this, arguments);
	    }
	    RootType.prototype.kind = function () {
	        return "root";
	    };
	    return RootType;
	}(AbstractType));
	exports.RootType = RootType;
	var InheritedType = (function (_super) {
	    __extends(InheritedType, _super);
	    function InheritedType() {
	        _super.apply(this, arguments);
	        this._superTypes = [];
	    }
	    InheritedType.prototype.superTypes = function () {
	        return this._superTypes;
	    };
	    InheritedType.prototype.knownProperties = function () {
	        var vs = this.metaOfType(restrictions_5.MatchesProperty);
	        this.superTypes().forEach(function (x) {
	            vs = vs.concat(x.knownProperties());
	        });
	        return vs;
	    };
	    InheritedType.prototype.kind = function () {
	        return "inherited";
	    };
	    InheritedType.prototype.meta = function () {
	        var _this = this;
	        var rs = _super.prototype.meta.call(this);
	        var hasKp = false;
	        this.superTypes().forEach(function (x) {
	            x.meta().forEach(function (m) {
	                if (m instanceof restrictions_1.KnownPropertyRestriction) {
	                    if (hasKp) {
	                        return;
	                    }
	                    var kp = new restrictions_1.KnownPropertyRestriction(true);
	                    kp.patchOwner(_this);
	                    rs.push(kp);
	                    return;
	                }
	                if (m.isInheritable()) {
	                    rs.push(m);
	                }
	            });
	        });
	        return rs;
	    };
	    InheritedType.prototype.addSuper = function (t) {
	        this._superTypes.push(t);
	        if (!t.isLocked()) {
	            t._subTypes.push(this);
	        }
	        if (t.nullable) {
	            this.nullable = true;
	        }
	    };
	    return InheritedType;
	}(AbstractType));
	exports.InheritedType = InheritedType;
	var DerivedType = (function (_super) {
	    __extends(DerivedType, _super);
	    function DerivedType(name, _options) {
	        _super.call(this, name);
	        this._options = _options;
	    }
	    /**
	     *
	     * @returns all possible options
	     */
	    DerivedType.prototype.allOptions = function () {
	        var _this = this;
	        var rs = [];
	        this._options.forEach(function (x) {
	            if (x.kind() == _this.kind()) {
	                rs = rs.concat(x.allOptions());
	            }
	            else {
	                rs.push(x);
	            }
	        });
	        return _.unique(rs);
	    };
	    DerivedType.prototype.options = function () {
	        return this._options;
	    };
	    return DerivedType;
	}(AbstractType));
	exports.DerivedType = DerivedType;
	var UnionType = (function (_super) {
	    __extends(UnionType, _super);
	    function UnionType(name, _options) {
	        var _this = this;
	        _super.call(this, name, _options);
	        this.options().forEach(function (x) {
	            if (x.nullable) {
	                _this.nullable = true;
	            }
	        });
	    }
	    UnionType.prototype.kind = function () {
	        return "union";
	    };
	    UnionType.prototype.isSubTypeOf = function (t) {
	        var isSubType = true;
	        this.allOptions().forEach(function (x) {
	            if (!x.isSubTypeOf(t)) {
	                isSubType = false;
	            }
	        });
	        return isSubType;
	        //return t===ANY||this===t|| this.superTypes().some(x=>x.isSubTypeOf(t));
	    };
	    UnionType.prototype.validate = function (i) {
	        return this.validateDirect(i);
	    };
	    UnionType.prototype.typeFamily = function () {
	        var res = [];
	        this.allOptions().forEach(function (x) {
	            res = res.concat(x.typeFamily());
	        });
	        return res;
	    };
	    UnionType.prototype.knownProperties = function () {
	        var vs = this.metaOfType(restrictions_5.MatchesProperty);
	        this.options().forEach(function (x) {
	            vs = vs.concat(x.knownProperties());
	        });
	        return vs;
	    };
	    UnionType.prototype.validateDirect = function (i, autoClose) {
	        if (autoClose === void 0) { autoClose = false; }
	        var st = new Status(Status.OK, 0, "", this);
	        var options = null;
	        for (var j = 0; j < this.options().length; j++) {
	            var s = this.options()[j].validateDirect(i, autoClose);
	            if (s.isOk()) {
	                return s;
	            }
	            options = s;
	        }
	        st.addSubStatus(options);
	        return st;
	    };
	    UnionType.prototype.isUnion = function () {
	        return true;
	    };
	    UnionType.prototype.restrictions = function () {
	        return [new OrRestriction(this.allOptions().map(function (x) { return new AndRestriction(x.restrictions()); }), "union type options does not pass validation")];
	    };
	    return UnionType;
	}(DerivedType));
	exports.UnionType = UnionType;
	var IntersectionType = (function (_super) {
	    __extends(IntersectionType, _super);
	    function IntersectionType() {
	        _super.apply(this, arguments);
	    }
	    IntersectionType.prototype.kind = function () {
	        return "intersection";
	    };
	    IntersectionType.prototype.restrictions = function () {
	        var rs = [];
	        this.allOptions().forEach(function (x) { return rs = rs.concat(x.restrictions()); });
	        return [new AndRestriction(rs)];
	    };
	    return IntersectionType;
	}(DerivedType));
	exports.IntersectionType = IntersectionType;
	var registry = new TypeRegistry();
	function builtInRegistry() {
	    return registry;
	}
	exports.builtInRegistry = builtInRegistry;
	function union(name, t) {
	    return new UnionType(name, t);
	}
	exports.union = union;
	function intersect(name, t) {
	    return new IntersectionType(name, t);
	}
	exports.intersect = intersect;
	/**
	 * allows you to extend a type from other types
	 * @param name
	 * @param t
	 * @returns {InheritedType}
	 */
	function derive(name, t) {
	    var r = new InheritedType(name);
	    t.forEach(function (x) { return r.addSuper(x); });
	    if (r.isSubTypeOf(exports.NULL)) {
	        r.nullable = true;
	    }
	    return r;
	}
	exports.derive = derive;
	/**
	 * this function allows you to quickly derive a new type from object;
	 * @param name
	 * @returns {InheritedType}
	 */
	function deriveObjectType(name) {
	    return derive(name, [exports.OBJECT]);
	}
	exports.deriveObjectType = deriveObjectType;
	function select(obj, t0, t1) {
	    if (t0.isScalar() && t1.isScalar()) {
	        if (t0.allSubTypes().indexOf(t1) != -1) {
	            return t0;
	        }
	        if (t1.allSubTypes().indexOf(t0) != -1) {
	            return t1;
	        }
	    }
	    var d0 = t0.oneMeta(metaInfo.Discriminator);
	    var d1 = t1.oneMeta(metaInfo.Discriminator);
	    if (d0 && d1) {
	        if (d0.property === d1.property) {
	            var v0 = t0.descValue();
	            var v1 = t1.descValue();
	            if (v0 !== v1) {
	                var val = obj[d0.property];
	                if (val === v0) {
	                    return t0;
	                }
	                if (val === v1) {
	                    return t1;
	                }
	            }
	        }
	    }
	    return null;
	}
	var NothingRestriction = (function (_super) {
	    __extends(NothingRestriction, _super);
	    function NothingRestriction() {
	        _super.apply(this, arguments);
	    }
	    NothingRestriction.prototype.check = function (i) {
	        if (i === null || i === undefined) {
	            return ok();
	        }
	        return error("nothing ", this);
	    };
	    NothingRestriction.prototype.requiredType = function () {
	        return exports.ANY;
	    };
	    NothingRestriction.prototype.facetName = function () {
	        return "nothing";
	    };
	    NothingRestriction.prototype.value = function () {
	        return "!!!";
	    };
	    return NothingRestriction;
	}(Constraint));
	exports.NothingRestriction = NothingRestriction;
	var RestrictionStackEntry = (function () {
	    function RestrictionStackEntry(_previous, _restriction, id) {
	        this._previous = _previous;
	        this._restriction = _restriction;
	        this.id = id;
	    }
	    RestrictionStackEntry.prototype.getRestriction = function () { return this._restriction; };
	    RestrictionStackEntry.prototype.pop = function () { return this._previous; };
	    RestrictionStackEntry.prototype.push = function (r) {
	        return new RestrictionStackEntry(this, r, r.toString());
	    };
	    return RestrictionStackEntry;
	}());
	exports.RestrictionStackEntry = RestrictionStackEntry;
	var NothingRestrictionWithLocation = (function (_super) {
	    __extends(NothingRestrictionWithLocation, _super);
	    function NothingRestrictionWithLocation(_entry, _message, _another) {
	        _super.call(this);
	        this._entry = _entry;
	        this._message = _message;
	        this._another = _another;
	    }
	    NothingRestrictionWithLocation.prototype.getMessage = function () { return this._message; };
	    NothingRestrictionWithLocation.prototype.getStack = function () { return this._entry; };
	    NothingRestrictionWithLocation.prototype.another = function () { return this._another; };
	    return NothingRestrictionWithLocation;
	}(NothingRestriction));
	exports.NothingRestrictionWithLocation = NothingRestrictionWithLocation;
	var GenericTypeOf = (function (_super) {
	    __extends(GenericTypeOf, _super);
	    function GenericTypeOf() {
	        _super.apply(this, arguments);
	    }
	    return GenericTypeOf;
	}(Constraint));
	exports.GenericTypeOf = GenericTypeOf;
	var TypeOfRestriction = (function (_super) {
	    __extends(TypeOfRestriction, _super);
	    function TypeOfRestriction(val) {
	        _super.call(this);
	        this.val = val;
	    }
	    TypeOfRestriction.prototype.check = function (i) {
	        var to = typeof i;
	        if (i === null || i === undefined) {
	            return ok();
	        }
	        if (Array.isArray(i)) {
	            to = "array";
	        }
	        if (to === this.val) {
	            return ok();
	        }
	        return error(this.val + " is expected", this);
	    };
	    TypeOfRestriction.prototype.value = function () {
	        return this.val;
	    };
	    TypeOfRestriction.prototype.requiredType = function () {
	        return exports.ANY;
	    };
	    TypeOfRestriction.prototype.facetName = function () {
	        return "typeOf";
	    };
	    TypeOfRestriction.prototype.composeWith = function (r) {
	        if (r instanceof TypeOfRestriction) {
	            var to = r;
	            if (to.val == this.val) {
	                return this;
	            }
	            return this.nothing(r);
	        }
	        return null;
	    };
	    TypeOfRestriction.prototype.toString = function () {
	        return "should be of type " + this.val;
	    };
	    return TypeOfRestriction;
	}(GenericTypeOf));
	exports.TypeOfRestriction = TypeOfRestriction;
	function is_int(value) {
	    if ((parseFloat(value) == parseInt(value)) && !isNaN(value)) {
	        return true;
	    }
	    else {
	        return false;
	    }
	}
	var IntegerRestriction = (function (_super) {
	    __extends(IntegerRestriction, _super);
	    function IntegerRestriction() {
	        _super.call(this);
	    }
	    IntegerRestriction.prototype.check = function (i) {
	        if (typeof i == "number" && is_int(i)) {
	            return ok();
	        }
	        return error("integer is expected", this);
	    };
	    IntegerRestriction.prototype.requiredType = function () {
	        return exports.ANY;
	    };
	    IntegerRestriction.prototype.value = function () {
	        return true;
	    };
	    IntegerRestriction.prototype.facetName = function () {
	        return "should be integer";
	    };
	    return IntegerRestriction;
	}(GenericTypeOf));
	exports.IntegerRestriction = IntegerRestriction;
	var NullRestriction = (function (_super) {
	    __extends(NullRestriction, _super);
	    function NullRestriction() {
	        _super.call(this);
	    }
	    NullRestriction.prototype.check = function (i) {
	        if (i === null || i == undefined || i === "null") {
	            return ok();
	        }
	        return error("null is expected", this);
	    };
	    NullRestriction.prototype.requiredType = function () {
	        return exports.ANY;
	    };
	    NullRestriction.prototype.value = function () {
	        return true;
	    };
	    NullRestriction.prototype.facetName = function () {
	        return "should be null";
	    };
	    return NullRestriction;
	}(GenericTypeOf));
	exports.NullRestriction = NullRestriction;
	var ScalarRestriction = (function (_super) {
	    __extends(ScalarRestriction, _super);
	    function ScalarRestriction() {
	        _super.call(this);
	    }
	    ScalarRestriction.prototype.check = function (i) {
	        if (!i) {
	            return ok();
	        }
	        if (typeof i === 'number' || typeof i === 'boolean' || typeof i === 'string') {
	            return ok();
	        }
	        return error("scalar is expected", this);
	    };
	    ScalarRestriction.prototype.requiredType = function () {
	        return exports.ANY;
	    };
	    ScalarRestriction.prototype.facetName = function () {
	        return "should be scalar";
	    };
	    ScalarRestriction.prototype.value = function () {
	        return true;
	    };
	    return ScalarRestriction;
	}(GenericTypeOf));
	exports.ScalarRestriction = ScalarRestriction;
	var OrRestriction = (function (_super) {
	    __extends(OrRestriction, _super);
	    function OrRestriction(val, _extraMessage) {
	        _super.call(this);
	        this.val = val;
	        this._extraMessage = _extraMessage;
	    }
	    OrRestriction.prototype.check = function (i, p) {
	        var cs = new Status(Status.OK, 0, "", this);
	        var first = null;
	        for (var j = 0; j < this.val.length; j++) {
	            var m = this.val[j].check(i, p);
	            if (m.isOk()) {
	                return ok();
	            }
	            if (!first) {
	                first = m;
	            }
	            ;
	        }
	        if (first) {
	            cs.addSubStatus(first);
	            if (this._extraMessage) {
	                cs.addSubStatus(error(this._extraMessage, this));
	            }
	        }
	        return cs;
	    };
	    OrRestriction.prototype.value = function () {
	        return this.val.map(function (x) { return x.value(); });
	    };
	    OrRestriction.prototype.requiredType = function () {
	        return exports.ANY;
	    };
	    OrRestriction.prototype.facetName = function () {
	        return "or";
	    };
	    return OrRestriction;
	}(Constraint));
	exports.OrRestriction = OrRestriction;
	var AndRestriction = (function (_super) {
	    __extends(AndRestriction, _super);
	    function AndRestriction(val) {
	        _super.call(this);
	        this.val = val;
	    }
	    AndRestriction.prototype.value = function () {
	        return this.val.map(function (x) { return x.value(); });
	    };
	    AndRestriction.prototype.options = function () {
	        return this.val;
	    };
	    AndRestriction.prototype.check = function (i, p) {
	        for (var j = 0; j < this.val.length; j++) {
	            var st = this.val[j].check(i, p);
	            if (!st.isOk()) {
	                return st;
	            }
	        }
	        return ok();
	    };
	    AndRestriction.prototype.requiredType = function () {
	        return exports.ANY;
	    };
	    AndRestriction.prototype.facetName = function () {
	        return "and";
	    };
	    return AndRestriction;
	}(Constraint));
	exports.AndRestriction = AndRestriction;
	/***
	 *
	 * lets declare built in types
	 */
	exports.ANY = new RootType("any");
	exports.SCALAR = exports.ANY.inherit("scalar");
	exports.OBJECT = exports.ANY.inherit("object");
	//export const POLYMORPHIC=OBJECT.inherit("polymorphic");
	exports.ARRAY = exports.ANY.inherit("array");
	exports.NULL = exports.ANY.inherit("null");
	exports.EXTERNAL = exports.ANY.inherit("external");
	exports.NUMBER = exports.SCALAR.inherit("number");
	exports.INTEGER = exports.NUMBER.inherit("integer");
	exports.BOOLEAN = exports.SCALAR.inherit("boolean");
	exports.STRING = exports.SCALAR.inherit("string");
	//export const DATE=SCALAR.inherit("date");
	exports.DATE_ONLY = exports.SCALAR.inherit("date-only");
	exports.TIME_ONLY = exports.SCALAR.inherit("time-only");
	exports.DATETIME_ONLY = exports.SCALAR.inherit("datetime-only");
	exports.DATETIME = exports.SCALAR.inherit("datetime");
	exports.FILE = exports.SCALAR.inherit("file");
	exports.NOTHING = new RootType("nothing");
	exports.UNION = exports.ANY.inherit("union");
	exports.UNKNOWN = exports.NOTHING.inherit("unknown");
	exports.RECURRENT = exports.NOTHING.inherit("recurrent");
	///
	//POLYMORPHIC.addMeta(new Polymorphic())
	exports.ANY.addMeta(BUILT_IN);
	exports.NULL.addMeta(BUILT_IN);
	exports.UNION.addMeta(BUILT_IN);
	exports.SCALAR.addMeta(BUILT_IN);
	exports.OBJECT.addMeta(BUILT_IN);
	exports.ARRAY.addMeta(BUILT_IN);
	exports.NUMBER.addMeta(BUILT_IN);
	exports.INTEGER.addMeta(BUILT_IN);
	exports.BOOLEAN.addMeta(BUILT_IN);
	exports.STRING.addMeta(BUILT_IN);
	exports.EXTERNAL.addMeta(BUILT_IN);
	exports.UNKNOWN.addMeta(BUILT_IN);
	exports.RECURRENT.addMeta(BUILT_IN);
	exports.DATE_ONLY.addMeta(BUILT_IN);
	exports.TIME_ONLY.addMeta(BUILT_IN);
	exports.DATETIME_ONLY.addMeta(BUILT_IN);
	exports.DATETIME.addMeta(BUILT_IN);
	exports.FILE.addMeta(BUILT_IN);
	//POLYMORPHIC.addMeta(BUILT_IN);
	exports.UNKNOWN.addMeta(BUILT_IN);
	exports.UNKNOWN.lock();
	exports.RECURRENT.addMeta(BUILT_IN);
	exports.RECURRENT.lock();
	exports.EXTERNAL.lock();
	exports.UNION.lock();
	///lets register all types in registry
	registry.addType(exports.ANY);
	registry.addType(exports.SCALAR);
	registry.addType(exports.OBJECT);
	registry.addType(exports.ARRAY);
	registry.addType(exports.NUMBER);
	registry.addType(exports.INTEGER);
	registry.addType(exports.BOOLEAN);
	registry.addType(exports.NULL);
	registry.addType(exports.STRING);
	registry.addType(exports.DATE_ONLY);
	registry.addType(exports.TIME_ONLY);
	registry.addType(exports.DATETIME_ONLY);
	registry.addType(exports.DATETIME);
	registry.addType(exports.FILE);
	//registry.addType(POLYMORPHIC);
	exports.NOTHING.addMeta(new NothingRestriction());
	exports.NUMBER.addMeta(new TypeOfRestriction("number"));
	exports.NUMBER.addMeta(new metainfo_1.FacetDeclaration("format", exports.STRING, true));
	exports.BOOLEAN.addMeta(new TypeOfRestriction("boolean"));
	exports.OBJECT.addMeta(new TypeOfRestriction("object"));
	exports.ARRAY.addMeta(new TypeOfRestriction("array"));
	exports.STRING.addMeta(new TypeOfRestriction("string"));
	exports.INTEGER.addMeta(new IntegerRestriction());
	exports.NULL.addMeta(new NullRestriction());
	var dt = __webpack_require__(135);
	exports.DATE_ONLY.addMeta(new dt.DateOnlyR());
	exports.TIME_ONLY.addMeta(new dt.TimeOnlyR());
	exports.DATETIME_ONLY.addMeta(new dt.DateTimeOnlyR());
	exports.DATETIME.addMeta(new dt.DateTimeR());
	exports.FILE.addMeta(new TypeOfRestriction("string"));
	var arrayOfString = exports.ARRAY.inherit("");
	arrayOfString.addMeta(new restrictions_3.ComponentShouldBeOfType(exports.STRING));
	exports.FILE.addMeta(new metainfo_1.FacetDeclaration("fileTypes", arrayOfString, true));
	exports.FILE.addMeta(new metainfo_1.FacetDeclaration("minLength", exports.INTEGER, true));
	exports.FILE.addMeta(new metainfo_1.FacetDeclaration("maxLength", exports.INTEGER, true));
	exports.DATETIME.addMeta(new metainfo_1.FacetDeclaration("format", exports.STRING, true));
	exports.NULL.nullable = true;
	exports.SCALAR.addMeta(new ScalarRestriction());
	registry.types().forEach(function (x) { return x.lock(); });
	var ExternalType = (function (_super) {
	    __extends(ExternalType, _super);
	    function ExternalType(name, _content, json, provider) {
	        _super.call(this, name);
	        this._content = _content;
	        this.json = json;
	        this.provider = provider;
	        this.addMeta(new restr.MatchToSchema(_content, provider));
	        this.addSuper(exports.EXTERNAL);
	    }
	    ExternalType.prototype.getContentProvider = function () {
	        return this.provider;
	    };
	    ExternalType.prototype.setContentProvider = function (provider) {
	        this.provider = provider;
	    };
	    ExternalType.prototype.kind = function () {
	        return "external";
	    };
	    ExternalType.prototype.isJSON = function () {
	        return this.json;
	    };
	    ExternalType.prototype.schema = function () {
	        return this._content;
	    };
	    return ExternalType;
	}(InheritedType));
	exports.ExternalType = ExternalType;
	//# sourceMappingURL=typesystem.js.map

/***/ },
/* 91 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	exports.REPEAT = "repeat";
	exports.PARSE_ERROR = "parseError";
	exports.TOP_LEVEL_EXTRA = "topLevel";
	exports.DEFINED_IN_TYPES_EXTRA = "definedInTypes";
	exports.USER_DEFINED_EXTRA = "USER_DEFINED";
	exports.SOURCE_EXTRA = "SOURCE";
	exports.SCHEMA_AND_TYPE_EXTRA = "SCHEMA";
	exports.GLOBAL_EXTRA = "GLOBAL";
	exports.HAS_FACETS = "HAS_FACETS";
	exports.HAS_ITEMS = "HAS_ITEMS";
	//# sourceMappingURL=typesystem-interfaces.js.map

/***/ },
/* 92 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var __extends = (this && this.__extends) || function (d, b) {
	    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
	    function __() { this.constructor = d; }
	    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
	};
	var ts = __webpack_require__(90);
	var tsInterfaces = __webpack_require__(91);
	var rs = __webpack_require__(94);
	var typesystem_1 = __webpack_require__(90);
	var typeExpressions = __webpack_require__(136);
	var facetR = __webpack_require__(93);
	var meta = __webpack_require__(95);
	var metainfo_1 = __webpack_require__(95);
	var metainfo_2 = __webpack_require__(95);
	var typesystem_2 = __webpack_require__(90);
	var restrictions_1 = __webpack_require__(94);
	var restrictions_2 = __webpack_require__(94);
	(function (NodeKind) {
	    NodeKind[NodeKind["SCALAR"] = 0] = "SCALAR";
	    NodeKind[NodeKind["ARRAY"] = 1] = "ARRAY";
	    NodeKind[NodeKind["MAP"] = 2] = "MAP";
	})(exports.NodeKind || (exports.NodeKind = {}));
	var NodeKind = exports.NodeKind;
	var JSObjectNode = (function () {
	    function JSObjectNode(_key, obj, inArr, provider) {
	        if (inArr === void 0) { inArr = false; }
	        this._key = _key;
	        this.obj = obj;
	        this.inArr = inArr;
	        this.provider = provider;
	    }
	    JSObjectNode.prototype.value = function () {
	        return this.obj;
	    };
	    JSObjectNode.prototype.key = function () {
	        if (!this._key) {
	            if (this.kind() === NodeKind.MAP && this.inArr) {
	                var l = Object.keys(this.obj);
	                if (l.length === 1) {
	                    return l[0];
	                }
	            }
	        }
	        return this._key;
	    };
	    JSObjectNode.prototype.childWithKey = function (k) {
	        if (this.obj == null) {
	            return null;
	        }
	        if (this.obj.hasOwnProperty(k)) {
	            return new JSObjectNode(k, this.obj[k], false, this.contentProvider());
	        }
	        return null;
	    };
	    JSObjectNode.prototype.children = function () {
	        var _this = this;
	        if (Array.isArray(this.obj)) {
	            return this.obj.map(function (x) { return new JSObjectNode(null, x, true, _this.contentProvider()); });
	        }
	        else if (this.obj && typeof this.obj == "object") {
	            return Object.keys(this.obj).map(function (x) { return new JSObjectNode(x, _this.obj[x], false, _this.provider); });
	        }
	        return [];
	    };
	    JSObjectNode.prototype.kind = function () {
	        if (!this.obj) {
	            return NodeKind.SCALAR;
	        }
	        if (Array.isArray(this.obj)) {
	            return NodeKind.ARRAY;
	        }
	        else if (typeof this.obj === "object") {
	            return NodeKind.MAP;
	        }
	        return NodeKind.SCALAR;
	    };
	    JSObjectNode.prototype.contentProvider = function () {
	        return this.provider;
	    };
	    ;
	    return JSObjectNode;
	}());
	function parseJSON(name, n, r, provider) {
	    if (r === void 0) { r = ts.builtInRegistry(); }
	    return parse(name, new JSObjectNode(null, n, false, provider), r);
	}
	exports.parseJSON = parseJSON;
	function parseJSONTypeCollection(n, r, provider) {
	    if (r === void 0) { r = ts.builtInRegistry(); }
	    return parseTypeCollection(new JSObjectNode(null, n, false, provider), r);
	}
	exports.parseJSONTypeCollection = parseJSONTypeCollection;
	function isOptional(p) {
	    return p.charAt(p.length - 1) == '?';
	}
	var PropertyBean = (function () {
	    function PropertyBean() {
	    }
	    PropertyBean.prototype.add = function (t) {
	        if (!this.optional && !this.additonal && !this.regExp) {
	            t.addMeta(new rs.HasProperty(this.id));
	        }
	        if (this.additonal) {
	            t.addMeta(new rs.AdditionalPropertyIs(this.type));
	        }
	        else if (this.regExp) {
	            t.addMeta(new rs.MapPropertyIs(this.id, this.type));
	        }
	        else {
	            t.addMeta(new rs.PropertyIs(this.id, this.type));
	        }
	    };
	    return PropertyBean;
	}());
	exports.PropertyBean = PropertyBean;
	var TypeCollection = (function () {
	    function TypeCollection() {
	        this._types = [];
	        this._typeMap = {};
	        this.uses = {};
	        this._annotationTypes = [];
	        this._annotationTypeMap = {};
	    }
	    TypeCollection.prototype.library = function (n) {
	        return this.uses[n];
	    };
	    TypeCollection.prototype.addLibrary = function (n, t) {
	        this.uses[n] = t;
	    };
	    TypeCollection.prototype.add = function (t) {
	        this._types.push(t);
	        this._typeMap[t.name()] = t;
	    };
	    TypeCollection.prototype.getType = function (name) {
	        if (this._typeMap.hasOwnProperty(name)) {
	            return this._typeMap[name];
	        }
	        return null;
	    };
	    TypeCollection.prototype.addAnnotationType = function (t) {
	        this._annotationTypes.push(t);
	        this._annotationTypeMap[t.name()] = t;
	    };
	    TypeCollection.prototype.getAnnotationType = function (name) {
	        if (this._annotationTypeMap.hasOwnProperty(name)) {
	            return this._annotationTypeMap[name];
	        }
	        return null;
	    };
	    TypeCollection.prototype.types = function () {
	        return this._types;
	    };
	    TypeCollection.prototype.annotationTypes = function () {
	        return this._annotationTypes;
	    };
	    TypeCollection.prototype.getAnnotationTypeRegistry = function () {
	        var _this = this;
	        var r = new typesystem_2.TypeRegistry(ts.builtInRegistry());
	        this.annotationTypes().forEach(function (x) { return r.addType(x); });
	        Object.keys(this.uses).forEach(function (x) {
	            _this.uses[x].annotationTypes().forEach(function (y) { return r.put(x + "." + y.name(), y); });
	        });
	        return r;
	    };
	    TypeCollection.prototype.getTypeRegistry = function () {
	        var _this = this;
	        var r = new typesystem_2.TypeRegistry(ts.builtInRegistry());
	        this.types().forEach(function (x) { return r.addType(x); });
	        Object.keys(this.uses).forEach(function (x) {
	            _this.uses[x].types().forEach(function (y) { return r.put(x + "." + y.name(), y); });
	        });
	        return r;
	    };
	    return TypeCollection;
	}());
	exports.TypeCollection = TypeCollection;
	var AccumulatingRegistry = (function (_super) {
	    __extends(AccumulatingRegistry, _super);
	    function AccumulatingRegistry(toParse, schemas, ts, _c) {
	        _super.call(this, ts);
	        this.toParse = toParse;
	        this.schemas = schemas;
	        this._c = _c;
	        this.parsing = {};
	    }
	    AccumulatingRegistry.prototype.get = function (name) {
	        var result = _super.prototype.get.call(this, name);
	        if (!result) {
	            var chld = this.toParse ? this.toParse.childWithKey(name) : null;
	            if (!chld) {
	                chld = this.schemas ? this.schemas.childWithKey(name) : null;
	            }
	            if (chld) {
	                if (this.parsing[name]) {
	                    return ts.derive(name, [ts.RECURRENT]);
	                }
	                this.parsing[name] = true;
	                try {
	                    var tp = parse(name, chld, this);
	                }
	                finally {
	                    delete this.parsing[name];
	                }
	                return tp;
	            }
	            else {
	                var dt = name.indexOf('.');
	                if (dt != -1) {
	                    var ln = name.substring(0, dt);
	                    var tn = name.substr(dt + 1);
	                    var lib = this._c.library(ln);
	                    if (lib) {
	                        var t = lib.getType(tn);
	                        if (t) {
	                            return t;
	                        }
	                    }
	                }
	            }
	        }
	        return result;
	    };
	    return AccumulatingRegistry;
	}(ts.TypeRegistry));
	exports.AccumulatingRegistry = AccumulatingRegistry;
	function parseTypes(n, tr) {
	    if (tr === void 0) { tr = ts.builtInRegistry(); }
	    var provider = n.provider && n.provider();
	    return parseTypeCollection(new JSObjectNode(null, n, false, provider), tr);
	}
	exports.parseTypes = parseTypes;
	var WrapArrayNode = (function () {
	    function WrapArrayNode(n) {
	        this.n = n;
	    }
	    WrapArrayNode.prototype.key = function () {
	        return null;
	    };
	    WrapArrayNode.prototype.value = function () {
	        return null;
	    };
	    WrapArrayNode.prototype.childWithKey = function (k) {
	        var r = this.children();
	        for (var i = 0; i < r.length; i++) {
	            if (r[i].key() == k) {
	                return r[i];
	            }
	        }
	        return null;
	    };
	    WrapArrayNode.prototype.children = function () {
	        return this.n.children().map(function (x) {
	            var c = x.children();
	            if (c.length == 1) {
	                return c[0];
	            }
	            return x;
	        });
	    };
	    WrapArrayNode.prototype.kind = function () {
	        return NodeKind.MAP;
	    };
	    return WrapArrayNode;
	}());
	function transformToArray(n) {
	    return new WrapArrayNode(n);
	}
	function parseTypeCollection(n, tr) {
	    var result = new TypeCollection();
	    if (n.anchor) {
	        if (n.anchor().__$$) {
	            return n.anchor().__$$;
	        }
	        n.anchor().__$$ = result;
	    }
	    var uses = n.childWithKey("uses");
	    if (uses && uses.kind() === NodeKind.ARRAY) {
	        uses = transformToArray(uses);
	    }
	    if (uses && uses.kind() === NodeKind.MAP) {
	        uses.children().forEach(function (c) {
	            result.addLibrary(c.key(), parseTypeCollection(c, tr));
	        });
	    }
	    var tpes = n.childWithKey("types");
	    if (tpes && tpes.kind() === NodeKind.ARRAY) {
	        tpes = transformToArray(tpes);
	    }
	    var schemas = n.childWithKey("schemas");
	    if (schemas && schemas.kind() === NodeKind.ARRAY) {
	        schemas = transformToArray(schemas);
	    }
	    var reg = new AccumulatingRegistry(tpes, schemas, tr, result);
	    if (tpes && tpes.kind() !== NodeKind.SCALAR) {
	        tpes.children().forEach(function (x) {
	            reg.get(x.key());
	        });
	    }
	    if (schemas && schemas.kind() !== NodeKind.SCALAR) {
	        schemas.children().forEach(function (x) {
	            reg.get(x.key());
	        });
	    }
	    reg.types().forEach(function (x) { return result.add(x); });
	    var tpes = n.childWithKey("annotationTypes");
	    if (tpes && tpes.kind() === NodeKind.ARRAY) {
	        tpes = transformToArray(tpes);
	    }
	    if (tpes != null && tpes.kind() === NodeKind.MAP) {
	        tpes.children().forEach(function (x) {
	            result.addAnnotationType(parse(x.key(), x, reg, false, true, false));
	        });
	    }
	    return result;
	}
	exports.parseTypeCollection = parseTypeCollection;
	function parsePropertyBean(n, tr) {
	    var result = new PropertyBean();
	    var name = n.key();
	    if (isOptional(n.key())) {
	        name = name.substr(0, name.length - 1);
	        result.optional = true;
	    }
	    if (name === '[]' || name.length == 0 || name === '//') {
	        result.additonal = true;
	    }
	    else if (name.charAt(0) == '[' && name.charAt(name.length - 1) == ']') {
	        name = name.substring(1, name.length - 1);
	        result.regExp = true;
	    }
	    else if (name.charAt(0) == '/' && name.charAt(name.length - 1) == '/') {
	        name = name.substring(1, name.length - 1);
	        result.regExp = true;
	    }
	    result.type = parse(null, n, tr, false, false, false);
	    result.id = name;
	    var rs = n.childWithKey("required");
	    if (rs) {
	        if (rs.value() == false) {
	            result.optional = true;
	            result.id = n.key();
	        }
	    }
	    return result;
	}
	exports.parsePropertyBean = parsePropertyBean;
	var TypeProto = (function () {
	    function TypeProto() {
	    }
	    TypeProto.prototype.toJSON = function () {
	        var result = {};
	        if (this.superTypes && this.superTypes.length > 0) {
	            if (this.superTypes.length == 1) {
	                result['type'] = this.superTypes[0];
	            }
	            else {
	                result['type'] = this.superTypes;
	            }
	        }
	        if (this.customFacets) {
	            this.customFacets.forEach(function (x) { return result[x.facetName()] = x.value(); });
	        }
	        if (this.annotations) {
	            this.annotations.forEach(function (x) { return result["(" + x.facetName() + ")"] = x.value(); });
	        }
	        if (this.facetDeclarations && this.facetDeclarations.length > 0) {
	            var facets = {};
	            this.facetDeclarations.forEach(function (x) {
	                var nm = x.facetName();
	                if (x.isOptional()) {
	                    nm = nm + "?";
	                }
	                var vl = null;
	                if (x.type().isAnonymous()) {
	                    if (x.type().isEmpty()) {
	                        vl = typeToSignature(x.type());
	                    }
	                    else {
	                        vl = toProto(x.type()).toJSON();
	                    }
	                }
	                else {
	                    vl = typeToSignature(x.type());
	                }
	                facets[nm] = vl;
	            });
	            result['facets'] = facets;
	        }
	        if (this.properties && this.properties.length > 0) {
	            var properties = {};
	            this.properties.forEach(function (x) {
	                var nm = x.id;
	                if (x.optional) {
	                    nm = nm + "?";
	                }
	                if (x.additonal) {
	                    nm = "[]";
	                }
	                if (x.regExp) {
	                    nm = "[" + nm + "]";
	                }
	                var vl = null;
	                if (x.type.isAnonymous()) {
	                    if (x.type.isEmpty()) {
	                        vl = typeToSignature(x.type);
	                    }
	                    else {
	                        vl = toProto(x.type).toJSON();
	                    }
	                }
	                else {
	                    vl = typeToSignature(x.type);
	                }
	                properties[nm] = vl;
	            });
	            result['properties'] = properties;
	        }
	        if (this.basicFacets) {
	            this.basicFacets.forEach(function (x) {
	                result[x.facetName()] = x.value();
	            });
	        }
	        if (Object.keys(result).length == 1 && !this.notAScalar) {
	            if (result['type']) {
	                return result['type'];
	            }
	        }
	        return result;
	    };
	    return TypeProto;
	}());
	exports.TypeProto = TypeProto;
	function toProto(type) {
	    var result = new TypeProto();
	    result.name = type.name();
	    result.superTypes = type.superTypes().map(function (x) { return typeToSignature(x); });
	    result.annotations = [];
	    result.customFacets = [];
	    result.facetDeclarations = [];
	    result.basicFacets = [];
	    result.properties = [];
	    var pmap = {};
	    type.declaredMeta().forEach(function (x) {
	        if (x instanceof meta.Annotation) {
	            result.annotations.push(x);
	        }
	        else if (x instanceof meta.CustomFacet) {
	            result.customFacets.push(x);
	        }
	        else if (x instanceof meta.NotScalar) {
	            result.notAScalar = true;
	        }
	        else if (x instanceof metainfo_2.FacetDeclaration) {
	            result.facetDeclarations.push(x);
	        }
	        else {
	            if (x instanceof rs.HasProperty) {
	                if (pmap.hasOwnProperty(x.value())) {
	                    pmap[x.value()].optional = false;
	                }
	                else {
	                    var pbean = new PropertyBean();
	                    pbean.optional = false;
	                    pbean.id = x.value();
	                    pbean.type = ts.ANY;
	                    pmap[x.value()] = pbean;
	                }
	            }
	            else if (x instanceof rs.AdditionalPropertyIs) {
	                var pbean = new PropertyBean();
	                pbean.optional = false;
	                pbean.id = "[]";
	                pbean.additonal = true;
	                pbean.type = x.value();
	                pmap['[]'] = pbean;
	            }
	            else if (x instanceof rs.MapPropertyIs) {
	                var pbean = new PropertyBean();
	                pbean.optional = false;
	                pbean.id = x.regexpValue();
	                pbean.regExp = true;
	                pbean.type = x.value();
	                pmap[x.regexpValue()] = pbean;
	            }
	            else if (x instanceof rs.PropertyIs) {
	                if (pmap.hasOwnProperty(x.propertyName())) {
	                    pmap[x.propertyName()].type = x.value();
	                }
	                else {
	                    var pbean = new PropertyBean();
	                    pbean.optional = true;
	                    pbean.id = x.propertyName();
	                    pbean.type = x.value();
	                    pmap[x.propertyName()] = pbean;
	                }
	            }
	            else {
	                if (!(x instanceof rs.KnownPropertyRestriction)) {
	                    result.basicFacets.push(x);
	                }
	            }
	        }
	    });
	    Object.keys(pmap).forEach(function (x) { return result.properties.push(pmap[x]); });
	    return result;
	}
	exports.toProto = toProto;
	/***
	 * stores a type to JSON structure
	 * @param ts
	 */
	function storeAsJSON(ts) {
	    if (ts instanceof typesystem_1.AbstractType) {
	        return toProto(ts).toJSON();
	    }
	    else {
	        return storeTypeCollection(ts);
	    }
	}
	exports.storeAsJSON = storeAsJSON;
	function storeTypeCollection(tc) {
	    var res = {};
	    var types = {};
	    tc.types().forEach(function (x) {
	        types[x.name()] = storeAsJSON(x);
	    });
	    if (Object.keys(types).length > 0) {
	        res["types"] = types;
	    }
	    var types = {};
	    tc.annotationTypes().forEach(function (x) {
	        types[x.name()] = storeAsJSON(x);
	    });
	    if (Object.keys(types).length > 0) {
	        res["annotationTypes"] = types;
	    }
	    return res;
	}
	function typeToSignature(t) {
	    if (t.isAnonymous()) {
	        if (t.isArray()) {
	            var ci = t.oneMeta(rs.ComponentShouldBeOfType);
	            if (ci) {
	                var vl = ci.value();
	                if (vl.isAnonymous() && vl.isUnion()) {
	                    return "(" + typeToSignature(vl) + ")" + "[]";
	                }
	                return typeToSignature(vl) + "[]";
	            }
	        }
	        if (t.isUnion()) {
	            return t.options().map(function (x) { return typeToSignature(x); }).join(" | ");
	        }
	        return t.superTypes().map(function (x) { return typeToSignature(x); }).join(" , ");
	    }
	    return t.name();
	}
	/**
	 * parses a type from a JSON structure
	 * @param name
	 * @param n
	 * @param r
	 * @returns {any}
	 */
	function parse(name, n, r, defaultsToAny, annotation, global) {
	    //Build super types.
	    if (r === void 0) { r = ts.builtInRegistry(); }
	    if (defaultsToAny === void 0) { defaultsToAny = false; }
	    if (annotation === void 0) { annotation = false; }
	    if (global === void 0) { global = true; }
	    var provider = n.contentProvider ? n.contentProvider() : null;
	    if (n.kind() == NodeKind.SCALAR) {
	        var sp = n.value() ? typeExpressions.parseToType("" + n.value(), r, provider) : ts.STRING;
	        if (name == null) {
	            return sp;
	        }
	        var res = ts.derive(name, [sp]);
	        if (r instanceof AccumulatingRegistry) {
	            r.addType(res);
	            res.putExtra(tsInterfaces.TOP_LEVEL_EXTRA, true);
	        }
	        return res;
	    }
	    if (n.kind() == NodeKind.ARRAY) {
	        var supers = [];
	        n.children().forEach(function (x) {
	            supers.push(typeExpressions.parseToType("" + x.value(), r, provider));
	        });
	        var res = ts.derive(name, supers);
	        if (r instanceof AccumulatingRegistry) {
	            r.addType(res);
	            res.putExtra(tsInterfaces.TOP_LEVEL_EXTRA, true);
	        }
	        return res;
	    }
	    var superTypes = [];
	    var tp = n.childWithKey("type");
	    var shAndType = false;
	    if (!tp) {
	        tp = n.childWithKey("schema");
	    }
	    else {
	        if (n.childWithKey("schema")) {
	            shAndType = true;
	        }
	    }
	    if (!tp) {
	        if (defaultsToAny) {
	            if (n.childWithKey("properties")) {
	                superTypes = [ts.OBJECT];
	            }
	            else {
	                superTypes = [ts.ANY];
	            }
	        }
	        else {
	            if (n.childWithKey("properties")) {
	                superTypes = [ts.OBJECT];
	            }
	            else {
	                superTypes = [ts.STRING];
	            }
	        }
	    }
	    else {
	        if (tp.kind() == NodeKind.SCALAR) {
	            superTypes = [typeExpressions.parseToType("" + tp.value(), r, provider)];
	        }
	        else if (tp.kind() == NodeKind.ARRAY) {
	            superTypes = tp.children().map(function (x) { return x.value(); }).map(function (y) { return typeExpressions.parseToType("" + y, r, provider); });
	        }
	        else if (tp.kind() == NodeKind.MAP) {
	            superTypes = [parse("", tp, r, false, false, false)];
	        }
	    }
	    var result = ts.derive(name, superTypes);
	    var actualResult = result;
	    var repeat = n.childWithKey("repeat");
	    if (repeat && repeat.value() == true) {
	        actualResult = ts.derive(name, [ts.ARRAY]);
	        actualResult.putExtra(tsInterfaces.REPEAT, true);
	        actualResult.addMeta(new restrictions_1.ComponentShouldBeOfType(result));
	    }
	    if (r instanceof AccumulatingRegistry) {
	        r.addType(actualResult);
	        actualResult.putExtra(tsInterfaces.TOP_LEVEL_EXTRA, true);
	    }
	    var hasfacetsOrOtherStuffDoesNotAllowedInExternals = null;
	    n.children().forEach(function (x) {
	        var key = x.key();
	        if (!key) {
	            return;
	        }
	        if (key === "type") {
	            return;
	        }
	        if (key === "repeat") {
	            hasfacetsOrOtherStuffDoesNotAllowedInExternals = "repeat";
	            return;
	        }
	        if (key === "uses") {
	            //FIXME this should be handled depending from parse level
	            return;
	        }
	        if (key === "schema") {
	            return;
	        }
	        if (key == "properties" || key == "additionalProperties" || key == "patternProperties") {
	            if (result.isSubTypeOf(ts.OBJECT)) {
	                return;
	            }
	        }
	        if (key == "items") {
	            if (result.isSubTypeOf(ts.ARRAY)) {
	                var tp = parse(null, x, r, false, false, false);
	                actualResult.addMeta(new restrictions_1.ComponentShouldBeOfType(tp));
	                actualResult.putExtra(tsInterfaces.HAS_ITEMS, true);
	                return;
	            }
	        }
	        if (key === "facets") {
	            hasfacetsOrOtherStuffDoesNotAllowedInExternals = key;
	            return;
	        }
	        if (key == "default" || key == "xml" || key == "required") {
	            hasfacetsOrOtherStuffDoesNotAllowedInExternals = key;
	        }
	        if (key.charAt(0) == '(' && key.charAt(key.length - 1) == ')') {
	            result.addMeta(new meta.Annotation(key.substr(1, key.length - 2), x.value()));
	            return;
	        }
	        var vl = facetR.getInstance().buildFacet(key, x.value());
	        if (vl && result.isSubTypeOf(vl.requiredType())) {
	            result.addMeta(vl);
	        }
	        else {
	            if (annotation && key === "allowedTargets") {
	                result.addMeta(new meta.AllowedTargets(x.value()));
	            }
	            else {
	                result.addMeta(new meta.CustomFacet(key, x.value()));
	            }
	        }
	    });
	    if (result.isSubTypeOf(ts.OBJECT)) {
	        var props = n.childWithKey("properties");
	        var hasProps = false;
	        if (props) {
	            if (props.kind() == NodeKind.MAP) {
	                props.children().forEach(function (x) {
	                    hasProps = true;
	                    parsePropertyBean(x, r).add(result);
	                });
	            }
	            else {
	                var err = new ts.Status(ts.Status.ERROR, 2, "properties should be a map", actualResult);
	                err.setValidationPath({ name: "properties" });
	                result.putExtra(tsInterfaces.PARSE_ERROR, err);
	            }
	        }
	        var ap = n.childWithKey("additionalProperties");
	        if (ap) {
	            result.addMeta(new restrictions_2.KnownPropertyRestriction(ap.value()));
	        }
	        var props = n.childWithKey("patternProperties");
	        if (props) {
	            if (props.kind() == NodeKind.MAP) {
	                props.children().forEach(function (x) {
	                    var pb = parsePropertyBean(x, r);
	                    result.declareMapProperty(pb.id, pb.type);
	                });
	            }
	            else {
	                var err = new ts.Status(ts.Status.ERROR, 2, "pattern properties should be a map", actualResult);
	                err.setValidationPath({ name: "patternProperties" });
	                result.putExtra(tsInterfaces.PARSE_ERROR, err);
	            }
	        }
	    }
	    var props = n.childWithKey("facets");
	    if (props) {
	        if (props.kind() == NodeKind.MAP) {
	            props.children().forEach(function (x) {
	                var bean = parsePropertyBean(x, r);
	                result.addMeta(new meta.FacetDeclaration(bean.id, bean.type, bean.optional));
	            });
	        }
	        else {
	            var err = new ts.Status(ts.Status.ERROR, 2, "facets should be a map", actualResult);
	            err.setValidationPath({ name: "facets" });
	            result.putExtra(tsInterfaces.PARSE_ERROR, err);
	        }
	    }
	    if (result.isAnonymous() && result.isEmpty()) {
	        if (result.superTypes().length == 1) {
	            return result.superTypes()[0];
	        }
	    }
	    if (n.kind() != NodeKind.SCALAR) {
	        result.addMeta(new meta.NotScalar());
	    }
	    if (shAndType) {
	        actualResult.putExtra(ts.SCHEMA_AND_TYPE, true);
	    }
	    actualResult.putExtra(ts.GLOBAL, global);
	    actualResult.putExtra(ts.SOURCE_EXTRA, n);
	    actualResult.putExtra(tsInterfaces.HAS_FACETS, hasfacetsOrOtherStuffDoesNotAllowedInExternals);
	    if (repeat) {
	        result.meta().forEach(function (x) {
	            if (x instanceof metainfo_1.Example) {
	                actualResult.addMeta(x);
	            }
	            if (x instanceof metainfo_1.Examples) {
	                actualResult.addMeta(x);
	            }
	        });
	    }
	    return actualResult;
	}
	exports.parse = parse;
	//# sourceMappingURL=parse.js.map

/***/ },
/* 93 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var ts = __webpack_require__(90);
	var ms = __webpack_require__(95);
	var typesystem_1 = __webpack_require__(90);
	var restrictions_1 = __webpack_require__(94);
	var metainfo_1 = __webpack_require__(95);
	var metainfo_2 = __webpack_require__(95);
	var metainfo_3 = __webpack_require__(95);
	var metainfo_4 = __webpack_require__(95);
	var restrictions_2 = __webpack_require__(94);
	var FacetPrototype = (function () {
	    function FacetPrototype(_construct, _constructWithValue) {
	        this._construct = _construct;
	        this._constructWithValue = _constructWithValue;
	    }
	    FacetPrototype.prototype.isSimple = function () {
	        return this._constructWithValue != null;
	    };
	    FacetPrototype.prototype.newInstance = function () {
	        return this._construct();
	    };
	    FacetPrototype.prototype.createWithValue = function (v) {
	        return this._constructWithValue(v);
	    };
	    FacetPrototype.prototype.isApplicable = function (t) {
	        return t.isSubTypeOf(this.newInstance().requiredType());
	    };
	    FacetPrototype.prototype.isInheritable = function () {
	        return this.newInstance().isInheritable();
	    };
	    FacetPrototype.prototype.isConstraint = function () {
	        return this.newInstance() instanceof ts.Constraint;
	    };
	    FacetPrototype.prototype.isMeta = function () {
	        return !this.isConstraint();
	    };
	    FacetPrototype.prototype.name = function () {
	        return this.newInstance().facetName();
	    };
	    return FacetPrototype;
	}());
	exports.FacetPrototype = FacetPrototype;
	var Registry = (function () {
	    function Registry() {
	        var _this = this;
	        this.constraints = [
	            new FacetPrototype(function () { return new restrictions_1.MinProperties(1); }, function (x) { return new restrictions_1.MinProperties(x); }),
	            new FacetPrototype(function () { return new restrictions_1.MaxProperties(1); }, function (x) { return new restrictions_1.MaxProperties(x); }),
	            new FacetPrototype(function () { return new restrictions_1.MinItems(1); }, function (x) { return new restrictions_1.MinItems(x); }),
	            new FacetPrototype(function () { return new restrictions_1.MaxItems(1); }, function (x) { return new restrictions_1.MaxItems(x); }),
	            new FacetPrototype(function () { return new restrictions_1.MinLength(1); }, function (x) { return new restrictions_1.MinLength(x); }),
	            new FacetPrototype(function () { return new restrictions_1.MaxLength(1); }, function (x) { return new restrictions_1.MaxLength(x); }),
	            new FacetPrototype(function () { return new restrictions_1.Minimum(1); }, function (x) { return new restrictions_1.Minimum(x); }),
	            new FacetPrototype(function () { return new restrictions_2.MultipleOf(1); }, function (x) { return new restrictions_2.MultipleOf(x); }),
	            new FacetPrototype(function () { return new restrictions_1.Maximum(1); }, function (x) { return new restrictions_1.Maximum(x); }),
	            new FacetPrototype(function () { return new restrictions_1.Enum([""]); }, function (x) { return new restrictions_1.Enum(x); }),
	            new FacetPrototype(function () { return new restrictions_1.Pattern("."); }, function (x) { return new restrictions_1.Pattern(x); }),
	            new FacetPrototype(function () { return new restrictions_1.PropertyIs("x", ts.ANY); }, null),
	            new FacetPrototype(function () { return new restrictions_1.AdditionalPropertyIs(ts.ANY); }, null),
	            new FacetPrototype(function () { return new restrictions_1.MapPropertyIs(".", ts.ANY); }, null),
	            new FacetPrototype(function () { return new restrictions_1.HasProperty("x"); }, null),
	            new FacetPrototype(function () { return new restrictions_1.UniqueItems(true); }, function (x) { return new restrictions_1.UniqueItems(x); }),
	            new FacetPrototype(function () { return new restrictions_1.ComponentShouldBeOfType(ts.ANY); }, null),
	            new FacetPrototype(function () { return new restrictions_1.KnownPropertyRestriction(true); }, function (x) { return new restrictions_1.KnownPropertyRestriction(x); })
	        ];
	        this.meta = [
	            new FacetPrototype(function () { return new ms.Discriminator("kind"); }, function (x) { return new ms.Discriminator(x); }),
	            new FacetPrototype(function () { return new ms.DiscriminatorValue("x"); }, function (x) { return new ms.DiscriminatorValue(x); }),
	            new FacetPrototype(function () { return new metainfo_1.Default(""); }, function (x) { return new metainfo_1.Default(x); }),
	            new FacetPrototype(function () { return new metainfo_4.Usage(""); }, function (x) { return new metainfo_4.Usage(x); }),
	            new FacetPrototype(function () { return new metainfo_1.Example(""); }, function (x) { return new metainfo_1.Example(x); }),
	            new FacetPrototype(function () { return new metainfo_3.Required(true); }, function (x) { return new metainfo_3.Required(x); }),
	            new FacetPrototype(function () { return new ms.Examples({}); }, function (x) { return new ms.Examples(x); }),
	            new FacetPrototype(function () { return new metainfo_1.Description(""); }, function (x) { return new metainfo_1.Description(x); }),
	            new FacetPrototype(function () { return new metainfo_1.DisplayName(""); }, function (x) { return new metainfo_1.DisplayName(x); }),
	            new FacetPrototype(function () { return new typesystem_1.Abstract(); }, function (x) { return new typesystem_1.Abstract(); }),
	            new FacetPrototype(function () { return new typesystem_1.Polymorphic(); }, function (x) { return new typesystem_1.Polymorphic(); }),
	            new FacetPrototype(function () { return new metainfo_2.XMLInfo({}); }, function (x) { return new metainfo_2.XMLInfo(x); }),
	        ];
	        this.known = {};
	        this.allPrototypes().forEach(function (x) { return _this.known[x.name()] = x; });
	    }
	    Registry.prototype.allPrototypes = function () {
	        return this.meta.concat(this.constraints);
	    };
	    Registry.prototype.buildFacet = function (n, value) {
	        if (this.known.hasOwnProperty(n) && this.known[n].isSimple()) {
	            return this.known[n].createWithValue(value);
	        }
	        return null;
	    };
	    Registry.prototype.facetPrototypeWithName = function (n) {
	        if (this.known.hasOwnProperty(n)) {
	            return this.known[n];
	        }
	        return null;
	    };
	    Registry.prototype.applyableTo = function (t) {
	        return this.allPrototypes().filter(function (x) { return x.isApplicable(t); });
	    };
	    Registry.prototype.allMeta = function () {
	        return this.allPrototypes().filter(function (x) { return x.isMeta(); });
	    };
	    return Registry;
	}());
	exports.Registry = Registry;
	var instance;
	function getInstance() {
	    if (instance) {
	        return instance;
	    }
	    instance = new Registry();
	    return instance;
	}
	exports.getInstance = getInstance;
	//# sourceMappingURL=facetRegistry.js.map

/***/ },
/* 94 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var __extends = (this && this.__extends) || function (d, b) {
	    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
	    function __() { this.constructor = d; }
	    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
	};
	/// <reference path="../typings/main.d.ts" />
	var ts = __webpack_require__(90);
	var su = __webpack_require__(99);
	var _ = __webpack_require__(177);
	var typesystem_1 = __webpack_require__(90);
	var typesystem_2 = __webpack_require__(90);
	/**
	 * this class is an abstract super type for every constraint that can select properties from objects
	 */
	var MatchesProperty = (function (_super) {
	    __extends(MatchesProperty, _super);
	    function MatchesProperty(_type) {
	        _super.call(this);
	        this._type = _type;
	    }
	    MatchesProperty.prototype.matches = function (s) {
	        return false;
	    };
	    MatchesProperty.prototype.check = function (i, p) {
	        throw new Error("Should be never called");
	    };
	    MatchesProperty.prototype.patchPath = function (p) {
	        if (!p) {
	            return { name: this.propId() };
	        }
	        else {
	            var c = p;
	            var r = null;
	            var cp = null;
	            while (c) {
	                if (!r) {
	                    r = { name: c.name };
	                    cp = r;
	                }
	                else {
	                    var news = { name: c.name };
	                    cp.child = news;
	                    c = c.child;
	                    cp = news;
	                }
	            }
	            r.child = { name: this.propId() };
	            return r;
	        }
	    };
	    MatchesProperty.prototype.validateProp = function (i, n, t, q) {
	        var vl = i[n];
	        if (vl !== null && vl !== undefined) {
	            var st = t.validate(vl, true, false);
	            if (!st.isOk()) {
	                if (t.isUnknown() || t.isRecurrent()) {
	                    var s = new typesystem_2.Status(typesystem_2.Status.ERROR, 0, "Validating instance against unknown type:" + t.name(), this);
	                    s.setValidationPath(this.patchPath(q));
	                    return s;
	                }
	                var s = new typesystem_2.Status(typesystem_2.Status.OK, 0, "", this);
	                st.getErrors().forEach(function (x) { return s.addSubStatus(x); });
	                s.setValidationPath(this.patchPath(q));
	                return s;
	            }
	        }
	        return ts.ok();
	    };
	    MatchesProperty.prototype.validateSelf = function (registry) {
	        if (this._type.isExternal()) {
	            var p = new typesystem_2.Status(typesystem_2.Status.ERROR, 0, "It is not allowed to use external types in property definitions", this);
	            p.setValidationPath({ name: this.propId() });
	            return p;
	        }
	        if (this._type.isSubTypeOf(ts.UNKNOWN) || this._type.isSubTypeOf(ts.RECURRENT)) {
	            var p = new typesystem_2.Status(typesystem_2.Status.ERROR, 0, "property " + this.propId() + " refers to unknown type " + this._type.name(), this);
	            p.setValidationPath({ name: this.propId(), child: { name: "type" } });
	            return p;
	        }
	        if (this._type.isAnonymous()) {
	            var st = this._type.validateType(registry);
	            if (!st.isOk()) {
	                var p = new typesystem_2.Status(typesystem_2.Status.ERROR, 0, "property " + this.propId() + " range type has error:" + st.getMessage(), this);
	                st.getErrors().forEach(function (y) { p.addSubStatus(y); });
	                p.setValidationPath({ name: this.propId() });
	                return p;
	            }
	            return st;
	        }
	        if (this._type.isUnion()) {
	            var ui = _.find(this._type.typeFamily(), function (x) { return x.isSubTypeOf(ts.UNKNOWN); });
	            if (ui) {
	                var p = new typesystem_2.Status(typesystem_2.Status.ERROR, 0, "property " + this.propId() + " refers to unknown type " + ui.name(), this);
	                p.setValidationPath({ name: this.propId() });
	                return p;
	            }
	        }
	        return ts.ok();
	    };
	    return MatchesProperty;
	}(ts.Constraint));
	exports.MatchesProperty = MatchesProperty;
	var MatchToSchema = (function (_super) {
	    __extends(MatchToSchema, _super);
	    function MatchToSchema(_value, provider) {
	        _super.call(this);
	        this._value = _value;
	        this.provider = provider;
	    }
	    MatchToSchema.prototype.value = function () {
	        return this._value;
	    };
	    MatchToSchema.prototype.check = function (i) {
	        var so = null;
	        var strVal = this.value();
	        if (strVal.charAt(0) == "{") {
	            try {
	                so = su.getJSONSchema(strVal, this.provider);
	            }
	            catch (e) {
	                return new ts.Status(ts.Status.ERROR, 0, "Incorrect schema :" + e.message, this);
	            }
	        }
	        if (strVal.charAt(0) == "<") {
	            try {
	                so = su.getXMLSchema(strVal);
	            }
	            catch (e) {
	                return ts.ok();
	            }
	        }
	        if (so) {
	            try {
	                so.validateObject(i);
	            }
	            catch (e) {
	                if (e.message == "!_PERF_!") {
	                    return new ts.Status(ts.Status.WARNING, 0, "Unable to validate example against schema (xmllint)", this);
	                }
	                if (e.message == "Cannot assign to read only property '__$validated' of object") {
	                    return ts.ok();
	                }
	                if (e.message == "Object.keys called on non-object") {
	                    return ts.ok();
	                }
	                return new ts.Status(ts.Status.ERROR, 0, "Example does not conform to schema:" + e.message, this);
	            }
	        }
	        return ts.ok();
	    };
	    MatchToSchema.prototype.facetName = function () {
	        return "schema";
	    };
	    MatchToSchema.prototype.requiredType = function () {
	        return ts.EXTERNAL;
	    };
	    return MatchToSchema;
	}(ts.Constraint));
	exports.MatchToSchema = MatchToSchema;
	/**
	 * this is a constraint which checks that object has no unknown properties if at has not additional properties
	 */
	var KnownPropertyRestriction = (function (_super) {
	    __extends(KnownPropertyRestriction, _super);
	    function KnownPropertyRestriction(_value) {
	        _super.call(this);
	        this._value = _value;
	    }
	    KnownPropertyRestriction.prototype.facetName = function () {
	        return "closed";
	    };
	    KnownPropertyRestriction.prototype.requiredType = function () {
	        return ts.OBJECT;
	    };
	    KnownPropertyRestriction.prototype.value = function () {
	        return true;
	    };
	    KnownPropertyRestriction.prototype.patchOwner = function (t) {
	        this._owner = t;
	    };
	    KnownPropertyRestriction.prototype.check = function (i) {
	        var _this = this;
	        if (this._value) {
	            if (i && typeof i == 'object' && !Array.isArray(i)) {
	                var nm = {};
	                Object.getOwnPropertyNames(i).forEach(function (n) { return nm[n] = true; });
	                var mp = this.owner().knownProperties();
	                Object.getOwnPropertyNames(i).forEach(function (p) {
	                    mp.forEach(function (v) {
	                        if (v.matches(p)) {
	                            delete nm[p];
	                        }
	                    });
	                });
	                if (Object.keys(nm).length > 0 && mp.length > 0) {
	                    var s = new ts.Status(ts.Status.OK, 0, "", this);
	                    Object.keys(nm).forEach(function (x) {
	                        var err = ts.error("Unknown property:" + x, _this);
	                        err.setValidationPath({ name: x });
	                        s.addSubStatus(err);
	                    });
	                    return s;
	                }
	            }
	        }
	        return ts.ok();
	    };
	    KnownPropertyRestriction.prototype.composeWith = function (restriction) {
	        if (!this._value) {
	            return null;
	        }
	        if (restriction instanceof KnownPropertyRestriction) {
	            var mm = restriction;
	            if (_.isEqual(this.owner().propertySet(), mm.owner().propertySet())) {
	                return mm;
	            }
	        }
	        if (restriction instanceof HasProperty) {
	            var ps = restriction;
	            var name = ps.value();
	            var allowedPropertySet = this.owner().propertySet();
	            if (allowedPropertySet.indexOf(name) == -1) {
	                return this.nothing(ps);
	            }
	        }
	    };
	    return KnownPropertyRestriction;
	}(ts.Constraint));
	exports.KnownPropertyRestriction = KnownPropertyRestriction;
	/**
	 * this constaint checks that object has a particular property
	 */
	var HasProperty = (function (_super) {
	    __extends(HasProperty, _super);
	    function HasProperty(name) {
	        _super.call(this);
	        this.name = name;
	    }
	    HasProperty.prototype.check = function (i) {
	        if (i && typeof i == 'object' && !Array.isArray(i)) {
	            if (i.hasOwnProperty(this.name)) {
	                return ts.ok();
	            }
	            return ts.error("Required property: " + this.name + " is missed", this);
	        }
	        return ts.ok();
	    };
	    HasProperty.prototype.requiredType = function () {
	        return ts.OBJECT;
	    };
	    HasProperty.prototype.facetName = function () {
	        return "hasProperty";
	    };
	    HasProperty.prototype.value = function () {
	        return this.name;
	    };
	    HasProperty.prototype.composeWith = function (r) {
	        if (r instanceof HasProperty) {
	            var hp = r;
	            if (hp.name === this.name) {
	                return this;
	            }
	        }
	        return null;
	    };
	    return HasProperty;
	}(ts.Constraint));
	exports.HasProperty = HasProperty;
	/**
	 * this constraint checks that property has a particular tyoe if exists
	 */
	var PropertyIs = (function (_super) {
	    __extends(PropertyIs, _super);
	    function PropertyIs(name, type) {
	        _super.call(this, type);
	        this.name = name;
	        this.type = type;
	    }
	    PropertyIs.prototype.matches = function (s) {
	        return s === this.name;
	    };
	    PropertyIs.prototype.check = function (i, p) {
	        if (i && typeof i === "object") {
	            if (i.hasOwnProperty(this.name)) {
	                var st = this.validateProp(i, this.name, this.type, p);
	                return st;
	            }
	        }
	        return ts.ok();
	    };
	    PropertyIs.prototype.requiredType = function () {
	        return ts.OBJECT;
	    };
	    PropertyIs.prototype.propId = function () {
	        return this.name;
	    };
	    PropertyIs.prototype.propertyName = function () {
	        return this.name;
	    };
	    PropertyIs.prototype.facetName = function () {
	        return "propertyIs";
	    };
	    PropertyIs.prototype.value = function () {
	        return this.type;
	    };
	    PropertyIs.prototype.composeWith = function (t) {
	        if (t instanceof PropertyIs) {
	            var pi = t;
	            if (pi.name === this.name) {
	                if (this.type.typeFamily().indexOf(pi.type) != -1) {
	                    return pi;
	                }
	                if (pi.type.typeFamily().indexOf(this.type) != -1) {
	                    return this;
	                }
	                var intersectionType = this.intersect(this.type, pi.type);
	                try {
	                    var is = intersectionType.checkConfluent();
	                    if (!is.isOk()) {
	                        var rc = is;
	                        return rc.toRestriction();
	                    }
	                    return new PropertyIs(this.name, intersectionType);
	                }
	                finally {
	                    this.release(intersectionType);
	                }
	            }
	        }
	        return null;
	    };
	    return PropertyIs;
	}(MatchesProperty));
	exports.PropertyIs = PropertyIs;
	/**
	 * this cosnstraint checks that map property values passes to particular type if exists
	 */
	var MapPropertyIs = (function (_super) {
	    __extends(MapPropertyIs, _super);
	    function MapPropertyIs(regexp, type) {
	        _super.call(this, type);
	        this.regexp = regexp;
	        this.type = type;
	    }
	    MapPropertyIs.prototype.matches = function (s) {
	        if (s.match(this.regexp)) {
	            return true;
	        }
	        return false;
	    };
	    MapPropertyIs.prototype.requiredType = function () {
	        return ts.OBJECT;
	    };
	    MapPropertyIs.prototype.propId = function () {
	        return '[' + this.regexp + ']';
	    };
	    MapPropertyIs.prototype.facetName = function () {
	        return "mapPropertyIs";
	    };
	    MapPropertyIs.prototype.value = function () {
	        return this.type;
	    };
	    MapPropertyIs.prototype.regexpValue = function () {
	        return this.regexp;
	    };
	    MapPropertyIs.prototype.validateSelf = function (t) {
	        var m = this.checkValue();
	        if (m) {
	            return new typesystem_2.Status(typesystem_2.Status.ERROR, 0, m, this);
	        }
	        return _super.prototype.validateSelf.call(this, t);
	    };
	    MapPropertyIs.prototype.checkValue = function () {
	        try {
	            new RegExp(this.regexp);
	        }
	        catch (e) {
	            return e.message;
	        }
	        return null;
	    };
	    MapPropertyIs.prototype.composeWith = function (t) {
	        if (t instanceof MapPropertyIs) {
	            var pi = t;
	            if (pi.regexp === this.regexp) {
	                if (this.type.typeFamily().indexOf(pi.type) != -1) {
	                    return pi;
	                }
	                if (pi.type.typeFamily().indexOf(this.type) != -1) {
	                    return this;
	                }
	                var intersectionType = this.intersect(this.type, pi.type);
	                try {
	                    var is = intersectionType.checkConfluent();
	                    if (!is.isOk()) {
	                        var rc = is;
	                        return rc.toRestriction();
	                    }
	                    return new MapPropertyIs(this.regexp, intersectionType);
	                }
	                finally {
	                    this.release(intersectionType);
	                }
	            }
	        }
	        return null;
	    };
	    MapPropertyIs.prototype.check = function (i, p) {
	        var _this = this;
	        if (i) {
	            if (typeof i == 'object') {
	                var rs = new ts.Status(ts.Status.OK, 0, "", this);
	                Object.getOwnPropertyNames(i).forEach(function (n) {
	                    if (n.match(_this.regexp)) {
	                        var stat = _this.validateProp(i, n, _this.type, p);
	                        if (!stat.isOk()) {
	                            rs.addSubStatus(stat);
	                        }
	                    }
	                });
	                return rs;
	            }
	        }
	        return ts.ok();
	    };
	    return MapPropertyIs;
	}(MatchesProperty));
	exports.MapPropertyIs = MapPropertyIs;
	/**
	 * this constraint tests that additional property
	 */
	var AdditionalPropertyIs = (function (_super) {
	    __extends(AdditionalPropertyIs, _super);
	    function AdditionalPropertyIs(type) {
	        _super.call(this, type);
	        this.type = type;
	    }
	    AdditionalPropertyIs.prototype.matches = function (s) {
	        return true;
	    };
	    AdditionalPropertyIs.prototype.requiredType = function () {
	        return ts.OBJECT;
	    };
	    AdditionalPropertyIs.prototype.propId = function () {
	        return '[]';
	    };
	    AdditionalPropertyIs.prototype.facetName = function () {
	        return "additionalProperties";
	    };
	    AdditionalPropertyIs.prototype.value = function () {
	        return this.type;
	    };
	    AdditionalPropertyIs.prototype.match = function (n) {
	        var all = this.owner().metaOfType(PropertyIs);
	        var map = this.owner().metaOfType(MapPropertyIs);
	        for (var i = 0; i < all.length; i++) {
	            if (all[i].matches(n)) {
	                return true;
	            }
	        }
	        for (var i = 0; i < map.length; i++) {
	            if (map[i].matches(n)) {
	                return true;
	            }
	        }
	        return false;
	    };
	    AdditionalPropertyIs.prototype.composeWith = function (t) {
	        if (t instanceof AdditionalPropertyIs) {
	            var pi = t;
	            if (this.type.typeFamily().indexOf(pi.type) != -1) {
	                return pi;
	            }
	            if (pi.type.typeFamily().indexOf(this.type) != -1) {
	                return this;
	            }
	            var intersectionType = this.intersect(this.type, pi.type);
	            try {
	                var is = intersectionType.checkConfluent();
	                if (!is.isOk()) {
	                    var rc = is;
	                    return rc.toRestriction();
	                }
	                return new AdditionalPropertyIs(intersectionType);
	            }
	            finally {
	                this.release(intersectionType);
	            }
	        }
	        return null;
	    };
	    AdditionalPropertyIs.prototype.check = function (i, p) {
	        var _this = this;
	        var t = this.type;
	        var res = new ts.Status(ts.Status.OK, 0, "", this);
	        if (i && typeof i === "object") {
	            Object.getOwnPropertyNames(i).forEach(function (n) {
	                if (!_this.match(n)) {
	                    var stat = _this.validateProp(i, n, t, p);
	                    if (!stat.isOk()) {
	                        res.addSubStatus(stat);
	                    }
	                }
	            });
	        }
	        return res;
	    };
	    return AdditionalPropertyIs;
	}(MatchesProperty));
	exports.AdditionalPropertyIs = AdditionalPropertyIs;
	/**
	 * common super type for a simple restrictions
	 */
	var FacetRestriction = (function (_super) {
	    __extends(FacetRestriction, _super);
	    function FacetRestriction() {
	        _super.apply(this, arguments);
	    }
	    FacetRestriction.prototype.validateSelf = function (registry) {
	        if (!this.owner().isSubTypeOf(this.requiredType())) {
	            var rs = ts.error(this.facetName() + " facet can only be used with " + this.requiredType().name() + " types", this);
	            rs.setValidationPath({ name: this.facetName() });
	            return rs;
	        }
	        var m = this.checkValue();
	        if (m) {
	            var rs = ts.error(m, this);
	            rs.setValidationPath({ name: this.facetName() });
	            return rs;
	        }
	        return ts.ok();
	    };
	    return FacetRestriction;
	}(ts.Constraint));
	exports.FacetRestriction = FacetRestriction;
	function is_int(value) {
	    if ((parseFloat(value) == parseInt(value)) && !isNaN(value)) {
	        return true;
	    }
	    else {
	        return false;
	    }
	}
	/**
	 * abstract super type for every min max restriction
	 */
	var MinMaxRestriction = (function (_super) {
	    __extends(MinMaxRestriction, _super);
	    function MinMaxRestriction(_facetName, _value, _max, _opposite, _requiredType, _isInt) {
	        _super.call(this);
	        this._facetName = _facetName;
	        this._value = _value;
	        this._max = _max;
	        this._opposite = _opposite;
	        this._requiredType = _requiredType;
	        this._isInt = _isInt;
	    }
	    MinMaxRestriction.prototype.facetName = function () {
	        return this._facetName;
	    };
	    MinMaxRestriction.prototype.isIntConstraint = function () {
	        return this._isInt;
	    };
	    MinMaxRestriction.prototype.isMax = function () {
	        return this._max;
	    };
	    MinMaxRestriction.prototype.value = function () {
	        return this._value;
	    };
	    MinMaxRestriction.prototype.check = function (i) {
	        var o = this.extractValue(i);
	        if (typeof o == 'number') {
	            if (this.isMax()) {
	                if (this.value() < o) {
	                    return this.createError();
	                }
	            }
	            else {
	                if (this.value() > o) {
	                    return this.createError();
	                }
	            }
	        }
	        return ts.ok();
	    };
	    MinMaxRestriction.prototype.createError = function () {
	        return ts.error(this.toString(), this);
	    };
	    MinMaxRestriction.prototype.minValue = function () {
	        if (this._isInt) {
	            return 0;
	        }
	        return Number.NEGATIVE_INFINITY;
	    };
	    MinMaxRestriction.prototype.requiredType = function () {
	        return this._requiredType;
	    };
	    MinMaxRestriction.prototype.checkValue = function () {
	        if (typeof this._value != "number") {
	            return this.facetName() + " should be a number";
	        }
	        if (this.isIntConstraint()) {
	            if (!is_int(this.value())) {
	                return this.facetName() + " should be a integer";
	            }
	        }
	        if (this.value() < this.minValue()) {
	            return this.facetName() + " should be at least " + this.minValue();
	        }
	    };
	    MinMaxRestriction.prototype.composeWith = function (t) {
	        if (t instanceof MinMaxRestriction) {
	            var mx = t;
	            if (mx.facetName() == this.facetName()) {
	                if (mx.isMax() == this.isMax()) {
	                    if (this.isMax()) {
	                        if (this.value() < mx.value()) {
	                            return mx;
	                        }
	                        else {
	                            return this;
	                        }
	                    }
	                    else {
	                        if (this.value() > mx.value()) {
	                            return mx;
	                        }
	                        else {
	                            return this;
	                        }
	                    }
	                }
	            }
	            if (mx.facetName() === this._opposite) {
	                if (this.isMax()) {
	                    if (mx.value() > this.value()) {
	                        return this.nothing(t);
	                    }
	                }
	                else {
	                    if (mx.value() < this.value()) {
	                        return this.nothing(t);
	                    }
	                }
	            }
	        }
	        return null;
	    };
	    return MinMaxRestriction;
	}(FacetRestriction));
	exports.MinMaxRestriction = MinMaxRestriction;
	var MultipleOf = (function (_super) {
	    __extends(MultipleOf, _super);
	    function MultipleOf(_value) {
	        _super.call(this);
	        this._value = _value;
	    }
	    MultipleOf.prototype.value = function () {
	        return this._value;
	    };
	    MultipleOf.prototype.check = function (o) {
	        if (typeof o == 'number') {
	            var q = o / this.value();
	            if (!is_int(q)) {
	                return new ts.Status(ts.Status.ERROR, 0, "result of division of " + o + " on " + this.value() + " should be integer", this);
	            }
	        }
	        return ts.ok();
	    };
	    MultipleOf.prototype.composeWith = function (t) {
	        return null;
	    };
	    MultipleOf.prototype.facetName = function () {
	        return "multipleOf";
	    };
	    MultipleOf.prototype.checkValue = function () {
	        if (typeof this._value != "number") {
	            return this.facetName() + " should be a number";
	        }
	        return null;
	    };
	    MultipleOf.prototype.requiredType = function () {
	        return ts.NUMBER;
	    };
	    return MultipleOf;
	}(FacetRestriction));
	exports.MultipleOf = MultipleOf;
	/**
	 * maximum  constraint
	 */
	var Maximum = (function (_super) {
	    __extends(Maximum, _super);
	    function Maximum(val) {
	        _super.call(this, "maximum", val, true, "minimum", ts.NUMBER, false);
	    }
	    Maximum.prototype.extractValue = function (i) {
	        return i;
	    };
	    Maximum.prototype.toString = function () {
	        return "value should be not more then " + this.value();
	    };
	    return Maximum;
	}(MinMaxRestriction));
	exports.Maximum = Maximum;
	/**
	 * minimum constraint
	 */
	var Minimum = (function (_super) {
	    __extends(Minimum, _super);
	    function Minimum(val) {
	        _super.call(this, "minimum", val, false, "maximum", ts.NUMBER, false);
	    }
	    Minimum.prototype.extractValue = function (i) {
	        return i;
	    };
	    Minimum.prototype.toString = function () {
	        return "value should be not less then " + this.value();
	    };
	    return Minimum;
	}(MinMaxRestriction));
	exports.Minimum = Minimum;
	/**
	 * max items cosntraint
	 */
	var MaxItems = (function (_super) {
	    __extends(MaxItems, _super);
	    function MaxItems(val) {
	        _super.call(this, "maxItems", val, true, "minItems", ts.ARRAY, true);
	    }
	    MaxItems.prototype.extractValue = function (i) {
	        if (Array.isArray(i)) {
	            return i.length;
	        }
	    };
	    MaxItems.prototype.toString = function () {
	        return "array should have not more then " + this.value() + " items";
	    };
	    return MaxItems;
	}(MinMaxRestriction));
	exports.MaxItems = MaxItems;
	/**
	 * min items cosntraint
	 */
	var MinItems = (function (_super) {
	    __extends(MinItems, _super);
	    function MinItems(val) {
	        _super.call(this, "minItems", val, false, "maxItems", ts.ARRAY, true);
	    }
	    MinItems.prototype.extractValue = function (i) {
	        if (Array.isArray(i)) {
	            return i.length;
	        }
	    };
	    MinItems.prototype.toString = function () {
	        return "array should have not less then " + this.value() + " items";
	    };
	    return MinItems;
	}(MinMaxRestriction));
	exports.MinItems = MinItems;
	/**
	 * max length
	 */
	var MaxLength = (function (_super) {
	    __extends(MaxLength, _super);
	    function MaxLength(val) {
	        _super.call(this, "maxLength", val, true, "minLength", ts.STRING, true);
	    }
	    MaxLength.prototype.extractValue = function (i) {
	        if (typeof i == 'string') {
	            return i.length;
	        }
	        return 0;
	    };
	    MaxLength.prototype.toString = function () {
	        return "string length should be not more then " + this.value();
	    };
	    return MaxLength;
	}(MinMaxRestriction));
	exports.MaxLength = MaxLength;
	/**
	 * min length
	 */
	var MinLength = (function (_super) {
	    __extends(MinLength, _super);
	    function MinLength(val) {
	        _super.call(this, "minLength", val, false, "maxLength", ts.STRING, true);
	    }
	    MinLength.prototype.extractValue = function (i) {
	        if (typeof i == 'string') {
	            return i.length;
	        }
	        return 0;
	    };
	    MinLength.prototype.toString = function () {
	        return "string length should be not less then " + this.value();
	    };
	    return MinLength;
	}(MinMaxRestriction));
	exports.MinLength = MinLength;
	/**
	 * max properties constraint
	 */
	var MaxProperties = (function (_super) {
	    __extends(MaxProperties, _super);
	    function MaxProperties(val) {
	        _super.call(this, "maxProperties", val, true, "minProperties", ts.OBJECT, true);
	    }
	    MaxProperties.prototype.extractValue = function (i) {
	        return Object.keys(i).length;
	    };
	    MaxProperties.prototype.toString = function () {
	        return "object should have not more then " + this.value() + " properties";
	    };
	    return MaxProperties;
	}(MinMaxRestriction));
	exports.MaxProperties = MaxProperties;
	/**
	 * min properties constraint
	 */
	var MinProperties = (function (_super) {
	    __extends(MinProperties, _super);
	    function MinProperties(val) {
	        _super.call(this, "minProperties", val, false, "maxProperties", ts.OBJECT, true);
	    }
	    MinProperties.prototype.extractValue = function (i) {
	        return Object.keys(i).length;
	    };
	    MinProperties.prototype.toString = function () {
	        return "object should have not less then " + this.value() + " properties";
	    };
	    return MinProperties;
	}(MinMaxRestriction));
	exports.MinProperties = MinProperties;
	/**
	 * unique items constraint
	 */
	var UniqueItems = (function (_super) {
	    __extends(UniqueItems, _super);
	    function UniqueItems(_value) {
	        _super.call(this);
	        this._value = _value;
	    }
	    UniqueItems.prototype.facetName = function () { return "uniqueItems"; };
	    UniqueItems.prototype.requiredType = function () { return ts.ARRAY; };
	    UniqueItems.prototype.check = function (i) {
	        if (Array.isArray(i)) {
	            var r = i;
	            if (_.unique(r).length != r.length) {
	                return ts.error(this.toString(), this);
	            }
	        }
	        return ts.ok();
	    };
	    UniqueItems.prototype.composeWith = function (r) {
	        if (r instanceof UniqueItems) {
	            var mm = r;
	            if (mm._value == this._value) {
	                return this;
	            }
	        }
	        return null;
	    };
	    UniqueItems.prototype.value = function () {
	        return this._value;
	    };
	    UniqueItems.prototype.checkValue = function () {
	        return null;
	    };
	    UniqueItems.prototype.toString = function () {
	        return "items should be unique";
	    };
	    return UniqueItems;
	}(FacetRestriction));
	exports.UniqueItems = UniqueItems;
	/**
	 * components of array should be of type
	 */
	var ComponentShouldBeOfType = (function (_super) {
	    __extends(ComponentShouldBeOfType, _super);
	    function ComponentShouldBeOfType(type) {
	        _super.call(this);
	        this.type = type;
	    }
	    ComponentShouldBeOfType.prototype.facetName = function () { return "items"; };
	    ComponentShouldBeOfType.prototype.requiredType = function () { return ts.ARRAY; };
	    ComponentShouldBeOfType.prototype.toString = function () {
	        return "items should be of type " + this.type;
	    };
	    ComponentShouldBeOfType.prototype.check = function (i) {
	        var rs = new ts.Status(ts.Status.OK, 0, "", this);
	        if (Array.isArray(i)) {
	            var ar = i;
	            for (var j = 0; j < ar.length; j++) {
	                var ss = this.type.validate(ar[j], true);
	                if (!ss.isOk()) {
	                    var t = this.type;
	                    if (t.isUnknown() || t.isRecurrent()) {
	                        var s = new typesystem_2.Status(typesystem_2.Status.ERROR, 0, "array instance is validated against unknown type:" + t.name(), this);
	                        return s;
	                    }
	                }
	                ss.setValidationPath({ name: "" + j });
	                rs.addSubStatus(ss);
	            }
	        }
	        return rs;
	    };
	    ComponentShouldBeOfType.prototype.validateSelf = function (registry) {
	        if (this.type.isAnonymous()) {
	            var st = this.type.validateType(registry);
	            if (!st.isOk()) {
	                return new typesystem_2.Status(typesystem_2.Status.ERROR, 0, "component type has error:" + st.getMessage(), this);
	            }
	            return st;
	        }
	        if (this.type.isExternal()) {
	            var p = new typesystem_2.Status(typesystem_2.Status.ERROR, 0, "It is not allowed to use external types in component type definitions", this);
	            return p;
	        }
	        if (this.type.isSubTypeOf(ts.UNKNOWN) || this.type.isSubTypeOf(ts.RECURRENT)) {
	            return new typesystem_2.Status(typesystem_2.Status.ERROR, 0, "component refers to unknown type " + this.type.name(), this);
	        }
	        if (this.type.isUnion()) {
	            var ui = _.find(this.type.typeFamily(), function (x) { return x.isSubTypeOf(ts.UNKNOWN); });
	            if (ui) {
	                return new typesystem_2.Status(typesystem_2.Status.ERROR, 0, "component refers to unknown type " + ui.name(), this);
	            }
	        }
	        return ts.ok();
	    };
	    ComponentShouldBeOfType.prototype.composeWith = function (t) {
	        if (t instanceof ComponentShouldBeOfType) {
	            var pi = t;
	            if (this.type.typeFamily().indexOf(pi.type) != -1) {
	                return pi;
	            }
	            if (pi.type.typeFamily().indexOf(this.type) != -1) {
	                return this;
	            }
	            var intersectionType = this.intersect(this.type, pi.type);
	            try {
	                var is = intersectionType.checkConfluent();
	                if (!is.isOk()) {
	                    var rc = is;
	                    return rc.toRestriction();
	                }
	                return new ComponentShouldBeOfType(intersectionType);
	            }
	            finally {
	                this.release(intersectionType);
	            }
	        }
	        return null;
	    };
	    ComponentShouldBeOfType.prototype.checkValue = function () {
	        return null;
	    };
	    ComponentShouldBeOfType.prototype.value = function () {
	        return this.type;
	    };
	    return ComponentShouldBeOfType;
	}(FacetRestriction));
	exports.ComponentShouldBeOfType = ComponentShouldBeOfType;
	/**
	 * regular expression (pattern) constraint
	 */
	var Pattern = (function (_super) {
	    __extends(Pattern, _super);
	    function Pattern(_value) {
	        _super.call(this);
	        this._value = _value;
	    }
	    Pattern.prototype.facetName = function () { return "pattern"; };
	    Pattern.prototype.requiredType = function () { return ts.STRING; };
	    Pattern.prototype.check = function (i) {
	        if (typeof i == 'string') {
	            var st = i;
	            try {
	                var mm = st.match(this._value);
	                if (!mm) {
	                    return new ts.Status(ts.Status.ERROR, 0, "string should match to " + this.value(), this);
	                }
	            }
	            catch (e) {
	            }
	        }
	        return ts.ok();
	    };
	    Pattern.prototype.composeWith = function (r) {
	        if (r instanceof Pattern) {
	            var v = r;
	            if (v._value === this._value) {
	                return this;
	            }
	            return this.nothing(r, "pattern restrictions can not be composed at one type");
	        }
	        return null;
	    };
	    Pattern.prototype.value = function () {
	        return this._value;
	    };
	    Pattern.prototype.checkValue = function () {
	        try {
	            new RegExp(this._value);
	        }
	        catch (e) {
	            return e.message;
	        }
	        return null;
	    };
	    Pattern.prototype.toString = function () {
	        return "should pass reg exp:" + this.value;
	    };
	    return Pattern;
	}(FacetRestriction));
	exports.Pattern = Pattern;
	/**
	 * enum constraint
	 */
	var Enum = (function (_super) {
	    __extends(Enum, _super);
	    function Enum(_value) {
	        _super.call(this);
	        this._value = _value;
	        if (!Array.isArray(_value)) {
	            this._value = [_value];
	        }
	    }
	    Enum.prototype.facetName = function () { return "enum"; };
	    Enum.prototype.requiredType = function () { return ts.SCALAR; };
	    Enum.prototype.check = function (i) {
	        if (!this.checkStatus) {
	            if (!this.value().some(function (x) { return x == i; })) {
	                return ts.error(this.toString(), this);
	            }
	        }
	        return ts.ok();
	    };
	    Enum.prototype.composeWith = function (r) {
	        if (r instanceof Enum) {
	            var v = r;
	            var sss = _.intersection(this._value, v._value);
	            if (sss.length == 0) {
	                return this.nothing(r);
	            }
	            return new Enum(sss);
	        }
	        return null;
	    };
	    Enum.prototype.value = function () {
	        return this._value;
	    };
	    Enum.prototype.checkValue = function () {
	        var _this = this;
	        if (!this.owner().isSubTypeOf(this.requiredType())) {
	            return "enum facet can only be used with: " + this.requiredType().name();
	        }
	        if (_.uniq(this._value).length < this._value.length) {
	            return "enum facet can only contain unique items";
	        }
	        var result = null;
	        this.checkStatus = true;
	        try {
	            this._value.forEach(function (x) {
	                var res = _this.owner().validate(x);
	                if (!res.isOk()) {
	                    result = res.getMessage();
	                }
	            });
	        }
	        finally {
	            this.checkStatus = false;
	        }
	        return result;
	    };
	    Enum.prototype.toString = function () {
	        return "value should be one of:" + this._value;
	    };
	    return Enum;
	}(FacetRestriction));
	exports.Enum = Enum;
	/**
	 * this function attempts to optimize to set of restrictions
	 * @param r
	 * @returns {ts.Constraint[]}
	 */
	function optimize(r) {
	    r = r.map(function (x) { return x.preoptimize(); });
	    var optimized = [];
	    r.forEach(function (x) {
	        if (x instanceof typesystem_1.AndRestriction) {
	            var ar = x;
	            ar.options().forEach(function (y) { optimized.push(y); });
	        }
	        else {
	            optimized.push(x);
	        }
	    });
	    var transformed = true;
	    while (transformed) {
	        transformed = false;
	        for (var i = 0; i < optimized.length; i++) {
	            for (var j = 0; j < optimized.length; j++) {
	                var rs0 = optimized[i];
	                var rs1 = optimized[j];
	                if (rs0 !== rs1) {
	                    var compose = rs0.tryCompose(rs1);
	                    if (compose) {
	                        var newOptimized = optimized.filter(function (x) { return x !== rs0 && x !== rs1; });
	                        newOptimized.push(compose);
	                        transformed = true;
	                        optimized = newOptimized;
	                        break;
	                    }
	                }
	            }
	            if (transformed) {
	                break;
	            }
	        }
	    }
	    return optimized;
	}
	exports.optimize = optimize;
	//# sourceMappingURL=restrictions.js.map

/***/ },
/* 95 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var __extends = (this && this.__extends) || function (d, b) {
	    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
	    function __() { this.constructor = d; }
	    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
	};
	/// <reference path="../typings/main.d.ts" />
	var ts = __webpack_require__(90);
	var typesystem_1 = __webpack_require__(90);
	var restrictions_1 = __webpack_require__(94);
	var _ = __webpack_require__(177);
	var xmlio = __webpack_require__(137);
	var int = __webpack_require__(91);
	var MetaInfo = (function (_super) {
	    __extends(MetaInfo, _super);
	    function MetaInfo(_name, _value, inhertitable) {
	        if (inhertitable === void 0) { inhertitable = false; }
	        _super.call(this, inhertitable);
	        this._name = _name;
	        this._value = _value;
	    }
	    MetaInfo.prototype.value = function () {
	        return this._value;
	    };
	    MetaInfo.prototype.requiredType = function () {
	        return ts.ANY;
	    };
	    MetaInfo.prototype.facetName = function () {
	        return this._name;
	    };
	    return MetaInfo;
	}(ts.TypeInformation));
	exports.MetaInfo = MetaInfo;
	var Description = (function (_super) {
	    __extends(Description, _super);
	    function Description(value) {
	        _super.call(this, "description", value);
	    }
	    return Description;
	}(MetaInfo));
	exports.Description = Description;
	var NotScalar = (function (_super) {
	    __extends(NotScalar, _super);
	    function NotScalar() {
	        _super.call(this, "notScalar", true);
	    }
	    return NotScalar;
	}(MetaInfo));
	exports.NotScalar = NotScalar;
	var DisplayName = (function (_super) {
	    __extends(DisplayName, _super);
	    function DisplayName(value) {
	        _super.call(this, "displayName", value);
	    }
	    return DisplayName;
	}(MetaInfo));
	exports.DisplayName = DisplayName;
	var Usage = (function (_super) {
	    __extends(Usage, _super);
	    function Usage(value) {
	        _super.call(this, "usage", value);
	    }
	    return Usage;
	}(MetaInfo));
	exports.Usage = Usage;
	var Annotation = (function (_super) {
	    __extends(Annotation, _super);
	    function Annotation(name, value) {
	        _super.call(this, name, value);
	    }
	    Annotation.prototype.validateSelf = function (registry) {
	        var tp = registry.get(this.facetName());
	        if (!tp) {
	            return new typesystem_1.Status(typesystem_1.Status.ERROR, 0, "using unknown annotation type:" + this.facetName(), this);
	        }
	        var q = this.value();
	        if (!q) {
	            if (tp.isString()) {
	                q = "";
	            }
	        }
	        var valOwner = tp.validateDirect(q, true, false);
	        if (!valOwner.isOk()) {
	            var res = new typesystem_1.Status(typesystem_1.Status.OK, 0, "invalid annotation value" + valOwner.getMessage(), this);
	            res.addSubStatus(valOwner);
	            return res;
	        }
	        return ts.ok();
	    };
	    return Annotation;
	}(MetaInfo));
	exports.Annotation = Annotation;
	var FacetDeclaration = (function (_super) {
	    __extends(FacetDeclaration, _super);
	    function FacetDeclaration(name, _type, optional) {
	        _super.call(this, name, _type, true);
	        this.name = name;
	        this._type = _type;
	        this.optional = optional;
	    }
	    FacetDeclaration.prototype.actualName = function () {
	        if (this.name.charAt(this.name.length - 1) == '?') {
	            return this.name.substr(0, this.name.length - 1);
	        }
	        return this.name;
	    };
	    FacetDeclaration.prototype.isOptional = function () {
	        return this.optional;
	    };
	    FacetDeclaration.prototype.type = function () {
	        return this._type;
	    };
	    return FacetDeclaration;
	}(MetaInfo));
	exports.FacetDeclaration = FacetDeclaration;
	var CustomFacet = (function (_super) {
	    __extends(CustomFacet, _super);
	    function CustomFacet(name, value) {
	        _super.call(this, name, value, true);
	    }
	    return CustomFacet;
	}(MetaInfo));
	exports.CustomFacet = CustomFacet;
	function serializeToXml(value, type) {
	    return xmlio.serializeToXML(value, type);
	}
	function parseExampleIfNeeded(val, type) {
	    if (typeof val === 'string') {
	        if (type.isObject() || type.isArray() || type.isExternal() || type.isUnion()) {
	            var exampleString = val;
	            var firstChar = exampleString.trim().charAt(0);
	            if ((firstChar == "{" || firstChar == "[") && !type.isUnion()) {
	                try {
	                    return JSON.parse(exampleString);
	                }
	                catch (e) {
	                    if (type.isObject() || type.isArray()) {
	                        var c = new typesystem_1.Status(typesystem_1.Status.ERROR, 0, "Can not parse JSON example:" + e.message, this);
	                        return c;
	                    }
	                }
	            }
	            if (firstChar == "<") {
	                try {
	                    var jsonFromXml = xmlio.readObject(exampleString, type);
	                    var errors = xmlio.getXmlErrors(jsonFromXml);
	                    if (errors) {
	                        var error = new typesystem_1.Status(typesystem_1.Status.ERROR, 0, 'Invalid XML.', {});
	                        errors.forEach(function (child) { return error.addSubStatus(child); });
	                        return error;
	                    }
	                    return jsonFromXml;
	                }
	                catch (e) {
	                }
	            }
	        }
	    }
	    if (type.getExtra(int.REPEAT)) {
	        val = [val];
	    }
	    return val;
	}
	var Example = (function (_super) {
	    __extends(Example, _super);
	    function Example(value) {
	        _super.call(this, "example", value);
	    }
	    Example.prototype.validateSelf = function (registry) {
	        var val = this.value();
	        var isVal = false;
	        if (typeof val === "object" && val) {
	            if (val.value) {
	                if (val.strict === false) {
	                    return ts.ok();
	                }
	                if (val.strict && typeof val.strict != "boolean") {
	                    var s = new typesystem_1.Status(typesystem_1.Status.ERROR, 0, "strict should be boolean", this);
	                    s.setValidationPath({ name: "example", child: { name: "strict" } });
	                    return s;
	                }
	                val = val.value;
	                isVal = true;
	            }
	        }
	        var rr = parseExampleIfNeeded(val, this.owner());
	        if (rr instanceof ts.Status) {
	            rr.setValidationPath({ name: "example" });
	            return rr;
	        }
	        var valOwner = this.owner().validateDirect(rr, true, false);
	        if (!valOwner.isOk()) {
	            if (typeof this.value() === "string") {
	            }
	            var c = new typesystem_1.Status(typesystem_1.Status.ERROR, 0, "using invalid `example`:" + valOwner.getMessage(), this);
	            valOwner.getErrors().forEach(function (x) {
	                c.addSubStatus(x);
	                if (isVal) {
	                    x.setValidationPath({ name: "example", child: { name: "value" } });
	                }
	                else {
	                    x.setValidationPath({ name: "example" });
	                }
	            });
	            return c;
	        }
	        return ts.ok();
	    };
	    Example.prototype.example = function () {
	        var val = this.value();
	        if (typeof val === "object" && val) {
	            if (val.value) {
	                val = val.value;
	            }
	        }
	        return parseExampleIfNeeded(val, this.owner());
	    };
	    Example.prototype.asXMLString = function () {
	        var value = this.value();
	        if (typeof value === 'string' && value.trim().indexOf('<') === 0) {
	            return value;
	        }
	        var parsedValue = parseExampleIfNeeded(value, this.owner());
	        return serializeToXml(parsedValue, this.owner());
	    };
	    return Example;
	}(MetaInfo));
	exports.Example = Example;
	var Required = (function (_super) {
	    __extends(Required, _super);
	    function Required(value) {
	        _super.call(this, "required", value);
	    }
	    Required.prototype.validateSelf = function (registry) {
	        if (typeof this.value() !== "boolean") {
	            return new typesystem_1.Status(typesystem_1.Status.ERROR, 0, "value of required facet should be boolean", this);
	        }
	        return ts.ok();
	    };
	    return Required;
	}(MetaInfo));
	exports.Required = Required;
	var AllowedTargets = (function (_super) {
	    __extends(AllowedTargets, _super);
	    function AllowedTargets(value) {
	        _super.call(this, "allowedTargets", value);
	    }
	    AllowedTargets.prototype.validateSelf = function (registry) {
	        return ts.ok();
	    };
	    return AllowedTargets;
	}(MetaInfo));
	exports.AllowedTargets = AllowedTargets;
	var Examples = (function (_super) {
	    __extends(Examples, _super);
	    function Examples(value) {
	        _super.call(this, "examples", value);
	    }
	    Examples.prototype.examples = function () {
	        var _this = this;
	        var v = this.value();
	        var result = [];
	        Object.keys(v).forEach(function (x) {
	            if (typeof v[x] == 'object' && v[x]) {
	                var val = v[x].value;
	                if (!val) {
	                    val = v[x];
	                }
	                var example = parseExampleIfNeeded(val, _this.owner());
	                result.push(example);
	            }
	        });
	        return result;
	    };
	    Examples.prototype.asXMLStrings = function () {
	        var _this = this;
	        var value = this.value();
	        var result = {};
	        Object.keys(value).forEach(function (key) {
	            var childValue = value[key];
	            if (typeof childValue === 'string' && childValue.trim().indexOf('<') === 0) {
	                result[key] = childValue;
	                return;
	            }
	            var parsedValue = parseExampleIfNeeded(childValue, _this.owner());
	            result[key] = serializeToXml(parsedValue, _this.owner());
	        });
	        return result;
	    };
	    Examples.prototype.validateSelf = function (registry) {
	        var _this = this;
	        if (typeof this.value() === 'object') {
	            var rs = new typesystem_1.Status(typesystem_1.Status.OK, 0, "", this);
	            var v = this.value();
	            if (v) {
	                Object.keys(v).forEach(function (x) {
	                    if (v[x]) {
	                        var val = v[x].value;
	                        var noVal = !val;
	                        if (noVal) {
	                            val = v[x];
	                        }
	                        else {
	                            if (v[x].strict === false) {
	                                return;
	                            }
	                            if (v[x].strict && typeof v[x].strict != "boolean") {
	                                var s = new typesystem_1.Status(typesystem_1.Status.ERROR, 0, "strict should be boolean", _this);
	                                s.setValidationPath({ name: x, child: { name: "strict", child: { name: "strict" } } });
	                                return s;
	                            }
	                        }
	                        var example = parseExampleIfNeeded(val, _this.owner());
	                        if (example instanceof ts.Status) {
	                            examplesPatchPath(example, noVal, x);
	                            rs.addSubStatus(example);
	                            return;
	                        }
	                        var res = _this.owner().validateDirect(example, true, false);
	                        res.getErrors().forEach(function (ex) {
	                            rs.addSubStatus(ex);
	                            examplesPatchPath(ex, noVal, x);
	                        });
	                        if (typeof v[x] == "object" && v[x].value) {
	                            Object.keys(v[x]).forEach(function (key) {
	                                if (key.charAt(0) == '(' && key.charAt(key.length - 1) == ')') {
	                                    var a = new Annotation(key.substring(1, key.length - 1), v[x][key]);
	                                    rs.addSubStatus(a.validateSelf(registry));
	                                }
	                            });
	                        }
	                    }
	                });
	            }
	            return rs;
	        }
	        else {
	            return new typesystem_1.Status(typesystem_1.Status.ERROR, 0, "examples should be a map", this);
	        }
	    };
	    return Examples;
	}(MetaInfo));
	exports.Examples = Examples;
	function examplesPatchPath(example, noVal, x) {
	    if (noVal) {
	        example.setValidationPath({ name: "examples", child: { name: x } });
	    }
	    else {
	        example.setValidationPath({ name: "examples", child: { name: x, child: { name: "value" } } });
	    }
	}
	var XMLInfo = (function (_super) {
	    __extends(XMLInfo, _super);
	    function XMLInfo(o) {
	        _super.call(this, "xml", o);
	    }
	    return XMLInfo;
	}(MetaInfo));
	exports.XMLInfo = XMLInfo;
	var Default = (function (_super) {
	    __extends(Default, _super);
	    function Default(value) {
	        _super.call(this, "default", value);
	    }
	    Default.prototype.validateSelf = function (registry) {
	        var valOwner = this.owner().validateDirect(this.value(), true);
	        if (!valOwner.isOk()) {
	            return new typesystem_1.Status(typesystem_1.Status.ERROR, 0, "using invalid `defaultValue`:" + valOwner.getMessage(), this);
	        }
	        return ts.ok();
	    };
	    return Default;
	}(MetaInfo));
	exports.Default = Default;
	var Discriminator = (function (_super) {
	    __extends(Discriminator, _super);
	    function Discriminator(property) {
	        _super.call(this, true);
	        this.property = property;
	    }
	    Discriminator.prototype.requiredType = function () {
	        return ts.OBJECT;
	    };
	    Discriminator.prototype.value = function () {
	        return this.property;
	    };
	    Discriminator.prototype.facetName = function () { return "discriminator"; };
	    Discriminator.prototype.validateSelf = function (registry) {
	        var _this = this;
	        if (!this.owner().isSubTypeOf(ts.OBJECT)) {
	            return new typesystem_1.Status(typesystem_1.Status.ERROR, 0, "you only can use `discriminator` with object types", this);
	        }
	        if (this.owner().getExtra(ts.GLOBAL) === false) {
	            return new typesystem_1.Status(typesystem_1.Status.ERROR, 0, "you only can use `discriminator` with top level type definitions", this);
	        }
	        var prop = _.find(this.owner().meta(), function (x) { return x instanceof restrictions_1.PropertyIs && x.propertyName() == _this.value(); });
	        if (!prop) {
	            return new typesystem_1.Status(typesystem_1.Status.ERROR, 0, "Using unknown property: " + this.value() + " as discriminator", this);
	        }
	        if (!prop.value().isScalar()) {
	            return new typesystem_1.Status(typesystem_1.Status.ERROR, 0, "It is only allowed to use scalar properties as discriminators", this);
	        }
	        return ts.ok();
	    };
	    return Discriminator;
	}(ts.TypeInformation));
	exports.Discriminator = Discriminator;
	var DiscriminatorValue = (function (_super) {
	    __extends(DiscriminatorValue, _super);
	    function DiscriminatorValue(_value) {
	        _super.call(this, false);
	        this._value = _value;
	    }
	    DiscriminatorValue.prototype.facetName = function () { return "discriminatorValue"; };
	    DiscriminatorValue.prototype.validateSelf = function (registry) {
	        if (!this.owner().isSubTypeOf(ts.OBJECT)) {
	            return new typesystem_1.Status(typesystem_1.Status.ERROR, 0, "you only can use `discriminator` with object types", this);
	        }
	        if (this.owner().getExtra(ts.GLOBAL) === false) {
	            return new typesystem_1.Status(typesystem_1.Status.ERROR, 0, "you only can use `discriminator` with top level type definitions", this);
	        }
	        var ds = this.owner().oneMeta(Discriminator);
	        if (!ds) {
	            return new typesystem_1.Status(typesystem_1.Status.ERROR, 0, "you can not use `discriminatorValue` without declaring `discriminator`", this);
	        }
	        var prop = _.find(this.owner().meta(), function (x) { return x instanceof restrictions_1.PropertyIs && x.propertyName() == ds.value(); });
	        if (prop) {
	            var sm = prop.value().validate(this.value());
	            if (!sm.isOk()) {
	                return new typesystem_1.Status(typesystem_1.Status.ERROR, 0, "using invalid `disciminatorValue`:" + sm.getMessage(), this);
	            }
	        }
	        return ts.ok();
	    };
	    DiscriminatorValue.prototype.requiredType = function () {
	        return ts.OBJECT;
	    };
	    DiscriminatorValue.prototype.value = function () {
	        return this._value;
	    };
	    return DiscriminatorValue;
	}(ts.TypeInformation));
	exports.DiscriminatorValue = DiscriminatorValue;
	//# sourceMappingURL=metainfo.js.map

/***/ },
/* 96 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var ts = __webpack_require__(90);
	var nt = __webpack_require__(97);
	var parse = __webpack_require__(92);
	var restrictions_1 = __webpack_require__(94);
	var NOMINAL = "nominal";
	var pc;
	function setPropertyConstructor(p) {
	    pc = p;
	}
	exports.setPropertyConstructor = setPropertyConstructor;
	function toNominal(t, callback, customizer) {
	    if (customizer === void 0) { customizer = null; }
	    var vs = null;
	    if (t.getExtra(NOMINAL)) {
	        return t.getExtra(NOMINAL);
	    }
	    //if (t.isEmpty()){
	    //    if (t.superTypes().length==1){
	    //        return toNominal(t.superTypes()[0],callback);
	    //    }
	    //}
	    if (!t) {
	        var res = callback("any");
	        if (!res) {
	            vs = new nt.StructuredType(t.name());
	        }
	    }
	    if (t.isBuiltin()) {
	        var s = (t.name() != "any" && t.name() != "array") ? callback(t.name()) : null;
	        if (!s) {
	            if (t.isScalar()) {
	                vs = new nt.ValueType(t.name(), null);
	            }
	            else {
	                vs = new nt.StructuredType(t.name());
	            }
	        }
	        else {
	            vs = s;
	        }
	    }
	    else {
	        if (t.isObject()) {
	            vs = new nt.StructuredType(t.name(), null);
	        }
	        else if (t.isArray()) {
	            var ar = new nt.Array(t.name(), null);
	            vs = ar;
	            t.putExtra(NOMINAL, vs);
	            var cm = t.oneMeta(restrictions_1.ComponentShouldBeOfType);
	            var r = cm ? cm.value() : ts.ANY;
	            ar.setComponent(toNominal(r, callback));
	        }
	        else if (t instanceof ts.UnionType) {
	            var ut = new nt.Union(t.name(), null);
	            if (t.superTypes().length == 0) {
	                ut._superTypes.push(toNominal(ts.UNION, callback, customizer));
	            }
	            t.putExtra(NOMINAL, ut);
	            t.options().forEach(function (x) {
	                if (ut.left == null) {
	                    ut.left = toNominal(x, callback);
	                }
	                else if (ut.right == null) {
	                    ut.right = toNominal(x, callback);
	                }
	                else {
	                    var nu = new nt.Union(t.name(), null);
	                    nu.left = ut.right;
	                    nu.right = toNominal(x, callback);
	                    ut.right = nu;
	                }
	            });
	            vs = ut;
	        }
	        else if (t.isScalar()) {
	            vs = new nt.ValueType(t.name(), null);
	        }
	        else if (t instanceof ts.ExternalType) {
	            var e = t;
	            var et = new nt.ExternalType(e.name());
	            et.schemaString = e.schema();
	            vs = et;
	        }
	    }
	    if (!vs) {
	        vs = new nt.StructuredType(t.name());
	    }
	    t.superTypes().forEach(function (x) {
	        var mn = toNominal(x, callback);
	        if (x.isBuiltin()) {
	            vs._superTypes.push(mn);
	        }
	        else {
	            vs.addSuperType(mn);
	        }
	    });
	    if (t.isEmpty()) {
	        if (t.isArray() && t.superTypes().length == 1 && t.superTypes()[0].isAnonymous()) {
	            var q = vs.superTypes()[0];
	            q.setName(t.name());
	            q._subTypes = q._subTypes.filter(function (x) { return x != vs; });
	            vs = q;
	        }
	        if (t.isUnion() && t.superTypes().length == 1 && t.superTypes()[0].isAnonymous()) {
	            var q = vs.superTypes()[0];
	            q.setName(t.name());
	            q._subTypes = q._subTypes.filter(function (x) { return x != vs; });
	            vs = q;
	        }
	    }
	    t.putExtra(NOMINAL, vs);
	    var proto = parse.toProto(t);
	    proto.properties.forEach(function (x) {
	        var prop = pc ? pc(x.id) : new nt.Property(x.id);
	        prop.withDomain(vs);
	        prop.withRange(toNominal(x.type, callback));
	        if (!x.optional) {
	            prop.withRequired(true);
	        }
	    });
	    proto.facetDeclarations.forEach(function (x) {
	        var prop = pc ? pc(x.facetName()) : new nt.Property(x.facetName());
	        prop.withRange(toNominal(x.type(), callback));
	        vs.addFacet(prop);
	    });
	    t.customFacets().forEach(function (x) {
	        vs.fixFacet(x.facetName(), x.value());
	    });
	    vs.addAdapter(t);
	    if (t.isEmpty()) {
	        vs.addAdapter(new nt.Empty());
	    }
	    vs._validator = function (x) { return t.validate(x, false).getErrors(); };
	    if (t.isBuiltin()) {
	        vs.buildIn = true;
	    }
	    else {
	        t.subTypes().forEach(function (x) {
	            var ns = toNominal(x, callback, customizer);
	        });
	    }
	    return vs;
	}
	exports.toNominal = toNominal;
	//# sourceMappingURL=nominals.js.map

/***/ },
/* 97 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(global) {"use strict";
	var __extends = (this && this.__extends) || function (d, b) {
	    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
	    function __() { this.constructor = d; }
	    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
	};
	var ti = __webpack_require__(138);
	var tsInterfaces = __webpack_require__(91);
	var _ = __webpack_require__(139);
	global["extraInjectors"] = [];
	//var extraInjections:Injector[]=[];
	function registerInjector(i) {
	    //  extraInjections.push(i);
	    global["extraInjectors"].push(i);
	}
	exports.registerInjector = registerInjector;
	var Adaptable = (function () {
	    function Adaptable() {
	        var _this = this;
	        this.adapters = [];
	        global["extraInjectors"].forEach(function (x) { return x.inject(_this); });
	    }
	    Adaptable.prototype.addAdapter = function (q) {
	        this.adapters.push(q);
	    };
	    Adaptable.prototype.getAdapter = function (adapterType) {
	        var result = null;
	        this.adapters.forEach(function (x) {
	            if (x instanceof adapterType) {
	                result = x;
	            }
	        });
	        return result;
	    };
	    Adaptable.prototype.getAdapters = function () {
	        return this.adapters;
	    };
	    return Adaptable;
	}());
	exports.Adaptable = Adaptable;
	var Described = (function (_super) {
	    __extends(Described, _super);
	    function Described(_name, _description) {
	        if (_description === void 0) { _description = ""; }
	        _super.call(this);
	        this._name = _name;
	        this._description = _description;
	        this._tags = [];
	        this._annotations = [];
	    }
	    Described.prototype.nameId = function () { return this._name; };
	    Described.prototype.description = function () { return this._description; };
	    Described.prototype.addAnnotation = function (a) {
	        this._annotations.push(a);
	    };
	    Described.prototype.removeAnnotation = function (a) {
	        this._annotations = this._annotations.filter(function (x) { return x != a; });
	    };
	    Described.prototype.annotations = function () {
	        return [].concat(this._annotations);
	    };
	    Described.prototype.tags = function () {
	        return this._tags;
	    };
	    Described.prototype.withDescription = function (d) {
	        this._description = d;
	        return this;
	    };
	    Described.prototype.setName = function (name) {
	        this._name = name;
	    };
	    return Described;
	}(Adaptable));
	exports.Described = Described;
	var Annotation = (function (_super) {
	    __extends(Annotation, _super);
	    function Annotation(type, parameters) {
	        _super.call(this, type.nameId());
	        this.type = type;
	        this.parameters = parameters;
	    }
	    Annotation.prototype.parameterNames = function () {
	        return Object.keys(this.parameters);
	    };
	    Annotation.prototype.parameter = function (name) {
	        return this.parameters[name];
	    };
	    Annotation.prototype.getType = function () {
	        return this.type;
	    };
	    return Annotation;
	}(Described));
	exports.Annotation = Annotation;
	var Empty = (function () {
	    function Empty() {
	    }
	    return Empty;
	}());
	exports.Empty = Empty;
	var EmptyUniverse = (function () {
	    function EmptyUniverse() {
	    }
	    EmptyUniverse.prototype.type = function (name) {
	        return null;
	    };
	    EmptyUniverse.prototype.version = function () {
	        return "Empty";
	    };
	    EmptyUniverse.prototype.types = function () {
	        return [];
	    };
	    EmptyUniverse.prototype.matched = function () {
	        return {};
	    };
	    return EmptyUniverse;
	}());
	var emptyUniverse = new EmptyUniverse();
	var ebuilder = __webpack_require__(134);
	var AbstractType = (function (_super) {
	    __extends(AbstractType, _super);
	    function AbstractType(_name, _universe, _path) {
	        if (_universe === void 0) { _universe = emptyUniverse; }
	        if (_path === void 0) { _path = ""; }
	        _super.call(this, _name);
	        this._universe = _universe;
	        this._path = _path;
	        this._customProperties = [];
	        this._facets = [];
	        this._superTypes = [];
	        this._subTypes = [];
	        this._requirements = [];
	        this.fixedFacets = {};
	        this.uc = false;
	    }
	    AbstractType.prototype.properties = function () {
	        return [];
	    };
	    AbstractType.prototype.externalInHierarchy = function () {
	        var x = this.allSuperTypes();
	        var res = null;
	        x.forEach(function (y) {
	            if (y instanceof ExternalType) {
	                res = y;
	            }
	        });
	        return res;
	    };
	    AbstractType.prototype.addFacet = function (q) {
	        this._facets.push(q);
	    };
	    AbstractType.prototype.validate = function (x) {
	        if (!this._validator) {
	            throw new Error("Validate can be used only on runtime types instances");
	        }
	        return this._validator(x);
	    };
	    AbstractType.prototype.allFacets = function (ps) {
	        if (ps === void 0) { ps = {}; }
	        if (this._allFacets) {
	            return this._allFacets;
	        }
	        if (ps[this.nameId()]) {
	            return [];
	        }
	        ps[this.typeId()] = this;
	        var n = {};
	        if (this.superTypes().length > 0) {
	            this.superTypes().forEach(function (x) {
	                if (x instanceof AbstractType) {
	                    x.allFacets(ps).forEach(function (y) { return n[y.nameId()] = y; });
	                }
	            });
	        }
	        this._facets.forEach(function (x) { return n[x.nameId()] = x; });
	        //this.properties().forEach(x=>n[x.nameId()]=x);
	        this._allFacets = Object.keys(n).map(function (x) { return n[x]; });
	        return this._allFacets;
	    };
	    AbstractType.prototype.facets = function () {
	        return [].concat(this._facets);
	    };
	    AbstractType.prototype.facet = function (name) {
	        return _.find(this.allFacets(), function (x) { return x.nameId() == name; });
	    };
	    AbstractType.prototype.typeId = function () {
	        return this.nameId();
	    };
	    AbstractType.prototype.allProperties = function (ps) {
	        if (ps === void 0) { ps = {}; }
	        if (this._props) {
	            return this._props;
	        }
	        if (ps[this.typeId()]) {
	            return [];
	        }
	        ps[this.typeId()] = this;
	        var n = {};
	        if (this.superTypes().length > 0) {
	            this.superTypes().forEach(function (x) {
	                if (x instanceof AbstractType) {
	                    x.allProperties(ps).forEach(function (y) { return n[y.nameId()] = y; });
	                }
	                else {
	                    x.allProperties().forEach(function (y) { return n[y.nameId()] = y; });
	                }
	            });
	        }
	        for (var x in this.getFixedFacets()) {
	            delete n[x];
	        }
	        this.properties().forEach(function (x) { return n[x.nameId()] = x; });
	        this._props = Object.keys(n).map(function (x) { return n[x]; });
	        return this._props;
	    };
	    AbstractType.prototype.property = function (propName) {
	        return _.find(this.allProperties(), function (x) { return x.nameId() == propName; });
	    };
	    AbstractType.prototype.hasValueTypeInHierarchy = function () {
	        return _.find(this.allSuperTypes(), function (x) {
	            var mm = x;
	            if (mm.uc) {
	                return false;
	            }
	            mm.uc = true;
	            try {
	                return x.hasValueTypeInHierarchy();
	            }
	            finally {
	                mm.uc = false;
	            }
	        }) != null;
	    };
	    AbstractType.prototype.isAnnotationType = function () {
	        return false;
	    };
	    AbstractType.prototype.hasStructure = function () {
	        return false;
	    };
	    AbstractType.prototype.key = function () {
	        if (this._key) {
	            return this._key;
	        }
	        if (this._universe) {
	            this._key = this.universe().matched()[this.nameId()];
	            if (!this._key) {
	                return null;
	            }
	        }
	        return this._key;
	    };
	    AbstractType.prototype.hasArrayInHierarchy = function () {
	        var arr = _.find(this.allSuperTypes(), function (x) { return x instanceof Array; }) != null;
	        return arr;
	    };
	    AbstractType.prototype.arrayInHierarchy = function () {
	        var x = this.allSuperTypes();
	        var res = null;
	        x.forEach(function (y) {
	            if (y instanceof Array) {
	                res = y;
	            }
	        });
	        return res;
	    };
	    AbstractType.prototype.unionInHierarchy = function () {
	        var x = this.allSuperTypes();
	        var res = null;
	        x.forEach(function (y) {
	            if (y instanceof Union) {
	                res = y;
	            }
	        });
	        return res;
	    };
	    AbstractType.prototype.hasExternalInHierarchy = function () {
	        return _.find(this.allSuperTypes(), function (x) {
	            var mm = x;
	            if (mm.uc) {
	                return false;
	            }
	            mm.uc = true;
	            try {
	                return x instanceof ExternalType;
	            }
	            finally {
	                mm.uc = false;
	            }
	        }) != null;
	    };
	    AbstractType.prototype.hasUnionInHierarchy = function () {
	        return _.find(this.allSuperTypes(), function (x) {
	            var mm = x;
	            if (mm.uc) {
	                return false;
	            }
	            mm.uc = true;
	            try {
	                return x.hasUnionInHierarchy();
	            }
	            finally {
	                mm.uc = false;
	            }
	        }) != null;
	    };
	    AbstractType.prototype.fixFacet = function (name, v) {
	        this.fixedFacets[name] = v;
	    };
	    AbstractType.prototype.getFixedFacets = function () {
	        var mm = {};
	        for (var q in this.fixedFacets) {
	            mm[q] = this.fixedFacets[q];
	        }
	        this.contributeFacets(mm);
	        return mm;
	    };
	    AbstractType.prototype.allFixedFacets = function () {
	        if (this._af) {
	            return this._af;
	        }
	        var sp = this.allSuperTypes();
	        sp.push(this);
	        var mm = {};
	        sp.forEach(function (x) {
	            var ff = x.getFixedFacets();
	            for (var key in Object.keys(ff)) {
	                mm[key] = ff[key];
	            }
	        });
	        this._af = mm;
	        return mm;
	    };
	    AbstractType.prototype.contributeFacets = function (x) {
	    };
	    AbstractType.prototype.getPath = function () {
	        return this._path;
	    };
	    AbstractType.prototype.setNameAtRuntime = function (name) {
	        this._nameAtRuntime = name;
	    };
	    AbstractType.prototype.getNameAtRuntime = function () {
	        return this._nameAtRuntime;
	    };
	    AbstractType.prototype.universe = function () {
	        if (!this._universe) {
	            return new EmptyUniverse();
	        }
	        return this._universe;
	    };
	    AbstractType.prototype.superTypes = function () {
	        return [].concat(this._superTypes);
	    };
	    AbstractType.prototype.isAssignableFrom = function (typeName) {
	        if (this.nameId() == typeName) {
	            if (this.isUserDefined()) {
	                return false;
	            }
	            return true;
	        }
	        var currentSuperTypes = this.allSuperTypes();
	        for (var i = 0; i < currentSuperTypes.length; i++) {
	            if (currentSuperTypes[i].nameId() == typeName) {
	                return true;
	            }
	        }
	        return false;
	    };
	    AbstractType.prototype.annotationType = function () {
	        return null;
	    };
	    AbstractType.prototype.subTypes = function () {
	        return [].concat(this._subTypes);
	    };
	    AbstractType.prototype.allSubTypes = function () {
	        var rs = [];
	        this.subTypes().forEach(function (x) {
	            rs.push(x);
	            rs = rs.concat(x.allSubTypes());
	        });
	        return _.unique(rs);
	    };
	    AbstractType.prototype.allSuperTypes = function () {
	        if (this._allSupers) {
	            return this._allSupers;
	        }
	        var rs = [];
	        this.allSuperTypesRecurrent(this, {}, rs);
	        this._allSupers = _.unique(rs);
	        return this._allSupers;
	    };
	    AbstractType.prototype.allSuperTypesRecurrent = function (t, m, result) {
	        var _this = this;
	        t.superTypes().forEach(function (x) {
	            if (!m[x.typeId()]) {
	                result.push(x);
	                m[x.typeId()] = x;
	                _this.allSuperTypesRecurrent(x, m, result);
	            }
	        });
	    };
	    AbstractType.prototype.addSuperType = function (q) {
	        q._subTypes.push(this);
	        this._superTypes.push(q);
	    };
	    AbstractType.prototype.addRequirement = function (name, value) {
	        this._requirements.push(new ti.ValueRequirement(name, value));
	    };
	    //FIXME simplify it
	    AbstractType.prototype.valueRequirements = function () {
	        return this._requirements;
	    };
	    AbstractType.prototype.requiredProperties = function () {
	        return this.allProperties().filter(function (x) { return x.isRequired(); });
	    };
	    AbstractType.prototype.printDetails = function (indent, settings) {
	        var _this = this;
	        if (!indent) {
	            indent = "";
	        }
	        if (!settings) {
	            settings = {
	                hideProperties: false,
	                hideSuperTypeProperties: false,
	                printStandardSuperclasses: false
	            };
	        }
	        var standardIndent = "  ";
	        var result = "";
	        var className = this.getTypeClassName();
	        result += indent + this.nameId() + "[" + className + "]" + "\n";
	        var properties = this.properties();
	        if (properties && properties.length > 0 && !settings.hideProperties) {
	            result += indent + standardIndent + "Properties:\n";
	            properties.forEach(function (property) {
	                var propertyType = "";
	                var propertyRange = property.range();
	                if (propertyRange instanceof Described) {
	                    propertyType += propertyRange.nameId();
	                }
	                if (propertyRange instanceof AbstractType) {
	                    propertyType += "[";
	                    propertyType += propertyRange.getTypeClassName();
	                    propertyType += "]";
	                }
	                result += indent + standardIndent + standardIndent + property.nameId() + " : " + propertyType + "\n";
	            });
	        }
	        var superTypes = this.superTypes();
	        var filteredSuperTypes = superTypes;
	        if (superTypes && !settings.printStandardSuperclasses) {
	            filteredSuperTypes = _.filter(superTypes, function (superType) {
	                var name = superType instanceof Described ? superType.nameId() : "";
	                var type = superType instanceof AbstractType ?
	                    superType.getTypeClassName() : "";
	                return !_this.isStandardSuperclass(name, type);
	            });
	        }
	        if (filteredSuperTypes && filteredSuperTypes.length > 0) {
	            result += indent + standardIndent + "Super types:\n";
	            filteredSuperTypes.forEach(function (superType) {
	                result += superType.printDetails(indent + standardIndent + standardIndent, {
	                    hideProperties: settings.hideSuperTypeProperties,
	                    hideSuperTypeProperties: settings.hideSuperTypeProperties,
	                    printStandardSuperclasses: settings.printStandardSuperclasses
	                });
	            });
	        }
	        return result;
	    };
	    AbstractType.prototype.getTypeClassName = function () {
	        return this.constructor.toString().match(/\w+/g)[1];
	    };
	    AbstractType.prototype.isStandardSuperclass = function (nameId, className) {
	        if (nameId === "TypeDeclaration" && className === "NodeClass")
	            return true;
	        if (nameId === "ObjectTypeDeclaration" && className === "NodeClass")
	            return true;
	        if (nameId === "RAMLLanguageElement" && className === "NodeClass")
	            return true;
	        return false;
	    };
	    /**
	     * Returns example for this type.
	     * Returned example should be tested for being empty and being expandable.
	     */
	    AbstractType.prototype.examples = function () {
	        return ebuilder.exampleFromNominal(this);
	    };
	    /**
	     * Returns whether this type contain genuine user defined type in its hierarchy.
	     * Genuine user defined type is a type user intentionally defined and filled with
	     * properties or facets, or having user-defined name as opposed to a synthetic user-defined type.
	     */
	    AbstractType.prototype.isGenuineUserDefinedType = function () {
	        if (this.buildIn)
	            return false;
	        if (this.properties() && this.properties().length > 0)
	            return true;
	        if (this.getFixedFacets() && Object.keys(this.getFixedFacets()).length > 0)
	            return true;
	        return this.isTopLevel() && this.nameId() && this.nameId().length > 0;
	    };
	    /**
	     * Returns nearest genuine user-define type in the hierarchy.
	     * Genuine user defined type is a type user intentionally defined and filled with
	     * properties or facets, or having user-defined name as opposed to a synthetic user-defined type.
	     */
	    AbstractType.prototype.genuineUserDefinedTypeInHierarchy = function () {
	        if (this.isGenuineUserDefinedType())
	            return this;
	        var result = null;
	        var allSuperTypes = this.allSuperTypes();
	        allSuperTypes.forEach(function (currentSuperType) {
	            if (!result && currentSuperType.isGenuineUserDefinedType()) {
	                result = currentSuperType;
	            }
	        });
	        return result;
	    };
	    /**
	     * Returns whether this type contain genuine user defined type in its hierarchy.
	     * Genuine user defined type is a type user intentionally defined and filled with
	     * properties or facets, or having user-defined name as opposed to a synthetic user-defined type.
	     */
	    AbstractType.prototype.hasGenuineUserDefinedTypeInHierarchy = function () {
	        return _.find(this.allSuperTypes(), function (x) {
	            var mm = x;
	            if (mm.uc) {
	                return false;
	            }
	            mm.uc = true;
	            try {
	                return x.isGenuineUserDefinedType();
	            }
	            finally {
	                mm.uc = false;
	            }
	        }) != null;
	    };
	    AbstractType.prototype.customProperties = function () {
	        return [].concat(this._customProperties);
	    };
	    AbstractType.prototype.allCustomProperties = function () {
	        var props = [];
	        this.superTypes().forEach(function (x) { return props = props.concat(x.allCustomProperties()); });
	        props = props.concat(this.customProperties());
	        return props;
	    };
	    AbstractType.prototype.registerCustomProperty = function (p) {
	        if (p.domain() != this) {
	            throw new Error("Should be already owned by this");
	        }
	        if (this._customProperties.indexOf(p) != -1) {
	            throw new Error("Already included");
	        }
	        this._customProperties.push(p);
	    };
	    AbstractType.prototype.setCustom = function (val) {
	        this._isCustom = val;
	    };
	    AbstractType.prototype.isCustom = function () {
	        return this._isCustom;
	    };
	    AbstractType.prototype.isUnion = function () {
	        return false;
	    };
	    AbstractType.prototype.union = function () {
	        return null;
	    };
	    AbstractType.prototype.isExternal = function () {
	        return false;
	    };
	    AbstractType.prototype.external = function () {
	        return null;
	    };
	    AbstractType.prototype.isArray = function () {
	        return false;
	    };
	    AbstractType.prototype.isObject = function () {
	        if (this.nameId() == "object") {
	            return true;
	        }
	        for (var _i = 0, _a = this.allSuperTypes(); _i < _a.length; _i++) {
	            var t = _a[_i];
	            if (t.isObject()) {
	                return true;
	            }
	        }
	        return false;
	    };
	    AbstractType.prototype.array = function () {
	        return null;
	    };
	    AbstractType.prototype.isValueType = function () {
	        return false;
	    };
	    AbstractType.prototype.kind = function () {
	        var result = [];
	        if (this.isObject()) {
	            result.push("object");
	        }
	        if (this.isArray()) {
	            result.push("array");
	        }
	        if (this.isValueType()) {
	            result.push("value");
	        }
	        if (this.isUnion()) {
	            result.push("union");
	        }
	        if (this.isAnnotationType()) {
	            result.push("annotation");
	        }
	        if (this.isExternal()) {
	            result.push("external");
	        }
	        return result;
	    };
	    AbstractType.prototype.isBuiltIn = function () {
	        return this.buildIn;
	    };
	    AbstractType.prototype.setBuiltIn = function (builtIn) {
	        this.buildIn = builtIn;
	    };
	    AbstractType.prototype.isTopLevel = function () {
	        //TODO determine whether "topLevel" actually means a simple top-level type and
	        //this flag is absent due to a bug
	        if (this.getExtra(tsInterfaces.DEFINED_IN_TYPES_EXTRA) || this.getExtra(tsInterfaces.TOP_LEVEL_EXTRA))
	            return true;
	        return false;
	    };
	    AbstractType.prototype.isUserDefined = function () {
	        return this.getExtra(tsInterfaces.USER_DEFINED_EXTRA) && !this.buildIn;
	    };
	    AbstractType.prototype.putExtra = function (extraName, value) {
	        var extraAdapter = this.getExtraAdapter();
	        if (!extraAdapter)
	            return;
	        extraAdapter.putExtra(extraName, value);
	    };
	    AbstractType.prototype.getExtra = function (name) {
	        var extraAdapter = this.getExtraAdapter();
	        if (!extraAdapter)
	            return null;
	        return extraAdapter.getExtra(name);
	    };
	    AbstractType.prototype.getExtraAdapter = function () {
	        if (this.getAdapters()) {
	            var extraAdapter = _.find(this.getAdapters(), function (adapter) {
	                //weird duck-typing, but we can touch anything from nominal-types here
	                if (adapter.getExtra && typeof (adapter.getExtra) == "function"
	                    && adapter.putExtra && typeof (adapter.putExtra) == "function") {
	                    return true;
	                }
	            });
	            return extraAdapter;
	        }
	        return null;
	    };
	    return AbstractType;
	}(Described));
	exports.AbstractType = AbstractType;
	var ValueType = (function (_super) {
	    __extends(ValueType, _super);
	    function ValueType(name, _universe, path, description) {
	        if (_universe === void 0) { _universe = null; }
	        if (path === void 0) { path = ""; }
	        if (description === void 0) { description = ""; }
	        _super.call(this, name, _universe, path);
	    }
	    ValueType.prototype.hasStructure = function () {
	        return false;
	    };
	    ValueType.prototype.hasValueTypeInHierarchy = function () {
	        return true;
	    };
	    ValueType.prototype.isValueType = function () {
	        return true;
	    };
	    ValueType.prototype.isUnionType = function () {
	        return false;
	    };
	    ValueType.prototype.isObject = function () {
	        return false;
	    };
	    return ValueType;
	}(AbstractType));
	exports.ValueType = ValueType;
	var StructuredType = (function (_super) {
	    __extends(StructuredType, _super);
	    function StructuredType() {
	        _super.apply(this, arguments);
	        this._properties = [];
	    }
	    StructuredType.prototype.hasStructure = function () {
	        return true;
	    };
	    StructuredType.prototype.propertyIndex = function (name) {
	        var props = this.properties();
	        for (var i = 0; i < props.length; i++) {
	            if (props[i].nameId() == name)
	                return i;
	        }
	        return -1;
	    };
	    StructuredType.prototype.addProperty = function (name, range) {
	        return new Property(name).withDomain(this).withRange(range);
	    };
	    StructuredType.prototype.allPropertyIndex = function (name) {
	        var props = this.allProperties();
	        for (var i = 0; i < props.length; i++) {
	            if (props[i].nameId() == name)
	                return i;
	        }
	        return -1;
	    };
	    StructuredType.prototype.properties = function () {
	        return [].concat(this._properties);
	    };
	    StructuredType.prototype.registerProperty = function (p) {
	        if (p.domain() != this) {
	            throw new Error("Should be already owned by this");
	        }
	        if (this._properties.indexOf(p) != -1) {
	            throw new Error("Already included");
	        }
	        this._properties.push(p);
	    };
	    return StructuredType;
	}(AbstractType));
	exports.StructuredType = StructuredType;
	var Property = (function (_super) {
	    __extends(Property, _super);
	    function Property() {
	        _super.apply(this, arguments);
	        this._keyShouldStartFrom = null;
	        this._isRequired = false;
	        this._isMultiValue = false;
	        this._descriminates = false;
	        this._defaultBooleanValue = null;
	        this._defaultIntegerValue = null;
	    }
	    Property.prototype.withMultiValue = function (v) {
	        if (v === void 0) { v = true; }
	        this._isMultiValue = v;
	        return this;
	    };
	    Property.prototype.withDescriminating = function (b) {
	        this._descriminates = b;
	        return this;
	    };
	    Property.prototype.withRequired = function (req) {
	        this._isRequired = req;
	        return this;
	    };
	    Property.prototype.isRequired = function () {
	        return this._isRequired;
	    };
	    Property.prototype.withKeyRestriction = function (keyShouldStartFrom) {
	        this._keyShouldStartFrom = keyShouldStartFrom;
	        return this;
	    };
	    Property.prototype.withDomain = function (d, custom) {
	        if (custom === void 0) { custom = false; }
	        this._ownerClass = d;
	        if (custom) {
	            d.registerCustomProperty(this);
	        }
	        else {
	            d.registerProperty(this);
	        }
	        return this;
	    };
	    Property.prototype.setDefaultVal = function (s) {
	        this._defaultValue = s;
	        return this;
	    };
	    Property.prototype.setDefaultBooleanVal = function (s) {
	        this._defaultBooleanValue = s;
	        return this;
	    };
	    Property.prototype.setDefaultIntegerVal = function (s) {
	        this._defaultIntegerValue = s;
	        return this;
	    };
	    Property.prototype.defaultValue = function () {
	        if (this._defaultValue != null) {
	            return this._defaultValue;
	        }
	        else if (this._defaultBooleanValue != null) {
	            return this._defaultBooleanValue;
	        }
	        else if (this._defaultIntegerValue != null) {
	            return this._defaultIntegerValue;
	        }
	        return null;
	    };
	    Property.prototype.isPrimitive = function () {
	        return false;
	    };
	    Property.prototype.withRange = function (t) {
	        this._nodeRange = t;
	        return this;
	    };
	    Property.prototype.isValueProperty = function () {
	        return this._nodeRange.hasValueTypeInHierarchy();
	    };
	    Property.prototype.enumOptions = function () {
	        if (this._enumOptions && typeof this._enumOptions == 'string') {
	            return [this._enumOptions + ""];
	        }
	        return this._enumOptions;
	    };
	    Property.prototype.keyPrefix = function () {
	        return this._keyShouldStartFrom;
	    };
	    Property.prototype.withEnumOptions = function (op) {
	        this._enumOptions = op;
	        return this;
	    };
	    Property.prototype.withKeyRegexp = function (regexp) {
	        this._keyRegexp = regexp;
	        return this;
	    };
	    Property.prototype.getKeyRegexp = function () {
	        return this._keyRegexp;
	    };
	    Property.prototype.matchKey = function (k) {
	        if (k == null) {
	            return false;
	        }
	        if (this._groupName != null) {
	            return this._groupName == k;
	        }
	        else {
	            if (this._keyShouldStartFrom != null) {
	                if (k.indexOf(this._keyShouldStartFrom) == 0) {
	                    return true;
	                }
	            }
	            if (this._enumOptions) {
	                if (this._enumOptions.indexOf(k) != -1) {
	                    return true;
	                }
	            }
	            if (this.getKeyRegexp()) {
	                try {
	                    if (new RegExp(this.getKeyRegexp()).test(k)) {
	                        return true;
	                    }
	                }
	                catch (Error) {
	                }
	            }
	            return false;
	        }
	    };
	    Property.prototype.getFacetValidator = function () {
	        return this.facetValidator;
	    };
	    Property.prototype.setFacetValidator = function (f) {
	        this.facetValidator = f;
	    };
	    Property.prototype.domain = function () {
	        return this._ownerClass;
	    };
	    Property.prototype.range = function () {
	        return this._nodeRange;
	    };
	    Property.prototype.isMultiValue = function () {
	        if (this.range() && this.range().hasArrayInHierarchy()) {
	            return true;
	        }
	        return this._isMultiValue;
	    };
	    Property.prototype.isDescriminator = function () {
	        return this._descriminates;
	    };
	    return Property;
	}(Described));
	exports.Property = Property;
	var Union = (function (_super) {
	    __extends(Union, _super);
	    function Union() {
	        _super.apply(this, arguments);
	    }
	    Union.prototype.key = function () {
	        return null;
	    };
	    Union.prototype.leftType = function () {
	        return this.left;
	    };
	    Union.prototype.rightType = function () {
	        return this.right;
	    };
	    Union.prototype.isUserDefined = function () {
	        return true;
	    };
	    Union.prototype.unionInHierarchy = function () {
	        return this;
	    };
	    Union.prototype.union = function () {
	        return this;
	    };
	    Union.prototype.hasUnionInHierarchy = function () {
	        return true;
	    };
	    Union.prototype.isUnion = function () {
	        return true;
	    };
	    Union.prototype.isObject = function () {
	        return this.leftType().isObject() && this.rightType().isObject();
	    };
	    Union.prototype.hasArrayInHierarchy = function () {
	        if (this.left && this.right) {
	            return this.left.hasArrayInHierarchy() || this.right.hasArrayInHierarchy();
	        }
	        if (this.left) {
	            return this.left.hasArrayInHierarchy();
	        }
	        if (this.right) {
	            return this.right.hasArrayInHierarchy();
	        }
	    };
	    return Union;
	}(AbstractType));
	exports.Union = Union;
	var Array = (function (_super) {
	    __extends(Array, _super);
	    function Array() {
	        _super.apply(this, arguments);
	    }
	    Array.prototype.hasArrayInHierarchy = function () {
	        return true;
	    };
	    Array.prototype.isArray = function () {
	        return true;
	    };
	    Array.prototype.isObject = function () {
	        return false;
	    };
	    Array.prototype.arrayInHierarchy = function () {
	        return this;
	    };
	    Array.prototype.array = function () {
	        return this;
	    };
	    Array.prototype.isUserDefined = function () {
	        return true;
	    };
	    Array.prototype.componentType = function () {
	        return this.component;
	    };
	    Array.prototype.setComponent = function (t) {
	        this.component = t;
	    };
	    Array.prototype.key = function () {
	        return null;
	    };
	    return Array;
	}(AbstractType));
	exports.Array = Array;
	var ExternalType = (function (_super) {
	    __extends(ExternalType, _super);
	    function ExternalType() {
	        _super.apply(this, arguments);
	    }
	    ExternalType.prototype.externalInHierarchy = function () {
	        return this;
	    };
	    ExternalType.prototype.typeId = function () {
	        return this.schemaString;
	    };
	    ExternalType.prototype.schema = function () {
	        return this.schemaString;
	    };
	    ExternalType.prototype.isUserDefined = function () {
	        return true;
	    };
	    ExternalType.prototype.hasExternalInHierarchy = function () {
	        return true;
	    };
	    ExternalType.prototype.isExternal = function () {
	        return true;
	    };
	    ExternalType.prototype.external = function () {
	        return this;
	    };
	    return ExternalType;
	}(StructuredType));
	exports.ExternalType = ExternalType;
	//# sourceMappingURL=nominal-types.js.map
	/* WEBPACK VAR INJECTION */}.call(exports, (function() { return this; }())))

/***/ },
/* 98 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var te = __webpack_require__(136);
	function visit(node, action) {
	    te.visit(node, action);
	}
	exports.visit = visit;
	function serializeToString(node) {
	    return te.serializeToString(node);
	}
	exports.serializeToString = serializeToString;
	function parse(str) {
	    return te.parse(str);
	}
	exports.parse = parse;
	//# sourceMappingURL=typeExpressionUtil.js.map

/***/ },
/* 99 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(global) {"use strict";
	/// <reference path="../typings/main.d.ts" />
	var _ = __webpack_require__(139);
	var xmlValidator = __webpack_require__(140);
	var DOMParser = __webpack_require__(175).DOMParser;
	var ZSchema = __webpack_require__(187);
	var ValidationResult = (function () {
	    function ValidationResult() {
	    }
	    return ValidationResult;
	}());
	exports.ValidationResult = ValidationResult;
	var useLint = true;
	var ErrorsCache = (function () {
	    function ErrorsCache() {
	        this.errors = {};
	    }
	    ErrorsCache.prototype.getValue = function (key) {
	        return this.errors[key];
	    };
	    ErrorsCache.prototype.setValue = function (key, value) {
	        this.errors[key] = value;
	    };
	    return ErrorsCache;
	}());
	var globalCache = new ErrorsCache();
	global.cleanCache = function () {
	    globalCache = new ErrorsCache();
	};
	var DummyProvider = (function () {
	    function DummyProvider() {
	    }
	    DummyProvider.prototype.contextPath = function () {
	        return "";
	    };
	    DummyProvider.prototype.normalizePath = function (url) {
	        return "";
	    };
	    DummyProvider.prototype.content = function (reference) {
	        return "";
	    };
	    DummyProvider.prototype.hasAsyncRequests = function () {
	        return false;
	    };
	    DummyProvider.prototype.resolvePath = function (context, relativePath) {
	        return "";
	    };
	    DummyProvider.prototype.isAbsolutePath = function (uri) {
	        return false;
	    };
	    DummyProvider.prototype.contentAsync = function (reference) {
	        var _this = this;
	        return {
	            then: function (arg) { return arg(_this.content(reference)); },
	            resolve: function () { return null; }
	        };
	    };
	    DummyProvider.prototype.promiseResolve = function (arg) {
	        return {
	            then: function (arg1) { return arg1(arg); },
	            resolve: function () { return null; }
	        };
	    };
	    return DummyProvider;
	}());
	var JSONSchemaObject = (function () {
	    function JSONSchemaObject(schema, provider) {
	        this.schema = schema;
	        this.provider = provider;
	        if (!provider) {
	            this.provider = new DummyProvider();
	        }
	        else {
	            this.provider = provider;
	        }
	        if (!schema || schema.trim().length == 0 || schema.trim().charAt(0) != '{') {
	            throw new Error("Invalid JSON schema content");
	        }
	        var jsonSchemaObject;
	        try {
	            var jsonSchemaObject = JSON.parse(schema);
	        }
	        catch (err) {
	            throw new Error("It is not JSON schema(can not parse JSON:" + err.message + ")");
	        }
	        if (!jsonSchemaObject) {
	            return;
	        }
	        try {
	            var api = __webpack_require__(176);
	            this.setupId(jsonSchemaObject, this.provider.contextPath());
	            var schemaVer = "" + jsonSchemaObject["$schema"];
	            if (schemaVer.indexOf("http://json-schema.org/draft-04/") == -1) {
	                jsonSchemaObject = api.v4(jsonSchemaObject);
	            }
	            else {
	                this.fixRequired(jsonSchemaObject);
	            }
	        }
	        catch (e) {
	            throw new Error('Can not parse schema' + schema);
	        }
	        delete jsonSchemaObject['$schema'];
	        this.jsonSchema = jsonSchemaObject;
	    }
	    JSONSchemaObject.prototype.fixRequired = function (obj) {
	        // Object.keys(obj).forEach(x=>{
	        //     var val=obj[x];
	        //     if (x==="required"){
	        //         if (typeof val==="string"){
	        //             obj[x]=[val];
	        //         }
	        //     }
	        //     if (x==="properties"||x==="items"||x==="additionalItems"||x==="patternProperties"){
	        //         this.fixRequired(val);
	        //     }
	        //
	        // })
	    };
	    JSONSchemaObject.prototype.getType = function () {
	        return "source.json";
	    };
	    JSONSchemaObject.prototype.validateObject = function (object) {
	        //TODO Validation of objects
	        //xmlutil(content);
	        this.validate(JSON.stringify(object));
	    };
	    JSONSchemaObject.prototype.getMissingReferences = function (references, normalize) {
	        var _this = this;
	        if (normalize === void 0) { normalize = false; }
	        var result = [];
	        var validator = new ZSchema();
	        references.forEach(function (references) { return validator.setRemoteReference(references.reference, references.content || {}); });
	        var schemaUrl = null;
	        if (this.jsonSchema.id && typeof (this.jsonSchema.id) === "string") {
	            schemaUrl = this.jsonSchema.id;
	            var innerPos = schemaUrl.indexOf("#");
	            if (innerPos != -1) {
	                schemaUrl = schemaUrl.substr(0, innerPos);
	            }
	        }
	        try {
	            validator.validateSchema(this.jsonSchema);
	        }
	        catch (Error) {
	            //we should never be exploding here, instead we'll report this error later
	            return [];
	        }
	        var result = validator.getMissingRemoteReferences();
	        var filteredReferences = [];
	        if (result)
	            filteredReferences = _.filter(result, function (referenceUrl) {
	                return validator.cache[referenceUrl] == null && referenceUrl != schemaUrl;
	            });
	        return normalize ? filteredReferences.map(function (reference) { return _this.provider.normalizePath(reference); }) : filteredReferences;
	    };
	    JSONSchemaObject.prototype.getSchemaPath = function (schema, normalize) {
	        if (normalize === void 0) { normalize = false; }
	        if (!schema) {
	            return "";
	        }
	        if (!schema.id) {
	            return "";
	        }
	        var id = schema.id.trim();
	        if (!(id.lastIndexOf('#') === id.length - 1)) {
	            return id;
	        }
	        var result = id.substr(0, id.length - 1);
	        if (!normalize) {
	            return result;
	        }
	        return this.provider.normalizePath(result);
	    };
	    JSONSchemaObject.prototype.patchSchema = function (schema) {
	        var _this = this;
	        if (!schema) {
	            return schema;
	        }
	        if (!schema.id) {
	            return schema;
	        }
	        var id = schema.id.trim();
	        if (!(id.lastIndexOf('#') === id.length - 1)) {
	            id = id + '#';
	            schema.id = id;
	        }
	        ;
	        var currentPath = id.substr(0, id.length - 1);
	        if (!this.provider.isAbsolutePath(currentPath)) {
	            return schema;
	        }
	        currentPath = this.provider.normalizePath(currentPath);
	        var refContainers = [];
	        this.collectRefContainers(schema, refContainers);
	        refContainers.forEach(function (refConatiner) {
	            var reference = refConatiner['$ref'];
	            if (typeof reference !== 'string') {
	                return;
	            }
	            if (reference.indexOf('#') === 0) {
	                return;
	            }
	            if (reference.indexOf('#') === -1) {
	                reference = reference + '#';
	            }
	            if (!_this.provider.isAbsolutePath(reference)) {
	                refConatiner['$ref'] = _this.provider.resolvePath(currentPath, reference).replace(/\\/g, '/');
	            }
	        });
	    };
	    JSONSchemaObject.prototype.collectRefContainers = function (rootObject, refContainers) {
	        var _this = this;
	        Object.keys(rootObject).forEach(function (key) {
	            if (key === '$ref') {
	                refContainers.push(rootObject);
	                return;
	            }
	            if (!rootObject[key]) {
	                return;
	            }
	            if (typeof rootObject[key] === 'object') {
	                _this.collectRefContainers(rootObject[key], refContainers);
	            }
	        });
	    };
	    JSONSchemaObject.prototype.validate = function (content, alreadyAccepted) {
	        var _this = this;
	        if (alreadyAccepted === void 0) { alreadyAccepted = []; }
	        var key = content + this.schema + this.provider.contextPath();
	        var error = globalCache.getValue(key);
	        if (error) {
	            if (error instanceof Error) {
	                throw error;
	            }
	            return;
	        }
	        var validator = new ZSchema();
	        alreadyAccepted.forEach(function (accepted) { return validator.setRemoteReference(accepted.reference, accepted.content); });
	        validator.validate(JSON.parse(content), this.jsonSchema);
	        var missingReferences = validator.getMissingRemoteReferences().filter(function (reference) { return !_.find(alreadyAccepted, function (acceptedReference) { return reference === acceptedReference.reference; }); });
	        if (!missingReferences || missingReferences.length === 0) {
	            this.acceptErrors(key, validator.getLastErrors(), true);
	            return;
	        }
	        var acceptedReferences = [];
	        missingReferences.forEach(function (reference) {
	            var remoteSchemeContent;
	            var result = { reference: reference };
	            try {
	                var api = __webpack_require__(176);
	                var jsonObject = JSON.parse(_this.provider.content(reference));
	                _this.setupId(jsonObject, _this.provider.normalizePath(reference));
	                remoteSchemeContent = api.v4(jsonObject);
	                delete remoteSchemeContent['$schema'];
	                result.content = remoteSchemeContent;
	            }
	            catch (exception) {
	                result.error = exception;
	            }
	            finally {
	                acceptedReferences.push(result);
	            }
	        });
	        if (this.provider.hasAsyncRequests()) {
	            return;
	        }
	        acceptedReferences.forEach(function (accepted) {
	            alreadyAccepted.push(accepted);
	        });
	        this.validate(content, alreadyAccepted);
	    };
	    JSONSchemaObject.prototype.setupId = function (json, path) {
	        if (!path) {
	            return;
	        }
	        if (!json) {
	            return;
	        }
	        if (json.id) {
	            return;
	        }
	        json.id = path.replace(/\\/g, '/') + '#';
	        this.patchSchema(json);
	    };
	    JSONSchemaObject.prototype.acceptErrors = function (key, errors, throwImmediately) {
	        if (throwImmediately === void 0) { throwImmediately = false; }
	        if (errors && errors.length > 0) {
	            var res = new Error("Content is not valid according to schema:" + errors.map(function (x) { return x.message + " " + x.params; }).join(", "));
	            res.errors = errors;
	            globalCache.setValue(key, res);
	            if (throwImmediately) {
	                throw res;
	            }
	            return;
	        }
	        globalCache.setValue(key, 1);
	    };
	    JSONSchemaObject.prototype.contentAsync = function (reference) {
	        var _this = this;
	        var remoteSchemeContent;
	        var api = __webpack_require__(176);
	        var contentPromise = this.provider.contentAsync(reference);
	        if (!contentPromise) {
	            return this.provider.promiseResolve({
	                reference: reference,
	                content: null,
	                error: new Error('Reference not found: ' + reference)
	            });
	        }
	        var result = contentPromise.then(function (cnt) {
	            var content = { reference: reference };
	            try {
	                var jsonObject = JSON.parse(cnt);
	                _this.setupId(jsonObject, _this.provider.normalizePath(reference));
	                remoteSchemeContent = api.v4(jsonObject);
	                delete remoteSchemeContent['$schema'];
	                content.content = remoteSchemeContent;
	            }
	            catch (exception) {
	                content.error = exception;
	            }
	            return content;
	        });
	        return result;
	    };
	    return JSONSchemaObject;
	}());
	exports.JSONSchemaObject = JSONSchemaObject;
	var MAX_EXAMPLES_TRESHOLD = 10;
	var XMLSchemaObject = (function () {
	    function XMLSchemaObject(schema) {
	        this.schema = schema;
	        this.extraElementData = null;
	        this.contentToResult = {};
	        if (schema.charAt(0) != '<') {
	            throw new Error("Invalid JSON schema");
	        }
	        this.schemaObj = new xmlValidator.XMLValidator(this.handleReferenceElement(schema));
	    }
	    XMLSchemaObject.prototype.getType = function () {
	        return "text.xml";
	    };
	    XMLSchemaObject.prototype.validateObject = function (object) {
	        if (this.extraElementData) {
	            var objectName = Object.keys(object)[0];
	            if (!this.extraElementData.type && !this.extraElementData.originalName) {
	                this.acceptErrors("key", [new Error('Referenced type "' + this.extraElementData.requestedName + '" is not match with "' + objectName + '" root node')], true);
	                return;
	            }
	            if (this.extraElementData.originalName && objectName !== this.extraElementData.originalName) {
	                this.acceptErrors("key", [new Error('Referenced type "' + this.extraElementData.requestedName + '" is not match with "' + objectName + '" root node')], true);
	                return;
	            }
	            if (this.extraElementData.type) {
	                var root = object[objectName];
	                delete object[objectName];
	                object[this.extraElementData.name] = root;
	            }
	        }
	        this.validate(xmlValidator.jsonToXml(object));
	    };
	    XMLSchemaObject.prototype.validate = function (xml) {
	        try {
	            var rs = this.contentToResult[xml];
	            if (rs === false) {
	                return;
	            }
	            if (rs) {
	                throw rs;
	            }
	            var validationErrors = this.schemaObj.validate(xml);
	            this.acceptErrors("key", validationErrors, true);
	            this.contentToResult[xml] = false;
	            if (Object.keys(this.contentToResult).length > MAX_EXAMPLES_TRESHOLD) {
	                this.contentToResult = {};
	            }
	        }
	        catch (e) {
	            this.contentToResult[xml] = e;
	            throw e;
	        }
	    };
	    XMLSchemaObject.prototype.handleReferenceElement = function (content) {
	        var doc = new DOMParser().parseFromString(content);
	        var schema = elementChildrenByName(doc, 'xs:schema')[0];
	        var elements = elementChildrenByName(schema, 'xs:element');
	        var element = _.find(elements, function (element) { return element.getAttribute('extraelement') === 'true'; });
	        if (!element) {
	            return content;
	        }
	        var extraElementData = {};
	        extraElementData.name = element.getAttribute('name');
	        extraElementData.type = element.getAttribute('type');
	        extraElementData.originalName = element.getAttribute('originalname');
	        extraElementData.requestedName = element.getAttribute('requestedname');
	        if (!extraElementData.type) {
	            schema.removeChild(element);
	        }
	        element.removeAttribute('originalname');
	        element.removeAttribute('requestedname');
	        element.removeAttribute('extraelement');
	        this.extraElementData = extraElementData;
	        return doc.toString();
	    };
	    XMLSchemaObject.prototype.acceptErrors = function (key, errors, throwImmediately) {
	        if (throwImmediately === void 0) { throwImmediately = false; }
	        if (errors && errors.length > 0) {
	            var res = new Error("Content is not valid according to schema:" + errors.map(function (x) { return x.message; }).join(", "));
	            res.errors = errors;
	            globalCache.setValue(key, res);
	            if (throwImmediately) {
	                throw res;
	            }
	            return;
	        }
	    };
	    return XMLSchemaObject;
	}());
	exports.XMLSchemaObject = XMLSchemaObject;
	function getJSONSchema(content, provider) {
	    var rs = useLint ? globalCache.getValue(content) : false;
	    if (rs && rs.provider) {
	        return rs;
	    }
	    var res = new JSONSchemaObject(content, provider);
	    globalCache.setValue(content, res);
	    return res;
	}
	exports.getJSONSchema = getJSONSchema;
	function getXMLSchema(content) {
	    var rs = useLint ? globalCache.getValue(content) : false;
	    if (rs) {
	        return rs;
	    }
	    var res = new XMLSchemaObject(content);
	    if (useLint) {
	        globalCache.setValue(content, res);
	    }
	    return res;
	}
	exports.getXMLSchema = getXMLSchema;
	function createSchema(content, provider) {
	    var rs = useLint ? globalCache.getValue(content) : false;
	    if (rs) {
	        return rs;
	    }
	    try {
	        var res = new JSONSchemaObject(content, provider);
	        if (useLint) {
	            globalCache.setValue(content, res);
	        }
	        return res;
	    }
	    catch (e) {
	        try {
	            var res = new XMLSchemaObject(content);
	            if (useLint) {
	                globalCache.setValue(content, res);
	            }
	            return res;
	        }
	        catch (e) {
	            if (useLint) {
	                globalCache.setValue(content, new Error("Can not parse schema"));
	            }
	            return null;
	        }
	    }
	}
	exports.createSchema = createSchema;
	function elementChildrenByName(parent, tagName) {
	    var elements = parent.getElementsByTagName(tagName);
	    var result = [];
	    for (var i = 0; i < elements.length; i++) {
	        var child = elements[i];
	        if (child.parentNode === parent) {
	            result.push(child);
	        }
	    }
	    return result;
	}
	//# sourceMappingURL=schemaUtil.js.map
	/* WEBPACK VAR INJECTION */}.call(exports, (function() { return this; }())))

/***/ },
/* 100 */
/***/ function(module, exports, __webpack_require__) {

	var __WEBPACK_AMD_DEFINE_RESULT__;/* WEBPACK VAR INJECTION */(function(module, global) {/*! https://mths.be/punycode v1.3.2 by @mathias */
	;(function(root) {

		/** Detect free variables */
		var freeExports = typeof exports == 'object' && exports &&
			!exports.nodeType && exports;
		var freeModule = typeof module == 'object' && module &&
			!module.nodeType && module;
		var freeGlobal = typeof global == 'object' && global;
		if (
			freeGlobal.global === freeGlobal ||
			freeGlobal.window === freeGlobal ||
			freeGlobal.self === freeGlobal
		) {
			root = freeGlobal;
		}

		/**
		 * The `punycode` object.
		 * @name punycode
		 * @type Object
		 */
		var punycode,

		/** Highest positive signed 32-bit float value */
		maxInt = 2147483647, // aka. 0x7FFFFFFF or 2^31-1

		/** Bootstring parameters */
		base = 36,
		tMin = 1,
		tMax = 26,
		skew = 38,
		damp = 700,
		initialBias = 72,
		initialN = 128, // 0x80
		delimiter = '-', // '\x2D'

		/** Regular expressions */
		regexPunycode = /^xn--/,
		regexNonASCII = /[^\x20-\x7E]/, // unprintable ASCII chars + non-ASCII chars
		regexSeparators = /[\x2E\u3002\uFF0E\uFF61]/g, // RFC 3490 separators

		/** Error messages */
		errors = {
			'overflow': 'Overflow: input needs wider integers to process',
			'not-basic': 'Illegal input >= 0x80 (not a basic code point)',
			'invalid-input': 'Invalid input'
		},

		/** Convenience shortcuts */
		baseMinusTMin = base - tMin,
		floor = Math.floor,
		stringFromCharCode = String.fromCharCode,

		/** Temporary variable */
		key;

		/*--------------------------------------------------------------------------*/

		/**
		 * A generic error utility function.
		 * @private
		 * @param {String} type The error type.
		 * @returns {Error} Throws a `RangeError` with the applicable error message.
		 */
		function error(type) {
			throw RangeError(errors[type]);
		}

		/**
		 * A generic `Array#map` utility function.
		 * @private
		 * @param {Array} array The array to iterate over.
		 * @param {Function} callback The function that gets called for every array
		 * item.
		 * @returns {Array} A new array of values returned by the callback function.
		 */
		function map(array, fn) {
			var length = array.length;
			var result = [];
			while (length--) {
				result[length] = fn(array[length]);
			}
			return result;
		}

		/**
		 * A simple `Array#map`-like wrapper to work with domain name strings or email
		 * addresses.
		 * @private
		 * @param {String} domain The domain name or email address.
		 * @param {Function} callback The function that gets called for every
		 * character.
		 * @returns {Array} A new string of characters returned by the callback
		 * function.
		 */
		function mapDomain(string, fn) {
			var parts = string.split('@');
			var result = '';
			if (parts.length > 1) {
				// In email addresses, only the domain name should be punycoded. Leave
				// the local part (i.e. everything up to `@`) intact.
				result = parts[0] + '@';
				string = parts[1];
			}
			// Avoid `split(regex)` for IE8 compatibility. See #17.
			string = string.replace(regexSeparators, '\x2E');
			var labels = string.split('.');
			var encoded = map(labels, fn).join('.');
			return result + encoded;
		}

		/**
		 * Creates an array containing the numeric code points of each Unicode
		 * character in the string. While JavaScript uses UCS-2 internally,
		 * this function will convert a pair of surrogate halves (each of which
		 * UCS-2 exposes as separate characters) into a single code point,
		 * matching UTF-16.
		 * @see `punycode.ucs2.encode`
		 * @see <https://mathiasbynens.be/notes/javascript-encoding>
		 * @memberOf punycode.ucs2
		 * @name decode
		 * @param {String} string The Unicode input string (UCS-2).
		 * @returns {Array} The new array of code points.
		 */
		function ucs2decode(string) {
			var output = [],
			    counter = 0,
			    length = string.length,
			    value,
			    extra;
			while (counter < length) {
				value = string.charCodeAt(counter++);
				if (value >= 0xD800 && value <= 0xDBFF && counter < length) {
					// high surrogate, and there is a next character
					extra = string.charCodeAt(counter++);
					if ((extra & 0xFC00) == 0xDC00) { // low surrogate
						output.push(((value & 0x3FF) << 10) + (extra & 0x3FF) + 0x10000);
					} else {
						// unmatched surrogate; only append this code unit, in case the next
						// code unit is the high surrogate of a surrogate pair
						output.push(value);
						counter--;
					}
				} else {
					output.push(value);
				}
			}
			return output;
		}

		/**
		 * Creates a string based on an array of numeric code points.
		 * @see `punycode.ucs2.decode`
		 * @memberOf punycode.ucs2
		 * @name encode
		 * @param {Array} codePoints The array of numeric code points.
		 * @returns {String} The new Unicode string (UCS-2).
		 */
		function ucs2encode(array) {
			return map(array, function(value) {
				var output = '';
				if (value > 0xFFFF) {
					value -= 0x10000;
					output += stringFromCharCode(value >>> 10 & 0x3FF | 0xD800);
					value = 0xDC00 | value & 0x3FF;
				}
				output += stringFromCharCode(value);
				return output;
			}).join('');
		}

		/**
		 * Converts a basic code point into a digit/integer.
		 * @see `digitToBasic()`
		 * @private
		 * @param {Number} codePoint The basic numeric code point value.
		 * @returns {Number} The numeric value of a basic code point (for use in
		 * representing integers) in the range `0` to `base - 1`, or `base` if
		 * the code point does not represent a value.
		 */
		function basicToDigit(codePoint) {
			if (codePoint - 48 < 10) {
				return codePoint - 22;
			}
			if (codePoint - 65 < 26) {
				return codePoint - 65;
			}
			if (codePoint - 97 < 26) {
				return codePoint - 97;
			}
			return base;
		}

		/**
		 * Converts a digit/integer into a basic code point.
		 * @see `basicToDigit()`
		 * @private
		 * @param {Number} digit The numeric value of a basic code point.
		 * @returns {Number} The basic code point whose value (when used for
		 * representing integers) is `digit`, which needs to be in the range
		 * `0` to `base - 1`. If `flag` is non-zero, the uppercase form is
		 * used; else, the lowercase form is used. The behavior is undefined
		 * if `flag` is non-zero and `digit` has no uppercase form.
		 */
		function digitToBasic(digit, flag) {
			//  0..25 map to ASCII a..z or A..Z
			// 26..35 map to ASCII 0..9
			return digit + 22 + 75 * (digit < 26) - ((flag != 0) << 5);
		}

		/**
		 * Bias adaptation function as per section 3.4 of RFC 3492.
		 * http://tools.ietf.org/html/rfc3492#section-3.4
		 * @private
		 */
		function adapt(delta, numPoints, firstTime) {
			var k = 0;
			delta = firstTime ? floor(delta / damp) : delta >> 1;
			delta += floor(delta / numPoints);
			for (/* no initialization */; delta > baseMinusTMin * tMax >> 1; k += base) {
				delta = floor(delta / baseMinusTMin);
			}
			return floor(k + (baseMinusTMin + 1) * delta / (delta + skew));
		}

		/**
		 * Converts a Punycode string of ASCII-only symbols to a string of Unicode
		 * symbols.
		 * @memberOf punycode
		 * @param {String} input The Punycode string of ASCII-only symbols.
		 * @returns {String} The resulting string of Unicode symbols.
		 */
		function decode(input) {
			// Don't use UCS-2
			var output = [],
			    inputLength = input.length,
			    out,
			    i = 0,
			    n = initialN,
			    bias = initialBias,
			    basic,
			    j,
			    index,
			    oldi,
			    w,
			    k,
			    digit,
			    t,
			    /** Cached calculation results */
			    baseMinusT;

			// Handle the basic code points: let `basic` be the number of input code
			// points before the last delimiter, or `0` if there is none, then copy
			// the first basic code points to the output.

			basic = input.lastIndexOf(delimiter);
			if (basic < 0) {
				basic = 0;
			}

			for (j = 0; j < basic; ++j) {
				// if it's not a basic code point
				if (input.charCodeAt(j) >= 0x80) {
					error('not-basic');
				}
				output.push(input.charCodeAt(j));
			}

			// Main decoding loop: start just after the last delimiter if any basic code
			// points were copied; start at the beginning otherwise.

			for (index = basic > 0 ? basic + 1 : 0; index < inputLength; /* no final expression */) {

				// `index` is the index of the next character to be consumed.
				// Decode a generalized variable-length integer into `delta`,
				// which gets added to `i`. The overflow checking is easier
				// if we increase `i` as we go, then subtract off its starting
				// value at the end to obtain `delta`.
				for (oldi = i, w = 1, k = base; /* no condition */; k += base) {

					if (index >= inputLength) {
						error('invalid-input');
					}

					digit = basicToDigit(input.charCodeAt(index++));

					if (digit >= base || digit > floor((maxInt - i) / w)) {
						error('overflow');
					}

					i += digit * w;
					t = k <= bias ? tMin : (k >= bias + tMax ? tMax : k - bias);

					if (digit < t) {
						break;
					}

					baseMinusT = base - t;
					if (w > floor(maxInt / baseMinusT)) {
						error('overflow');
					}

					w *= baseMinusT;

				}

				out = output.length + 1;
				bias = adapt(i - oldi, out, oldi == 0);

				// `i` was supposed to wrap around from `out` to `0`,
				// incrementing `n` each time, so we'll fix that now:
				if (floor(i / out) > maxInt - n) {
					error('overflow');
				}

				n += floor(i / out);
				i %= out;

				// Insert `n` at position `i` of the output
				output.splice(i++, 0, n);

			}

			return ucs2encode(output);
		}

		/**
		 * Converts a string of Unicode symbols (e.g. a domain name label) to a
		 * Punycode string of ASCII-only symbols.
		 * @memberOf punycode
		 * @param {String} input The string of Unicode symbols.
		 * @returns {String} The resulting Punycode string of ASCII-only symbols.
		 */
		function encode(input) {
			var n,
			    delta,
			    handledCPCount,
			    basicLength,
			    bias,
			    j,
			    m,
			    q,
			    k,
			    t,
			    currentValue,
			    output = [],
			    /** `inputLength` will hold the number of code points in `input`. */
			    inputLength,
			    /** Cached calculation results */
			    handledCPCountPlusOne,
			    baseMinusT,
			    qMinusT;

			// Convert the input in UCS-2 to Unicode
			input = ucs2decode(input);

			// Cache the length
			inputLength = input.length;

			// Initialize the state
			n = initialN;
			delta = 0;
			bias = initialBias;

			// Handle the basic code points
			for (j = 0; j < inputLength; ++j) {
				currentValue = input[j];
				if (currentValue < 0x80) {
					output.push(stringFromCharCode(currentValue));
				}
			}

			handledCPCount = basicLength = output.length;

			// `handledCPCount` is the number of code points that have been handled;
			// `basicLength` is the number of basic code points.

			// Finish the basic string - if it is not empty - with a delimiter
			if (basicLength) {
				output.push(delimiter);
			}

			// Main encoding loop:
			while (handledCPCount < inputLength) {

				// All non-basic code points < n have been handled already. Find the next
				// larger one:
				for (m = maxInt, j = 0; j < inputLength; ++j) {
					currentValue = input[j];
					if (currentValue >= n && currentValue < m) {
						m = currentValue;
					}
				}

				// Increase `delta` enough to advance the decoder's <n,i> state to <m,0>,
				// but guard against overflow
				handledCPCountPlusOne = handledCPCount + 1;
				if (m - n > floor((maxInt - delta) / handledCPCountPlusOne)) {
					error('overflow');
				}

				delta += (m - n) * handledCPCountPlusOne;
				n = m;

				for (j = 0; j < inputLength; ++j) {
					currentValue = input[j];

					if (currentValue < n && ++delta > maxInt) {
						error('overflow');
					}

					if (currentValue == n) {
						// Represent delta as a generalized variable-length integer
						for (q = delta, k = base; /* no condition */; k += base) {
							t = k <= bias ? tMin : (k >= bias + tMax ? tMax : k - bias);
							if (q < t) {
								break;
							}
							qMinusT = q - t;
							baseMinusT = base - t;
							output.push(
								stringFromCharCode(digitToBasic(t + qMinusT % baseMinusT, 0))
							);
							q = floor(qMinusT / baseMinusT);
						}

						output.push(stringFromCharCode(digitToBasic(q, 0)));
						bias = adapt(delta, handledCPCountPlusOne, handledCPCount == basicLength);
						delta = 0;
						++handledCPCount;
					}
				}

				++delta;
				++n;

			}
			return output.join('');
		}

		/**
		 * Converts a Punycode string representing a domain name or an email address
		 * to Unicode. Only the Punycoded parts of the input will be converted, i.e.
		 * it doesn't matter if you call it on a string that has already been
		 * converted to Unicode.
		 * @memberOf punycode
		 * @param {String} input The Punycoded domain name or email address to
		 * convert to Unicode.
		 * @returns {String} The Unicode representation of the given Punycode
		 * string.
		 */
		function toUnicode(input) {
			return mapDomain(input, function(string) {
				return regexPunycode.test(string)
					? decode(string.slice(4).toLowerCase())
					: string;
			});
		}

		/**
		 * Converts a Unicode string representing a domain name or an email address to
		 * Punycode. Only the non-ASCII parts of the domain name will be converted,
		 * i.e. it doesn't matter if you call it with a domain that's already in
		 * ASCII.
		 * @memberOf punycode
		 * @param {String} input The domain name or email address to convert, as a
		 * Unicode string.
		 * @returns {String} The Punycode representation of the given domain name or
		 * email address.
		 */
		function toASCII(input) {
			return mapDomain(input, function(string) {
				return regexNonASCII.test(string)
					? 'xn--' + encode(string)
					: string;
			});
		}

		/*--------------------------------------------------------------------------*/

		/** Define the public API */
		punycode = {
			/**
			 * A string representing the current Punycode.js version number.
			 * @memberOf punycode
			 * @type String
			 */
			'version': '1.3.2',
			/**
			 * An object of methods to convert from JavaScript's internal character
			 * representation (UCS-2) to Unicode code points, and back.
			 * @see <https://mathiasbynens.be/notes/javascript-encoding>
			 * @memberOf punycode
			 * @type Object
			 */
			'ucs2': {
				'decode': ucs2decode,
				'encode': ucs2encode
			},
			'decode': decode,
			'encode': encode,
			'toASCII': toASCII,
			'toUnicode': toUnicode
		};

		/** Expose `punycode` */
		// Some AMD build optimizers, like r.js, check for specific condition patterns
		// like the following:
		if (
			true
		) {
			!(__WEBPACK_AMD_DEFINE_RESULT__ = function() {
				return punycode;
			}.call(exports, __webpack_require__, exports, module), __WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
		} else if (freeExports && freeModule) {
			if (module.exports == freeExports) { // in Node.js or RingoJS v0.8.0+
				freeModule.exports = punycode;
			} else { // in Narwhal or RingoJS v0.7.0-
				for (key in punycode) {
					punycode.hasOwnProperty(key) && (freeExports[key] = punycode[key]);
				}
			}
		} else { // in Rhino or a web browser
			root.punycode = punycode;
		}

	}(this));
	
	/* WEBPACK VAR INJECTION */}.call(exports, __webpack_require__(169)(module), (function() { return this; }())))

/***/ },
/* 101 */
/***/ function(module, exports, __webpack_require__) {

	var Stream = (function (){
	  try {
	    return __webpack_require__(165); // hack to fix a circular dependency issue when used with browserify
	  } catch(_){}
	}());
	exports = module.exports = __webpack_require__(141);
	exports.Stream = Stream || exports;
	exports.Readable = exports;
	exports.Writable = __webpack_require__(142);
	exports.Duplex = __webpack_require__(143);
	exports.Transform = __webpack_require__(144);
	exports.PassThrough = __webpack_require__(145);


/***/ },
/* 102 */
/***/ function(module, exports, __webpack_require__) {

	if (typeof Object.create === 'function') {
	  // implementation from standard node.js 'util' module
	  module.exports = function inherits(ctor, superCtor) {
	    ctor.super_ = superCtor
	    ctor.prototype = Object.create(superCtor.prototype, {
	      constructor: {
	        value: ctor,
	        enumerable: false,
	        writable: true,
	        configurable: true
	      }
	    });
	  };
	} else {
	  // old school shim for old browsers
	  module.exports = function inherits(ctor, superCtor) {
	    ctor.super_ = superCtor
	    var TempCtor = function () {}
	    TempCtor.prototype = superCtor.prototype
	    ctor.prototype = new TempCtor()
	    ctor.prototype.constructor = ctor
	  }
	}


/***/ },
/* 103 */
/***/ function(module, exports, __webpack_require__) {

	exports.parse = __webpack_require__(146);
	exports.stringify = __webpack_require__(147);


/***/ },
/* 104 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	module.exports = __webpack_require__(148)


/***/ },
/* 105 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	(function (Kind) {
	    Kind[Kind["SCALAR"] = 0] = "SCALAR";
	    Kind[Kind["MAPPING"] = 1] = "MAPPING";
	    Kind[Kind["MAP"] = 2] = "MAP";
	    Kind[Kind["SEQ"] = 3] = "SEQ";
	    Kind[Kind["ANCHOR_REF"] = 4] = "ANCHOR_REF";
	    Kind[Kind["INCLUDE_REF"] = 5] = "INCLUDE_REF";
	})(exports.Kind || (exports.Kind = {}));
	var Kind = exports.Kind;
	function newMapping(key, value) {
	    var end = (value ? value.endPosition : key.endPosition + 1);
	    var node = {
	        key: key,
	        value: value,
	        startPosition: key.startPosition,
	        endPosition: end,
	        kind: Kind.MAPPING,
	        parent: null,
	        errors: []
	    };
	    return node;
	}
	exports.newMapping = newMapping;
	function newAnchorRef(key, start, end, value) {
	    return {
	        errors: [],
	        referencesAnchor: key,
	        value: value,
	        startPosition: start,
	        endPosition: end,
	        kind: Kind.ANCHOR_REF,
	        parent: null
	    };
	}
	exports.newAnchorRef = newAnchorRef;
	function newScalar(v) {
	    if (v === void 0) { v = ""; }
	    return {
	        errors: [],
	        startPosition: -1,
	        endPosition: -1,
	        value: v,
	        kind: Kind.SCALAR,
	        parent: null,
	        doubleQuoted: false
	    };
	}
	exports.newScalar = newScalar;
	function newItems() {
	    return {
	        errors: [],
	        startPosition: -1,
	        endPosition: -1,
	        items: [],
	        kind: Kind.SEQ,
	        parent: null
	    };
	}
	exports.newItems = newItems;
	function newSeq() {
	    return newItems();
	}
	exports.newSeq = newSeq;
	function newMap(mappings) {
	    return {
	        errors: [],
	        startPosition: -1,
	        endPosition: -1,
	        mappings: mappings ? mappings : [],
	        kind: Kind.MAP,
	        parent: null
	    };
	}
	exports.newMap = newMap;
	//# sourceMappingURL=yamlAST.js.map

/***/ },
/* 106 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';
	function isNothing(subject) {
	    return (typeof subject === 'undefined') || (null === subject);
	}
	exports.isNothing = isNothing;
	function isObject(subject) {
	    return (typeof subject === 'object') && (null !== subject);
	}
	exports.isObject = isObject;
	function toArray(sequence) {
	    if (Array.isArray(sequence)) {
	        return sequence;
	    }
	    else if (isNothing(sequence)) {
	        return [];
	    }
	    return [sequence];
	}
	exports.toArray = toArray;
	function extend(target, source) {
	    var index, length, key, sourceKeys;
	    if (source) {
	        sourceKeys = Object.keys(source);
	        for (index = 0, length = sourceKeys.length; index < length; index += 1) {
	            key = sourceKeys[index];
	            target[key] = source[key];
	        }
	    }
	    return target;
	}
	exports.extend = extend;
	function repeat(string, count) {
	    var result = '', cycle;
	    for (cycle = 0; cycle < count; cycle += 1) {
	        result += string;
	    }
	    return result;
	}
	exports.repeat = repeat;
	function isNegativeZero(number) {
	    return (0 === number) && (Number.NEGATIVE_INFINITY === 1 / number);
	}
	exports.isNegativeZero = isNegativeZero;
	//# sourceMappingURL=common.js.map

/***/ },
/* 107 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	'use strict';
	var YAMLException = (function () {
	    function YAMLException(reason, mark) {
	        if (mark === void 0) { mark = null; }
	        this.name = 'YAMLException';
	        this.reason = reason;
	        this.mark = mark;
	        this.message = this.toString(false);
	    }
	    YAMLException.prototype.toString = function (compact) {
	        if (compact === void 0) { compact = false; }
	        var result;
	        result = 'JS-YAML: ' + (this.reason || '(unknown reason)');
	        if (!compact && this.mark) {
	            result += ' ' + this.mark.toString();
	        }
	        return result;
	    };
	    return YAMLException;
	}());
	module.exports = YAMLException;
	//# sourceMappingURL=exception.js.map

/***/ },
/* 108 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';
	var common = __webpack_require__(106);
	var Mark = (function () {
	    function Mark(name, buffer, position, line, column) {
	        this.name = name;
	        this.buffer = buffer;
	        this.position = position;
	        this.line = line;
	        this.column = column;
	    }
	    Mark.prototype.getSnippet = function (indent, maxLength) {
	        if (indent === void 0) { indent = 0; }
	        if (maxLength === void 0) { maxLength = 75; }
	        var head, start, tail, end, snippet;
	        if (!this.buffer) {
	            return null;
	        }
	        indent = indent || 4;
	        maxLength = maxLength || 75;
	        head = '';
	        start = this.position;
	        while (start > 0 && -1 === '\x00\r\n\x85\u2028\u2029'.indexOf(this.buffer.charAt(start - 1))) {
	            start -= 1;
	            if (this.position - start > (maxLength / 2 - 1)) {
	                head = ' ... ';
	                start += 5;
	                break;
	            }
	        }
	        tail = '';
	        end = this.position;
	        while (end < this.buffer.length && -1 === '\x00\r\n\x85\u2028\u2029'.indexOf(this.buffer.charAt(end))) {
	            end += 1;
	            if (end - this.position > (maxLength / 2 - 1)) {
	                tail = ' ... ';
	                end -= 5;
	                break;
	            }
	        }
	        snippet = this.buffer.slice(start, end);
	        return common.repeat(' ', indent) + head + snippet + tail + '\n' +
	            common.repeat(' ', indent + this.position - start + head.length) + '^';
	    };
	    Mark.prototype.toString = function (compact) {
	        if (compact === void 0) { compact = true; }
	        var snippet, where = '';
	        if (this.name) {
	            where += 'in "' + this.name + '" ';
	        }
	        where += 'at line ' + (this.line + 1) + ', column ' + (this.column + 1);
	        if (!compact) {
	            snippet = this.getSnippet();
	            if (snippet) {
	                where += ':\n' + snippet;
	            }
	        }
	        return where;
	    };
	    return Mark;
	}());
	module.exports = Mark;
	//# sourceMappingURL=mark.js.map

/***/ },
/* 109 */
/***/ function(module, exports, __webpack_require__) {

	var sentenceCase = __webpack_require__(120)

	/**
	 * Dot case a string.
	 *
	 * @param  {String} string
	 * @param  {String} [locale]
	 * @return {String}
	 */
	module.exports = function (string, locale) {
	  return sentenceCase(string, locale, '.')
	}


/***/ },
/* 110 */
/***/ function(module, exports, __webpack_require__) {

	var upperCase = __webpack_require__(111)
	var lowerCase = __webpack_require__(113)

	/**
	 * Swap the case of a string. Manually iterate over every character and check
	 * instead of replacing certain characters for better unicode support.
	 *
	 * @param  {String} str
	 * @param  {String} [locale]
	 * @return {String}
	 */
	module.exports = function (str, locale) {
	  if (str == null) {
	    return ''
	  }

	  var result = ''

	  for (var i = 0; i < str.length; i++) {
	    var c = str[i]
	    var u = upperCase(c, locale)

	    result += u === c ? lowerCase(c, locale) : u
	  }

	  return result
	}


/***/ },
/* 111 */
/***/ function(module, exports, __webpack_require__) {

	/**
	 * Special language-specific overrides.
	 *
	 * Source: ftp://ftp.unicode.org/Public/UCD/latest/ucd/SpecialCasing.txt
	 *
	 * @type {Object}
	 */
	var LANGUAGES = {
	  tr: {
	    regexp: /[\u0069]/g,
	    map: {
	      '\u0069': '\u0130'
	    }
	  },
	  az: {
	    regexp: /[\u0069]/g,
	    map: {
	      '\u0069': '\u0130'
	    }
	  },
	  lt: {
	    regexp: /[\u0069\u006A\u012F]\u0307|\u0069\u0307[\u0300\u0301\u0303]/g,
	    map: {
	      '\u0069\u0307': '\u0049',
	      '\u006A\u0307': '\u004A',
	      '\u012F\u0307': '\u012E',
	      '\u0069\u0307\u0300': '\u00CC',
	      '\u0069\u0307\u0301': '\u00CD',
	      '\u0069\u0307\u0303': '\u0128'
	    }
	  }
	}

	/**
	 * Upper case a string.
	 *
	 * @param  {String} str
	 * @return {String}
	 */
	module.exports = function (str, locale) {
	  var lang = LANGUAGES[locale]

	  str = str == null ? '' : String(str)

	  if (lang) {
	    str = str.replace(lang.regexp, function (m) { return lang.map[m] })
	  }

	  return str.toUpperCase()
	}


/***/ },
/* 112 */
/***/ function(module, exports, __webpack_require__) {

	var sentenceCase = __webpack_require__(120)

	/**
	 * Path case a string.
	 *
	 * @param  {String} string
	 * @param  {String} [locale]
	 * @return {String}
	 */
	module.exports = function (string, locale) {
	  return sentenceCase(string, locale, '/')
	}


/***/ },
/* 113 */
/***/ function(module, exports, __webpack_require__) {

	/**
	 * Special language-specific overrides.
	 *
	 * Source: ftp://ftp.unicode.org/Public/UCD/latest/ucd/SpecialCasing.txt
	 *
	 * @type {Object}
	 */
	var LANGUAGES = {
	  tr: {
	    regexp: /\u0130|\u0049|\u0049\u0307/g,
	    map: {
	      '\u0130': '\u0069',
	      '\u0049': '\u0131',
	      '\u0049\u0307': '\u0069'
	    }
	  },
	  az: {
	    regexp: /[\u0130]/g,
	    map: {
	      '\u0130': '\u0069',
	      '\u0049': '\u0131',
	      '\u0049\u0307': '\u0069'
	    }
	  },
	  lt: {
	    regexp: /[\u0049\u004A\u012E\u00CC\u00CD\u0128]/g,
	    map: {
	      '\u0049': '\u0069\u0307',
	      '\u004A': '\u006A\u0307',
	      '\u012E': '\u012F\u0307',
	      '\u00CC': '\u0069\u0307\u0300',
	      '\u00CD': '\u0069\u0307\u0301',
	      '\u0128': '\u0069\u0307\u0303'
	    }
	  }
	}

	/**
	 * Lowercase a string.
	 *
	 * @param  {String} str
	 * @return {String}
	 */
	module.exports = function (str, locale) {
	  var lang = LANGUAGES[locale]

	  str = str == null ? '' : String(str)

	  if (lang) {
	    str = str.replace(lang.regexp, function (m) { return lang.map[m] })
	  }

	  return str.toLowerCase()
	}


/***/ },
/* 114 */
/***/ function(module, exports, __webpack_require__) {

	var upperCase = __webpack_require__(111)
	var sentenceCase = __webpack_require__(120)

	/**
	 * Camel case a string.
	 *
	 * @param  {String} string
	 * @param  {String} [locale]
	 * @return {String}
	 */
	module.exports = function (string, locale, mergeNumbers) {
	  var result = sentenceCase(string, locale)

	  // Replace periods between numeric entities with an underscore.
	  if (!mergeNumbers) {
	    result = result.replace(/(\d) (?=\d)/g, '$1_')
	  }

	  // Replace spaces between words with an upper cased character.
	  return result.replace(/ (.)/g, function (m, $1) {
	    return upperCase($1, locale)
	  })
	}


/***/ },
/* 115 */
/***/ function(module, exports, __webpack_require__) {

	var sentenceCase = __webpack_require__(120)

	/**
	 * Param case a string.
	 *
	 * @param  {String} string
	 * @param  {String} [locale]
	 * @return {String}
	 */
	module.exports = function (string, locale) {
	  return sentenceCase(string, locale, '-')
	}


/***/ },
/* 116 */
/***/ function(module, exports, __webpack_require__) {

	var sentenceCase = __webpack_require__(120)

	/**
	 * Snake case a string.
	 *
	 * @param  {String} str
	 * @param  {String} [locale]
	 * @return {String}
	 */
	module.exports = function (str, locale) {
	  return sentenceCase(str, locale, '_')
	}


/***/ },
/* 117 */
/***/ function(module, exports, __webpack_require__) {

	var upperCase = __webpack_require__(111)
	var sentenceCase = __webpack_require__(120)

	/**
	 * Title case a string.
	 *
	 * @param  {String} string
	 * @param  {String} [locale]
	 * @return {String}
	 */
	module.exports = function (str, locale) {
	  return sentenceCase(str, locale).replace(/^.| ./g, function (m) {
	    return upperCase(m, locale)
	  })
	}


/***/ },
/* 118 */
/***/ function(module, exports, __webpack_require__) {

	var camelCase = __webpack_require__(114)
	var upperCaseFirst = __webpack_require__(124)

	/**
	 * Pascal case a string.
	 *
	 * @param  {String} string
	 * @param  {String} [locale]
	 * @return {String}
	 */
	module.exports = function (string, locale) {
	  return upperCaseFirst(camelCase(string, locale), locale)
	}


/***/ },
/* 119 */
/***/ function(module, exports, __webpack_require__) {

	var upperCase = __webpack_require__(111)
	var snakeCase = __webpack_require__(116)

	/**
	 * Constant case a string.
	 *
	 * @param  {String} string
	 * @param  {String} [locale]
	 * @return {String}
	 */
	module.exports = function (string, locale) {
	  return upperCase(snakeCase(string, locale), locale)
	}


/***/ },
/* 120 */
/***/ function(module, exports, __webpack_require__) {

	var lowerCase = __webpack_require__(113)

	var NON_WORD_REGEXP = __webpack_require__(152)
	var CAMEL_CASE_REGEXP = __webpack_require__(153)
	var TRAILING_DIGIT_REGEXP = __webpack_require__(154)

	/**
	 * Sentence case a string.
	 *
	 * @param  {String} str
	 * @param  {String} locale
	 * @param  {String} replacement
	 * @return {String}
	 */
	module.exports = function (str, locale, replacement) {
	  if (str == null) {
	    return ''
	  }

	  replacement = replacement || ' '

	  function replace (match, index, string) {
	    if (index === 0 || index === (string.length - match.length)) {
	      return ''
	    }

	    return replacement
	  }

	  str = String(str)
	    // Support camel case ("camelCase" -> "camel Case").
	    .replace(CAMEL_CASE_REGEXP, '$1 $2')
	    // Support digit groups ("test2012" -> "test 2012").
	    .replace(TRAILING_DIGIT_REGEXP, '$1 $2')
	    // Remove all non-word characters and replace with a single space.
	    .replace(NON_WORD_REGEXP, replace)

	  // Lower case the entire string.
	  return lowerCase(str, locale)
	}


/***/ },
/* 121 */
/***/ function(module, exports, __webpack_require__) {

	var upperCase = __webpack_require__(111)

	/**
	 * Check if a string is upper case.
	 *
	 * @param  {String}  string
	 * @param  {String}  [locale]
	 * @return {Boolean}
	 */
	module.exports = function (string, locale) {
	  return upperCase(string, locale) === string
	}


/***/ },
/* 122 */
/***/ function(module, exports, __webpack_require__) {

	var indexOf = __webpack_require__(184);

	var Object_keys = function (obj) {
	    if (Object.keys) return Object.keys(obj)
	    else {
	        var res = [];
	        for (var key in obj) res.push(key)
	        return res;
	    }
	};

	var forEach = function (xs, fn) {
	    if (xs.forEach) return xs.forEach(fn)
	    else for (var i = 0; i < xs.length; i++) {
	        fn(xs[i], i, xs);
	    }
	};

	var defineProp = (function() {
	    try {
	        Object.defineProperty({}, '_', {});
	        return function(obj, name, value) {
	            Object.defineProperty(obj, name, {
	                writable: true,
	                enumerable: false,
	                configurable: true,
	                value: value
	            })
	        };
	    } catch(e) {
	        return function(obj, name, value) {
	            obj[name] = value;
	        };
	    }
	}());

	var globals = ['Array', 'Boolean', 'Date', 'Error', 'EvalError', 'Function',
	'Infinity', 'JSON', 'Math', 'NaN', 'Number', 'Object', 'RangeError',
	'ReferenceError', 'RegExp', 'String', 'SyntaxError', 'TypeError', 'URIError',
	'decodeURI', 'decodeURIComponent', 'encodeURI', 'encodeURIComponent', 'escape',
	'eval', 'isFinite', 'isNaN', 'parseFloat', 'parseInt', 'undefined', 'unescape'];

	function Context() {}
	Context.prototype = {};

	var Script = exports.Script = function NodeScript (code) {
	    if (!(this instanceof Script)) return new Script(code);
	    this.code = code;
	};

	Script.prototype.runInContext = function (context) {
	    if (!(context instanceof Context)) {
	        throw new TypeError("needs a 'context' argument.");
	    }
	    
	    var iframe = document.createElement('iframe');
	    if (!iframe.style) iframe.style = {};
	    iframe.style.display = 'none';
	    
	    document.body.appendChild(iframe);
	    
	    var win = iframe.contentWindow;
	    var wEval = win.eval, wExecScript = win.execScript;

	    if (!wEval && wExecScript) {
	        // win.eval() magically appears when this is called in IE:
	        wExecScript.call(win, 'null');
	        wEval = win.eval;
	    }
	    
	    forEach(Object_keys(context), function (key) {
	        win[key] = context[key];
	    });
	    forEach(globals, function (key) {
	        if (context[key]) {
	            win[key] = context[key];
	        }
	    });
	    
	    var winKeys = Object_keys(win);

	    var res = wEval.call(win, this.code);
	    
	    forEach(Object_keys(win), function (key) {
	        // Avoid copying circular objects like `top` and `window` by only
	        // updating existing context properties or new properties in the `win`
	        // that was only introduced after the eval.
	        if (key in context || indexOf(winKeys, key) === -1) {
	            context[key] = win[key];
	        }
	    });

	    forEach(globals, function (key) {
	        if (!(key in context)) {
	            defineProp(context, key, win[key]);
	        }
	    });
	    
	    document.body.removeChild(iframe);
	    
	    return res;
	};

	Script.prototype.runInThisContext = function () {
	    return eval(this.code); // maybe...
	};

	Script.prototype.runInNewContext = function (context) {
	    var ctx = Script.createContext(context);
	    var res = this.runInContext(ctx);

	    forEach(Object_keys(ctx), function (key) {
	        context[key] = ctx[key];
	    });

	    return res;
	};

	forEach(Object_keys(Script.prototype), function (name) {
	    exports[name] = Script[name] = function (code) {
	        var s = Script(code);
	        return s[name].apply(s, [].slice.call(arguments, 1));
	    };
	});

	exports.createScript = function (code) {
	    return exports.Script(code);
	};

	exports.createContext = Script.createContext = function (context) {
	    var copy = new Context();
	    if(typeof context === 'object') {
	        forEach(Object_keys(context), function (key) {
	            copy[key] = context[key];
	        });
	    }
	    return copy;
	};


/***/ },
/* 123 */
/***/ function(module, exports, __webpack_require__) {

	var lowerCase = __webpack_require__(113)

	/**
	 * Check if a string is lower case.
	 *
	 * @param  {String}  string
	 * @param  {String}  [locale]
	 * @return {Boolean}
	 */
	module.exports = function (string, locale) {
	  return lowerCase(string, locale) === string
	}


/***/ },
/* 124 */
/***/ function(module, exports, __webpack_require__) {

	var upperCase = __webpack_require__(111)

	/**
	 * Upper case the first character of a string.
	 *
	 * @param  {String} str
	 * @return {String}
	 */
	module.exports = function (str, locale) {
	  if (str == null) {
	    return ''
	  }

	  str = String(str)

	  return upperCase(str.charAt(0), locale) + str.substr(1)
	}


/***/ },
/* 125 */
/***/ function(module, exports, __webpack_require__) {

	var lowerCase = __webpack_require__(113)

	/**
	 * Lower case the first character of a string.
	 *
	 * @param  {String} str
	 * @return {String}
	 */
	module.exports = function (str, locale) {
	  if (str == null) {
	    return ''
	  }

	  str = String(str)

	  return lowerCase(str.charAt(0), locale) + str.substr(1)
	}


/***/ },
/* 126 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';
	var Schema = __webpack_require__(149);
	var schema = new Schema({
	    include: [
	        __webpack_require__(150)
	    ],
	    implicit: [
	        __webpack_require__(155),
	        __webpack_require__(156)
	    ],
	    explicit: [
	        __webpack_require__(157),
	        __webpack_require__(158),
	        __webpack_require__(159),
	        __webpack_require__(160)
	    ]
	});
	module.exports = schema;
	//# sourceMappingURL=default_safe.js.map

/***/ },
/* 127 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';
	var Schema = __webpack_require__(149);
	var schema = new Schema({
	    include: [
	        __webpack_require__(126)
	    ],
	    explicit: [
	        __webpack_require__(161),
	        __webpack_require__(162)
	    ]
	});
	Schema.DEFAULT = schema;
	module.exports = schema;
	//# sourceMappingURL=default_full.js.map

/***/ },
/* 128 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var __extends = (this && this.__extends) || function (d, b) {
	    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
	    function __() { this.constructor = d; }
	    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
	};
	var ts = __webpack_require__(166);
	/***
	 * This module is designed to match simple patterns on Typescript AST Tree
	 * it functionality mirrors jsASTMatchers which allows you to match on jsAST
	 */
	//TODO RENAME TO MATCHERS
	var Matching;
	(function (Matching) {
	    /**
	     * do match checks the node type and if node type is ok
	     * calls match function otherwise it returns null
	     */
	    var BasicMatcher = (function () {
	        function BasicMatcher() {
	        }
	        BasicMatcher.prototype.match = function (node) {
	            throw new Error();
	        };
	        BasicMatcher.prototype.nodeType = function () {
	            throw new Error();
	        };
	        BasicMatcher.prototype.doMatch = function (n) {
	            if (!n) {
	                return null;
	            }
	            if (this.nodeType() == n.kind) {
	                return this.match(n);
	            }
	        };
	        return BasicMatcher;
	    }());
	    Matching.BasicMatcher = BasicMatcher;
	    var ClassDeclarationMatcher = (function (_super) {
	        __extends(ClassDeclarationMatcher, _super);
	        function ClassDeclarationMatcher() {
	            _super.call(this);
	        }
	        ClassDeclarationMatcher.prototype.match = function (node) {
	            return node;
	        };
	        ClassDeclarationMatcher.prototype.nodeType = function () {
	            return ts.SyntaxKind.ClassDeclaration;
	        };
	        return ClassDeclarationMatcher;
	    }(BasicMatcher));
	    Matching.ClassDeclarationMatcher = ClassDeclarationMatcher;
	    var FieldMatcher = (function (_super) {
	        __extends(FieldMatcher, _super);
	        function FieldMatcher() {
	            _super.apply(this, arguments);
	        }
	        FieldMatcher.prototype.match = function (node) {
	            return node;
	        };
	        FieldMatcher.prototype.nodeType = function () {
	            return ts.SyntaxKind.PropertyDeclaration;
	        };
	        return FieldMatcher;
	    }(BasicMatcher));
	    Matching.FieldMatcher = FieldMatcher;
	    var AssignmentExpressionMatcher = (function (_super) {
	        __extends(AssignmentExpressionMatcher, _super);
	        function AssignmentExpressionMatcher(left, right, tr) {
	            _super.call(this);
	            this.left = left;
	            this.right = right;
	            this.tr = tr;
	        }
	        AssignmentExpressionMatcher.prototype.match = function (node) {
	            if (node.operatorToken.kind == ts.SyntaxKind.EqualsToken) {
	                if (this.left.doMatch(node.left) && this.right.doMatch(node.right)) {
	                    return this.tr(node);
	                }
	            }
	            return null;
	        };
	        AssignmentExpressionMatcher.prototype.nodeType = function () {
	            return ts.SyntaxKind.BinaryExpression;
	        };
	        return AssignmentExpressionMatcher;
	    }(BasicMatcher));
	    Matching.AssignmentExpressionMatcher = AssignmentExpressionMatcher;
	    var VariableDeclarationMatcher = (function (_super) {
	        __extends(VariableDeclarationMatcher, _super);
	        function VariableDeclarationMatcher(left, right, tr) {
	            _super.call(this);
	            this.left = left;
	            this.right = right;
	            this.tr = tr;
	        }
	        VariableDeclarationMatcher.prototype.match = function (node) {
	            if (this.left.doMatch(node.name) && this.right.doMatch(node.initializer)) {
	                return this.tr(node);
	            }
	        };
	        VariableDeclarationMatcher.prototype.nodeType = function () {
	            return ts.SyntaxKind.VariableDeclaration;
	        };
	        return VariableDeclarationMatcher;
	    }(BasicMatcher));
	    Matching.VariableDeclarationMatcher = VariableDeclarationMatcher;
	    var ExpressionStatementMatcher = (function (_super) {
	        __extends(ExpressionStatementMatcher, _super);
	        function ExpressionStatementMatcher(expression, tr) {
	            _super.call(this);
	            this.expression = expression;
	            this.tr = tr;
	        }
	        ExpressionStatementMatcher.prototype.match = function (node) {
	            var exp = this.expression.doMatch(node.expression);
	            if (exp) {
	                var v = this.tr(node.expression);
	                if (v == true) {
	                    return exp;
	                }
	                return v;
	            }
	            return null;
	        };
	        ExpressionStatementMatcher.prototype.nodeType = function () {
	            return ts.SyntaxKind.ExpressionStatement;
	        };
	        return ExpressionStatementMatcher;
	    }(BasicMatcher));
	    var SimpleIdentMatcher = (function (_super) {
	        __extends(SimpleIdentMatcher, _super);
	        function SimpleIdentMatcher(val) {
	            _super.call(this);
	            this.val = val;
	        }
	        SimpleIdentMatcher.prototype.match = function (node) {
	            if (node.text == this.val) {
	                return true;
	            }
	            return null;
	        };
	        SimpleIdentMatcher.prototype.nodeType = function () {
	            return ts.SyntaxKind.Identifier;
	        };
	        return SimpleIdentMatcher;
	    }(BasicMatcher));
	    var TrueMatcher = (function () {
	        function TrueMatcher() {
	        }
	        TrueMatcher.prototype.doMatch = function (node) {
	            return true;
	        };
	        TrueMatcher.prototype.nodeType = function () {
	            return null;
	        };
	        return TrueMatcher;
	    }());
	    var CallExpressionMatcher = (function (_super) {
	        __extends(CallExpressionMatcher, _super);
	        function CallExpressionMatcher(calleeMatcher, tr) {
	            _super.call(this);
	            this.calleeMatcher = calleeMatcher;
	            this.tr = tr;
	        }
	        CallExpressionMatcher.prototype.match = function (node) {
	            if (this.calleeMatcher.doMatch(node.expression)) {
	                return this.tr(node);
	            }
	            return null;
	        };
	        CallExpressionMatcher.prototype.nodeType = function () {
	            return ts.SyntaxKind.CallExpression;
	        };
	        return CallExpressionMatcher;
	    }(BasicMatcher));
	    Matching.SKIP = {};
	    function visit(n, cb) {
	        var r0 = cb(n);
	        if (r0) {
	            if (r0 == Matching.SKIP) {
	                return null;
	            }
	            return r0;
	        }
	        var r = ts.forEachChild(n, function (x) {
	            var r = visit(x, cb);
	            if (r) {
	                return r;
	            }
	        });
	        return r;
	    }
	    Matching.visit = visit;
	    var PathNode = (function () {
	        function PathNode(name, _base) {
	            this._base = _base;
	            this.arguments = null;
	            this.name = name;
	        }
	        return PathNode;
	    }());
	    Matching.PathNode = PathNode;
	    var CallPath = (function () {
	        function CallPath(base, _baseNode) {
	            this._baseNode = _baseNode;
	            this.path = [];
	            this.base = base;
	        }
	        CallPath.prototype.start = function () {
	            return this._baseNode.pos;
	        };
	        CallPath.prototype.startLocation = function () {
	            return this._baseNode.getSourceFile().getLineAndCharacterOfPosition(this.start());
	        };
	        CallPath.prototype.endLocation = function () {
	            return this._baseNode.getSourceFile().getLineAndCharacterOfPosition(this.end());
	        };
	        CallPath.prototype.end = function () {
	            var ce = this.path[this.path.length - 1]._callExpression;
	            if (ce) {
	                return ce.end;
	            }
	            return this.start();
	        };
	        CallPath.prototype.toString = function () {
	            return this.path.map(function (x) { return x.name; }).join(".");
	        };
	        return CallPath;
	    }());
	    Matching.CallPath = CallPath;
	    var MemberExpressionMatcher = (function (_super) {
	        __extends(MemberExpressionMatcher, _super);
	        function MemberExpressionMatcher(objectMatcher, propertyMatcher, tr) {
	            _super.call(this);
	            this.objectMatcher = objectMatcher;
	            this.propertyMatcher = propertyMatcher;
	            this.tr = tr;
	        }
	        MemberExpressionMatcher.prototype.match = function (node) {
	            if (this.objectMatcher.doMatch(node.expression) && this.propertyMatcher.doMatch(node.name)) {
	                return this.tr(node);
	            }
	            return null;
	        };
	        MemberExpressionMatcher.prototype.nodeType = function () {
	            return ts.SyntaxKind.PropertyAccessExpression;
	        };
	        return MemberExpressionMatcher;
	    }(BasicMatcher));
	    function memberFromExp(objMatcher, tr) {
	        if (tr === void 0) { tr = function (x) { return true; }; }
	        var array = objMatcher.split(".");
	        var result = null;
	        for (var a = 0; a < array.length; a++) {
	            var arg = array[a];
	            var ci = arg.indexOf("(*)");
	            var isCall = false;
	            if (ci != -1) {
	                arg = arg.substr(0, ci);
	                isCall = true;
	            }
	            if (result == null) {
	                result = arg == '*' ? anyNode() : ident(arg);
	            }
	            else {
	                result = new MemberExpressionMatcher(result, arg == '*' ? anyNode() : ident(arg), tr);
	            }
	            if (isCall) {
	                result = new CallExpressionMatcher(result, tr);
	            }
	        }
	        //console.log(result)
	        return result;
	    }
	    Matching.memberFromExp = memberFromExp;
	    var CallBaseMatcher = (function () {
	        function CallBaseMatcher(rootMatcher) {
	            this.rootMatcher = rootMatcher;
	        }
	        CallBaseMatcher.prototype.doMatch = function (node) {
	            var original = node;
	            if (node.kind == ts.SyntaxKind.CallExpression) {
	                var call = node;
	                var res = this.doMatch(call.expression);
	                if (res) {
	                    if (res.path.length > 0 && res.path[res.path.length - 1].arguments == null) {
	                        res.path[res.path.length - 1].arguments = call.arguments;
	                        res.path[res.path.length - 1]._callExpression = call;
	                        return res;
	                    }
	                    //This case should not exist in type script clients now
	                    //but leaving it here for possible future use at the moment;
	                    //if (res.path.length==0&&call.arguments.length==1){
	                    //    //this is not resource based call!!!
	                    //    if (call.arguments[0].kind==ts.SyntaxKind.StringLiteral){
	                    //        var l:ts.LiteralExpression=<ts.LiteralExpression>call.arguments[0];
	                    //        var url=l.text;
	                    //        var uriPath=url.toString().split("/");
	                    //        uriPath.forEach(x=>res.path.push(
	                    //            new PathNode(x)
	                    //        ))
	                    //        return res;
	                    //    }
	                    //}
	                    return null;
	                }
	            }
	            else if (node.kind == ts.SyntaxKind.PropertyAccessExpression) {
	                var me = node;
	                var v = this.doMatch(me.expression);
	                if (v) {
	                    if (me.name.kind == ts.SyntaxKind.Identifier) {
	                        v.path.push(new PathNode(me.name.text, me.name));
	                        return v;
	                    }
	                    return null;
	                }
	            }
	            else if (node.kind == ts.SyntaxKind.Identifier) {
	                var id = node;
	                if (this.rootMatcher.doMatch(id)) {
	                    return new CallPath(id.text, id);
	                }
	            }
	            return null;
	        };
	        CallBaseMatcher.prototype.nodeType = function () {
	            return null;
	        };
	        return CallBaseMatcher;
	    }());
	    Matching.CallBaseMatcher = CallBaseMatcher;
	    function ident(name) {
	        return new SimpleIdentMatcher(name);
	    }
	    Matching.ident = ident;
	    function anyNode() {
	        return new TrueMatcher();
	    }
	    Matching.anyNode = anyNode;
	    function call(calleeMatcher, tr) {
	        if (tr === void 0) { tr = function (x) { return true; }; }
	        return new CallExpressionMatcher(calleeMatcher, tr);
	    }
	    Matching.call = call;
	    function exprStmt(eM, tr) {
	        if (tr === void 0) { tr = function (x) { return true; }; }
	        return new ExpressionStatementMatcher(eM, tr);
	    }
	    Matching.exprStmt = exprStmt;
	    function assign(left, right, tr) {
	        if (tr === void 0) { tr = function (x) { return true; }; }
	        return new AssignmentExpressionMatcher(left, right, tr);
	    }
	    Matching.assign = assign;
	    function varDecl(left, right, tr) {
	        if (tr === void 0) { tr = function (x) { return true; }; }
	        return new VariableDeclarationMatcher(left, right, tr);
	    }
	    Matching.varDecl = varDecl;
	    function field() {
	        return new FieldMatcher();
	    }
	    Matching.field = field;
	    function classDeclaration() {
	        return new ClassDeclarationMatcher();
	    }
	    Matching.classDeclaration = classDeclaration;
	})(Matching = exports.Matching || (exports.Matching = {}));
	//# sourceMappingURL=tsASTMatchers.js.map

/***/ },
/* 129 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var ts = __webpack_require__(166);
	var tsm = __webpack_require__(128);
	var path = __webpack_require__(15);
	var fs = __webpack_require__(36);
	var tsStructureParser = __webpack_require__(86);
	var ns = { 'RamlWrapper': true };
	var HelperMethod = (function () {
	    function HelperMethod(originalName, wrapperMethodName, returnType, args, meta) {
	        this.originalName = originalName;
	        this.wrapperMethodName = wrapperMethodName;
	        this.returnType = returnType;
	        this.args = args;
	        this.meta = meta;
	    }
	    HelperMethod.prototype.targetWrappers = function () {
	        var isValid = true;
	        var result = [];
	        this.args.forEach(function (x) {
	            var arr = flatten(x.type, ns);
	            if (arr.length == 0) {
	                return;
	            }
	            if (!isValid || result.length != 0) {
	                result = [];
	                isValid = false;
	                return;
	            }
	            result = result.concat(arr);
	        });
	        return result;
	    };
	    HelperMethod.prototype.callArgs = function () {
	        return this.args.map(function (x) {
	            if (flatten(x.type, ns).length == 0) {
	                return x;
	            }
	            return {
	                name: "this",
	                type: null
	            };
	        });
	    };
	    return HelperMethod;
	}());
	exports.HelperMethod = HelperMethod;
	function getHelperMethods(srcPath) {
	    var result = [];
	    var content = fs.readFileSync(path.resolve(srcPath)).toString();
	    var mod = ts.createSourceFile("sample.ts", content, ts.ScriptTarget.ES3, true);
	    tsm.Matching.visit(mod, function (x) {
	        var node = x;
	        if (node.kind == ts.SyntaxKind.FunctionDeclaration) {
	            var meta = getMeta(node, content);
	            if (!meta) {
	                return;
	            }
	            var originalName = node.name.text;
	            var wrapperMethodName = originalName;
	            if (meta.name) {
	                wrapperMethodName = meta.name;
	            }
	            else {
	                meta.name = originalName;
	            }
	            var wrapperMethodName = meta.name ? meta.name : originalName;
	            var args = node.parameters ? node.parameters.map(function (a) { return readArg(a, srcPath); }) : [];
	            var override = meta.override ? meta.override : false;
	            var returnType = tsStructureParser.buildType(node.type, srcPath);
	            result.push(new HelperMethod(originalName, wrapperMethodName, returnType, args, meta));
	        }
	    });
	    return result;
	}
	exports.getHelperMethods = getHelperMethods;
	var refineComment = function (comment) {
	    return comment.replace(/^\s*\/\*+/g, '').replace(/\*+\/\s*$/g, '').split('\n')
	        .map(function (x) { return x.replace(/^\s*\/\//g, '').replace(/^\s*\* {0,1}/g, ''); }).join('\n').trim();
	};
	function getMeta(node, content) {
	    var cRange = ts.getLeadingCommentRanges(content, node.pos);
	    if (!cRange) {
	        return null;
	    }
	    var comment = cRange.map(function (x) { return content.substring(x.pos, x.end); }).join('\n');
	    var ind = comment.indexOf('__$helperMethod__');
	    if (ind < 0) {
	        return null;
	    }
	    ind += '__$helperMethod__'.length;
	    var indMeta = comment.indexOf('__$meta__');
	    if (indMeta < 0) {
	        return { comment: refineComment(comment.substring(ind)) };
	    }
	    var commentStr = refineComment(comment.substring(ind, indMeta));
	    var indMetaObj = comment.indexOf('{', indMeta);
	    if (indMetaObj < 0) {
	        return { comment: commentStr };
	    }
	    try {
	        var meta = JSON.parse(refineComment(comment.substring(indMetaObj)));
	        meta.comment = commentStr.trim().length > 0 ? commentStr : null;
	        meta.override = meta.override || false;
	        meta.primary = meta.primary || false;
	        meta.deprecated = meta.deprecated || false;
	        return meta;
	    }
	    catch (e) {
	        console.log(e);
	    }
	    return {};
	}
	function readArg(node, srcPath) {
	    var name = node.name.text;
	    var type = tsStructureParser.buildType(node.type, srcPath);
	    return {
	        name: name,
	        type: type
	    };
	}
	function flatten(t, namespaces) {
	    if (t.typeKind == tsStructureParser.TypeKind.ARRAY) {
	        if (namespaces) {
	            return [];
	        }
	        else {
	            return [flatten(t.base)[0] + '[]'];
	        }
	    }
	    else if (t.typeKind == tsStructureParser.TypeKind.BASIC) {
	        var bt = t;
	        var str = bt.basicName;
	        var nameSpace = bt.nameSpace && bt.nameSpace.trim();
	        if (nameSpace != null && nameSpace.length > 0 && nameSpace != "RamlWrapper") {
	            str = nameSpace + "." + str;
	        }
	        if (bt.typeArguments && bt.typeArguments.length != 0) {
	            str += "<" + bt.typeArguments.map(function (x) { return flatten(x); }).join(', ') + ">";
	        }
	        if (namespaces) {
	            if (bt.nameSpace) {
	                return namespaces[bt.nameSpace] ? [str] : [];
	            }
	            else {
	                return [];
	            }
	        }
	        return [str];
	    }
	    else if (t.typeKind == tsStructureParser.TypeKind.UNION) {
	        var ut = t;
	        var result = [];
	        ut.options.forEach(function (x) { return result = result.concat(flatten(x, namespaces)); });
	        return result;
	    }
	    return [];
	}
	exports.flatten = flatten;
	//# sourceMappingURL=helperMethodExtractor.js.map

/***/ },
/* 130 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	/// <reference path="../typings/main.d.ts" />
	var pth = __webpack_require__(15);
	var fs = __webpack_require__(36);
	function resolve(p1, p2) {
	    return pth.resolve(p1, p2);
	}
	exports.resolve = resolve;
	function readFileSync(p) {
	    return fs.readFileSync(p).toString();
	}
	exports.readFileSync = readFileSync;
	function dirname(p) {
	    return pth.dirname(p);
	}
	exports.dirname = dirname;
	function existsSync(p) {
	    return fs.existsSync(p);
	}
	exports.existsSync = existsSync;
	//# sourceMappingURL=fsUtils.js.map

/***/ },
/* 131 */
/***/ function(module, exports, __webpack_require__) {

	var __WEBPACK_AMD_DEFINE_RESULT__;/*jshint node:true*/

	if (false) {
	    var define = require('amdefine')(module);
	}

	!(__WEBPACK_AMD_DEFINE_RESULT__ = function() {
	    "use strict";

	    var statusCodes = __webpack_require__(171),
	        statusCodesToPhrases = {},
	        statusPhrasesToCodes = {},
	        methods = __webpack_require__(172),
	        headers = __webpack_require__(173),
	        relations = __webpack_require__(174);

	    statusCodes.forEach(function(item) {
	        var code = parseInt(item.code, 10),
	            phrase;

	        // Ignore codes for classes
	        if (code.toString() !== item.code) {
	            return;
	        }

	        phrase = item.phrase.toUpperCase().replace(/[^A-Z]/g, '_');

	        statusCodesToPhrases[code] = item.phrase;
	        statusPhrasesToCodes[phrase] = item.code;
	    });

	    return {
	        statusCodes: statusCodes,
	        statusCodesToPhrases: statusCodesToPhrases,
	        statusPhrasesToCodes: statusPhrasesToCodes,
	        methods: methods,
	        headers: headers,
	        relations: relations
	    };
	}.call(exports, __webpack_require__, exports, module), __WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));


/***/ },
/* 132 */
/***/ function(module, exports, __webpack_require__) {

	// Copyright Joyent, Inc. and other Node contributors.
	//
	// Permission is hereby granted, free of charge, to any person obtaining a
	// copy of this software and associated documentation files (the
	// "Software"), to deal in the Software without restriction, including
	// without limitation the rights to use, copy, modify, merge, publish,
	// distribute, sublicense, and/or sell copies of the Software, and to permit
	// persons to whom the Software is furnished to do so, subject to the
	// following conditions:
	//
	// The above copyright notice and this permission notice shall be included
	// in all copies or substantial portions of the Software.
	//
	// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
	// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
	// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
	// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
	// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
	// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
	// USE OR OTHER DEALINGS IN THE SOFTWARE.

	'use strict';

	// If obj.hasOwnProperty has been overridden, then calling
	// obj.hasOwnProperty(prop) will break.
	// See: https://github.com/joyent/node/issues/1707
	function hasOwnProperty(obj, prop) {
	  return Object.prototype.hasOwnProperty.call(obj, prop);
	}

	module.exports = function(qs, sep, eq, options) {
	  sep = sep || '&';
	  eq = eq || '=';
	  var obj = {};

	  if (typeof qs !== 'string' || qs.length === 0) {
	    return obj;
	  }

	  var regexp = /\+/g;
	  qs = qs.split(sep);

	  var maxKeys = 1000;
	  if (options && typeof options.maxKeys === 'number') {
	    maxKeys = options.maxKeys;
	  }

	  var len = qs.length;
	  // maxKeys <= 0 means that we should not limit keys count
	  if (maxKeys > 0 && len > maxKeys) {
	    len = maxKeys;
	  }

	  for (var i = 0; i < len; ++i) {
	    var x = qs[i].replace(regexp, '%20'),
	        idx = x.indexOf(eq),
	        kstr, vstr, k, v;

	    if (idx >= 0) {
	      kstr = x.substr(0, idx);
	      vstr = x.substr(idx + 1);
	    } else {
	      kstr = x;
	      vstr = '';
	    }

	    k = decodeURIComponent(kstr);
	    v = decodeURIComponent(vstr);

	    if (!hasOwnProperty(obj, k)) {
	      obj[k] = v;
	    } else if (Array.isArray(obj[k])) {
	      obj[k].push(v);
	    } else {
	      obj[k] = [obj[k], v];
	    }
	  }

	  return obj;
	};


/***/ },
/* 133 */
/***/ function(module, exports, __webpack_require__) {

	// Copyright Joyent, Inc. and other Node contributors.
	//
	// Permission is hereby granted, free of charge, to any person obtaining a
	// copy of this software and associated documentation files (the
	// "Software"), to deal in the Software without restriction, including
	// without limitation the rights to use, copy, modify, merge, publish,
	// distribute, sublicense, and/or sell copies of the Software, and to permit
	// persons to whom the Software is furnished to do so, subject to the
	// following conditions:
	//
	// The above copyright notice and this permission notice shall be included
	// in all copies or substantial portions of the Software.
	//
	// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
	// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
	// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
	// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
	// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
	// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
	// USE OR OTHER DEALINGS IN THE SOFTWARE.

	'use strict';

	var stringifyPrimitive = function(v) {
	  switch (typeof v) {
	    case 'string':
	      return v;

	    case 'boolean':
	      return v ? 'true' : 'false';

	    case 'number':
	      return isFinite(v) ? v : '';

	    default:
	      return '';
	  }
	};

	module.exports = function(obj, sep, eq, name) {
	  sep = sep || '&';
	  eq = eq || '=';
	  if (obj === null) {
	    obj = undefined;
	  }

	  if (typeof obj === 'object') {
	    return Object.keys(obj).map(function(k) {
	      var ks = encodeURIComponent(stringifyPrimitive(k)) + eq;
	      if (Array.isArray(obj[k])) {
	        return obj[k].map(function(v) {
	          return ks + encodeURIComponent(stringifyPrimitive(v));
	        }).join(sep);
	      } else {
	        return ks + encodeURIComponent(stringifyPrimitive(obj[k]));
	      }
	    }).join(sep);

	  }

	  if (!name) return '';
	  return encodeURIComponent(stringifyPrimitive(name)) + eq +
	         encodeURIComponent(stringifyPrimitive(obj));
	};


/***/ },
/* 134 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var rt = __webpack_require__(90);
	var meta = __webpack_require__(95);
	var restrictions_1 = __webpack_require__(94);
	var restrictions_2 = __webpack_require__(94);
	var exCalcFlag = "exampleCalculation";
	function example(t) {
	    var ms = t.oneMeta(meta.Example);
	    if (ms) {
	        return ms.example();
	    }
	    if (t.getExtra(exCalcFlag)) {
	        return null;
	    }
	    t.putExtra(exCalcFlag, true);
	    try {
	        var ms1 = t.oneMeta(meta.Examples);
	        if (ms1) {
	            var examples = ms1.examples();
	            if (examples && examples.length > 0) {
	                return examples[0];
	            }
	        }
	        var d = t.oneMeta(meta.Default);
	        if (d) {
	            return d.value();
	        }
	        if (t.isObject()) {
	            var result = {};
	            t.meta().forEach(function (x) {
	                if (x instanceof restrictions_2.PropertyIs) {
	                    var p = x;
	                    var ex = example(p.value());
	                    result[p.propertyName()] = ex;
	                }
	            });
	            t.superTypes().forEach(function (x) {
	                if (x.oneMeta(meta.Example) || x.oneMeta(meta.Examples)) {
	                    var ex = example(x);
	                    if (ex && typeof ex === "object") {
	                        Object.keys(ex).forEach(function (key) {
	                            result[key] = ex[key];
	                        });
	                    }
	                }
	            });
	            return result;
	        }
	        if (t.isArray()) {
	            var c = t.oneMeta(restrictions_1.ComponentShouldBeOfType);
	            var resultArray = [];
	            if (c) {
	                resultArray.push(example(c.value()));
	            }
	            return resultArray;
	        }
	        if (t.isUnion()) {
	            return example(t.typeFamily()[0]);
	        }
	        if (t.isNumber()) {
	            return 1;
	        }
	        if (t.isBoolean()) {
	            return true;
	        }
	        return "some value";
	    }
	    finally {
	        t.putExtra(exCalcFlag, false);
	    }
	}
	exports.example = example;
	var Example = (function () {
	    function Example(_value, _name, _displayName, _description, _strict, _annotations, _isSingle, _empty) {
	        if (_name === void 0) { _name = undefined; }
	        if (_displayName === void 0) { _displayName = undefined; }
	        if (_description === void 0) { _description = undefined; }
	        if (_strict === void 0) { _strict = true; }
	        if (_annotations === void 0) { _annotations = undefined; }
	        if (_isSingle === void 0) { _isSingle = false; }
	        if (_empty === void 0) { _empty = false; }
	        this._value = _value;
	        this._name = _name;
	        this._displayName = _displayName;
	        this._description = _description;
	        this._strict = _strict;
	        this._annotations = _annotations;
	        this._isSingle = _isSingle;
	        this._empty = _empty;
	    }
	    Example.prototype.isEmpty = function () {
	        return this._empty;
	    };
	    Example.prototype.isJSONString = function () {
	        return typeof this._value === "string" && ((this._value + "").trim().indexOf("{") == 0 || (this._value + "").trim().indexOf("[") == 0);
	    };
	    Example.prototype.isXMLString = function () {
	        return typeof this._value === "string" && (this._value + "").trim().indexOf("<") == 0;
	    };
	    Example.prototype.asXMLString = function () {
	        if (this.isXMLString()) {
	            return this._value;
	        }
	        if (this._owner) {
	            return this._owner.asXMLString();
	        }
	        return null;
	    };
	    Example.prototype.isYAML = function () {
	        if (typeof this._value === "string") {
	            return !(this.isJSONString() || this.isXMLString());
	        }
	        return true;
	    };
	    Example.prototype.asString = function () {
	        if (typeof this._value === "string") {
	            return "" + this._value;
	        }
	        return this.expandAsString();
	    };
	    Example.prototype.asJSON = function () {
	        if (this.isJSONString()) {
	            try {
	                return JSON.parse(this._value);
	            }
	            catch (e) {
	                return null;
	            }
	        }
	        if (this.isYAML()) {
	            return this._value;
	        }
	        return this.expandAsString();
	    };
	    Example.prototype.original = function () {
	        return this._value;
	    };
	    Example.prototype.expandAsString = function () {
	        return JSON.stringify(this.expandAsJSON(), null, 2);
	    };
	    Example.prototype.expandAsJSON = function () {
	        return this._value;
	    };
	    Example.prototype.isSingle = function () {
	        return this._isSingle;
	    };
	    Example.prototype.strict = function () {
	        return this._strict;
	    };
	    Example.prototype.description = function () {
	        return this._description;
	    };
	    Example.prototype.displayName = function () {
	        return this._displayName;
	    };
	    Example.prototype.annotations = function () {
	        return this._annotations;
	    };
	    Example.prototype.name = function () {
	        return this._name;
	    };
	    return Example;
	}());
	var toExample = function (owner, exampleObj, name, isSingle) {
	    if (name === void 0) { name = null; }
	    if (isSingle === void 0) { isSingle = false; }
	    var example;
	    if (exampleObj) {
	        var val = exampleObj.value;
	        if (!val) {
	            val = exampleObj;
	            example = new Example(val, name, undefined, undefined, true, undefined, isSingle);
	        }
	        else {
	            var displayName = exampleObj.displayName;
	            var description = exampleObj.description;
	            var strict = exampleObj.strict;
	            var aObj = null;
	            var annotationNames = Object.keys(exampleObj).filter(function (x) { return x.charAt(0) == "("; });
	            if (annotationNames.length > 0) {
	                aObj = {};
	                for (var _i = 0, annotationNames_1 = annotationNames; _i < annotationNames_1.length; _i++) {
	                    var aName = annotationNames_1[_i];
	                    var aVal = exampleObj[aName];
	                    aName = aName.substring(1, aName.length - 1);
	                    aObj[aName] = aVal;
	                }
	            }
	            example = new Example(val, name, displayName, description, strict, aObj, isSingle);
	        }
	    }
	    if (example) {
	        example._owner = owner;
	    }
	    return example;
	};
	function exampleFromNominal(n) {
	    var tp = n.getAdapter(rt.InheritedType);
	    if (tp) {
	        var result = [];
	        var ms1 = tp.oneMeta(meta.Examples);
	        if (ms1) {
	            var vl = ms1.value();
	            if (vl && typeof vl === "object") {
	                var xmlValues;
	                Object.keys(vl).forEach(function (key) {
	                    var name = Array.isArray(vl) ? null : key;
	                    var exampleObj = vl[key];
	                    var example = toExample({ asXMLString: function () {
	                            if (!xmlValues) {
	                                xmlValues = ms1.asXMLStrings();
	                            }
	                            return xmlValues[key];
	                        } }, exampleObj, name);
	                    result.push(example);
	                });
	            }
	        }
	        var ms = tp.oneMeta(meta.Example);
	        if (ms) {
	            var exampleV = ms.example();
	            if (exampleV) {
	                result.push(toExample(ms, ms.value(), undefined, true));
	            }
	        }
	        if (result.length > 0) {
	            return result;
	        }
	    }
	    if (tp) {
	        return [new Example(example(tp), undefined, undefined, undefined, false, undefined, undefined, true)];
	    }
	    return [];
	}
	exports.exampleFromNominal = exampleFromNominal;
	//# sourceMappingURL=exampleBuilder.js.map

/***/ },
/* 135 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var __extends = (this && this.__extends) || function (d, b) {
	    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
	    function __() { this.constructor = d; }
	    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
	};
	var date = __webpack_require__(192);
	var ts = __webpack_require__(90);
	var DateOnlyR = (function (_super) {
	    __extends(DateOnlyR, _super);
	    function DateOnlyR() {
	        _super.apply(this, arguments);
	    }
	    DateOnlyR.prototype.check = function (i) {
	        if (typeof i == "string") {
	            if (!date.isValid(i, "YYYY-MM-DD")) {
	                return new ts.Status(ts.Status.ERROR, 0, "date-only should match to yyyy-mm-dd pattern", this);
	            }
	            return ts.ok();
	        }
	        return new ts.Status(ts.Status.ERROR, 0, "date-only should be string matching to  yyyy-mm-dd pattern ", this);
	    };
	    DateOnlyR.prototype.requiredType = function () {
	        return ts.STRING;
	    };
	    DateOnlyR.prototype.value = function () {
	        return true;
	    };
	    DateOnlyR.prototype.facetName = function () {
	        return "should be date-only";
	    };
	    return DateOnlyR;
	}(ts.GenericTypeOf));
	exports.DateOnlyR = DateOnlyR;
	var TimeOnlyR = (function (_super) {
	    __extends(TimeOnlyR, _super);
	    function TimeOnlyR() {
	        _super.apply(this, arguments);
	    }
	    TimeOnlyR.prototype.check = function (i) {
	        if (typeof i == "string") {
	            var c = i.indexOf(".");
	            if (c != -1) {
	                i = i.substring(0, c);
	            }
	            if (!i.match("[0-9][0-9]:[0-9][0-9]:[0-9][0-9]") || !date.isValid("11 " + i.trim(), "YY HH:mm:ss")) {
	                return new ts.Status(ts.Status.ERROR, 0, "time-only should match to hh:mm:ss[.ff...] pattern", this);
	            }
	            return ts.ok();
	        }
	        return new ts.Status(ts.Status.ERROR, 0, "time-only should be string matching to  hh:mm:ss[.ff...] pattern ", this);
	    };
	    TimeOnlyR.prototype.requiredType = function () {
	        return ts.STRING;
	    };
	    TimeOnlyR.prototype.value = function () {
	        return true;
	    };
	    TimeOnlyR.prototype.facetName = function () {
	        return "should be time-only";
	    };
	    return TimeOnlyR;
	}(ts.GenericTypeOf));
	exports.TimeOnlyR = TimeOnlyR;
	var DateTimeOnlyR = (function (_super) {
	    __extends(DateTimeOnlyR, _super);
	    function DateTimeOnlyR() {
	        _super.apply(this, arguments);
	    }
	    DateTimeOnlyR.prototype.check = function (i) {
	        if (typeof i == "string") {
	            var c = i.indexOf(".");
	            if (c != -1) {
	                i = i.substring(0, c);
	            }
	            if (!i.match("^\\d{4}-\\d{2}-\\d{2}T" + "[0-9][0-9]:[0-9][0-9]:[0-9][0-9]$")) {
	                return new ts.Status(ts.Status.ERROR, 0, "datetime-only should match to yyyy-mm-ddThh:mm:ss[.ff...] pattern", this);
	            }
	            return ts.ok();
	        }
	        return new ts.Status(ts.Status.ERROR, 0, "datetime-only should be string matching to  yyyy-mm-ddThh:mm:ss[.ff...] pattern ", this);
	    };
	    DateTimeOnlyR.prototype.requiredType = function () {
	        return ts.STRING;
	    };
	    DateTimeOnlyR.prototype.value = function () {
	        return true;
	    };
	    DateTimeOnlyR.prototype.facetName = function () {
	        return "should be datetime-only";
	    };
	    return DateTimeOnlyR;
	}(ts.GenericTypeOf));
	exports.DateTimeOnlyR = DateTimeOnlyR;
	var r1 = /(Mon|Tue|Wed|Thu|Fri|Sat|Sun)\,[ ]+\d{2}[ ]+(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)[ ]+\d{4}[ ]+\d{2}:\d{2}:\d{2}[ ]+GMT/;
	var r2 = /(Monday|Tuesday|Wednesday|Thursday|Friday|Saturday|Sunday)\,[ ]+\d{2}-(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)-\d{2}[ ]+\d{2}:\d{2}:\d{2}[ ]+GMT/;
	var r3 = /(Mon|Tue|Wed|Thu|Fri|Sat|Sun)\,[ ]+(Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec)[ ]+\d{1,2}[ ]+\d{2}:\d{2}:\d{2}[ ]+GMT/;
	var r0 = /^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}:\d{2}(?:\.\d{1,3})?((?:[\+\-]\d{2}:\d{2})|Z)$/;
	var DateTimeR = (function (_super) {
	    __extends(DateTimeR, _super);
	    function DateTimeR() {
	        _super.apply(this, arguments);
	    }
	    DateTimeR.prototype.check = function (i) {
	        var c = ts.VALIDATED_TYPE;
	        var rfc2616 = false;
	        c.allCustomFacets().forEach(function (x) {
	            if (x.facetName() == "format") {
	                if (x.value() === "rfc2616") {
	                    rfc2616 = true;
	                }
	            }
	        });
	        if (typeof i == "string") {
	            if (!rfc2616) {
	                if (!i.match(r0)) {
	                    return new ts.Status(ts.Status.ERROR, 0, "valid rfc3339 formatted string is expected", this);
	                }
	                return ts.ok();
	            }
	            else {
	                if (!(i.match(r1) || i.match(r2) || i.match(r3))) {
	                    return new ts.Status(ts.Status.ERROR, 0, "valid rfc2616 formatted string is expected", this);
	                }
	            }
	            return ts.ok();
	        }
	        return new ts.Status(ts.Status.ERROR, 0, "valid datetime formatted string is expected", this);
	    };
	    DateTimeR.prototype.requiredType = function () {
	        return ts.STRING;
	    };
	    DateTimeR.prototype.value = function () {
	        return true;
	    };
	    DateTimeR.prototype.facetName = function () {
	        return "should be datetime-only";
	    };
	    return DateTimeR;
	}(ts.GenericTypeOf));
	exports.DateTimeR = DateTimeR;
	//# sourceMappingURL=datetime.js.map

/***/ },
/* 136 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var typeExpression = __webpack_require__(167);
	var ts = __webpack_require__(90);
	var restrictions_1 = __webpack_require__(94);
	function parseToType(val, t, contentProvider) {
	    if (contentProvider === void 0) { contentProvider = null; }
	    try {
	        var q = val.trim();
	        var json = q.charAt(0) == '{';
	        if (json || q.charAt(0) == '<') {
	            return new ts.ExternalType("", q, json, contentProvider);
	        }
	        var node = typeExpression.parse(val);
	        var result = parseNode(node, t);
	        return result;
	    }
	    catch (e) {
	        return ts.derive(val, [ts.UNKNOWN]);
	    }
	}
	exports.parseToType = parseToType;
	function wrapArray(a, result) {
	    while (a > 0) {
	        var nt = ts.derive("", [ts.ARRAY]);
	        nt.addMeta(new restrictions_1.ComponentShouldBeOfType(result));
	        result = nt;
	        a--;
	    }
	    return result;
	}
	function parseNode(node, t) {
	    if (node.type == "union") {
	        var ut = node;
	        return ts.union("", [parseNode(ut.first, t), parseNode(ut.rest, t)]);
	    }
	    else if (node.type == "parens") {
	        var ps = node;
	        var rs = parseNode(ps.expr, t);
	        return wrapArray(ps.arr, rs);
	    }
	    else {
	        var lit = node;
	        if (lit.value.charAt(lit.value.length - 1) == '?') {
	            var result = t.get(lit.value.substr(0, lit.value.length - 1));
	            if (!result) {
	                result = ts.derive(lit.value, [ts.UNKNOWN]);
	            }
	            result = ts.union(lit.value, [result, ts.NULL]);
	            var a = lit.arr;
	            return wrapArray(a, result);
	        }
	        var result = t.get(lit.value);
	        if (!result) {
	            result = ts.derive(lit.value, [ts.UNKNOWN]);
	        }
	        var a = lit.arr;
	        return wrapArray(a, result);
	    }
	}
	function storeToString(t) {
	    if (t.isSubTypeOf(ts.ARRAY)) {
	        var cm = t.oneMeta(restrictions_1.ComponentShouldBeOfType);
	        if (cm) {
	            if (cm.value().isUnion()) {
	                return "(" + storeToString(cm.value()) + ")" + "[]";
	            }
	            else
	                return storeToString(cm.value()) + "[]";
	        }
	        return "array";
	    }
	    if (t instanceof ts.UnionType) {
	        var ut = t;
	        return ut.options().map(function (x) { return storeToString(x); }).join(" | ");
	    }
	    if (t.isAnonymous()) {
	        if (t.isEmpty()) {
	            return t.superTypes().map(function (x) { return storeToString(x); }).join(" , ");
	        }
	    }
	    return t.name();
	}
	exports.storeToString = storeToString;
	function visit(node, action) {
	    action(node);
	    if (node.type == "union") {
	        var union = node;
	        visit(union.first, action);
	        visit(union.rest, action);
	    }
	    else if (node.type == "parens") {
	        var parens = node;
	        visit(parens.expr, action);
	    }
	}
	exports.visit = visit;
	function serializeToString(node) {
	    var arr = 0;
	    var str;
	    if (node.type == "name") {
	        var literal = node;
	        str = literal.value;
	        arr = literal.arr;
	    }
	    else if (node.type == "union") {
	        var union = node;
	        str = serializeToString(union.first) + " | " + serializeToString(union.rest);
	    }
	    else if (node.type == "parens") {
	        var parens = node;
	        str = "(" + serializeToString(parens.expr) + ")";
	        arr = parens.arr;
	    }
	    while (--arr >= 0) {
	        str += "[]";
	    }
	    return str;
	}
	exports.serializeToString = serializeToString;
	function parse(str) {
	    return typeExpression.parse(str);
	}
	exports.parse = parse;
	//# sourceMappingURL=typeExpressions.js.map

/***/ },
/* 137 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	/// <reference path="../typings/main.d.ts" />
	var xml2js = __webpack_require__(200);
	var _ = __webpack_require__(177);
	var restrictions_1 = __webpack_require__(94);
	var metainfo_1 = __webpack_require__(95);
	var typesystem_1 = __webpack_require__(90);
	var XML_ERRORS = '@unexpected_root_attributes_and_elements';
	var bodyNames = [
	    'application/x-www-form-urlencoded',
	    'application/json',
	    'application/xml',
	    'multipart/form-data'
	];
	function xmlOpen(tagname, attributes, level, newLine) {
	    if (level === void 0) { level = 0; }
	    if (newLine === void 0) { newLine = true; }
	    var result = '<' + tagname;
	    for (var i = 0; i < level; i++) {
	        result = '    ' + result;
	    }
	    if (attributes && Object.keys(attributes).length > 0) {
	        Object.keys(attributes).forEach(function (key) {
	            if (typeof attributes[key] !== 'string') {
	                return;
	            }
	            result = result + ' ' + key + '="' + attributes[key] + '"';
	        });
	    }
	    result = result + '>' + (newLine ? '\n' : '');
	    return result;
	}
	;
	function xmlClose(tagname, level) {
	    if (level === void 0) { level = 0; }
	    var result = '</' + tagname;
	    for (var i = 0; i < level && i > -1; i++) {
	        result = '    ' + result;
	    }
	    var result = (level > -1 ? '\n' : '') + result + '>\n';
	    return result;
	}
	function serializeToXML(object, type) {
	    type = actualType(type);
	    var expectedRootNodeName = rootXmlName(type);
	    var infos = getInfos(type);
	    var result = xmlOpen(expectedRootNodeName, getAttributesFromJson(object, infos));
	    var valueWrapper = {};
	    valueWrapper[expectedRootNodeName] = object;
	    if (type.isArray()) {
	        var componentMeta = type.meta().filter(function (metaInfo) { return metaInfo instanceof restrictions_1.ComponentShouldBeOfType; })[0];
	        result = result + getArrayFromJson(valueWrapper, type, 1, true);
	    }
	    else {
	        result = result + getElementsFromJson(object, infos, 1);
	    }
	    var result = result + xmlClose(expectedRootNodeName);
	    return result;
	}
	exports.serializeToXML = serializeToXML;
	function getAttributesFromJson(node, infos) {
	    var nodeAttributes = {};
	    var attributeInfos = _.filter(infos, function (info) { return xmlDescriptor(info.value()).attribute; });
	    attributeInfos.forEach(function (info) {
	        var key = info.propId();
	        var xmlKey = xmlName(info);
	        if (node[key]) {
	            nodeAttributes[xmlKey] = node[key].toString();
	        }
	    });
	    return nodeAttributes;
	}
	function getElementFromJson(node, type, level) {
	    var jsonKey = Object.keys(node)[0];
	    var jsonValue = node[jsonKey];
	    var result = null;
	    if (type.isScalar()) {
	        var infos = getInfos(type);
	        result = xmlOpen(jsonKey, getAttributesFromJson(jsonValue, infos), level, !type.isScalar()) + jsonValue.toString();
	    }
	    else if (type.isUnion()) {
	        return getElementFromJson(node, selectTypeFromJson(jsonValue, type), level);
	    }
	    else {
	        var infos = getInfos(type);
	        result = xmlOpen(jsonKey, getAttributesFromJson(jsonValue, infos), level, !type.isScalar()) + getElementsFromJson(jsonValue, infos, level + 1);
	    }
	    result = result + xmlClose(jsonKey, type.isScalar() ? -1 : level);
	    return result;
	}
	function selectTypeFromJson(value, unionType) {
	    var canBeTypes = unionType.typeFamily();
	    var results = [];
	    var result = null;
	    canBeTypes.forEach(function (type) {
	        var xmlValue = serializeToXML(value, type);
	        if (!xmlValue) {
	            return;
	        }
	        var jsonValue = readObject(xmlValue, type);
	        if (jsonValue) {
	            var errors = getXmlErrors(jsonValue);
	            results.push({ type: type, errors: (errors && errors.length) || 0 });
	        }
	    });
	    result = results.length > 0 ? results[0] : { type: canBeTypes[0] };
	    results.forEach(function (canBe) {
	        if (canBe.errors < result.errors) {
	            result = canBe;
	        }
	    });
	    return result.type;
	}
	function getElementsFromJson(node, infos, level) {
	    var elementInfos = _.filter(infos, function (info) { return !xmlDescriptor(info.value()).attribute; });
	    var result = '';
	    elementInfos.forEach(function (info) {
	        var xmlKey = xmlName(info);
	        var key = info.propId();
	        var value = {};
	        value[xmlKey] = node[key];
	        if (info.value().isArray()) {
	            result = result + getArrayFromJson(value, info.value(), level);
	        }
	        else {
	            result = result + ((node[key] || node[key] === '') ? getElementFromJson(value, info.value(), level) : '');
	        }
	    });
	    return result;
	}
	function getArrayFromJson(values, type, level, rootNode) {
	    if (rootNode === void 0) { rootNode = false; }
	    var jsonKey = Object.keys(values)[0];
	    var jsonValue = values[jsonKey];
	    var descriptor = xmlDescriptor(type);
	    var isWrapped = rootNode || descriptor.wrapped;
	    var result = '';
	    var componentType = arrayElementType(type);
	    var typeName = componentType && componentType.name();
	    var elementsLevel = level;
	    if (isWrapped && !rootNode) {
	        result = xmlOpen(jsonKey, null, level);
	        elementsLevel = elementsLevel + 1;
	    }
	    if (jsonValue && isArray(jsonValue)) {
	        jsonValue.forEach(function (item) {
	            var itemWrapper = {};
	            itemWrapper[isWrapped ? typeName : jsonKey] = item;
	            result = result + getElementFromJson(itemWrapper, componentType, elementsLevel);
	        });
	    }
	    if (isWrapped) {
	        result = result + xmlClose(jsonKey, level);
	    }
	    return result;
	}
	function readObject(content, t) {
	    var result = null;
	    var opts = {};
	    opts.explicitChildren = false;
	    opts.explicitArray = false;
	    opts.explicitRoot = isSchema(t) || !t.isExternal();
	    xml2js.parseString(content, opts, function (err, res) {
	        result = res;
	        if (err) {
	            throw new Error();
	        }
	    });
	    result = isSchema(t) ? result : postProcess(result, actualType(t));
	    return result;
	}
	exports.readObject = readObject;
	function getXmlErrors(root) {
	    var errors = root[XML_ERRORS];
	    delete root[XML_ERRORS];
	    if (!errors || errors.length === 0) {
	        return null;
	    }
	    return errors.map(function (error) { return new typesystem_1.Status(typesystem_1.Status.ERROR, 0, error, {}); });
	}
	exports.getXmlErrors = getXmlErrors;
	function actualType(type) {
	    if (!type) {
	        return type;
	    }
	    if (isBodyLike(type)) {
	        if (!type.superTypes() || type.superTypes().length === 0) {
	            return type;
	        }
	        if (type.superTypes().length === 1) {
	            return type.superTypes()[0];
	        }
	        return _.find(type.allSuperTypes(), function (superType) { return superType.name() === 'object'; }) || type;
	    }
	    return type;
	}
	function isBodyLike(type) {
	    if (!type) {
	        return false;
	    }
	    return _.find(bodyNames, function (name) { return type.name() === name; }) ? true : false;
	}
	function isSchema(t) {
	    if (isXmlContent(t)) {
	        return true;
	    }
	    return _.find(t.allSuperTypes(), function (supertype) { return isXmlContent(supertype); }) ? true : false;
	}
	function isXmlContent(t) {
	    if (t.isExternal() && t._content && typeof t._content === 'string' && t._content.trim().indexOf('<') === 0) {
	        return true;
	    }
	    return false;
	}
	function postProcess(result, type) {
	    var rootNodeName = Object.keys(result)[0];
	    var rootNode = result[rootNodeName];
	    var errors = [];
	    var expectedRootNodeName = rootXmlName(type);
	    if (expectedRootNodeName !== rootNodeName) {
	        errors.push('Unexpected root node "' + rootNodeName + '", "' + expectedRootNodeName + '" is expected.');
	    }
	    var newJson;
	    if (type.isArray()) {
	        var expectedAttributeNames = [];
	        var expectedElementNames = [];
	        var componentMeta = type.meta().filter(function (metaInfo) { return metaInfo instanceof restrictions_1.ComponentShouldBeOfType; })[0];
	        var typeName = componentMeta && componentMeta.value().name();
	        expectedElementNames.push(typeName);
	        newJson = getArray(rootNode, type, errors, true);
	        fillExtras(rootNode, errors, expectedAttributeNames, expectedElementNames);
	    }
	    else {
	        newJson = buildJson(rootNode, type.isUnion() ? selectFromUnion(rootNode, type) : type, errors);
	    }
	    newJson[XML_ERRORS] = errors;
	    return newJson;
	}
	function checkErrors(rootNode, actualType) {
	    var errors = [];
	    var newJson;
	    newJson = buildJson(rootNode, actualType, errors);
	    var validationErrors = actualType.validateDirect(newJson, true, false).getErrors();
	    return errors.length + (validationErrors && validationErrors.length);
	}
	function selectFromUnion(rootNode, union) {
	    var results = [];
	    union.typeFamily().forEach(function (type) { return results.push({ type: type, errors: checkErrors(JSON.parse(JSON.stringify(rootNode)), type) }); });
	    if (results.length === 0) {
	        return union;
	    }
	    var result = results[0];
	    results.forEach(function (oneOf) {
	        if (oneOf.errors < result.errors) {
	            result = oneOf;
	        }
	    });
	    return result.type;
	}
	function buildJson(node, type, errors) {
	    var initialRoot = {};
	    if (!type) {
	        return node;
	    }
	    if (type.isScalar()) {
	        return toPrimitiveValue(type, node, errors);
	    }
	    if (type.isUnion()) {
	        return buildJson(node, selectFromUnion(node, type), errors);
	    }
	    var infos = getInfos(type);
	    var expectedAttributeNames = [];
	    var expectedElementNames = [];
	    getAttributes(node, infos, expectedAttributeNames).forEach(function (attribute) { return initialRoot[Object.keys(attribute)[0]] = attribute[Object.keys(attribute)[0]]; });
	    getElements(node, infos, expectedElementNames, errors).forEach(function (element) { return initialRoot[Object.keys(element)[0]] = element[Object.keys(element)[0]]; });
	    fillExtras(node, errors, expectedAttributeNames, expectedElementNames);
	    return initialRoot;
	}
	function fillExtras(node, errors, expectedAttributeNames, expectedElementNames, remove) {
	    if (remove === void 0) { remove = false; }
	    if (typeof node !== "object") {
	        return;
	    }
	    if (!node['$']) {
	        node['$'] = {};
	    }
	    expectedAttributeNames.forEach(function (name) {
	        delete node['$'][name];
	    });
	    expectedElementNames.forEach(function (name) {
	        delete node[name];
	    });
	    var extraAttributes = Object.keys(node['$']);
	    delete node['$'];
	    var extraElements = Object.keys(node);
	    extraAttributes.forEach(function (name) {
	        errors.push('Unexpected attribute "' + name + '".');
	    });
	    extraElements.forEach(function (name) {
	        errors.push('Unexpected element "' + name + '".');
	        if (remove) {
	            delete node[name];
	        }
	    });
	}
	function getInfos(type) {
	    return type.meta().filter(function (info) { return info instanceof restrictions_1.PropertyIs; }).map(function (info) { return info; }) || [];
	}
	function getAttributes(node, infos, expectedNames) {
	    var nodeAttributes = node['$'];
	    if (!nodeAttributes) {
	        return [];
	    }
	    var attributeInfos = _.filter(infos, function (info) { return xmlDescriptor(info.value()).attribute; });
	    return attributeInfos.map(function (info) {
	        var attribute = {};
	        var key = info.propId();
	        var xmlKey = xmlName(info);
	        expectedNames.push(xmlKey);
	        var value = nodeAttributes[xmlKey];
	        attribute[key] = toPrimitiveValue(info.value(), value);
	        return attribute[key] === null ? null : attribute;
	    }).filter(function (attribute) { return attribute; });
	}
	function getElements(node, infos, expectedNames, errors) {
	    var elementInfos = _.filter(infos, function (info) { return !xmlDescriptor(info.value()).attribute; });
	    return elementInfos.map(function (info) {
	        var element = {};
	        var descriptor = xmlDescriptor(info.value());
	        var key = info.propId();
	        var xmlKey = xmlName(info);
	        expectedNames.push(xmlKey);
	        var value = node[xmlKey];
	        if (info.value().isArray()) {
	            element[key] = getArray(node[xmlKey], info.value(), errors);
	        }
	        else {
	            element[key] = (value || value === '') ? buildJson(value, info.value(), errors) : null;
	        }
	        return element[key] === null ? null : element;
	    }).filter(function (info) { return info; });
	}
	function getArray(values, type, errors, rootNode) {
	    if (rootNode === void 0) { rootNode = false; }
	    var descriptor = xmlDescriptor(type);
	    var isWrapped = rootNode || descriptor.wrapped;
	    var componentType = arrayElementType(type);
	    var typeName = componentType && componentType.name();
	    if (isWrapped) {
	        var valuesWrapper = values;
	        values = values && values[typeName];
	        fillExtras(valuesWrapper, errors, [], [typeName], true);
	    }
	    if (!values) {
	        return [];
	    }
	    values = getArrayValues(values);
	    if (isArray(values)) {
	        values = values.map(function (value) { return buildJson(value, componentType, errors); });
	    }
	    else {
	        values = (typeof values === 'object' && values) || [];
	    }
	    return values;
	}
	function getArrayValues(preValues) {
	    if (isArray(preValues)) {
	        return preValues;
	    }
	    if (typeof preValues === 'object') {
	        return [preValues];
	    }
	    return [];
	}
	function arrayElementType(arrayType) {
	    if (!arrayType || !arrayType.isArray()) {
	        return null;
	    }
	    var componentMetas = arrayType.meta().filter(function (metaInfo) { return metaInfo instanceof restrictions_1.ComponentShouldBeOfType; });
	    return componentMetas && componentMetas.length > 0 && componentMetas[0].value();
	}
	function xmlName(property) {
	    var descriptor = xmlDescriptor(property.value());
	    var ramlName = property.propId();
	    var actualName = descriptor.name || ramlName;
	    if (descriptor.namespace) {
	        actualName = descriptor.namespace + ':' + actualName;
	    }
	    return (descriptor.prefix || '') + actualName;
	}
	function rootXmlName(type) {
	    var descriptor = xmlDescriptor(type);
	    var ramlName = type.name();
	    if (ramlName === '' && type.isUnion()) {
	        ramlName = 'object';
	    }
	    var actualName = descriptor.name || ramlName;
	    return (descriptor.prefix || '') + actualName;
	}
	function xmlDescriptor(type) {
	    var info = type.meta().filter(function (xmlInfo) { return xmlInfo instanceof metainfo_1.XMLInfo; }).map(function (xmlInfo) { return xmlInfo; })[0];
	    var result = {
	        attribute: false,
	        wrapped: false,
	        name: false,
	        namespace: false,
	        prefix: false
	    };
	    if (!info) {
	        return result;
	    }
	    var infoValue = info.value();
	    if (!infoValue) {
	        return result;
	    }
	    Object.keys(result).forEach(function (key) {
	        result[key] = infoValue[key] || result[key];
	    });
	    return result;
	}
	function toPrimitiveValue(type, actual, errors) {
	    if (errors === void 0) { errors = []; }
	    if (typeof actual === 'object') {
	        var result = toPrimitiveValue(type, actual['_']);
	        delete actual['_'];
	        fillExtras(actual, errors, [], [], true);
	        return result;
	    }
	    if (!actual && actual.trim() !== '') {
	        return null;
	    }
	    if (type.isNumber()) {
	        var parsedValue = parseFloat(actual);
	        if (!isNaN(parsedValue)) {
	            return parsedValue;
	        }
	    }
	    if (type.isBoolean()) {
	        if (actual === 'true') {
	            return true;
	        }
	        if (actual === 'false') {
	            return false;
	        }
	    }
	    if (typeof actual === 'string') {
	        return actual;
	    }
	    return null;
	}
	function isArray(instance) {
	    if (!instance) {
	        return false;
	    }
	    return typeof instance === 'object' && typeof instance.length === 'number';
	}
	//# sourceMappingURL=xmlio.js.map

/***/ },
/* 138 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var ValueRequirement = (function () {
	    /**
	     *
	     * @param name name of the property to discriminate
	     * @param value expected value of discriminating property
	     */
	    function ValueRequirement(name, value) {
	        this.name = name;
	        this.value = value;
	    }
	    return ValueRequirement;
	}());
	exports.ValueRequirement = ValueRequirement;
	//# sourceMappingURL=nominal-interfaces.js.map

/***/ },
/* 139 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var _ = __webpack_require__(177);
	function find(t, it) {
	    return _.find(t, it);
	}
	exports.find = find;
	function filter(t, it) {
	    return _.filter(t, it);
	}
	exports.filter = filter;
	function unique(t) {
	    return _.unique(t);
	}
	exports.unique = unique;
	//# sourceMappingURL=utils.js.map

/***/ },
/* 140 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	/// <reference path="../typings/main.d.ts" />
	var validator = __webpack_require__(197);
	var XMLValidator = (function () {
	    function XMLValidator(schema) {
	        this.schema = schema;
	    }
	    XMLValidator.prototype.validate = function (xml) {
	        var result = validator.validateXML({ xml: xml, schema: this.schema });
	        return (result && result.errors && result.errors.map(function (error) { return new Error(error); })) || [];
	    };
	    return XMLValidator;
	}());
	exports.XMLValidator = XMLValidator;
	function objectToXml(object) {
	    if (!object) {
	        return '';
	    }
	    var nodeName = Object.keys(object)[0];
	    var root = object[nodeName];
	    if (!root && root !== '') {
	        return '';
	    }
	    var result = '<' + nodeName;
	    var attributes = root['$'] || {};
	    Object.keys(attributes).forEach(function (key) {
	        result = result + ' ' + key + '="' + attributes[key] + '"';
	    });
	    result = result + '>';
	    if (typeof root === 'string') {
	        result = result + root;
	    }
	    else {
	        Object.keys(root).forEach(function (key) {
	            if (key === '$') {
	                return;
	            }
	            if (typeof root[key] === 'object' && !root[key].length) {
	                var child = {};
	                child[key] = root[key];
	                result = result + objectToXml(child);
	            }
	            else if (typeof root[key] === 'string' || !root[key]) {
	                var child = {};
	                child[key] = root[key] || '';
	                result = result + objectToXml(child);
	            }
	            else if (typeof root[key] === 'array' || root[key].length) {
	                var children = root[key];
	                for (var i = 0; i < children.length; i++) {
	                    var member = children[i];
	                    var child = {};
	                    child[key] = member;
	                    result = result + objectToXml(child);
	                }
	            }
	        });
	    }
	    result = result + '</' + nodeName + '>';
	    return result;
	}
	function jsonToXml(jsonObject) {
	    var nodeName = jsonObject && Object.keys(jsonObject)[0];
	    if (nodeName) {
	        var root = jsonObject[nodeName];
	        checkAttributes(root);
	    }
	    return objectToXml(jsonObject);
	}
	exports.jsonToXml = jsonToXml;
	function checkAttributes(root) {
	    if (!root || typeof root === 'string') {
	        return;
	    }
	    var attributes = [];
	    Object.keys(root).forEach(function (key) {
	        if (key.indexOf('@') === 0) {
	            var attribute = { key: key, value: root[key] };
	            attributes.push(attribute);
	        }
	        else {
	            if (isArray(root[key])) {
	                var elements = root[key];
	                elements.forEach(function (element) { return checkAttributes(element); });
	            }
	            else if (typeof root[key] !== 'string') {
	                checkAttributes(root[key]);
	            }
	        }
	    });
	    if (!root['$']) {
	        root['$'] = {};
	    }
	    var newAttributes = root['$'];
	    attributes.forEach(function (attribute) {
	        delete root[attribute.key];
	        var newKey = attribute.key.substring(1);
	        newAttributes[newKey] = attribute.value;
	    });
	}
	function isArray(instance) {
	    if (!instance) {
	        return false;
	    }
	    return typeof instance === 'object' && typeof instance.length === 'number';
	}
	//# sourceMappingURL=xmlUtil.js.map

/***/ },
/* 141 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(process) {'use strict';

	module.exports = Readable;

	/*<replacement>*/
	var processNextTick = __webpack_require__(193);
	/*</replacement>*/

	/*<replacement>*/
	var isArray = __webpack_require__(195);
	/*</replacement>*/

	/*<replacement>*/
	var Buffer = __webpack_require__(87).Buffer;
	/*</replacement>*/

	Readable.ReadableState = ReadableState;

	var EE = __webpack_require__(194);

	/*<replacement>*/
	var EElistenerCount = function (emitter, type) {
	  return emitter.listeners(type).length;
	};
	/*</replacement>*/

	/*<replacement>*/
	var Stream;
	(function () {
	  try {
	    Stream = __webpack_require__(165);
	  } catch (_) {} finally {
	    if (!Stream) Stream = __webpack_require__(194).EventEmitter;
	  }
	})();
	/*</replacement>*/

	var Buffer = __webpack_require__(87).Buffer;

	/*<replacement>*/
	var util = __webpack_require__(215);
	util.inherits = __webpack_require__(102);
	/*</replacement>*/

	/*<replacement>*/
	var debugUtil = __webpack_require__(168);
	var debug = undefined;
	if (debugUtil && debugUtil.debuglog) {
	  debug = debugUtil.debuglog('stream');
	} else {
	  debug = function () {};
	}
	/*</replacement>*/

	var StringDecoder;

	util.inherits(Readable, Stream);

	var Duplex;
	function ReadableState(options, stream) {
	  Duplex = Duplex || __webpack_require__(143);

	  options = options || {};

	  // object stream flag. Used to make read(n) ignore n and to
	  // make all the buffer merging and length checks go away
	  this.objectMode = !!options.objectMode;

	  if (stream instanceof Duplex) this.objectMode = this.objectMode || !!options.readableObjectMode;

	  // the point at which it stops calling _read() to fill the buffer
	  // Note: 0 is a valid value, means "don't call _read preemptively ever"
	  var hwm = options.highWaterMark;
	  var defaultHwm = this.objectMode ? 16 : 16 * 1024;
	  this.highWaterMark = hwm || hwm === 0 ? hwm : defaultHwm;

	  // cast to ints.
	  this.highWaterMark = ~ ~this.highWaterMark;

	  this.buffer = [];
	  this.length = 0;
	  this.pipes = null;
	  this.pipesCount = 0;
	  this.flowing = null;
	  this.ended = false;
	  this.endEmitted = false;
	  this.reading = false;

	  // a flag to be able to tell if the onwrite cb is called immediately,
	  // or on a later tick.  We set this to true at first, because any
	  // actions that shouldn't happen until "later" should generally also
	  // not happen before the first write call.
	  this.sync = true;

	  // whenever we return null, then we set a flag to say
	  // that we're awaiting a 'readable' event emission.
	  this.needReadable = false;
	  this.emittedReadable = false;
	  this.readableListening = false;
	  this.resumeScheduled = false;

	  // Crypto is kind of old and crusty.  Historically, its default string
	  // encoding is 'binary' so we have to make this configurable.
	  // Everything else in the universe uses 'utf8', though.
	  this.defaultEncoding = options.defaultEncoding || 'utf8';

	  // when piping, we only care about 'readable' events that happen
	  // after read()ing all the bytes and not getting any pushback.
	  this.ranOut = false;

	  // the number of writers that are awaiting a drain event in .pipe()s
	  this.awaitDrain = 0;

	  // if true, a maybeReadMore has been scheduled
	  this.readingMore = false;

	  this.decoder = null;
	  this.encoding = null;
	  if (options.encoding) {
	    if (!StringDecoder) StringDecoder = __webpack_require__(196).StringDecoder;
	    this.decoder = new StringDecoder(options.encoding);
	    this.encoding = options.encoding;
	  }
	}

	var Duplex;
	function Readable(options) {
	  Duplex = Duplex || __webpack_require__(143);

	  if (!(this instanceof Readable)) return new Readable(options);

	  this._readableState = new ReadableState(options, this);

	  // legacy
	  this.readable = true;

	  if (options && typeof options.read === 'function') this._read = options.read;

	  Stream.call(this);
	}

	// Manually shove something into the read() buffer.
	// This returns true if the highWaterMark has not been hit yet,
	// similar to how Writable.write() returns true if you should
	// write() some more.
	Readable.prototype.push = function (chunk, encoding) {
	  var state = this._readableState;

	  if (!state.objectMode && typeof chunk === 'string') {
	    encoding = encoding || state.defaultEncoding;
	    if (encoding !== state.encoding) {
	      chunk = new Buffer(chunk, encoding);
	      encoding = '';
	    }
	  }

	  return readableAddChunk(this, state, chunk, encoding, false);
	};

	// Unshift should *always* be something directly out of read()
	Readable.prototype.unshift = function (chunk) {
	  var state = this._readableState;
	  return readableAddChunk(this, state, chunk, '', true);
	};

	Readable.prototype.isPaused = function () {
	  return this._readableState.flowing === false;
	};

	function readableAddChunk(stream, state, chunk, encoding, addToFront) {
	  var er = chunkInvalid(state, chunk);
	  if (er) {
	    stream.emit('error', er);
	  } else if (chunk === null) {
	    state.reading = false;
	    onEofChunk(stream, state);
	  } else if (state.objectMode || chunk && chunk.length > 0) {
	    if (state.ended && !addToFront) {
	      var e = new Error('stream.push() after EOF');
	      stream.emit('error', e);
	    } else if (state.endEmitted && addToFront) {
	      var e = new Error('stream.unshift() after end event');
	      stream.emit('error', e);
	    } else {
	      var skipAdd;
	      if (state.decoder && !addToFront && !encoding) {
	        chunk = state.decoder.write(chunk);
	        skipAdd = !state.objectMode && chunk.length === 0;
	      }

	      if (!addToFront) state.reading = false;

	      // Don't add to the buffer if we've decoded to an empty string chunk and
	      // we're not in object mode
	      if (!skipAdd) {
	        // if we want the data now, just emit it.
	        if (state.flowing && state.length === 0 && !state.sync) {
	          stream.emit('data', chunk);
	          stream.read(0);
	        } else {
	          // update the buffer info.
	          state.length += state.objectMode ? 1 : chunk.length;
	          if (addToFront) state.buffer.unshift(chunk);else state.buffer.push(chunk);

	          if (state.needReadable) emitReadable(stream);
	        }
	      }

	      maybeReadMore(stream, state);
	    }
	  } else if (!addToFront) {
	    state.reading = false;
	  }

	  return needMoreData(state);
	}

	// if it's past the high water mark, we can push in some more.
	// Also, if we have no data yet, we can stand some
	// more bytes.  This is to work around cases where hwm=0,
	// such as the repl.  Also, if the push() triggered a
	// readable event, and the user called read(largeNumber) such that
	// needReadable was set, then we ought to push more, so that another
	// 'readable' event will be triggered.
	function needMoreData(state) {
	  return !state.ended && (state.needReadable || state.length < state.highWaterMark || state.length === 0);
	}

	// backwards compatibility.
	Readable.prototype.setEncoding = function (enc) {
	  if (!StringDecoder) StringDecoder = __webpack_require__(196).StringDecoder;
	  this._readableState.decoder = new StringDecoder(enc);
	  this._readableState.encoding = enc;
	  return this;
	};

	// Don't raise the hwm > 8MB
	var MAX_HWM = 0x800000;
	function computeNewHighWaterMark(n) {
	  if (n >= MAX_HWM) {
	    n = MAX_HWM;
	  } else {
	    // Get the next highest power of 2
	    n--;
	    n |= n >>> 1;
	    n |= n >>> 2;
	    n |= n >>> 4;
	    n |= n >>> 8;
	    n |= n >>> 16;
	    n++;
	  }
	  return n;
	}

	function howMuchToRead(n, state) {
	  if (state.length === 0 && state.ended) return 0;

	  if (state.objectMode) return n === 0 ? 0 : 1;

	  if (n === null || isNaN(n)) {
	    // only flow one buffer at a time
	    if (state.flowing && state.buffer.length) return state.buffer[0].length;else return state.length;
	  }

	  if (n <= 0) return 0;

	  // If we're asking for more than the target buffer level,
	  // then raise the water mark.  Bump up to the next highest
	  // power of 2, to prevent increasing it excessively in tiny
	  // amounts.
	  if (n > state.highWaterMark) state.highWaterMark = computeNewHighWaterMark(n);

	  // don't have that much.  return null, unless we've ended.
	  if (n > state.length) {
	    if (!state.ended) {
	      state.needReadable = true;
	      return 0;
	    } else {
	      return state.length;
	    }
	  }

	  return n;
	}

	// you can override either this method, or the async _read(n) below.
	Readable.prototype.read = function (n) {
	  debug('read', n);
	  var state = this._readableState;
	  var nOrig = n;

	  if (typeof n !== 'number' || n > 0) state.emittedReadable = false;

	  // if we're doing read(0) to trigger a readable event, but we
	  // already have a bunch of data in the buffer, then just trigger
	  // the 'readable' event and move on.
	  if (n === 0 && state.needReadable && (state.length >= state.highWaterMark || state.ended)) {
	    debug('read: emitReadable', state.length, state.ended);
	    if (state.length === 0 && state.ended) endReadable(this);else emitReadable(this);
	    return null;
	  }

	  n = howMuchToRead(n, state);

	  // if we've ended, and we're now clear, then finish it up.
	  if (n === 0 && state.ended) {
	    if (state.length === 0) endReadable(this);
	    return null;
	  }

	  // All the actual chunk generation logic needs to be
	  // *below* the call to _read.  The reason is that in certain
	  // synthetic stream cases, such as passthrough streams, _read
	  // may be a completely synchronous operation which may change
	  // the state of the read buffer, providing enough data when
	  // before there was *not* enough.
	  //
	  // So, the steps are:
	  // 1. Figure out what the state of things will be after we do
	  // a read from the buffer.
	  //
	  // 2. If that resulting state will trigger a _read, then call _read.
	  // Note that this may be asynchronous, or synchronous.  Yes, it is
	  // deeply ugly to write APIs this way, but that still doesn't mean
	  // that the Readable class should behave improperly, as streams are
	  // designed to be sync/async agnostic.
	  // Take note if the _read call is sync or async (ie, if the read call
	  // has returned yet), so that we know whether or not it's safe to emit
	  // 'readable' etc.
	  //
	  // 3. Actually pull the requested chunks out of the buffer and return.

	  // if we need a readable event, then we need to do some reading.
	  var doRead = state.needReadable;
	  debug('need readable', doRead);

	  // if we currently have less than the highWaterMark, then also read some
	  if (state.length === 0 || state.length - n < state.highWaterMark) {
	    doRead = true;
	    debug('length less than watermark', doRead);
	  }

	  // however, if we've ended, then there's no point, and if we're already
	  // reading, then it's unnecessary.
	  if (state.ended || state.reading) {
	    doRead = false;
	    debug('reading or ended', doRead);
	  }

	  if (doRead) {
	    debug('do read');
	    state.reading = true;
	    state.sync = true;
	    // if the length is currently zero, then we *need* a readable event.
	    if (state.length === 0) state.needReadable = true;
	    // call internal read method
	    this._read(state.highWaterMark);
	    state.sync = false;
	  }

	  // If _read pushed data synchronously, then `reading` will be false,
	  // and we need to re-evaluate how much data we can return to the user.
	  if (doRead && !state.reading) n = howMuchToRead(nOrig, state);

	  var ret;
	  if (n > 0) ret = fromList(n, state);else ret = null;

	  if (ret === null) {
	    state.needReadable = true;
	    n = 0;
	  }

	  state.length -= n;

	  // If we have nothing in the buffer, then we want to know
	  // as soon as we *do* get something into the buffer.
	  if (state.length === 0 && !state.ended) state.needReadable = true;

	  // If we tried to read() past the EOF, then emit end on the next tick.
	  if (nOrig !== n && state.ended && state.length === 0) endReadable(this);

	  if (ret !== null) this.emit('data', ret);

	  return ret;
	};

	function chunkInvalid(state, chunk) {
	  var er = null;
	  if (!Buffer.isBuffer(chunk) && typeof chunk !== 'string' && chunk !== null && chunk !== undefined && !state.objectMode) {
	    er = new TypeError('Invalid non-string/buffer chunk');
	  }
	  return er;
	}

	function onEofChunk(stream, state) {
	  if (state.ended) return;
	  if (state.decoder) {
	    var chunk = state.decoder.end();
	    if (chunk && chunk.length) {
	      state.buffer.push(chunk);
	      state.length += state.objectMode ? 1 : chunk.length;
	    }
	  }
	  state.ended = true;

	  // emit 'readable' now to make sure it gets picked up.
	  emitReadable(stream);
	}

	// Don't emit readable right away in sync mode, because this can trigger
	// another read() call => stack overflow.  This way, it might trigger
	// a nextTick recursion warning, but that's not so bad.
	function emitReadable(stream) {
	  var state = stream._readableState;
	  state.needReadable = false;
	  if (!state.emittedReadable) {
	    debug('emitReadable', state.flowing);
	    state.emittedReadable = true;
	    if (state.sync) processNextTick(emitReadable_, stream);else emitReadable_(stream);
	  }
	}

	function emitReadable_(stream) {
	  debug('emit readable');
	  stream.emit('readable');
	  flow(stream);
	}

	// at this point, the user has presumably seen the 'readable' event,
	// and called read() to consume some data.  that may have triggered
	// in turn another _read(n) call, in which case reading = true if
	// it's in progress.
	// However, if we're not ended, or reading, and the length < hwm,
	// then go ahead and try to read some more preemptively.
	function maybeReadMore(stream, state) {
	  if (!state.readingMore) {
	    state.readingMore = true;
	    processNextTick(maybeReadMore_, stream, state);
	  }
	}

	function maybeReadMore_(stream, state) {
	  var len = state.length;
	  while (!state.reading && !state.flowing && !state.ended && state.length < state.highWaterMark) {
	    debug('maybeReadMore read 0');
	    stream.read(0);
	    if (len === state.length)
	      // didn't get any data, stop spinning.
	      break;else len = state.length;
	  }
	  state.readingMore = false;
	}

	// abstract method.  to be overridden in specific implementation classes.
	// call cb(er, data) where data is <= n in length.
	// for virtual (non-string, non-buffer) streams, "length" is somewhat
	// arbitrary, and perhaps not very meaningful.
	Readable.prototype._read = function (n) {
	  this.emit('error', new Error('not implemented'));
	};

	Readable.prototype.pipe = function (dest, pipeOpts) {
	  var src = this;
	  var state = this._readableState;

	  switch (state.pipesCount) {
	    case 0:
	      state.pipes = dest;
	      break;
	    case 1:
	      state.pipes = [state.pipes, dest];
	      break;
	    default:
	      state.pipes.push(dest);
	      break;
	  }
	  state.pipesCount += 1;
	  debug('pipe count=%d opts=%j', state.pipesCount, pipeOpts);

	  var doEnd = (!pipeOpts || pipeOpts.end !== false) && dest !== process.stdout && dest !== process.stderr;

	  var endFn = doEnd ? onend : cleanup;
	  if (state.endEmitted) processNextTick(endFn);else src.once('end', endFn);

	  dest.on('unpipe', onunpipe);
	  function onunpipe(readable) {
	    debug('onunpipe');
	    if (readable === src) {
	      cleanup();
	    }
	  }

	  function onend() {
	    debug('onend');
	    dest.end();
	  }

	  // when the dest drains, it reduces the awaitDrain counter
	  // on the source.  This would be more elegant with a .once()
	  // handler in flow(), but adding and removing repeatedly is
	  // too slow.
	  var ondrain = pipeOnDrain(src);
	  dest.on('drain', ondrain);

	  var cleanedUp = false;
	  function cleanup() {
	    debug('cleanup');
	    // cleanup event handlers once the pipe is broken
	    dest.removeListener('close', onclose);
	    dest.removeListener('finish', onfinish);
	    dest.removeListener('drain', ondrain);
	    dest.removeListener('error', onerror);
	    dest.removeListener('unpipe', onunpipe);
	    src.removeListener('end', onend);
	    src.removeListener('end', cleanup);
	    src.removeListener('data', ondata);

	    cleanedUp = true;

	    // if the reader is waiting for a drain event from this
	    // specific writer, then it would cause it to never start
	    // flowing again.
	    // So, if this is awaiting a drain, then we just call it now.
	    // If we don't know, then assume that we are waiting for one.
	    if (state.awaitDrain && (!dest._writableState || dest._writableState.needDrain)) ondrain();
	  }

	  src.on('data', ondata);
	  function ondata(chunk) {
	    debug('ondata');
	    var ret = dest.write(chunk);
	    if (false === ret) {
	      // If the user unpiped during `dest.write()`, it is possible
	      // to get stuck in a permanently paused state if that write
	      // also returned false.
	      if (state.pipesCount === 1 && state.pipes[0] === dest && src.listenerCount('data') === 1 && !cleanedUp) {
	        debug('false write response, pause', src._readableState.awaitDrain);
	        src._readableState.awaitDrain++;
	      }
	      src.pause();
	    }
	  }

	  // if the dest has an error, then stop piping into it.
	  // however, don't suppress the throwing behavior for this.
	  function onerror(er) {
	    debug('onerror', er);
	    unpipe();
	    dest.removeListener('error', onerror);
	    if (EElistenerCount(dest, 'error') === 0) dest.emit('error', er);
	  }
	  // This is a brutally ugly hack to make sure that our error handler
	  // is attached before any userland ones.  NEVER DO THIS.
	  if (!dest._events || !dest._events.error) dest.on('error', onerror);else if (isArray(dest._events.error)) dest._events.error.unshift(onerror);else dest._events.error = [onerror, dest._events.error];

	  // Both close and finish should trigger unpipe, but only once.
	  function onclose() {
	    dest.removeListener('finish', onfinish);
	    unpipe();
	  }
	  dest.once('close', onclose);
	  function onfinish() {
	    debug('onfinish');
	    dest.removeListener('close', onclose);
	    unpipe();
	  }
	  dest.once('finish', onfinish);

	  function unpipe() {
	    debug('unpipe');
	    src.unpipe(dest);
	  }

	  // tell the dest that it's being piped to
	  dest.emit('pipe', src);

	  // start the flow if it hasn't been started already.
	  if (!state.flowing) {
	    debug('pipe resume');
	    src.resume();
	  }

	  return dest;
	};

	function pipeOnDrain(src) {
	  return function () {
	    var state = src._readableState;
	    debug('pipeOnDrain', state.awaitDrain);
	    if (state.awaitDrain) state.awaitDrain--;
	    if (state.awaitDrain === 0 && EElistenerCount(src, 'data')) {
	      state.flowing = true;
	      flow(src);
	    }
	  };
	}

	Readable.prototype.unpipe = function (dest) {
	  var state = this._readableState;

	  // if we're not piping anywhere, then do nothing.
	  if (state.pipesCount === 0) return this;

	  // just one destination.  most common case.
	  if (state.pipesCount === 1) {
	    // passed in one, but it's not the right one.
	    if (dest && dest !== state.pipes) return this;

	    if (!dest) dest = state.pipes;

	    // got a match.
	    state.pipes = null;
	    state.pipesCount = 0;
	    state.flowing = false;
	    if (dest) dest.emit('unpipe', this);
	    return this;
	  }

	  // slow case. multiple pipe destinations.

	  if (!dest) {
	    // remove all.
	    var dests = state.pipes;
	    var len = state.pipesCount;
	    state.pipes = null;
	    state.pipesCount = 0;
	    state.flowing = false;

	    for (var _i = 0; _i < len; _i++) {
	      dests[_i].emit('unpipe', this);
	    }return this;
	  }

	  // try to find the right one.
	  var i = indexOf(state.pipes, dest);
	  if (i === -1) return this;

	  state.pipes.splice(i, 1);
	  state.pipesCount -= 1;
	  if (state.pipesCount === 1) state.pipes = state.pipes[0];

	  dest.emit('unpipe', this);

	  return this;
	};

	// set up data events if they are asked for
	// Ensure readable listeners eventually get something
	Readable.prototype.on = function (ev, fn) {
	  var res = Stream.prototype.on.call(this, ev, fn);

	  // If listening to data, and it has not explicitly been paused,
	  // then call resume to start the flow of data on the next tick.
	  if (ev === 'data' && false !== this._readableState.flowing) {
	    this.resume();
	  }

	  if (ev === 'readable' && !this._readableState.endEmitted) {
	    var state = this._readableState;
	    if (!state.readableListening) {
	      state.readableListening = true;
	      state.emittedReadable = false;
	      state.needReadable = true;
	      if (!state.reading) {
	        processNextTick(nReadingNextTick, this);
	      } else if (state.length) {
	        emitReadable(this, state);
	      }
	    }
	  }

	  return res;
	};
	Readable.prototype.addListener = Readable.prototype.on;

	function nReadingNextTick(self) {
	  debug('readable nexttick read 0');
	  self.read(0);
	}

	// pause() and resume() are remnants of the legacy readable stream API
	// If the user uses them, then switch into old mode.
	Readable.prototype.resume = function () {
	  var state = this._readableState;
	  if (!state.flowing) {
	    debug('resume');
	    state.flowing = true;
	    resume(this, state);
	  }
	  return this;
	};

	function resume(stream, state) {
	  if (!state.resumeScheduled) {
	    state.resumeScheduled = true;
	    processNextTick(resume_, stream, state);
	  }
	}

	function resume_(stream, state) {
	  if (!state.reading) {
	    debug('resume read 0');
	    stream.read(0);
	  }

	  state.resumeScheduled = false;
	  stream.emit('resume');
	  flow(stream);
	  if (state.flowing && !state.reading) stream.read(0);
	}

	Readable.prototype.pause = function () {
	  debug('call pause flowing=%j', this._readableState.flowing);
	  if (false !== this._readableState.flowing) {
	    debug('pause');
	    this._readableState.flowing = false;
	    this.emit('pause');
	  }
	  return this;
	};

	function flow(stream) {
	  var state = stream._readableState;
	  debug('flow', state.flowing);
	  if (state.flowing) {
	    do {
	      var chunk = stream.read();
	    } while (null !== chunk && state.flowing);
	  }
	}

	// wrap an old-style stream as the async data source.
	// This is *not* part of the readable stream interface.
	// It is an ugly unfortunate mess of history.
	Readable.prototype.wrap = function (stream) {
	  var state = this._readableState;
	  var paused = false;

	  var self = this;
	  stream.on('end', function () {
	    debug('wrapped end');
	    if (state.decoder && !state.ended) {
	      var chunk = state.decoder.end();
	      if (chunk && chunk.length) self.push(chunk);
	    }

	    self.push(null);
	  });

	  stream.on('data', function (chunk) {
	    debug('wrapped data');
	    if (state.decoder) chunk = state.decoder.write(chunk);

	    // don't skip over falsy values in objectMode
	    if (state.objectMode && (chunk === null || chunk === undefined)) return;else if (!state.objectMode && (!chunk || !chunk.length)) return;

	    var ret = self.push(chunk);
	    if (!ret) {
	      paused = true;
	      stream.pause();
	    }
	  });

	  // proxy all the other methods.
	  // important when wrapping filters and duplexes.
	  for (var i in stream) {
	    if (this[i] === undefined && typeof stream[i] === 'function') {
	      this[i] = function (method) {
	        return function () {
	          return stream[method].apply(stream, arguments);
	        };
	      }(i);
	    }
	  }

	  // proxy certain important events.
	  var events = ['error', 'close', 'destroy', 'pause', 'resume'];
	  forEach(events, function (ev) {
	    stream.on(ev, self.emit.bind(self, ev));
	  });

	  // when we try to consume some more bytes, simply unpause the
	  // underlying stream.
	  self._read = function (n) {
	    debug('wrapped _read', n);
	    if (paused) {
	      paused = false;
	      stream.resume();
	    }
	  };

	  return self;
	};

	// exposed for testing purposes only.
	Readable._fromList = fromList;

	// Pluck off n bytes from an array of buffers.
	// Length is the combined lengths of all the buffers in the list.
	function fromList(n, state) {
	  var list = state.buffer;
	  var length = state.length;
	  var stringMode = !!state.decoder;
	  var objectMode = !!state.objectMode;
	  var ret;

	  // nothing in the list, definitely empty.
	  if (list.length === 0) return null;

	  if (length === 0) ret = null;else if (objectMode) ret = list.shift();else if (!n || n >= length) {
	    // read it all, truncate the array.
	    if (stringMode) ret = list.join('');else if (list.length === 1) ret = list[0];else ret = Buffer.concat(list, length);
	    list.length = 0;
	  } else {
	    // read just some of it.
	    if (n < list[0].length) {
	      // just take a part of the first list item.
	      // slice is the same for buffers and strings.
	      var buf = list[0];
	      ret = buf.slice(0, n);
	      list[0] = buf.slice(n);
	    } else if (n === list[0].length) {
	      // first list is a perfect match
	      ret = list.shift();
	    } else {
	      // complex case.
	      // we have enough to cover it, but it spans past the first buffer.
	      if (stringMode) ret = '';else ret = new Buffer(n);

	      var c = 0;
	      for (var i = 0, l = list.length; i < l && c < n; i++) {
	        var buf = list[0];
	        var cpy = Math.min(n - c, buf.length);

	        if (stringMode) ret += buf.slice(0, cpy);else buf.copy(ret, c, 0, cpy);

	        if (cpy < buf.length) list[0] = buf.slice(cpy);else list.shift();

	        c += cpy;
	      }
	    }
	  }

	  return ret;
	}

	function endReadable(stream) {
	  var state = stream._readableState;

	  // If we get here before consuming all the bytes, then that is a
	  // bug in node.  Should never happen.
	  if (state.length > 0) throw new Error('endReadable called on non-empty stream');

	  if (!state.endEmitted) {
	    state.ended = true;
	    processNextTick(endReadableNT, state, stream);
	  }
	}

	function endReadableNT(state, stream) {
	  // Check that we didn't get one last unshift.
	  if (!state.endEmitted && state.length === 0) {
	    state.endEmitted = true;
	    stream.readable = false;
	    stream.emit('end');
	  }
	}

	function forEach(xs, f) {
	  for (var i = 0, l = xs.length; i < l; i++) {
	    f(xs[i], i);
	  }
	}

	function indexOf(xs, x) {
	  for (var i = 0, l = xs.length; i < l; i++) {
	    if (xs[i] === x) return i;
	  }
	  return -1;
	}
	/* WEBPACK VAR INJECTION */}.call(exports, __webpack_require__(56)))

/***/ },
/* 142 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(process) {// A bit simpler than readable streams.
	// Implement an async ._write(chunk, encoding, cb), and it'll handle all
	// the drain event emission and buffering.

	'use strict';

	module.exports = Writable;

	/*<replacement>*/
	var processNextTick = __webpack_require__(193);
	/*</replacement>*/

	/*<replacement>*/
	var asyncWrite = !process.browser && ['v0.10', 'v0.9.'].indexOf(process.version.slice(0, 5)) > -1 ? setImmediate : processNextTick;
	/*</replacement>*/

	/*<replacement>*/
	var Buffer = __webpack_require__(87).Buffer;
	/*</replacement>*/

	Writable.WritableState = WritableState;

	/*<replacement>*/
	var util = __webpack_require__(215);
	util.inherits = __webpack_require__(102);
	/*</replacement>*/

	/*<replacement>*/
	var internalUtil = {
	  deprecate: __webpack_require__(201)
	};
	/*</replacement>*/

	/*<replacement>*/
	var Stream;
	(function () {
	  try {
	    Stream = __webpack_require__(165);
	  } catch (_) {} finally {
	    if (!Stream) Stream = __webpack_require__(194).EventEmitter;
	  }
	})();
	/*</replacement>*/

	var Buffer = __webpack_require__(87).Buffer;

	util.inherits(Writable, Stream);

	function nop() {}

	function WriteReq(chunk, encoding, cb) {
	  this.chunk = chunk;
	  this.encoding = encoding;
	  this.callback = cb;
	  this.next = null;
	}

	var Duplex;
	function WritableState(options, stream) {
	  Duplex = Duplex || __webpack_require__(143);

	  options = options || {};

	  // object stream flag to indicate whether or not this stream
	  // contains buffers or objects.
	  this.objectMode = !!options.objectMode;

	  if (stream instanceof Duplex) this.objectMode = this.objectMode || !!options.writableObjectMode;

	  // the point at which write() starts returning false
	  // Note: 0 is a valid value, means that we always return false if
	  // the entire buffer is not flushed immediately on write()
	  var hwm = options.highWaterMark;
	  var defaultHwm = this.objectMode ? 16 : 16 * 1024;
	  this.highWaterMark = hwm || hwm === 0 ? hwm : defaultHwm;

	  // cast to ints.
	  this.highWaterMark = ~ ~this.highWaterMark;

	  this.needDrain = false;
	  // at the start of calling end()
	  this.ending = false;
	  // when end() has been called, and returned
	  this.ended = false;
	  // when 'finish' is emitted
	  this.finished = false;

	  // should we decode strings into buffers before passing to _write?
	  // this is here so that some node-core streams can optimize string
	  // handling at a lower level.
	  var noDecode = options.decodeStrings === false;
	  this.decodeStrings = !noDecode;

	  // Crypto is kind of old and crusty.  Historically, its default string
	  // encoding is 'binary' so we have to make this configurable.
	  // Everything else in the universe uses 'utf8', though.
	  this.defaultEncoding = options.defaultEncoding || 'utf8';

	  // not an actual buffer we keep track of, but a measurement
	  // of how much we're waiting to get pushed to some underlying
	  // socket or file.
	  this.length = 0;

	  // a flag to see when we're in the middle of a write.
	  this.writing = false;

	  // when true all writes will be buffered until .uncork() call
	  this.corked = 0;

	  // a flag to be able to tell if the onwrite cb is called immediately,
	  // or on a later tick.  We set this to true at first, because any
	  // actions that shouldn't happen until "later" should generally also
	  // not happen before the first write call.
	  this.sync = true;

	  // a flag to know if we're processing previously buffered items, which
	  // may call the _write() callback in the same tick, so that we don't
	  // end up in an overlapped onwrite situation.
	  this.bufferProcessing = false;

	  // the callback that's passed to _write(chunk,cb)
	  this.onwrite = function (er) {
	    onwrite(stream, er);
	  };

	  // the callback that the user supplies to write(chunk,encoding,cb)
	  this.writecb = null;

	  // the amount that is being written when _write is called.
	  this.writelen = 0;

	  this.bufferedRequest = null;
	  this.lastBufferedRequest = null;

	  // number of pending user-supplied write callbacks
	  // this must be 0 before 'finish' can be emitted
	  this.pendingcb = 0;

	  // emit prefinish if the only thing we're waiting for is _write cbs
	  // This is relevant for synchronous Transform streams
	  this.prefinished = false;

	  // True if the error was already emitted and should not be thrown again
	  this.errorEmitted = false;

	  // count buffered requests
	  this.bufferedRequestCount = 0;

	  // create the two objects needed to store the corked requests
	  // they are not a linked list, as no new elements are inserted in there
	  this.corkedRequestsFree = new CorkedRequest(this);
	  this.corkedRequestsFree.next = new CorkedRequest(this);
	}

	WritableState.prototype.getBuffer = function writableStateGetBuffer() {
	  var current = this.bufferedRequest;
	  var out = [];
	  while (current) {
	    out.push(current);
	    current = current.next;
	  }
	  return out;
	};

	(function () {
	  try {
	    Object.defineProperty(WritableState.prototype, 'buffer', {
	      get: internalUtil.deprecate(function () {
	        return this.getBuffer();
	      }, '_writableState.buffer is deprecated. Use _writableState.getBuffer ' + 'instead.')
	    });
	  } catch (_) {}
	})();

	var Duplex;
	function Writable(options) {
	  Duplex = Duplex || __webpack_require__(143);

	  // Writable ctor is applied to Duplexes, though they're not
	  // instanceof Writable, they're instanceof Readable.
	  if (!(this instanceof Writable) && !(this instanceof Duplex)) return new Writable(options);

	  this._writableState = new WritableState(options, this);

	  // legacy.
	  this.writable = true;

	  if (options) {
	    if (typeof options.write === 'function') this._write = options.write;

	    if (typeof options.writev === 'function') this._writev = options.writev;
	  }

	  Stream.call(this);
	}

	// Otherwise people can pipe Writable streams, which is just wrong.
	Writable.prototype.pipe = function () {
	  this.emit('error', new Error('Cannot pipe. Not readable.'));
	};

	function writeAfterEnd(stream, cb) {
	  var er = new Error('write after end');
	  // TODO: defer error events consistently everywhere, not just the cb
	  stream.emit('error', er);
	  processNextTick(cb, er);
	}

	// If we get something that is not a buffer, string, null, or undefined,
	// and we're not in objectMode, then that's an error.
	// Otherwise stream chunks are all considered to be of length=1, and the
	// watermarks determine how many objects to keep in the buffer, rather than
	// how many bytes or characters.
	function validChunk(stream, state, chunk, cb) {
	  var valid = true;

	  if (!Buffer.isBuffer(chunk) && typeof chunk !== 'string' && chunk !== null && chunk !== undefined && !state.objectMode) {
	    var er = new TypeError('Invalid non-string/buffer chunk');
	    stream.emit('error', er);
	    processNextTick(cb, er);
	    valid = false;
	  }
	  return valid;
	}

	Writable.prototype.write = function (chunk, encoding, cb) {
	  var state = this._writableState;
	  var ret = false;

	  if (typeof encoding === 'function') {
	    cb = encoding;
	    encoding = null;
	  }

	  if (Buffer.isBuffer(chunk)) encoding = 'buffer';else if (!encoding) encoding = state.defaultEncoding;

	  if (typeof cb !== 'function') cb = nop;

	  if (state.ended) writeAfterEnd(this, cb);else if (validChunk(this, state, chunk, cb)) {
	    state.pendingcb++;
	    ret = writeOrBuffer(this, state, chunk, encoding, cb);
	  }

	  return ret;
	};

	Writable.prototype.cork = function () {
	  var state = this._writableState;

	  state.corked++;
	};

	Writable.prototype.uncork = function () {
	  var state = this._writableState;

	  if (state.corked) {
	    state.corked--;

	    if (!state.writing && !state.corked && !state.finished && !state.bufferProcessing && state.bufferedRequest) clearBuffer(this, state);
	  }
	};

	Writable.prototype.setDefaultEncoding = function setDefaultEncoding(encoding) {
	  // node::ParseEncoding() requires lower case.
	  if (typeof encoding === 'string') encoding = encoding.toLowerCase();
	  if (!(['hex', 'utf8', 'utf-8', 'ascii', 'binary', 'base64', 'ucs2', 'ucs-2', 'utf16le', 'utf-16le', 'raw'].indexOf((encoding + '').toLowerCase()) > -1)) throw new TypeError('Unknown encoding: ' + encoding);
	  this._writableState.defaultEncoding = encoding;
	};

	function decodeChunk(state, chunk, encoding) {
	  if (!state.objectMode && state.decodeStrings !== false && typeof chunk === 'string') {
	    chunk = new Buffer(chunk, encoding);
	  }
	  return chunk;
	}

	// if we're already writing something, then just put this
	// in the queue, and wait our turn.  Otherwise, call _write
	// If we return false, then we need a drain event, so set that flag.
	function writeOrBuffer(stream, state, chunk, encoding, cb) {
	  chunk = decodeChunk(state, chunk, encoding);

	  if (Buffer.isBuffer(chunk)) encoding = 'buffer';
	  var len = state.objectMode ? 1 : chunk.length;

	  state.length += len;

	  var ret = state.length < state.highWaterMark;
	  // we must ensure that previous needDrain will not be reset to false.
	  if (!ret) state.needDrain = true;

	  if (state.writing || state.corked) {
	    var last = state.lastBufferedRequest;
	    state.lastBufferedRequest = new WriteReq(chunk, encoding, cb);
	    if (last) {
	      last.next = state.lastBufferedRequest;
	    } else {
	      state.bufferedRequest = state.lastBufferedRequest;
	    }
	    state.bufferedRequestCount += 1;
	  } else {
	    doWrite(stream, state, false, len, chunk, encoding, cb);
	  }

	  return ret;
	}

	function doWrite(stream, state, writev, len, chunk, encoding, cb) {
	  state.writelen = len;
	  state.writecb = cb;
	  state.writing = true;
	  state.sync = true;
	  if (writev) stream._writev(chunk, state.onwrite);else stream._write(chunk, encoding, state.onwrite);
	  state.sync = false;
	}

	function onwriteError(stream, state, sync, er, cb) {
	  --state.pendingcb;
	  if (sync) processNextTick(cb, er);else cb(er);

	  stream._writableState.errorEmitted = true;
	  stream.emit('error', er);
	}

	function onwriteStateUpdate(state) {
	  state.writing = false;
	  state.writecb = null;
	  state.length -= state.writelen;
	  state.writelen = 0;
	}

	function onwrite(stream, er) {
	  var state = stream._writableState;
	  var sync = state.sync;
	  var cb = state.writecb;

	  onwriteStateUpdate(state);

	  if (er) onwriteError(stream, state, sync, er, cb);else {
	    // Check if we're actually ready to finish, but don't emit yet
	    var finished = needFinish(state);

	    if (!finished && !state.corked && !state.bufferProcessing && state.bufferedRequest) {
	      clearBuffer(stream, state);
	    }

	    if (sync) {
	      /*<replacement>*/
	      asyncWrite(afterWrite, stream, state, finished, cb);
	      /*</replacement>*/
	    } else {
	        afterWrite(stream, state, finished, cb);
	      }
	  }
	}

	function afterWrite(stream, state, finished, cb) {
	  if (!finished) onwriteDrain(stream, state);
	  state.pendingcb--;
	  cb();
	  finishMaybe(stream, state);
	}

	// Must force callback to be called on nextTick, so that we don't
	// emit 'drain' before the write() consumer gets the 'false' return
	// value, and has a chance to attach a 'drain' listener.
	function onwriteDrain(stream, state) {
	  if (state.length === 0 && state.needDrain) {
	    state.needDrain = false;
	    stream.emit('drain');
	  }
	}

	// if there's something in the buffer waiting, then process it
	function clearBuffer(stream, state) {
	  state.bufferProcessing = true;
	  var entry = state.bufferedRequest;

	  if (stream._writev && entry && entry.next) {
	    // Fast case, write everything using _writev()
	    var l = state.bufferedRequestCount;
	    var buffer = new Array(l);
	    var holder = state.corkedRequestsFree;
	    holder.entry = entry;

	    var count = 0;
	    while (entry) {
	      buffer[count] = entry;
	      entry = entry.next;
	      count += 1;
	    }

	    doWrite(stream, state, true, state.length, buffer, '', holder.finish);

	    // doWrite is always async, defer these to save a bit of time
	    // as the hot path ends with doWrite
	    state.pendingcb++;
	    state.lastBufferedRequest = null;
	    state.corkedRequestsFree = holder.next;
	    holder.next = null;
	  } else {
	    // Slow case, write chunks one-by-one
	    while (entry) {
	      var chunk = entry.chunk;
	      var encoding = entry.encoding;
	      var cb = entry.callback;
	      var len = state.objectMode ? 1 : chunk.length;

	      doWrite(stream, state, false, len, chunk, encoding, cb);
	      entry = entry.next;
	      // if we didn't call the onwrite immediately, then
	      // it means that we need to wait until it does.
	      // also, that means that the chunk and cb are currently
	      // being processed, so move the buffer counter past them.
	      if (state.writing) {
	        break;
	      }
	    }

	    if (entry === null) state.lastBufferedRequest = null;
	  }

	  state.bufferedRequestCount = 0;
	  state.bufferedRequest = entry;
	  state.bufferProcessing = false;
	}

	Writable.prototype._write = function (chunk, encoding, cb) {
	  cb(new Error('not implemented'));
	};

	Writable.prototype._writev = null;

	Writable.prototype.end = function (chunk, encoding, cb) {
	  var state = this._writableState;

	  if (typeof chunk === 'function') {
	    cb = chunk;
	    chunk = null;
	    encoding = null;
	  } else if (typeof encoding === 'function') {
	    cb = encoding;
	    encoding = null;
	  }

	  if (chunk !== null && chunk !== undefined) this.write(chunk, encoding);

	  // .end() fully uncorks
	  if (state.corked) {
	    state.corked = 1;
	    this.uncork();
	  }

	  // ignore unnecessary end() calls.
	  if (!state.ending && !state.finished) endWritable(this, state, cb);
	};

	function needFinish(state) {
	  return state.ending && state.length === 0 && state.bufferedRequest === null && !state.finished && !state.writing;
	}

	function prefinish(stream, state) {
	  if (!state.prefinished) {
	    state.prefinished = true;
	    stream.emit('prefinish');
	  }
	}

	function finishMaybe(stream, state) {
	  var need = needFinish(state);
	  if (need) {
	    if (state.pendingcb === 0) {
	      prefinish(stream, state);
	      state.finished = true;
	      stream.emit('finish');
	    } else {
	      prefinish(stream, state);
	    }
	  }
	  return need;
	}

	function endWritable(stream, state, cb) {
	  state.ending = true;
	  finishMaybe(stream, state);
	  if (cb) {
	    if (state.finished) processNextTick(cb);else stream.once('finish', cb);
	  }
	  state.ended = true;
	  stream.writable = false;
	}

	// It seems a linked list but it is not
	// there will be only 2 of these for each stream
	function CorkedRequest(state) {
	  var _this = this;

	  this.next = null;
	  this.entry = null;

	  this.finish = function (err) {
	    var entry = _this.entry;
	    _this.entry = null;
	    while (entry) {
	      var cb = entry.callback;
	      state.pendingcb--;
	      cb(err);
	      entry = entry.next;
	    }
	    if (state.corkedRequestsFree) {
	      state.corkedRequestsFree.next = _this;
	    } else {
	      state.corkedRequestsFree = _this;
	    }
	  };
	}
	/* WEBPACK VAR INJECTION */}.call(exports, __webpack_require__(56)))

/***/ },
/* 143 */
/***/ function(module, exports, __webpack_require__) {

	// a duplex stream is just a stream that is both readable and writable.
	// Since JS doesn't have multiple prototypal inheritance, this class
	// prototypally inherits from Readable, and then parasitically from
	// Writable.

	'use strict';

	/*<replacement>*/

	var objectKeys = Object.keys || function (obj) {
	  var keys = [];
	  for (var key in obj) {
	    keys.push(key);
	  }return keys;
	};
	/*</replacement>*/

	module.exports = Duplex;

	/*<replacement>*/
	var processNextTick = __webpack_require__(193);
	/*</replacement>*/

	/*<replacement>*/
	var util = __webpack_require__(215);
	util.inherits = __webpack_require__(102);
	/*</replacement>*/

	var Readable = __webpack_require__(141);
	var Writable = __webpack_require__(142);

	util.inherits(Duplex, Readable);

	var keys = objectKeys(Writable.prototype);
	for (var v = 0; v < keys.length; v++) {
	  var method = keys[v];
	  if (!Duplex.prototype[method]) Duplex.prototype[method] = Writable.prototype[method];
	}

	function Duplex(options) {
	  if (!(this instanceof Duplex)) return new Duplex(options);

	  Readable.call(this, options);
	  Writable.call(this, options);

	  if (options && options.readable === false) this.readable = false;

	  if (options && options.writable === false) this.writable = false;

	  this.allowHalfOpen = true;
	  if (options && options.allowHalfOpen === false) this.allowHalfOpen = false;

	  this.once('end', onend);
	}

	// the no-half-open enforcer
	function onend() {
	  // if we allow half-open state, or if the writable side ended,
	  // then we're ok.
	  if (this.allowHalfOpen || this._writableState.ended) return;

	  // no more data can be written.
	  // But allow more writes to happen in this tick.
	  processNextTick(onEndNT, this);
	}

	function onEndNT(self) {
	  self.end();
	}

	function forEach(xs, f) {
	  for (var i = 0, l = xs.length; i < l; i++) {
	    f(xs[i], i);
	  }
	}

/***/ },
/* 144 */
/***/ function(module, exports, __webpack_require__) {

	// a transform stream is a readable/writable stream where you do
	// something with the data.  Sometimes it's called a "filter",
	// but that's not a great name for it, since that implies a thing where
	// some bits pass through, and others are simply ignored.  (That would
	// be a valid example of a transform, of course.)
	//
	// While the output is causally related to the input, it's not a
	// necessarily symmetric or synchronous transformation.  For example,
	// a zlib stream might take multiple plain-text writes(), and then
	// emit a single compressed chunk some time in the future.
	//
	// Here's how this works:
	//
	// The Transform stream has all the aspects of the readable and writable
	// stream classes.  When you write(chunk), that calls _write(chunk,cb)
	// internally, and returns false if there's a lot of pending writes
	// buffered up.  When you call read(), that calls _read(n) until
	// there's enough pending readable data buffered up.
	//
	// In a transform stream, the written data is placed in a buffer.  When
	// _read(n) is called, it transforms the queued up data, calling the
	// buffered _write cb's as it consumes chunks.  If consuming a single
	// written chunk would result in multiple output chunks, then the first
	// outputted bit calls the readcb, and subsequent chunks just go into
	// the read buffer, and will cause it to emit 'readable' if necessary.
	//
	// This way, back-pressure is actually determined by the reading side,
	// since _read has to be called to start processing a new chunk.  However,
	// a pathological inflate type of transform can cause excessive buffering
	// here.  For example, imagine a stream where every byte of input is
	// interpreted as an integer from 0-255, and then results in that many
	// bytes of output.  Writing the 4 bytes {ff,ff,ff,ff} would result in
	// 1kb of data being output.  In this case, you could write a very small
	// amount of input, and end up with a very large amount of output.  In
	// such a pathological inflating mechanism, there'd be no way to tell
	// the system to stop doing the transform.  A single 4MB write could
	// cause the system to run out of memory.
	//
	// However, even in such a pathological case, only a single written chunk
	// would be consumed, and then the rest would wait (un-transformed) until
	// the results of the previous transformed chunk were consumed.

	'use strict';

	module.exports = Transform;

	var Duplex = __webpack_require__(143);

	/*<replacement>*/
	var util = __webpack_require__(215);
	util.inherits = __webpack_require__(102);
	/*</replacement>*/

	util.inherits(Transform, Duplex);

	function TransformState(stream) {
	  this.afterTransform = function (er, data) {
	    return afterTransform(stream, er, data);
	  };

	  this.needTransform = false;
	  this.transforming = false;
	  this.writecb = null;
	  this.writechunk = null;
	  this.writeencoding = null;
	}

	function afterTransform(stream, er, data) {
	  var ts = stream._transformState;
	  ts.transforming = false;

	  var cb = ts.writecb;

	  if (!cb) return stream.emit('error', new Error('no writecb in Transform class'));

	  ts.writechunk = null;
	  ts.writecb = null;

	  if (data !== null && data !== undefined) stream.push(data);

	  cb(er);

	  var rs = stream._readableState;
	  rs.reading = false;
	  if (rs.needReadable || rs.length < rs.highWaterMark) {
	    stream._read(rs.highWaterMark);
	  }
	}

	function Transform(options) {
	  if (!(this instanceof Transform)) return new Transform(options);

	  Duplex.call(this, options);

	  this._transformState = new TransformState(this);

	  // when the writable side finishes, then flush out anything remaining.
	  var stream = this;

	  // start out asking for a readable event once data is transformed.
	  this._readableState.needReadable = true;

	  // we have implemented the _read method, and done the other things
	  // that Readable wants before the first _read call, so unset the
	  // sync guard flag.
	  this._readableState.sync = false;

	  if (options) {
	    if (typeof options.transform === 'function') this._transform = options.transform;

	    if (typeof options.flush === 'function') this._flush = options.flush;
	  }

	  this.once('prefinish', function () {
	    if (typeof this._flush === 'function') this._flush(function (er) {
	      done(stream, er);
	    });else done(stream);
	  });
	}

	Transform.prototype.push = function (chunk, encoding) {
	  this._transformState.needTransform = false;
	  return Duplex.prototype.push.call(this, chunk, encoding);
	};

	// This is the part where you do stuff!
	// override this function in implementation classes.
	// 'chunk' is an input chunk.
	//
	// Call `push(newChunk)` to pass along transformed output
	// to the readable side.  You may call 'push' zero or more times.
	//
	// Call `cb(err)` when you are done with this chunk.  If you pass
	// an error, then that'll put the hurt on the whole operation.  If you
	// never call cb(), then you'll never get another chunk.
	Transform.prototype._transform = function (chunk, encoding, cb) {
	  throw new Error('not implemented');
	};

	Transform.prototype._write = function (chunk, encoding, cb) {
	  var ts = this._transformState;
	  ts.writecb = cb;
	  ts.writechunk = chunk;
	  ts.writeencoding = encoding;
	  if (!ts.transforming) {
	    var rs = this._readableState;
	    if (ts.needTransform || rs.needReadable || rs.length < rs.highWaterMark) this._read(rs.highWaterMark);
	  }
	};

	// Doesn't matter what the args are here.
	// _transform does all the work.
	// That we got here means that the readable side wants more data.
	Transform.prototype._read = function (n) {
	  var ts = this._transformState;

	  if (ts.writechunk !== null && ts.writecb && !ts.transforming) {
	    ts.transforming = true;
	    this._transform(ts.writechunk, ts.writeencoding, ts.afterTransform);
	  } else {
	    // mark that we need a transform, so that any data that comes in
	    // will get processed, now that we've asked for it.
	    ts.needTransform = true;
	  }
	};

	function done(stream, er) {
	  if (er) return stream.emit('error', er);

	  // if there's nothing in the write buffer, then that means
	  // that nothing more will ever be provided
	  var ws = stream._writableState;
	  var ts = stream._transformState;

	  if (ws.length) throw new Error('calling transform done when ws.length != 0');

	  if (ts.transforming) throw new Error('calling transform done when still transforming');

	  return stream.push(null);
	}

/***/ },
/* 145 */
/***/ function(module, exports, __webpack_require__) {

	// a passthrough stream.
	// basically just the most minimal sort of Transform stream.
	// Every written chunk gets output as-is.

	'use strict';

	module.exports = PassThrough;

	var Transform = __webpack_require__(144);

	/*<replacement>*/
	var util = __webpack_require__(215);
	util.inherits = __webpack_require__(102);
	/*</replacement>*/

	util.inherits(PassThrough, Transform);

	function PassThrough(options) {
	  if (!(this instanceof PassThrough)) return new PassThrough(options);

	  Transform.call(this, options);
	}

	PassThrough.prototype._transform = function (chunk, encoding, cb) {
	  cb(null, chunk);
	};

/***/ },
/* 146 */
/***/ function(module, exports, __webpack_require__) {

	var at, // The index of the current character
	    ch, // The current character
	    escapee = {
	        '"':  '"',
	        '\\': '\\',
	        '/':  '/',
	        b:    '\b',
	        f:    '\f',
	        n:    '\n',
	        r:    '\r',
	        t:    '\t'
	    },
	    text,

	    error = function (m) {
	        // Call error when something is wrong.
	        throw {
	            name:    'SyntaxError',
	            message: m,
	            at:      at,
	            text:    text
	        };
	    },
	    
	    next = function (c) {
	        // If a c parameter is provided, verify that it matches the current character.
	        if (c && c !== ch) {
	            error("Expected '" + c + "' instead of '" + ch + "'");
	        }
	        
	        // Get the next character. When there are no more characters,
	        // return the empty string.
	        
	        ch = text.charAt(at);
	        at += 1;
	        return ch;
	    },
	    
	    number = function () {
	        // Parse a number value.
	        var number,
	            string = '';
	        
	        if (ch === '-') {
	            string = '-';
	            next('-');
	        }
	        while (ch >= '0' && ch <= '9') {
	            string += ch;
	            next();
	        }
	        if (ch === '.') {
	            string += '.';
	            while (next() && ch >= '0' && ch <= '9') {
	                string += ch;
	            }
	        }
	        if (ch === 'e' || ch === 'E') {
	            string += ch;
	            next();
	            if (ch === '-' || ch === '+') {
	                string += ch;
	                next();
	            }
	            while (ch >= '0' && ch <= '9') {
	                string += ch;
	                next();
	            }
	        }
	        number = +string;
	        if (!isFinite(number)) {
	            error("Bad number");
	        } else {
	            return number;
	        }
	    },
	    
	    string = function () {
	        // Parse a string value.
	        var hex,
	            i,
	            string = '',
	            uffff;
	        
	        // When parsing for string values, we must look for " and \ characters.
	        if (ch === '"') {
	            while (next()) {
	                if (ch === '"') {
	                    next();
	                    return string;
	                } else if (ch === '\\') {
	                    next();
	                    if (ch === 'u') {
	                        uffff = 0;
	                        for (i = 0; i < 4; i += 1) {
	                            hex = parseInt(next(), 16);
	                            if (!isFinite(hex)) {
	                                break;
	                            }
	                            uffff = uffff * 16 + hex;
	                        }
	                        string += String.fromCharCode(uffff);
	                    } else if (typeof escapee[ch] === 'string') {
	                        string += escapee[ch];
	                    } else {
	                        break;
	                    }
	                } else {
	                    string += ch;
	                }
	            }
	        }
	        error("Bad string");
	    },

	    white = function () {

	// Skip whitespace.

	        while (ch && ch <= ' ') {
	            next();
	        }
	    },

	    word = function () {

	// true, false, or null.

	        switch (ch) {
	        case 't':
	            next('t');
	            next('r');
	            next('u');
	            next('e');
	            return true;
	        case 'f':
	            next('f');
	            next('a');
	            next('l');
	            next('s');
	            next('e');
	            return false;
	        case 'n':
	            next('n');
	            next('u');
	            next('l');
	            next('l');
	            return null;
	        }
	        error("Unexpected '" + ch + "'");
	    },

	    value,  // Place holder for the value function.

	    array = function () {

	// Parse an array value.

	        var array = [];

	        if (ch === '[') {
	            next('[');
	            white();
	            if (ch === ']') {
	                next(']');
	                return array;   // empty array
	            }
	            while (ch) {
	                array.push(value());
	                white();
	                if (ch === ']') {
	                    next(']');
	                    return array;
	                }
	                next(',');
	                white();
	            }
	        }
	        error("Bad array");
	    },

	    object = function () {

	// Parse an object value.

	        var key,
	            object = {};

	        if (ch === '{') {
	            next('{');
	            white();
	            if (ch === '}') {
	                next('}');
	                return object;   // empty object
	            }
	            while (ch) {
	                key = string();
	                white();
	                next(':');
	                if (Object.hasOwnProperty.call(object, key)) {
	                    error('Duplicate key "' + key + '"');
	                }
	                object[key] = value();
	                white();
	                if (ch === '}') {
	                    next('}');
	                    return object;
	                }
	                next(',');
	                white();
	            }
	        }
	        error("Bad object");
	    };

	value = function () {

	// Parse a JSON value. It could be an object, an array, a string, a number,
	// or a word.

	    white();
	    switch (ch) {
	    case '{':
	        return object();
	    case '[':
	        return array();
	    case '"':
	        return string();
	    case '-':
	        return number();
	    default:
	        return ch >= '0' && ch <= '9' ? number() : word();
	    }
	};

	// Return the json_parse function. It will have access to all of the above
	// functions and variables.

	module.exports = function (source, reviver) {
	    var result;
	    
	    text = source;
	    at = 0;
	    ch = ' ';
	    result = value();
	    white();
	    if (ch) {
	        error("Syntax error");
	    }

	    // If there is a reviver function, we recursively walk the new structure,
	    // passing each name/value pair to the reviver function for possible
	    // transformation, starting with a temporary root object that holds the result
	    // in an empty key. If there is not a reviver function, we simply return the
	    // result.

	    return typeof reviver === 'function' ? (function walk(holder, key) {
	        var k, v, value = holder[key];
	        if (value && typeof value === 'object') {
	            for (k in value) {
	                if (Object.prototype.hasOwnProperty.call(value, k)) {
	                    v = walk(value, k);
	                    if (v !== undefined) {
	                        value[k] = v;
	                    } else {
	                        delete value[k];
	                    }
	                }
	            }
	        }
	        return reviver.call(holder, key, value);
	    }({'': result}, '')) : result;
	};


/***/ },
/* 147 */
/***/ function(module, exports, __webpack_require__) {

	var cx = /[\u0000\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,
	    escapable = /[\\\"\x00-\x1f\x7f-\x9f\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g,
	    gap,
	    indent,
	    meta = {    // table of character substitutions
	        '\b': '\\b',
	        '\t': '\\t',
	        '\n': '\\n',
	        '\f': '\\f',
	        '\r': '\\r',
	        '"' : '\\"',
	        '\\': '\\\\'
	    },
	    rep;

	function quote(string) {
	    // If the string contains no control characters, no quote characters, and no
	    // backslash characters, then we can safely slap some quotes around it.
	    // Otherwise we must also replace the offending characters with safe escape
	    // sequences.
	    
	    escapable.lastIndex = 0;
	    return escapable.test(string) ? '"' + string.replace(escapable, function (a) {
	        var c = meta[a];
	        return typeof c === 'string' ? c :
	            '\\u' + ('0000' + a.charCodeAt(0).toString(16)).slice(-4);
	    }) + '"' : '"' + string + '"';
	}

	function str(key, holder) {
	    // Produce a string from holder[key].
	    var i,          // The loop counter.
	        k,          // The member key.
	        v,          // The member value.
	        length,
	        mind = gap,
	        partial,
	        value = holder[key];
	    
	    // If the value has a toJSON method, call it to obtain a replacement value.
	    if (value && typeof value === 'object' &&
	            typeof value.toJSON === 'function') {
	        value = value.toJSON(key);
	    }
	    
	    // If we were called with a replacer function, then call the replacer to
	    // obtain a replacement value.
	    if (typeof rep === 'function') {
	        value = rep.call(holder, key, value);
	    }
	    
	    // What happens next depends on the value's type.
	    switch (typeof value) {
	        case 'string':
	            return quote(value);
	        
	        case 'number':
	            // JSON numbers must be finite. Encode non-finite numbers as null.
	            return isFinite(value) ? String(value) : 'null';
	        
	        case 'boolean':
	        case 'null':
	            // If the value is a boolean or null, convert it to a string. Note:
	            // typeof null does not produce 'null'. The case is included here in
	            // the remote chance that this gets fixed someday.
	            return String(value);
	            
	        case 'object':
	            if (!value) return 'null';
	            gap += indent;
	            partial = [];
	            
	            // Array.isArray
	            if (Object.prototype.toString.apply(value) === '[object Array]') {
	                length = value.length;
	                for (i = 0; i < length; i += 1) {
	                    partial[i] = str(i, value) || 'null';
	                }
	                
	                // Join all of the elements together, separated with commas, and
	                // wrap them in brackets.
	                v = partial.length === 0 ? '[]' : gap ?
	                    '[\n' + gap + partial.join(',\n' + gap) + '\n' + mind + ']' :
	                    '[' + partial.join(',') + ']';
	                gap = mind;
	                return v;
	            }
	            
	            // If the replacer is an array, use it to select the members to be
	            // stringified.
	            if (rep && typeof rep === 'object') {
	                length = rep.length;
	                for (i = 0; i < length; i += 1) {
	                    k = rep[i];
	                    if (typeof k === 'string') {
	                        v = str(k, value);
	                        if (v) {
	                            partial.push(quote(k) + (gap ? ': ' : ':') + v);
	                        }
	                    }
	                }
	            }
	            else {
	                // Otherwise, iterate through all of the keys in the object.
	                for (k in value) {
	                    if (Object.prototype.hasOwnProperty.call(value, k)) {
	                        v = str(k, value);
	                        if (v) {
	                            partial.push(quote(k) + (gap ? ': ' : ':') + v);
	                        }
	                    }
	                }
	            }
	            
	        // Join all of the member texts together, separated with commas,
	        // and wrap them in braces.

	        v = partial.length === 0 ? '{}' : gap ?
	            '{\n' + gap + partial.join(',\n' + gap) + '\n' + mind + '}' :
	            '{' + partial.join(',') + '}';
	        gap = mind;
	        return v;
	    }
	}

	module.exports = function (value, replacer, space) {
	    var i;
	    gap = '';
	    indent = '';
	    
	    // If the space parameter is a number, make an indent string containing that
	    // many spaces.
	    if (typeof space === 'number') {
	        for (i = 0; i < space; i += 1) {
	            indent += ' ';
	        }
	    }
	    // If the space parameter is a string, it will be used as the indent string.
	    else if (typeof space === 'string') {
	        indent = space;
	    }

	    // If there is a replacer, it must be a function or an array.
	    // Otherwise, throw an error.
	    rep = replacer;
	    if (replacer && typeof replacer !== 'function'
	    && (typeof replacer !== 'object' || typeof replacer.length !== 'number')) {
	        throw new Error('JSON.stringify');
	    }
	    
	    // Make a fake root object containing our value under the key of ''.
	    // Return the result of stringifying the value.
	    return str('', {'': value});
	};


/***/ },
/* 148 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	module.exports = __webpack_require__(178);
	__webpack_require__(179);
	__webpack_require__(180);
	__webpack_require__(181);
	__webpack_require__(182);
	__webpack_require__(183);


/***/ },
/* 149 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';
	var common = __webpack_require__(106);
	var YAMLException = __webpack_require__(107);
	var Type = __webpack_require__(185);
	function compileList(schema, name, result) {
	    var exclude = [];
	    schema.include.forEach(function (includedSchema) {
	        result = compileList(includedSchema, name, result);
	    });
	    schema[name].forEach(function (currentType) {
	        result.forEach(function (previousType, previousIndex) {
	            if (previousType.tag === currentType.tag) {
	                exclude.push(previousIndex);
	            }
	        });
	        result.push(currentType);
	    });
	    return result.filter(function (type, index) {
	        return -1 === exclude.indexOf(index);
	    });
	}
	function compileMap() {
	    var result = {}, index, length;
	    function collectType(type) {
	        result[type.tag] = type;
	    }
	    for (index = 0, length = arguments.length; index < length; index += 1) {
	        arguments[index].forEach(collectType);
	    }
	    return result;
	}
	var Schema = (function () {
	    function Schema(definition) {
	        this.include = definition.include || [];
	        this.implicit = definition.implicit || [];
	        this.explicit = definition.explicit || [];
	        this.implicit.forEach(function (type) {
	            if (type.loadKind && 'scalar' !== type.loadKind) {
	                throw new YAMLException('There is a non-scalar type in the implicit list of a schema. Implicit resolving of such types is not supported.');
	            }
	        });
	        this.compiledImplicit = compileList(this, 'implicit', []);
	        this.compiledExplicit = compileList(this, 'explicit', []);
	        this.compiledTypeMap = compileMap(this.compiledImplicit, this.compiledExplicit);
	    }
	    Schema.DEFAULT = null;
	    Schema.create = function createSchema() {
	        var schemas, types;
	        switch (arguments.length) {
	            case 1:
	                schemas = Schema.DEFAULT;
	                types = arguments[0];
	                break;
	            case 2:
	                schemas = arguments[0];
	                types = arguments[1];
	                break;
	            default:
	                throw new YAMLException('Wrong number of arguments for Schema.create function');
	        }
	        schemas = common.toArray(schemas);
	        types = common.toArray(types);
	        if (!schemas.every(function (schema) { return schema instanceof Schema; })) {
	            throw new YAMLException('Specified list of super schemas (or a single Schema object) contains a non-Schema object.');
	        }
	        if (!types.every(function (type) { return type instanceof Type; })) {
	            throw new YAMLException('Specified list of YAML types (or a single Type object) contains a non-Type object.');
	        }
	        return new Schema({
	            include: schemas,
	            explicit: types
	        });
	    };
	    return Schema;
	}());
	module.exports = Schema;
	//# sourceMappingURL=schema.js.map

/***/ },
/* 150 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';
	var Schema = __webpack_require__(149);
	module.exports = new Schema({
	    include: [
	        __webpack_require__(186)
	    ]
	});
	//# sourceMappingURL=core.js.map

/***/ },
/* 151 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	var Stringify = __webpack_require__(188);
	var Parse = __webpack_require__(189);

	module.exports = {
	    stringify: Stringify,
	    parse: Parse
	};


/***/ },
/* 152 */
/***/ function(module, exports, __webpack_require__) {

	module.exports = /[^\u0041-\u005A\u0061-\u007A\u00AA\u00B5\u00BA\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u0527\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u08A0\u08A2-\u08AC\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0977\u0979-\u097F\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C33\u0C35-\u0C39\u0C3D\u0C58\u0C59\u0C60\u0C61\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D60\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F4\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191C\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19C1-\u19C7\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2183\u2184\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2E2F\u3005\u3006\u3031-\u3035\u303B\u303C\u3041-\u3096\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FCC\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA697\uA6A0-\uA6E5\uA717-\uA71F\uA722-\uA788\uA78B-\uA78E\uA790-\uA793\uA7A0-\uA7AA\uA7F8-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA80-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uABC0-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC\u0030-\u0039\u00B2\u00B3\u00B9\u00BC-\u00BE\u0660-\u0669\u06F0-\u06F9\u07C0-\u07C9\u0966-\u096F\u09E6-\u09EF\u09F4-\u09F9\u0A66-\u0A6F\u0AE6-\u0AEF\u0B66-\u0B6F\u0B72-\u0B77\u0BE6-\u0BF2\u0C66-\u0C6F\u0C78-\u0C7E\u0CE6-\u0CEF\u0D66-\u0D75\u0E50-\u0E59\u0ED0-\u0ED9\u0F20-\u0F33\u1040-\u1049\u1090-\u1099\u1369-\u137C\u16EE-\u16F0\u17E0-\u17E9\u17F0-\u17F9\u1810-\u1819\u1946-\u194F\u19D0-\u19DA\u1A80-\u1A89\u1A90-\u1A99\u1B50-\u1B59\u1BB0-\u1BB9\u1C40-\u1C49\u1C50-\u1C59\u2070\u2074-\u2079\u2080-\u2089\u2150-\u2182\u2185-\u2189\u2460-\u249B\u24EA-\u24FF\u2776-\u2793\u2CFD\u3007\u3021-\u3029\u3038-\u303A\u3192-\u3195\u3220-\u3229\u3248-\u324F\u3251-\u325F\u3280-\u3289\u32B1-\u32BF\uA620-\uA629\uA6E6-\uA6EF\uA830-\uA835\uA8D0-\uA8D9\uA900-\uA909\uA9D0-\uA9D9\uAA50-\uAA59\uABF0-\uABF9\uFF10-\uFF19]+/g


/***/ },
/* 153 */
/***/ function(module, exports, __webpack_require__) {

	module.exports = /([\u0061-\u007A\u00B5\u00DF-\u00F6\u00F8-\u00FF\u0101\u0103\u0105\u0107\u0109\u010B\u010D\u010F\u0111\u0113\u0115\u0117\u0119\u011B\u011D\u011F\u0121\u0123\u0125\u0127\u0129\u012B\u012D\u012F\u0131\u0133\u0135\u0137\u0138\u013A\u013C\u013E\u0140\u0142\u0144\u0146\u0148\u0149\u014B\u014D\u014F\u0151\u0153\u0155\u0157\u0159\u015B\u015D\u015F\u0161\u0163\u0165\u0167\u0169\u016B\u016D\u016F\u0171\u0173\u0175\u0177\u017A\u017C\u017E-\u0180\u0183\u0185\u0188\u018C\u018D\u0192\u0195\u0199-\u019B\u019E\u01A1\u01A3\u01A5\u01A8\u01AA\u01AB\u01AD\u01B0\u01B4\u01B6\u01B9\u01BA\u01BD-\u01BF\u01C6\u01C9\u01CC\u01CE\u01D0\u01D2\u01D4\u01D6\u01D8\u01DA\u01DC\u01DD\u01DF\u01E1\u01E3\u01E5\u01E7\u01E9\u01EB\u01ED\u01EF\u01F0\u01F3\u01F5\u01F9\u01FB\u01FD\u01FF\u0201\u0203\u0205\u0207\u0209\u020B\u020D\u020F\u0211\u0213\u0215\u0217\u0219\u021B\u021D\u021F\u0221\u0223\u0225\u0227\u0229\u022B\u022D\u022F\u0231\u0233-\u0239\u023C\u023F\u0240\u0242\u0247\u0249\u024B\u024D\u024F-\u0293\u0295-\u02AF\u0371\u0373\u0377\u037B-\u037D\u0390\u03AC-\u03CE\u03D0\u03D1\u03D5-\u03D7\u03D9\u03DB\u03DD\u03DF\u03E1\u03E3\u03E5\u03E7\u03E9\u03EB\u03ED\u03EF-\u03F3\u03F5\u03F8\u03FB\u03FC\u0430-\u045F\u0461\u0463\u0465\u0467\u0469\u046B\u046D\u046F\u0471\u0473\u0475\u0477\u0479\u047B\u047D\u047F\u0481\u048B\u048D\u048F\u0491\u0493\u0495\u0497\u0499\u049B\u049D\u049F\u04A1\u04A3\u04A5\u04A7\u04A9\u04AB\u04AD\u04AF\u04B1\u04B3\u04B5\u04B7\u04B9\u04BB\u04BD\u04BF\u04C2\u04C4\u04C6\u04C8\u04CA\u04CC\u04CE\u04CF\u04D1\u04D3\u04D5\u04D7\u04D9\u04DB\u04DD\u04DF\u04E1\u04E3\u04E5\u04E7\u04E9\u04EB\u04ED\u04EF\u04F1\u04F3\u04F5\u04F7\u04F9\u04FB\u04FD\u04FF\u0501\u0503\u0505\u0507\u0509\u050B\u050D\u050F\u0511\u0513\u0515\u0517\u0519\u051B\u051D\u051F\u0521\u0523\u0525\u0527\u0561-\u0587\u1D00-\u1D2B\u1D6B-\u1D77\u1D79-\u1D9A\u1E01\u1E03\u1E05\u1E07\u1E09\u1E0B\u1E0D\u1E0F\u1E11\u1E13\u1E15\u1E17\u1E19\u1E1B\u1E1D\u1E1F\u1E21\u1E23\u1E25\u1E27\u1E29\u1E2B\u1E2D\u1E2F\u1E31\u1E33\u1E35\u1E37\u1E39\u1E3B\u1E3D\u1E3F\u1E41\u1E43\u1E45\u1E47\u1E49\u1E4B\u1E4D\u1E4F\u1E51\u1E53\u1E55\u1E57\u1E59\u1E5B\u1E5D\u1E5F\u1E61\u1E63\u1E65\u1E67\u1E69\u1E6B\u1E6D\u1E6F\u1E71\u1E73\u1E75\u1E77\u1E79\u1E7B\u1E7D\u1E7F\u1E81\u1E83\u1E85\u1E87\u1E89\u1E8B\u1E8D\u1E8F\u1E91\u1E93\u1E95-\u1E9D\u1E9F\u1EA1\u1EA3\u1EA5\u1EA7\u1EA9\u1EAB\u1EAD\u1EAF\u1EB1\u1EB3\u1EB5\u1EB7\u1EB9\u1EBB\u1EBD\u1EBF\u1EC1\u1EC3\u1EC5\u1EC7\u1EC9\u1ECB\u1ECD\u1ECF\u1ED1\u1ED3\u1ED5\u1ED7\u1ED9\u1EDB\u1EDD\u1EDF\u1EE1\u1EE3\u1EE5\u1EE7\u1EE9\u1EEB\u1EED\u1EEF\u1EF1\u1EF3\u1EF5\u1EF7\u1EF9\u1EFB\u1EFD\u1EFF-\u1F07\u1F10-\u1F15\u1F20-\u1F27\u1F30-\u1F37\u1F40-\u1F45\u1F50-\u1F57\u1F60-\u1F67\u1F70-\u1F7D\u1F80-\u1F87\u1F90-\u1F97\u1FA0-\u1FA7\u1FB0-\u1FB4\u1FB6\u1FB7\u1FBE\u1FC2-\u1FC4\u1FC6\u1FC7\u1FD0-\u1FD3\u1FD6\u1FD7\u1FE0-\u1FE7\u1FF2-\u1FF4\u1FF6\u1FF7\u210A\u210E\u210F\u2113\u212F\u2134\u2139\u213C\u213D\u2146-\u2149\u214E\u2184\u2C30-\u2C5E\u2C61\u2C65\u2C66\u2C68\u2C6A\u2C6C\u2C71\u2C73\u2C74\u2C76-\u2C7B\u2C81\u2C83\u2C85\u2C87\u2C89\u2C8B\u2C8D\u2C8F\u2C91\u2C93\u2C95\u2C97\u2C99\u2C9B\u2C9D\u2C9F\u2CA1\u2CA3\u2CA5\u2CA7\u2CA9\u2CAB\u2CAD\u2CAF\u2CB1\u2CB3\u2CB5\u2CB7\u2CB9\u2CBB\u2CBD\u2CBF\u2CC1\u2CC3\u2CC5\u2CC7\u2CC9\u2CCB\u2CCD\u2CCF\u2CD1\u2CD3\u2CD5\u2CD7\u2CD9\u2CDB\u2CDD\u2CDF\u2CE1\u2CE3\u2CE4\u2CEC\u2CEE\u2CF3\u2D00-\u2D25\u2D27\u2D2D\uA641\uA643\uA645\uA647\uA649\uA64B\uA64D\uA64F\uA651\uA653\uA655\uA657\uA659\uA65B\uA65D\uA65F\uA661\uA663\uA665\uA667\uA669\uA66B\uA66D\uA681\uA683\uA685\uA687\uA689\uA68B\uA68D\uA68F\uA691\uA693\uA695\uA697\uA723\uA725\uA727\uA729\uA72B\uA72D\uA72F-\uA731\uA733\uA735\uA737\uA739\uA73B\uA73D\uA73F\uA741\uA743\uA745\uA747\uA749\uA74B\uA74D\uA74F\uA751\uA753\uA755\uA757\uA759\uA75B\uA75D\uA75F\uA761\uA763\uA765\uA767\uA769\uA76B\uA76D\uA76F\uA771-\uA778\uA77A\uA77C\uA77F\uA781\uA783\uA785\uA787\uA78C\uA78E\uA791\uA793\uA7A1\uA7A3\uA7A5\uA7A7\uA7A9\uA7FA\uFB00-\uFB06\uFB13-\uFB17\uFF41-\uFF5A])([\u0041-\u005A\u00C0-\u00D6\u00D8-\u00DE\u0100\u0102\u0104\u0106\u0108\u010A\u010C\u010E\u0110\u0112\u0114\u0116\u0118\u011A\u011C\u011E\u0120\u0122\u0124\u0126\u0128\u012A\u012C\u012E\u0130\u0132\u0134\u0136\u0139\u013B\u013D\u013F\u0141\u0143\u0145\u0147\u014A\u014C\u014E\u0150\u0152\u0154\u0156\u0158\u015A\u015C\u015E\u0160\u0162\u0164\u0166\u0168\u016A\u016C\u016E\u0170\u0172\u0174\u0176\u0178\u0179\u017B\u017D\u0181\u0182\u0184\u0186\u0187\u0189-\u018B\u018E-\u0191\u0193\u0194\u0196-\u0198\u019C\u019D\u019F\u01A0\u01A2\u01A4\u01A6\u01A7\u01A9\u01AC\u01AE\u01AF\u01B1-\u01B3\u01B5\u01B7\u01B8\u01BC\u01C4\u01C7\u01CA\u01CD\u01CF\u01D1\u01D3\u01D5\u01D7\u01D9\u01DB\u01DE\u01E0\u01E2\u01E4\u01E6\u01E8\u01EA\u01EC\u01EE\u01F1\u01F4\u01F6-\u01F8\u01FA\u01FC\u01FE\u0200\u0202\u0204\u0206\u0208\u020A\u020C\u020E\u0210\u0212\u0214\u0216\u0218\u021A\u021C\u021E\u0220\u0222\u0224\u0226\u0228\u022A\u022C\u022E\u0230\u0232\u023A\u023B\u023D\u023E\u0241\u0243-\u0246\u0248\u024A\u024C\u024E\u0370\u0372\u0376\u0386\u0388-\u038A\u038C\u038E\u038F\u0391-\u03A1\u03A3-\u03AB\u03CF\u03D2-\u03D4\u03D8\u03DA\u03DC\u03DE\u03E0\u03E2\u03E4\u03E6\u03E8\u03EA\u03EC\u03EE\u03F4\u03F7\u03F9\u03FA\u03FD-\u042F\u0460\u0462\u0464\u0466\u0468\u046A\u046C\u046E\u0470\u0472\u0474\u0476\u0478\u047A\u047C\u047E\u0480\u048A\u048C\u048E\u0490\u0492\u0494\u0496\u0498\u049A\u049C\u049E\u04A0\u04A2\u04A4\u04A6\u04A8\u04AA\u04AC\u04AE\u04B0\u04B2\u04B4\u04B6\u04B8\u04BA\u04BC\u04BE\u04C0\u04C1\u04C3\u04C5\u04C7\u04C9\u04CB\u04CD\u04D0\u04D2\u04D4\u04D6\u04D8\u04DA\u04DC\u04DE\u04E0\u04E2\u04E4\u04E6\u04E8\u04EA\u04EC\u04EE\u04F0\u04F2\u04F4\u04F6\u04F8\u04FA\u04FC\u04FE\u0500\u0502\u0504\u0506\u0508\u050A\u050C\u050E\u0510\u0512\u0514\u0516\u0518\u051A\u051C\u051E\u0520\u0522\u0524\u0526\u0531-\u0556\u10A0-\u10C5\u10C7\u10CD\u1E00\u1E02\u1E04\u1E06\u1E08\u1E0A\u1E0C\u1E0E\u1E10\u1E12\u1E14\u1E16\u1E18\u1E1A\u1E1C\u1E1E\u1E20\u1E22\u1E24\u1E26\u1E28\u1E2A\u1E2C\u1E2E\u1E30\u1E32\u1E34\u1E36\u1E38\u1E3A\u1E3C\u1E3E\u1E40\u1E42\u1E44\u1E46\u1E48\u1E4A\u1E4C\u1E4E\u1E50\u1E52\u1E54\u1E56\u1E58\u1E5A\u1E5C\u1E5E\u1E60\u1E62\u1E64\u1E66\u1E68\u1E6A\u1E6C\u1E6E\u1E70\u1E72\u1E74\u1E76\u1E78\u1E7A\u1E7C\u1E7E\u1E80\u1E82\u1E84\u1E86\u1E88\u1E8A\u1E8C\u1E8E\u1E90\u1E92\u1E94\u1E9E\u1EA0\u1EA2\u1EA4\u1EA6\u1EA8\u1EAA\u1EAC\u1EAE\u1EB0\u1EB2\u1EB4\u1EB6\u1EB8\u1EBA\u1EBC\u1EBE\u1EC0\u1EC2\u1EC4\u1EC6\u1EC8\u1ECA\u1ECC\u1ECE\u1ED0\u1ED2\u1ED4\u1ED6\u1ED8\u1EDA\u1EDC\u1EDE\u1EE0\u1EE2\u1EE4\u1EE6\u1EE8\u1EEA\u1EEC\u1EEE\u1EF0\u1EF2\u1EF4\u1EF6\u1EF8\u1EFA\u1EFC\u1EFE\u1F08-\u1F0F\u1F18-\u1F1D\u1F28-\u1F2F\u1F38-\u1F3F\u1F48-\u1F4D\u1F59\u1F5B\u1F5D\u1F5F\u1F68-\u1F6F\u1FB8-\u1FBB\u1FC8-\u1FCB\u1FD8-\u1FDB\u1FE8-\u1FEC\u1FF8-\u1FFB\u2102\u2107\u210B-\u210D\u2110-\u2112\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u2130-\u2133\u213E\u213F\u2145\u2183\u2C00-\u2C2E\u2C60\u2C62-\u2C64\u2C67\u2C69\u2C6B\u2C6D-\u2C70\u2C72\u2C75\u2C7E-\u2C80\u2C82\u2C84\u2C86\u2C88\u2C8A\u2C8C\u2C8E\u2C90\u2C92\u2C94\u2C96\u2C98\u2C9A\u2C9C\u2C9E\u2CA0\u2CA2\u2CA4\u2CA6\u2CA8\u2CAA\u2CAC\u2CAE\u2CB0\u2CB2\u2CB4\u2CB6\u2CB8\u2CBA\u2CBC\u2CBE\u2CC0\u2CC2\u2CC4\u2CC6\u2CC8\u2CCA\u2CCC\u2CCE\u2CD0\u2CD2\u2CD4\u2CD6\u2CD8\u2CDA\u2CDC\u2CDE\u2CE0\u2CE2\u2CEB\u2CED\u2CF2\uA640\uA642\uA644\uA646\uA648\uA64A\uA64C\uA64E\uA650\uA652\uA654\uA656\uA658\uA65A\uA65C\uA65E\uA660\uA662\uA664\uA666\uA668\uA66A\uA66C\uA680\uA682\uA684\uA686\uA688\uA68A\uA68C\uA68E\uA690\uA692\uA694\uA696\uA722\uA724\uA726\uA728\uA72A\uA72C\uA72E\uA732\uA734\uA736\uA738\uA73A\uA73C\uA73E\uA740\uA742\uA744\uA746\uA748\uA74A\uA74C\uA74E\uA750\uA752\uA754\uA756\uA758\uA75A\uA75C\uA75E\uA760\uA762\uA764\uA766\uA768\uA76A\uA76C\uA76E\uA779\uA77B\uA77D\uA77E\uA780\uA782\uA784\uA786\uA78B\uA78D\uA790\uA792\uA7A0\uA7A2\uA7A4\uA7A6\uA7A8\uA7AA\uFF21-\uFF3A\u0030-\u0039\u00B2\u00B3\u00B9\u00BC-\u00BE\u0660-\u0669\u06F0-\u06F9\u07C0-\u07C9\u0966-\u096F\u09E6-\u09EF\u09F4-\u09F9\u0A66-\u0A6F\u0AE6-\u0AEF\u0B66-\u0B6F\u0B72-\u0B77\u0BE6-\u0BF2\u0C66-\u0C6F\u0C78-\u0C7E\u0CE6-\u0CEF\u0D66-\u0D75\u0E50-\u0E59\u0ED0-\u0ED9\u0F20-\u0F33\u1040-\u1049\u1090-\u1099\u1369-\u137C\u16EE-\u16F0\u17E0-\u17E9\u17F0-\u17F9\u1810-\u1819\u1946-\u194F\u19D0-\u19DA\u1A80-\u1A89\u1A90-\u1A99\u1B50-\u1B59\u1BB0-\u1BB9\u1C40-\u1C49\u1C50-\u1C59\u2070\u2074-\u2079\u2080-\u2089\u2150-\u2182\u2185-\u2189\u2460-\u249B\u24EA-\u24FF\u2776-\u2793\u2CFD\u3007\u3021-\u3029\u3038-\u303A\u3192-\u3195\u3220-\u3229\u3248-\u324F\u3251-\u325F\u3280-\u3289\u32B1-\u32BF\uA620-\uA629\uA6E6-\uA6EF\uA830-\uA835\uA8D0-\uA8D9\uA900-\uA909\uA9D0-\uA9D9\uAA50-\uAA59\uABF0-\uABF9\uFF10-\uFF19])/g


/***/ },
/* 154 */
/***/ function(module, exports, __webpack_require__) {

	module.exports = /([\u0030-\u0039\u00B2\u00B3\u00B9\u00BC-\u00BE\u0660-\u0669\u06F0-\u06F9\u07C0-\u07C9\u0966-\u096F\u09E6-\u09EF\u09F4-\u09F9\u0A66-\u0A6F\u0AE6-\u0AEF\u0B66-\u0B6F\u0B72-\u0B77\u0BE6-\u0BF2\u0C66-\u0C6F\u0C78-\u0C7E\u0CE6-\u0CEF\u0D66-\u0D75\u0E50-\u0E59\u0ED0-\u0ED9\u0F20-\u0F33\u1040-\u1049\u1090-\u1099\u1369-\u137C\u16EE-\u16F0\u17E0-\u17E9\u17F0-\u17F9\u1810-\u1819\u1946-\u194F\u19D0-\u19DA\u1A80-\u1A89\u1A90-\u1A99\u1B50-\u1B59\u1BB0-\u1BB9\u1C40-\u1C49\u1C50-\u1C59\u2070\u2074-\u2079\u2080-\u2089\u2150-\u2182\u2185-\u2189\u2460-\u249B\u24EA-\u24FF\u2776-\u2793\u2CFD\u3007\u3021-\u3029\u3038-\u303A\u3192-\u3195\u3220-\u3229\u3248-\u324F\u3251-\u325F\u3280-\u3289\u32B1-\u32BF\uA620-\uA629\uA6E6-\uA6EF\uA830-\uA835\uA8D0-\uA8D9\uA900-\uA909\uA9D0-\uA9D9\uAA50-\uAA59\uABF0-\uABF9\uFF10-\uFF19])([^\u0030-\u0039\u00B2\u00B3\u00B9\u00BC-\u00BE\u0660-\u0669\u06F0-\u06F9\u07C0-\u07C9\u0966-\u096F\u09E6-\u09EF\u09F4-\u09F9\u0A66-\u0A6F\u0AE6-\u0AEF\u0B66-\u0B6F\u0B72-\u0B77\u0BE6-\u0BF2\u0C66-\u0C6F\u0C78-\u0C7E\u0CE6-\u0CEF\u0D66-\u0D75\u0E50-\u0E59\u0ED0-\u0ED9\u0F20-\u0F33\u1040-\u1049\u1090-\u1099\u1369-\u137C\u16EE-\u16F0\u17E0-\u17E9\u17F0-\u17F9\u1810-\u1819\u1946-\u194F\u19D0-\u19DA\u1A80-\u1A89\u1A90-\u1A99\u1B50-\u1B59\u1BB0-\u1BB9\u1C40-\u1C49\u1C50-\u1C59\u2070\u2074-\u2079\u2080-\u2089\u2150-\u2182\u2185-\u2189\u2460-\u249B\u24EA-\u24FF\u2776-\u2793\u2CFD\u3007\u3021-\u3029\u3038-\u303A\u3192-\u3195\u3220-\u3229\u3248-\u324F\u3251-\u325F\u3280-\u3289\u32B1-\u32BF\uA620-\uA629\uA6E6-\uA6EF\uA830-\uA835\uA8D0-\uA8D9\uA900-\uA909\uA9D0-\uA9D9\uAA50-\uAA59\uABF0-\uABF9\uFF10-\uFF19])/g


/***/ },
/* 155 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';
	var Type = __webpack_require__(185);
	var YAML_TIMESTAMP_REGEXP = new RegExp('^([0-9][0-9][0-9][0-9])' +
	    '-([0-9][0-9]?)' +
	    '-([0-9][0-9]?)' +
	    '(?:(?:[Tt]|[ \\t]+)' +
	    '([0-9][0-9]?)' +
	    ':([0-9][0-9])' +
	    ':([0-9][0-9])' +
	    '(?:\\.([0-9]*))?' +
	    '(?:[ \\t]*(Z|([-+])([0-9][0-9]?)' +
	    '(?::([0-9][0-9]))?))?)?$');
	function resolveYamlTimestamp(data) {
	    if (null === data) {
	        return false;
	    }
	    var match, year, month, day, hour, minute, second, fraction = 0, delta = null, tz_hour, tz_minute, date;
	    match = YAML_TIMESTAMP_REGEXP.exec(data);
	    if (null === match) {
	        return false;
	    }
	    return true;
	}
	function constructYamlTimestamp(data) {
	    var match, year, month, day, hour, minute, second, fraction = 0, delta = null, tz_hour, tz_minute, date;
	    match = YAML_TIMESTAMP_REGEXP.exec(data);
	    if (null === match) {
	        throw new Error('Date resolve error');
	    }
	    year = +(match[1]);
	    month = +(match[2]) - 1;
	    day = +(match[3]);
	    if (!match[4]) {
	        return new Date(Date.UTC(year, month, day));
	    }
	    hour = +(match[4]);
	    minute = +(match[5]);
	    second = +(match[6]);
	    if (match[7]) {
	        fraction = match[7].slice(0, 3);
	        while (fraction.length < 3) {
	            fraction = fraction + '0';
	        }
	        fraction = +fraction;
	    }
	    if (match[9]) {
	        tz_hour = +(match[10]);
	        tz_minute = +(match[11] || 0);
	        delta = (tz_hour * 60 + tz_minute) * 60000;
	        if ('-' === match[9]) {
	            delta = -delta;
	        }
	    }
	    date = new Date(Date.UTC(year, month, day, hour, minute, second, fraction));
	    if (delta) {
	        date.setTime(date.getTime() - delta);
	    }
	    return date;
	}
	function representYamlTimestamp(object) {
	    return object.toISOString();
	}
	module.exports = new Type('tag:yaml.org,2002:timestamp', {
	    kind: 'scalar',
	    resolve: resolveYamlTimestamp,
	    construct: constructYamlTimestamp,
	    instanceOf: Date,
	    represent: representYamlTimestamp
	});
	//# sourceMappingURL=timestamp.js.map

/***/ },
/* 156 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';
	var Type = __webpack_require__(185);
	function resolveYamlMerge(data) {
	    return '<<' === data || null === data;
	}
	module.exports = new Type('tag:yaml.org,2002:merge', {
	    kind: 'scalar',
	    resolve: resolveYamlMerge
	});
	//# sourceMappingURL=merge.js.map

/***/ },
/* 157 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';
	var NodeBuffer = __webpack_require__(87).Buffer;
	var Type = __webpack_require__(185);
	var BASE64_MAP = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=\n\r';
	function resolveYamlBinary(data) {
	    if (null === data) {
	        return false;
	    }
	    var code, idx, bitlen = 0, len = 0, max = data.length, map = BASE64_MAP;
	    for (idx = 0; idx < max; idx++) {
	        code = map.indexOf(data.charAt(idx));
	        if (code > 64) {
	            continue;
	        }
	        if (code < 0) {
	            return false;
	        }
	        bitlen += 6;
	    }
	    return (bitlen % 8) === 0;
	}
	function constructYamlBinary(data) {
	    var code, idx, tailbits, input = data.replace(/[\r\n=]/g, ''), max = input.length, map = BASE64_MAP, bits = 0, result = [];
	    for (idx = 0; idx < max; idx++) {
	        if ((idx % 4 === 0) && idx) {
	            result.push((bits >> 16) & 0xFF);
	            result.push((bits >> 8) & 0xFF);
	            result.push(bits & 0xFF);
	        }
	        bits = (bits << 6) | map.indexOf(input.charAt(idx));
	    }
	    tailbits = (max % 4) * 6;
	    if (tailbits === 0) {
	        result.push((bits >> 16) & 0xFF);
	        result.push((bits >> 8) & 0xFF);
	        result.push(bits & 0xFF);
	    }
	    else if (tailbits === 18) {
	        result.push((bits >> 10) & 0xFF);
	        result.push((bits >> 2) & 0xFF);
	    }
	    else if (tailbits === 12) {
	        result.push((bits >> 4) & 0xFF);
	    }
	    if (NodeBuffer) {
	        return new NodeBuffer(result);
	    }
	    return result;
	}
	function representYamlBinary(object) {
	    var result = '', bits = 0, idx, tail, max = object.length, map = BASE64_MAP;
	    for (idx = 0; idx < max; idx++) {
	        if ((idx % 3 === 0) && idx) {
	            result += map[(bits >> 18) & 0x3F];
	            result += map[(bits >> 12) & 0x3F];
	            result += map[(bits >> 6) & 0x3F];
	            result += map[bits & 0x3F];
	        }
	        bits = (bits << 8) + object[idx];
	    }
	    tail = max % 3;
	    if (tail === 0) {
	        result += map[(bits >> 18) & 0x3F];
	        result += map[(bits >> 12) & 0x3F];
	        result += map[(bits >> 6) & 0x3F];
	        result += map[bits & 0x3F];
	    }
	    else if (tail === 2) {
	        result += map[(bits >> 10) & 0x3F];
	        result += map[(bits >> 4) & 0x3F];
	        result += map[(bits << 2) & 0x3F];
	        result += map[64];
	    }
	    else if (tail === 1) {
	        result += map[(bits >> 2) & 0x3F];
	        result += map[(bits << 4) & 0x3F];
	        result += map[64];
	        result += map[64];
	    }
	    return result;
	}
	function isBinary(object) {
	    return NodeBuffer && NodeBuffer.isBuffer(object);
	}
	module.exports = new Type('tag:yaml.org,2002:binary', {
	    kind: 'scalar',
	    resolve: resolveYamlBinary,
	    construct: constructYamlBinary,
	    predicate: isBinary,
	    represent: representYamlBinary
	});
	//# sourceMappingURL=binary.js.map

/***/ },
/* 158 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';
	var Type = __webpack_require__(185);
	var _hasOwnProperty = Object.prototype.hasOwnProperty;
	var _toString = Object.prototype.toString;
	function resolveYamlOmap(data) {
	    if (null === data) {
	        return true;
	    }
	    var objectKeys = [], index, length, pair, pairKey, pairHasKey, object = data;
	    for (index = 0, length = object.length; index < length; index += 1) {
	        pair = object[index];
	        pairHasKey = false;
	        if ('[object Object]' !== _toString.call(pair)) {
	            return false;
	        }
	        for (pairKey in pair) {
	            if (_hasOwnProperty.call(pair, pairKey)) {
	                if (!pairHasKey) {
	                    pairHasKey = true;
	                }
	                else {
	                    return false;
	                }
	            }
	        }
	        if (!pairHasKey) {
	            return false;
	        }
	        if (-1 === objectKeys.indexOf(pairKey)) {
	            objectKeys.push(pairKey);
	        }
	        else {
	            return false;
	        }
	    }
	    return true;
	}
	function constructYamlOmap(data) {
	    return null !== data ? data : [];
	}
	module.exports = new Type('tag:yaml.org,2002:omap', {
	    kind: 'sequence',
	    resolve: resolveYamlOmap,
	    construct: constructYamlOmap
	});
	//# sourceMappingURL=omap.js.map

/***/ },
/* 159 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';
	var Type = __webpack_require__(185);
	var _toString = Object.prototype.toString;
	function resolveYamlPairs(data) {
	    if (null === data) {
	        return true;
	    }
	    var index, length, pair, keys, result, object = data;
	    result = new Array(object.length);
	    for (index = 0, length = object.length; index < length; index += 1) {
	        pair = object[index];
	        if ('[object Object]' !== _toString.call(pair)) {
	            return false;
	        }
	        keys = Object.keys(pair);
	        if (1 !== keys.length) {
	            return false;
	        }
	        result[index] = [keys[0], pair[keys[0]]];
	    }
	    return true;
	}
	function constructYamlPairs(data) {
	    if (null === data) {
	        return [];
	    }
	    var index, length, pair, keys, result, object = data;
	    result = new Array(object.length);
	    for (index = 0, length = object.length; index < length; index += 1) {
	        pair = object[index];
	        keys = Object.keys(pair);
	        result[index] = [keys[0], pair[keys[0]]];
	    }
	    return result;
	}
	module.exports = new Type('tag:yaml.org,2002:pairs', {
	    kind: 'sequence',
	    resolve: resolveYamlPairs,
	    construct: constructYamlPairs
	});
	//# sourceMappingURL=pairs.js.map

/***/ },
/* 160 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';
	var Type = __webpack_require__(185);
	var _hasOwnProperty = Object.prototype.hasOwnProperty;
	function resolveYamlSet(data) {
	    if (null === data) {
	        return true;
	    }
	    var key, object = data;
	    for (key in object) {
	        if (_hasOwnProperty.call(object, key)) {
	            if (null !== object[key]) {
	                return false;
	            }
	        }
	    }
	    return true;
	}
	function constructYamlSet(data) {
	    return null !== data ? data : {};
	}
	module.exports = new Type('tag:yaml.org,2002:set', {
	    kind: 'mapping',
	    resolve: resolveYamlSet,
	    construct: constructYamlSet
	});
	//# sourceMappingURL=set.js.map

/***/ },
/* 161 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';
	var Type = __webpack_require__(185);
	function resolveJavascriptUndefined() {
	    return true;
	}
	function constructJavascriptUndefined() {
	    return undefined;
	}
	function representJavascriptUndefined() {
	    return '';
	}
	function isUndefined(object) {
	    return 'undefined' === typeof object;
	}
	module.exports = new Type('tag:yaml.org,2002:js/undefined', {
	    kind: 'scalar',
	    resolve: resolveJavascriptUndefined,
	    construct: constructJavascriptUndefined,
	    predicate: isUndefined,
	    represent: representJavascriptUndefined
	});
	//# sourceMappingURL=undefined.js.map

/***/ },
/* 162 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';
	var Type = __webpack_require__(185);
	function resolveJavascriptRegExp(data) {
	    if (null === data) {
	        return false;
	    }
	    if (0 === data.length) {
	        return false;
	    }
	    var regexp = data, tail = /\/([gim]*)$/.exec(data), modifiers = '';
	    if ('/' === regexp[0]) {
	        if (tail) {
	            modifiers = tail[1];
	        }
	        if (modifiers.length > 3) {
	            return false;
	        }
	        if (regexp[regexp.length - modifiers.length - 1] !== '/') {
	            return false;
	        }
	        regexp = regexp.slice(1, regexp.length - modifiers.length - 1);
	    }
	    try {
	        var dummy = new RegExp(regexp, modifiers);
	        return true;
	    }
	    catch (error) {
	        return false;
	    }
	}
	function constructJavascriptRegExp(data) {
	    var regexp = data, tail = /\/([gim]*)$/.exec(data), modifiers = '';
	    if ('/' === regexp[0]) {
	        if (tail) {
	            modifiers = tail[1];
	        }
	        regexp = regexp.slice(1, regexp.length - modifiers.length - 1);
	    }
	    return new RegExp(regexp, modifiers);
	}
	function representJavascriptRegExp(object) {
	    var result = '/' + object.source + '/';
	    if (object.global) {
	        result += 'g';
	    }
	    if (object.multiline) {
	        result += 'm';
	    }
	    if (object.ignoreCase) {
	        result += 'i';
	    }
	    return result;
	}
	function isRegExp(object) {
	    return '[object RegExp]' === Object.prototype.toString.call(object);
	}
	module.exports = new Type('tag:yaml.org,2002:js/regexp', {
	    kind: 'scalar',
	    resolve: resolveJavascriptRegExp,
	    construct: constructJavascriptRegExp,
	    predicate: isRegExp,
	    represent: representJavascriptRegExp
	});
	//# sourceMappingURL=regexp.js.map

/***/ },
/* 163 */
/***/ function(module, exports, __webpack_require__) {

	exports.read = function (buffer, offset, isLE, mLen, nBytes) {
	  var e, m
	  var eLen = nBytes * 8 - mLen - 1
	  var eMax = (1 << eLen) - 1
	  var eBias = eMax >> 1
	  var nBits = -7
	  var i = isLE ? (nBytes - 1) : 0
	  var d = isLE ? -1 : 1
	  var s = buffer[offset + i]

	  i += d

	  e = s & ((1 << (-nBits)) - 1)
	  s >>= (-nBits)
	  nBits += eLen
	  for (; nBits > 0; e = e * 256 + buffer[offset + i], i += d, nBits -= 8) {}

	  m = e & ((1 << (-nBits)) - 1)
	  e >>= (-nBits)
	  nBits += mLen
	  for (; nBits > 0; m = m * 256 + buffer[offset + i], i += d, nBits -= 8) {}

	  if (e === 0) {
	    e = 1 - eBias
	  } else if (e === eMax) {
	    return m ? NaN : ((s ? -1 : 1) * Infinity)
	  } else {
	    m = m + Math.pow(2, mLen)
	    e = e - eBias
	  }
	  return (s ? -1 : 1) * m * Math.pow(2, e - mLen)
	}

	exports.write = function (buffer, value, offset, isLE, mLen, nBytes) {
	  var e, m, c
	  var eLen = nBytes * 8 - mLen - 1
	  var eMax = (1 << eLen) - 1
	  var eBias = eMax >> 1
	  var rt = (mLen === 23 ? Math.pow(2, -24) - Math.pow(2, -77) : 0)
	  var i = isLE ? 0 : (nBytes - 1)
	  var d = isLE ? 1 : -1
	  var s = value < 0 || (value === 0 && 1 / value < 0) ? 1 : 0

	  value = Math.abs(value)

	  if (isNaN(value) || value === Infinity) {
	    m = isNaN(value) ? 1 : 0
	    e = eMax
	  } else {
	    e = Math.floor(Math.log(value) / Math.LN2)
	    if (value * (c = Math.pow(2, -e)) < 1) {
	      e--
	      c *= 2
	    }
	    if (e + eBias >= 1) {
	      value += rt / c
	    } else {
	      value += rt * Math.pow(2, 1 - eBias)
	    }
	    if (value * c >= 2) {
	      e++
	      c /= 2
	    }

	    if (e + eBias >= eMax) {
	      m = 0
	      e = eMax
	    } else if (e + eBias >= 1) {
	      m = (value * c - 1) * Math.pow(2, mLen)
	      e = e + eBias
	    } else {
	      m = value * Math.pow(2, eBias - 1) * Math.pow(2, mLen)
	      e = 0
	    }
	  }

	  for (; mLen >= 8; buffer[offset + i] = m & 0xff, i += d, m /= 256, mLen -= 8) {}

	  e = (e << mLen) | m
	  eLen += mLen
	  for (; eLen > 0; buffer[offset + i] = e & 0xff, i += d, e /= 256, eLen -= 8) {}

	  buffer[offset + i - d] |= s * 128
	}


/***/ },
/* 164 */
/***/ function(module, exports, __webpack_require__) {

	var toString = {}.toString;

	module.exports = Array.isArray || function (arr) {
	  return toString.call(arr) == '[object Array]';
	};


/***/ },
/* 165 */
/***/ function(module, exports, __webpack_require__) {

	// Copyright Joyent, Inc. and other Node contributors.
	//
	// Permission is hereby granted, free of charge, to any person obtaining a
	// copy of this software and associated documentation files (the
	// "Software"), to deal in the Software without restriction, including
	// without limitation the rights to use, copy, modify, merge, publish,
	// distribute, sublicense, and/or sell copies of the Software, and to permit
	// persons to whom the Software is furnished to do so, subject to the
	// following conditions:
	//
	// The above copyright notice and this permission notice shall be included
	// in all copies or substantial portions of the Software.
	//
	// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
	// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
	// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
	// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
	// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
	// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
	// USE OR OTHER DEALINGS IN THE SOFTWARE.

	module.exports = Stream;

	var EE = __webpack_require__(194).EventEmitter;
	var inherits = __webpack_require__(223);

	inherits(Stream, EE);
	Stream.Readable = __webpack_require__(217);
	Stream.Writable = __webpack_require__(218);
	Stream.Duplex = __webpack_require__(219);
	Stream.Transform = __webpack_require__(220);
	Stream.PassThrough = __webpack_require__(221);

	// Backwards-compat with node 0.4.x
	Stream.Stream = Stream;



	// old-style streams.  Note that the pipe method (the only relevant
	// part of this class) is overridden in the Readable class.

	function Stream() {
	  EE.call(this);
	}

	Stream.prototype.pipe = function(dest, options) {
	  var source = this;

	  function ondata(chunk) {
	    if (dest.writable) {
	      if (false === dest.write(chunk) && source.pause) {
	        source.pause();
	      }
	    }
	  }

	  source.on('data', ondata);

	  function ondrain() {
	    if (source.readable && source.resume) {
	      source.resume();
	    }
	  }

	  dest.on('drain', ondrain);

	  // If the 'end' option is not supplied, dest.end() will be called when
	  // source gets the 'end' or 'close' events.  Only dest.end() once.
	  if (!dest._isStdio && (!options || options.end !== false)) {
	    source.on('end', onend);
	    source.on('close', onclose);
	  }

	  var didOnEnd = false;
	  function onend() {
	    if (didOnEnd) return;
	    didOnEnd = true;

	    dest.end();
	  }


	  function onclose() {
	    if (didOnEnd) return;
	    didOnEnd = true;

	    if (typeof dest.destroy === 'function') dest.destroy();
	  }

	  // don't leave dangling pipes when there are errors.
	  function onerror(er) {
	    cleanup();
	    if (EE.listenerCount(this, 'error') === 0) {
	      throw er; // Unhandled stream error in pipe.
	    }
	  }

	  source.on('error', onerror);
	  dest.on('error', onerror);

	  // remove all the event listeners that were added.
	  function cleanup() {
	    source.removeListener('data', ondata);
	    dest.removeListener('drain', ondrain);

	    source.removeListener('end', onend);
	    source.removeListener('close', onclose);

	    source.removeListener('error', onerror);
	    dest.removeListener('error', onerror);

	    source.removeListener('end', cleanup);
	    source.removeListener('close', cleanup);

	    dest.removeListener('close', cleanup);
	  }

	  source.on('end', cleanup);
	  source.on('close', cleanup);

	  dest.on('close', cleanup);

	  dest.emit('pipe', source);

	  // Allow for unix-like usage: A.pipe(B).pipe(C)
	  return dest;
	};


/***/ },
/* 166 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(process, __filename, global, __dirname) {/*! *****************************************************************************
	Copyright (c) Microsoft Corporation. All rights reserved. 
	Licensed under the Apache License, Version 2.0 (the "License"); you may not use
	this file except in compliance with the License. You may obtain a copy of the
	License at http://www.apache.org/licenses/LICENSE-2.0  
	 
	THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
	KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
	WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE, 
	MERCHANTABLITY OR NON-INFRINGEMENT. 
	 
	See the Apache Version 2.0 License for specific language governing permissions
	and limitations under the License.
	***************************************************************************** */

	var __extends = (this && this.__extends) || function (d, b) {
	    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
	    function __() { this.constructor = d; }
	    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
	};
	var ts;
	(function (ts) {
	    // token > SyntaxKind.Identifer => token is a keyword
	    // Also, If you add a new SyntaxKind be sure to keep the `Markers` section at the bottom in sync
	    (function (SyntaxKind) {
	        SyntaxKind[SyntaxKind["Unknown"] = 0] = "Unknown";
	        SyntaxKind[SyntaxKind["EndOfFileToken"] = 1] = "EndOfFileToken";
	        SyntaxKind[SyntaxKind["SingleLineCommentTrivia"] = 2] = "SingleLineCommentTrivia";
	        SyntaxKind[SyntaxKind["MultiLineCommentTrivia"] = 3] = "MultiLineCommentTrivia";
	        SyntaxKind[SyntaxKind["NewLineTrivia"] = 4] = "NewLineTrivia";
	        SyntaxKind[SyntaxKind["WhitespaceTrivia"] = 5] = "WhitespaceTrivia";
	        // We detect and preserve #! on the first line
	        SyntaxKind[SyntaxKind["ShebangTrivia"] = 6] = "ShebangTrivia";
	        // We detect and provide better error recovery when we encounter a git merge marker.  This
	        // allows us to edit files with git-conflict markers in them in a much more pleasant manner.
	        SyntaxKind[SyntaxKind["ConflictMarkerTrivia"] = 7] = "ConflictMarkerTrivia";
	        // Literals
	        SyntaxKind[SyntaxKind["NumericLiteral"] = 8] = "NumericLiteral";
	        SyntaxKind[SyntaxKind["StringLiteral"] = 9] = "StringLiteral";
	        SyntaxKind[SyntaxKind["RegularExpressionLiteral"] = 10] = "RegularExpressionLiteral";
	        SyntaxKind[SyntaxKind["NoSubstitutionTemplateLiteral"] = 11] = "NoSubstitutionTemplateLiteral";
	        // Pseudo-literals
	        SyntaxKind[SyntaxKind["TemplateHead"] = 12] = "TemplateHead";
	        SyntaxKind[SyntaxKind["TemplateMiddle"] = 13] = "TemplateMiddle";
	        SyntaxKind[SyntaxKind["TemplateTail"] = 14] = "TemplateTail";
	        // Punctuation
	        SyntaxKind[SyntaxKind["OpenBraceToken"] = 15] = "OpenBraceToken";
	        SyntaxKind[SyntaxKind["CloseBraceToken"] = 16] = "CloseBraceToken";
	        SyntaxKind[SyntaxKind["OpenParenToken"] = 17] = "OpenParenToken";
	        SyntaxKind[SyntaxKind["CloseParenToken"] = 18] = "CloseParenToken";
	        SyntaxKind[SyntaxKind["OpenBracketToken"] = 19] = "OpenBracketToken";
	        SyntaxKind[SyntaxKind["CloseBracketToken"] = 20] = "CloseBracketToken";
	        SyntaxKind[SyntaxKind["DotToken"] = 21] = "DotToken";
	        SyntaxKind[SyntaxKind["DotDotDotToken"] = 22] = "DotDotDotToken";
	        SyntaxKind[SyntaxKind["SemicolonToken"] = 23] = "SemicolonToken";
	        SyntaxKind[SyntaxKind["CommaToken"] = 24] = "CommaToken";
	        SyntaxKind[SyntaxKind["LessThanToken"] = 25] = "LessThanToken";
	        SyntaxKind[SyntaxKind["LessThanSlashToken"] = 26] = "LessThanSlashToken";
	        SyntaxKind[SyntaxKind["GreaterThanToken"] = 27] = "GreaterThanToken";
	        SyntaxKind[SyntaxKind["LessThanEqualsToken"] = 28] = "LessThanEqualsToken";
	        SyntaxKind[SyntaxKind["GreaterThanEqualsToken"] = 29] = "GreaterThanEqualsToken";
	        SyntaxKind[SyntaxKind["EqualsEqualsToken"] = 30] = "EqualsEqualsToken";
	        SyntaxKind[SyntaxKind["ExclamationEqualsToken"] = 31] = "ExclamationEqualsToken";
	        SyntaxKind[SyntaxKind["EqualsEqualsEqualsToken"] = 32] = "EqualsEqualsEqualsToken";
	        SyntaxKind[SyntaxKind["ExclamationEqualsEqualsToken"] = 33] = "ExclamationEqualsEqualsToken";
	        SyntaxKind[SyntaxKind["EqualsGreaterThanToken"] = 34] = "EqualsGreaterThanToken";
	        SyntaxKind[SyntaxKind["PlusToken"] = 35] = "PlusToken";
	        SyntaxKind[SyntaxKind["MinusToken"] = 36] = "MinusToken";
	        SyntaxKind[SyntaxKind["AsteriskToken"] = 37] = "AsteriskToken";
	        SyntaxKind[SyntaxKind["AsteriskAsteriskToken"] = 38] = "AsteriskAsteriskToken";
	        SyntaxKind[SyntaxKind["SlashToken"] = 39] = "SlashToken";
	        SyntaxKind[SyntaxKind["PercentToken"] = 40] = "PercentToken";
	        SyntaxKind[SyntaxKind["PlusPlusToken"] = 41] = "PlusPlusToken";
	        SyntaxKind[SyntaxKind["MinusMinusToken"] = 42] = "MinusMinusToken";
	        SyntaxKind[SyntaxKind["LessThanLessThanToken"] = 43] = "LessThanLessThanToken";
	        SyntaxKind[SyntaxKind["GreaterThanGreaterThanToken"] = 44] = "GreaterThanGreaterThanToken";
	        SyntaxKind[SyntaxKind["GreaterThanGreaterThanGreaterThanToken"] = 45] = "GreaterThanGreaterThanGreaterThanToken";
	        SyntaxKind[SyntaxKind["AmpersandToken"] = 46] = "AmpersandToken";
	        SyntaxKind[SyntaxKind["BarToken"] = 47] = "BarToken";
	        SyntaxKind[SyntaxKind["CaretToken"] = 48] = "CaretToken";
	        SyntaxKind[SyntaxKind["ExclamationToken"] = 49] = "ExclamationToken";
	        SyntaxKind[SyntaxKind["TildeToken"] = 50] = "TildeToken";
	        SyntaxKind[SyntaxKind["AmpersandAmpersandToken"] = 51] = "AmpersandAmpersandToken";
	        SyntaxKind[SyntaxKind["BarBarToken"] = 52] = "BarBarToken";
	        SyntaxKind[SyntaxKind["QuestionToken"] = 53] = "QuestionToken";
	        SyntaxKind[SyntaxKind["ColonToken"] = 54] = "ColonToken";
	        SyntaxKind[SyntaxKind["AtToken"] = 55] = "AtToken";
	        // Assignments
	        SyntaxKind[SyntaxKind["EqualsToken"] = 56] = "EqualsToken";
	        SyntaxKind[SyntaxKind["PlusEqualsToken"] = 57] = "PlusEqualsToken";
	        SyntaxKind[SyntaxKind["MinusEqualsToken"] = 58] = "MinusEqualsToken";
	        SyntaxKind[SyntaxKind["AsteriskEqualsToken"] = 59] = "AsteriskEqualsToken";
	        SyntaxKind[SyntaxKind["AsteriskAsteriskEqualsToken"] = 60] = "AsteriskAsteriskEqualsToken";
	        SyntaxKind[SyntaxKind["SlashEqualsToken"] = 61] = "SlashEqualsToken";
	        SyntaxKind[SyntaxKind["PercentEqualsToken"] = 62] = "PercentEqualsToken";
	        SyntaxKind[SyntaxKind["LessThanLessThanEqualsToken"] = 63] = "LessThanLessThanEqualsToken";
	        SyntaxKind[SyntaxKind["GreaterThanGreaterThanEqualsToken"] = 64] = "GreaterThanGreaterThanEqualsToken";
	        SyntaxKind[SyntaxKind["GreaterThanGreaterThanGreaterThanEqualsToken"] = 65] = "GreaterThanGreaterThanGreaterThanEqualsToken";
	        SyntaxKind[SyntaxKind["AmpersandEqualsToken"] = 66] = "AmpersandEqualsToken";
	        SyntaxKind[SyntaxKind["BarEqualsToken"] = 67] = "BarEqualsToken";
	        SyntaxKind[SyntaxKind["CaretEqualsToken"] = 68] = "CaretEqualsToken";
	        // Identifiers
	        SyntaxKind[SyntaxKind["Identifier"] = 69] = "Identifier";
	        // Reserved words
	        SyntaxKind[SyntaxKind["BreakKeyword"] = 70] = "BreakKeyword";
	        SyntaxKind[SyntaxKind["CaseKeyword"] = 71] = "CaseKeyword";
	        SyntaxKind[SyntaxKind["CatchKeyword"] = 72] = "CatchKeyword";
	        SyntaxKind[SyntaxKind["ClassKeyword"] = 73] = "ClassKeyword";
	        SyntaxKind[SyntaxKind["ConstKeyword"] = 74] = "ConstKeyword";
	        SyntaxKind[SyntaxKind["ContinueKeyword"] = 75] = "ContinueKeyword";
	        SyntaxKind[SyntaxKind["DebuggerKeyword"] = 76] = "DebuggerKeyword";
	        SyntaxKind[SyntaxKind["DefaultKeyword"] = 77] = "DefaultKeyword";
	        SyntaxKind[SyntaxKind["DeleteKeyword"] = 78] = "DeleteKeyword";
	        SyntaxKind[SyntaxKind["DoKeyword"] = 79] = "DoKeyword";
	        SyntaxKind[SyntaxKind["ElseKeyword"] = 80] = "ElseKeyword";
	        SyntaxKind[SyntaxKind["EnumKeyword"] = 81] = "EnumKeyword";
	        SyntaxKind[SyntaxKind["ExportKeyword"] = 82] = "ExportKeyword";
	        SyntaxKind[SyntaxKind["ExtendsKeyword"] = 83] = "ExtendsKeyword";
	        SyntaxKind[SyntaxKind["FalseKeyword"] = 84] = "FalseKeyword";
	        SyntaxKind[SyntaxKind["FinallyKeyword"] = 85] = "FinallyKeyword";
	        SyntaxKind[SyntaxKind["ForKeyword"] = 86] = "ForKeyword";
	        SyntaxKind[SyntaxKind["FunctionKeyword"] = 87] = "FunctionKeyword";
	        SyntaxKind[SyntaxKind["IfKeyword"] = 88] = "IfKeyword";
	        SyntaxKind[SyntaxKind["ImportKeyword"] = 89] = "ImportKeyword";
	        SyntaxKind[SyntaxKind["InKeyword"] = 90] = "InKeyword";
	        SyntaxKind[SyntaxKind["InstanceOfKeyword"] = 91] = "InstanceOfKeyword";
	        SyntaxKind[SyntaxKind["NewKeyword"] = 92] = "NewKeyword";
	        SyntaxKind[SyntaxKind["NullKeyword"] = 93] = "NullKeyword";
	        SyntaxKind[SyntaxKind["ReturnKeyword"] = 94] = "ReturnKeyword";
	        SyntaxKind[SyntaxKind["SuperKeyword"] = 95] = "SuperKeyword";
	        SyntaxKind[SyntaxKind["SwitchKeyword"] = 96] = "SwitchKeyword";
	        SyntaxKind[SyntaxKind["ThisKeyword"] = 97] = "ThisKeyword";
	        SyntaxKind[SyntaxKind["ThrowKeyword"] = 98] = "ThrowKeyword";
	        SyntaxKind[SyntaxKind["TrueKeyword"] = 99] = "TrueKeyword";
	        SyntaxKind[SyntaxKind["TryKeyword"] = 100] = "TryKeyword";
	        SyntaxKind[SyntaxKind["TypeOfKeyword"] = 101] = "TypeOfKeyword";
	        SyntaxKind[SyntaxKind["VarKeyword"] = 102] = "VarKeyword";
	        SyntaxKind[SyntaxKind["VoidKeyword"] = 103] = "VoidKeyword";
	        SyntaxKind[SyntaxKind["WhileKeyword"] = 104] = "WhileKeyword";
	        SyntaxKind[SyntaxKind["WithKeyword"] = 105] = "WithKeyword";
	        // Strict mode reserved words
	        SyntaxKind[SyntaxKind["ImplementsKeyword"] = 106] = "ImplementsKeyword";
	        SyntaxKind[SyntaxKind["InterfaceKeyword"] = 107] = "InterfaceKeyword";
	        SyntaxKind[SyntaxKind["LetKeyword"] = 108] = "LetKeyword";
	        SyntaxKind[SyntaxKind["PackageKeyword"] = 109] = "PackageKeyword";
	        SyntaxKind[SyntaxKind["PrivateKeyword"] = 110] = "PrivateKeyword";
	        SyntaxKind[SyntaxKind["ProtectedKeyword"] = 111] = "ProtectedKeyword";
	        SyntaxKind[SyntaxKind["PublicKeyword"] = 112] = "PublicKeyword";
	        SyntaxKind[SyntaxKind["StaticKeyword"] = 113] = "StaticKeyword";
	        SyntaxKind[SyntaxKind["YieldKeyword"] = 114] = "YieldKeyword";
	        // Contextual keywords
	        SyntaxKind[SyntaxKind["AbstractKeyword"] = 115] = "AbstractKeyword";
	        SyntaxKind[SyntaxKind["AsKeyword"] = 116] = "AsKeyword";
	        SyntaxKind[SyntaxKind["AnyKeyword"] = 117] = "AnyKeyword";
	        SyntaxKind[SyntaxKind["AsyncKeyword"] = 118] = "AsyncKeyword";
	        SyntaxKind[SyntaxKind["AwaitKeyword"] = 119] = "AwaitKeyword";
	        SyntaxKind[SyntaxKind["BooleanKeyword"] = 120] = "BooleanKeyword";
	        SyntaxKind[SyntaxKind["ConstructorKeyword"] = 121] = "ConstructorKeyword";
	        SyntaxKind[SyntaxKind["DeclareKeyword"] = 122] = "DeclareKeyword";
	        SyntaxKind[SyntaxKind["GetKeyword"] = 123] = "GetKeyword";
	        SyntaxKind[SyntaxKind["IsKeyword"] = 124] = "IsKeyword";
	        SyntaxKind[SyntaxKind["ModuleKeyword"] = 125] = "ModuleKeyword";
	        SyntaxKind[SyntaxKind["NamespaceKeyword"] = 126] = "NamespaceKeyword";
	        SyntaxKind[SyntaxKind["RequireKeyword"] = 127] = "RequireKeyword";
	        SyntaxKind[SyntaxKind["NumberKeyword"] = 128] = "NumberKeyword";
	        SyntaxKind[SyntaxKind["SetKeyword"] = 129] = "SetKeyword";
	        SyntaxKind[SyntaxKind["StringKeyword"] = 130] = "StringKeyword";
	        SyntaxKind[SyntaxKind["SymbolKeyword"] = 131] = "SymbolKeyword";
	        SyntaxKind[SyntaxKind["TypeKeyword"] = 132] = "TypeKeyword";
	        SyntaxKind[SyntaxKind["FromKeyword"] = 133] = "FromKeyword";
	        SyntaxKind[SyntaxKind["GlobalKeyword"] = 134] = "GlobalKeyword";
	        SyntaxKind[SyntaxKind["OfKeyword"] = 135] = "OfKeyword";
	        // Parse tree nodes
	        // Names
	        SyntaxKind[SyntaxKind["QualifiedName"] = 136] = "QualifiedName";
	        SyntaxKind[SyntaxKind["ComputedPropertyName"] = 137] = "ComputedPropertyName";
	        // Signature elements
	        SyntaxKind[SyntaxKind["TypeParameter"] = 138] = "TypeParameter";
	        SyntaxKind[SyntaxKind["Parameter"] = 139] = "Parameter";
	        SyntaxKind[SyntaxKind["Decorator"] = 140] = "Decorator";
	        // TypeMember
	        SyntaxKind[SyntaxKind["PropertySignature"] = 141] = "PropertySignature";
	        SyntaxKind[SyntaxKind["PropertyDeclaration"] = 142] = "PropertyDeclaration";
	        SyntaxKind[SyntaxKind["MethodSignature"] = 143] = "MethodSignature";
	        SyntaxKind[SyntaxKind["MethodDeclaration"] = 144] = "MethodDeclaration";
	        SyntaxKind[SyntaxKind["Constructor"] = 145] = "Constructor";
	        SyntaxKind[SyntaxKind["GetAccessor"] = 146] = "GetAccessor";
	        SyntaxKind[SyntaxKind["SetAccessor"] = 147] = "SetAccessor";
	        SyntaxKind[SyntaxKind["CallSignature"] = 148] = "CallSignature";
	        SyntaxKind[SyntaxKind["ConstructSignature"] = 149] = "ConstructSignature";
	        SyntaxKind[SyntaxKind["IndexSignature"] = 150] = "IndexSignature";
	        // Type
	        SyntaxKind[SyntaxKind["TypePredicate"] = 151] = "TypePredicate";
	        SyntaxKind[SyntaxKind["TypeReference"] = 152] = "TypeReference";
	        SyntaxKind[SyntaxKind["FunctionType"] = 153] = "FunctionType";
	        SyntaxKind[SyntaxKind["ConstructorType"] = 154] = "ConstructorType";
	        SyntaxKind[SyntaxKind["TypeQuery"] = 155] = "TypeQuery";
	        SyntaxKind[SyntaxKind["TypeLiteral"] = 156] = "TypeLiteral";
	        SyntaxKind[SyntaxKind["ArrayType"] = 157] = "ArrayType";
	        SyntaxKind[SyntaxKind["TupleType"] = 158] = "TupleType";
	        SyntaxKind[SyntaxKind["UnionType"] = 159] = "UnionType";
	        SyntaxKind[SyntaxKind["IntersectionType"] = 160] = "IntersectionType";
	        SyntaxKind[SyntaxKind["ParenthesizedType"] = 161] = "ParenthesizedType";
	        SyntaxKind[SyntaxKind["ThisType"] = 162] = "ThisType";
	        SyntaxKind[SyntaxKind["StringLiteralType"] = 163] = "StringLiteralType";
	        // Binding patterns
	        SyntaxKind[SyntaxKind["ObjectBindingPattern"] = 164] = "ObjectBindingPattern";
	        SyntaxKind[SyntaxKind["ArrayBindingPattern"] = 165] = "ArrayBindingPattern";
	        SyntaxKind[SyntaxKind["BindingElement"] = 166] = "BindingElement";
	        // Expression
	        SyntaxKind[SyntaxKind["ArrayLiteralExpression"] = 167] = "ArrayLiteralExpression";
	        SyntaxKind[SyntaxKind["ObjectLiteralExpression"] = 168] = "ObjectLiteralExpression";
	        SyntaxKind[SyntaxKind["PropertyAccessExpression"] = 169] = "PropertyAccessExpression";
	        SyntaxKind[SyntaxKind["ElementAccessExpression"] = 170] = "ElementAccessExpression";
	        SyntaxKind[SyntaxKind["CallExpression"] = 171] = "CallExpression";
	        SyntaxKind[SyntaxKind["NewExpression"] = 172] = "NewExpression";
	        SyntaxKind[SyntaxKind["TaggedTemplateExpression"] = 173] = "TaggedTemplateExpression";
	        SyntaxKind[SyntaxKind["TypeAssertionExpression"] = 174] = "TypeAssertionExpression";
	        SyntaxKind[SyntaxKind["ParenthesizedExpression"] = 175] = "ParenthesizedExpression";
	        SyntaxKind[SyntaxKind["FunctionExpression"] = 176] = "FunctionExpression";
	        SyntaxKind[SyntaxKind["ArrowFunction"] = 177] = "ArrowFunction";
	        SyntaxKind[SyntaxKind["DeleteExpression"] = 178] = "DeleteExpression";
	        SyntaxKind[SyntaxKind["TypeOfExpression"] = 179] = "TypeOfExpression";
	        SyntaxKind[SyntaxKind["VoidExpression"] = 180] = "VoidExpression";
	        SyntaxKind[SyntaxKind["AwaitExpression"] = 181] = "AwaitExpression";
	        SyntaxKind[SyntaxKind["PrefixUnaryExpression"] = 182] = "PrefixUnaryExpression";
	        SyntaxKind[SyntaxKind["PostfixUnaryExpression"] = 183] = "PostfixUnaryExpression";
	        SyntaxKind[SyntaxKind["BinaryExpression"] = 184] = "BinaryExpression";
	        SyntaxKind[SyntaxKind["ConditionalExpression"] = 185] = "ConditionalExpression";
	        SyntaxKind[SyntaxKind["TemplateExpression"] = 186] = "TemplateExpression";
	        SyntaxKind[SyntaxKind["YieldExpression"] = 187] = "YieldExpression";
	        SyntaxKind[SyntaxKind["SpreadElementExpression"] = 188] = "SpreadElementExpression";
	        SyntaxKind[SyntaxKind["ClassExpression"] = 189] = "ClassExpression";
	        SyntaxKind[SyntaxKind["OmittedExpression"] = 190] = "OmittedExpression";
	        SyntaxKind[SyntaxKind["ExpressionWithTypeArguments"] = 191] = "ExpressionWithTypeArguments";
	        SyntaxKind[SyntaxKind["AsExpression"] = 192] = "AsExpression";
	        // Misc
	        SyntaxKind[SyntaxKind["TemplateSpan"] = 193] = "TemplateSpan";
	        SyntaxKind[SyntaxKind["SemicolonClassElement"] = 194] = "SemicolonClassElement";
	        // Element
	        SyntaxKind[SyntaxKind["Block"] = 195] = "Block";
	        SyntaxKind[SyntaxKind["VariableStatement"] = 196] = "VariableStatement";
	        SyntaxKind[SyntaxKind["EmptyStatement"] = 197] = "EmptyStatement";
	        SyntaxKind[SyntaxKind["ExpressionStatement"] = 198] = "ExpressionStatement";
	        SyntaxKind[SyntaxKind["IfStatement"] = 199] = "IfStatement";
	        SyntaxKind[SyntaxKind["DoStatement"] = 200] = "DoStatement";
	        SyntaxKind[SyntaxKind["WhileStatement"] = 201] = "WhileStatement";
	        SyntaxKind[SyntaxKind["ForStatement"] = 202] = "ForStatement";
	        SyntaxKind[SyntaxKind["ForInStatement"] = 203] = "ForInStatement";
	        SyntaxKind[SyntaxKind["ForOfStatement"] = 204] = "ForOfStatement";
	        SyntaxKind[SyntaxKind["ContinueStatement"] = 205] = "ContinueStatement";
	        SyntaxKind[SyntaxKind["BreakStatement"] = 206] = "BreakStatement";
	        SyntaxKind[SyntaxKind["ReturnStatement"] = 207] = "ReturnStatement";
	        SyntaxKind[SyntaxKind["WithStatement"] = 208] = "WithStatement";
	        SyntaxKind[SyntaxKind["SwitchStatement"] = 209] = "SwitchStatement";
	        SyntaxKind[SyntaxKind["LabeledStatement"] = 210] = "LabeledStatement";
	        SyntaxKind[SyntaxKind["ThrowStatement"] = 211] = "ThrowStatement";
	        SyntaxKind[SyntaxKind["TryStatement"] = 212] = "TryStatement";
	        SyntaxKind[SyntaxKind["DebuggerStatement"] = 213] = "DebuggerStatement";
	        SyntaxKind[SyntaxKind["VariableDeclaration"] = 214] = "VariableDeclaration";
	        SyntaxKind[SyntaxKind["VariableDeclarationList"] = 215] = "VariableDeclarationList";
	        SyntaxKind[SyntaxKind["FunctionDeclaration"] = 216] = "FunctionDeclaration";
	        SyntaxKind[SyntaxKind["ClassDeclaration"] = 217] = "ClassDeclaration";
	        SyntaxKind[SyntaxKind["InterfaceDeclaration"] = 218] = "InterfaceDeclaration";
	        SyntaxKind[SyntaxKind["TypeAliasDeclaration"] = 219] = "TypeAliasDeclaration";
	        SyntaxKind[SyntaxKind["EnumDeclaration"] = 220] = "EnumDeclaration";
	        SyntaxKind[SyntaxKind["ModuleDeclaration"] = 221] = "ModuleDeclaration";
	        SyntaxKind[SyntaxKind["ModuleBlock"] = 222] = "ModuleBlock";
	        SyntaxKind[SyntaxKind["CaseBlock"] = 223] = "CaseBlock";
	        SyntaxKind[SyntaxKind["ImportEqualsDeclaration"] = 224] = "ImportEqualsDeclaration";
	        SyntaxKind[SyntaxKind["ImportDeclaration"] = 225] = "ImportDeclaration";
	        SyntaxKind[SyntaxKind["ImportClause"] = 226] = "ImportClause";
	        SyntaxKind[SyntaxKind["NamespaceImport"] = 227] = "NamespaceImport";
	        SyntaxKind[SyntaxKind["NamedImports"] = 228] = "NamedImports";
	        SyntaxKind[SyntaxKind["ImportSpecifier"] = 229] = "ImportSpecifier";
	        SyntaxKind[SyntaxKind["ExportAssignment"] = 230] = "ExportAssignment";
	        SyntaxKind[SyntaxKind["ExportDeclaration"] = 231] = "ExportDeclaration";
	        SyntaxKind[SyntaxKind["NamedExports"] = 232] = "NamedExports";
	        SyntaxKind[SyntaxKind["ExportSpecifier"] = 233] = "ExportSpecifier";
	        SyntaxKind[SyntaxKind["MissingDeclaration"] = 234] = "MissingDeclaration";
	        // Module references
	        SyntaxKind[SyntaxKind["ExternalModuleReference"] = 235] = "ExternalModuleReference";
	        // JSX
	        SyntaxKind[SyntaxKind["JsxElement"] = 236] = "JsxElement";
	        SyntaxKind[SyntaxKind["JsxSelfClosingElement"] = 237] = "JsxSelfClosingElement";
	        SyntaxKind[SyntaxKind["JsxOpeningElement"] = 238] = "JsxOpeningElement";
	        SyntaxKind[SyntaxKind["JsxText"] = 239] = "JsxText";
	        SyntaxKind[SyntaxKind["JsxClosingElement"] = 240] = "JsxClosingElement";
	        SyntaxKind[SyntaxKind["JsxAttribute"] = 241] = "JsxAttribute";
	        SyntaxKind[SyntaxKind["JsxSpreadAttribute"] = 242] = "JsxSpreadAttribute";
	        SyntaxKind[SyntaxKind["JsxExpression"] = 243] = "JsxExpression";
	        // Clauses
	        SyntaxKind[SyntaxKind["CaseClause"] = 244] = "CaseClause";
	        SyntaxKind[SyntaxKind["DefaultClause"] = 245] = "DefaultClause";
	        SyntaxKind[SyntaxKind["HeritageClause"] = 246] = "HeritageClause";
	        SyntaxKind[SyntaxKind["CatchClause"] = 247] = "CatchClause";
	        // Property assignments
	        SyntaxKind[SyntaxKind["PropertyAssignment"] = 248] = "PropertyAssignment";
	        SyntaxKind[SyntaxKind["ShorthandPropertyAssignment"] = 249] = "ShorthandPropertyAssignment";
	        // Enum
	        SyntaxKind[SyntaxKind["EnumMember"] = 250] = "EnumMember";
	        // Top-level nodes
	        SyntaxKind[SyntaxKind["SourceFile"] = 251] = "SourceFile";
	        // JSDoc nodes
	        SyntaxKind[SyntaxKind["JSDocTypeExpression"] = 252] = "JSDocTypeExpression";
	        // The * type
	        SyntaxKind[SyntaxKind["JSDocAllType"] = 253] = "JSDocAllType";
	        // The ? type
	        SyntaxKind[SyntaxKind["JSDocUnknownType"] = 254] = "JSDocUnknownType";
	        SyntaxKind[SyntaxKind["JSDocArrayType"] = 255] = "JSDocArrayType";
	        SyntaxKind[SyntaxKind["JSDocUnionType"] = 256] = "JSDocUnionType";
	        SyntaxKind[SyntaxKind["JSDocTupleType"] = 257] = "JSDocTupleType";
	        SyntaxKind[SyntaxKind["JSDocNullableType"] = 258] = "JSDocNullableType";
	        SyntaxKind[SyntaxKind["JSDocNonNullableType"] = 259] = "JSDocNonNullableType";
	        SyntaxKind[SyntaxKind["JSDocRecordType"] = 260] = "JSDocRecordType";
	        SyntaxKind[SyntaxKind["JSDocRecordMember"] = 261] = "JSDocRecordMember";
	        SyntaxKind[SyntaxKind["JSDocTypeReference"] = 262] = "JSDocTypeReference";
	        SyntaxKind[SyntaxKind["JSDocOptionalType"] = 263] = "JSDocOptionalType";
	        SyntaxKind[SyntaxKind["JSDocFunctionType"] = 264] = "JSDocFunctionType";
	        SyntaxKind[SyntaxKind["JSDocVariadicType"] = 265] = "JSDocVariadicType";
	        SyntaxKind[SyntaxKind["JSDocConstructorType"] = 266] = "JSDocConstructorType";
	        SyntaxKind[SyntaxKind["JSDocThisType"] = 267] = "JSDocThisType";
	        SyntaxKind[SyntaxKind["JSDocComment"] = 268] = "JSDocComment";
	        SyntaxKind[SyntaxKind["JSDocTag"] = 269] = "JSDocTag";
	        SyntaxKind[SyntaxKind["JSDocParameterTag"] = 270] = "JSDocParameterTag";
	        SyntaxKind[SyntaxKind["JSDocReturnTag"] = 271] = "JSDocReturnTag";
	        SyntaxKind[SyntaxKind["JSDocTypeTag"] = 272] = "JSDocTypeTag";
	        SyntaxKind[SyntaxKind["JSDocTemplateTag"] = 273] = "JSDocTemplateTag";
	        // Synthesized list
	        SyntaxKind[SyntaxKind["SyntaxList"] = 274] = "SyntaxList";
	        // Enum value count
	        SyntaxKind[SyntaxKind["Count"] = 275] = "Count";
	        // Markers
	        SyntaxKind[SyntaxKind["FirstAssignment"] = 56] = "FirstAssignment";
	        SyntaxKind[SyntaxKind["LastAssignment"] = 68] = "LastAssignment";
	        SyntaxKind[SyntaxKind["FirstReservedWord"] = 70] = "FirstReservedWord";
	        SyntaxKind[SyntaxKind["LastReservedWord"] = 105] = "LastReservedWord";
	        SyntaxKind[SyntaxKind["FirstKeyword"] = 70] = "FirstKeyword";
	        SyntaxKind[SyntaxKind["LastKeyword"] = 135] = "LastKeyword";
	        SyntaxKind[SyntaxKind["FirstFutureReservedWord"] = 106] = "FirstFutureReservedWord";
	        SyntaxKind[SyntaxKind["LastFutureReservedWord"] = 114] = "LastFutureReservedWord";
	        SyntaxKind[SyntaxKind["FirstTypeNode"] = 151] = "FirstTypeNode";
	        SyntaxKind[SyntaxKind["LastTypeNode"] = 163] = "LastTypeNode";
	        SyntaxKind[SyntaxKind["FirstPunctuation"] = 15] = "FirstPunctuation";
	        SyntaxKind[SyntaxKind["LastPunctuation"] = 68] = "LastPunctuation";
	        SyntaxKind[SyntaxKind["FirstToken"] = 0] = "FirstToken";
	        SyntaxKind[SyntaxKind["LastToken"] = 135] = "LastToken";
	        SyntaxKind[SyntaxKind["FirstTriviaToken"] = 2] = "FirstTriviaToken";
	        SyntaxKind[SyntaxKind["LastTriviaToken"] = 7] = "LastTriviaToken";
	        SyntaxKind[SyntaxKind["FirstLiteralToken"] = 8] = "FirstLiteralToken";
	        SyntaxKind[SyntaxKind["LastLiteralToken"] = 11] = "LastLiteralToken";
	        SyntaxKind[SyntaxKind["FirstTemplateToken"] = 11] = "FirstTemplateToken";
	        SyntaxKind[SyntaxKind["LastTemplateToken"] = 14] = "LastTemplateToken";
	        SyntaxKind[SyntaxKind["FirstBinaryOperator"] = 25] = "FirstBinaryOperator";
	        SyntaxKind[SyntaxKind["LastBinaryOperator"] = 68] = "LastBinaryOperator";
	        SyntaxKind[SyntaxKind["FirstNode"] = 136] = "FirstNode";
	    })(ts.SyntaxKind || (ts.SyntaxKind = {}));
	    var SyntaxKind = ts.SyntaxKind;
	    (function (NodeFlags) {
	        NodeFlags[NodeFlags["None"] = 0] = "None";
	        NodeFlags[NodeFlags["Export"] = 2] = "Export";
	        NodeFlags[NodeFlags["Ambient"] = 4] = "Ambient";
	        NodeFlags[NodeFlags["Public"] = 8] = "Public";
	        NodeFlags[NodeFlags["Private"] = 16] = "Private";
	        NodeFlags[NodeFlags["Protected"] = 32] = "Protected";
	        NodeFlags[NodeFlags["Static"] = 64] = "Static";
	        NodeFlags[NodeFlags["Abstract"] = 128] = "Abstract";
	        NodeFlags[NodeFlags["Async"] = 256] = "Async";
	        NodeFlags[NodeFlags["Default"] = 512] = "Default";
	        NodeFlags[NodeFlags["MultiLine"] = 1024] = "MultiLine";
	        NodeFlags[NodeFlags["Synthetic"] = 2048] = "Synthetic";
	        NodeFlags[NodeFlags["DeclarationFile"] = 4096] = "DeclarationFile";
	        NodeFlags[NodeFlags["Let"] = 8192] = "Let";
	        NodeFlags[NodeFlags["Const"] = 16384] = "Const";
	        NodeFlags[NodeFlags["OctalLiteral"] = 32768] = "OctalLiteral";
	        NodeFlags[NodeFlags["Namespace"] = 65536] = "Namespace";
	        NodeFlags[NodeFlags["ExportContext"] = 131072] = "ExportContext";
	        NodeFlags[NodeFlags["ContainsThis"] = 262144] = "ContainsThis";
	        NodeFlags[NodeFlags["HasImplicitReturn"] = 524288] = "HasImplicitReturn";
	        NodeFlags[NodeFlags["HasExplicitReturn"] = 1048576] = "HasExplicitReturn";
	        NodeFlags[NodeFlags["GlobalAugmentation"] = 2097152] = "GlobalAugmentation";
	        NodeFlags[NodeFlags["HasClassExtends"] = 4194304] = "HasClassExtends";
	        NodeFlags[NodeFlags["HasDecorators"] = 8388608] = "HasDecorators";
	        NodeFlags[NodeFlags["HasParamDecorators"] = 16777216] = "HasParamDecorators";
	        NodeFlags[NodeFlags["HasAsyncFunctions"] = 33554432] = "HasAsyncFunctions";
	        NodeFlags[NodeFlags["Modifier"] = 1022] = "Modifier";
	        NodeFlags[NodeFlags["AccessibilityModifier"] = 56] = "AccessibilityModifier";
	        NodeFlags[NodeFlags["BlockScoped"] = 24576] = "BlockScoped";
	        NodeFlags[NodeFlags["ReachabilityCheckFlags"] = 1572864] = "ReachabilityCheckFlags";
	        NodeFlags[NodeFlags["EmitHelperFlags"] = 62914560] = "EmitHelperFlags";
	    })(ts.NodeFlags || (ts.NodeFlags = {}));
	    var NodeFlags = ts.NodeFlags;
	    /* @internal */
	    (function (ParserContextFlags) {
	        ParserContextFlags[ParserContextFlags["None"] = 0] = "None";
	        // If this node was parsed in a context where 'in-expressions' are not allowed.
	        ParserContextFlags[ParserContextFlags["DisallowIn"] = 1] = "DisallowIn";
	        // If this node was parsed in the 'yield' context created when parsing a generator.
	        ParserContextFlags[ParserContextFlags["Yield"] = 2] = "Yield";
	        // If this node was parsed as part of a decorator
	        ParserContextFlags[ParserContextFlags["Decorator"] = 4] = "Decorator";
	        // If this node was parsed in the 'await' context created when parsing an async function.
	        ParserContextFlags[ParserContextFlags["Await"] = 8] = "Await";
	        // If the parser encountered an error when parsing the code that created this node.  Note
	        // the parser only sets this directly on the node it creates right after encountering the
	        // error.
	        ParserContextFlags[ParserContextFlags["ThisNodeHasError"] = 16] = "ThisNodeHasError";
	        // This node was parsed in a JavaScript file and can be processed differently.  For example
	        // its type can be specified usign a JSDoc comment.
	        ParserContextFlags[ParserContextFlags["JavaScriptFile"] = 32] = "JavaScriptFile";
	        // Context flags set directly by the parser.
	        ParserContextFlags[ParserContextFlags["ParserGeneratedFlags"] = 31] = "ParserGeneratedFlags";
	        // Exclude these flags when parsing a Type
	        ParserContextFlags[ParserContextFlags["TypeExcludesFlags"] = 10] = "TypeExcludesFlags";
	        // Context flags computed by aggregating child flags upwards.
	        // Used during incremental parsing to determine if this node or any of its children had an
	        // error.  Computed only once and then cached.
	        ParserContextFlags[ParserContextFlags["ThisNodeOrAnySubNodesHasError"] = 64] = "ThisNodeOrAnySubNodesHasError";
	        // Used to know if we've computed data from children and cached it in this node.
	        ParserContextFlags[ParserContextFlags["HasAggregatedChildData"] = 128] = "HasAggregatedChildData";
	    })(ts.ParserContextFlags || (ts.ParserContextFlags = {}));
	    var ParserContextFlags = ts.ParserContextFlags;
	    (function (JsxFlags) {
	        JsxFlags[JsxFlags["None"] = 0] = "None";
	        /** An element from a named property of the JSX.IntrinsicElements interface */
	        JsxFlags[JsxFlags["IntrinsicNamedElement"] = 1] = "IntrinsicNamedElement";
	        /** An element inferred from the string index signature of the JSX.IntrinsicElements interface */
	        JsxFlags[JsxFlags["IntrinsicIndexedElement"] = 2] = "IntrinsicIndexedElement";
	        /** An element backed by a class, class-like, or function value */
	        JsxFlags[JsxFlags["ValueElement"] = 4] = "ValueElement";
	        /** Element resolution failed */
	        JsxFlags[JsxFlags["UnknownElement"] = 16] = "UnknownElement";
	        JsxFlags[JsxFlags["IntrinsicElement"] = 3] = "IntrinsicElement";
	    })(ts.JsxFlags || (ts.JsxFlags = {}));
	    var JsxFlags = ts.JsxFlags;
	    /* @internal */
	    (function (RelationComparisonResult) {
	        RelationComparisonResult[RelationComparisonResult["Succeeded"] = 1] = "Succeeded";
	        RelationComparisonResult[RelationComparisonResult["Failed"] = 2] = "Failed";
	        RelationComparisonResult[RelationComparisonResult["FailedAndReported"] = 3] = "FailedAndReported";
	    })(ts.RelationComparisonResult || (ts.RelationComparisonResult = {}));
	    var RelationComparisonResult = ts.RelationComparisonResult;
	    var OperationCanceledException = (function () {
	        function OperationCanceledException() {
	        }
	        return OperationCanceledException;
	    }());
	    ts.OperationCanceledException = OperationCanceledException;
	    /** Return code used by getEmitOutput function to indicate status of the function */
	    (function (ExitStatus) {
	        // Compiler ran successfully.  Either this was a simple do-nothing compilation (for example,
	        // when -version or -help was provided, or this was a normal compilation, no diagnostics
	        // were produced, and all outputs were generated successfully.
	        ExitStatus[ExitStatus["Success"] = 0] = "Success";
	        // Diagnostics were produced and because of them no code was generated.
	        ExitStatus[ExitStatus["DiagnosticsPresent_OutputsSkipped"] = 1] = "DiagnosticsPresent_OutputsSkipped";
	        // Diagnostics were produced and outputs were generated in spite of them.
	        ExitStatus[ExitStatus["DiagnosticsPresent_OutputsGenerated"] = 2] = "DiagnosticsPresent_OutputsGenerated";
	    })(ts.ExitStatus || (ts.ExitStatus = {}));
	    var ExitStatus = ts.ExitStatus;
	    (function (TypeFormatFlags) {
	        TypeFormatFlags[TypeFormatFlags["None"] = 0] = "None";
	        TypeFormatFlags[TypeFormatFlags["WriteArrayAsGenericType"] = 1] = "WriteArrayAsGenericType";
	        TypeFormatFlags[TypeFormatFlags["UseTypeOfFunction"] = 2] = "UseTypeOfFunction";
	        TypeFormatFlags[TypeFormatFlags["NoTruncation"] = 4] = "NoTruncation";
	        TypeFormatFlags[TypeFormatFlags["WriteArrowStyleSignature"] = 8] = "WriteArrowStyleSignature";
	        TypeFormatFlags[TypeFormatFlags["WriteOwnNameForAnyLike"] = 16] = "WriteOwnNameForAnyLike";
	        TypeFormatFlags[TypeFormatFlags["WriteTypeArgumentsOfSignature"] = 32] = "WriteTypeArgumentsOfSignature";
	        TypeFormatFlags[TypeFormatFlags["InElementType"] = 64] = "InElementType";
	        TypeFormatFlags[TypeFormatFlags["UseFullyQualifiedType"] = 128] = "UseFullyQualifiedType";
	    })(ts.TypeFormatFlags || (ts.TypeFormatFlags = {}));
	    var TypeFormatFlags = ts.TypeFormatFlags;
	    (function (SymbolFormatFlags) {
	        SymbolFormatFlags[SymbolFormatFlags["None"] = 0] = "None";
	        // Write symbols's type argument if it is instantiated symbol
	        // eg. class C<T> { p: T }   <-- Show p as C<T>.p here
	        //     var a: C<number>;
	        //     var p = a.p;  <--- Here p is property of C<number> so show it as C<number>.p instead of just C.p
	        SymbolFormatFlags[SymbolFormatFlags["WriteTypeParametersOrArguments"] = 1] = "WriteTypeParametersOrArguments";
	        // Use only external alias information to get the symbol name in the given context
	        // eg.  module m { export class c { } } import x = m.c;
	        // When this flag is specified m.c will be used to refer to the class instead of alias symbol x
	        SymbolFormatFlags[SymbolFormatFlags["UseOnlyExternalAliasing"] = 2] = "UseOnlyExternalAliasing";
	    })(ts.SymbolFormatFlags || (ts.SymbolFormatFlags = {}));
	    var SymbolFormatFlags = ts.SymbolFormatFlags;
	    /* @internal */
	    (function (SymbolAccessibility) {
	        SymbolAccessibility[SymbolAccessibility["Accessible"] = 0] = "Accessible";
	        SymbolAccessibility[SymbolAccessibility["NotAccessible"] = 1] = "NotAccessible";
	        SymbolAccessibility[SymbolAccessibility["CannotBeNamed"] = 2] = "CannotBeNamed";
	    })(ts.SymbolAccessibility || (ts.SymbolAccessibility = {}));
	    var SymbolAccessibility = ts.SymbolAccessibility;
	    (function (TypePredicateKind) {
	        TypePredicateKind[TypePredicateKind["This"] = 0] = "This";
	        TypePredicateKind[TypePredicateKind["Identifier"] = 1] = "Identifier";
	    })(ts.TypePredicateKind || (ts.TypePredicateKind = {}));
	    var TypePredicateKind = ts.TypePredicateKind;
	    /** Indicates how to serialize the name for a TypeReferenceNode when emitting decorator
	      * metadata */
	    /* @internal */
	    (function (TypeReferenceSerializationKind) {
	        TypeReferenceSerializationKind[TypeReferenceSerializationKind["Unknown"] = 0] = "Unknown";
	        // should be emitted using a safe fallback.
	        TypeReferenceSerializationKind[TypeReferenceSerializationKind["TypeWithConstructSignatureAndValue"] = 1] = "TypeWithConstructSignatureAndValue";
	        // function that can be reached at runtime (e.g. a `class`
	        // declaration or a `var` declaration for the static side
	        // of a type, such as the global `Promise` type in lib.d.ts).
	        TypeReferenceSerializationKind[TypeReferenceSerializationKind["VoidType"] = 2] = "VoidType";
	        TypeReferenceSerializationKind[TypeReferenceSerializationKind["NumberLikeType"] = 3] = "NumberLikeType";
	        TypeReferenceSerializationKind[TypeReferenceSerializationKind["StringLikeType"] = 4] = "StringLikeType";
	        TypeReferenceSerializationKind[TypeReferenceSerializationKind["BooleanType"] = 5] = "BooleanType";
	        TypeReferenceSerializationKind[TypeReferenceSerializationKind["ArrayLikeType"] = 6] = "ArrayLikeType";
	        TypeReferenceSerializationKind[TypeReferenceSerializationKind["ESSymbolType"] = 7] = "ESSymbolType";
	        TypeReferenceSerializationKind[TypeReferenceSerializationKind["TypeWithCallSignature"] = 8] = "TypeWithCallSignature";
	        // with call signatures.
	        TypeReferenceSerializationKind[TypeReferenceSerializationKind["ObjectType"] = 9] = "ObjectType";
	    })(ts.TypeReferenceSerializationKind || (ts.TypeReferenceSerializationKind = {}));
	    var TypeReferenceSerializationKind = ts.TypeReferenceSerializationKind;
	    (function (SymbolFlags) {
	        SymbolFlags[SymbolFlags["None"] = 0] = "None";
	        SymbolFlags[SymbolFlags["FunctionScopedVariable"] = 1] = "FunctionScopedVariable";
	        SymbolFlags[SymbolFlags["BlockScopedVariable"] = 2] = "BlockScopedVariable";
	        SymbolFlags[SymbolFlags["Property"] = 4] = "Property";
	        SymbolFlags[SymbolFlags["EnumMember"] = 8] = "EnumMember";
	        SymbolFlags[SymbolFlags["Function"] = 16] = "Function";
	        SymbolFlags[SymbolFlags["Class"] = 32] = "Class";
	        SymbolFlags[SymbolFlags["Interface"] = 64] = "Interface";
	        SymbolFlags[SymbolFlags["ConstEnum"] = 128] = "ConstEnum";
	        SymbolFlags[SymbolFlags["RegularEnum"] = 256] = "RegularEnum";
	        SymbolFlags[SymbolFlags["ValueModule"] = 512] = "ValueModule";
	        SymbolFlags[SymbolFlags["NamespaceModule"] = 1024] = "NamespaceModule";
	        SymbolFlags[SymbolFlags["TypeLiteral"] = 2048] = "TypeLiteral";
	        SymbolFlags[SymbolFlags["ObjectLiteral"] = 4096] = "ObjectLiteral";
	        SymbolFlags[SymbolFlags["Method"] = 8192] = "Method";
	        SymbolFlags[SymbolFlags["Constructor"] = 16384] = "Constructor";
	        SymbolFlags[SymbolFlags["GetAccessor"] = 32768] = "GetAccessor";
	        SymbolFlags[SymbolFlags["SetAccessor"] = 65536] = "SetAccessor";
	        SymbolFlags[SymbolFlags["Signature"] = 131072] = "Signature";
	        SymbolFlags[SymbolFlags["TypeParameter"] = 262144] = "TypeParameter";
	        SymbolFlags[SymbolFlags["TypeAlias"] = 524288] = "TypeAlias";
	        SymbolFlags[SymbolFlags["ExportValue"] = 1048576] = "ExportValue";
	        SymbolFlags[SymbolFlags["ExportType"] = 2097152] = "ExportType";
	        SymbolFlags[SymbolFlags["ExportNamespace"] = 4194304] = "ExportNamespace";
	        SymbolFlags[SymbolFlags["Alias"] = 8388608] = "Alias";
	        SymbolFlags[SymbolFlags["Instantiated"] = 16777216] = "Instantiated";
	        SymbolFlags[SymbolFlags["Merged"] = 33554432] = "Merged";
	        SymbolFlags[SymbolFlags["Transient"] = 67108864] = "Transient";
	        SymbolFlags[SymbolFlags["Prototype"] = 134217728] = "Prototype";
	        SymbolFlags[SymbolFlags["SyntheticProperty"] = 268435456] = "SyntheticProperty";
	        SymbolFlags[SymbolFlags["Optional"] = 536870912] = "Optional";
	        SymbolFlags[SymbolFlags["ExportStar"] = 1073741824] = "ExportStar";
	        SymbolFlags[SymbolFlags["Enum"] = 384] = "Enum";
	        SymbolFlags[SymbolFlags["Variable"] = 3] = "Variable";
	        SymbolFlags[SymbolFlags["Value"] = 107455] = "Value";
	        SymbolFlags[SymbolFlags["Type"] = 793056] = "Type";
	        SymbolFlags[SymbolFlags["Namespace"] = 1536] = "Namespace";
	        SymbolFlags[SymbolFlags["Module"] = 1536] = "Module";
	        SymbolFlags[SymbolFlags["Accessor"] = 98304] = "Accessor";
	        // Variables can be redeclared, but can not redeclare a block-scoped declaration with the
	        // same name, or any other value that is not a variable, e.g. ValueModule or Class
	        SymbolFlags[SymbolFlags["FunctionScopedVariableExcludes"] = 107454] = "FunctionScopedVariableExcludes";
	        // Block-scoped declarations are not allowed to be re-declared
	        // they can not merge with anything in the value space
	        SymbolFlags[SymbolFlags["BlockScopedVariableExcludes"] = 107455] = "BlockScopedVariableExcludes";
	        SymbolFlags[SymbolFlags["ParameterExcludes"] = 107455] = "ParameterExcludes";
	        SymbolFlags[SymbolFlags["PropertyExcludes"] = 107455] = "PropertyExcludes";
	        SymbolFlags[SymbolFlags["EnumMemberExcludes"] = 107455] = "EnumMemberExcludes";
	        SymbolFlags[SymbolFlags["FunctionExcludes"] = 106927] = "FunctionExcludes";
	        SymbolFlags[SymbolFlags["ClassExcludes"] = 899519] = "ClassExcludes";
	        SymbolFlags[SymbolFlags["InterfaceExcludes"] = 792960] = "InterfaceExcludes";
	        SymbolFlags[SymbolFlags["RegularEnumExcludes"] = 899327] = "RegularEnumExcludes";
	        SymbolFlags[SymbolFlags["ConstEnumExcludes"] = 899967] = "ConstEnumExcludes";
	        SymbolFlags[SymbolFlags["ValueModuleExcludes"] = 106639] = "ValueModuleExcludes";
	        SymbolFlags[SymbolFlags["NamespaceModuleExcludes"] = 0] = "NamespaceModuleExcludes";
	        SymbolFlags[SymbolFlags["MethodExcludes"] = 99263] = "MethodExcludes";
	        SymbolFlags[SymbolFlags["GetAccessorExcludes"] = 41919] = "GetAccessorExcludes";
	        SymbolFlags[SymbolFlags["SetAccessorExcludes"] = 74687] = "SetAccessorExcludes";
	        SymbolFlags[SymbolFlags["TypeParameterExcludes"] = 530912] = "TypeParameterExcludes";
	        SymbolFlags[SymbolFlags["TypeAliasExcludes"] = 793056] = "TypeAliasExcludes";
	        SymbolFlags[SymbolFlags["AliasExcludes"] = 8388608] = "AliasExcludes";
	        SymbolFlags[SymbolFlags["ModuleMember"] = 8914931] = "ModuleMember";
	        SymbolFlags[SymbolFlags["ExportHasLocal"] = 944] = "ExportHasLocal";
	        SymbolFlags[SymbolFlags["HasExports"] = 1952] = "HasExports";
	        SymbolFlags[SymbolFlags["HasMembers"] = 6240] = "HasMembers";
	        SymbolFlags[SymbolFlags["BlockScoped"] = 418] = "BlockScoped";
	        SymbolFlags[SymbolFlags["PropertyOrAccessor"] = 98308] = "PropertyOrAccessor";
	        SymbolFlags[SymbolFlags["Export"] = 7340032] = "Export";
	        /* @internal */
	        // The set of things we consider semantically classifiable.  Used to speed up the LS during
	        // classification.
	        SymbolFlags[SymbolFlags["Classifiable"] = 788448] = "Classifiable";
	    })(ts.SymbolFlags || (ts.SymbolFlags = {}));
	    var SymbolFlags = ts.SymbolFlags;
	    /* @internal */
	    (function (NodeCheckFlags) {
	        NodeCheckFlags[NodeCheckFlags["TypeChecked"] = 1] = "TypeChecked";
	        NodeCheckFlags[NodeCheckFlags["LexicalThis"] = 2] = "LexicalThis";
	        NodeCheckFlags[NodeCheckFlags["CaptureThis"] = 4] = "CaptureThis";
	        NodeCheckFlags[NodeCheckFlags["SuperInstance"] = 256] = "SuperInstance";
	        NodeCheckFlags[NodeCheckFlags["SuperStatic"] = 512] = "SuperStatic";
	        NodeCheckFlags[NodeCheckFlags["ContextChecked"] = 1024] = "ContextChecked";
	        NodeCheckFlags[NodeCheckFlags["AsyncMethodWithSuper"] = 2048] = "AsyncMethodWithSuper";
	        NodeCheckFlags[NodeCheckFlags["AsyncMethodWithSuperBinding"] = 4096] = "AsyncMethodWithSuperBinding";
	        NodeCheckFlags[NodeCheckFlags["CaptureArguments"] = 8192] = "CaptureArguments";
	        // Values for enum members have been computed, and any errors have been reported for them.
	        NodeCheckFlags[NodeCheckFlags["EnumValuesComputed"] = 16384] = "EnumValuesComputed";
	        NodeCheckFlags[NodeCheckFlags["LexicalModuleMergesWithClass"] = 32768] = "LexicalModuleMergesWithClass";
	        NodeCheckFlags[NodeCheckFlags["LoopWithCapturedBlockScopedBinding"] = 65536] = "LoopWithCapturedBlockScopedBinding";
	        NodeCheckFlags[NodeCheckFlags["CapturedBlockScopedBinding"] = 131072] = "CapturedBlockScopedBinding";
	        NodeCheckFlags[NodeCheckFlags["BlockScopedBindingInLoop"] = 262144] = "BlockScopedBindingInLoop";
	        NodeCheckFlags[NodeCheckFlags["ClassWithBodyScopedClassBinding"] = 524288] = "ClassWithBodyScopedClassBinding";
	        NodeCheckFlags[NodeCheckFlags["BodyScopedClassBinding"] = 1048576] = "BodyScopedClassBinding";
	        NodeCheckFlags[NodeCheckFlags["NeedsLoopOutParameter"] = 2097152] = "NeedsLoopOutParameter";
	    })(ts.NodeCheckFlags || (ts.NodeCheckFlags = {}));
	    var NodeCheckFlags = ts.NodeCheckFlags;
	    (function (TypeFlags) {
	        TypeFlags[TypeFlags["Any"] = 1] = "Any";
	        TypeFlags[TypeFlags["String"] = 2] = "String";
	        TypeFlags[TypeFlags["Number"] = 4] = "Number";
	        TypeFlags[TypeFlags["Boolean"] = 8] = "Boolean";
	        TypeFlags[TypeFlags["Void"] = 16] = "Void";
	        TypeFlags[TypeFlags["Undefined"] = 32] = "Undefined";
	        TypeFlags[TypeFlags["Null"] = 64] = "Null";
	        TypeFlags[TypeFlags["Enum"] = 128] = "Enum";
	        TypeFlags[TypeFlags["StringLiteral"] = 256] = "StringLiteral";
	        TypeFlags[TypeFlags["TypeParameter"] = 512] = "TypeParameter";
	        TypeFlags[TypeFlags["Class"] = 1024] = "Class";
	        TypeFlags[TypeFlags["Interface"] = 2048] = "Interface";
	        TypeFlags[TypeFlags["Reference"] = 4096] = "Reference";
	        TypeFlags[TypeFlags["Tuple"] = 8192] = "Tuple";
	        TypeFlags[TypeFlags["Union"] = 16384] = "Union";
	        TypeFlags[TypeFlags["Intersection"] = 32768] = "Intersection";
	        TypeFlags[TypeFlags["Anonymous"] = 65536] = "Anonymous";
	        TypeFlags[TypeFlags["Instantiated"] = 131072] = "Instantiated";
	        /* @internal */
	        TypeFlags[TypeFlags["FromSignature"] = 262144] = "FromSignature";
	        TypeFlags[TypeFlags["ObjectLiteral"] = 524288] = "ObjectLiteral";
	        /* @internal */
	        TypeFlags[TypeFlags["FreshObjectLiteral"] = 1048576] = "FreshObjectLiteral";
	        /* @internal */
	        TypeFlags[TypeFlags["ContainsUndefinedOrNull"] = 2097152] = "ContainsUndefinedOrNull";
	        /* @internal */
	        TypeFlags[TypeFlags["ContainsObjectLiteral"] = 4194304] = "ContainsObjectLiteral";
	        /* @internal */
	        TypeFlags[TypeFlags["ContainsAnyFunctionType"] = 8388608] = "ContainsAnyFunctionType";
	        TypeFlags[TypeFlags["ESSymbol"] = 16777216] = "ESSymbol";
	        TypeFlags[TypeFlags["ThisType"] = 33554432] = "ThisType";
	        TypeFlags[TypeFlags["ObjectLiteralPatternWithComputedProperties"] = 67108864] = "ObjectLiteralPatternWithComputedProperties";
	        /* @internal */
	        TypeFlags[TypeFlags["Intrinsic"] = 16777343] = "Intrinsic";
	        /* @internal */
	        TypeFlags[TypeFlags["Primitive"] = 16777726] = "Primitive";
	        TypeFlags[TypeFlags["StringLike"] = 258] = "StringLike";
	        TypeFlags[TypeFlags["NumberLike"] = 132] = "NumberLike";
	        TypeFlags[TypeFlags["ObjectType"] = 80896] = "ObjectType";
	        TypeFlags[TypeFlags["UnionOrIntersection"] = 49152] = "UnionOrIntersection";
	        TypeFlags[TypeFlags["StructuredType"] = 130048] = "StructuredType";
	        /* @internal */
	        TypeFlags[TypeFlags["RequiresWidening"] = 6291456] = "RequiresWidening";
	        /* @internal */
	        TypeFlags[TypeFlags["PropagatingFlags"] = 14680064] = "PropagatingFlags";
	    })(ts.TypeFlags || (ts.TypeFlags = {}));
	    var TypeFlags = ts.TypeFlags;
	    (function (SignatureKind) {
	        SignatureKind[SignatureKind["Call"] = 0] = "Call";
	        SignatureKind[SignatureKind["Construct"] = 1] = "Construct";
	    })(ts.SignatureKind || (ts.SignatureKind = {}));
	    var SignatureKind = ts.SignatureKind;
	    (function (IndexKind) {
	        IndexKind[IndexKind["String"] = 0] = "String";
	        IndexKind[IndexKind["Number"] = 1] = "Number";
	    })(ts.IndexKind || (ts.IndexKind = {}));
	    var IndexKind = ts.IndexKind;
	    /* @internal */
	    (function (SpecialPropertyAssignmentKind) {
	        SpecialPropertyAssignmentKind[SpecialPropertyAssignmentKind["None"] = 0] = "None";
	        /// exports.name = expr
	        SpecialPropertyAssignmentKind[SpecialPropertyAssignmentKind["ExportsProperty"] = 1] = "ExportsProperty";
	        /// module.exports = expr
	        SpecialPropertyAssignmentKind[SpecialPropertyAssignmentKind["ModuleExports"] = 2] = "ModuleExports";
	        /// className.prototype.name = expr
	        SpecialPropertyAssignmentKind[SpecialPropertyAssignmentKind["PrototypeProperty"] = 3] = "PrototypeProperty";
	        /// this.name = expr
	        SpecialPropertyAssignmentKind[SpecialPropertyAssignmentKind["ThisProperty"] = 4] = "ThisProperty";
	    })(ts.SpecialPropertyAssignmentKind || (ts.SpecialPropertyAssignmentKind = {}));
	    var SpecialPropertyAssignmentKind = ts.SpecialPropertyAssignmentKind;
	    (function (DiagnosticCategory) {
	        DiagnosticCategory[DiagnosticCategory["Warning"] = 0] = "Warning";
	        DiagnosticCategory[DiagnosticCategory["Error"] = 1] = "Error";
	        DiagnosticCategory[DiagnosticCategory["Message"] = 2] = "Message";
	    })(ts.DiagnosticCategory || (ts.DiagnosticCategory = {}));
	    var DiagnosticCategory = ts.DiagnosticCategory;
	    (function (ModuleResolutionKind) {
	        ModuleResolutionKind[ModuleResolutionKind["Classic"] = 1] = "Classic";
	        ModuleResolutionKind[ModuleResolutionKind["NodeJs"] = 2] = "NodeJs";
	    })(ts.ModuleResolutionKind || (ts.ModuleResolutionKind = {}));
	    var ModuleResolutionKind = ts.ModuleResolutionKind;
	    (function (ModuleKind) {
	        ModuleKind[ModuleKind["None"] = 0] = "None";
	        ModuleKind[ModuleKind["CommonJS"] = 1] = "CommonJS";
	        ModuleKind[ModuleKind["AMD"] = 2] = "AMD";
	        ModuleKind[ModuleKind["UMD"] = 3] = "UMD";
	        ModuleKind[ModuleKind["System"] = 4] = "System";
	        ModuleKind[ModuleKind["ES6"] = 5] = "ES6";
	        ModuleKind[ModuleKind["ES2015"] = 5] = "ES2015";
	    })(ts.ModuleKind || (ts.ModuleKind = {}));
	    var ModuleKind = ts.ModuleKind;
	    (function (JsxEmit) {
	        JsxEmit[JsxEmit["None"] = 0] = "None";
	        JsxEmit[JsxEmit["Preserve"] = 1] = "Preserve";
	        JsxEmit[JsxEmit["React"] = 2] = "React";
	    })(ts.JsxEmit || (ts.JsxEmit = {}));
	    var JsxEmit = ts.JsxEmit;
	    (function (NewLineKind) {
	        NewLineKind[NewLineKind["CarriageReturnLineFeed"] = 0] = "CarriageReturnLineFeed";
	        NewLineKind[NewLineKind["LineFeed"] = 1] = "LineFeed";
	    })(ts.NewLineKind || (ts.NewLineKind = {}));
	    var NewLineKind = ts.NewLineKind;
	    (function (ScriptTarget) {
	        ScriptTarget[ScriptTarget["ES3"] = 0] = "ES3";
	        ScriptTarget[ScriptTarget["ES5"] = 1] = "ES5";
	        ScriptTarget[ScriptTarget["ES6"] = 2] = "ES6";
	        ScriptTarget[ScriptTarget["ES2015"] = 2] = "ES2015";
	        ScriptTarget[ScriptTarget["Latest"] = 2] = "Latest";
	    })(ts.ScriptTarget || (ts.ScriptTarget = {}));
	    var ScriptTarget = ts.ScriptTarget;
	    (function (LanguageVariant) {
	        LanguageVariant[LanguageVariant["Standard"] = 0] = "Standard";
	        LanguageVariant[LanguageVariant["JSX"] = 1] = "JSX";
	    })(ts.LanguageVariant || (ts.LanguageVariant = {}));
	    var LanguageVariant = ts.LanguageVariant;
	    /* @internal */
	    (function (DiagnosticStyle) {
	        DiagnosticStyle[DiagnosticStyle["Simple"] = 0] = "Simple";
	        DiagnosticStyle[DiagnosticStyle["Pretty"] = 1] = "Pretty";
	    })(ts.DiagnosticStyle || (ts.DiagnosticStyle = {}));
	    var DiagnosticStyle = ts.DiagnosticStyle;
	    /* @internal */
	    (function (CharacterCodes) {
	        CharacterCodes[CharacterCodes["nullCharacter"] = 0] = "nullCharacter";
	        CharacterCodes[CharacterCodes["maxAsciiCharacter"] = 127] = "maxAsciiCharacter";
	        CharacterCodes[CharacterCodes["lineFeed"] = 10] = "lineFeed";
	        CharacterCodes[CharacterCodes["carriageReturn"] = 13] = "carriageReturn";
	        CharacterCodes[CharacterCodes["lineSeparator"] = 8232] = "lineSeparator";
	        CharacterCodes[CharacterCodes["paragraphSeparator"] = 8233] = "paragraphSeparator";
	        CharacterCodes[CharacterCodes["nextLine"] = 133] = "nextLine";
	        // Unicode 3.0 space characters
	        CharacterCodes[CharacterCodes["space"] = 32] = "space";
	        CharacterCodes[CharacterCodes["nonBreakingSpace"] = 160] = "nonBreakingSpace";
	        CharacterCodes[CharacterCodes["enQuad"] = 8192] = "enQuad";
	        CharacterCodes[CharacterCodes["emQuad"] = 8193] = "emQuad";
	        CharacterCodes[CharacterCodes["enSpace"] = 8194] = "enSpace";
	        CharacterCodes[CharacterCodes["emSpace"] = 8195] = "emSpace";
	        CharacterCodes[CharacterCodes["threePerEmSpace"] = 8196] = "threePerEmSpace";
	        CharacterCodes[CharacterCodes["fourPerEmSpace"] = 8197] = "fourPerEmSpace";
	        CharacterCodes[CharacterCodes["sixPerEmSpace"] = 8198] = "sixPerEmSpace";
	        CharacterCodes[CharacterCodes["figureSpace"] = 8199] = "figureSpace";
	        CharacterCodes[CharacterCodes["punctuationSpace"] = 8200] = "punctuationSpace";
	        CharacterCodes[CharacterCodes["thinSpace"] = 8201] = "thinSpace";
	        CharacterCodes[CharacterCodes["hairSpace"] = 8202] = "hairSpace";
	        CharacterCodes[CharacterCodes["zeroWidthSpace"] = 8203] = "zeroWidthSpace";
	        CharacterCodes[CharacterCodes["narrowNoBreakSpace"] = 8239] = "narrowNoBreakSpace";
	        CharacterCodes[CharacterCodes["ideographicSpace"] = 12288] = "ideographicSpace";
	        CharacterCodes[CharacterCodes["mathematicalSpace"] = 8287] = "mathematicalSpace";
	        CharacterCodes[CharacterCodes["ogham"] = 5760] = "ogham";
	        CharacterCodes[CharacterCodes["_"] = 95] = "_";
	        CharacterCodes[CharacterCodes["$"] = 36] = "$";
	        CharacterCodes[CharacterCodes["_0"] = 48] = "_0";
	        CharacterCodes[CharacterCodes["_1"] = 49] = "_1";
	        CharacterCodes[CharacterCodes["_2"] = 50] = "_2";
	        CharacterCodes[CharacterCodes["_3"] = 51] = "_3";
	        CharacterCodes[CharacterCodes["_4"] = 52] = "_4";
	        CharacterCodes[CharacterCodes["_5"] = 53] = "_5";
	        CharacterCodes[CharacterCodes["_6"] = 54] = "_6";
	        CharacterCodes[CharacterCodes["_7"] = 55] = "_7";
	        CharacterCodes[CharacterCodes["_8"] = 56] = "_8";
	        CharacterCodes[CharacterCodes["_9"] = 57] = "_9";
	        CharacterCodes[CharacterCodes["a"] = 97] = "a";
	        CharacterCodes[CharacterCodes["b"] = 98] = "b";
	        CharacterCodes[CharacterCodes["c"] = 99] = "c";
	        CharacterCodes[CharacterCodes["d"] = 100] = "d";
	        CharacterCodes[CharacterCodes["e"] = 101] = "e";
	        CharacterCodes[CharacterCodes["f"] = 102] = "f";
	        CharacterCodes[CharacterCodes["g"] = 103] = "g";
	        CharacterCodes[CharacterCodes["h"] = 104] = "h";
	        CharacterCodes[CharacterCodes["i"] = 105] = "i";
	        CharacterCodes[CharacterCodes["j"] = 106] = "j";
	        CharacterCodes[CharacterCodes["k"] = 107] = "k";
	        CharacterCodes[CharacterCodes["l"] = 108] = "l";
	        CharacterCodes[CharacterCodes["m"] = 109] = "m";
	        CharacterCodes[CharacterCodes["n"] = 110] = "n";
	        CharacterCodes[CharacterCodes["o"] = 111] = "o";
	        CharacterCodes[CharacterCodes["p"] = 112] = "p";
	        CharacterCodes[CharacterCodes["q"] = 113] = "q";
	        CharacterCodes[CharacterCodes["r"] = 114] = "r";
	        CharacterCodes[CharacterCodes["s"] = 115] = "s";
	        CharacterCodes[CharacterCodes["t"] = 116] = "t";
	        CharacterCodes[CharacterCodes["u"] = 117] = "u";
	        CharacterCodes[CharacterCodes["v"] = 118] = "v";
	        CharacterCodes[CharacterCodes["w"] = 119] = "w";
	        CharacterCodes[CharacterCodes["x"] = 120] = "x";
	        CharacterCodes[CharacterCodes["y"] = 121] = "y";
	        CharacterCodes[CharacterCodes["z"] = 122] = "z";
	        CharacterCodes[CharacterCodes["A"] = 65] = "A";
	        CharacterCodes[CharacterCodes["B"] = 66] = "B";
	        CharacterCodes[CharacterCodes["C"] = 67] = "C";
	        CharacterCodes[CharacterCodes["D"] = 68] = "D";
	        CharacterCodes[CharacterCodes["E"] = 69] = "E";
	        CharacterCodes[CharacterCodes["F"] = 70] = "F";
	        CharacterCodes[CharacterCodes["G"] = 71] = "G";
	        CharacterCodes[CharacterCodes["H"] = 72] = "H";
	        CharacterCodes[CharacterCodes["I"] = 73] = "I";
	        CharacterCodes[CharacterCodes["J"] = 74] = "J";
	        CharacterCodes[CharacterCodes["K"] = 75] = "K";
	        CharacterCodes[CharacterCodes["L"] = 76] = "L";
	        CharacterCodes[CharacterCodes["M"] = 77] = "M";
	        CharacterCodes[CharacterCodes["N"] = 78] = "N";
	        CharacterCodes[CharacterCodes["O"] = 79] = "O";
	        CharacterCodes[CharacterCodes["P"] = 80] = "P";
	        CharacterCodes[CharacterCodes["Q"] = 81] = "Q";
	        CharacterCodes[CharacterCodes["R"] = 82] = "R";
	        CharacterCodes[CharacterCodes["S"] = 83] = "S";
	        CharacterCodes[CharacterCodes["T"] = 84] = "T";
	        CharacterCodes[CharacterCodes["U"] = 85] = "U";
	        CharacterCodes[CharacterCodes["V"] = 86] = "V";
	        CharacterCodes[CharacterCodes["W"] = 87] = "W";
	        CharacterCodes[CharacterCodes["X"] = 88] = "X";
	        CharacterCodes[CharacterCodes["Y"] = 89] = "Y";
	        CharacterCodes[CharacterCodes["Z"] = 90] = "Z";
	        CharacterCodes[CharacterCodes["ampersand"] = 38] = "ampersand";
	        CharacterCodes[CharacterCodes["asterisk"] = 42] = "asterisk";
	        CharacterCodes[CharacterCodes["at"] = 64] = "at";
	        CharacterCodes[CharacterCodes["backslash"] = 92] = "backslash";
	        CharacterCodes[CharacterCodes["backtick"] = 96] = "backtick";
	        CharacterCodes[CharacterCodes["bar"] = 124] = "bar";
	        CharacterCodes[CharacterCodes["caret"] = 94] = "caret";
	        CharacterCodes[CharacterCodes["closeBrace"] = 125] = "closeBrace";
	        CharacterCodes[CharacterCodes["closeBracket"] = 93] = "closeBracket";
	        CharacterCodes[CharacterCodes["closeParen"] = 41] = "closeParen";
	        CharacterCodes[CharacterCodes["colon"] = 58] = "colon";
	        CharacterCodes[CharacterCodes["comma"] = 44] = "comma";
	        CharacterCodes[CharacterCodes["dot"] = 46] = "dot";
	        CharacterCodes[CharacterCodes["doubleQuote"] = 34] = "doubleQuote";
	        CharacterCodes[CharacterCodes["equals"] = 61] = "equals";
	        CharacterCodes[CharacterCodes["exclamation"] = 33] = "exclamation";
	        CharacterCodes[CharacterCodes["greaterThan"] = 62] = "greaterThan";
	        CharacterCodes[CharacterCodes["hash"] = 35] = "hash";
	        CharacterCodes[CharacterCodes["lessThan"] = 60] = "lessThan";
	        CharacterCodes[CharacterCodes["minus"] = 45] = "minus";
	        CharacterCodes[CharacterCodes["openBrace"] = 123] = "openBrace";
	        CharacterCodes[CharacterCodes["openBracket"] = 91] = "openBracket";
	        CharacterCodes[CharacterCodes["openParen"] = 40] = "openParen";
	        CharacterCodes[CharacterCodes["percent"] = 37] = "percent";
	        CharacterCodes[CharacterCodes["plus"] = 43] = "plus";
	        CharacterCodes[CharacterCodes["question"] = 63] = "question";
	        CharacterCodes[CharacterCodes["semicolon"] = 59] = "semicolon";
	        CharacterCodes[CharacterCodes["singleQuote"] = 39] = "singleQuote";
	        CharacterCodes[CharacterCodes["slash"] = 47] = "slash";
	        CharacterCodes[CharacterCodes["tilde"] = 126] = "tilde";
	        CharacterCodes[CharacterCodes["backspace"] = 8] = "backspace";
	        CharacterCodes[CharacterCodes["formFeed"] = 12] = "formFeed";
	        CharacterCodes[CharacterCodes["byteOrderMark"] = 65279] = "byteOrderMark";
	        CharacterCodes[CharacterCodes["tab"] = 9] = "tab";
	        CharacterCodes[CharacterCodes["verticalTab"] = 11] = "verticalTab";
	    })(ts.CharacterCodes || (ts.CharacterCodes = {}));
	    var CharacterCodes = ts.CharacterCodes;
	})(ts || (ts = {}));
	/// <reference path="types.ts"/>
	/* @internal */
	var ts;
	(function (ts) {
	    /**
	     * Ternary values are defined such that
	     * x & y is False if either x or y is False.
	     * x & y is Maybe if either x or y is Maybe, but neither x or y is False.
	     * x & y is True if both x and y are True.
	     * x | y is False if both x and y are False.
	     * x | y is Maybe if either x or y is Maybe, but neither x or y is True.
	     * x | y is True if either x or y is True.
	     */
	    (function (Ternary) {
	        Ternary[Ternary["False"] = 0] = "False";
	        Ternary[Ternary["Maybe"] = 1] = "Maybe";
	        Ternary[Ternary["True"] = -1] = "True";
	    })(ts.Ternary || (ts.Ternary = {}));
	    var Ternary = ts.Ternary;
	    function createFileMap(keyMapper) {
	        var files = {};
	        return {
	            get: get,
	            set: set,
	            contains: contains,
	            remove: remove,
	            forEachValue: forEachValueInMap,
	            clear: clear
	        };
	        function forEachValueInMap(f) {
	            for (var key in files) {
	                f(key, files[key]);
	            }
	        }
	        // path should already be well-formed so it does not need to be normalized
	        function get(path) {
	            return files[toKey(path)];
	        }
	        function set(path, value) {
	            files[toKey(path)] = value;
	        }
	        function contains(path) {
	            return hasProperty(files, toKey(path));
	        }
	        function remove(path) {
	            var key = toKey(path);
	            delete files[key];
	        }
	        function clear() {
	            files = {};
	        }
	        function toKey(path) {
	            return keyMapper ? keyMapper(path) : path;
	        }
	    }
	    ts.createFileMap = createFileMap;
	    function toPath(fileName, basePath, getCanonicalFileName) {
	        var nonCanonicalizedPath = isRootedDiskPath(fileName)
	            ? normalizePath(fileName)
	            : getNormalizedAbsolutePath(fileName, basePath);
	        return getCanonicalFileName(nonCanonicalizedPath);
	    }
	    ts.toPath = toPath;
	    (function (Comparison) {
	        Comparison[Comparison["LessThan"] = -1] = "LessThan";
	        Comparison[Comparison["EqualTo"] = 0] = "EqualTo";
	        Comparison[Comparison["GreaterThan"] = 1] = "GreaterThan";
	    })(ts.Comparison || (ts.Comparison = {}));
	    var Comparison = ts.Comparison;
	    /**
	     * Iterates through 'array' by index and performs the callback on each element of array until the callback
	     * returns a truthy value, then returns that value.
	     * If no such value is found, the callback is applied to each element of array and undefined is returned.
	     */
	    function forEach(array, callback) {
	        if (array) {
	            for (var i = 0, len = array.length; i < len; i++) {
	                var result = callback(array[i], i);
	                if (result) {
	                    return result;
	                }
	            }
	        }
	        return undefined;
	    }
	    ts.forEach = forEach;
	    function contains(array, value) {
	        if (array) {
	            for (var _i = 0, array_1 = array; _i < array_1.length; _i++) {
	                var v = array_1[_i];
	                if (v === value) {
	                    return true;
	                }
	            }
	        }
	        return false;
	    }
	    ts.contains = contains;
	    function indexOf(array, value) {
	        if (array) {
	            for (var i = 0, len = array.length; i < len; i++) {
	                if (array[i] === value) {
	                    return i;
	                }
	            }
	        }
	        return -1;
	    }
	    ts.indexOf = indexOf;
	    function countWhere(array, predicate) {
	        var count = 0;
	        if (array) {
	            for (var _i = 0, array_2 = array; _i < array_2.length; _i++) {
	                var v = array_2[_i];
	                if (predicate(v)) {
	                    count++;
	                }
	            }
	        }
	        return count;
	    }
	    ts.countWhere = countWhere;
	    function filter(array, f) {
	        var result;
	        if (array) {
	            result = [];
	            for (var _i = 0, array_3 = array; _i < array_3.length; _i++) {
	                var item = array_3[_i];
	                if (f(item)) {
	                    result.push(item);
	                }
	            }
	        }
	        return result;
	    }
	    ts.filter = filter;
	    function map(array, f) {
	        var result;
	        if (array) {
	            result = [];
	            for (var _i = 0, array_4 = array; _i < array_4.length; _i++) {
	                var v = array_4[_i];
	                result.push(f(v));
	            }
	        }
	        return result;
	    }
	    ts.map = map;
	    function concatenate(array1, array2) {
	        if (!array2 || !array2.length)
	            return array1;
	        if (!array1 || !array1.length)
	            return array2;
	        return array1.concat(array2);
	    }
	    ts.concatenate = concatenate;
	    function deduplicate(array) {
	        var result;
	        if (array) {
	            result = [];
	            for (var _i = 0, array_5 = array; _i < array_5.length; _i++) {
	                var item = array_5[_i];
	                if (!contains(result, item)) {
	                    result.push(item);
	                }
	            }
	        }
	        return result;
	    }
	    ts.deduplicate = deduplicate;
	    function sum(array, prop) {
	        var result = 0;
	        for (var _i = 0, array_6 = array; _i < array_6.length; _i++) {
	            var v = array_6[_i];
	            result += v[prop];
	        }
	        return result;
	    }
	    ts.sum = sum;
	    function addRange(to, from) {
	        if (to && from) {
	            for (var _i = 0, from_1 = from; _i < from_1.length; _i++) {
	                var v = from_1[_i];
	                to.push(v);
	            }
	        }
	    }
	    ts.addRange = addRange;
	    function rangeEquals(array1, array2, pos, end) {
	        while (pos < end) {
	            if (array1[pos] !== array2[pos]) {
	                return false;
	            }
	            pos++;
	        }
	        return true;
	    }
	    ts.rangeEquals = rangeEquals;
	    /**
	     * Returns the last element of an array if non-empty, undefined otherwise.
	     */
	    function lastOrUndefined(array) {
	        if (array.length === 0) {
	            return undefined;
	        }
	        return array[array.length - 1];
	    }
	    ts.lastOrUndefined = lastOrUndefined;
	    /**
	     * Performs a binary search, finding the index at which 'value' occurs in 'array'.
	     * If no such index is found, returns the 2's-complement of first index at which
	     * number[index] exceeds number.
	     * @param array A sorted array whose first element must be no larger than number
	     * @param number The value to be searched for in the array.
	     */
	    function binarySearch(array, value) {
	        var low = 0;
	        var high = array.length - 1;
	        while (low <= high) {
	            var middle = low + ((high - low) >> 1);
	            var midValue = array[middle];
	            if (midValue === value) {
	                return middle;
	            }
	            else if (midValue > value) {
	                high = middle - 1;
	            }
	            else {
	                low = middle + 1;
	            }
	        }
	        return ~low;
	    }
	    ts.binarySearch = binarySearch;
	    function reduceLeft(array, f, initial) {
	        if (array) {
	            var count = array.length;
	            if (count > 0) {
	                var pos = 0;
	                var result = arguments.length <= 2 ? array[pos] : initial;
	                pos++;
	                while (pos < count) {
	                    result = f(result, array[pos]);
	                    pos++;
	                }
	                return result;
	            }
	        }
	        return initial;
	    }
	    ts.reduceLeft = reduceLeft;
	    function reduceRight(array, f, initial) {
	        if (array) {
	            var pos = array.length - 1;
	            if (pos >= 0) {
	                var result = arguments.length <= 2 ? array[pos] : initial;
	                pos--;
	                while (pos >= 0) {
	                    result = f(result, array[pos]);
	                    pos--;
	                }
	                return result;
	            }
	        }
	        return initial;
	    }
	    ts.reduceRight = reduceRight;
	    var hasOwnProperty = Object.prototype.hasOwnProperty;
	    function hasProperty(map, key) {
	        return hasOwnProperty.call(map, key);
	    }
	    ts.hasProperty = hasProperty;
	    function getProperty(map, key) {
	        return hasOwnProperty.call(map, key) ? map[key] : undefined;
	    }
	    ts.getProperty = getProperty;
	    function isEmpty(map) {
	        for (var id in map) {
	            if (hasProperty(map, id)) {
	                return false;
	            }
	        }
	        return true;
	    }
	    ts.isEmpty = isEmpty;
	    function clone(object) {
	        var result = {};
	        for (var id in object) {
	            result[id] = object[id];
	        }
	        return result;
	    }
	    ts.clone = clone;
	    function extend(first, second) {
	        var result = {};
	        for (var id in first) {
	            result[id] = first[id];
	        }
	        for (var id in second) {
	            if (!hasProperty(result, id)) {
	                result[id] = second[id];
	            }
	        }
	        return result;
	    }
	    ts.extend = extend;
	    function forEachValue(map, callback) {
	        var result;
	        for (var id in map) {
	            if (result = callback(map[id]))
	                break;
	        }
	        return result;
	    }
	    ts.forEachValue = forEachValue;
	    function forEachKey(map, callback) {
	        var result;
	        for (var id in map) {
	            if (result = callback(id))
	                break;
	        }
	        return result;
	    }
	    ts.forEachKey = forEachKey;
	    function lookUp(map, key) {
	        return hasProperty(map, key) ? map[key] : undefined;
	    }
	    ts.lookUp = lookUp;
	    function copyMap(source, target) {
	        for (var p in source) {
	            target[p] = source[p];
	        }
	    }
	    ts.copyMap = copyMap;
	    /**
	     * Creates a map from the elements of an array.
	     *
	     * @param array the array of input elements.
	     * @param makeKey a function that produces a key for a given element.
	     *
	     * This function makes no effort to avoid collisions; if any two elements produce
	     * the same key with the given 'makeKey' function, then the element with the higher
	     * index in the array will be the one associated with the produced key.
	     */
	    function arrayToMap(array, makeKey) {
	        var result = {};
	        forEach(array, function (value) {
	            result[makeKey(value)] = value;
	        });
	        return result;
	    }
	    ts.arrayToMap = arrayToMap;
	    /**
	     * Reduce the properties of a map.
	     *
	     * @param map The map to reduce
	     * @param callback An aggregation function that is called for each entry in the map
	     * @param initial The initial value for the reduction.
	     */
	    function reduceProperties(map, callback, initial) {
	        var result = initial;
	        if (map) {
	            for (var key in map) {
	                if (hasProperty(map, key)) {
	                    result = callback(result, map[key], String(key));
	                }
	            }
	        }
	        return result;
	    }
	    ts.reduceProperties = reduceProperties;
	    /**
	     * Tests whether a value is an array.
	     */
	    function isArray(value) {
	        return Array.isArray ? Array.isArray(value) : value instanceof Array;
	    }
	    ts.isArray = isArray;
	    function memoize(callback) {
	        var value;
	        return function () {
	            if (callback) {
	                value = callback();
	                callback = undefined;
	            }
	            return value;
	        };
	    }
	    ts.memoize = memoize;
	    function formatStringFromArgs(text, args, baseIndex) {
	        baseIndex = baseIndex || 0;
	        return text.replace(/{(\d+)}/g, function (match, index) { return args[+index + baseIndex]; });
	    }
	    ts.localizedDiagnosticMessages = undefined;
	    function getLocaleSpecificMessage(message) {
	        return ts.localizedDiagnosticMessages && ts.localizedDiagnosticMessages[message.key]
	            ? ts.localizedDiagnosticMessages[message.key]
	            : message.message;
	    }
	    ts.getLocaleSpecificMessage = getLocaleSpecificMessage;
	    function createFileDiagnostic(file, start, length, message) {
	        var end = start + length;
	        Debug.assert(start >= 0, "start must be non-negative, is " + start);
	        Debug.assert(length >= 0, "length must be non-negative, is " + length);
	        if (file) {
	            Debug.assert(start <= file.text.length, "start must be within the bounds of the file. " + start + " > " + file.text.length);
	            Debug.assert(end <= file.text.length, "end must be the bounds of the file. " + end + " > " + file.text.length);
	        }
	        var text = getLocaleSpecificMessage(message);
	        if (arguments.length > 4) {
	            text = formatStringFromArgs(text, arguments, 4);
	        }
	        return {
	            file: file,
	            start: start,
	            length: length,
	            messageText: text,
	            category: message.category,
	            code: message.code
	        };
	    }
	    ts.createFileDiagnostic = createFileDiagnostic;
	    function createCompilerDiagnostic(message) {
	        var text = getLocaleSpecificMessage(message);
	        if (arguments.length > 1) {
	            text = formatStringFromArgs(text, arguments, 1);
	        }
	        return {
	            file: undefined,
	            start: undefined,
	            length: undefined,
	            messageText: text,
	            category: message.category,
	            code: message.code
	        };
	    }
	    ts.createCompilerDiagnostic = createCompilerDiagnostic;
	    function chainDiagnosticMessages(details, message) {
	        var text = getLocaleSpecificMessage(message);
	        if (arguments.length > 2) {
	            text = formatStringFromArgs(text, arguments, 2);
	        }
	        return {
	            messageText: text,
	            category: message.category,
	            code: message.code,
	            next: details
	        };
	    }
	    ts.chainDiagnosticMessages = chainDiagnosticMessages;
	    function concatenateDiagnosticMessageChains(headChain, tailChain) {
	        var lastChain = headChain;
	        while (lastChain.next) {
	            lastChain = lastChain.next;
	        }
	        lastChain.next = tailChain;
	        return headChain;
	    }
	    ts.concatenateDiagnosticMessageChains = concatenateDiagnosticMessageChains;
	    function compareValues(a, b) {
	        if (a === b)
	            return 0 /* EqualTo */;
	        if (a === undefined)
	            return -1 /* LessThan */;
	        if (b === undefined)
	            return 1 /* GreaterThan */;
	        return a < b ? -1 /* LessThan */ : 1 /* GreaterThan */;
	    }
	    ts.compareValues = compareValues;
	    function getDiagnosticFileName(diagnostic) {
	        return diagnostic.file ? diagnostic.file.fileName : undefined;
	    }
	    function compareDiagnostics(d1, d2) {
	        return compareValues(getDiagnosticFileName(d1), getDiagnosticFileName(d2)) ||
	            compareValues(d1.start, d2.start) ||
	            compareValues(d1.length, d2.length) ||
	            compareValues(d1.code, d2.code) ||
	            compareMessageText(d1.messageText, d2.messageText) ||
	            0 /* EqualTo */;
	    }
	    ts.compareDiagnostics = compareDiagnostics;
	    function compareMessageText(text1, text2) {
	        while (text1 && text2) {
	            // We still have both chains.
	            var string1 = typeof text1 === "string" ? text1 : text1.messageText;
	            var string2 = typeof text2 === "string" ? text2 : text2.messageText;
	            var res = compareValues(string1, string2);
	            if (res) {
	                return res;
	            }
	            text1 = typeof text1 === "string" ? undefined : text1.next;
	            text2 = typeof text2 === "string" ? undefined : text2.next;
	        }
	        if (!text1 && !text2) {
	            // if the chains are done, then these messages are the same.
	            return 0 /* EqualTo */;
	        }
	        // We still have one chain remaining.  The shorter chain should come first.
	        return text1 ? 1 /* GreaterThan */ : -1 /* LessThan */;
	    }
	    function sortAndDeduplicateDiagnostics(diagnostics) {
	        return deduplicateSortedDiagnostics(diagnostics.sort(compareDiagnostics));
	    }
	    ts.sortAndDeduplicateDiagnostics = sortAndDeduplicateDiagnostics;
	    function deduplicateSortedDiagnostics(diagnostics) {
	        if (diagnostics.length < 2) {
	            return diagnostics;
	        }
	        var newDiagnostics = [diagnostics[0]];
	        var previousDiagnostic = diagnostics[0];
	        for (var i = 1; i < diagnostics.length; i++) {
	            var currentDiagnostic = diagnostics[i];
	            var isDupe = compareDiagnostics(currentDiagnostic, previousDiagnostic) === 0 /* EqualTo */;
	            if (!isDupe) {
	                newDiagnostics.push(currentDiagnostic);
	                previousDiagnostic = currentDiagnostic;
	            }
	        }
	        return newDiagnostics;
	    }
	    ts.deduplicateSortedDiagnostics = deduplicateSortedDiagnostics;
	    function normalizeSlashes(path) {
	        return path.replace(/\\/g, "/");
	    }
	    ts.normalizeSlashes = normalizeSlashes;
	    // Returns length of path root (i.e. length of "/", "x:/", "//server/share/, file:///user/files")
	    function getRootLength(path) {
	        if (path.charCodeAt(0) === 47 /* slash */) {
	            if (path.charCodeAt(1) !== 47 /* slash */)
	                return 1;
	            var p1 = path.indexOf("/", 2);
	            if (p1 < 0)
	                return 2;
	            var p2 = path.indexOf("/", p1 + 1);
	            if (p2 < 0)
	                return p1 + 1;
	            return p2 + 1;
	        }
	        if (path.charCodeAt(1) === 58 /* colon */) {
	            if (path.charCodeAt(2) === 47 /* slash */)
	                return 3;
	            return 2;
	        }
	        // Per RFC 1738 'file' URI schema has the shape file://<host>/<path>
	        // if <host> is omitted then it is assumed that host value is 'localhost',
	        // however slash after the omitted <host> is not removed.
	        // file:///folder1/file1 - this is a correct URI
	        // file://folder2/file2 - this is an incorrect URI
	        if (path.lastIndexOf("file:///", 0) === 0) {
	            return "file:///".length;
	        }
	        var idx = path.indexOf("://");
	        if (idx !== -1) {
	            return idx + "://".length;
	        }
	        return 0;
	    }
	    ts.getRootLength = getRootLength;
	    ts.directorySeparator = "/";
	    function getNormalizedParts(normalizedSlashedPath, rootLength) {
	        var parts = normalizedSlashedPath.substr(rootLength).split(ts.directorySeparator);
	        var normalized = [];
	        for (var _i = 0, parts_1 = parts; _i < parts_1.length; _i++) {
	            var part = parts_1[_i];
	            if (part !== ".") {
	                if (part === ".." && normalized.length > 0 && lastOrUndefined(normalized) !== "..") {
	                    normalized.pop();
	                }
	                else {
	                    // A part may be an empty string (which is 'falsy') if the path had consecutive slashes,
	                    // e.g. "path//file.ts".  Drop these before re-joining the parts.
	                    if (part) {
	                        normalized.push(part);
	                    }
	                }
	            }
	        }
	        return normalized;
	    }
	    function normalizePath(path) {
	        path = normalizeSlashes(path);
	        var rootLength = getRootLength(path);
	        var normalized = getNormalizedParts(path, rootLength);
	        return path.substr(0, rootLength) + normalized.join(ts.directorySeparator);
	    }
	    ts.normalizePath = normalizePath;
	    function getDirectoryPath(path) {
	        return path.substr(0, Math.max(getRootLength(path), path.lastIndexOf(ts.directorySeparator)));
	    }
	    ts.getDirectoryPath = getDirectoryPath;
	    function isUrl(path) {
	        return path && !isRootedDiskPath(path) && path.indexOf("://") !== -1;
	    }
	    ts.isUrl = isUrl;
	    function isRootedDiskPath(path) {
	        return getRootLength(path) !== 0;
	    }
	    ts.isRootedDiskPath = isRootedDiskPath;
	    function normalizedPathComponents(path, rootLength) {
	        var normalizedParts = getNormalizedParts(path, rootLength);
	        return [path.substr(0, rootLength)].concat(normalizedParts);
	    }
	    function getNormalizedPathComponents(path, currentDirectory) {
	        path = normalizeSlashes(path);
	        var rootLength = getRootLength(path);
	        if (rootLength === 0) {
	            // If the path is not rooted it is relative to current directory
	            path = combinePaths(normalizeSlashes(currentDirectory), path);
	            rootLength = getRootLength(path);
	        }
	        return normalizedPathComponents(path, rootLength);
	    }
	    ts.getNormalizedPathComponents = getNormalizedPathComponents;
	    function getNormalizedAbsolutePath(fileName, currentDirectory) {
	        return getNormalizedPathFromPathComponents(getNormalizedPathComponents(fileName, currentDirectory));
	    }
	    ts.getNormalizedAbsolutePath = getNormalizedAbsolutePath;
	    function getNormalizedPathFromPathComponents(pathComponents) {
	        if (pathComponents && pathComponents.length) {
	            return pathComponents[0] + pathComponents.slice(1).join(ts.directorySeparator);
	        }
	    }
	    ts.getNormalizedPathFromPathComponents = getNormalizedPathFromPathComponents;
	    function getNormalizedPathComponentsOfUrl(url) {
	        // Get root length of http://www.website.com/folder1/foler2/
	        // In this example the root is:  http://www.website.com/
	        // normalized path components should be ["http://www.website.com/", "folder1", "folder2"]
	        var urlLength = url.length;
	        // Initial root length is http:// part
	        var rootLength = url.indexOf("://") + "://".length;
	        while (rootLength < urlLength) {
	            // Consume all immediate slashes in the protocol
	            // eg.initial rootlength is just file:// but it needs to consume another "/" in file:///
	            if (url.charCodeAt(rootLength) === 47 /* slash */) {
	                rootLength++;
	            }
	            else {
	                // non slash character means we continue proceeding to next component of root search
	                break;
	            }
	        }
	        // there are no parts after http:// just return current string as the pathComponent
	        if (rootLength === urlLength) {
	            return [url];
	        }
	        // Find the index of "/" after website.com so the root can be http://www.website.com/ (from existing http://)
	        var indexOfNextSlash = url.indexOf(ts.directorySeparator, rootLength);
	        if (indexOfNextSlash !== -1) {
	            // Found the "/" after the website.com so the root is length of http://www.website.com/
	            // and get components afetr the root normally like any other folder components
	            rootLength = indexOfNextSlash + 1;
	            return normalizedPathComponents(url, rootLength);
	        }
	        else {
	            // Can't find the host assume the rest of the string as component
	            // but make sure we append "/"  to it as root is not joined using "/"
	            // eg. if url passed in was http://website.com we want to use root as [http://website.com/]
	            // so that other path manipulations will be correct and it can be merged with relative paths correctly
	            return [url + ts.directorySeparator];
	        }
	    }
	    function getNormalizedPathOrUrlComponents(pathOrUrl, currentDirectory) {
	        if (isUrl(pathOrUrl)) {
	            return getNormalizedPathComponentsOfUrl(pathOrUrl);
	        }
	        else {
	            return getNormalizedPathComponents(pathOrUrl, currentDirectory);
	        }
	    }
	    function getRelativePathToDirectoryOrUrl(directoryPathOrUrl, relativeOrAbsolutePath, currentDirectory, getCanonicalFileName, isAbsolutePathAnUrl) {
	        var pathComponents = getNormalizedPathOrUrlComponents(relativeOrAbsolutePath, currentDirectory);
	        var directoryComponents = getNormalizedPathOrUrlComponents(directoryPathOrUrl, currentDirectory);
	        if (directoryComponents.length > 1 && lastOrUndefined(directoryComponents) === "") {
	            // If the directory path given was of type test/cases/ then we really need components of directory to be only till its name
	            // that is  ["test", "cases", ""] needs to be actually ["test", "cases"]
	            directoryComponents.length--;
	        }
	        // Find the component that differs
	        var joinStartIndex;
	        for (joinStartIndex = 0; joinStartIndex < pathComponents.length && joinStartIndex < directoryComponents.length; joinStartIndex++) {
	            if (getCanonicalFileName(directoryComponents[joinStartIndex]) !== getCanonicalFileName(pathComponents[joinStartIndex])) {
	                break;
	            }
	        }
	        // Get the relative path
	        if (joinStartIndex) {
	            var relativePath = "";
	            var relativePathComponents = pathComponents.slice(joinStartIndex, pathComponents.length);
	            for (; joinStartIndex < directoryComponents.length; joinStartIndex++) {
	                if (directoryComponents[joinStartIndex] !== "") {
	                    relativePath = relativePath + ".." + ts.directorySeparator;
	                }
	            }
	            return relativePath + relativePathComponents.join(ts.directorySeparator);
	        }
	        // Cant find the relative path, get the absolute path
	        var absolutePath = getNormalizedPathFromPathComponents(pathComponents);
	        if (isAbsolutePathAnUrl && isRootedDiskPath(absolutePath)) {
	            absolutePath = "file:///" + absolutePath;
	        }
	        return absolutePath;
	    }
	    ts.getRelativePathToDirectoryOrUrl = getRelativePathToDirectoryOrUrl;
	    function getBaseFileName(path) {
	        if (path === undefined) {
	            return undefined;
	        }
	        var i = path.lastIndexOf(ts.directorySeparator);
	        return i < 0 ? path : path.substring(i + 1);
	    }
	    ts.getBaseFileName = getBaseFileName;
	    function combinePaths(path1, path2) {
	        if (!(path1 && path1.length))
	            return path2;
	        if (!(path2 && path2.length))
	            return path1;
	        if (getRootLength(path2) !== 0)
	            return path2;
	        if (path1.charAt(path1.length - 1) === ts.directorySeparator)
	            return path1 + path2;
	        return path1 + ts.directorySeparator + path2;
	    }
	    ts.combinePaths = combinePaths;
	    function fileExtensionIs(path, extension) {
	        var pathLen = path.length;
	        var extLen = extension.length;
	        return pathLen > extLen && path.substr(pathLen - extLen, extLen) === extension;
	    }
	    ts.fileExtensionIs = fileExtensionIs;
	    /**
	     *  List of supported extensions in order of file resolution precedence.
	     */
	    ts.supportedTypeScriptExtensions = [".ts", ".tsx", ".d.ts"];
	    ts.supportedJavascriptExtensions = [".js", ".jsx"];
	    var allSupportedExtensions = ts.supportedTypeScriptExtensions.concat(ts.supportedJavascriptExtensions);
	    function getSupportedExtensions(options) {
	        return options && options.allowJs ? allSupportedExtensions : ts.supportedTypeScriptExtensions;
	    }
	    ts.getSupportedExtensions = getSupportedExtensions;
	    function isSupportedSourceFileName(fileName, compilerOptions) {
	        if (!fileName) {
	            return false;
	        }
	        for (var _i = 0, _a = getSupportedExtensions(compilerOptions); _i < _a.length; _i++) {
	            var extension = _a[_i];
	            if (fileExtensionIs(fileName, extension)) {
	                return true;
	            }
	        }
	        return false;
	    }
	    ts.isSupportedSourceFileName = isSupportedSourceFileName;
	    var extensionsToRemove = [".d.ts", ".ts", ".js", ".tsx", ".jsx"];
	    function removeFileExtension(path) {
	        for (var _i = 0, extensionsToRemove_1 = extensionsToRemove; _i < extensionsToRemove_1.length; _i++) {
	            var ext = extensionsToRemove_1[_i];
	            if (fileExtensionIs(path, ext)) {
	                return path.substr(0, path.length - ext.length);
	            }
	        }
	        return path;
	    }
	    ts.removeFileExtension = removeFileExtension;
	    function Symbol(flags, name) {
	        this.flags = flags;
	        this.name = name;
	        this.declarations = undefined;
	    }
	    function Type(checker, flags) {
	        this.flags = flags;
	    }
	    function Signature(checker) {
	    }
	    function Node(kind, pos, end) {
	        this.kind = kind;
	        this.pos = pos;
	        this.end = end;
	        this.flags = 0 /* None */;
	        this.parent = undefined;
	    }
	    ts.objectAllocator = {
	        getNodeConstructor: function () { return Node; },
	        getSourceFileConstructor: function () { return Node; },
	        getSymbolConstructor: function () { return Symbol; },
	        getTypeConstructor: function () { return Type; },
	        getSignatureConstructor: function () { return Signature; }
	    };
	    (function (AssertionLevel) {
	        AssertionLevel[AssertionLevel["None"] = 0] = "None";
	        AssertionLevel[AssertionLevel["Normal"] = 1] = "Normal";
	        AssertionLevel[AssertionLevel["Aggressive"] = 2] = "Aggressive";
	        AssertionLevel[AssertionLevel["VeryAggressive"] = 3] = "VeryAggressive";
	    })(ts.AssertionLevel || (ts.AssertionLevel = {}));
	    var AssertionLevel = ts.AssertionLevel;
	    var Debug;
	    (function (Debug) {
	        var currentAssertionLevel = 0 /* None */;
	        function shouldAssert(level) {
	            return currentAssertionLevel >= level;
	        }
	        Debug.shouldAssert = shouldAssert;
	        function assert(expression, message, verboseDebugInfo) {
	            if (!expression) {
	                var verboseDebugString = "";
	                if (verboseDebugInfo) {
	                    verboseDebugString = "\r\nVerbose Debug Information: " + verboseDebugInfo();
	                }
	                debugger;
	                throw new Error("Debug Failure. False expression: " + (message || "") + verboseDebugString);
	            }
	        }
	        Debug.assert = assert;
	        function fail(message) {
	            Debug.assert(/*expression*/ false, message);
	        }
	        Debug.fail = fail;
	    })(Debug = ts.Debug || (ts.Debug = {}));
	    function copyListRemovingItem(item, list) {
	        var copiedList = [];
	        for (var _i = 0, list_1 = list; _i < list_1.length; _i++) {
	            var e = list_1[_i];
	            if (e !== item) {
	                copiedList.push(e);
	            }
	        }
	        return copiedList;
	    }
	    ts.copyListRemovingItem = copyListRemovingItem;
	    function createGetCanonicalFileName(useCaseSensitivefileNames) {
	        return useCaseSensitivefileNames
	            ? (function (fileName) { return fileName; })
	            : (function (fileName) { return fileName.toLowerCase(); });
	    }
	    ts.createGetCanonicalFileName = createGetCanonicalFileName;
	})(ts || (ts = {}));
	/// <reference path="core.ts"/>
	var ts;
	(function (ts) {
	    ts.sys = (function () {
	        function getWScriptSystem() {
	            var fso = new ActiveXObject("Scripting.FileSystemObject");
	            var fileStream = new ActiveXObject("ADODB.Stream");
	            fileStream.Type = 2 /*text*/;
	            var binaryStream = new ActiveXObject("ADODB.Stream");
	            binaryStream.Type = 1 /*binary*/;
	            var args = [];
	            for (var i = 0; i < WScript.Arguments.length; i++) {
	                args[i] = WScript.Arguments.Item(i);
	            }
	            function readFile(fileName, encoding) {
	                if (!fso.FileExists(fileName)) {
	                    return undefined;
	                }
	                fileStream.Open();
	                try {
	                    if (encoding) {
	                        fileStream.Charset = encoding;
	                        fileStream.LoadFromFile(fileName);
	                    }
	                    else {
	                        // Load file and read the first two bytes into a string with no interpretation
	                        fileStream.Charset = "x-ansi";
	                        fileStream.LoadFromFile(fileName);
	                        var bom = fileStream.ReadText(2) || "";
	                        // Position must be at 0 before encoding can be changed
	                        fileStream.Position = 0;
	                        // [0xFF,0xFE] and [0xFE,0xFF] mean utf-16 (little or big endian), otherwise default to utf-8
	                        fileStream.Charset = bom.length >= 2 && (bom.charCodeAt(0) === 0xFF && bom.charCodeAt(1) === 0xFE || bom.charCodeAt(0) === 0xFE && bom.charCodeAt(1) === 0xFF) ? "unicode" : "utf-8";
	                    }
	                    // ReadText method always strips byte order mark from resulting string
	                    return fileStream.ReadText();
	                }
	                catch (e) {
	                    throw e;
	                }
	                finally {
	                    fileStream.Close();
	                }
	            }
	            function writeFile(fileName, data, writeByteOrderMark) {
	                fileStream.Open();
	                binaryStream.Open();
	                try {
	                    // Write characters in UTF-8 encoding
	                    fileStream.Charset = "utf-8";
	                    fileStream.WriteText(data);
	                    // If we don't want the BOM, then skip it by setting the starting location to 3 (size of BOM).
	                    // If not, start from position 0, as the BOM will be added automatically when charset==utf8.
	                    if (writeByteOrderMark) {
	                        fileStream.Position = 0;
	                    }
	                    else {
	                        fileStream.Position = 3;
	                    }
	                    fileStream.CopyTo(binaryStream);
	                    binaryStream.SaveToFile(fileName, 2 /*overwrite*/);
	                }
	                finally {
	                    binaryStream.Close();
	                    fileStream.Close();
	                }
	            }
	            function getCanonicalPath(path) {
	                return path.toLowerCase();
	            }
	            function getNames(collection) {
	                var result = [];
	                for (var e = new Enumerator(collection); !e.atEnd(); e.moveNext()) {
	                    result.push(e.item().Name);
	                }
	                return result.sort();
	            }
	            function readDirectory(path, extension, exclude) {
	                var result = [];
	                exclude = ts.map(exclude, function (s) { return getCanonicalPath(ts.combinePaths(path, s)); });
	                visitDirectory(path);
	                return result;
	                function visitDirectory(path) {
	                    var folder = fso.GetFolder(path || ".");
	                    var files = getNames(folder.files);
	                    for (var _i = 0, files_1 = files; _i < files_1.length; _i++) {
	                        var current = files_1[_i];
	                        var name_1 = ts.combinePaths(path, current);
	                        if ((!extension || ts.fileExtensionIs(name_1, extension)) && !ts.contains(exclude, getCanonicalPath(name_1))) {
	                            result.push(name_1);
	                        }
	                    }
	                    var subfolders = getNames(folder.subfolders);
	                    for (var _a = 0, subfolders_1 = subfolders; _a < subfolders_1.length; _a++) {
	                        var current = subfolders_1[_a];
	                        var name_2 = ts.combinePaths(path, current);
	                        if (!ts.contains(exclude, getCanonicalPath(name_2))) {
	                            visitDirectory(name_2);
	                        }
	                    }
	                }
	            }
	            return {
	                args: args,
	                newLine: "\r\n",
	                useCaseSensitiveFileNames: false,
	                write: function (s) {
	                    WScript.StdOut.Write(s);
	                },
	                readFile: readFile,
	                writeFile: writeFile,
	                resolvePath: function (path) {
	                    return fso.GetAbsolutePathName(path);
	                },
	                fileExists: function (path) {
	                    return fso.FileExists(path);
	                },
	                directoryExists: function (path) {
	                    return fso.FolderExists(path);
	                },
	                createDirectory: function (directoryName) {
	                    if (!this.directoryExists(directoryName)) {
	                        fso.CreateFolder(directoryName);
	                    }
	                },
	                getExecutingFilePath: function () {
	                    return WScript.ScriptFullName;
	                },
	                getCurrentDirectory: function () {
	                    return new ActiveXObject("WScript.Shell").CurrentDirectory;
	                },
	                readDirectory: readDirectory,
	                exit: function (exitCode) {
	                    try {
	                        WScript.Quit(exitCode);
	                    }
	                    catch (e) {
	                    }
	                }
	            };
	        }
	        function getNodeSystem() {
	            var _fs = __webpack_require__(36);
	            var _path = __webpack_require__(190);
	            var _os = __webpack_require__(191);
	            // average async stat takes about 30 microseconds
	            // set chunk size to do 30 files in < 1 millisecond
	            function createPollingWatchedFileSet(interval, chunkSize) {
	                if (interval === void 0) { interval = 2500; }
	                if (chunkSize === void 0) { chunkSize = 30; }
	                var watchedFiles = [];
	                var nextFileToCheck = 0;
	                var watchTimer;
	                function getModifiedTime(fileName) {
	                    return _fs.statSync(fileName).mtime;
	                }
	                function poll(checkedIndex) {
	                    var watchedFile = watchedFiles[checkedIndex];
	                    if (!watchedFile) {
	                        return;
	                    }
	                    _fs.stat(watchedFile.filePath, function (err, stats) {
	                        if (err) {
	                            watchedFile.callback(watchedFile.filePath);
	                        }
	                        else if (watchedFile.mtime.getTime() !== stats.mtime.getTime()) {
	                            watchedFile.mtime = getModifiedTime(watchedFile.filePath);
	                            watchedFile.callback(watchedFile.filePath, watchedFile.mtime.getTime() === 0);
	                        }
	                    });
	                }
	                // this implementation uses polling and
	                // stat due to inconsistencies of fs.watch
	                // and efficiency of stat on modern filesystems
	                function startWatchTimer() {
	                    watchTimer = setInterval(function () {
	                        var count = 0;
	                        var nextToCheck = nextFileToCheck;
	                        var firstCheck = -1;
	                        while ((count < chunkSize) && (nextToCheck !== firstCheck)) {
	                            poll(nextToCheck);
	                            if (firstCheck < 0) {
	                                firstCheck = nextToCheck;
	                            }
	                            nextToCheck++;
	                            if (nextToCheck === watchedFiles.length) {
	                                nextToCheck = 0;
	                            }
	                            count++;
	                        }
	                        nextFileToCheck = nextToCheck;
	                    }, interval);
	                }
	                function addFile(filePath, callback) {
	                    var file = {
	                        filePath: filePath,
	                        callback: callback,
	                        mtime: getModifiedTime(filePath)
	                    };
	                    watchedFiles.push(file);
	                    if (watchedFiles.length === 1) {
	                        startWatchTimer();
	                    }
	                    return file;
	                }
	                function removeFile(file) {
	                    watchedFiles = ts.copyListRemovingItem(file, watchedFiles);
	                }
	                return {
	                    getModifiedTime: getModifiedTime,
	                    poll: poll,
	                    startWatchTimer: startWatchTimer,
	                    addFile: addFile,
	                    removeFile: removeFile
	                };
	            }
	            function createWatchedFileSet() {
	                var dirWatchers = ts.createFileMap();
	                // One file can have multiple watchers
	                var fileWatcherCallbacks = ts.createFileMap();
	                return { addFile: addFile, removeFile: removeFile };
	                function reduceDirWatcherRefCountForFile(filePath) {
	                    var dirPath = ts.getDirectoryPath(filePath);
	                    if (dirWatchers.contains(dirPath)) {
	                        var watcher = dirWatchers.get(dirPath);
	                        watcher.referenceCount -= 1;
	                        if (watcher.referenceCount <= 0) {
	                            watcher.close();
	                            dirWatchers.remove(dirPath);
	                        }
	                    }
	                }
	                function addDirWatcher(dirPath) {
	                    if (dirWatchers.contains(dirPath)) {
	                        var watcher_1 = dirWatchers.get(dirPath);
	                        watcher_1.referenceCount += 1;
	                        return;
	                    }
	                    var watcher = _fs.watch(dirPath, { persistent: true }, function (eventName, relativeFileName) { return fileEventHandler(eventName, relativeFileName, dirPath); });
	                    watcher.referenceCount = 1;
	                    dirWatchers.set(dirPath, watcher);
	                    return;
	                }
	                function addFileWatcherCallback(filePath, callback) {
	                    if (fileWatcherCallbacks.contains(filePath)) {
	                        fileWatcherCallbacks.get(filePath).push(callback);
	                    }
	                    else {
	                        fileWatcherCallbacks.set(filePath, [callback]);
	                    }
	                }
	                function addFile(filePath, callback) {
	                    addFileWatcherCallback(filePath, callback);
	                    addDirWatcher(ts.getDirectoryPath(filePath));
	                    return { filePath: filePath, callback: callback };
	                }
	                function removeFile(watchedFile) {
	                    removeFileWatcherCallback(watchedFile.filePath, watchedFile.callback);
	                    reduceDirWatcherRefCountForFile(watchedFile.filePath);
	                }
	                function removeFileWatcherCallback(filePath, callback) {
	                    if (fileWatcherCallbacks.contains(filePath)) {
	                        var newCallbacks = ts.copyListRemovingItem(callback, fileWatcherCallbacks.get(filePath));
	                        if (newCallbacks.length === 0) {
	                            fileWatcherCallbacks.remove(filePath);
	                        }
	                        else {
	                            fileWatcherCallbacks.set(filePath, newCallbacks);
	                        }
	                    }
	                }
	                /**
	                 * @param watcherPath is the path from which the watcher is triggered.
	                 */
	                function fileEventHandler(eventName, relativeFileName, baseDirPath) {
	                    // When files are deleted from disk, the triggered "rename" event would have a relativefileName of "undefined"
	                    var filePath = typeof relativeFileName !== "string"
	                        ? undefined
	                        : ts.toPath(relativeFileName, baseDirPath, ts.createGetCanonicalFileName(ts.sys.useCaseSensitiveFileNames));
	                    // Some applications save a working file via rename operations
	                    if ((eventName === "change" || eventName === "rename") && fileWatcherCallbacks.contains(filePath)) {
	                        for (var _i = 0, _a = fileWatcherCallbacks.get(filePath); _i < _a.length; _i++) {
	                            var fileCallback = _a[_i];
	                            fileCallback(filePath);
	                        }
	                    }
	                }
	            }
	            // REVIEW: for now this implementation uses polling.
	            // The advantage of polling is that it works reliably
	            // on all os and with network mounted files.
	            // For 90 referenced files, the average time to detect
	            // changes is 2*msInterval (by default 5 seconds).
	            // The overhead of this is .04 percent (1/2500) with
	            // average pause of < 1 millisecond (and max
	            // pause less than 1.5 milliseconds); question is
	            // do we anticipate reference sets in the 100s and
	            // do we care about waiting 10-20 seconds to detect
	            // changes for large reference sets? If so, do we want
	            // to increase the chunk size or decrease the interval
	            // time dynamically to match the large reference set?
	            var pollingWatchedFileSet = createPollingWatchedFileSet();
	            var watchedFileSet = createWatchedFileSet();
	            function isNode4OrLater() {
	                return parseInt(process.version.charAt(1)) >= 4;
	            }
	            var platform = _os.platform();
	            // win32\win64 are case insensitive platforms, MacOS (darwin) by default is also case insensitive
	            var useCaseSensitiveFileNames = platform !== "win32" && platform !== "win64" && platform !== "darwin";
	            function readFile(fileName, encoding) {
	                if (!_fs.existsSync(fileName)) {
	                    return undefined;
	                }
	                var buffer = _fs.readFileSync(fileName);
	                var len = buffer.length;
	                if (len >= 2 && buffer[0] === 0xFE && buffer[1] === 0xFF) {
	                    // Big endian UTF-16 byte order mark detected. Since big endian is not supported by node.js,
	                    // flip all byte pairs and treat as little endian.
	                    len &= ~1;
	                    for (var i = 0; i < len; i += 2) {
	                        var temp = buffer[i];
	                        buffer[i] = buffer[i + 1];
	                        buffer[i + 1] = temp;
	                    }
	                    return buffer.toString("utf16le", 2);
	                }
	                if (len >= 2 && buffer[0] === 0xFF && buffer[1] === 0xFE) {
	                    // Little endian UTF-16 byte order mark detected
	                    return buffer.toString("utf16le", 2);
	                }
	                if (len >= 3 && buffer[0] === 0xEF && buffer[1] === 0xBB && buffer[2] === 0xBF) {
	                    // UTF-8 byte order mark detected
	                    return buffer.toString("utf8", 3);
	                }
	                // Default is UTF-8 with no byte order mark
	                return buffer.toString("utf8");
	            }
	            function writeFile(fileName, data, writeByteOrderMark) {
	                // If a BOM is required, emit one
	                if (writeByteOrderMark) {
	                    data = "\uFEFF" + data;
	                }
	                var fd;
	                try {
	                    fd = _fs.openSync(fileName, "w");
	                    _fs.writeSync(fd, data, undefined, "utf8");
	                }
	                finally {
	                    if (fd !== undefined) {
	                        _fs.closeSync(fd);
	                    }
	                }
	            }
	            function getCanonicalPath(path) {
	                return useCaseSensitiveFileNames ? path : path.toLowerCase();
	            }
	            function readDirectory(path, extension, exclude) {
	                var result = [];
	                exclude = ts.map(exclude, function (s) { return getCanonicalPath(ts.combinePaths(path, s)); });
	                visitDirectory(path);
	                return result;
	                function visitDirectory(path) {
	                    var files = _fs.readdirSync(path || ".").sort();
	                    var directories = [];
	                    for (var _i = 0, files_2 = files; _i < files_2.length; _i++) {
	                        var current = files_2[_i];
	                        var name_3 = ts.combinePaths(path, current);
	                        if (!ts.contains(exclude, getCanonicalPath(name_3))) {
	                            var stat = _fs.statSync(name_3);
	                            if (stat.isFile()) {
	                                if (!extension || ts.fileExtensionIs(name_3, extension)) {
	                                    result.push(name_3);
	                                }
	                            }
	                            else if (stat.isDirectory()) {
	                                directories.push(name_3);
	                            }
	                        }
	                    }
	                    for (var _a = 0, directories_1 = directories; _a < directories_1.length; _a++) {
	                        var current = directories_1[_a];
	                        visitDirectory(current);
	                    }
	                }
	            }
	            return {
	                args: process.argv.slice(2),
	                newLine: _os.EOL,
	                useCaseSensitiveFileNames: useCaseSensitiveFileNames,
	                write: function (s) {
	                    process.stdout.write(s);
	                },
	                readFile: readFile,
	                writeFile: writeFile,
	                watchFile: function (filePath, callback) {
	                    // Node 4.0 stablized the `fs.watch` function on Windows which avoids polling
	                    // and is more efficient than `fs.watchFile` (ref: https://github.com/nodejs/node/pull/2649
	                    // and https://github.com/Microsoft/TypeScript/issues/4643), therefore
	                    // if the current node.js version is newer than 4, use `fs.watch` instead.
	                    var watchSet = isNode4OrLater() ? watchedFileSet : pollingWatchedFileSet;
	                    var watchedFile = watchSet.addFile(filePath, callback);
	                    return {
	                        close: function () { return watchSet.removeFile(watchedFile); }
	                    };
	                },
	                watchDirectory: function (path, callback, recursive) {
	                    // Node 4.0 `fs.watch` function supports the "recursive" option on both OSX and Windows
	                    // (ref: https://github.com/nodejs/node/pull/2649 and https://github.com/Microsoft/TypeScript/issues/4643)
	                    var options;
	                    if (isNode4OrLater() && (process.platform === "win32" || process.platform === "darwin")) {
	                        options = { persistent: true, recursive: !!recursive };
	                    }
	                    else {
	                        options = { persistent: true };
	                    }
	                    return _fs.watch(path, options, function (eventName, relativeFileName) {
	                        // In watchDirectory we only care about adding and removing files (when event name is
	                        // "rename"); changes made within files are handled by corresponding fileWatchers (when
	                        // event name is "change")
	                        if (eventName === "rename") {
	                            // When deleting a file, the passed baseFileName is null
	                            callback(!relativeFileName ? relativeFileName : ts.normalizePath(ts.combinePaths(path, relativeFileName)));
	                        }
	                        ;
	                    });
	                },
	                resolvePath: function (path) {
	                    return _path.resolve(path);
	                },
	                fileExists: function (path) {
	                    return _fs.existsSync(path);
	                },
	                directoryExists: function (path) {
	                    return _fs.existsSync(path) && _fs.statSync(path).isDirectory();
	                },
	                createDirectory: function (directoryName) {
	                    if (!this.directoryExists(directoryName)) {
	                        _fs.mkdirSync(directoryName);
	                    }
	                },
	                getExecutingFilePath: function () {
	                    return __filename;
	                },
	                getCurrentDirectory: function () {
	                    return process.cwd();
	                },
	                readDirectory: readDirectory,
	                getMemoryUsage: function () {
	                    if (global.gc) {
	                        global.gc();
	                    }
	                    return process.memoryUsage().heapUsed;
	                },
	                exit: function (exitCode) {
	                    process.exit(exitCode);
	                }
	            };
	        }
	        function getChakraSystem() {
	            return {
	                newLine: ChakraHost.newLine || "\r\n",
	                args: ChakraHost.args,
	                useCaseSensitiveFileNames: !!ChakraHost.useCaseSensitiveFileNames,
	                write: ChakraHost.echo,
	                readFile: function (path, encoding) {
	                    // encoding is automatically handled by the implementation in ChakraHost
	                    return ChakraHost.readFile(path);
	                },
	                writeFile: function (path, data, writeByteOrderMark) {
	                    // If a BOM is required, emit one
	                    if (writeByteOrderMark) {
	                        data = "\uFEFF" + data;
	                    }
	                    ChakraHost.writeFile(path, data);
	                },
	                resolvePath: ChakraHost.resolvePath,
	                fileExists: ChakraHost.fileExists,
	                directoryExists: ChakraHost.directoryExists,
	                createDirectory: ChakraHost.createDirectory,
	                getExecutingFilePath: function () { return ChakraHost.executingFile; },
	                getCurrentDirectory: function () { return ChakraHost.currentDirectory; },
	                readDirectory: ChakraHost.readDirectory,
	                exit: ChakraHost.quit
	            };
	        }
	        if (typeof WScript !== "undefined" && typeof ActiveXObject === "function") {
	            return getWScriptSystem();
	        }
	        else if (typeof process !== "undefined" && process.nextTick && !process.browser && "function" !== "undefined") {
	            // process and process.nextTick checks if current environment is node-like
	            // process.browser check excludes webpack and browserify
	            return getNodeSystem();
	        }
	        else if (typeof ChakraHost !== "undefined") {
	            return getChakraSystem();
	        }
	        else {
	            return undefined; // Unsupported host
	        }
	    })();
	})(ts || (ts = {}));
	// <auto-generated />
	/// <reference path="types.ts" />
	/* @internal */
	var ts;
	(function (ts) {
	    ts.Diagnostics = {
	        Unterminated_string_literal: { code: 1002, category: ts.DiagnosticCategory.Error, key: "Unterminated_string_literal_1002", message: "Unterminated string literal." },
	        Identifier_expected: { code: 1003, category: ts.DiagnosticCategory.Error, key: "Identifier_expected_1003", message: "Identifier expected." },
	        _0_expected: { code: 1005, category: ts.DiagnosticCategory.Error, key: "_0_expected_1005", message: "'{0}' expected." },
	        A_file_cannot_have_a_reference_to_itself: { code: 1006, category: ts.DiagnosticCategory.Error, key: "A_file_cannot_have_a_reference_to_itself_1006", message: "A file cannot have a reference to itself." },
	        Trailing_comma_not_allowed: { code: 1009, category: ts.DiagnosticCategory.Error, key: "Trailing_comma_not_allowed_1009", message: "Trailing comma not allowed." },
	        Asterisk_Slash_expected: { code: 1010, category: ts.DiagnosticCategory.Error, key: "Asterisk_Slash_expected_1010", message: "'*/' expected." },
	        Unexpected_token: { code: 1012, category: ts.DiagnosticCategory.Error, key: "Unexpected_token_1012", message: "Unexpected token." },
	        A_rest_parameter_must_be_last_in_a_parameter_list: { code: 1014, category: ts.DiagnosticCategory.Error, key: "A_rest_parameter_must_be_last_in_a_parameter_list_1014", message: "A rest parameter must be last in a parameter list." },
	        Parameter_cannot_have_question_mark_and_initializer: { code: 1015, category: ts.DiagnosticCategory.Error, key: "Parameter_cannot_have_question_mark_and_initializer_1015", message: "Parameter cannot have question mark and initializer." },
	        A_required_parameter_cannot_follow_an_optional_parameter: { code: 1016, category: ts.DiagnosticCategory.Error, key: "A_required_parameter_cannot_follow_an_optional_parameter_1016", message: "A required parameter cannot follow an optional parameter." },
	        An_index_signature_cannot_have_a_rest_parameter: { code: 1017, category: ts.DiagnosticCategory.Error, key: "An_index_signature_cannot_have_a_rest_parameter_1017", message: "An index signature cannot have a rest parameter." },
	        An_index_signature_parameter_cannot_have_an_accessibility_modifier: { code: 1018, category: ts.DiagnosticCategory.Error, key: "An_index_signature_parameter_cannot_have_an_accessibility_modifier_1018", message: "An index signature parameter cannot have an accessibility modifier." },
	        An_index_signature_parameter_cannot_have_a_question_mark: { code: 1019, category: ts.DiagnosticCategory.Error, key: "An_index_signature_parameter_cannot_have_a_question_mark_1019", message: "An index signature parameter cannot have a question mark." },
	        An_index_signature_parameter_cannot_have_an_initializer: { code: 1020, category: ts.DiagnosticCategory.Error, key: "An_index_signature_parameter_cannot_have_an_initializer_1020", message: "An index signature parameter cannot have an initializer." },
	        An_index_signature_must_have_a_type_annotation: { code: 1021, category: ts.DiagnosticCategory.Error, key: "An_index_signature_must_have_a_type_annotation_1021", message: "An index signature must have a type annotation." },
	        An_index_signature_parameter_must_have_a_type_annotation: { code: 1022, category: ts.DiagnosticCategory.Error, key: "An_index_signature_parameter_must_have_a_type_annotation_1022", message: "An index signature parameter must have a type annotation." },
	        An_index_signature_parameter_type_must_be_string_or_number: { code: 1023, category: ts.DiagnosticCategory.Error, key: "An_index_signature_parameter_type_must_be_string_or_number_1023", message: "An index signature parameter type must be 'string' or 'number'." },
	        Accessibility_modifier_already_seen: { code: 1028, category: ts.DiagnosticCategory.Error, key: "Accessibility_modifier_already_seen_1028", message: "Accessibility modifier already seen." },
	        _0_modifier_must_precede_1_modifier: { code: 1029, category: ts.DiagnosticCategory.Error, key: "_0_modifier_must_precede_1_modifier_1029", message: "'{0}' modifier must precede '{1}' modifier." },
	        _0_modifier_already_seen: { code: 1030, category: ts.DiagnosticCategory.Error, key: "_0_modifier_already_seen_1030", message: "'{0}' modifier already seen." },
	        _0_modifier_cannot_appear_on_a_class_element: { code: 1031, category: ts.DiagnosticCategory.Error, key: "_0_modifier_cannot_appear_on_a_class_element_1031", message: "'{0}' modifier cannot appear on a class element." },
	        super_must_be_followed_by_an_argument_list_or_member_access: { code: 1034, category: ts.DiagnosticCategory.Error, key: "super_must_be_followed_by_an_argument_list_or_member_access_1034", message: "'super' must be followed by an argument list or member access." },
	        Only_ambient_modules_can_use_quoted_names: { code: 1035, category: ts.DiagnosticCategory.Error, key: "Only_ambient_modules_can_use_quoted_names_1035", message: "Only ambient modules can use quoted names." },
	        Statements_are_not_allowed_in_ambient_contexts: { code: 1036, category: ts.DiagnosticCategory.Error, key: "Statements_are_not_allowed_in_ambient_contexts_1036", message: "Statements are not allowed in ambient contexts." },
	        A_declare_modifier_cannot_be_used_in_an_already_ambient_context: { code: 1038, category: ts.DiagnosticCategory.Error, key: "A_declare_modifier_cannot_be_used_in_an_already_ambient_context_1038", message: "A 'declare' modifier cannot be used in an already ambient context." },
	        Initializers_are_not_allowed_in_ambient_contexts: { code: 1039, category: ts.DiagnosticCategory.Error, key: "Initializers_are_not_allowed_in_ambient_contexts_1039", message: "Initializers are not allowed in ambient contexts." },
	        _0_modifier_cannot_be_used_in_an_ambient_context: { code: 1040, category: ts.DiagnosticCategory.Error, key: "_0_modifier_cannot_be_used_in_an_ambient_context_1040", message: "'{0}' modifier cannot be used in an ambient context." },
	        _0_modifier_cannot_be_used_with_a_class_declaration: { code: 1041, category: ts.DiagnosticCategory.Error, key: "_0_modifier_cannot_be_used_with_a_class_declaration_1041", message: "'{0}' modifier cannot be used with a class declaration." },
	        _0_modifier_cannot_be_used_here: { code: 1042, category: ts.DiagnosticCategory.Error, key: "_0_modifier_cannot_be_used_here_1042", message: "'{0}' modifier cannot be used here." },
	        _0_modifier_cannot_appear_on_a_data_property: { code: 1043, category: ts.DiagnosticCategory.Error, key: "_0_modifier_cannot_appear_on_a_data_property_1043", message: "'{0}' modifier cannot appear on a data property." },
	        _0_modifier_cannot_appear_on_a_module_element: { code: 1044, category: ts.DiagnosticCategory.Error, key: "_0_modifier_cannot_appear_on_a_module_element_1044", message: "'{0}' modifier cannot appear on a module element." },
	        A_0_modifier_cannot_be_used_with_an_interface_declaration: { code: 1045, category: ts.DiagnosticCategory.Error, key: "A_0_modifier_cannot_be_used_with_an_interface_declaration_1045", message: "A '{0}' modifier cannot be used with an interface declaration." },
	        A_declare_modifier_is_required_for_a_top_level_declaration_in_a_d_ts_file: { code: 1046, category: ts.DiagnosticCategory.Error, key: "A_declare_modifier_is_required_for_a_top_level_declaration_in_a_d_ts_file_1046", message: "A 'declare' modifier is required for a top level declaration in a .d.ts file." },
	        A_rest_parameter_cannot_be_optional: { code: 1047, category: ts.DiagnosticCategory.Error, key: "A_rest_parameter_cannot_be_optional_1047", message: "A rest parameter cannot be optional." },
	        A_rest_parameter_cannot_have_an_initializer: { code: 1048, category: ts.DiagnosticCategory.Error, key: "A_rest_parameter_cannot_have_an_initializer_1048", message: "A rest parameter cannot have an initializer." },
	        A_set_accessor_must_have_exactly_one_parameter: { code: 1049, category: ts.DiagnosticCategory.Error, key: "A_set_accessor_must_have_exactly_one_parameter_1049", message: "A 'set' accessor must have exactly one parameter." },
	        A_set_accessor_cannot_have_an_optional_parameter: { code: 1051, category: ts.DiagnosticCategory.Error, key: "A_set_accessor_cannot_have_an_optional_parameter_1051", message: "A 'set' accessor cannot have an optional parameter." },
	        A_set_accessor_parameter_cannot_have_an_initializer: { code: 1052, category: ts.DiagnosticCategory.Error, key: "A_set_accessor_parameter_cannot_have_an_initializer_1052", message: "A 'set' accessor parameter cannot have an initializer." },
	        A_set_accessor_cannot_have_rest_parameter: { code: 1053, category: ts.DiagnosticCategory.Error, key: "A_set_accessor_cannot_have_rest_parameter_1053", message: "A 'set' accessor cannot have rest parameter." },
	        A_get_accessor_cannot_have_parameters: { code: 1054, category: ts.DiagnosticCategory.Error, key: "A_get_accessor_cannot_have_parameters_1054", message: "A 'get' accessor cannot have parameters." },
	        Type_0_is_not_a_valid_async_function_return_type: { code: 1055, category: ts.DiagnosticCategory.Error, key: "Type_0_is_not_a_valid_async_function_return_type_1055", message: "Type '{0}' is not a valid async function return type." },
	        Accessors_are_only_available_when_targeting_ECMAScript_5_and_higher: { code: 1056, category: ts.DiagnosticCategory.Error, key: "Accessors_are_only_available_when_targeting_ECMAScript_5_and_higher_1056", message: "Accessors are only available when targeting ECMAScript 5 and higher." },
	        An_async_function_or_method_must_have_a_valid_awaitable_return_type: { code: 1057, category: ts.DiagnosticCategory.Error, key: "An_async_function_or_method_must_have_a_valid_awaitable_return_type_1057", message: "An async function or method must have a valid awaitable return type." },
	        Operand_for_await_does_not_have_a_valid_callable_then_member: { code: 1058, category: ts.DiagnosticCategory.Error, key: "Operand_for_await_does_not_have_a_valid_callable_then_member_1058", message: "Operand for 'await' does not have a valid callable 'then' member." },
	        Return_expression_in_async_function_does_not_have_a_valid_callable_then_member: { code: 1059, category: ts.DiagnosticCategory.Error, key: "Return_expression_in_async_function_does_not_have_a_valid_callable_then_member_1059", message: "Return expression in async function does not have a valid callable 'then' member." },
	        Expression_body_for_async_arrow_function_does_not_have_a_valid_callable_then_member: { code: 1060, category: ts.DiagnosticCategory.Error, key: "Expression_body_for_async_arrow_function_does_not_have_a_valid_callable_then_member_1060", message: "Expression body for async arrow function does not have a valid callable 'then' member." },
	        Enum_member_must_have_initializer: { code: 1061, category: ts.DiagnosticCategory.Error, key: "Enum_member_must_have_initializer_1061", message: "Enum member must have initializer." },
	        _0_is_referenced_directly_or_indirectly_in_the_fulfillment_callback_of_its_own_then_method: { code: 1062, category: ts.DiagnosticCategory.Error, key: "_0_is_referenced_directly_or_indirectly_in_the_fulfillment_callback_of_its_own_then_method_1062", message: "{0} is referenced directly or indirectly in the fulfillment callback of its own 'then' method." },
	        An_export_assignment_cannot_be_used_in_a_namespace: { code: 1063, category: ts.DiagnosticCategory.Error, key: "An_export_assignment_cannot_be_used_in_a_namespace_1063", message: "An export assignment cannot be used in a namespace." },
	        The_return_type_of_an_async_function_or_method_must_be_the_global_Promise_T_type: { code: 1064, category: ts.DiagnosticCategory.Error, key: "The_return_type_of_an_async_function_or_method_must_be_the_global_Promise_T_type_1064", message: "The return type of an async function or method must be the global Promise<T> type." },
	        In_ambient_enum_declarations_member_initializer_must_be_constant_expression: { code: 1066, category: ts.DiagnosticCategory.Error, key: "In_ambient_enum_declarations_member_initializer_must_be_constant_expression_1066", message: "In ambient enum declarations member initializer must be constant expression." },
	        Unexpected_token_A_constructor_method_accessor_or_property_was_expected: { code: 1068, category: ts.DiagnosticCategory.Error, key: "Unexpected_token_A_constructor_method_accessor_or_property_was_expected_1068", message: "Unexpected token. A constructor, method, accessor, or property was expected." },
	        A_0_modifier_cannot_be_used_with_an_import_declaration: { code: 1079, category: ts.DiagnosticCategory.Error, key: "A_0_modifier_cannot_be_used_with_an_import_declaration_1079", message: "A '{0}' modifier cannot be used with an import declaration." },
	        Invalid_reference_directive_syntax: { code: 1084, category: ts.DiagnosticCategory.Error, key: "Invalid_reference_directive_syntax_1084", message: "Invalid 'reference' directive syntax." },
	        Octal_literals_are_not_available_when_targeting_ECMAScript_5_and_higher: { code: 1085, category: ts.DiagnosticCategory.Error, key: "Octal_literals_are_not_available_when_targeting_ECMAScript_5_and_higher_1085", message: "Octal literals are not available when targeting ECMAScript 5 and higher." },
	        An_accessor_cannot_be_declared_in_an_ambient_context: { code: 1086, category: ts.DiagnosticCategory.Error, key: "An_accessor_cannot_be_declared_in_an_ambient_context_1086", message: "An accessor cannot be declared in an ambient context." },
	        _0_modifier_cannot_appear_on_a_constructor_declaration: { code: 1089, category: ts.DiagnosticCategory.Error, key: "_0_modifier_cannot_appear_on_a_constructor_declaration_1089", message: "'{0}' modifier cannot appear on a constructor declaration." },
	        _0_modifier_cannot_appear_on_a_parameter: { code: 1090, category: ts.DiagnosticCategory.Error, key: "_0_modifier_cannot_appear_on_a_parameter_1090", message: "'{0}' modifier cannot appear on a parameter." },
	        Only_a_single_variable_declaration_is_allowed_in_a_for_in_statement: { code: 1091, category: ts.DiagnosticCategory.Error, key: "Only_a_single_variable_declaration_is_allowed_in_a_for_in_statement_1091", message: "Only a single variable declaration is allowed in a 'for...in' statement." },
	        Type_parameters_cannot_appear_on_a_constructor_declaration: { code: 1092, category: ts.DiagnosticCategory.Error, key: "Type_parameters_cannot_appear_on_a_constructor_declaration_1092", message: "Type parameters cannot appear on a constructor declaration." },
	        Type_annotation_cannot_appear_on_a_constructor_declaration: { code: 1093, category: ts.DiagnosticCategory.Error, key: "Type_annotation_cannot_appear_on_a_constructor_declaration_1093", message: "Type annotation cannot appear on a constructor declaration." },
	        An_accessor_cannot_have_type_parameters: { code: 1094, category: ts.DiagnosticCategory.Error, key: "An_accessor_cannot_have_type_parameters_1094", message: "An accessor cannot have type parameters." },
	        A_set_accessor_cannot_have_a_return_type_annotation: { code: 1095, category: ts.DiagnosticCategory.Error, key: "A_set_accessor_cannot_have_a_return_type_annotation_1095", message: "A 'set' accessor cannot have a return type annotation." },
	        An_index_signature_must_have_exactly_one_parameter: { code: 1096, category: ts.DiagnosticCategory.Error, key: "An_index_signature_must_have_exactly_one_parameter_1096", message: "An index signature must have exactly one parameter." },
	        _0_list_cannot_be_empty: { code: 1097, category: ts.DiagnosticCategory.Error, key: "_0_list_cannot_be_empty_1097", message: "'{0}' list cannot be empty." },
	        Type_parameter_list_cannot_be_empty: { code: 1098, category: ts.DiagnosticCategory.Error, key: "Type_parameter_list_cannot_be_empty_1098", message: "Type parameter list cannot be empty." },
	        Type_argument_list_cannot_be_empty: { code: 1099, category: ts.DiagnosticCategory.Error, key: "Type_argument_list_cannot_be_empty_1099", message: "Type argument list cannot be empty." },
	        Invalid_use_of_0_in_strict_mode: { code: 1100, category: ts.DiagnosticCategory.Error, key: "Invalid_use_of_0_in_strict_mode_1100", message: "Invalid use of '{0}' in strict mode." },
	        with_statements_are_not_allowed_in_strict_mode: { code: 1101, category: ts.DiagnosticCategory.Error, key: "with_statements_are_not_allowed_in_strict_mode_1101", message: "'with' statements are not allowed in strict mode." },
	        delete_cannot_be_called_on_an_identifier_in_strict_mode: { code: 1102, category: ts.DiagnosticCategory.Error, key: "delete_cannot_be_called_on_an_identifier_in_strict_mode_1102", message: "'delete' cannot be called on an identifier in strict mode." },
	        A_continue_statement_can_only_be_used_within_an_enclosing_iteration_statement: { code: 1104, category: ts.DiagnosticCategory.Error, key: "A_continue_statement_can_only_be_used_within_an_enclosing_iteration_statement_1104", message: "A 'continue' statement can only be used within an enclosing iteration statement." },
	        A_break_statement_can_only_be_used_within_an_enclosing_iteration_or_switch_statement: { code: 1105, category: ts.DiagnosticCategory.Error, key: "A_break_statement_can_only_be_used_within_an_enclosing_iteration_or_switch_statement_1105", message: "A 'break' statement can only be used within an enclosing iteration or switch statement." },
	        Jump_target_cannot_cross_function_boundary: { code: 1107, category: ts.DiagnosticCategory.Error, key: "Jump_target_cannot_cross_function_boundary_1107", message: "Jump target cannot cross function boundary." },
	        A_return_statement_can_only_be_used_within_a_function_body: { code: 1108, category: ts.DiagnosticCategory.Error, key: "A_return_statement_can_only_be_used_within_a_function_body_1108", message: "A 'return' statement can only be used within a function body." },
	        Expression_expected: { code: 1109, category: ts.DiagnosticCategory.Error, key: "Expression_expected_1109", message: "Expression expected." },
	        Type_expected: { code: 1110, category: ts.DiagnosticCategory.Error, key: "Type_expected_1110", message: "Type expected." },
	        A_class_member_cannot_be_declared_optional: { code: 1112, category: ts.DiagnosticCategory.Error, key: "A_class_member_cannot_be_declared_optional_1112", message: "A class member cannot be declared optional." },
	        A_default_clause_cannot_appear_more_than_once_in_a_switch_statement: { code: 1113, category: ts.DiagnosticCategory.Error, key: "A_default_clause_cannot_appear_more_than_once_in_a_switch_statement_1113", message: "A 'default' clause cannot appear more than once in a 'switch' statement." },
	        Duplicate_label_0: { code: 1114, category: ts.DiagnosticCategory.Error, key: "Duplicate_label_0_1114", message: "Duplicate label '{0}'" },
	        A_continue_statement_can_only_jump_to_a_label_of_an_enclosing_iteration_statement: { code: 1115, category: ts.DiagnosticCategory.Error, key: "A_continue_statement_can_only_jump_to_a_label_of_an_enclosing_iteration_statement_1115", message: "A 'continue' statement can only jump to a label of an enclosing iteration statement." },
	        A_break_statement_can_only_jump_to_a_label_of_an_enclosing_statement: { code: 1116, category: ts.DiagnosticCategory.Error, key: "A_break_statement_can_only_jump_to_a_label_of_an_enclosing_statement_1116", message: "A 'break' statement can only jump to a label of an enclosing statement." },
	        An_object_literal_cannot_have_multiple_properties_with_the_same_name_in_strict_mode: { code: 1117, category: ts.DiagnosticCategory.Error, key: "An_object_literal_cannot_have_multiple_properties_with_the_same_name_in_strict_mode_1117", message: "An object literal cannot have multiple properties with the same name in strict mode." },
	        An_object_literal_cannot_have_multiple_get_Slashset_accessors_with_the_same_name: { code: 1118, category: ts.DiagnosticCategory.Error, key: "An_object_literal_cannot_have_multiple_get_Slashset_accessors_with_the_same_name_1118", message: "An object literal cannot have multiple get/set accessors with the same name." },
	        An_object_literal_cannot_have_property_and_accessor_with_the_same_name: { code: 1119, category: ts.DiagnosticCategory.Error, key: "An_object_literal_cannot_have_property_and_accessor_with_the_same_name_1119", message: "An object literal cannot have property and accessor with the same name." },
	        An_export_assignment_cannot_have_modifiers: { code: 1120, category: ts.DiagnosticCategory.Error, key: "An_export_assignment_cannot_have_modifiers_1120", message: "An export assignment cannot have modifiers." },
	        Octal_literals_are_not_allowed_in_strict_mode: { code: 1121, category: ts.DiagnosticCategory.Error, key: "Octal_literals_are_not_allowed_in_strict_mode_1121", message: "Octal literals are not allowed in strict mode." },
	        A_tuple_type_element_list_cannot_be_empty: { code: 1122, category: ts.DiagnosticCategory.Error, key: "A_tuple_type_element_list_cannot_be_empty_1122", message: "A tuple type element list cannot be empty." },
	        Variable_declaration_list_cannot_be_empty: { code: 1123, category: ts.DiagnosticCategory.Error, key: "Variable_declaration_list_cannot_be_empty_1123", message: "Variable declaration list cannot be empty." },
	        Digit_expected: { code: 1124, category: ts.DiagnosticCategory.Error, key: "Digit_expected_1124", message: "Digit expected." },
	        Hexadecimal_digit_expected: { code: 1125, category: ts.DiagnosticCategory.Error, key: "Hexadecimal_digit_expected_1125", message: "Hexadecimal digit expected." },
	        Unexpected_end_of_text: { code: 1126, category: ts.DiagnosticCategory.Error, key: "Unexpected_end_of_text_1126", message: "Unexpected end of text." },
	        Invalid_character: { code: 1127, category: ts.DiagnosticCategory.Error, key: "Invalid_character_1127", message: "Invalid character." },
	        Declaration_or_statement_expected: { code: 1128, category: ts.DiagnosticCategory.Error, key: "Declaration_or_statement_expected_1128", message: "Declaration or statement expected." },
	        Statement_expected: { code: 1129, category: ts.DiagnosticCategory.Error, key: "Statement_expected_1129", message: "Statement expected." },
	        case_or_default_expected: { code: 1130, category: ts.DiagnosticCategory.Error, key: "case_or_default_expected_1130", message: "'case' or 'default' expected." },
	        Property_or_signature_expected: { code: 1131, category: ts.DiagnosticCategory.Error, key: "Property_or_signature_expected_1131", message: "Property or signature expected." },
	        Enum_member_expected: { code: 1132, category: ts.DiagnosticCategory.Error, key: "Enum_member_expected_1132", message: "Enum member expected." },
	        Variable_declaration_expected: { code: 1134, category: ts.DiagnosticCategory.Error, key: "Variable_declaration_expected_1134", message: "Variable declaration expected." },
	        Argument_expression_expected: { code: 1135, category: ts.DiagnosticCategory.Error, key: "Argument_expression_expected_1135", message: "Argument expression expected." },
	        Property_assignment_expected: { code: 1136, category: ts.DiagnosticCategory.Error, key: "Property_assignment_expected_1136", message: "Property assignment expected." },
	        Expression_or_comma_expected: { code: 1137, category: ts.DiagnosticCategory.Error, key: "Expression_or_comma_expected_1137", message: "Expression or comma expected." },
	        Parameter_declaration_expected: { code: 1138, category: ts.DiagnosticCategory.Error, key: "Parameter_declaration_expected_1138", message: "Parameter declaration expected." },
	        Type_parameter_declaration_expected: { code: 1139, category: ts.DiagnosticCategory.Error, key: "Type_parameter_declaration_expected_1139", message: "Type parameter declaration expected." },
	        Type_argument_expected: { code: 1140, category: ts.DiagnosticCategory.Error, key: "Type_argument_expected_1140", message: "Type argument expected." },
	        String_literal_expected: { code: 1141, category: ts.DiagnosticCategory.Error, key: "String_literal_expected_1141", message: "String literal expected." },
	        Line_break_not_permitted_here: { code: 1142, category: ts.DiagnosticCategory.Error, key: "Line_break_not_permitted_here_1142", message: "Line break not permitted here." },
	        or_expected: { code: 1144, category: ts.DiagnosticCategory.Error, key: "or_expected_1144", message: "'{' or ';' expected." },
	        Modifiers_not_permitted_on_index_signature_members: { code: 1145, category: ts.DiagnosticCategory.Error, key: "Modifiers_not_permitted_on_index_signature_members_1145", message: "Modifiers not permitted on index signature members." },
	        Declaration_expected: { code: 1146, category: ts.DiagnosticCategory.Error, key: "Declaration_expected_1146", message: "Declaration expected." },
	        Import_declarations_in_a_namespace_cannot_reference_a_module: { code: 1147, category: ts.DiagnosticCategory.Error, key: "Import_declarations_in_a_namespace_cannot_reference_a_module_1147", message: "Import declarations in a namespace cannot reference a module." },
	        Cannot_compile_modules_unless_the_module_flag_is_provided_with_a_valid_module_type_Consider_setting_the_module_compiler_option_in_a_tsconfig_json_file: { code: 1148, category: ts.DiagnosticCategory.Error, key: "Cannot_compile_modules_unless_the_module_flag_is_provided_with_a_valid_module_type_Consider_setting__1148", message: "Cannot compile modules unless the '--module' flag is provided with a valid module type. Consider setting the 'module' compiler option in a 'tsconfig.json' file." },
	        File_name_0_differs_from_already_included_file_name_1_only_in_casing: { code: 1149, category: ts.DiagnosticCategory.Error, key: "File_name_0_differs_from_already_included_file_name_1_only_in_casing_1149", message: "File name '{0}' differs from already included file name '{1}' only in casing" },
	        new_T_cannot_be_used_to_create_an_array_Use_new_Array_T_instead: { code: 1150, category: ts.DiagnosticCategory.Error, key: "new_T_cannot_be_used_to_create_an_array_Use_new_Array_T_instead_1150", message: "'new T[]' cannot be used to create an array. Use 'new Array<T>()' instead." },
	        const_declarations_must_be_initialized: { code: 1155, category: ts.DiagnosticCategory.Error, key: "const_declarations_must_be_initialized_1155", message: "'const' declarations must be initialized" },
	        const_declarations_can_only_be_declared_inside_a_block: { code: 1156, category: ts.DiagnosticCategory.Error, key: "const_declarations_can_only_be_declared_inside_a_block_1156", message: "'const' declarations can only be declared inside a block." },
	        let_declarations_can_only_be_declared_inside_a_block: { code: 1157, category: ts.DiagnosticCategory.Error, key: "let_declarations_can_only_be_declared_inside_a_block_1157", message: "'let' declarations can only be declared inside a block." },
	        Unterminated_template_literal: { code: 1160, category: ts.DiagnosticCategory.Error, key: "Unterminated_template_literal_1160", message: "Unterminated template literal." },
	        Unterminated_regular_expression_literal: { code: 1161, category: ts.DiagnosticCategory.Error, key: "Unterminated_regular_expression_literal_1161", message: "Unterminated regular expression literal." },
	        An_object_member_cannot_be_declared_optional: { code: 1162, category: ts.DiagnosticCategory.Error, key: "An_object_member_cannot_be_declared_optional_1162", message: "An object member cannot be declared optional." },
	        A_yield_expression_is_only_allowed_in_a_generator_body: { code: 1163, category: ts.DiagnosticCategory.Error, key: "A_yield_expression_is_only_allowed_in_a_generator_body_1163", message: "A 'yield' expression is only allowed in a generator body." },
	        Computed_property_names_are_not_allowed_in_enums: { code: 1164, category: ts.DiagnosticCategory.Error, key: "Computed_property_names_are_not_allowed_in_enums_1164", message: "Computed property names are not allowed in enums." },
	        A_computed_property_name_in_an_ambient_context_must_directly_refer_to_a_built_in_symbol: { code: 1165, category: ts.DiagnosticCategory.Error, key: "A_computed_property_name_in_an_ambient_context_must_directly_refer_to_a_built_in_symbol_1165", message: "A computed property name in an ambient context must directly refer to a built-in symbol." },
	        A_computed_property_name_in_a_class_property_declaration_must_directly_refer_to_a_built_in_symbol: { code: 1166, category: ts.DiagnosticCategory.Error, key: "A_computed_property_name_in_a_class_property_declaration_must_directly_refer_to_a_built_in_symbol_1166", message: "A computed property name in a class property declaration must directly refer to a built-in symbol." },
	        A_computed_property_name_in_a_method_overload_must_directly_refer_to_a_built_in_symbol: { code: 1168, category: ts.DiagnosticCategory.Error, key: "A_computed_property_name_in_a_method_overload_must_directly_refer_to_a_built_in_symbol_1168", message: "A computed property name in a method overload must directly refer to a built-in symbol." },
	        A_computed_property_name_in_an_interface_must_directly_refer_to_a_built_in_symbol: { code: 1169, category: ts.DiagnosticCategory.Error, key: "A_computed_property_name_in_an_interface_must_directly_refer_to_a_built_in_symbol_1169", message: "A computed property name in an interface must directly refer to a built-in symbol." },
	        A_computed_property_name_in_a_type_literal_must_directly_refer_to_a_built_in_symbol: { code: 1170, category: ts.DiagnosticCategory.Error, key: "A_computed_property_name_in_a_type_literal_must_directly_refer_to_a_built_in_symbol_1170", message: "A computed property name in a type literal must directly refer to a built-in symbol." },
	        A_comma_expression_is_not_allowed_in_a_computed_property_name: { code: 1171, category: ts.DiagnosticCategory.Error, key: "A_comma_expression_is_not_allowed_in_a_computed_property_name_1171", message: "A comma expression is not allowed in a computed property name." },
	        extends_clause_already_seen: { code: 1172, category: ts.DiagnosticCategory.Error, key: "extends_clause_already_seen_1172", message: "'extends' clause already seen." },
	        extends_clause_must_precede_implements_clause: { code: 1173, category: ts.DiagnosticCategory.Error, key: "extends_clause_must_precede_implements_clause_1173", message: "'extends' clause must precede 'implements' clause." },
	        Classes_can_only_extend_a_single_class: { code: 1174, category: ts.DiagnosticCategory.Error, key: "Classes_can_only_extend_a_single_class_1174", message: "Classes can only extend a single class." },
	        implements_clause_already_seen: { code: 1175, category: ts.DiagnosticCategory.Error, key: "implements_clause_already_seen_1175", message: "'implements' clause already seen." },
	        Interface_declaration_cannot_have_implements_clause: { code: 1176, category: ts.DiagnosticCategory.Error, key: "Interface_declaration_cannot_have_implements_clause_1176", message: "Interface declaration cannot have 'implements' clause." },
	        Binary_digit_expected: { code: 1177, category: ts.DiagnosticCategory.Error, key: "Binary_digit_expected_1177", message: "Binary digit expected." },
	        Octal_digit_expected: { code: 1178, category: ts.DiagnosticCategory.Error, key: "Octal_digit_expected_1178", message: "Octal digit expected." },
	        Unexpected_token_expected: { code: 1179, category: ts.DiagnosticCategory.Error, key: "Unexpected_token_expected_1179", message: "Unexpected token. '{' expected." },
	        Property_destructuring_pattern_expected: { code: 1180, category: ts.DiagnosticCategory.Error, key: "Property_destructuring_pattern_expected_1180", message: "Property destructuring pattern expected." },
	        Array_element_destructuring_pattern_expected: { code: 1181, category: ts.DiagnosticCategory.Error, key: "Array_element_destructuring_pattern_expected_1181", message: "Array element destructuring pattern expected." },
	        A_destructuring_declaration_must_have_an_initializer: { code: 1182, category: ts.DiagnosticCategory.Error, key: "A_destructuring_declaration_must_have_an_initializer_1182", message: "A destructuring declaration must have an initializer." },
	        An_implementation_cannot_be_declared_in_ambient_contexts: { code: 1183, category: ts.DiagnosticCategory.Error, key: "An_implementation_cannot_be_declared_in_ambient_contexts_1183", message: "An implementation cannot be declared in ambient contexts." },
	        Modifiers_cannot_appear_here: { code: 1184, category: ts.DiagnosticCategory.Error, key: "Modifiers_cannot_appear_here_1184", message: "Modifiers cannot appear here." },
	        Merge_conflict_marker_encountered: { code: 1185, category: ts.DiagnosticCategory.Error, key: "Merge_conflict_marker_encountered_1185", message: "Merge conflict marker encountered." },
	        A_rest_element_cannot_have_an_initializer: { code: 1186, category: ts.DiagnosticCategory.Error, key: "A_rest_element_cannot_have_an_initializer_1186", message: "A rest element cannot have an initializer." },
	        A_parameter_property_may_not_be_a_binding_pattern: { code: 1187, category: ts.DiagnosticCategory.Error, key: "A_parameter_property_may_not_be_a_binding_pattern_1187", message: "A parameter property may not be a binding pattern." },
	        Only_a_single_variable_declaration_is_allowed_in_a_for_of_statement: { code: 1188, category: ts.DiagnosticCategory.Error, key: "Only_a_single_variable_declaration_is_allowed_in_a_for_of_statement_1188", message: "Only a single variable declaration is allowed in a 'for...of' statement." },
	        The_variable_declaration_of_a_for_in_statement_cannot_have_an_initializer: { code: 1189, category: ts.DiagnosticCategory.Error, key: "The_variable_declaration_of_a_for_in_statement_cannot_have_an_initializer_1189", message: "The variable declaration of a 'for...in' statement cannot have an initializer." },
	        The_variable_declaration_of_a_for_of_statement_cannot_have_an_initializer: { code: 1190, category: ts.DiagnosticCategory.Error, key: "The_variable_declaration_of_a_for_of_statement_cannot_have_an_initializer_1190", message: "The variable declaration of a 'for...of' statement cannot have an initializer." },
	        An_import_declaration_cannot_have_modifiers: { code: 1191, category: ts.DiagnosticCategory.Error, key: "An_import_declaration_cannot_have_modifiers_1191", message: "An import declaration cannot have modifiers." },
	        Module_0_has_no_default_export: { code: 1192, category: ts.DiagnosticCategory.Error, key: "Module_0_has_no_default_export_1192", message: "Module '{0}' has no default export." },
	        An_export_declaration_cannot_have_modifiers: { code: 1193, category: ts.DiagnosticCategory.Error, key: "An_export_declaration_cannot_have_modifiers_1193", message: "An export declaration cannot have modifiers." },
	        Export_declarations_are_not_permitted_in_a_namespace: { code: 1194, category: ts.DiagnosticCategory.Error, key: "Export_declarations_are_not_permitted_in_a_namespace_1194", message: "Export declarations are not permitted in a namespace." },
	        Catch_clause_variable_name_must_be_an_identifier: { code: 1195, category: ts.DiagnosticCategory.Error, key: "Catch_clause_variable_name_must_be_an_identifier_1195", message: "Catch clause variable name must be an identifier." },
	        Catch_clause_variable_cannot_have_a_type_annotation: { code: 1196, category: ts.DiagnosticCategory.Error, key: "Catch_clause_variable_cannot_have_a_type_annotation_1196", message: "Catch clause variable cannot have a type annotation." },
	        Catch_clause_variable_cannot_have_an_initializer: { code: 1197, category: ts.DiagnosticCategory.Error, key: "Catch_clause_variable_cannot_have_an_initializer_1197", message: "Catch clause variable cannot have an initializer." },
	        An_extended_Unicode_escape_value_must_be_between_0x0_and_0x10FFFF_inclusive: { code: 1198, category: ts.DiagnosticCategory.Error, key: "An_extended_Unicode_escape_value_must_be_between_0x0_and_0x10FFFF_inclusive_1198", message: "An extended Unicode escape value must be between 0x0 and 0x10FFFF inclusive." },
	        Unterminated_Unicode_escape_sequence: { code: 1199, category: ts.DiagnosticCategory.Error, key: "Unterminated_Unicode_escape_sequence_1199", message: "Unterminated Unicode escape sequence." },
	        Line_terminator_not_permitted_before_arrow: { code: 1200, category: ts.DiagnosticCategory.Error, key: "Line_terminator_not_permitted_before_arrow_1200", message: "Line terminator not permitted before arrow." },
	        Import_assignment_cannot_be_used_when_targeting_ECMAScript_6_modules_Consider_using_import_Asterisk_as_ns_from_mod_import_a_from_mod_import_d_from_mod_or_another_module_format_instead: { code: 1202, category: ts.DiagnosticCategory.Error, key: "Import_assignment_cannot_be_used_when_targeting_ECMAScript_6_modules_Consider_using_import_Asterisk__1202", message: "Import assignment cannot be used when targeting ECMAScript 6 modules. Consider using 'import * as ns from \"mod\"', 'import {a} from \"mod\"', 'import d from \"mod\"', or another module format instead." },
	        Export_assignment_cannot_be_used_when_targeting_ECMAScript_6_modules_Consider_using_export_default_or_another_module_format_instead: { code: 1203, category: ts.DiagnosticCategory.Error, key: "Export_assignment_cannot_be_used_when_targeting_ECMAScript_6_modules_Consider_using_export_default_o_1203", message: "Export assignment cannot be used when targeting ECMAScript 6 modules. Consider using 'export default' or another module format instead." },
	        Cannot_compile_modules_into_es2015_when_targeting_ES5_or_lower: { code: 1204, category: ts.DiagnosticCategory.Error, key: "Cannot_compile_modules_into_es2015_when_targeting_ES5_or_lower_1204", message: "Cannot compile modules into 'es2015' when targeting 'ES5' or lower." },
	        Decorators_are_not_valid_here: { code: 1206, category: ts.DiagnosticCategory.Error, key: "Decorators_are_not_valid_here_1206", message: "Decorators are not valid here." },
	        Decorators_cannot_be_applied_to_multiple_get_Slashset_accessors_of_the_same_name: { code: 1207, category: ts.DiagnosticCategory.Error, key: "Decorators_cannot_be_applied_to_multiple_get_Slashset_accessors_of_the_same_name_1207", message: "Decorators cannot be applied to multiple get/set accessors of the same name." },
	        Cannot_compile_namespaces_when_the_isolatedModules_flag_is_provided: { code: 1208, category: ts.DiagnosticCategory.Error, key: "Cannot_compile_namespaces_when_the_isolatedModules_flag_is_provided_1208", message: "Cannot compile namespaces when the '--isolatedModules' flag is provided." },
	        Ambient_const_enums_are_not_allowed_when_the_isolatedModules_flag_is_provided: { code: 1209, category: ts.DiagnosticCategory.Error, key: "Ambient_const_enums_are_not_allowed_when_the_isolatedModules_flag_is_provided_1209", message: "Ambient const enums are not allowed when the '--isolatedModules' flag is provided." },
	        Invalid_use_of_0_Class_definitions_are_automatically_in_strict_mode: { code: 1210, category: ts.DiagnosticCategory.Error, key: "Invalid_use_of_0_Class_definitions_are_automatically_in_strict_mode_1210", message: "Invalid use of '{0}'. Class definitions are automatically in strict mode." },
	        A_class_declaration_without_the_default_modifier_must_have_a_name: { code: 1211, category: ts.DiagnosticCategory.Error, key: "A_class_declaration_without_the_default_modifier_must_have_a_name_1211", message: "A class declaration without the 'default' modifier must have a name" },
	        Identifier_expected_0_is_a_reserved_word_in_strict_mode: { code: 1212, category: ts.DiagnosticCategory.Error, key: "Identifier_expected_0_is_a_reserved_word_in_strict_mode_1212", message: "Identifier expected. '{0}' is a reserved word in strict mode" },
	        Identifier_expected_0_is_a_reserved_word_in_strict_mode_Class_definitions_are_automatically_in_strict_mode: { code: 1213, category: ts.DiagnosticCategory.Error, key: "Identifier_expected_0_is_a_reserved_word_in_strict_mode_Class_definitions_are_automatically_in_stric_1213", message: "Identifier expected. '{0}' is a reserved word in strict mode. Class definitions are automatically in strict mode." },
	        Identifier_expected_0_is_a_reserved_word_in_strict_mode_Modules_are_automatically_in_strict_mode: { code: 1214, category: ts.DiagnosticCategory.Error, key: "Identifier_expected_0_is_a_reserved_word_in_strict_mode_Modules_are_automatically_in_strict_mode_1214", message: "Identifier expected. '{0}' is a reserved word in strict mode. Modules are automatically in strict mode." },
	        Invalid_use_of_0_Modules_are_automatically_in_strict_mode: { code: 1215, category: ts.DiagnosticCategory.Error, key: "Invalid_use_of_0_Modules_are_automatically_in_strict_mode_1215", message: "Invalid use of '{0}'. Modules are automatically in strict mode." },
	        Export_assignment_is_not_supported_when_module_flag_is_system: { code: 1218, category: ts.DiagnosticCategory.Error, key: "Export_assignment_is_not_supported_when_module_flag_is_system_1218", message: "Export assignment is not supported when '--module' flag is 'system'." },
	        Experimental_support_for_decorators_is_a_feature_that_is_subject_to_change_in_a_future_release_Set_the_experimentalDecorators_option_to_remove_this_warning: { code: 1219, category: ts.DiagnosticCategory.Error, key: "Experimental_support_for_decorators_is_a_feature_that_is_subject_to_change_in_a_future_release_Set_t_1219", message: "Experimental support for decorators is a feature that is subject to change in a future release. Set the 'experimentalDecorators' option to remove this warning." },
	        Generators_are_only_available_when_targeting_ECMAScript_6_or_higher: { code: 1220, category: ts.DiagnosticCategory.Error, key: "Generators_are_only_available_when_targeting_ECMAScript_6_or_higher_1220", message: "Generators are only available when targeting ECMAScript 6 or higher." },
	        Generators_are_not_allowed_in_an_ambient_context: { code: 1221, category: ts.DiagnosticCategory.Error, key: "Generators_are_not_allowed_in_an_ambient_context_1221", message: "Generators are not allowed in an ambient context." },
	        An_overload_signature_cannot_be_declared_as_a_generator: { code: 1222, category: ts.DiagnosticCategory.Error, key: "An_overload_signature_cannot_be_declared_as_a_generator_1222", message: "An overload signature cannot be declared as a generator." },
	        _0_tag_already_specified: { code: 1223, category: ts.DiagnosticCategory.Error, key: "_0_tag_already_specified_1223", message: "'{0}' tag already specified." },
	        Signature_0_must_have_a_type_predicate: { code: 1224, category: ts.DiagnosticCategory.Error, key: "Signature_0_must_have_a_type_predicate_1224", message: "Signature '{0}' must have a type predicate." },
	        Cannot_find_parameter_0: { code: 1225, category: ts.DiagnosticCategory.Error, key: "Cannot_find_parameter_0_1225", message: "Cannot find parameter '{0}'." },
	        Type_predicate_0_is_not_assignable_to_1: { code: 1226, category: ts.DiagnosticCategory.Error, key: "Type_predicate_0_is_not_assignable_to_1_1226", message: "Type predicate '{0}' is not assignable to '{1}'." },
	        Parameter_0_is_not_in_the_same_position_as_parameter_1: { code: 1227, category: ts.DiagnosticCategory.Error, key: "Parameter_0_is_not_in_the_same_position_as_parameter_1_1227", message: "Parameter '{0}' is not in the same position as parameter '{1}'." },
	        A_type_predicate_is_only_allowed_in_return_type_position_for_functions_and_methods: { code: 1228, category: ts.DiagnosticCategory.Error, key: "A_type_predicate_is_only_allowed_in_return_type_position_for_functions_and_methods_1228", message: "A type predicate is only allowed in return type position for functions and methods." },
	        A_type_predicate_cannot_reference_a_rest_parameter: { code: 1229, category: ts.DiagnosticCategory.Error, key: "A_type_predicate_cannot_reference_a_rest_parameter_1229", message: "A type predicate cannot reference a rest parameter." },
	        A_type_predicate_cannot_reference_element_0_in_a_binding_pattern: { code: 1230, category: ts.DiagnosticCategory.Error, key: "A_type_predicate_cannot_reference_element_0_in_a_binding_pattern_1230", message: "A type predicate cannot reference element '{0}' in a binding pattern." },
	        An_export_assignment_can_only_be_used_in_a_module: { code: 1231, category: ts.DiagnosticCategory.Error, key: "An_export_assignment_can_only_be_used_in_a_module_1231", message: "An export assignment can only be used in a module." },
	        An_import_declaration_can_only_be_used_in_a_namespace_or_module: { code: 1232, category: ts.DiagnosticCategory.Error, key: "An_import_declaration_can_only_be_used_in_a_namespace_or_module_1232", message: "An import declaration can only be used in a namespace or module." },
	        An_export_declaration_can_only_be_used_in_a_module: { code: 1233, category: ts.DiagnosticCategory.Error, key: "An_export_declaration_can_only_be_used_in_a_module_1233", message: "An export declaration can only be used in a module." },
	        An_ambient_module_declaration_is_only_allowed_at_the_top_level_in_a_file: { code: 1234, category: ts.DiagnosticCategory.Error, key: "An_ambient_module_declaration_is_only_allowed_at_the_top_level_in_a_file_1234", message: "An ambient module declaration is only allowed at the top level in a file." },
	        A_namespace_declaration_is_only_allowed_in_a_namespace_or_module: { code: 1235, category: ts.DiagnosticCategory.Error, key: "A_namespace_declaration_is_only_allowed_in_a_namespace_or_module_1235", message: "A namespace declaration is only allowed in a namespace or module." },
	        The_return_type_of_a_property_decorator_function_must_be_either_void_or_any: { code: 1236, category: ts.DiagnosticCategory.Error, key: "The_return_type_of_a_property_decorator_function_must_be_either_void_or_any_1236", message: "The return type of a property decorator function must be either 'void' or 'any'." },
	        The_return_type_of_a_parameter_decorator_function_must_be_either_void_or_any: { code: 1237, category: ts.DiagnosticCategory.Error, key: "The_return_type_of_a_parameter_decorator_function_must_be_either_void_or_any_1237", message: "The return type of a parameter decorator function must be either 'void' or 'any'." },
	        Unable_to_resolve_signature_of_class_decorator_when_called_as_an_expression: { code: 1238, category: ts.DiagnosticCategory.Error, key: "Unable_to_resolve_signature_of_class_decorator_when_called_as_an_expression_1238", message: "Unable to resolve signature of class decorator when called as an expression." },
	        Unable_to_resolve_signature_of_parameter_decorator_when_called_as_an_expression: { code: 1239, category: ts.DiagnosticCategory.Error, key: "Unable_to_resolve_signature_of_parameter_decorator_when_called_as_an_expression_1239", message: "Unable to resolve signature of parameter decorator when called as an expression." },
	        Unable_to_resolve_signature_of_property_decorator_when_called_as_an_expression: { code: 1240, category: ts.DiagnosticCategory.Error, key: "Unable_to_resolve_signature_of_property_decorator_when_called_as_an_expression_1240", message: "Unable to resolve signature of property decorator when called as an expression." },
	        Unable_to_resolve_signature_of_method_decorator_when_called_as_an_expression: { code: 1241, category: ts.DiagnosticCategory.Error, key: "Unable_to_resolve_signature_of_method_decorator_when_called_as_an_expression_1241", message: "Unable to resolve signature of method decorator when called as an expression." },
	        abstract_modifier_can_only_appear_on_a_class_or_method_declaration: { code: 1242, category: ts.DiagnosticCategory.Error, key: "abstract_modifier_can_only_appear_on_a_class_or_method_declaration_1242", message: "'abstract' modifier can only appear on a class or method declaration." },
	        _0_modifier_cannot_be_used_with_1_modifier: { code: 1243, category: ts.DiagnosticCategory.Error, key: "_0_modifier_cannot_be_used_with_1_modifier_1243", message: "'{0}' modifier cannot be used with '{1}' modifier." },
	        Abstract_methods_can_only_appear_within_an_abstract_class: { code: 1244, category: ts.DiagnosticCategory.Error, key: "Abstract_methods_can_only_appear_within_an_abstract_class_1244", message: "Abstract methods can only appear within an abstract class." },
	        Method_0_cannot_have_an_implementation_because_it_is_marked_abstract: { code: 1245, category: ts.DiagnosticCategory.Error, key: "Method_0_cannot_have_an_implementation_because_it_is_marked_abstract_1245", message: "Method '{0}' cannot have an implementation because it is marked abstract." },
	        An_interface_property_cannot_have_an_initializer: { code: 1246, category: ts.DiagnosticCategory.Error, key: "An_interface_property_cannot_have_an_initializer_1246", message: "An interface property cannot have an initializer." },
	        A_type_literal_property_cannot_have_an_initializer: { code: 1247, category: ts.DiagnosticCategory.Error, key: "A_type_literal_property_cannot_have_an_initializer_1247", message: "A type literal property cannot have an initializer." },
	        A_class_member_cannot_have_the_0_keyword: { code: 1248, category: ts.DiagnosticCategory.Error, key: "A_class_member_cannot_have_the_0_keyword_1248", message: "A class member cannot have the '{0}' keyword." },
	        A_decorator_can_only_decorate_a_method_implementation_not_an_overload: { code: 1249, category: ts.DiagnosticCategory.Error, key: "A_decorator_can_only_decorate_a_method_implementation_not_an_overload_1249", message: "A decorator can only decorate a method implementation, not an overload." },
	        with_statements_are_not_allowed_in_an_async_function_block: { code: 1300, category: ts.DiagnosticCategory.Error, key: "with_statements_are_not_allowed_in_an_async_function_block_1300", message: "'with' statements are not allowed in an async function block." },
	        await_expression_is_only_allowed_within_an_async_function: { code: 1308, category: ts.DiagnosticCategory.Error, key: "await_expression_is_only_allowed_within_an_async_function_1308", message: "'await' expression is only allowed within an async function." },
	        Async_functions_are_only_available_when_targeting_ECMAScript_6_and_higher: { code: 1311, category: ts.DiagnosticCategory.Error, key: "Async_functions_are_only_available_when_targeting_ECMAScript_6_and_higher_1311", message: "Async functions are only available when targeting ECMAScript 6 and higher." },
	        can_only_be_used_in_an_object_literal_property_inside_a_destructuring_assignment: { code: 1312, category: ts.DiagnosticCategory.Error, key: "can_only_be_used_in_an_object_literal_property_inside_a_destructuring_assignment_1312", message: "'=' can only be used in an object literal property inside a destructuring assignment." },
	        The_body_of_an_if_statement_cannot_be_the_empty_statement: { code: 1313, category: ts.DiagnosticCategory.Error, key: "The_body_of_an_if_statement_cannot_be_the_empty_statement_1313", message: "The body of an 'if' statement cannot be the empty statement." },
	        Duplicate_identifier_0: { code: 2300, category: ts.DiagnosticCategory.Error, key: "Duplicate_identifier_0_2300", message: "Duplicate identifier '{0}'." },
	        Initializer_of_instance_member_variable_0_cannot_reference_identifier_1_declared_in_the_constructor: { code: 2301, category: ts.DiagnosticCategory.Error, key: "Initializer_of_instance_member_variable_0_cannot_reference_identifier_1_declared_in_the_constructor_2301", message: "Initializer of instance member variable '{0}' cannot reference identifier '{1}' declared in the constructor." },
	        Static_members_cannot_reference_class_type_parameters: { code: 2302, category: ts.DiagnosticCategory.Error, key: "Static_members_cannot_reference_class_type_parameters_2302", message: "Static members cannot reference class type parameters." },
	        Circular_definition_of_import_alias_0: { code: 2303, category: ts.DiagnosticCategory.Error, key: "Circular_definition_of_import_alias_0_2303", message: "Circular definition of import alias '{0}'." },
	        Cannot_find_name_0: { code: 2304, category: ts.DiagnosticCategory.Error, key: "Cannot_find_name_0_2304", message: "Cannot find name '{0}'." },
	        Module_0_has_no_exported_member_1: { code: 2305, category: ts.DiagnosticCategory.Error, key: "Module_0_has_no_exported_member_1_2305", message: "Module '{0}' has no exported member '{1}'." },
	        File_0_is_not_a_module: { code: 2306, category: ts.DiagnosticCategory.Error, key: "File_0_is_not_a_module_2306", message: "File '{0}' is not a module." },
	        Cannot_find_module_0: { code: 2307, category: ts.DiagnosticCategory.Error, key: "Cannot_find_module_0_2307", message: "Cannot find module '{0}'." },
	        Module_0_has_already_exported_a_member_named_1_Consider_explicitly_re_exporting_to_resolve_the_ambiguity: { code: 2308, category: ts.DiagnosticCategory.Error, key: "Module_0_has_already_exported_a_member_named_1_Consider_explicitly_re_exporting_to_resolve_the_ambig_2308", message: "Module {0} has already exported a member named '{1}'. Consider explicitly re-exporting to resolve the ambiguity." },
	        An_export_assignment_cannot_be_used_in_a_module_with_other_exported_elements: { code: 2309, category: ts.DiagnosticCategory.Error, key: "An_export_assignment_cannot_be_used_in_a_module_with_other_exported_elements_2309", message: "An export assignment cannot be used in a module with other exported elements." },
	        Type_0_recursively_references_itself_as_a_base_type: { code: 2310, category: ts.DiagnosticCategory.Error, key: "Type_0_recursively_references_itself_as_a_base_type_2310", message: "Type '{0}' recursively references itself as a base type." },
	        A_class_may_only_extend_another_class: { code: 2311, category: ts.DiagnosticCategory.Error, key: "A_class_may_only_extend_another_class_2311", message: "A class may only extend another class." },
	        An_interface_may_only_extend_a_class_or_another_interface: { code: 2312, category: ts.DiagnosticCategory.Error, key: "An_interface_may_only_extend_a_class_or_another_interface_2312", message: "An interface may only extend a class or another interface." },
	        Type_parameter_0_has_a_circular_constraint: { code: 2313, category: ts.DiagnosticCategory.Error, key: "Type_parameter_0_has_a_circular_constraint_2313", message: "Type parameter '{0}' has a circular constraint." },
	        Generic_type_0_requires_1_type_argument_s: { code: 2314, category: ts.DiagnosticCategory.Error, key: "Generic_type_0_requires_1_type_argument_s_2314", message: "Generic type '{0}' requires {1} type argument(s)." },
	        Type_0_is_not_generic: { code: 2315, category: ts.DiagnosticCategory.Error, key: "Type_0_is_not_generic_2315", message: "Type '{0}' is not generic." },
	        Global_type_0_must_be_a_class_or_interface_type: { code: 2316, category: ts.DiagnosticCategory.Error, key: "Global_type_0_must_be_a_class_or_interface_type_2316", message: "Global type '{0}' must be a class or interface type." },
	        Global_type_0_must_have_1_type_parameter_s: { code: 2317, category: ts.DiagnosticCategory.Error, key: "Global_type_0_must_have_1_type_parameter_s_2317", message: "Global type '{0}' must have {1} type parameter(s)." },
	        Cannot_find_global_type_0: { code: 2318, category: ts.DiagnosticCategory.Error, key: "Cannot_find_global_type_0_2318", message: "Cannot find global type '{0}'." },
	        Named_property_0_of_types_1_and_2_are_not_identical: { code: 2319, category: ts.DiagnosticCategory.Error, key: "Named_property_0_of_types_1_and_2_are_not_identical_2319", message: "Named property '{0}' of types '{1}' and '{2}' are not identical." },
	        Interface_0_cannot_simultaneously_extend_types_1_and_2: { code: 2320, category: ts.DiagnosticCategory.Error, key: "Interface_0_cannot_simultaneously_extend_types_1_and_2_2320", message: "Interface '{0}' cannot simultaneously extend types '{1}' and '{2}'." },
	        Excessive_stack_depth_comparing_types_0_and_1: { code: 2321, category: ts.DiagnosticCategory.Error, key: "Excessive_stack_depth_comparing_types_0_and_1_2321", message: "Excessive stack depth comparing types '{0}' and '{1}'." },
	        Type_0_is_not_assignable_to_type_1: { code: 2322, category: ts.DiagnosticCategory.Error, key: "Type_0_is_not_assignable_to_type_1_2322", message: "Type '{0}' is not assignable to type '{1}'." },
	        Cannot_redeclare_exported_variable_0: { code: 2323, category: ts.DiagnosticCategory.Error, key: "Cannot_redeclare_exported_variable_0_2323", message: "Cannot redeclare exported variable '{0}'." },
	        Property_0_is_missing_in_type_1: { code: 2324, category: ts.DiagnosticCategory.Error, key: "Property_0_is_missing_in_type_1_2324", message: "Property '{0}' is missing in type '{1}'." },
	        Property_0_is_private_in_type_1_but_not_in_type_2: { code: 2325, category: ts.DiagnosticCategory.Error, key: "Property_0_is_private_in_type_1_but_not_in_type_2_2325", message: "Property '{0}' is private in type '{1}' but not in type '{2}'." },
	        Types_of_property_0_are_incompatible: { code: 2326, category: ts.DiagnosticCategory.Error, key: "Types_of_property_0_are_incompatible_2326", message: "Types of property '{0}' are incompatible." },
	        Property_0_is_optional_in_type_1_but_required_in_type_2: { code: 2327, category: ts.DiagnosticCategory.Error, key: "Property_0_is_optional_in_type_1_but_required_in_type_2_2327", message: "Property '{0}' is optional in type '{1}' but required in type '{2}'." },
	        Types_of_parameters_0_and_1_are_incompatible: { code: 2328, category: ts.DiagnosticCategory.Error, key: "Types_of_parameters_0_and_1_are_incompatible_2328", message: "Types of parameters '{0}' and '{1}' are incompatible." },
	        Index_signature_is_missing_in_type_0: { code: 2329, category: ts.DiagnosticCategory.Error, key: "Index_signature_is_missing_in_type_0_2329", message: "Index signature is missing in type '{0}'." },
	        Index_signatures_are_incompatible: { code: 2330, category: ts.DiagnosticCategory.Error, key: "Index_signatures_are_incompatible_2330", message: "Index signatures are incompatible." },
	        this_cannot_be_referenced_in_a_module_or_namespace_body: { code: 2331, category: ts.DiagnosticCategory.Error, key: "this_cannot_be_referenced_in_a_module_or_namespace_body_2331", message: "'this' cannot be referenced in a module or namespace body." },
	        this_cannot_be_referenced_in_current_location: { code: 2332, category: ts.DiagnosticCategory.Error, key: "this_cannot_be_referenced_in_current_location_2332", message: "'this' cannot be referenced in current location." },
	        this_cannot_be_referenced_in_constructor_arguments: { code: 2333, category: ts.DiagnosticCategory.Error, key: "this_cannot_be_referenced_in_constructor_arguments_2333", message: "'this' cannot be referenced in constructor arguments." },
	        this_cannot_be_referenced_in_a_static_property_initializer: { code: 2334, category: ts.DiagnosticCategory.Error, key: "this_cannot_be_referenced_in_a_static_property_initializer_2334", message: "'this' cannot be referenced in a static property initializer." },
	        super_can_only_be_referenced_in_a_derived_class: { code: 2335, category: ts.DiagnosticCategory.Error, key: "super_can_only_be_referenced_in_a_derived_class_2335", message: "'super' can only be referenced in a derived class." },
	        super_cannot_be_referenced_in_constructor_arguments: { code: 2336, category: ts.DiagnosticCategory.Error, key: "super_cannot_be_referenced_in_constructor_arguments_2336", message: "'super' cannot be referenced in constructor arguments." },
	        Super_calls_are_not_permitted_outside_constructors_or_in_nested_functions_inside_constructors: { code: 2337, category: ts.DiagnosticCategory.Error, key: "Super_calls_are_not_permitted_outside_constructors_or_in_nested_functions_inside_constructors_2337", message: "Super calls are not permitted outside constructors or in nested functions inside constructors." },
	        super_property_access_is_permitted_only_in_a_constructor_member_function_or_member_accessor_of_a_derived_class: { code: 2338, category: ts.DiagnosticCategory.Error, key: "super_property_access_is_permitted_only_in_a_constructor_member_function_or_member_accessor_of_a_der_2338", message: "'super' property access is permitted only in a constructor, member function, or member accessor of a derived class." },
	        Property_0_does_not_exist_on_type_1: { code: 2339, category: ts.DiagnosticCategory.Error, key: "Property_0_does_not_exist_on_type_1_2339", message: "Property '{0}' does not exist on type '{1}'." },
	        Only_public_and_protected_methods_of_the_base_class_are_accessible_via_the_super_keyword: { code: 2340, category: ts.DiagnosticCategory.Error, key: "Only_public_and_protected_methods_of_the_base_class_are_accessible_via_the_super_keyword_2340", message: "Only public and protected methods of the base class are accessible via the 'super' keyword." },
	        Property_0_is_private_and_only_accessible_within_class_1: { code: 2341, category: ts.DiagnosticCategory.Error, key: "Property_0_is_private_and_only_accessible_within_class_1_2341", message: "Property '{0}' is private and only accessible within class '{1}'." },
	        An_index_expression_argument_must_be_of_type_string_number_symbol_or_any: { code: 2342, category: ts.DiagnosticCategory.Error, key: "An_index_expression_argument_must_be_of_type_string_number_symbol_or_any_2342", message: "An index expression argument must be of type 'string', 'number', 'symbol', or 'any'." },
	        Type_0_does_not_satisfy_the_constraint_1: { code: 2344, category: ts.DiagnosticCategory.Error, key: "Type_0_does_not_satisfy_the_constraint_1_2344", message: "Type '{0}' does not satisfy the constraint '{1}'." },
	        Argument_of_type_0_is_not_assignable_to_parameter_of_type_1: { code: 2345, category: ts.DiagnosticCategory.Error, key: "Argument_of_type_0_is_not_assignable_to_parameter_of_type_1_2345", message: "Argument of type '{0}' is not assignable to parameter of type '{1}'." },
	        Supplied_parameters_do_not_match_any_signature_of_call_target: { code: 2346, category: ts.DiagnosticCategory.Error, key: "Supplied_parameters_do_not_match_any_signature_of_call_target_2346", message: "Supplied parameters do not match any signature of call target." },
	        Untyped_function_calls_may_not_accept_type_arguments: { code: 2347, category: ts.DiagnosticCategory.Error, key: "Untyped_function_calls_may_not_accept_type_arguments_2347", message: "Untyped function calls may not accept type arguments." },
	        Value_of_type_0_is_not_callable_Did_you_mean_to_include_new: { code: 2348, category: ts.DiagnosticCategory.Error, key: "Value_of_type_0_is_not_callable_Did_you_mean_to_include_new_2348", message: "Value of type '{0}' is not callable. Did you mean to include 'new'?" },
	        Cannot_invoke_an_expression_whose_type_lacks_a_call_signature: { code: 2349, category: ts.DiagnosticCategory.Error, key: "Cannot_invoke_an_expression_whose_type_lacks_a_call_signature_2349", message: "Cannot invoke an expression whose type lacks a call signature." },
	        Only_a_void_function_can_be_called_with_the_new_keyword: { code: 2350, category: ts.DiagnosticCategory.Error, key: "Only_a_void_function_can_be_called_with_the_new_keyword_2350", message: "Only a void function can be called with the 'new' keyword." },
	        Cannot_use_new_with_an_expression_whose_type_lacks_a_call_or_construct_signature: { code: 2351, category: ts.DiagnosticCategory.Error, key: "Cannot_use_new_with_an_expression_whose_type_lacks_a_call_or_construct_signature_2351", message: "Cannot use 'new' with an expression whose type lacks a call or construct signature." },
	        Neither_type_0_nor_type_1_is_assignable_to_the_other: { code: 2352, category: ts.DiagnosticCategory.Error, key: "Neither_type_0_nor_type_1_is_assignable_to_the_other_2352", message: "Neither type '{0}' nor type '{1}' is assignable to the other." },
	        Object_literal_may_only_specify_known_properties_and_0_does_not_exist_in_type_1: { code: 2353, category: ts.DiagnosticCategory.Error, key: "Object_literal_may_only_specify_known_properties_and_0_does_not_exist_in_type_1_2353", message: "Object literal may only specify known properties, and '{0}' does not exist in type '{1}'." },
	        No_best_common_type_exists_among_return_expressions: { code: 2354, category: ts.DiagnosticCategory.Error, key: "No_best_common_type_exists_among_return_expressions_2354", message: "No best common type exists among return expressions." },
	        A_function_whose_declared_type_is_neither_void_nor_any_must_return_a_value: { code: 2355, category: ts.DiagnosticCategory.Error, key: "A_function_whose_declared_type_is_neither_void_nor_any_must_return_a_value_2355", message: "A function whose declared type is neither 'void' nor 'any' must return a value." },
	        An_arithmetic_operand_must_be_of_type_any_number_or_an_enum_type: { code: 2356, category: ts.DiagnosticCategory.Error, key: "An_arithmetic_operand_must_be_of_type_any_number_or_an_enum_type_2356", message: "An arithmetic operand must be of type 'any', 'number' or an enum type." },
	        The_operand_of_an_increment_or_decrement_operator_must_be_a_variable_property_or_indexer: { code: 2357, category: ts.DiagnosticCategory.Error, key: "The_operand_of_an_increment_or_decrement_operator_must_be_a_variable_property_or_indexer_2357", message: "The operand of an increment or decrement operator must be a variable, property or indexer." },
	        The_left_hand_side_of_an_instanceof_expression_must_be_of_type_any_an_object_type_or_a_type_parameter: { code: 2358, category: ts.DiagnosticCategory.Error, key: "The_left_hand_side_of_an_instanceof_expression_must_be_of_type_any_an_object_type_or_a_type_paramete_2358", message: "The left-hand side of an 'instanceof' expression must be of type 'any', an object type or a type parameter." },
	        The_right_hand_side_of_an_instanceof_expression_must_be_of_type_any_or_of_a_type_assignable_to_the_Function_interface_type: { code: 2359, category: ts.DiagnosticCategory.Error, key: "The_right_hand_side_of_an_instanceof_expression_must_be_of_type_any_or_of_a_type_assignable_to_the_F_2359", message: "The right-hand side of an 'instanceof' expression must be of type 'any' or of a type assignable to the 'Function' interface type." },
	        The_left_hand_side_of_an_in_expression_must_be_of_type_any_string_number_or_symbol: { code: 2360, category: ts.DiagnosticCategory.Error, key: "The_left_hand_side_of_an_in_expression_must_be_of_type_any_string_number_or_symbol_2360", message: "The left-hand side of an 'in' expression must be of type 'any', 'string', 'number', or 'symbol'." },
	        The_right_hand_side_of_an_in_expression_must_be_of_type_any_an_object_type_or_a_type_parameter: { code: 2361, category: ts.DiagnosticCategory.Error, key: "The_right_hand_side_of_an_in_expression_must_be_of_type_any_an_object_type_or_a_type_parameter_2361", message: "The right-hand side of an 'in' expression must be of type 'any', an object type or a type parameter" },
	        The_left_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_or_an_enum_type: { code: 2362, category: ts.DiagnosticCategory.Error, key: "The_left_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_or_an_enum_type_2362", message: "The left-hand side of an arithmetic operation must be of type 'any', 'number' or an enum type." },
	        The_right_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_or_an_enum_type: { code: 2363, category: ts.DiagnosticCategory.Error, key: "The_right_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_or_an_enum_type_2363", message: "The right-hand side of an arithmetic operation must be of type 'any', 'number' or an enum type." },
	        Invalid_left_hand_side_of_assignment_expression: { code: 2364, category: ts.DiagnosticCategory.Error, key: "Invalid_left_hand_side_of_assignment_expression_2364", message: "Invalid left-hand side of assignment expression." },
	        Operator_0_cannot_be_applied_to_types_1_and_2: { code: 2365, category: ts.DiagnosticCategory.Error, key: "Operator_0_cannot_be_applied_to_types_1_and_2_2365", message: "Operator '{0}' cannot be applied to types '{1}' and '{2}'." },
	        Type_parameter_name_cannot_be_0: { code: 2368, category: ts.DiagnosticCategory.Error, key: "Type_parameter_name_cannot_be_0_2368", message: "Type parameter name cannot be '{0}'" },
	        A_parameter_property_is_only_allowed_in_a_constructor_implementation: { code: 2369, category: ts.DiagnosticCategory.Error, key: "A_parameter_property_is_only_allowed_in_a_constructor_implementation_2369", message: "A parameter property is only allowed in a constructor implementation." },
	        A_rest_parameter_must_be_of_an_array_type: { code: 2370, category: ts.DiagnosticCategory.Error, key: "A_rest_parameter_must_be_of_an_array_type_2370", message: "A rest parameter must be of an array type." },
	        A_parameter_initializer_is_only_allowed_in_a_function_or_constructor_implementation: { code: 2371, category: ts.DiagnosticCategory.Error, key: "A_parameter_initializer_is_only_allowed_in_a_function_or_constructor_implementation_2371", message: "A parameter initializer is only allowed in a function or constructor implementation." },
	        Parameter_0_cannot_be_referenced_in_its_initializer: { code: 2372, category: ts.DiagnosticCategory.Error, key: "Parameter_0_cannot_be_referenced_in_its_initializer_2372", message: "Parameter '{0}' cannot be referenced in its initializer." },
	        Initializer_of_parameter_0_cannot_reference_identifier_1_declared_after_it: { code: 2373, category: ts.DiagnosticCategory.Error, key: "Initializer_of_parameter_0_cannot_reference_identifier_1_declared_after_it_2373", message: "Initializer of parameter '{0}' cannot reference identifier '{1}' declared after it." },
	        Duplicate_string_index_signature: { code: 2374, category: ts.DiagnosticCategory.Error, key: "Duplicate_string_index_signature_2374", message: "Duplicate string index signature." },
	        Duplicate_number_index_signature: { code: 2375, category: ts.DiagnosticCategory.Error, key: "Duplicate_number_index_signature_2375", message: "Duplicate number index signature." },
	        A_super_call_must_be_the_first_statement_in_the_constructor_when_a_class_contains_initialized_properties_or_has_parameter_properties: { code: 2376, category: ts.DiagnosticCategory.Error, key: "A_super_call_must_be_the_first_statement_in_the_constructor_when_a_class_contains_initialized_proper_2376", message: "A 'super' call must be the first statement in the constructor when a class contains initialized properties or has parameter properties." },
	        Constructors_for_derived_classes_must_contain_a_super_call: { code: 2377, category: ts.DiagnosticCategory.Error, key: "Constructors_for_derived_classes_must_contain_a_super_call_2377", message: "Constructors for derived classes must contain a 'super' call." },
	        A_get_accessor_must_return_a_value: { code: 2378, category: ts.DiagnosticCategory.Error, key: "A_get_accessor_must_return_a_value_2378", message: "A 'get' accessor must return a value." },
	        Getter_and_setter_accessors_do_not_agree_in_visibility: { code: 2379, category: ts.DiagnosticCategory.Error, key: "Getter_and_setter_accessors_do_not_agree_in_visibility_2379", message: "Getter and setter accessors do not agree in visibility." },
	        get_and_set_accessor_must_have_the_same_type: { code: 2380, category: ts.DiagnosticCategory.Error, key: "get_and_set_accessor_must_have_the_same_type_2380", message: "'get' and 'set' accessor must have the same type." },
	        A_signature_with_an_implementation_cannot_use_a_string_literal_type: { code: 2381, category: ts.DiagnosticCategory.Error, key: "A_signature_with_an_implementation_cannot_use_a_string_literal_type_2381", message: "A signature with an implementation cannot use a string literal type." },
	        Specialized_overload_signature_is_not_assignable_to_any_non_specialized_signature: { code: 2382, category: ts.DiagnosticCategory.Error, key: "Specialized_overload_signature_is_not_assignable_to_any_non_specialized_signature_2382", message: "Specialized overload signature is not assignable to any non-specialized signature." },
	        Overload_signatures_must_all_be_exported_or_not_exported: { code: 2383, category: ts.DiagnosticCategory.Error, key: "Overload_signatures_must_all_be_exported_or_not_exported_2383", message: "Overload signatures must all be exported or not exported." },
	        Overload_signatures_must_all_be_ambient_or_non_ambient: { code: 2384, category: ts.DiagnosticCategory.Error, key: "Overload_signatures_must_all_be_ambient_or_non_ambient_2384", message: "Overload signatures must all be ambient or non-ambient." },
	        Overload_signatures_must_all_be_public_private_or_protected: { code: 2385, category: ts.DiagnosticCategory.Error, key: "Overload_signatures_must_all_be_public_private_or_protected_2385", message: "Overload signatures must all be public, private or protected." },
	        Overload_signatures_must_all_be_optional_or_required: { code: 2386, category: ts.DiagnosticCategory.Error, key: "Overload_signatures_must_all_be_optional_or_required_2386", message: "Overload signatures must all be optional or required." },
	        Function_overload_must_be_static: { code: 2387, category: ts.DiagnosticCategory.Error, key: "Function_overload_must_be_static_2387", message: "Function overload must be static." },
	        Function_overload_must_not_be_static: { code: 2388, category: ts.DiagnosticCategory.Error, key: "Function_overload_must_not_be_static_2388", message: "Function overload must not be static." },
	        Function_implementation_name_must_be_0: { code: 2389, category: ts.DiagnosticCategory.Error, key: "Function_implementation_name_must_be_0_2389", message: "Function implementation name must be '{0}'." },
	        Constructor_implementation_is_missing: { code: 2390, category: ts.DiagnosticCategory.Error, key: "Constructor_implementation_is_missing_2390", message: "Constructor implementation is missing." },
	        Function_implementation_is_missing_or_not_immediately_following_the_declaration: { code: 2391, category: ts.DiagnosticCategory.Error, key: "Function_implementation_is_missing_or_not_immediately_following_the_declaration_2391", message: "Function implementation is missing or not immediately following the declaration." },
	        Multiple_constructor_implementations_are_not_allowed: { code: 2392, category: ts.DiagnosticCategory.Error, key: "Multiple_constructor_implementations_are_not_allowed_2392", message: "Multiple constructor implementations are not allowed." },
	        Duplicate_function_implementation: { code: 2393, category: ts.DiagnosticCategory.Error, key: "Duplicate_function_implementation_2393", message: "Duplicate function implementation." },
	        Overload_signature_is_not_compatible_with_function_implementation: { code: 2394, category: ts.DiagnosticCategory.Error, key: "Overload_signature_is_not_compatible_with_function_implementation_2394", message: "Overload signature is not compatible with function implementation." },
	        Individual_declarations_in_merged_declaration_0_must_be_all_exported_or_all_local: { code: 2395, category: ts.DiagnosticCategory.Error, key: "Individual_declarations_in_merged_declaration_0_must_be_all_exported_or_all_local_2395", message: "Individual declarations in merged declaration '{0}' must be all exported or all local." },
	        Duplicate_identifier_arguments_Compiler_uses_arguments_to_initialize_rest_parameters: { code: 2396, category: ts.DiagnosticCategory.Error, key: "Duplicate_identifier_arguments_Compiler_uses_arguments_to_initialize_rest_parameters_2396", message: "Duplicate identifier 'arguments'. Compiler uses 'arguments' to initialize rest parameters." },
	        Declaration_name_conflicts_with_built_in_global_identifier_0: { code: 2397, category: ts.DiagnosticCategory.Error, key: "Declaration_name_conflicts_with_built_in_global_identifier_0_2397", message: "Declaration name conflicts with built-in global identifier '{0}'." },
	        Duplicate_identifier_this_Compiler_uses_variable_declaration_this_to_capture_this_reference: { code: 2399, category: ts.DiagnosticCategory.Error, key: "Duplicate_identifier_this_Compiler_uses_variable_declaration_this_to_capture_this_reference_2399", message: "Duplicate identifier '_this'. Compiler uses variable declaration '_this' to capture 'this' reference." },
	        Expression_resolves_to_variable_declaration_this_that_compiler_uses_to_capture_this_reference: { code: 2400, category: ts.DiagnosticCategory.Error, key: "Expression_resolves_to_variable_declaration_this_that_compiler_uses_to_capture_this_reference_2400", message: "Expression resolves to variable declaration '_this' that compiler uses to capture 'this' reference." },
	        Duplicate_identifier_super_Compiler_uses_super_to_capture_base_class_reference: { code: 2401, category: ts.DiagnosticCategory.Error, key: "Duplicate_identifier_super_Compiler_uses_super_to_capture_base_class_reference_2401", message: "Duplicate identifier '_super'. Compiler uses '_super' to capture base class reference." },
	        Expression_resolves_to_super_that_compiler_uses_to_capture_base_class_reference: { code: 2402, category: ts.DiagnosticCategory.Error, key: "Expression_resolves_to_super_that_compiler_uses_to_capture_base_class_reference_2402", message: "Expression resolves to '_super' that compiler uses to capture base class reference." },
	        Subsequent_variable_declarations_must_have_the_same_type_Variable_0_must_be_of_type_1_but_here_has_type_2: { code: 2403, category: ts.DiagnosticCategory.Error, key: "Subsequent_variable_declarations_must_have_the_same_type_Variable_0_must_be_of_type_1_but_here_has_t_2403", message: "Subsequent variable declarations must have the same type.  Variable '{0}' must be of type '{1}', but here has type '{2}'." },
	        The_left_hand_side_of_a_for_in_statement_cannot_use_a_type_annotation: { code: 2404, category: ts.DiagnosticCategory.Error, key: "The_left_hand_side_of_a_for_in_statement_cannot_use_a_type_annotation_2404", message: "The left-hand side of a 'for...in' statement cannot use a type annotation." },
	        The_left_hand_side_of_a_for_in_statement_must_be_of_type_string_or_any: { code: 2405, category: ts.DiagnosticCategory.Error, key: "The_left_hand_side_of_a_for_in_statement_must_be_of_type_string_or_any_2405", message: "The left-hand side of a 'for...in' statement must be of type 'string' or 'any'." },
	        Invalid_left_hand_side_in_for_in_statement: { code: 2406, category: ts.DiagnosticCategory.Error, key: "Invalid_left_hand_side_in_for_in_statement_2406", message: "Invalid left-hand side in 'for...in' statement." },
	        The_right_hand_side_of_a_for_in_statement_must_be_of_type_any_an_object_type_or_a_type_parameter: { code: 2407, category: ts.DiagnosticCategory.Error, key: "The_right_hand_side_of_a_for_in_statement_must_be_of_type_any_an_object_type_or_a_type_parameter_2407", message: "The right-hand side of a 'for...in' statement must be of type 'any', an object type or a type parameter." },
	        Setters_cannot_return_a_value: { code: 2408, category: ts.DiagnosticCategory.Error, key: "Setters_cannot_return_a_value_2408", message: "Setters cannot return a value." },
	        Return_type_of_constructor_signature_must_be_assignable_to_the_instance_type_of_the_class: { code: 2409, category: ts.DiagnosticCategory.Error, key: "Return_type_of_constructor_signature_must_be_assignable_to_the_instance_type_of_the_class_2409", message: "Return type of constructor signature must be assignable to the instance type of the class" },
	        All_symbols_within_a_with_block_will_be_resolved_to_any: { code: 2410, category: ts.DiagnosticCategory.Error, key: "All_symbols_within_a_with_block_will_be_resolved_to_any_2410", message: "All symbols within a 'with' block will be resolved to 'any'." },
	        Property_0_of_type_1_is_not_assignable_to_string_index_type_2: { code: 2411, category: ts.DiagnosticCategory.Error, key: "Property_0_of_type_1_is_not_assignable_to_string_index_type_2_2411", message: "Property '{0}' of type '{1}' is not assignable to string index type '{2}'." },
	        Property_0_of_type_1_is_not_assignable_to_numeric_index_type_2: { code: 2412, category: ts.DiagnosticCategory.Error, key: "Property_0_of_type_1_is_not_assignable_to_numeric_index_type_2_2412", message: "Property '{0}' of type '{1}' is not assignable to numeric index type '{2}'." },
	        Numeric_index_type_0_is_not_assignable_to_string_index_type_1: { code: 2413, category: ts.DiagnosticCategory.Error, key: "Numeric_index_type_0_is_not_assignable_to_string_index_type_1_2413", message: "Numeric index type '{0}' is not assignable to string index type '{1}'." },
	        Class_name_cannot_be_0: { code: 2414, category: ts.DiagnosticCategory.Error, key: "Class_name_cannot_be_0_2414", message: "Class name cannot be '{0}'" },
	        Class_0_incorrectly_extends_base_class_1: { code: 2415, category: ts.DiagnosticCategory.Error, key: "Class_0_incorrectly_extends_base_class_1_2415", message: "Class '{0}' incorrectly extends base class '{1}'." },
	        Class_static_side_0_incorrectly_extends_base_class_static_side_1: { code: 2417, category: ts.DiagnosticCategory.Error, key: "Class_static_side_0_incorrectly_extends_base_class_static_side_1_2417", message: "Class static side '{0}' incorrectly extends base class static side '{1}'." },
	        Type_name_0_in_extends_clause_does_not_reference_constructor_function_for_0: { code: 2419, category: ts.DiagnosticCategory.Error, key: "Type_name_0_in_extends_clause_does_not_reference_constructor_function_for_0_2419", message: "Type name '{0}' in extends clause does not reference constructor function for '{0}'." },
	        Class_0_incorrectly_implements_interface_1: { code: 2420, category: ts.DiagnosticCategory.Error, key: "Class_0_incorrectly_implements_interface_1_2420", message: "Class '{0}' incorrectly implements interface '{1}'." },
	        A_class_may_only_implement_another_class_or_interface: { code: 2422, category: ts.DiagnosticCategory.Error, key: "A_class_may_only_implement_another_class_or_interface_2422", message: "A class may only implement another class or interface." },
	        Class_0_defines_instance_member_function_1_but_extended_class_2_defines_it_as_instance_member_accessor: { code: 2423, category: ts.DiagnosticCategory.Error, key: "Class_0_defines_instance_member_function_1_but_extended_class_2_defines_it_as_instance_member_access_2423", message: "Class '{0}' defines instance member function '{1}', but extended class '{2}' defines it as instance member accessor." },
	        Class_0_defines_instance_member_function_1_but_extended_class_2_defines_it_as_instance_member_property: { code: 2424, category: ts.DiagnosticCategory.Error, key: "Class_0_defines_instance_member_function_1_but_extended_class_2_defines_it_as_instance_member_proper_2424", message: "Class '{0}' defines instance member function '{1}', but extended class '{2}' defines it as instance member property." },
	        Class_0_defines_instance_member_property_1_but_extended_class_2_defines_it_as_instance_member_function: { code: 2425, category: ts.DiagnosticCategory.Error, key: "Class_0_defines_instance_member_property_1_but_extended_class_2_defines_it_as_instance_member_functi_2425", message: "Class '{0}' defines instance member property '{1}', but extended class '{2}' defines it as instance member function." },
	        Class_0_defines_instance_member_accessor_1_but_extended_class_2_defines_it_as_instance_member_function: { code: 2426, category: ts.DiagnosticCategory.Error, key: "Class_0_defines_instance_member_accessor_1_but_extended_class_2_defines_it_as_instance_member_functi_2426", message: "Class '{0}' defines instance member accessor '{1}', but extended class '{2}' defines it as instance member function." },
	        Interface_name_cannot_be_0: { code: 2427, category: ts.DiagnosticCategory.Error, key: "Interface_name_cannot_be_0_2427", message: "Interface name cannot be '{0}'" },
	        All_declarations_of_an_interface_must_have_identical_type_parameters: { code: 2428, category: ts.DiagnosticCategory.Error, key: "All_declarations_of_an_interface_must_have_identical_type_parameters_2428", message: "All declarations of an interface must have identical type parameters." },
	        Interface_0_incorrectly_extends_interface_1: { code: 2430, category: ts.DiagnosticCategory.Error, key: "Interface_0_incorrectly_extends_interface_1_2430", message: "Interface '{0}' incorrectly extends interface '{1}'." },
	        Enum_name_cannot_be_0: { code: 2431, category: ts.DiagnosticCategory.Error, key: "Enum_name_cannot_be_0_2431", message: "Enum name cannot be '{0}'" },
	        In_an_enum_with_multiple_declarations_only_one_declaration_can_omit_an_initializer_for_its_first_enum_element: { code: 2432, category: ts.DiagnosticCategory.Error, key: "In_an_enum_with_multiple_declarations_only_one_declaration_can_omit_an_initializer_for_its_first_enu_2432", message: "In an enum with multiple declarations, only one declaration can omit an initializer for its first enum element." },
	        A_namespace_declaration_cannot_be_in_a_different_file_from_a_class_or_function_with_which_it_is_merged: { code: 2433, category: ts.DiagnosticCategory.Error, key: "A_namespace_declaration_cannot_be_in_a_different_file_from_a_class_or_function_with_which_it_is_merg_2433", message: "A namespace declaration cannot be in a different file from a class or function with which it is merged" },
	        A_namespace_declaration_cannot_be_located_prior_to_a_class_or_function_with_which_it_is_merged: { code: 2434, category: ts.DiagnosticCategory.Error, key: "A_namespace_declaration_cannot_be_located_prior_to_a_class_or_function_with_which_it_is_merged_2434", message: "A namespace declaration cannot be located prior to a class or function with which it is merged" },
	        Ambient_modules_cannot_be_nested_in_other_modules_or_namespaces: { code: 2435, category: ts.DiagnosticCategory.Error, key: "Ambient_modules_cannot_be_nested_in_other_modules_or_namespaces_2435", message: "Ambient modules cannot be nested in other modules or namespaces." },
	        Ambient_module_declaration_cannot_specify_relative_module_name: { code: 2436, category: ts.DiagnosticCategory.Error, key: "Ambient_module_declaration_cannot_specify_relative_module_name_2436", message: "Ambient module declaration cannot specify relative module name." },
	        Module_0_is_hidden_by_a_local_declaration_with_the_same_name: { code: 2437, category: ts.DiagnosticCategory.Error, key: "Module_0_is_hidden_by_a_local_declaration_with_the_same_name_2437", message: "Module '{0}' is hidden by a local declaration with the same name" },
	        Import_name_cannot_be_0: { code: 2438, category: ts.DiagnosticCategory.Error, key: "Import_name_cannot_be_0_2438", message: "Import name cannot be '{0}'" },
	        Import_or_export_declaration_in_an_ambient_module_declaration_cannot_reference_module_through_relative_module_name: { code: 2439, category: ts.DiagnosticCategory.Error, key: "Import_or_export_declaration_in_an_ambient_module_declaration_cannot_reference_module_through_relati_2439", message: "Import or export declaration in an ambient module declaration cannot reference module through relative module name." },
	        Import_declaration_conflicts_with_local_declaration_of_0: { code: 2440, category: ts.DiagnosticCategory.Error, key: "Import_declaration_conflicts_with_local_declaration_of_0_2440", message: "Import declaration conflicts with local declaration of '{0}'" },
	        Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module: { code: 2441, category: ts.DiagnosticCategory.Error, key: "Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module_2441", message: "Duplicate identifier '{0}'. Compiler reserves name '{1}' in top level scope of a module." },
	        Types_have_separate_declarations_of_a_private_property_0: { code: 2442, category: ts.DiagnosticCategory.Error, key: "Types_have_separate_declarations_of_a_private_property_0_2442", message: "Types have separate declarations of a private property '{0}'." },
	        Property_0_is_protected_but_type_1_is_not_a_class_derived_from_2: { code: 2443, category: ts.DiagnosticCategory.Error, key: "Property_0_is_protected_but_type_1_is_not_a_class_derived_from_2_2443", message: "Property '{0}' is protected but type '{1}' is not a class derived from '{2}'." },
	        Property_0_is_protected_in_type_1_but_public_in_type_2: { code: 2444, category: ts.DiagnosticCategory.Error, key: "Property_0_is_protected_in_type_1_but_public_in_type_2_2444", message: "Property '{0}' is protected in type '{1}' but public in type '{2}'." },
	        Property_0_is_protected_and_only_accessible_within_class_1_and_its_subclasses: { code: 2445, category: ts.DiagnosticCategory.Error, key: "Property_0_is_protected_and_only_accessible_within_class_1_and_its_subclasses_2445", message: "Property '{0}' is protected and only accessible within class '{1}' and its subclasses." },
	        Property_0_is_protected_and_only_accessible_through_an_instance_of_class_1: { code: 2446, category: ts.DiagnosticCategory.Error, key: "Property_0_is_protected_and_only_accessible_through_an_instance_of_class_1_2446", message: "Property '{0}' is protected and only accessible through an instance of class '{1}'." },
	        The_0_operator_is_not_allowed_for_boolean_types_Consider_using_1_instead: { code: 2447, category: ts.DiagnosticCategory.Error, key: "The_0_operator_is_not_allowed_for_boolean_types_Consider_using_1_instead_2447", message: "The '{0}' operator is not allowed for boolean types. Consider using '{1}' instead." },
	        Block_scoped_variable_0_used_before_its_declaration: { code: 2448, category: ts.DiagnosticCategory.Error, key: "Block_scoped_variable_0_used_before_its_declaration_2448", message: "Block-scoped variable '{0}' used before its declaration." },
	        The_operand_of_an_increment_or_decrement_operator_cannot_be_a_constant: { code: 2449, category: ts.DiagnosticCategory.Error, key: "The_operand_of_an_increment_or_decrement_operator_cannot_be_a_constant_2449", message: "The operand of an increment or decrement operator cannot be a constant." },
	        Left_hand_side_of_assignment_expression_cannot_be_a_constant: { code: 2450, category: ts.DiagnosticCategory.Error, key: "Left_hand_side_of_assignment_expression_cannot_be_a_constant_2450", message: "Left-hand side of assignment expression cannot be a constant." },
	        Cannot_redeclare_block_scoped_variable_0: { code: 2451, category: ts.DiagnosticCategory.Error, key: "Cannot_redeclare_block_scoped_variable_0_2451", message: "Cannot redeclare block-scoped variable '{0}'." },
	        An_enum_member_cannot_have_a_numeric_name: { code: 2452, category: ts.DiagnosticCategory.Error, key: "An_enum_member_cannot_have_a_numeric_name_2452", message: "An enum member cannot have a numeric name." },
	        The_type_argument_for_type_parameter_0_cannot_be_inferred_from_the_usage_Consider_specifying_the_type_arguments_explicitly: { code: 2453, category: ts.DiagnosticCategory.Error, key: "The_type_argument_for_type_parameter_0_cannot_be_inferred_from_the_usage_Consider_specifying_the_typ_2453", message: "The type argument for type parameter '{0}' cannot be inferred from the usage. Consider specifying the type arguments explicitly." },
	        Type_argument_candidate_1_is_not_a_valid_type_argument_because_it_is_not_a_supertype_of_candidate_0: { code: 2455, category: ts.DiagnosticCategory.Error, key: "Type_argument_candidate_1_is_not_a_valid_type_argument_because_it_is_not_a_supertype_of_candidate_0_2455", message: "Type argument candidate '{1}' is not a valid type argument because it is not a supertype of candidate '{0}'." },
	        Type_alias_0_circularly_references_itself: { code: 2456, category: ts.DiagnosticCategory.Error, key: "Type_alias_0_circularly_references_itself_2456", message: "Type alias '{0}' circularly references itself." },
	        Type_alias_name_cannot_be_0: { code: 2457, category: ts.DiagnosticCategory.Error, key: "Type_alias_name_cannot_be_0_2457", message: "Type alias name cannot be '{0}'" },
	        An_AMD_module_cannot_have_multiple_name_assignments: { code: 2458, category: ts.DiagnosticCategory.Error, key: "An_AMD_module_cannot_have_multiple_name_assignments_2458", message: "An AMD module cannot have multiple name assignments." },
	        Type_0_has_no_property_1_and_no_string_index_signature: { code: 2459, category: ts.DiagnosticCategory.Error, key: "Type_0_has_no_property_1_and_no_string_index_signature_2459", message: "Type '{0}' has no property '{1}' and no string index signature." },
	        Type_0_has_no_property_1: { code: 2460, category: ts.DiagnosticCategory.Error, key: "Type_0_has_no_property_1_2460", message: "Type '{0}' has no property '{1}'." },
	        Type_0_is_not_an_array_type: { code: 2461, category: ts.DiagnosticCategory.Error, key: "Type_0_is_not_an_array_type_2461", message: "Type '{0}' is not an array type." },
	        A_rest_element_must_be_last_in_an_array_destructuring_pattern: { code: 2462, category: ts.DiagnosticCategory.Error, key: "A_rest_element_must_be_last_in_an_array_destructuring_pattern_2462", message: "A rest element must be last in an array destructuring pattern" },
	        A_binding_pattern_parameter_cannot_be_optional_in_an_implementation_signature: { code: 2463, category: ts.DiagnosticCategory.Error, key: "A_binding_pattern_parameter_cannot_be_optional_in_an_implementation_signature_2463", message: "A binding pattern parameter cannot be optional in an implementation signature." },
	        A_computed_property_name_must_be_of_type_string_number_symbol_or_any: { code: 2464, category: ts.DiagnosticCategory.Error, key: "A_computed_property_name_must_be_of_type_string_number_symbol_or_any_2464", message: "A computed property name must be of type 'string', 'number', 'symbol', or 'any'." },
	        this_cannot_be_referenced_in_a_computed_property_name: { code: 2465, category: ts.DiagnosticCategory.Error, key: "this_cannot_be_referenced_in_a_computed_property_name_2465", message: "'this' cannot be referenced in a computed property name." },
	        super_cannot_be_referenced_in_a_computed_property_name: { code: 2466, category: ts.DiagnosticCategory.Error, key: "super_cannot_be_referenced_in_a_computed_property_name_2466", message: "'super' cannot be referenced in a computed property name." },
	        A_computed_property_name_cannot_reference_a_type_parameter_from_its_containing_type: { code: 2467, category: ts.DiagnosticCategory.Error, key: "A_computed_property_name_cannot_reference_a_type_parameter_from_its_containing_type_2467", message: "A computed property name cannot reference a type parameter from its containing type." },
	        Cannot_find_global_value_0: { code: 2468, category: ts.DiagnosticCategory.Error, key: "Cannot_find_global_value_0_2468", message: "Cannot find global value '{0}'." },
	        The_0_operator_cannot_be_applied_to_type_symbol: { code: 2469, category: ts.DiagnosticCategory.Error, key: "The_0_operator_cannot_be_applied_to_type_symbol_2469", message: "The '{0}' operator cannot be applied to type 'symbol'." },
	        Symbol_reference_does_not_refer_to_the_global_Symbol_constructor_object: { code: 2470, category: ts.DiagnosticCategory.Error, key: "Symbol_reference_does_not_refer_to_the_global_Symbol_constructor_object_2470", message: "'Symbol' reference does not refer to the global Symbol constructor object." },
	        A_computed_property_name_of_the_form_0_must_be_of_type_symbol: { code: 2471, category: ts.DiagnosticCategory.Error, key: "A_computed_property_name_of_the_form_0_must_be_of_type_symbol_2471", message: "A computed property name of the form '{0}' must be of type 'symbol'." },
	        Spread_operator_in_new_expressions_is_only_available_when_targeting_ECMAScript_5_and_higher: { code: 2472, category: ts.DiagnosticCategory.Error, key: "Spread_operator_in_new_expressions_is_only_available_when_targeting_ECMAScript_5_and_higher_2472", message: "Spread operator in 'new' expressions is only available when targeting ECMAScript 5 and higher." },
	        Enum_declarations_must_all_be_const_or_non_const: { code: 2473, category: ts.DiagnosticCategory.Error, key: "Enum_declarations_must_all_be_const_or_non_const_2473", message: "Enum declarations must all be const or non-const." },
	        In_const_enum_declarations_member_initializer_must_be_constant_expression: { code: 2474, category: ts.DiagnosticCategory.Error, key: "In_const_enum_declarations_member_initializer_must_be_constant_expression_2474", message: "In 'const' enum declarations member initializer must be constant expression." },
	        const_enums_can_only_be_used_in_property_or_index_access_expressions_or_the_right_hand_side_of_an_import_declaration_or_export_assignment: { code: 2475, category: ts.DiagnosticCategory.Error, key: "const_enums_can_only_be_used_in_property_or_index_access_expressions_or_the_right_hand_side_of_an_im_2475", message: "'const' enums can only be used in property or index access expressions or the right hand side of an import declaration or export assignment." },
	        A_const_enum_member_can_only_be_accessed_using_a_string_literal: { code: 2476, category: ts.DiagnosticCategory.Error, key: "A_const_enum_member_can_only_be_accessed_using_a_string_literal_2476", message: "A const enum member can only be accessed using a string literal." },
	        const_enum_member_initializer_was_evaluated_to_a_non_finite_value: { code: 2477, category: ts.DiagnosticCategory.Error, key: "const_enum_member_initializer_was_evaluated_to_a_non_finite_value_2477", message: "'const' enum member initializer was evaluated to a non-finite value." },
	        const_enum_member_initializer_was_evaluated_to_disallowed_value_NaN: { code: 2478, category: ts.DiagnosticCategory.Error, key: "const_enum_member_initializer_was_evaluated_to_disallowed_value_NaN_2478", message: "'const' enum member initializer was evaluated to disallowed value 'NaN'." },
	        Property_0_does_not_exist_on_const_enum_1: { code: 2479, category: ts.DiagnosticCategory.Error, key: "Property_0_does_not_exist_on_const_enum_1_2479", message: "Property '{0}' does not exist on 'const' enum '{1}'." },
	        let_is_not_allowed_to_be_used_as_a_name_in_let_or_const_declarations: { code: 2480, category: ts.DiagnosticCategory.Error, key: "let_is_not_allowed_to_be_used_as_a_name_in_let_or_const_declarations_2480", message: "'let' is not allowed to be used as a name in 'let' or 'const' declarations." },
	        Cannot_initialize_outer_scoped_variable_0_in_the_same_scope_as_block_scoped_declaration_1: { code: 2481, category: ts.DiagnosticCategory.Error, key: "Cannot_initialize_outer_scoped_variable_0_in_the_same_scope_as_block_scoped_declaration_1_2481", message: "Cannot initialize outer scoped variable '{0}' in the same scope as block scoped declaration '{1}'." },
	        The_left_hand_side_of_a_for_of_statement_cannot_use_a_type_annotation: { code: 2483, category: ts.DiagnosticCategory.Error, key: "The_left_hand_side_of_a_for_of_statement_cannot_use_a_type_annotation_2483", message: "The left-hand side of a 'for...of' statement cannot use a type annotation." },
	        Export_declaration_conflicts_with_exported_declaration_of_0: { code: 2484, category: ts.DiagnosticCategory.Error, key: "Export_declaration_conflicts_with_exported_declaration_of_0_2484", message: "Export declaration conflicts with exported declaration of '{0}'" },
	        The_left_hand_side_of_a_for_of_statement_cannot_be_a_previously_defined_constant: { code: 2485, category: ts.DiagnosticCategory.Error, key: "The_left_hand_side_of_a_for_of_statement_cannot_be_a_previously_defined_constant_2485", message: "The left-hand side of a 'for...of' statement cannot be a previously defined constant." },
	        The_left_hand_side_of_a_for_in_statement_cannot_be_a_previously_defined_constant: { code: 2486, category: ts.DiagnosticCategory.Error, key: "The_left_hand_side_of_a_for_in_statement_cannot_be_a_previously_defined_constant_2486", message: "The left-hand side of a 'for...in' statement cannot be a previously defined constant." },
	        Invalid_left_hand_side_in_for_of_statement: { code: 2487, category: ts.DiagnosticCategory.Error, key: "Invalid_left_hand_side_in_for_of_statement_2487", message: "Invalid left-hand side in 'for...of' statement." },
	        Type_must_have_a_Symbol_iterator_method_that_returns_an_iterator: { code: 2488, category: ts.DiagnosticCategory.Error, key: "Type_must_have_a_Symbol_iterator_method_that_returns_an_iterator_2488", message: "Type must have a '[Symbol.iterator]()' method that returns an iterator." },
	        An_iterator_must_have_a_next_method: { code: 2489, category: ts.DiagnosticCategory.Error, key: "An_iterator_must_have_a_next_method_2489", message: "An iterator must have a 'next()' method." },
	        The_type_returned_by_the_next_method_of_an_iterator_must_have_a_value_property: { code: 2490, category: ts.DiagnosticCategory.Error, key: "The_type_returned_by_the_next_method_of_an_iterator_must_have_a_value_property_2490", message: "The type returned by the 'next()' method of an iterator must have a 'value' property." },
	        The_left_hand_side_of_a_for_in_statement_cannot_be_a_destructuring_pattern: { code: 2491, category: ts.DiagnosticCategory.Error, key: "The_left_hand_side_of_a_for_in_statement_cannot_be_a_destructuring_pattern_2491", message: "The left-hand side of a 'for...in' statement cannot be a destructuring pattern." },
	        Cannot_redeclare_identifier_0_in_catch_clause: { code: 2492, category: ts.DiagnosticCategory.Error, key: "Cannot_redeclare_identifier_0_in_catch_clause_2492", message: "Cannot redeclare identifier '{0}' in catch clause" },
	        Tuple_type_0_with_length_1_cannot_be_assigned_to_tuple_with_length_2: { code: 2493, category: ts.DiagnosticCategory.Error, key: "Tuple_type_0_with_length_1_cannot_be_assigned_to_tuple_with_length_2_2493", message: "Tuple type '{0}' with length '{1}' cannot be assigned to tuple with length '{2}'." },
	        Using_a_string_in_a_for_of_statement_is_only_supported_in_ECMAScript_5_and_higher: { code: 2494, category: ts.DiagnosticCategory.Error, key: "Using_a_string_in_a_for_of_statement_is_only_supported_in_ECMAScript_5_and_higher_2494", message: "Using a string in a 'for...of' statement is only supported in ECMAScript 5 and higher." },
	        Type_0_is_not_an_array_type_or_a_string_type: { code: 2495, category: ts.DiagnosticCategory.Error, key: "Type_0_is_not_an_array_type_or_a_string_type_2495", message: "Type '{0}' is not an array type or a string type." },
	        The_arguments_object_cannot_be_referenced_in_an_arrow_function_in_ES3_and_ES5_Consider_using_a_standard_function_expression: { code: 2496, category: ts.DiagnosticCategory.Error, key: "The_arguments_object_cannot_be_referenced_in_an_arrow_function_in_ES3_and_ES5_Consider_using_a_stand_2496", message: "The 'arguments' object cannot be referenced in an arrow function in ES3 and ES5. Consider using a standard function expression." },
	        Module_0_resolves_to_a_non_module_entity_and_cannot_be_imported_using_this_construct: { code: 2497, category: ts.DiagnosticCategory.Error, key: "Module_0_resolves_to_a_non_module_entity_and_cannot_be_imported_using_this_construct_2497", message: "Module '{0}' resolves to a non-module entity and cannot be imported using this construct." },
	        Module_0_uses_export_and_cannot_be_used_with_export_Asterisk: { code: 2498, category: ts.DiagnosticCategory.Error, key: "Module_0_uses_export_and_cannot_be_used_with_export_Asterisk_2498", message: "Module '{0}' uses 'export =' and cannot be used with 'export *'." },
	        An_interface_can_only_extend_an_identifier_Slashqualified_name_with_optional_type_arguments: { code: 2499, category: ts.DiagnosticCategory.Error, key: "An_interface_can_only_extend_an_identifier_Slashqualified_name_with_optional_type_arguments_2499", message: "An interface can only extend an identifier/qualified-name with optional type arguments." },
	        A_class_can_only_implement_an_identifier_Slashqualified_name_with_optional_type_arguments: { code: 2500, category: ts.DiagnosticCategory.Error, key: "A_class_can_only_implement_an_identifier_Slashqualified_name_with_optional_type_arguments_2500", message: "A class can only implement an identifier/qualified-name with optional type arguments." },
	        A_rest_element_cannot_contain_a_binding_pattern: { code: 2501, category: ts.DiagnosticCategory.Error, key: "A_rest_element_cannot_contain_a_binding_pattern_2501", message: "A rest element cannot contain a binding pattern." },
	        _0_is_referenced_directly_or_indirectly_in_its_own_type_annotation: { code: 2502, category: ts.DiagnosticCategory.Error, key: "_0_is_referenced_directly_or_indirectly_in_its_own_type_annotation_2502", message: "'{0}' is referenced directly or indirectly in its own type annotation." },
	        Cannot_find_namespace_0: { code: 2503, category: ts.DiagnosticCategory.Error, key: "Cannot_find_namespace_0_2503", message: "Cannot find namespace '{0}'." },
	        No_best_common_type_exists_among_yield_expressions: { code: 2504, category: ts.DiagnosticCategory.Error, key: "No_best_common_type_exists_among_yield_expressions_2504", message: "No best common type exists among yield expressions." },
	        A_generator_cannot_have_a_void_type_annotation: { code: 2505, category: ts.DiagnosticCategory.Error, key: "A_generator_cannot_have_a_void_type_annotation_2505", message: "A generator cannot have a 'void' type annotation." },
	        _0_is_referenced_directly_or_indirectly_in_its_own_base_expression: { code: 2506, category: ts.DiagnosticCategory.Error, key: "_0_is_referenced_directly_or_indirectly_in_its_own_base_expression_2506", message: "'{0}' is referenced directly or indirectly in its own base expression." },
	        Type_0_is_not_a_constructor_function_type: { code: 2507, category: ts.DiagnosticCategory.Error, key: "Type_0_is_not_a_constructor_function_type_2507", message: "Type '{0}' is not a constructor function type." },
	        No_base_constructor_has_the_specified_number_of_type_arguments: { code: 2508, category: ts.DiagnosticCategory.Error, key: "No_base_constructor_has_the_specified_number_of_type_arguments_2508", message: "No base constructor has the specified number of type arguments." },
	        Base_constructor_return_type_0_is_not_a_class_or_interface_type: { code: 2509, category: ts.DiagnosticCategory.Error, key: "Base_constructor_return_type_0_is_not_a_class_or_interface_type_2509", message: "Base constructor return type '{0}' is not a class or interface type." },
	        Base_constructors_must_all_have_the_same_return_type: { code: 2510, category: ts.DiagnosticCategory.Error, key: "Base_constructors_must_all_have_the_same_return_type_2510", message: "Base constructors must all have the same return type." },
	        Cannot_create_an_instance_of_the_abstract_class_0: { code: 2511, category: ts.DiagnosticCategory.Error, key: "Cannot_create_an_instance_of_the_abstract_class_0_2511", message: "Cannot create an instance of the abstract class '{0}'." },
	        Overload_signatures_must_all_be_abstract_or_not_abstract: { code: 2512, category: ts.DiagnosticCategory.Error, key: "Overload_signatures_must_all_be_abstract_or_not_abstract_2512", message: "Overload signatures must all be abstract or not abstract." },
	        Abstract_method_0_in_class_1_cannot_be_accessed_via_super_expression: { code: 2513, category: ts.DiagnosticCategory.Error, key: "Abstract_method_0_in_class_1_cannot_be_accessed_via_super_expression_2513", message: "Abstract method '{0}' in class '{1}' cannot be accessed via super expression." },
	        Classes_containing_abstract_methods_must_be_marked_abstract: { code: 2514, category: ts.DiagnosticCategory.Error, key: "Classes_containing_abstract_methods_must_be_marked_abstract_2514", message: "Classes containing abstract methods must be marked abstract." },
	        Non_abstract_class_0_does_not_implement_inherited_abstract_member_1_from_class_2: { code: 2515, category: ts.DiagnosticCategory.Error, key: "Non_abstract_class_0_does_not_implement_inherited_abstract_member_1_from_class_2_2515", message: "Non-abstract class '{0}' does not implement inherited abstract member '{1}' from class '{2}'." },
	        All_declarations_of_an_abstract_method_must_be_consecutive: { code: 2516, category: ts.DiagnosticCategory.Error, key: "All_declarations_of_an_abstract_method_must_be_consecutive_2516", message: "All declarations of an abstract method must be consecutive." },
	        Cannot_assign_an_abstract_constructor_type_to_a_non_abstract_constructor_type: { code: 2517, category: ts.DiagnosticCategory.Error, key: "Cannot_assign_an_abstract_constructor_type_to_a_non_abstract_constructor_type_2517", message: "Cannot assign an abstract constructor type to a non-abstract constructor type." },
	        A_this_based_type_guard_is_not_compatible_with_a_parameter_based_type_guard: { code: 2518, category: ts.DiagnosticCategory.Error, key: "A_this_based_type_guard_is_not_compatible_with_a_parameter_based_type_guard_2518", message: "A 'this'-based type guard is not compatible with a parameter-based type guard." },
	        Duplicate_identifier_0_Compiler_uses_declaration_1_to_support_async_functions: { code: 2520, category: ts.DiagnosticCategory.Error, key: "Duplicate_identifier_0_Compiler_uses_declaration_1_to_support_async_functions_2520", message: "Duplicate identifier '{0}'. Compiler uses declaration '{1}' to support async functions." },
	        Expression_resolves_to_variable_declaration_0_that_compiler_uses_to_support_async_functions: { code: 2521, category: ts.DiagnosticCategory.Error, key: "Expression_resolves_to_variable_declaration_0_that_compiler_uses_to_support_async_functions_2521", message: "Expression resolves to variable declaration '{0}' that compiler uses to support async functions." },
	        The_arguments_object_cannot_be_referenced_in_an_async_arrow_function_Consider_using_a_standard_async_function_expression: { code: 2522, category: ts.DiagnosticCategory.Error, key: "The_arguments_object_cannot_be_referenced_in_an_async_arrow_function_Consider_using_a_standard_async_2522", message: "The 'arguments' object cannot be referenced in an async arrow function. Consider using a standard async function expression." },
	        yield_expressions_cannot_be_used_in_a_parameter_initializer: { code: 2523, category: ts.DiagnosticCategory.Error, key: "yield_expressions_cannot_be_used_in_a_parameter_initializer_2523", message: "'yield' expressions cannot be used in a parameter initializer." },
	        await_expressions_cannot_be_used_in_a_parameter_initializer: { code: 2524, category: ts.DiagnosticCategory.Error, key: "await_expressions_cannot_be_used_in_a_parameter_initializer_2524", message: "'await' expressions cannot be used in a parameter initializer." },
	        Initializer_provides_no_value_for_this_binding_element_and_the_binding_element_has_no_default_value: { code: 2525, category: ts.DiagnosticCategory.Error, key: "Initializer_provides_no_value_for_this_binding_element_and_the_binding_element_has_no_default_value_2525", message: "Initializer provides no value for this binding element and the binding element has no default value." },
	        A_this_type_is_available_only_in_a_non_static_member_of_a_class_or_interface: { code: 2526, category: ts.DiagnosticCategory.Error, key: "A_this_type_is_available_only_in_a_non_static_member_of_a_class_or_interface_2526", message: "A 'this' type is available only in a non-static member of a class or interface." },
	        The_inferred_type_of_0_references_an_inaccessible_this_type_A_type_annotation_is_necessary: { code: 2527, category: ts.DiagnosticCategory.Error, key: "The_inferred_type_of_0_references_an_inaccessible_this_type_A_type_annotation_is_necessary_2527", message: "The inferred type of '{0}' references an inaccessible 'this' type. A type annotation is necessary." },
	        A_module_cannot_have_multiple_default_exports: { code: 2528, category: ts.DiagnosticCategory.Error, key: "A_module_cannot_have_multiple_default_exports_2528", message: "A module cannot have multiple default exports." },
	        Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module_containing_async_functions: { code: 2529, category: ts.DiagnosticCategory.Error, key: "Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module_containing_async_func_2529", message: "Duplicate identifier '{0}'. Compiler reserves name '{1}' in top level scope of a module containing async functions." },
	        JSX_element_attributes_type_0_may_not_be_a_union_type: { code: 2600, category: ts.DiagnosticCategory.Error, key: "JSX_element_attributes_type_0_may_not_be_a_union_type_2600", message: "JSX element attributes type '{0}' may not be a union type." },
	        The_return_type_of_a_JSX_element_constructor_must_return_an_object_type: { code: 2601, category: ts.DiagnosticCategory.Error, key: "The_return_type_of_a_JSX_element_constructor_must_return_an_object_type_2601", message: "The return type of a JSX element constructor must return an object type." },
	        JSX_element_implicitly_has_type_any_because_the_global_type_JSX_Element_does_not_exist: { code: 2602, category: ts.DiagnosticCategory.Error, key: "JSX_element_implicitly_has_type_any_because_the_global_type_JSX_Element_does_not_exist_2602", message: "JSX element implicitly has type 'any' because the global type 'JSX.Element' does not exist." },
	        Property_0_in_type_1_is_not_assignable_to_type_2: { code: 2603, category: ts.DiagnosticCategory.Error, key: "Property_0_in_type_1_is_not_assignable_to_type_2_2603", message: "Property '{0}' in type '{1}' is not assignable to type '{2}'" },
	        JSX_element_type_0_does_not_have_any_construct_or_call_signatures: { code: 2604, category: ts.DiagnosticCategory.Error, key: "JSX_element_type_0_does_not_have_any_construct_or_call_signatures_2604", message: "JSX element type '{0}' does not have any construct or call signatures." },
	        JSX_element_type_0_is_not_a_constructor_function_for_JSX_elements: { code: 2605, category: ts.DiagnosticCategory.Error, key: "JSX_element_type_0_is_not_a_constructor_function_for_JSX_elements_2605", message: "JSX element type '{0}' is not a constructor function for JSX elements." },
	        Property_0_of_JSX_spread_attribute_is_not_assignable_to_target_property: { code: 2606, category: ts.DiagnosticCategory.Error, key: "Property_0_of_JSX_spread_attribute_is_not_assignable_to_target_property_2606", message: "Property '{0}' of JSX spread attribute is not assignable to target property." },
	        JSX_element_class_does_not_support_attributes_because_it_does_not_have_a_0_property: { code: 2607, category: ts.DiagnosticCategory.Error, key: "JSX_element_class_does_not_support_attributes_because_it_does_not_have_a_0_property_2607", message: "JSX element class does not support attributes because it does not have a '{0}' property" },
	        The_global_type_JSX_0_may_not_have_more_than_one_property: { code: 2608, category: ts.DiagnosticCategory.Error, key: "The_global_type_JSX_0_may_not_have_more_than_one_property_2608", message: "The global type 'JSX.{0}' may not have more than one property" },
	        Cannot_emit_namespaced_JSX_elements_in_React: { code: 2650, category: ts.DiagnosticCategory.Error, key: "Cannot_emit_namespaced_JSX_elements_in_React_2650", message: "Cannot emit namespaced JSX elements in React" },
	        A_member_initializer_in_a_enum_declaration_cannot_reference_members_declared_after_it_including_members_defined_in_other_enums: { code: 2651, category: ts.DiagnosticCategory.Error, key: "A_member_initializer_in_a_enum_declaration_cannot_reference_members_declared_after_it_including_memb_2651", message: "A member initializer in a enum declaration cannot reference members declared after it, including members defined in other enums." },
	        Merged_declaration_0_cannot_include_a_default_export_declaration_Consider_adding_a_separate_export_default_0_declaration_instead: { code: 2652, category: ts.DiagnosticCategory.Error, key: "Merged_declaration_0_cannot_include_a_default_export_declaration_Consider_adding_a_separate_export_d_2652", message: "Merged declaration '{0}' cannot include a default export declaration. Consider adding a separate 'export default {0}' declaration instead." },
	        Non_abstract_class_expression_does_not_implement_inherited_abstract_member_0_from_class_1: { code: 2653, category: ts.DiagnosticCategory.Error, key: "Non_abstract_class_expression_does_not_implement_inherited_abstract_member_0_from_class_1_2653", message: "Non-abstract class expression does not implement inherited abstract member '{0}' from class '{1}'." },
	        Exported_external_package_typings_file_cannot_contain_tripleslash_references_Please_contact_the_package_author_to_update_the_package_definition: { code: 2654, category: ts.DiagnosticCategory.Error, key: "Exported_external_package_typings_file_cannot_contain_tripleslash_references_Please_contact_the_pack_2654", message: "Exported external package typings file cannot contain tripleslash references. Please contact the package author to update the package definition." },
	        Exported_external_package_typings_file_0_is_not_a_module_Please_contact_the_package_author_to_update_the_package_definition: { code: 2656, category: ts.DiagnosticCategory.Error, key: "Exported_external_package_typings_file_0_is_not_a_module_Please_contact_the_package_author_to_update_2656", message: "Exported external package typings file '{0}' is not a module. Please contact the package author to update the package definition." },
	        JSX_expressions_must_have_one_parent_element: { code: 2657, category: ts.DiagnosticCategory.Error, key: "JSX_expressions_must_have_one_parent_element_2657", message: "JSX expressions must have one parent element" },
	        Type_0_provides_no_match_for_the_signature_1: { code: 2658, category: ts.DiagnosticCategory.Error, key: "Type_0_provides_no_match_for_the_signature_1_2658", message: "Type '{0}' provides no match for the signature '{1}'" },
	        super_is_only_allowed_in_members_of_object_literal_expressions_when_option_target_is_ES2015_or_higher: { code: 2659, category: ts.DiagnosticCategory.Error, key: "super_is_only_allowed_in_members_of_object_literal_expressions_when_option_target_is_ES2015_or_highe_2659", message: "'super' is only allowed in members of object literal expressions when option 'target' is 'ES2015' or higher." },
	        super_can_only_be_referenced_in_members_of_derived_classes_or_object_literal_expressions: { code: 2660, category: ts.DiagnosticCategory.Error, key: "super_can_only_be_referenced_in_members_of_derived_classes_or_object_literal_expressions_2660", message: "'super' can only be referenced in members of derived classes or object literal expressions." },
	        Cannot_re_export_name_that_is_not_defined_in_the_module: { code: 2661, category: ts.DiagnosticCategory.Error, key: "Cannot_re_export_name_that_is_not_defined_in_the_module_2661", message: "Cannot re-export name that is not defined in the module." },
	        Cannot_find_name_0_Did_you_mean_the_static_member_1_0: { code: 2662, category: ts.DiagnosticCategory.Error, key: "Cannot_find_name_0_Did_you_mean_the_static_member_1_0_2662", message: "Cannot find name '{0}'. Did you mean the static member '{1}.{0}'?" },
	        Cannot_find_name_0_Did_you_mean_the_instance_member_this_0: { code: 2663, category: ts.DiagnosticCategory.Error, key: "Cannot_find_name_0_Did_you_mean_the_instance_member_this_0_2663", message: "Cannot find name '{0}'. Did you mean the instance member 'this.{0}'?" },
	        Invalid_module_name_in_augmentation_module_0_cannot_be_found: { code: 2664, category: ts.DiagnosticCategory.Error, key: "Invalid_module_name_in_augmentation_module_0_cannot_be_found_2664", message: "Invalid module name in augmentation, module '{0}' cannot be found." },
	        Module_augmentation_cannot_introduce_new_names_in_the_top_level_scope: { code: 2665, category: ts.DiagnosticCategory.Error, key: "Module_augmentation_cannot_introduce_new_names_in_the_top_level_scope_2665", message: "Module augmentation cannot introduce new names in the top level scope." },
	        Exports_and_export_assignments_are_not_permitted_in_module_augmentations: { code: 2666, category: ts.DiagnosticCategory.Error, key: "Exports_and_export_assignments_are_not_permitted_in_module_augmentations_2666", message: "Exports and export assignments are not permitted in module augmentations." },
	        Imports_are_not_permitted_in_module_augmentations_Consider_moving_them_to_the_enclosing_external_module: { code: 2667, category: ts.DiagnosticCategory.Error, key: "Imports_are_not_permitted_in_module_augmentations_Consider_moving_them_to_the_enclosing_external_mod_2667", message: "Imports are not permitted in module augmentations. Consider moving them to the enclosing external module." },
	        export_modifier_cannot_be_applied_to_ambient_modules_and_module_augmentations_since_they_are_always_visible: { code: 2668, category: ts.DiagnosticCategory.Error, key: "export_modifier_cannot_be_applied_to_ambient_modules_and_module_augmentations_since_they_are_always__2668", message: "'export' modifier cannot be applied to ambient modules and module augmentations since they are always visible." },
	        Augmentations_for_the_global_scope_can_only_be_directly_nested_in_external_modules_or_ambient_module_declarations: { code: 2669, category: ts.DiagnosticCategory.Error, key: "Augmentations_for_the_global_scope_can_only_be_directly_nested_in_external_modules_or_ambient_module_2669", message: "Augmentations for the global scope can only be directly nested in external modules or ambient module declarations." },
	        Augmentations_for_the_global_scope_should_have_declare_modifier_unless_they_appear_in_already_ambient_context: { code: 2670, category: ts.DiagnosticCategory.Error, key: "Augmentations_for_the_global_scope_should_have_declare_modifier_unless_they_appear_in_already_ambien_2670", message: "Augmentations for the global scope should have 'declare' modifier unless they appear in already ambient context." },
	        Cannot_augment_module_0_because_it_resolves_to_a_non_module_entity: { code: 2671, category: ts.DiagnosticCategory.Error, key: "Cannot_augment_module_0_because_it_resolves_to_a_non_module_entity_2671", message: "Cannot augment module '{0}' because it resolves to a non-module entity." },
	        Import_declaration_0_is_using_private_name_1: { code: 4000, category: ts.DiagnosticCategory.Error, key: "Import_declaration_0_is_using_private_name_1_4000", message: "Import declaration '{0}' is using private name '{1}'." },
	        Type_parameter_0_of_exported_class_has_or_is_using_private_name_1: { code: 4002, category: ts.DiagnosticCategory.Error, key: "Type_parameter_0_of_exported_class_has_or_is_using_private_name_1_4002", message: "Type parameter '{0}' of exported class has or is using private name '{1}'." },
	        Type_parameter_0_of_exported_interface_has_or_is_using_private_name_1: { code: 4004, category: ts.DiagnosticCategory.Error, key: "Type_parameter_0_of_exported_interface_has_or_is_using_private_name_1_4004", message: "Type parameter '{0}' of exported interface has or is using private name '{1}'." },
	        Type_parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1: { code: 4006, category: ts.DiagnosticCategory.Error, key: "Type_parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1_4006", message: "Type parameter '{0}' of constructor signature from exported interface has or is using private name '{1}'." },
	        Type_parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1: { code: 4008, category: ts.DiagnosticCategory.Error, key: "Type_parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1_4008", message: "Type parameter '{0}' of call signature from exported interface has or is using private name '{1}'." },
	        Type_parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1: { code: 4010, category: ts.DiagnosticCategory.Error, key: "Type_parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1_4010", message: "Type parameter '{0}' of public static method from exported class has or is using private name '{1}'." },
	        Type_parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1: { code: 4012, category: ts.DiagnosticCategory.Error, key: "Type_parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1_4012", message: "Type parameter '{0}' of public method from exported class has or is using private name '{1}'." },
	        Type_parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1: { code: 4014, category: ts.DiagnosticCategory.Error, key: "Type_parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1_4014", message: "Type parameter '{0}' of method from exported interface has or is using private name '{1}'." },
	        Type_parameter_0_of_exported_function_has_or_is_using_private_name_1: { code: 4016, category: ts.DiagnosticCategory.Error, key: "Type_parameter_0_of_exported_function_has_or_is_using_private_name_1_4016", message: "Type parameter '{0}' of exported function has or is using private name '{1}'." },
	        Implements_clause_of_exported_class_0_has_or_is_using_private_name_1: { code: 4019, category: ts.DiagnosticCategory.Error, key: "Implements_clause_of_exported_class_0_has_or_is_using_private_name_1_4019", message: "Implements clause of exported class '{0}' has or is using private name '{1}'." },
	        Extends_clause_of_exported_class_0_has_or_is_using_private_name_1: { code: 4020, category: ts.DiagnosticCategory.Error, key: "Extends_clause_of_exported_class_0_has_or_is_using_private_name_1_4020", message: "Extends clause of exported class '{0}' has or is using private name '{1}'." },
	        Extends_clause_of_exported_interface_0_has_or_is_using_private_name_1: { code: 4022, category: ts.DiagnosticCategory.Error, key: "Extends_clause_of_exported_interface_0_has_or_is_using_private_name_1_4022", message: "Extends clause of exported interface '{0}' has or is using private name '{1}'." },
	        Exported_variable_0_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: { code: 4023, category: ts.DiagnosticCategory.Error, key: "Exported_variable_0_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named_4023", message: "Exported variable '{0}' has or is using name '{1}' from external module {2} but cannot be named." },
	        Exported_variable_0_has_or_is_using_name_1_from_private_module_2: { code: 4024, category: ts.DiagnosticCategory.Error, key: "Exported_variable_0_has_or_is_using_name_1_from_private_module_2_4024", message: "Exported variable '{0}' has or is using name '{1}' from private module '{2}'." },
	        Exported_variable_0_has_or_is_using_private_name_1: { code: 4025, category: ts.DiagnosticCategory.Error, key: "Exported_variable_0_has_or_is_using_private_name_1_4025", message: "Exported variable '{0}' has or is using private name '{1}'." },
	        Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: { code: 4026, category: ts.DiagnosticCategory.Error, key: "Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot__4026", message: "Public static property '{0}' of exported class has or is using name '{1}' from external module {2} but cannot be named." },
	        Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2: { code: 4027, category: ts.DiagnosticCategory.Error, key: "Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2_4027", message: "Public static property '{0}' of exported class has or is using name '{1}' from private module '{2}'." },
	        Public_static_property_0_of_exported_class_has_or_is_using_private_name_1: { code: 4028, category: ts.DiagnosticCategory.Error, key: "Public_static_property_0_of_exported_class_has_or_is_using_private_name_1_4028", message: "Public static property '{0}' of exported class has or is using private name '{1}'." },
	        Public_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: { code: 4029, category: ts.DiagnosticCategory.Error, key: "Public_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_name_4029", message: "Public property '{0}' of exported class has or is using name '{1}' from external module {2} but cannot be named." },
	        Public_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2: { code: 4030, category: ts.DiagnosticCategory.Error, key: "Public_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2_4030", message: "Public property '{0}' of exported class has or is using name '{1}' from private module '{2}'." },
	        Public_property_0_of_exported_class_has_or_is_using_private_name_1: { code: 4031, category: ts.DiagnosticCategory.Error, key: "Public_property_0_of_exported_class_has_or_is_using_private_name_1_4031", message: "Public property '{0}' of exported class has or is using private name '{1}'." },
	        Property_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2: { code: 4032, category: ts.DiagnosticCategory.Error, key: "Property_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2_4032", message: "Property '{0}' of exported interface has or is using name '{1}' from private module '{2}'." },
	        Property_0_of_exported_interface_has_or_is_using_private_name_1: { code: 4033, category: ts.DiagnosticCategory.Error, key: "Property_0_of_exported_interface_has_or_is_using_private_name_1_4033", message: "Property '{0}' of exported interface has or is using private name '{1}'." },
	        Parameter_0_of_public_static_property_setter_from_exported_class_has_or_is_using_name_1_from_private_module_2: { code: 4034, category: ts.DiagnosticCategory.Error, key: "Parameter_0_of_public_static_property_setter_from_exported_class_has_or_is_using_name_1_from_private_4034", message: "Parameter '{0}' of public static property setter from exported class has or is using name '{1}' from private module '{2}'." },
	        Parameter_0_of_public_static_property_setter_from_exported_class_has_or_is_using_private_name_1: { code: 4035, category: ts.DiagnosticCategory.Error, key: "Parameter_0_of_public_static_property_setter_from_exported_class_has_or_is_using_private_name_1_4035", message: "Parameter '{0}' of public static property setter from exported class has or is using private name '{1}'." },
	        Parameter_0_of_public_property_setter_from_exported_class_has_or_is_using_name_1_from_private_module_2: { code: 4036, category: ts.DiagnosticCategory.Error, key: "Parameter_0_of_public_property_setter_from_exported_class_has_or_is_using_name_1_from_private_module_4036", message: "Parameter '{0}' of public property setter from exported class has or is using name '{1}' from private module '{2}'." },
	        Parameter_0_of_public_property_setter_from_exported_class_has_or_is_using_private_name_1: { code: 4037, category: ts.DiagnosticCategory.Error, key: "Parameter_0_of_public_property_setter_from_exported_class_has_or_is_using_private_name_1_4037", message: "Parameter '{0}' of public property setter from exported class has or is using private name '{1}'." },
	        Return_type_of_public_static_property_getter_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named: { code: 4038, category: ts.DiagnosticCategory.Error, key: "Return_type_of_public_static_property_getter_from_exported_class_has_or_is_using_name_0_from_externa_4038", message: "Return type of public static property getter from exported class has or is using name '{0}' from external module {1} but cannot be named." },
	        Return_type_of_public_static_property_getter_from_exported_class_has_or_is_using_name_0_from_private_module_1: { code: 4039, category: ts.DiagnosticCategory.Error, key: "Return_type_of_public_static_property_getter_from_exported_class_has_or_is_using_name_0_from_private_4039", message: "Return type of public static property getter from exported class has or is using name '{0}' from private module '{1}'." },
	        Return_type_of_public_static_property_getter_from_exported_class_has_or_is_using_private_name_0: { code: 4040, category: ts.DiagnosticCategory.Error, key: "Return_type_of_public_static_property_getter_from_exported_class_has_or_is_using_private_name_0_4040", message: "Return type of public static property getter from exported class has or is using private name '{0}'." },
	        Return_type_of_public_property_getter_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named: { code: 4041, category: ts.DiagnosticCategory.Error, key: "Return_type_of_public_property_getter_from_exported_class_has_or_is_using_name_0_from_external_modul_4041", message: "Return type of public property getter from exported class has or is using name '{0}' from external module {1} but cannot be named." },
	        Return_type_of_public_property_getter_from_exported_class_has_or_is_using_name_0_from_private_module_1: { code: 4042, category: ts.DiagnosticCategory.Error, key: "Return_type_of_public_property_getter_from_exported_class_has_or_is_using_name_0_from_private_module_4042", message: "Return type of public property getter from exported class has or is using name '{0}' from private module '{1}'." },
	        Return_type_of_public_property_getter_from_exported_class_has_or_is_using_private_name_0: { code: 4043, category: ts.DiagnosticCategory.Error, key: "Return_type_of_public_property_getter_from_exported_class_has_or_is_using_private_name_0_4043", message: "Return type of public property getter from exported class has or is using private name '{0}'." },
	        Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1: { code: 4044, category: ts.DiagnosticCategory.Error, key: "Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_name_0_from_private_mod_4044", message: "Return type of constructor signature from exported interface has or is using name '{0}' from private module '{1}'." },
	        Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_0: { code: 4045, category: ts.DiagnosticCategory.Error, key: "Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_0_4045", message: "Return type of constructor signature from exported interface has or is using private name '{0}'." },
	        Return_type_of_call_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1: { code: 4046, category: ts.DiagnosticCategory.Error, key: "Return_type_of_call_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1_4046", message: "Return type of call signature from exported interface has or is using name '{0}' from private module '{1}'." },
	        Return_type_of_call_signature_from_exported_interface_has_or_is_using_private_name_0: { code: 4047, category: ts.DiagnosticCategory.Error, key: "Return_type_of_call_signature_from_exported_interface_has_or_is_using_private_name_0_4047", message: "Return type of call signature from exported interface has or is using private name '{0}'." },
	        Return_type_of_index_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1: { code: 4048, category: ts.DiagnosticCategory.Error, key: "Return_type_of_index_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1_4048", message: "Return type of index signature from exported interface has or is using name '{0}' from private module '{1}'." },
	        Return_type_of_index_signature_from_exported_interface_has_or_is_using_private_name_0: { code: 4049, category: ts.DiagnosticCategory.Error, key: "Return_type_of_index_signature_from_exported_interface_has_or_is_using_private_name_0_4049", message: "Return type of index signature from exported interface has or is using private name '{0}'." },
	        Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named: { code: 4050, category: ts.DiagnosticCategory.Error, key: "Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_external_module__4050", message: "Return type of public static method from exported class has or is using name '{0}' from external module {1} but cannot be named." },
	        Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_private_module_1: { code: 4051, category: ts.DiagnosticCategory.Error, key: "Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_private_module_1_4051", message: "Return type of public static method from exported class has or is using name '{0}' from private module '{1}'." },
	        Return_type_of_public_static_method_from_exported_class_has_or_is_using_private_name_0: { code: 4052, category: ts.DiagnosticCategory.Error, key: "Return_type_of_public_static_method_from_exported_class_has_or_is_using_private_name_0_4052", message: "Return type of public static method from exported class has or is using private name '{0}'." },
	        Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named: { code: 4053, category: ts.DiagnosticCategory.Error, key: "Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_c_4053", message: "Return type of public method from exported class has or is using name '{0}' from external module {1} but cannot be named." },
	        Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_private_module_1: { code: 4054, category: ts.DiagnosticCategory.Error, key: "Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_private_module_1_4054", message: "Return type of public method from exported class has or is using name '{0}' from private module '{1}'." },
	        Return_type_of_public_method_from_exported_class_has_or_is_using_private_name_0: { code: 4055, category: ts.DiagnosticCategory.Error, key: "Return_type_of_public_method_from_exported_class_has_or_is_using_private_name_0_4055", message: "Return type of public method from exported class has or is using private name '{0}'." },
	        Return_type_of_method_from_exported_interface_has_or_is_using_name_0_from_private_module_1: { code: 4056, category: ts.DiagnosticCategory.Error, key: "Return_type_of_method_from_exported_interface_has_or_is_using_name_0_from_private_module_1_4056", message: "Return type of method from exported interface has or is using name '{0}' from private module '{1}'." },
	        Return_type_of_method_from_exported_interface_has_or_is_using_private_name_0: { code: 4057, category: ts.DiagnosticCategory.Error, key: "Return_type_of_method_from_exported_interface_has_or_is_using_private_name_0_4057", message: "Return type of method from exported interface has or is using private name '{0}'." },
	        Return_type_of_exported_function_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named: { code: 4058, category: ts.DiagnosticCategory.Error, key: "Return_type_of_exported_function_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named_4058", message: "Return type of exported function has or is using name '{0}' from external module {1} but cannot be named." },
	        Return_type_of_exported_function_has_or_is_using_name_0_from_private_module_1: { code: 4059, category: ts.DiagnosticCategory.Error, key: "Return_type_of_exported_function_has_or_is_using_name_0_from_private_module_1_4059", message: "Return type of exported function has or is using name '{0}' from private module '{1}'." },
	        Return_type_of_exported_function_has_or_is_using_private_name_0: { code: 4060, category: ts.DiagnosticCategory.Error, key: "Return_type_of_exported_function_has_or_is_using_private_name_0_4060", message: "Return type of exported function has or is using private name '{0}'." },
	        Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: { code: 4061, category: ts.DiagnosticCategory.Error, key: "Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_can_4061", message: "Parameter '{0}' of constructor from exported class has or is using name '{1}' from external module {2} but cannot be named." },
	        Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_private_module_2: { code: 4062, category: ts.DiagnosticCategory.Error, key: "Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_private_module_2_4062", message: "Parameter '{0}' of constructor from exported class has or is using name '{1}' from private module '{2}'." },
	        Parameter_0_of_constructor_from_exported_class_has_or_is_using_private_name_1: { code: 4063, category: ts.DiagnosticCategory.Error, key: "Parameter_0_of_constructor_from_exported_class_has_or_is_using_private_name_1_4063", message: "Parameter '{0}' of constructor from exported class has or is using private name '{1}'." },
	        Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2: { code: 4064, category: ts.DiagnosticCategory.Error, key: "Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_name_1_from_private_mod_4064", message: "Parameter '{0}' of constructor signature from exported interface has or is using name '{1}' from private module '{2}'." },
	        Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1: { code: 4065, category: ts.DiagnosticCategory.Error, key: "Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1_4065", message: "Parameter '{0}' of constructor signature from exported interface has or is using private name '{1}'." },
	        Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2: { code: 4066, category: ts.DiagnosticCategory.Error, key: "Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2_4066", message: "Parameter '{0}' of call signature from exported interface has or is using name '{1}' from private module '{2}'." },
	        Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1: { code: 4067, category: ts.DiagnosticCategory.Error, key: "Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1_4067", message: "Parameter '{0}' of call signature from exported interface has or is using private name '{1}'." },
	        Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: { code: 4068, category: ts.DiagnosticCategory.Error, key: "Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_external_module__4068", message: "Parameter '{0}' of public static method from exported class has or is using name '{1}' from external module {2} but cannot be named." },
	        Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_private_module_2: { code: 4069, category: ts.DiagnosticCategory.Error, key: "Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_private_module_2_4069", message: "Parameter '{0}' of public static method from exported class has or is using name '{1}' from private module '{2}'." },
	        Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1: { code: 4070, category: ts.DiagnosticCategory.Error, key: "Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1_4070", message: "Parameter '{0}' of public static method from exported class has or is using private name '{1}'." },
	        Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: { code: 4071, category: ts.DiagnosticCategory.Error, key: "Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_c_4071", message: "Parameter '{0}' of public method from exported class has or is using name '{1}' from external module {2} but cannot be named." },
	        Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_private_module_2: { code: 4072, category: ts.DiagnosticCategory.Error, key: "Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_private_module_2_4072", message: "Parameter '{0}' of public method from exported class has or is using name '{1}' from private module '{2}'." },
	        Parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1: { code: 4073, category: ts.DiagnosticCategory.Error, key: "Parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1_4073", message: "Parameter '{0}' of public method from exported class has or is using private name '{1}'." },
	        Parameter_0_of_method_from_exported_interface_has_or_is_using_name_1_from_private_module_2: { code: 4074, category: ts.DiagnosticCategory.Error, key: "Parameter_0_of_method_from_exported_interface_has_or_is_using_name_1_from_private_module_2_4074", message: "Parameter '{0}' of method from exported interface has or is using name '{1}' from private module '{2}'." },
	        Parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1: { code: 4075, category: ts.DiagnosticCategory.Error, key: "Parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1_4075", message: "Parameter '{0}' of method from exported interface has or is using private name '{1}'." },
	        Parameter_0_of_exported_function_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named: { code: 4076, category: ts.DiagnosticCategory.Error, key: "Parameter_0_of_exported_function_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named_4076", message: "Parameter '{0}' of exported function has or is using name '{1}' from external module {2} but cannot be named." },
	        Parameter_0_of_exported_function_has_or_is_using_name_1_from_private_module_2: { code: 4077, category: ts.DiagnosticCategory.Error, key: "Parameter_0_of_exported_function_has_or_is_using_name_1_from_private_module_2_4077", message: "Parameter '{0}' of exported function has or is using name '{1}' from private module '{2}'." },
	        Parameter_0_of_exported_function_has_or_is_using_private_name_1: { code: 4078, category: ts.DiagnosticCategory.Error, key: "Parameter_0_of_exported_function_has_or_is_using_private_name_1_4078", message: "Parameter '{0}' of exported function has or is using private name '{1}'." },
	        Exported_type_alias_0_has_or_is_using_private_name_1: { code: 4081, category: ts.DiagnosticCategory.Error, key: "Exported_type_alias_0_has_or_is_using_private_name_1_4081", message: "Exported type alias '{0}' has or is using private name '{1}'." },
	        Default_export_of_the_module_has_or_is_using_private_name_0: { code: 4082, category: ts.DiagnosticCategory.Error, key: "Default_export_of_the_module_has_or_is_using_private_name_0_4082", message: "Default export of the module has or is using private name '{0}'." },
	        The_current_host_does_not_support_the_0_option: { code: 5001, category: ts.DiagnosticCategory.Error, key: "The_current_host_does_not_support_the_0_option_5001", message: "The current host does not support the '{0}' option." },
	        Cannot_find_the_common_subdirectory_path_for_the_input_files: { code: 5009, category: ts.DiagnosticCategory.Error, key: "Cannot_find_the_common_subdirectory_path_for_the_input_files_5009", message: "Cannot find the common subdirectory path for the input files." },
	        Cannot_read_file_0_Colon_1: { code: 5012, category: ts.DiagnosticCategory.Error, key: "Cannot_read_file_0_Colon_1_5012", message: "Cannot read file '{0}': {1}" },
	        Unsupported_file_encoding: { code: 5013, category: ts.DiagnosticCategory.Error, key: "Unsupported_file_encoding_5013", message: "Unsupported file encoding." },
	        Failed_to_parse_file_0_Colon_1: { code: 5014, category: ts.DiagnosticCategory.Error, key: "Failed_to_parse_file_0_Colon_1_5014", message: "Failed to parse file '{0}': {1}." },
	        Unknown_compiler_option_0: { code: 5023, category: ts.DiagnosticCategory.Error, key: "Unknown_compiler_option_0_5023", message: "Unknown compiler option '{0}'." },
	        Compiler_option_0_requires_a_value_of_type_1: { code: 5024, category: ts.DiagnosticCategory.Error, key: "Compiler_option_0_requires_a_value_of_type_1_5024", message: "Compiler option '{0}' requires a value of type {1}." },
	        Could_not_write_file_0_Colon_1: { code: 5033, category: ts.DiagnosticCategory.Error, key: "Could_not_write_file_0_Colon_1_5033", message: "Could not write file '{0}': {1}" },
	        Option_project_cannot_be_mixed_with_source_files_on_a_command_line: { code: 5042, category: ts.DiagnosticCategory.Error, key: "Option_project_cannot_be_mixed_with_source_files_on_a_command_line_5042", message: "Option 'project' cannot be mixed with source files on a command line." },
	        Option_isolatedModules_can_only_be_used_when_either_option_module_is_provided_or_option_target_is_ES2015_or_higher: { code: 5047, category: ts.DiagnosticCategory.Error, key: "Option_isolatedModules_can_only_be_used_when_either_option_module_is_provided_or_option_target_is_ES_5047", message: "Option 'isolatedModules' can only be used when either option '--module' is provided or option 'target' is 'ES2015' or higher." },
	        Option_inlineSources_can_only_be_used_when_either_option_inlineSourceMap_or_option_sourceMap_is_provided: { code: 5051, category: ts.DiagnosticCategory.Error, key: "Option_inlineSources_can_only_be_used_when_either_option_inlineSourceMap_or_option_sourceMap_is_prov_5051", message: "Option 'inlineSources' can only be used when either option '--inlineSourceMap' or option '--sourceMap' is provided." },
	        Option_0_cannot_be_specified_without_specifying_option_1: { code: 5052, category: ts.DiagnosticCategory.Error, key: "Option_0_cannot_be_specified_without_specifying_option_1_5052", message: "Option '{0}' cannot be specified without specifying option '{1}'." },
	        Option_0_cannot_be_specified_with_option_1: { code: 5053, category: ts.DiagnosticCategory.Error, key: "Option_0_cannot_be_specified_with_option_1_5053", message: "Option '{0}' cannot be specified with option '{1}'." },
	        A_tsconfig_json_file_is_already_defined_at_Colon_0: { code: 5054, category: ts.DiagnosticCategory.Error, key: "A_tsconfig_json_file_is_already_defined_at_Colon_0_5054", message: "A 'tsconfig.json' file is already defined at: '{0}'." },
	        Cannot_write_file_0_because_it_would_overwrite_input_file: { code: 5055, category: ts.DiagnosticCategory.Error, key: "Cannot_write_file_0_because_it_would_overwrite_input_file_5055", message: "Cannot write file '{0}' because it would overwrite input file." },
	        Cannot_write_file_0_because_it_would_be_overwritten_by_multiple_input_files: { code: 5056, category: ts.DiagnosticCategory.Error, key: "Cannot_write_file_0_because_it_would_be_overwritten_by_multiple_input_files_5056", message: "Cannot write file '{0}' because it would be overwritten by multiple input files." },
	        Cannot_find_a_tsconfig_json_file_at_the_specified_directory_Colon_0: { code: 5057, category: ts.DiagnosticCategory.Error, key: "Cannot_find_a_tsconfig_json_file_at_the_specified_directory_Colon_0_5057", message: "Cannot find a tsconfig.json file at the specified directory: '{0}'" },
	        The_specified_path_does_not_exist_Colon_0: { code: 5058, category: ts.DiagnosticCategory.Error, key: "The_specified_path_does_not_exist_Colon_0_5058", message: "The specified path does not exist: '{0}'" },
	        Invalide_value_for_reactNamespace_0_is_not_a_valid_identifier: { code: 5059, category: ts.DiagnosticCategory.Error, key: "Invalide_value_for_reactNamespace_0_is_not_a_valid_identifier_5059", message: "Invalide value for '--reactNamespace'. '{0}' is not a valid identifier." },
	        Concatenate_and_emit_output_to_single_file: { code: 6001, category: ts.DiagnosticCategory.Message, key: "Concatenate_and_emit_output_to_single_file_6001", message: "Concatenate and emit output to single file." },
	        Generates_corresponding_d_ts_file: { code: 6002, category: ts.DiagnosticCategory.Message, key: "Generates_corresponding_d_ts_file_6002", message: "Generates corresponding '.d.ts' file." },
	        Specifies_the_location_where_debugger_should_locate_map_files_instead_of_generated_locations: { code: 6003, category: ts.DiagnosticCategory.Message, key: "Specifies_the_location_where_debugger_should_locate_map_files_instead_of_generated_locations_6003", message: "Specifies the location where debugger should locate map files instead of generated locations." },
	        Specifies_the_location_where_debugger_should_locate_TypeScript_files_instead_of_source_locations: { code: 6004, category: ts.DiagnosticCategory.Message, key: "Specifies_the_location_where_debugger_should_locate_TypeScript_files_instead_of_source_locations_6004", message: "Specifies the location where debugger should locate TypeScript files instead of source locations." },
	        Watch_input_files: { code: 6005, category: ts.DiagnosticCategory.Message, key: "Watch_input_files_6005", message: "Watch input files." },
	        Redirect_output_structure_to_the_directory: { code: 6006, category: ts.DiagnosticCategory.Message, key: "Redirect_output_structure_to_the_directory_6006", message: "Redirect output structure to the directory." },
	        Do_not_erase_const_enum_declarations_in_generated_code: { code: 6007, category: ts.DiagnosticCategory.Message, key: "Do_not_erase_const_enum_declarations_in_generated_code_6007", message: "Do not erase const enum declarations in generated code." },
	        Do_not_emit_outputs_if_any_errors_were_reported: { code: 6008, category: ts.DiagnosticCategory.Message, key: "Do_not_emit_outputs_if_any_errors_were_reported_6008", message: "Do not emit outputs if any errors were reported." },
	        Do_not_emit_comments_to_output: { code: 6009, category: ts.DiagnosticCategory.Message, key: "Do_not_emit_comments_to_output_6009", message: "Do not emit comments to output." },
	        Do_not_emit_outputs: { code: 6010, category: ts.DiagnosticCategory.Message, key: "Do_not_emit_outputs_6010", message: "Do not emit outputs." },
	        Allow_default_imports_from_modules_with_no_default_export_This_does_not_affect_code_emit_just_typechecking: { code: 6011, category: ts.DiagnosticCategory.Message, key: "Allow_default_imports_from_modules_with_no_default_export_This_does_not_affect_code_emit_just_typech_6011", message: "Allow default imports from modules with no default export. This does not affect code emit, just typechecking." },
	        Specify_ECMAScript_target_version_Colon_ES3_default_ES5_or_ES2015_experimental: { code: 6015, category: ts.DiagnosticCategory.Message, key: "Specify_ECMAScript_target_version_Colon_ES3_default_ES5_or_ES2015_experimental_6015", message: "Specify ECMAScript target version: 'ES3' (default), 'ES5', or 'ES2015' (experimental)" },
	        Specify_module_code_generation_Colon_commonjs_amd_system_umd_or_es2015: { code: 6016, category: ts.DiagnosticCategory.Message, key: "Specify_module_code_generation_Colon_commonjs_amd_system_umd_or_es2015_6016", message: "Specify module code generation: 'commonjs', 'amd', 'system', 'umd' or 'es2015'" },
	        Print_this_message: { code: 6017, category: ts.DiagnosticCategory.Message, key: "Print_this_message_6017", message: "Print this message." },
	        Print_the_compiler_s_version: { code: 6019, category: ts.DiagnosticCategory.Message, key: "Print_the_compiler_s_version_6019", message: "Print the compiler's version." },
	        Compile_the_project_in_the_given_directory: { code: 6020, category: ts.DiagnosticCategory.Message, key: "Compile_the_project_in_the_given_directory_6020", message: "Compile the project in the given directory." },
	        Syntax_Colon_0: { code: 6023, category: ts.DiagnosticCategory.Message, key: "Syntax_Colon_0_6023", message: "Syntax: {0}" },
	        options: { code: 6024, category: ts.DiagnosticCategory.Message, key: "options_6024", message: "options" },
	        file: { code: 6025, category: ts.DiagnosticCategory.Message, key: "file_6025", message: "file" },
	        Examples_Colon_0: { code: 6026, category: ts.DiagnosticCategory.Message, key: "Examples_Colon_0_6026", message: "Examples: {0}" },
	        Options_Colon: { code: 6027, category: ts.DiagnosticCategory.Message, key: "Options_Colon_6027", message: "Options:" },
	        Version_0: { code: 6029, category: ts.DiagnosticCategory.Message, key: "Version_0_6029", message: "Version {0}" },
	        Insert_command_line_options_and_files_from_a_file: { code: 6030, category: ts.DiagnosticCategory.Message, key: "Insert_command_line_options_and_files_from_a_file_6030", message: "Insert command line options and files from a file." },
	        File_change_detected_Starting_incremental_compilation: { code: 6032, category: ts.DiagnosticCategory.Message, key: "File_change_detected_Starting_incremental_compilation_6032", message: "File change detected. Starting incremental compilation..." },
	        KIND: { code: 6034, category: ts.DiagnosticCategory.Message, key: "KIND_6034", message: "KIND" },
	        FILE: { code: 6035, category: ts.DiagnosticCategory.Message, key: "FILE_6035", message: "FILE" },
	        VERSION: { code: 6036, category: ts.DiagnosticCategory.Message, key: "VERSION_6036", message: "VERSION" },
	        LOCATION: { code: 6037, category: ts.DiagnosticCategory.Message, key: "LOCATION_6037", message: "LOCATION" },
	        DIRECTORY: { code: 6038, category: ts.DiagnosticCategory.Message, key: "DIRECTORY_6038", message: "DIRECTORY" },
	        Compilation_complete_Watching_for_file_changes: { code: 6042, category: ts.DiagnosticCategory.Message, key: "Compilation_complete_Watching_for_file_changes_6042", message: "Compilation complete. Watching for file changes." },
	        Generates_corresponding_map_file: { code: 6043, category: ts.DiagnosticCategory.Message, key: "Generates_corresponding_map_file_6043", message: "Generates corresponding '.map' file." },
	        Compiler_option_0_expects_an_argument: { code: 6044, category: ts.DiagnosticCategory.Error, key: "Compiler_option_0_expects_an_argument_6044", message: "Compiler option '{0}' expects an argument." },
	        Unterminated_quoted_string_in_response_file_0: { code: 6045, category: ts.DiagnosticCategory.Error, key: "Unterminated_quoted_string_in_response_file_0_6045", message: "Unterminated quoted string in response file '{0}'." },
	        Argument_for_module_option_must_be_commonjs_amd_system_umd_es2015_or_none: { code: 6046, category: ts.DiagnosticCategory.Error, key: "Argument_for_module_option_must_be_commonjs_amd_system_umd_es2015_or_none_6046", message: "Argument for '--module' option must be 'commonjs', 'amd', 'system', 'umd', 'es2015', or 'none'." },
	        Argument_for_target_option_must_be_ES3_ES5_or_ES2015: { code: 6047, category: ts.DiagnosticCategory.Error, key: "Argument_for_target_option_must_be_ES3_ES5_or_ES2015_6047", message: "Argument for '--target' option must be 'ES3', 'ES5', or 'ES2015'." },
	        Locale_must_be_of_the_form_language_or_language_territory_For_example_0_or_1: { code: 6048, category: ts.DiagnosticCategory.Error, key: "Locale_must_be_of_the_form_language_or_language_territory_For_example_0_or_1_6048", message: "Locale must be of the form <language> or <language>-<territory>. For example '{0}' or '{1}'." },
	        Unsupported_locale_0: { code: 6049, category: ts.DiagnosticCategory.Error, key: "Unsupported_locale_0_6049", message: "Unsupported locale '{0}'." },
	        Unable_to_open_file_0: { code: 6050, category: ts.DiagnosticCategory.Error, key: "Unable_to_open_file_0_6050", message: "Unable to open file '{0}'." },
	        Corrupted_locale_file_0: { code: 6051, category: ts.DiagnosticCategory.Error, key: "Corrupted_locale_file_0_6051", message: "Corrupted locale file {0}." },
	        Raise_error_on_expressions_and_declarations_with_an_implied_any_type: { code: 6052, category: ts.DiagnosticCategory.Message, key: "Raise_error_on_expressions_and_declarations_with_an_implied_any_type_6052", message: "Raise error on expressions and declarations with an implied 'any' type." },
	        File_0_not_found: { code: 6053, category: ts.DiagnosticCategory.Error, key: "File_0_not_found_6053", message: "File '{0}' not found." },
	        File_0_has_unsupported_extension_The_only_supported_extensions_are_1: { code: 6054, category: ts.DiagnosticCategory.Error, key: "File_0_has_unsupported_extension_The_only_supported_extensions_are_1_6054", message: "File '{0}' has unsupported extension. The only supported extensions are {1}." },
	        Suppress_noImplicitAny_errors_for_indexing_objects_lacking_index_signatures: { code: 6055, category: ts.DiagnosticCategory.Message, key: "Suppress_noImplicitAny_errors_for_indexing_objects_lacking_index_signatures_6055", message: "Suppress noImplicitAny errors for indexing objects lacking index signatures." },
	        Do_not_emit_declarations_for_code_that_has_an_internal_annotation: { code: 6056, category: ts.DiagnosticCategory.Message, key: "Do_not_emit_declarations_for_code_that_has_an_internal_annotation_6056", message: "Do not emit declarations for code that has an '@internal' annotation." },
	        Specifies_the_root_directory_of_input_files_Use_to_control_the_output_directory_structure_with_outDir: { code: 6058, category: ts.DiagnosticCategory.Message, key: "Specifies_the_root_directory_of_input_files_Use_to_control_the_output_directory_structure_with_outDi_6058", message: "Specifies the root directory of input files. Use to control the output directory structure with --outDir." },
	        File_0_is_not_under_rootDir_1_rootDir_is_expected_to_contain_all_source_files: { code: 6059, category: ts.DiagnosticCategory.Error, key: "File_0_is_not_under_rootDir_1_rootDir_is_expected_to_contain_all_source_files_6059", message: "File '{0}' is not under 'rootDir' '{1}'. 'rootDir' is expected to contain all source files." },
	        Specifies_the_end_of_line_sequence_to_be_used_when_emitting_files_Colon_CRLF_dos_or_LF_unix: { code: 6060, category: ts.DiagnosticCategory.Message, key: "Specifies_the_end_of_line_sequence_to_be_used_when_emitting_files_Colon_CRLF_dos_or_LF_unix_6060", message: "Specifies the end of line sequence to be used when emitting files: 'CRLF' (dos) or 'LF' (unix)." },
	        NEWLINE: { code: 6061, category: ts.DiagnosticCategory.Message, key: "NEWLINE_6061", message: "NEWLINE" },
	        Argument_for_newLine_option_must_be_CRLF_or_LF: { code: 6062, category: ts.DiagnosticCategory.Error, key: "Argument_for_newLine_option_must_be_CRLF_or_LF_6062", message: "Argument for '--newLine' option must be 'CRLF' or 'LF'." },
	        Argument_for_moduleResolution_option_must_be_node_or_classic: { code: 6063, category: ts.DiagnosticCategory.Error, key: "Argument_for_moduleResolution_option_must_be_node_or_classic_6063", message: "Argument for '--moduleResolution' option must be 'node' or 'classic'." },
	        Enables_experimental_support_for_ES7_decorators: { code: 6065, category: ts.DiagnosticCategory.Message, key: "Enables_experimental_support_for_ES7_decorators_6065", message: "Enables experimental support for ES7 decorators." },
	        Enables_experimental_support_for_emitting_type_metadata_for_decorators: { code: 6066, category: ts.DiagnosticCategory.Message, key: "Enables_experimental_support_for_emitting_type_metadata_for_decorators_6066", message: "Enables experimental support for emitting type metadata for decorators." },
	        Enables_experimental_support_for_ES7_async_functions: { code: 6068, category: ts.DiagnosticCategory.Message, key: "Enables_experimental_support_for_ES7_async_functions_6068", message: "Enables experimental support for ES7 async functions." },
	        Specifies_module_resolution_strategy_Colon_node_Node_js_or_classic_TypeScript_pre_1_6: { code: 6069, category: ts.DiagnosticCategory.Message, key: "Specifies_module_resolution_strategy_Colon_node_Node_js_or_classic_TypeScript_pre_1_6_6069", message: "Specifies module resolution strategy: 'node' (Node.js) or 'classic' (TypeScript pre-1.6)." },
	        Initializes_a_TypeScript_project_and_creates_a_tsconfig_json_file: { code: 6070, category: ts.DiagnosticCategory.Message, key: "Initializes_a_TypeScript_project_and_creates_a_tsconfig_json_file_6070", message: "Initializes a TypeScript project and creates a tsconfig.json file." },
	        Successfully_created_a_tsconfig_json_file: { code: 6071, category: ts.DiagnosticCategory.Message, key: "Successfully_created_a_tsconfig_json_file_6071", message: "Successfully created a tsconfig.json file." },
	        Suppress_excess_property_checks_for_object_literals: { code: 6072, category: ts.DiagnosticCategory.Message, key: "Suppress_excess_property_checks_for_object_literals_6072", message: "Suppress excess property checks for object literals." },
	        Stylize_errors_and_messages_using_color_and_context_experimental: { code: 6073, category: ts.DiagnosticCategory.Message, key: "Stylize_errors_and_messages_using_color_and_context_experimental_6073", message: "Stylize errors and messages using color and context. (experimental)" },
	        Do_not_report_errors_on_unused_labels: { code: 6074, category: ts.DiagnosticCategory.Message, key: "Do_not_report_errors_on_unused_labels_6074", message: "Do not report errors on unused labels." },
	        Report_error_when_not_all_code_paths_in_function_return_a_value: { code: 6075, category: ts.DiagnosticCategory.Message, key: "Report_error_when_not_all_code_paths_in_function_return_a_value_6075", message: "Report error when not all code paths in function return a value." },
	        Report_errors_for_fallthrough_cases_in_switch_statement: { code: 6076, category: ts.DiagnosticCategory.Message, key: "Report_errors_for_fallthrough_cases_in_switch_statement_6076", message: "Report errors for fallthrough cases in switch statement." },
	        Do_not_report_errors_on_unreachable_code: { code: 6077, category: ts.DiagnosticCategory.Message, key: "Do_not_report_errors_on_unreachable_code_6077", message: "Do not report errors on unreachable code." },
	        Disallow_inconsistently_cased_references_to_the_same_file: { code: 6078, category: ts.DiagnosticCategory.Message, key: "Disallow_inconsistently_cased_references_to_the_same_file_6078", message: "Disallow inconsistently-cased references to the same file." },
	        Specify_JSX_code_generation_Colon_preserve_or_react: { code: 6080, category: ts.DiagnosticCategory.Message, key: "Specify_JSX_code_generation_Colon_preserve_or_react_6080", message: "Specify JSX code generation: 'preserve' or 'react'" },
	        Argument_for_jsx_must_be_preserve_or_react: { code: 6081, category: ts.DiagnosticCategory.Message, key: "Argument_for_jsx_must_be_preserve_or_react_6081", message: "Argument for '--jsx' must be 'preserve' or 'react'." },
	        Only_amd_and_system_modules_are_supported_alongside_0: { code: 6082, category: ts.DiagnosticCategory.Error, key: "Only_amd_and_system_modules_are_supported_alongside_0_6082", message: "Only 'amd' and 'system' modules are supported alongside --{0}." },
	        Allow_javascript_files_to_be_compiled: { code: 6083, category: ts.DiagnosticCategory.Message, key: "Allow_javascript_files_to_be_compiled_6083", message: "Allow javascript files to be compiled." },
	        Specifies_the_object_invoked_for_createElement_and_spread_when_targeting_react_JSX_emit: { code: 6084, category: ts.DiagnosticCategory.Message, key: "Specifies_the_object_invoked_for_createElement_and_spread_when_targeting_react_JSX_emit_6084", message: "Specifies the object invoked for createElement and __spread when targeting 'react' JSX emit" },
	        Do_not_emit_use_strict_directives_in_module_output: { code: 6112, category: ts.DiagnosticCategory.Message, key: "Do_not_emit_use_strict_directives_in_module_output_6112", message: "Do not emit 'use strict' directives in module output." },
	        Variable_0_implicitly_has_an_1_type: { code: 7005, category: ts.DiagnosticCategory.Error, key: "Variable_0_implicitly_has_an_1_type_7005", message: "Variable '{0}' implicitly has an '{1}' type." },
	        Parameter_0_implicitly_has_an_1_type: { code: 7006, category: ts.DiagnosticCategory.Error, key: "Parameter_0_implicitly_has_an_1_type_7006", message: "Parameter '{0}' implicitly has an '{1}' type." },
	        Member_0_implicitly_has_an_1_type: { code: 7008, category: ts.DiagnosticCategory.Error, key: "Member_0_implicitly_has_an_1_type_7008", message: "Member '{0}' implicitly has an '{1}' type." },
	        new_expression_whose_target_lacks_a_construct_signature_implicitly_has_an_any_type: { code: 7009, category: ts.DiagnosticCategory.Error, key: "new_expression_whose_target_lacks_a_construct_signature_implicitly_has_an_any_type_7009", message: "'new' expression, whose target lacks a construct signature, implicitly has an 'any' type." },
	        _0_which_lacks_return_type_annotation_implicitly_has_an_1_return_type: { code: 7010, category: ts.DiagnosticCategory.Error, key: "_0_which_lacks_return_type_annotation_implicitly_has_an_1_return_type_7010", message: "'{0}', which lacks return-type annotation, implicitly has an '{1}' return type." },
	        Function_expression_which_lacks_return_type_annotation_implicitly_has_an_0_return_type: { code: 7011, category: ts.DiagnosticCategory.Error, key: "Function_expression_which_lacks_return_type_annotation_implicitly_has_an_0_return_type_7011", message: "Function expression, which lacks return-type annotation, implicitly has an '{0}' return type." },
	        Construct_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type: { code: 7013, category: ts.DiagnosticCategory.Error, key: "Construct_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type_7013", message: "Construct signature, which lacks return-type annotation, implicitly has an 'any' return type." },
	        Element_implicitly_has_an_any_type_because_index_expression_is_not_of_type_number: { code: 7015, category: ts.DiagnosticCategory.Error, key: "Element_implicitly_has_an_any_type_because_index_expression_is_not_of_type_number_7015", message: "Element implicitly has an 'any' type because index expression is not of type 'number'." },
	        Property_0_implicitly_has_type_any_because_its_set_accessor_lacks_a_type_annotation: { code: 7016, category: ts.DiagnosticCategory.Error, key: "Property_0_implicitly_has_type_any_because_its_set_accessor_lacks_a_type_annotation_7016", message: "Property '{0}' implicitly has type 'any', because its 'set' accessor lacks a type annotation." },
	        Index_signature_of_object_type_implicitly_has_an_any_type: { code: 7017, category: ts.DiagnosticCategory.Error, key: "Index_signature_of_object_type_implicitly_has_an_any_type_7017", message: "Index signature of object type implicitly has an 'any' type." },
	        Object_literal_s_property_0_implicitly_has_an_1_type: { code: 7018, category: ts.DiagnosticCategory.Error, key: "Object_literal_s_property_0_implicitly_has_an_1_type_7018", message: "Object literal's property '{0}' implicitly has an '{1}' type." },
	        Rest_parameter_0_implicitly_has_an_any_type: { code: 7019, category: ts.DiagnosticCategory.Error, key: "Rest_parameter_0_implicitly_has_an_any_type_7019", message: "Rest parameter '{0}' implicitly has an 'any[]' type." },
	        Call_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type: { code: 7020, category: ts.DiagnosticCategory.Error, key: "Call_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type_7020", message: "Call signature, which lacks return-type annotation, implicitly has an 'any' return type." },
	        _0_implicitly_has_type_any_because_it_does_not_have_a_type_annotation_and_is_referenced_directly_or_indirectly_in_its_own_initializer: { code: 7022, category: ts.DiagnosticCategory.Error, key: "_0_implicitly_has_type_any_because_it_does_not_have_a_type_annotation_and_is_referenced_directly_or__7022", message: "'{0}' implicitly has type 'any' because it does not have a type annotation and is referenced directly or indirectly in its own initializer." },
	        _0_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_referenced_directly_or_indirectly_in_one_of_its_return_expressions: { code: 7023, category: ts.DiagnosticCategory.Error, key: "_0_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_reference_7023", message: "'{0}' implicitly has return type 'any' because it does not have a return type annotation and is referenced directly or indirectly in one of its return expressions." },
	        Function_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_referenced_directly_or_indirectly_in_one_of_its_return_expressions: { code: 7024, category: ts.DiagnosticCategory.Error, key: "Function_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_ref_7024", message: "Function implicitly has return type 'any' because it does not have a return type annotation and is referenced directly or indirectly in one of its return expressions." },
	        Generator_implicitly_has_type_0_because_it_does_not_yield_any_values_Consider_supplying_a_return_type: { code: 7025, category: ts.DiagnosticCategory.Error, key: "Generator_implicitly_has_type_0_because_it_does_not_yield_any_values_Consider_supplying_a_return_typ_7025", message: "Generator implicitly has type '{0}' because it does not yield any values. Consider supplying a return type." },
	        JSX_element_implicitly_has_type_any_because_no_interface_JSX_0_exists: { code: 7026, category: ts.DiagnosticCategory.Error, key: "JSX_element_implicitly_has_type_any_because_no_interface_JSX_0_exists_7026", message: "JSX element implicitly has type 'any' because no interface 'JSX.{0}' exists" },
	        Unreachable_code_detected: { code: 7027, category: ts.DiagnosticCategory.Error, key: "Unreachable_code_detected_7027", message: "Unreachable code detected." },
	        Unused_label: { code: 7028, category: ts.DiagnosticCategory.Error, key: "Unused_label_7028", message: "Unused label." },
	        Fallthrough_case_in_switch: { code: 7029, category: ts.DiagnosticCategory.Error, key: "Fallthrough_case_in_switch_7029", message: "Fallthrough case in switch." },
	        Not_all_code_paths_return_a_value: { code: 7030, category: ts.DiagnosticCategory.Error, key: "Not_all_code_paths_return_a_value_7030", message: "Not all code paths return a value." },
	        You_cannot_rename_this_element: { code: 8000, category: ts.DiagnosticCategory.Error, key: "You_cannot_rename_this_element_8000", message: "You cannot rename this element." },
	        You_cannot_rename_elements_that_are_defined_in_the_standard_TypeScript_library: { code: 8001, category: ts.DiagnosticCategory.Error, key: "You_cannot_rename_elements_that_are_defined_in_the_standard_TypeScript_library_8001", message: "You cannot rename elements that are defined in the standard TypeScript library." },
	        import_can_only_be_used_in_a_ts_file: { code: 8002, category: ts.DiagnosticCategory.Error, key: "import_can_only_be_used_in_a_ts_file_8002", message: "'import ... =' can only be used in a .ts file." },
	        export_can_only_be_used_in_a_ts_file: { code: 8003, category: ts.DiagnosticCategory.Error, key: "export_can_only_be_used_in_a_ts_file_8003", message: "'export=' can only be used in a .ts file." },
	        type_parameter_declarations_can_only_be_used_in_a_ts_file: { code: 8004, category: ts.DiagnosticCategory.Error, key: "type_parameter_declarations_can_only_be_used_in_a_ts_file_8004", message: "'type parameter declarations' can only be used in a .ts file." },
	        implements_clauses_can_only_be_used_in_a_ts_file: { code: 8005, category: ts.DiagnosticCategory.Error, key: "implements_clauses_can_only_be_used_in_a_ts_file_8005", message: "'implements clauses' can only be used in a .ts file." },
	        interface_declarations_can_only_be_used_in_a_ts_file: { code: 8006, category: ts.DiagnosticCategory.Error, key: "interface_declarations_can_only_be_used_in_a_ts_file_8006", message: "'interface declarations' can only be used in a .ts file." },
	        module_declarations_can_only_be_used_in_a_ts_file: { code: 8007, category: ts.DiagnosticCategory.Error, key: "module_declarations_can_only_be_used_in_a_ts_file_8007", message: "'module declarations' can only be used in a .ts file." },
	        type_aliases_can_only_be_used_in_a_ts_file: { code: 8008, category: ts.DiagnosticCategory.Error, key: "type_aliases_can_only_be_used_in_a_ts_file_8008", message: "'type aliases' can only be used in a .ts file." },
	        _0_can_only_be_used_in_a_ts_file: { code: 8009, category: ts.DiagnosticCategory.Error, key: "_0_can_only_be_used_in_a_ts_file_8009", message: "'{0}' can only be used in a .ts file." },
	        types_can_only_be_used_in_a_ts_file: { code: 8010, category: ts.DiagnosticCategory.Error, key: "types_can_only_be_used_in_a_ts_file_8010", message: "'types' can only be used in a .ts file." },
	        type_arguments_can_only_be_used_in_a_ts_file: { code: 8011, category: ts.DiagnosticCategory.Error, key: "type_arguments_can_only_be_used_in_a_ts_file_8011", message: "'type arguments' can only be used in a .ts file." },
	        parameter_modifiers_can_only_be_used_in_a_ts_file: { code: 8012, category: ts.DiagnosticCategory.Error, key: "parameter_modifiers_can_only_be_used_in_a_ts_file_8012", message: "'parameter modifiers' can only be used in a .ts file." },
	        property_declarations_can_only_be_used_in_a_ts_file: { code: 8014, category: ts.DiagnosticCategory.Error, key: "property_declarations_can_only_be_used_in_a_ts_file_8014", message: "'property declarations' can only be used in a .ts file." },
	        enum_declarations_can_only_be_used_in_a_ts_file: { code: 8015, category: ts.DiagnosticCategory.Error, key: "enum_declarations_can_only_be_used_in_a_ts_file_8015", message: "'enum declarations' can only be used in a .ts file." },
	        type_assertion_expressions_can_only_be_used_in_a_ts_file: { code: 8016, category: ts.DiagnosticCategory.Error, key: "type_assertion_expressions_can_only_be_used_in_a_ts_file_8016", message: "'type assertion expressions' can only be used in a .ts file." },
	        Only_identifiers_Slashqualified_names_with_optional_type_arguments_are_currently_supported_in_a_class_extends_clauses: { code: 9002, category: ts.DiagnosticCategory.Error, key: "Only_identifiers_Slashqualified_names_with_optional_type_arguments_are_currently_supported_in_a_clas_9002", message: "Only identifiers/qualified-names with optional type arguments are currently supported in a class 'extends' clauses." },
	        class_expressions_are_not_currently_supported: { code: 9003, category: ts.DiagnosticCategory.Error, key: "class_expressions_are_not_currently_supported_9003", message: "'class' expressions are not currently supported." },
	        JSX_attributes_must_only_be_assigned_a_non_empty_expression: { code: 17000, category: ts.DiagnosticCategory.Error, key: "JSX_attributes_must_only_be_assigned_a_non_empty_expression_17000", message: "JSX attributes must only be assigned a non-empty 'expression'." },
	        JSX_elements_cannot_have_multiple_attributes_with_the_same_name: { code: 17001, category: ts.DiagnosticCategory.Error, key: "JSX_elements_cannot_have_multiple_attributes_with_the_same_name_17001", message: "JSX elements cannot have multiple attributes with the same name." },
	        Expected_corresponding_JSX_closing_tag_for_0: { code: 17002, category: ts.DiagnosticCategory.Error, key: "Expected_corresponding_JSX_closing_tag_for_0_17002", message: "Expected corresponding JSX closing tag for '{0}'." },
	        JSX_attribute_expected: { code: 17003, category: ts.DiagnosticCategory.Error, key: "JSX_attribute_expected_17003", message: "JSX attribute expected." },
	        Cannot_use_JSX_unless_the_jsx_flag_is_provided: { code: 17004, category: ts.DiagnosticCategory.Error, key: "Cannot_use_JSX_unless_the_jsx_flag_is_provided_17004", message: "Cannot use JSX unless the '--jsx' flag is provided." },
	        A_constructor_cannot_contain_a_super_call_when_its_class_extends_null: { code: 17005, category: ts.DiagnosticCategory.Error, key: "A_constructor_cannot_contain_a_super_call_when_its_class_extends_null_17005", message: "A constructor cannot contain a 'super' call when its class extends 'null'" },
	        An_unary_expression_with_the_0_operator_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Consider_enclosing_the_expression_in_parentheses: { code: 17006, category: ts.DiagnosticCategory.Error, key: "An_unary_expression_with_the_0_operator_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_ex_17006", message: "An unary expression with the '{0}' operator is not allowed in the left-hand side of an exponentiation expression. Consider enclosing the expression in parentheses." },
	        A_type_assertion_expression_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Consider_enclosing_the_expression_in_parentheses: { code: 17007, category: ts.DiagnosticCategory.Error, key: "A_type_assertion_expression_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Con_17007", message: "A type assertion expression is not allowed in the left-hand side of an exponentiation expression. Consider enclosing the expression in parentheses." },
	        JSX_element_0_has_no_corresponding_closing_tag: { code: 17008, category: ts.DiagnosticCategory.Error, key: "JSX_element_0_has_no_corresponding_closing_tag_17008", message: "JSX element '{0}' has no corresponding closing tag." },
	        super_must_be_called_before_accessing_this_in_the_constructor_of_a_derived_class: { code: 17009, category: ts.DiagnosticCategory.Error, key: "super_must_be_called_before_accessing_this_in_the_constructor_of_a_derived_class_17009", message: "'super' must be called before accessing 'this' in the constructor of a derived class." }
	    };
	})(ts || (ts = {}));
	/// <reference path="core.ts"/>
	/// <reference path="diagnosticInformationMap.generated.ts"/>
	var ts;
	(function (ts) {
	    /* @internal */
	    function tokenIsIdentifierOrKeyword(token) {
	        return token >= 69 /* Identifier */;
	    }
	    ts.tokenIsIdentifierOrKeyword = tokenIsIdentifierOrKeyword;
	    var textToToken = {
	        "abstract": 115 /* AbstractKeyword */,
	        "any": 117 /* AnyKeyword */,
	        "as": 116 /* AsKeyword */,
	        "boolean": 120 /* BooleanKeyword */,
	        "break": 70 /* BreakKeyword */,
	        "case": 71 /* CaseKeyword */,
	        "catch": 72 /* CatchKeyword */,
	        "class": 73 /* ClassKeyword */,
	        "continue": 75 /* ContinueKeyword */,
	        "const": 74 /* ConstKeyword */,
	        "constructor": 121 /* ConstructorKeyword */,
	        "debugger": 76 /* DebuggerKeyword */,
	        "declare": 122 /* DeclareKeyword */,
	        "default": 77 /* DefaultKeyword */,
	        "delete": 78 /* DeleteKeyword */,
	        "do": 79 /* DoKeyword */,
	        "else": 80 /* ElseKeyword */,
	        "enum": 81 /* EnumKeyword */,
	        "export": 82 /* ExportKeyword */,
	        "extends": 83 /* ExtendsKeyword */,
	        "false": 84 /* FalseKeyword */,
	        "finally": 85 /* FinallyKeyword */,
	        "for": 86 /* ForKeyword */,
	        "from": 133 /* FromKeyword */,
	        "function": 87 /* FunctionKeyword */,
	        "get": 123 /* GetKeyword */,
	        "if": 88 /* IfKeyword */,
	        "implements": 106 /* ImplementsKeyword */,
	        "import": 89 /* ImportKeyword */,
	        "in": 90 /* InKeyword */,
	        "instanceof": 91 /* InstanceOfKeyword */,
	        "interface": 107 /* InterfaceKeyword */,
	        "is": 124 /* IsKeyword */,
	        "let": 108 /* LetKeyword */,
	        "module": 125 /* ModuleKeyword */,
	        "namespace": 126 /* NamespaceKeyword */,
	        "new": 92 /* NewKeyword */,
	        "null": 93 /* NullKeyword */,
	        "number": 128 /* NumberKeyword */,
	        "package": 109 /* PackageKeyword */,
	        "private": 110 /* PrivateKeyword */,
	        "protected": 111 /* ProtectedKeyword */,
	        "public": 112 /* PublicKeyword */,
	        "require": 127 /* RequireKeyword */,
	        "global": 134 /* GlobalKeyword */,
	        "return": 94 /* ReturnKeyword */,
	        "set": 129 /* SetKeyword */,
	        "static": 113 /* StaticKeyword */,
	        "string": 130 /* StringKeyword */,
	        "super": 95 /* SuperKeyword */,
	        "switch": 96 /* SwitchKeyword */,
	        "symbol": 131 /* SymbolKeyword */,
	        "this": 97 /* ThisKeyword */,
	        "throw": 98 /* ThrowKeyword */,
	        "true": 99 /* TrueKeyword */,
	        "try": 100 /* TryKeyword */,
	        "type": 132 /* TypeKeyword */,
	        "typeof": 101 /* TypeOfKeyword */,
	        "var": 102 /* VarKeyword */,
	        "void": 103 /* VoidKeyword */,
	        "while": 104 /* WhileKeyword */,
	        "with": 105 /* WithKeyword */,
	        "yield": 114 /* YieldKeyword */,
	        "async": 118 /* AsyncKeyword */,
	        "await": 119 /* AwaitKeyword */,
	        "of": 135 /* OfKeyword */,
	        "{": 15 /* OpenBraceToken */,
	        "}": 16 /* CloseBraceToken */,
	        "(": 17 /* OpenParenToken */,
	        ")": 18 /* CloseParenToken */,
	        "[": 19 /* OpenBracketToken */,
	        "]": 20 /* CloseBracketToken */,
	        ".": 21 /* DotToken */,
	        "...": 22 /* DotDotDotToken */,
	        ";": 23 /* SemicolonToken */,
	        ",": 24 /* CommaToken */,
	        "<": 25 /* LessThanToken */,
	        ">": 27 /* GreaterThanToken */,
	        "<=": 28 /* LessThanEqualsToken */,
	        ">=": 29 /* GreaterThanEqualsToken */,
	        "==": 30 /* EqualsEqualsToken */,
	        "!=": 31 /* ExclamationEqualsToken */,
	        "===": 32 /* EqualsEqualsEqualsToken */,
	        "!==": 33 /* ExclamationEqualsEqualsToken */,
	        "=>": 34 /* EqualsGreaterThanToken */,
	        "+": 35 /* PlusToken */,
	        "-": 36 /* MinusToken */,
	        "**": 38 /* AsteriskAsteriskToken */,
	        "*": 37 /* AsteriskToken */,
	        "/": 39 /* SlashToken */,
	        "%": 40 /* PercentToken */,
	        "++": 41 /* PlusPlusToken */,
	        "--": 42 /* MinusMinusToken */,
	        "<<": 43 /* LessThanLessThanToken */,
	        "</": 26 /* LessThanSlashToken */,
	        ">>": 44 /* GreaterThanGreaterThanToken */,
	        ">>>": 45 /* GreaterThanGreaterThanGreaterThanToken */,
	        "&": 46 /* AmpersandToken */,
	        "|": 47 /* BarToken */,
	        "^": 48 /* CaretToken */,
	        "!": 49 /* ExclamationToken */,
	        "~": 50 /* TildeToken */,
	        "&&": 51 /* AmpersandAmpersandToken */,
	        "||": 52 /* BarBarToken */,
	        "?": 53 /* QuestionToken */,
	        ":": 54 /* ColonToken */,
	        "=": 56 /* EqualsToken */,
	        "+=": 57 /* PlusEqualsToken */,
	        "-=": 58 /* MinusEqualsToken */,
	        "*=": 59 /* AsteriskEqualsToken */,
	        "**=": 60 /* AsteriskAsteriskEqualsToken */,
	        "/=": 61 /* SlashEqualsToken */,
	        "%=": 62 /* PercentEqualsToken */,
	        "<<=": 63 /* LessThanLessThanEqualsToken */,
	        ">>=": 64 /* GreaterThanGreaterThanEqualsToken */,
	        ">>>=": 65 /* GreaterThanGreaterThanGreaterThanEqualsToken */,
	        "&=": 66 /* AmpersandEqualsToken */,
	        "|=": 67 /* BarEqualsToken */,
	        "^=": 68 /* CaretEqualsToken */,
	        "@": 55 /* AtToken */
	    };
	    /*
	        As per ECMAScript Language Specification 3th Edition, Section 7.6: Identifiers
	        IdentifierStart ::
	            Can contain Unicode 3.0.0  categories:
	            Uppercase letter (Lu),
	            Lowercase letter (Ll),
	            Titlecase letter (Lt),
	            Modifier letter (Lm),
	            Other letter (Lo), or
	            Letter number (Nl).
	        IdentifierPart :: =
	            Can contain IdentifierStart + Unicode 3.0.0  categories:
	            Non-spacing mark (Mn),
	            Combining spacing mark (Mc),
	            Decimal number (Nd), or
	            Connector punctuation (Pc).

	        Codepoint ranges for ES3 Identifiers are extracted from the Unicode 3.0.0 specification at:
	        http://www.unicode.org/Public/3.0-Update/UnicodeData-3.0.0.txt
	    */
	    var unicodeES3IdentifierStart = [170, 170, 181, 181, 186, 186, 192, 214, 216, 246, 248, 543, 546, 563, 592, 685, 688, 696, 699, 705, 720, 721, 736, 740, 750, 750, 890, 890, 902, 902, 904, 906, 908, 908, 910, 929, 931, 974, 976, 983, 986, 1011, 1024, 1153, 1164, 1220, 1223, 1224, 1227, 1228, 1232, 1269, 1272, 1273, 1329, 1366, 1369, 1369, 1377, 1415, 1488, 1514, 1520, 1522, 1569, 1594, 1600, 1610, 1649, 1747, 1749, 1749, 1765, 1766, 1786, 1788, 1808, 1808, 1810, 1836, 1920, 1957, 2309, 2361, 2365, 2365, 2384, 2384, 2392, 2401, 2437, 2444, 2447, 2448, 2451, 2472, 2474, 2480, 2482, 2482, 2486, 2489, 2524, 2525, 2527, 2529, 2544, 2545, 2565, 2570, 2575, 2576, 2579, 2600, 2602, 2608, 2610, 2611, 2613, 2614, 2616, 2617, 2649, 2652, 2654, 2654, 2674, 2676, 2693, 2699, 2701, 2701, 2703, 2705, 2707, 2728, 2730, 2736, 2738, 2739, 2741, 2745, 2749, 2749, 2768, 2768, 2784, 2784, 2821, 2828, 2831, 2832, 2835, 2856, 2858, 2864, 2866, 2867, 2870, 2873, 2877, 2877, 2908, 2909, 2911, 2913, 2949, 2954, 2958, 2960, 2962, 2965, 2969, 2970, 2972, 2972, 2974, 2975, 2979, 2980, 2984, 2986, 2990, 2997, 2999, 3001, 3077, 3084, 3086, 3088, 3090, 3112, 3114, 3123, 3125, 3129, 3168, 3169, 3205, 3212, 3214, 3216, 3218, 3240, 3242, 3251, 3253, 3257, 3294, 3294, 3296, 3297, 3333, 3340, 3342, 3344, 3346, 3368, 3370, 3385, 3424, 3425, 3461, 3478, 3482, 3505, 3507, 3515, 3517, 3517, 3520, 3526, 3585, 3632, 3634, 3635, 3648, 3654, 3713, 3714, 3716, 3716, 3719, 3720, 3722, 3722, 3725, 3725, 3732, 3735, 3737, 3743, 3745, 3747, 3749, 3749, 3751, 3751, 3754, 3755, 3757, 3760, 3762, 3763, 3773, 3773, 3776, 3780, 3782, 3782, 3804, 3805, 3840, 3840, 3904, 3911, 3913, 3946, 3976, 3979, 4096, 4129, 4131, 4135, 4137, 4138, 4176, 4181, 4256, 4293, 4304, 4342, 4352, 4441, 4447, 4514, 4520, 4601, 4608, 4614, 4616, 4678, 4680, 4680, 4682, 4685, 4688, 4694, 4696, 4696, 4698, 4701, 4704, 4742, 4744, 4744, 4746, 4749, 4752, 4782, 4784, 4784, 4786, 4789, 4792, 4798, 4800, 4800, 4802, 4805, 4808, 4814, 4816, 4822, 4824, 4846, 4848, 4878, 4880, 4880, 4882, 4885, 4888, 4894, 4896, 4934, 4936, 4954, 5024, 5108, 5121, 5740, 5743, 5750, 5761, 5786, 5792, 5866, 6016, 6067, 6176, 6263, 6272, 6312, 7680, 7835, 7840, 7929, 7936, 7957, 7960, 7965, 7968, 8005, 8008, 8013, 8016, 8023, 8025, 8025, 8027, 8027, 8029, 8029, 8031, 8061, 8064, 8116, 8118, 8124, 8126, 8126, 8130, 8132, 8134, 8140, 8144, 8147, 8150, 8155, 8160, 8172, 8178, 8180, 8182, 8188, 8319, 8319, 8450, 8450, 8455, 8455, 8458, 8467, 8469, 8469, 8473, 8477, 8484, 8484, 8486, 8486, 8488, 8488, 8490, 8493, 8495, 8497, 8499, 8505, 8544, 8579, 12293, 12295, 12321, 12329, 12337, 12341, 12344, 12346, 12353, 12436, 12445, 12446, 12449, 12538, 12540, 12542, 12549, 12588, 12593, 12686, 12704, 12727, 13312, 19893, 19968, 40869, 40960, 42124, 44032, 55203, 63744, 64045, 64256, 64262, 64275, 64279, 64285, 64285, 64287, 64296, 64298, 64310, 64312, 64316, 64318, 64318, 64320, 64321, 64323, 64324, 64326, 64433, 64467, 64829, 64848, 64911, 64914, 64967, 65008, 65019, 65136, 65138, 65140, 65140, 65142, 65276, 65313, 65338, 65345, 65370, 65382, 65470, 65474, 65479, 65482, 65487, 65490, 65495, 65498, 65500,];
	    var unicodeES3IdentifierPart = [170, 170, 181, 181, 186, 186, 192, 214, 216, 246, 248, 543, 546, 563, 592, 685, 688, 696, 699, 705, 720, 721, 736, 740, 750, 750, 768, 846, 864, 866, 890, 890, 902, 902, 904, 906, 908, 908, 910, 929, 931, 974, 976, 983, 986, 1011, 1024, 1153, 1155, 1158, 1164, 1220, 1223, 1224, 1227, 1228, 1232, 1269, 1272, 1273, 1329, 1366, 1369, 1369, 1377, 1415, 1425, 1441, 1443, 1465, 1467, 1469, 1471, 1471, 1473, 1474, 1476, 1476, 1488, 1514, 1520, 1522, 1569, 1594, 1600, 1621, 1632, 1641, 1648, 1747, 1749, 1756, 1759, 1768, 1770, 1773, 1776, 1788, 1808, 1836, 1840, 1866, 1920, 1968, 2305, 2307, 2309, 2361, 2364, 2381, 2384, 2388, 2392, 2403, 2406, 2415, 2433, 2435, 2437, 2444, 2447, 2448, 2451, 2472, 2474, 2480, 2482, 2482, 2486, 2489, 2492, 2492, 2494, 2500, 2503, 2504, 2507, 2509, 2519, 2519, 2524, 2525, 2527, 2531, 2534, 2545, 2562, 2562, 2565, 2570, 2575, 2576, 2579, 2600, 2602, 2608, 2610, 2611, 2613, 2614, 2616, 2617, 2620, 2620, 2622, 2626, 2631, 2632, 2635, 2637, 2649, 2652, 2654, 2654, 2662, 2676, 2689, 2691, 2693, 2699, 2701, 2701, 2703, 2705, 2707, 2728, 2730, 2736, 2738, 2739, 2741, 2745, 2748, 2757, 2759, 2761, 2763, 2765, 2768, 2768, 2784, 2784, 2790, 2799, 2817, 2819, 2821, 2828, 2831, 2832, 2835, 2856, 2858, 2864, 2866, 2867, 2870, 2873, 2876, 2883, 2887, 2888, 2891, 2893, 2902, 2903, 2908, 2909, 2911, 2913, 2918, 2927, 2946, 2947, 2949, 2954, 2958, 2960, 2962, 2965, 2969, 2970, 2972, 2972, 2974, 2975, 2979, 2980, 2984, 2986, 2990, 2997, 2999, 3001, 3006, 3010, 3014, 3016, 3018, 3021, 3031, 3031, 3047, 3055, 3073, 3075, 3077, 3084, 3086, 3088, 3090, 3112, 3114, 3123, 3125, 3129, 3134, 3140, 3142, 3144, 3146, 3149, 3157, 3158, 3168, 3169, 3174, 3183, 3202, 3203, 3205, 3212, 3214, 3216, 3218, 3240, 3242, 3251, 3253, 3257, 3262, 3268, 3270, 3272, 3274, 3277, 3285, 3286, 3294, 3294, 3296, 3297, 3302, 3311, 3330, 3331, 3333, 3340, 3342, 3344, 3346, 3368, 3370, 3385, 3390, 3395, 3398, 3400, 3402, 3405, 3415, 3415, 3424, 3425, 3430, 3439, 3458, 3459, 3461, 3478, 3482, 3505, 3507, 3515, 3517, 3517, 3520, 3526, 3530, 3530, 3535, 3540, 3542, 3542, 3544, 3551, 3570, 3571, 3585, 3642, 3648, 3662, 3664, 3673, 3713, 3714, 3716, 3716, 3719, 3720, 3722, 3722, 3725, 3725, 3732, 3735, 3737, 3743, 3745, 3747, 3749, 3749, 3751, 3751, 3754, 3755, 3757, 3769, 3771, 3773, 3776, 3780, 3782, 3782, 3784, 3789, 3792, 3801, 3804, 3805, 3840, 3840, 3864, 3865, 3872, 3881, 3893, 3893, 3895, 3895, 3897, 3897, 3902, 3911, 3913, 3946, 3953, 3972, 3974, 3979, 3984, 3991, 3993, 4028, 4038, 4038, 4096, 4129, 4131, 4135, 4137, 4138, 4140, 4146, 4150, 4153, 4160, 4169, 4176, 4185, 4256, 4293, 4304, 4342, 4352, 4441, 4447, 4514, 4520, 4601, 4608, 4614, 4616, 4678, 4680, 4680, 4682, 4685, 4688, 4694, 4696, 4696, 4698, 4701, 4704, 4742, 4744, 4744, 4746, 4749, 4752, 4782, 4784, 4784, 4786, 4789, 4792, 4798, 4800, 4800, 4802, 4805, 4808, 4814, 4816, 4822, 4824, 4846, 4848, 4878, 4880, 4880, 4882, 4885, 4888, 4894, 4896, 4934, 4936, 4954, 4969, 4977, 5024, 5108, 5121, 5740, 5743, 5750, 5761, 5786, 5792, 5866, 6016, 6099, 6112, 6121, 6160, 6169, 6176, 6263, 6272, 6313, 7680, 7835, 7840, 7929, 7936, 7957, 7960, 7965, 7968, 8005, 8008, 8013, 8016, 8023, 8025, 8025, 8027, 8027, 8029, 8029, 8031, 8061, 8064, 8116, 8118, 8124, 8126, 8126, 8130, 8132, 8134, 8140, 8144, 8147, 8150, 8155, 8160, 8172, 8178, 8180, 8182, 8188, 8255, 8256, 8319, 8319, 8400, 8412, 8417, 8417, 8450, 8450, 8455, 8455, 8458, 8467, 8469, 8469, 8473, 8477, 8484, 8484, 8486, 8486, 8488, 8488, 8490, 8493, 8495, 8497, 8499, 8505, 8544, 8579, 12293, 12295, 12321, 12335, 12337, 12341, 12344, 12346, 12353, 12436, 12441, 12442, 12445, 12446, 12449, 12542, 12549, 12588, 12593, 12686, 12704, 12727, 13312, 19893, 19968, 40869, 40960, 42124, 44032, 55203, 63744, 64045, 64256, 64262, 64275, 64279, 64285, 64296, 64298, 64310, 64312, 64316, 64318, 64318, 64320, 64321, 64323, 64324, 64326, 64433, 64467, 64829, 64848, 64911, 64914, 64967, 65008, 65019, 65056, 65059, 65075, 65076, 65101, 65103, 65136, 65138, 65140, 65140, 65142, 65276, 65296, 65305, 65313, 65338, 65343, 65343, 65345, 65370, 65381, 65470, 65474, 65479, 65482, 65487, 65490, 65495, 65498, 65500,];
	    /*
	        As per ECMAScript Language Specification 5th Edition, Section 7.6: ISyntaxToken Names and Identifiers
	        IdentifierStart ::
	            Can contain Unicode 6.2  categories:
	            Uppercase letter (Lu),
	            Lowercase letter (Ll),
	            Titlecase letter (Lt),
	            Modifier letter (Lm),
	            Other letter (Lo), or
	            Letter number (Nl).
	        IdentifierPart ::
	            Can contain IdentifierStart + Unicode 6.2  categories:
	            Non-spacing mark (Mn),
	            Combining spacing mark (Mc),
	            Decimal number (Nd),
	            Connector punctuation (Pc),
	            <ZWNJ>, or
	            <ZWJ>.

	        Codepoint ranges for ES5 Identifiers are extracted from the Unicode 6.2 specification at:
	        http://www.unicode.org/Public/6.2.0/ucd/UnicodeData.txt
	    */
	    var unicodeES5IdentifierStart = [170, 170, 181, 181, 186, 186, 192, 214, 216, 246, 248, 705, 710, 721, 736, 740, 748, 748, 750, 750, 880, 884, 886, 887, 890, 893, 902, 902, 904, 906, 908, 908, 910, 929, 931, 1013, 1015, 1153, 1162, 1319, 1329, 1366, 1369, 1369, 1377, 1415, 1488, 1514, 1520, 1522, 1568, 1610, 1646, 1647, 1649, 1747, 1749, 1749, 1765, 1766, 1774, 1775, 1786, 1788, 1791, 1791, 1808, 1808, 1810, 1839, 1869, 1957, 1969, 1969, 1994, 2026, 2036, 2037, 2042, 2042, 2048, 2069, 2074, 2074, 2084, 2084, 2088, 2088, 2112, 2136, 2208, 2208, 2210, 2220, 2308, 2361, 2365, 2365, 2384, 2384, 2392, 2401, 2417, 2423, 2425, 2431, 2437, 2444, 2447, 2448, 2451, 2472, 2474, 2480, 2482, 2482, 2486, 2489, 2493, 2493, 2510, 2510, 2524, 2525, 2527, 2529, 2544, 2545, 2565, 2570, 2575, 2576, 2579, 2600, 2602, 2608, 2610, 2611, 2613, 2614, 2616, 2617, 2649, 2652, 2654, 2654, 2674, 2676, 2693, 2701, 2703, 2705, 2707, 2728, 2730, 2736, 2738, 2739, 2741, 2745, 2749, 2749, 2768, 2768, 2784, 2785, 2821, 2828, 2831, 2832, 2835, 2856, 2858, 2864, 2866, 2867, 2869, 2873, 2877, 2877, 2908, 2909, 2911, 2913, 2929, 2929, 2947, 2947, 2949, 2954, 2958, 2960, 2962, 2965, 2969, 2970, 2972, 2972, 2974, 2975, 2979, 2980, 2984, 2986, 2990, 3001, 3024, 3024, 3077, 3084, 3086, 3088, 3090, 3112, 3114, 3123, 3125, 3129, 3133, 3133, 3160, 3161, 3168, 3169, 3205, 3212, 3214, 3216, 3218, 3240, 3242, 3251, 3253, 3257, 3261, 3261, 3294, 3294, 3296, 3297, 3313, 3314, 3333, 3340, 3342, 3344, 3346, 3386, 3389, 3389, 3406, 3406, 3424, 3425, 3450, 3455, 3461, 3478, 3482, 3505, 3507, 3515, 3517, 3517, 3520, 3526, 3585, 3632, 3634, 3635, 3648, 3654, 3713, 3714, 3716, 3716, 3719, 3720, 3722, 3722, 3725, 3725, 3732, 3735, 3737, 3743, 3745, 3747, 3749, 3749, 3751, 3751, 3754, 3755, 3757, 3760, 3762, 3763, 3773, 3773, 3776, 3780, 3782, 3782, 3804, 3807, 3840, 3840, 3904, 3911, 3913, 3948, 3976, 3980, 4096, 4138, 4159, 4159, 4176, 4181, 4186, 4189, 4193, 4193, 4197, 4198, 4206, 4208, 4213, 4225, 4238, 4238, 4256, 4293, 4295, 4295, 4301, 4301, 4304, 4346, 4348, 4680, 4682, 4685, 4688, 4694, 4696, 4696, 4698, 4701, 4704, 4744, 4746, 4749, 4752, 4784, 4786, 4789, 4792, 4798, 4800, 4800, 4802, 4805, 4808, 4822, 4824, 4880, 4882, 4885, 4888, 4954, 4992, 5007, 5024, 5108, 5121, 5740, 5743, 5759, 5761, 5786, 5792, 5866, 5870, 5872, 5888, 5900, 5902, 5905, 5920, 5937, 5952, 5969, 5984, 5996, 5998, 6000, 6016, 6067, 6103, 6103, 6108, 6108, 6176, 6263, 6272, 6312, 6314, 6314, 6320, 6389, 6400, 6428, 6480, 6509, 6512, 6516, 6528, 6571, 6593, 6599, 6656, 6678, 6688, 6740, 6823, 6823, 6917, 6963, 6981, 6987, 7043, 7072, 7086, 7087, 7098, 7141, 7168, 7203, 7245, 7247, 7258, 7293, 7401, 7404, 7406, 7409, 7413, 7414, 7424, 7615, 7680, 7957, 7960, 7965, 7968, 8005, 8008, 8013, 8016, 8023, 8025, 8025, 8027, 8027, 8029, 8029, 8031, 8061, 8064, 8116, 8118, 8124, 8126, 8126, 8130, 8132, 8134, 8140, 8144, 8147, 8150, 8155, 8160, 8172, 8178, 8180, 8182, 8188, 8305, 8305, 8319, 8319, 8336, 8348, 8450, 8450, 8455, 8455, 8458, 8467, 8469, 8469, 8473, 8477, 8484, 8484, 8486, 8486, 8488, 8488, 8490, 8493, 8495, 8505, 8508, 8511, 8517, 8521, 8526, 8526, 8544, 8584, 11264, 11310, 11312, 11358, 11360, 11492, 11499, 11502, 11506, 11507, 11520, 11557, 11559, 11559, 11565, 11565, 11568, 11623, 11631, 11631, 11648, 11670, 11680, 11686, 11688, 11694, 11696, 11702, 11704, 11710, 11712, 11718, 11720, 11726, 11728, 11734, 11736, 11742, 11823, 11823, 12293, 12295, 12321, 12329, 12337, 12341, 12344, 12348, 12353, 12438, 12445, 12447, 12449, 12538, 12540, 12543, 12549, 12589, 12593, 12686, 12704, 12730, 12784, 12799, 13312, 19893, 19968, 40908, 40960, 42124, 42192, 42237, 42240, 42508, 42512, 42527, 42538, 42539, 42560, 42606, 42623, 42647, 42656, 42735, 42775, 42783, 42786, 42888, 42891, 42894, 42896, 42899, 42912, 42922, 43000, 43009, 43011, 43013, 43015, 43018, 43020, 43042, 43072, 43123, 43138, 43187, 43250, 43255, 43259, 43259, 43274, 43301, 43312, 43334, 43360, 43388, 43396, 43442, 43471, 43471, 43520, 43560, 43584, 43586, 43588, 43595, 43616, 43638, 43642, 43642, 43648, 43695, 43697, 43697, 43701, 43702, 43705, 43709, 43712, 43712, 43714, 43714, 43739, 43741, 43744, 43754, 43762, 43764, 43777, 43782, 43785, 43790, 43793, 43798, 43808, 43814, 43816, 43822, 43968, 44002, 44032, 55203, 55216, 55238, 55243, 55291, 63744, 64109, 64112, 64217, 64256, 64262, 64275, 64279, 64285, 64285, 64287, 64296, 64298, 64310, 64312, 64316, 64318, 64318, 64320, 64321, 64323, 64324, 64326, 64433, 64467, 64829, 64848, 64911, 64914, 64967, 65008, 65019, 65136, 65140, 65142, 65276, 65313, 65338, 65345, 65370, 65382, 65470, 65474, 65479, 65482, 65487, 65490, 65495, 65498, 65500,];
	    var unicodeES5IdentifierPart = [170, 170, 181, 181, 186, 186, 192, 214, 216, 246, 248, 705, 710, 721, 736, 740, 748, 748, 750, 750, 768, 884, 886, 887, 890, 893, 902, 902, 904, 906, 908, 908, 910, 929, 931, 1013, 1015, 1153, 1155, 1159, 1162, 1319, 1329, 1366, 1369, 1369, 1377, 1415, 1425, 1469, 1471, 1471, 1473, 1474, 1476, 1477, 1479, 1479, 1488, 1514, 1520, 1522, 1552, 1562, 1568, 1641, 1646, 1747, 1749, 1756, 1759, 1768, 1770, 1788, 1791, 1791, 1808, 1866, 1869, 1969, 1984, 2037, 2042, 2042, 2048, 2093, 2112, 2139, 2208, 2208, 2210, 2220, 2276, 2302, 2304, 2403, 2406, 2415, 2417, 2423, 2425, 2431, 2433, 2435, 2437, 2444, 2447, 2448, 2451, 2472, 2474, 2480, 2482, 2482, 2486, 2489, 2492, 2500, 2503, 2504, 2507, 2510, 2519, 2519, 2524, 2525, 2527, 2531, 2534, 2545, 2561, 2563, 2565, 2570, 2575, 2576, 2579, 2600, 2602, 2608, 2610, 2611, 2613, 2614, 2616, 2617, 2620, 2620, 2622, 2626, 2631, 2632, 2635, 2637, 2641, 2641, 2649, 2652, 2654, 2654, 2662, 2677, 2689, 2691, 2693, 2701, 2703, 2705, 2707, 2728, 2730, 2736, 2738, 2739, 2741, 2745, 2748, 2757, 2759, 2761, 2763, 2765, 2768, 2768, 2784, 2787, 2790, 2799, 2817, 2819, 2821, 2828, 2831, 2832, 2835, 2856, 2858, 2864, 2866, 2867, 2869, 2873, 2876, 2884, 2887, 2888, 2891, 2893, 2902, 2903, 2908, 2909, 2911, 2915, 2918, 2927, 2929, 2929, 2946, 2947, 2949, 2954, 2958, 2960, 2962, 2965, 2969, 2970, 2972, 2972, 2974, 2975, 2979, 2980, 2984, 2986, 2990, 3001, 3006, 3010, 3014, 3016, 3018, 3021, 3024, 3024, 3031, 3031, 3046, 3055, 3073, 3075, 3077, 3084, 3086, 3088, 3090, 3112, 3114, 3123, 3125, 3129, 3133, 3140, 3142, 3144, 3146, 3149, 3157, 3158, 3160, 3161, 3168, 3171, 3174, 3183, 3202, 3203, 3205, 3212, 3214, 3216, 3218, 3240, 3242, 3251, 3253, 3257, 3260, 3268, 3270, 3272, 3274, 3277, 3285, 3286, 3294, 3294, 3296, 3299, 3302, 3311, 3313, 3314, 3330, 3331, 3333, 3340, 3342, 3344, 3346, 3386, 3389, 3396, 3398, 3400, 3402, 3406, 3415, 3415, 3424, 3427, 3430, 3439, 3450, 3455, 3458, 3459, 3461, 3478, 3482, 3505, 3507, 3515, 3517, 3517, 3520, 3526, 3530, 3530, 3535, 3540, 3542, 3542, 3544, 3551, 3570, 3571, 3585, 3642, 3648, 3662, 3664, 3673, 3713, 3714, 3716, 3716, 3719, 3720, 3722, 3722, 3725, 3725, 3732, 3735, 3737, 3743, 3745, 3747, 3749, 3749, 3751, 3751, 3754, 3755, 3757, 3769, 3771, 3773, 3776, 3780, 3782, 3782, 3784, 3789, 3792, 3801, 3804, 3807, 3840, 3840, 3864, 3865, 3872, 3881, 3893, 3893, 3895, 3895, 3897, 3897, 3902, 3911, 3913, 3948, 3953, 3972, 3974, 3991, 3993, 4028, 4038, 4038, 4096, 4169, 4176, 4253, 4256, 4293, 4295, 4295, 4301, 4301, 4304, 4346, 4348, 4680, 4682, 4685, 4688, 4694, 4696, 4696, 4698, 4701, 4704, 4744, 4746, 4749, 4752, 4784, 4786, 4789, 4792, 4798, 4800, 4800, 4802, 4805, 4808, 4822, 4824, 4880, 4882, 4885, 4888, 4954, 4957, 4959, 4992, 5007, 5024, 5108, 5121, 5740, 5743, 5759, 5761, 5786, 5792, 5866, 5870, 5872, 5888, 5900, 5902, 5908, 5920, 5940, 5952, 5971, 5984, 5996, 5998, 6000, 6002, 6003, 6016, 6099, 6103, 6103, 6108, 6109, 6112, 6121, 6155, 6157, 6160, 6169, 6176, 6263, 6272, 6314, 6320, 6389, 6400, 6428, 6432, 6443, 6448, 6459, 6470, 6509, 6512, 6516, 6528, 6571, 6576, 6601, 6608, 6617, 6656, 6683, 6688, 6750, 6752, 6780, 6783, 6793, 6800, 6809, 6823, 6823, 6912, 6987, 6992, 7001, 7019, 7027, 7040, 7155, 7168, 7223, 7232, 7241, 7245, 7293, 7376, 7378, 7380, 7414, 7424, 7654, 7676, 7957, 7960, 7965, 7968, 8005, 8008, 8013, 8016, 8023, 8025, 8025, 8027, 8027, 8029, 8029, 8031, 8061, 8064, 8116, 8118, 8124, 8126, 8126, 8130, 8132, 8134, 8140, 8144, 8147, 8150, 8155, 8160, 8172, 8178, 8180, 8182, 8188, 8204, 8205, 8255, 8256, 8276, 8276, 8305, 8305, 8319, 8319, 8336, 8348, 8400, 8412, 8417, 8417, 8421, 8432, 8450, 8450, 8455, 8455, 8458, 8467, 8469, 8469, 8473, 8477, 8484, 8484, 8486, 8486, 8488, 8488, 8490, 8493, 8495, 8505, 8508, 8511, 8517, 8521, 8526, 8526, 8544, 8584, 11264, 11310, 11312, 11358, 11360, 11492, 11499, 11507, 11520, 11557, 11559, 11559, 11565, 11565, 11568, 11623, 11631, 11631, 11647, 11670, 11680, 11686, 11688, 11694, 11696, 11702, 11704, 11710, 11712, 11718, 11720, 11726, 11728, 11734, 11736, 11742, 11744, 11775, 11823, 11823, 12293, 12295, 12321, 12335, 12337, 12341, 12344, 12348, 12353, 12438, 12441, 12442, 12445, 12447, 12449, 12538, 12540, 12543, 12549, 12589, 12593, 12686, 12704, 12730, 12784, 12799, 13312, 19893, 19968, 40908, 40960, 42124, 42192, 42237, 42240, 42508, 42512, 42539, 42560, 42607, 42612, 42621, 42623, 42647, 42655, 42737, 42775, 42783, 42786, 42888, 42891, 42894, 42896, 42899, 42912, 42922, 43000, 43047, 43072, 43123, 43136, 43204, 43216, 43225, 43232, 43255, 43259, 43259, 43264, 43309, 43312, 43347, 43360, 43388, 43392, 43456, 43471, 43481, 43520, 43574, 43584, 43597, 43600, 43609, 43616, 43638, 43642, 43643, 43648, 43714, 43739, 43741, 43744, 43759, 43762, 43766, 43777, 43782, 43785, 43790, 43793, 43798, 43808, 43814, 43816, 43822, 43968, 44010, 44012, 44013, 44016, 44025, 44032, 55203, 55216, 55238, 55243, 55291, 63744, 64109, 64112, 64217, 64256, 64262, 64275, 64279, 64285, 64296, 64298, 64310, 64312, 64316, 64318, 64318, 64320, 64321, 64323, 64324, 64326, 64433, 64467, 64829, 64848, 64911, 64914, 64967, 65008, 65019, 65024, 65039, 65056, 65062, 65075, 65076, 65101, 65103, 65136, 65140, 65142, 65276, 65296, 65305, 65313, 65338, 65343, 65343, 65345, 65370, 65382, 65470, 65474, 65479, 65482, 65487, 65490, 65495, 65498, 65500,];
	    function lookupInUnicodeMap(code, map) {
	        // Bail out quickly if it couldn't possibly be in the map.
	        if (code < map[0]) {
	            return false;
	        }
	        // Perform binary search in one of the Unicode range maps
	        var lo = 0;
	        var hi = map.length;
	        var mid;
	        while (lo + 1 < hi) {
	            mid = lo + (hi - lo) / 2;
	            // mid has to be even to catch a range's beginning
	            mid -= mid % 2;
	            if (map[mid] <= code && code <= map[mid + 1]) {
	                return true;
	            }
	            if (code < map[mid]) {
	                hi = mid;
	            }
	            else {
	                lo = mid + 2;
	            }
	        }
	        return false;
	    }
	    /* @internal */ function isUnicodeIdentifierStart(code, languageVersion) {
	        return languageVersion >= 1 /* ES5 */ ?
	            lookupInUnicodeMap(code, unicodeES5IdentifierStart) :
	            lookupInUnicodeMap(code, unicodeES3IdentifierStart);
	    }
	    ts.isUnicodeIdentifierStart = isUnicodeIdentifierStart;
	    function isUnicodeIdentifierPart(code, languageVersion) {
	        return languageVersion >= 1 /* ES5 */ ?
	            lookupInUnicodeMap(code, unicodeES5IdentifierPart) :
	            lookupInUnicodeMap(code, unicodeES3IdentifierPart);
	    }
	    function makeReverseMap(source) {
	        var result = [];
	        for (var name_4 in source) {
	            if (source.hasOwnProperty(name_4)) {
	                result[source[name_4]] = name_4;
	            }
	        }
	        return result;
	    }
	    var tokenStrings = makeReverseMap(textToToken);
	    function tokenToString(t) {
	        return tokenStrings[t];
	    }
	    ts.tokenToString = tokenToString;
	    /* @internal */
	    function stringToToken(s) {
	        return textToToken[s];
	    }
	    ts.stringToToken = stringToToken;
	    /* @internal */
	    function computeLineStarts(text) {
	        var result = new Array();
	        var pos = 0;
	        var lineStart = 0;
	        while (pos < text.length) {
	            var ch = text.charCodeAt(pos);
	            pos++;
	            switch (ch) {
	                case 13 /* carriageReturn */:
	                    if (text.charCodeAt(pos) === 10 /* lineFeed */) {
	                        pos++;
	                    }
	                case 10 /* lineFeed */:
	                    result.push(lineStart);
	                    lineStart = pos;
	                    break;
	                default:
	                    if (ch > 127 /* maxAsciiCharacter */ && isLineBreak(ch)) {
	                        result.push(lineStart);
	                        lineStart = pos;
	                    }
	                    break;
	            }
	        }
	        result.push(lineStart);
	        return result;
	    }
	    ts.computeLineStarts = computeLineStarts;
	    function getPositionOfLineAndCharacter(sourceFile, line, character) {
	        return computePositionOfLineAndCharacter(getLineStarts(sourceFile), line, character);
	    }
	    ts.getPositionOfLineAndCharacter = getPositionOfLineAndCharacter;
	    /* @internal */
	    function computePositionOfLineAndCharacter(lineStarts, line, character) {
	        ts.Debug.assert(line >= 0 && line < lineStarts.length);
	        return lineStarts[line] + character;
	    }
	    ts.computePositionOfLineAndCharacter = computePositionOfLineAndCharacter;
	    /* @internal */
	    function getLineStarts(sourceFile) {
	        return sourceFile.lineMap || (sourceFile.lineMap = computeLineStarts(sourceFile.text));
	    }
	    ts.getLineStarts = getLineStarts;
	    /* @internal */
	    /**
	     * We assume the first line starts at position 0 and 'position' is non-negative.
	     */
	    function computeLineAndCharacterOfPosition(lineStarts, position) {
	        var lineNumber = ts.binarySearch(lineStarts, position);
	        if (lineNumber < 0) {
	            // If the actual position was not found,
	            // the binary search returns the 2's-complement of the next line start
	            // e.g. if the line starts at [5, 10, 23, 80] and the position requested was 20
	            // then the search will return -2.
	            //
	            // We want the index of the previous line start, so we subtract 1.
	            // Review 2's-complement if this is confusing.
	            lineNumber = ~lineNumber - 1;
	            ts.Debug.assert(lineNumber !== -1, "position cannot precede the beginning of the file");
	        }
	        return {
	            line: lineNumber,
	            character: position - lineStarts[lineNumber]
	        };
	    }
	    ts.computeLineAndCharacterOfPosition = computeLineAndCharacterOfPosition;
	    function getLineAndCharacterOfPosition(sourceFile, position) {
	        return computeLineAndCharacterOfPosition(getLineStarts(sourceFile), position);
	    }
	    ts.getLineAndCharacterOfPosition = getLineAndCharacterOfPosition;
	    var hasOwnProperty = Object.prototype.hasOwnProperty;
	    function isWhiteSpace(ch) {
	        // Note: nextLine is in the Zs space, and should be considered to be a whitespace.
	        // It is explicitly not a line-break as it isn't in the exact set specified by EcmaScript.
	        return ch === 32 /* space */ ||
	            ch === 9 /* tab */ ||
	            ch === 11 /* verticalTab */ ||
	            ch === 12 /* formFeed */ ||
	            ch === 160 /* nonBreakingSpace */ ||
	            ch === 133 /* nextLine */ ||
	            ch === 5760 /* ogham */ ||
	            ch >= 8192 /* enQuad */ && ch <= 8203 /* zeroWidthSpace */ ||
	            ch === 8239 /* narrowNoBreakSpace */ ||
	            ch === 8287 /* mathematicalSpace */ ||
	            ch === 12288 /* ideographicSpace */ ||
	            ch === 65279 /* byteOrderMark */;
	    }
	    ts.isWhiteSpace = isWhiteSpace;
	    function isLineBreak(ch) {
	        // ES5 7.3:
	        // The ECMAScript line terminator characters are listed in Table 3.
	        //     Table 3: Line Terminator Characters
	        //     Code Unit Value     Name                    Formal Name
	        //     \u000A              Line Feed               <LF>
	        //     \u000D              Carriage Return         <CR>
	        //     \u2028              Line separator          <LS>
	        //     \u2029              Paragraph separator     <PS>
	        // Only the characters in Table 3 are treated as line terminators. Other new line or line
	        // breaking characters are treated as white space but not as line terminators.
	        return ch === 10 /* lineFeed */ ||
	            ch === 13 /* carriageReturn */ ||
	            ch === 8232 /* lineSeparator */ ||
	            ch === 8233 /* paragraphSeparator */;
	    }
	    ts.isLineBreak = isLineBreak;
	    function isDigit(ch) {
	        return ch >= 48 /* _0 */ && ch <= 57 /* _9 */;
	    }
	    /* @internal */
	    function isOctalDigit(ch) {
	        return ch >= 48 /* _0 */ && ch <= 55 /* _7 */;
	    }
	    ts.isOctalDigit = isOctalDigit;
	    function couldStartTrivia(text, pos) {
	        // Keep in sync with skipTrivia
	        var ch = text.charCodeAt(pos);
	        switch (ch) {
	            case 13 /* carriageReturn */:
	            case 10 /* lineFeed */:
	            case 9 /* tab */:
	            case 11 /* verticalTab */:
	            case 12 /* formFeed */:
	            case 32 /* space */:
	            case 47 /* slash */:
	            // starts of normal trivia
	            case 60 /* lessThan */:
	            case 61 /* equals */:
	            case 62 /* greaterThan */:
	                // Starts of conflict marker trivia
	                return true;
	            case 35 /* hash */:
	                // Only if its the beginning can we have #! trivia
	                return pos === 0;
	            default:
	                return ch > 127 /* maxAsciiCharacter */;
	        }
	    }
	    ts.couldStartTrivia = couldStartTrivia;
	    /* @internal */
	    function skipTrivia(text, pos, stopAfterLineBreak) {
	        // Using ! with a greater than test is a fast way of testing the following conditions:
	        //  pos === undefined || pos === null || isNaN(pos) || pos < 0;
	        if (!(pos >= 0)) {
	            return pos;
	        }
	        // Keep in sync with couldStartTrivia
	        while (true) {
	            var ch = text.charCodeAt(pos);
	            switch (ch) {
	                case 13 /* carriageReturn */:
	                    if (text.charCodeAt(pos + 1) === 10 /* lineFeed */) {
	                        pos++;
	                    }
	                case 10 /* lineFeed */:
	                    pos++;
	                    if (stopAfterLineBreak) {
	                        return pos;
	                    }
	                    continue;
	                case 9 /* tab */:
	                case 11 /* verticalTab */:
	                case 12 /* formFeed */:
	                case 32 /* space */:
	                    pos++;
	                    continue;
	                case 47 /* slash */:
	                    if (text.charCodeAt(pos + 1) === 47 /* slash */) {
	                        pos += 2;
	                        while (pos < text.length) {
	                            if (isLineBreak(text.charCodeAt(pos))) {
	                                break;
	                            }
	                            pos++;
	                        }
	                        continue;
	                    }
	                    if (text.charCodeAt(pos + 1) === 42 /* asterisk */) {
	                        pos += 2;
	                        while (pos < text.length) {
	                            if (text.charCodeAt(pos) === 42 /* asterisk */ && text.charCodeAt(pos + 1) === 47 /* slash */) {
	                                pos += 2;
	                                break;
	                            }
	                            pos++;
	                        }
	                        continue;
	                    }
	                    break;
	                case 60 /* lessThan */:
	                case 61 /* equals */:
	                case 62 /* greaterThan */:
	                    if (isConflictMarkerTrivia(text, pos)) {
	                        pos = scanConflictMarkerTrivia(text, pos);
	                        continue;
	                    }
	                    break;
	                case 35 /* hash */:
	                    if (pos === 0 && isShebangTrivia(text, pos)) {
	                        pos = scanShebangTrivia(text, pos);
	                        continue;
	                    }
	                    break;
	                default:
	                    if (ch > 127 /* maxAsciiCharacter */ && (isWhiteSpace(ch) || isLineBreak(ch))) {
	                        pos++;
	                        continue;
	                    }
	                    break;
	            }
	            return pos;
	        }
	    }
	    ts.skipTrivia = skipTrivia;
	    // All conflict markers consist of the same character repeated seven times.  If it is
	    // a <<<<<<< or >>>>>>> marker then it is also followd by a space.
	    var mergeConflictMarkerLength = "<<<<<<<".length;
	    function isConflictMarkerTrivia(text, pos) {
	        ts.Debug.assert(pos >= 0);
	        // Conflict markers must be at the start of a line.
	        if (pos === 0 || isLineBreak(text.charCodeAt(pos - 1))) {
	            var ch = text.charCodeAt(pos);
	            if ((pos + mergeConflictMarkerLength) < text.length) {
	                for (var i = 0, n = mergeConflictMarkerLength; i < n; i++) {
	                    if (text.charCodeAt(pos + i) !== ch) {
	                        return false;
	                    }
	                }
	                return ch === 61 /* equals */ ||
	                    text.charCodeAt(pos + mergeConflictMarkerLength) === 32 /* space */;
	            }
	        }
	        return false;
	    }
	    function scanConflictMarkerTrivia(text, pos, error) {
	        if (error) {
	            error(ts.Diagnostics.Merge_conflict_marker_encountered, mergeConflictMarkerLength);
	        }
	        var ch = text.charCodeAt(pos);
	        var len = text.length;
	        if (ch === 60 /* lessThan */ || ch === 62 /* greaterThan */) {
	            while (pos < len && !isLineBreak(text.charCodeAt(pos))) {
	                pos++;
	            }
	        }
	        else {
	            ts.Debug.assert(ch === 61 /* equals */);
	            // Consume everything from the start of the mid-conlict marker to the start of the next
	            // end-conflict marker.
	            while (pos < len) {
	                var ch_1 = text.charCodeAt(pos);
	                if (ch_1 === 62 /* greaterThan */ && isConflictMarkerTrivia(text, pos)) {
	                    break;
	                }
	                pos++;
	            }
	        }
	        return pos;
	    }
	    var shebangTriviaRegex = /^#!.*/;
	    function isShebangTrivia(text, pos) {
	        // Shebangs check must only be done at the start of the file
	        ts.Debug.assert(pos === 0);
	        return shebangTriviaRegex.test(text);
	    }
	    function scanShebangTrivia(text, pos) {
	        var shebang = shebangTriviaRegex.exec(text)[0];
	        pos = pos + shebang.length;
	        return pos;
	    }
	    /**
	     * Extract comments from text prefixing the token closest following `pos`.
	     * The return value is an array containing a TextRange for each comment.
	     * Single-line comment ranges include the beginning '//' characters but not the ending line break.
	     * Multi - line comment ranges include the beginning '/* and ending '<asterisk>/' characters.
	     * The return value is undefined if no comments were found.
	     * @param trailing
	     * If false, whitespace is skipped until the first line break and comments between that location
	     * and the next token are returned.
	     * If true, comments occurring between the given position and the next line break are returned.
	     */
	    function getCommentRanges(text, pos, trailing) {
	        var result;
	        var collecting = trailing || pos === 0;
	        while (pos < text.length) {
	            var ch = text.charCodeAt(pos);
	            switch (ch) {
	                case 13 /* carriageReturn */:
	                    if (text.charCodeAt(pos + 1) === 10 /* lineFeed */) {
	                        pos++;
	                    }
	                case 10 /* lineFeed */:
	                    pos++;
	                    if (trailing) {
	                        return result;
	                    }
	                    collecting = true;
	                    if (result && result.length) {
	                        ts.lastOrUndefined(result).hasTrailingNewLine = true;
	                    }
	                    continue;
	                case 9 /* tab */:
	                case 11 /* verticalTab */:
	                case 12 /* formFeed */:
	                case 32 /* space */:
	                    pos++;
	                    continue;
	                case 47 /* slash */:
	                    var nextChar = text.charCodeAt(pos + 1);
	                    var hasTrailingNewLine = false;
	                    if (nextChar === 47 /* slash */ || nextChar === 42 /* asterisk */) {
	                        var kind = nextChar === 47 /* slash */ ? 2 /* SingleLineCommentTrivia */ : 3 /* MultiLineCommentTrivia */;
	                        var startPos = pos;
	                        pos += 2;
	                        if (nextChar === 47 /* slash */) {
	                            while (pos < text.length) {
	                                if (isLineBreak(text.charCodeAt(pos))) {
	                                    hasTrailingNewLine = true;
	                                    break;
	                                }
	                                pos++;
	                            }
	                        }
	                        else {
	                            while (pos < text.length) {
	                                if (text.charCodeAt(pos) === 42 /* asterisk */ && text.charCodeAt(pos + 1) === 47 /* slash */) {
	                                    pos += 2;
	                                    break;
	                                }
	                                pos++;
	                            }
	                        }
	                        if (collecting) {
	                            if (!result) {
	                                result = [];
	                            }
	                            result.push({ pos: startPos, end: pos, hasTrailingNewLine: hasTrailingNewLine, kind: kind });
	                        }
	                        continue;
	                    }
	                    break;
	                default:
	                    if (ch > 127 /* maxAsciiCharacter */ && (isWhiteSpace(ch) || isLineBreak(ch))) {
	                        if (result && result.length && isLineBreak(ch)) {
	                            ts.lastOrUndefined(result).hasTrailingNewLine = true;
	                        }
	                        pos++;
	                        continue;
	                    }
	                    break;
	            }
	            return result;
	        }
	        return result;
	    }
	    function getLeadingCommentRanges(text, pos) {
	        return getCommentRanges(text, pos, /*trailing*/ false);
	    }
	    ts.getLeadingCommentRanges = getLeadingCommentRanges;
	    function getTrailingCommentRanges(text, pos) {
	        return getCommentRanges(text, pos, /*trailing*/ true);
	    }
	    ts.getTrailingCommentRanges = getTrailingCommentRanges;
	    /** Optionally, get the shebang */
	    function getShebang(text) {
	        return shebangTriviaRegex.test(text)
	            ? shebangTriviaRegex.exec(text)[0]
	            : undefined;
	    }
	    ts.getShebang = getShebang;
	    function isIdentifierStart(ch, languageVersion) {
	        return ch >= 65 /* A */ && ch <= 90 /* Z */ || ch >= 97 /* a */ && ch <= 122 /* z */ ||
	            ch === 36 /* $ */ || ch === 95 /* _ */ ||
	            ch > 127 /* maxAsciiCharacter */ && isUnicodeIdentifierStart(ch, languageVersion);
	    }
	    ts.isIdentifierStart = isIdentifierStart;
	    function isIdentifierPart(ch, languageVersion) {
	        return ch >= 65 /* A */ && ch <= 90 /* Z */ || ch >= 97 /* a */ && ch <= 122 /* z */ ||
	            ch >= 48 /* _0 */ && ch <= 57 /* _9 */ || ch === 36 /* $ */ || ch === 95 /* _ */ ||
	            ch > 127 /* maxAsciiCharacter */ && isUnicodeIdentifierPart(ch, languageVersion);
	    }
	    ts.isIdentifierPart = isIdentifierPart;
	    /* @internal */
	    function isIdentifier(name, languageVersion) {
	        if (!isIdentifierStart(name.charCodeAt(0), languageVersion)) {
	            return false;
	        }
	        for (var i = 1, n = name.length; i < n; i++) {
	            if (!isIdentifierPart(name.charCodeAt(i), languageVersion)) {
	                return false;
	            }
	        }
	        return true;
	    }
	    ts.isIdentifier = isIdentifier;
	    // Creates a scanner over a (possibly unspecified) range of a piece of text.
	    function createScanner(languageVersion, skipTrivia, languageVariant, text, onError, start, length) {
	        if (languageVariant === void 0) { languageVariant = 0 /* Standard */; }
	        // Current position (end position of text of current token)
	        var pos;
	        // end of text
	        var end;
	        // Start position of whitespace before current token
	        var startPos;
	        // Start position of text of current token
	        var tokenPos;
	        var token;
	        var tokenValue;
	        var precedingLineBreak;
	        var hasExtendedUnicodeEscape;
	        var tokenIsUnterminated;
	        setText(text, start, length);
	        return {
	            getStartPos: function () { return startPos; },
	            getTextPos: function () { return pos; },
	            getToken: function () { return token; },
	            getTokenPos: function () { return tokenPos; },
	            getTokenText: function () { return text.substring(tokenPos, pos); },
	            getTokenValue: function () { return tokenValue; },
	            hasExtendedUnicodeEscape: function () { return hasExtendedUnicodeEscape; },
	            hasPrecedingLineBreak: function () { return precedingLineBreak; },
	            isIdentifier: function () { return token === 69 /* Identifier */ || token > 105 /* LastReservedWord */; },
	            isReservedWord: function () { return token >= 70 /* FirstReservedWord */ && token <= 105 /* LastReservedWord */; },
	            isUnterminated: function () { return tokenIsUnterminated; },
	            reScanGreaterToken: reScanGreaterToken,
	            reScanSlashToken: reScanSlashToken,
	            reScanTemplateToken: reScanTemplateToken,
	            scanJsxIdentifier: scanJsxIdentifier,
	            reScanJsxToken: reScanJsxToken,
	            scanJsxToken: scanJsxToken,
	            scanJSDocToken: scanJSDocToken,
	            scan: scan,
	            setText: setText,
	            setScriptTarget: setScriptTarget,
	            setLanguageVariant: setLanguageVariant,
	            setOnError: setOnError,
	            setTextPos: setTextPos,
	            tryScan: tryScan,
	            lookAhead: lookAhead,
	            scanRange: scanRange
	        };
	        function error(message, length) {
	            if (onError) {
	                onError(message, length || 0);
	            }
	        }
	        function scanNumber() {
	            var start = pos;
	            while (isDigit(text.charCodeAt(pos)))
	                pos++;
	            if (text.charCodeAt(pos) === 46 /* dot */) {
	                pos++;
	                while (isDigit(text.charCodeAt(pos)))
	                    pos++;
	            }
	            var end = pos;
	            if (text.charCodeAt(pos) === 69 /* E */ || text.charCodeAt(pos) === 101 /* e */) {
	                pos++;
	                if (text.charCodeAt(pos) === 43 /* plus */ || text.charCodeAt(pos) === 45 /* minus */)
	                    pos++;
	                if (isDigit(text.charCodeAt(pos))) {
	                    pos++;
	                    while (isDigit(text.charCodeAt(pos)))
	                        pos++;
	                    end = pos;
	                }
	                else {
	                    error(ts.Diagnostics.Digit_expected);
	                }
	            }
	            return "" + +(text.substring(start, end));
	        }
	        function scanOctalDigits() {
	            var start = pos;
	            while (isOctalDigit(text.charCodeAt(pos))) {
	                pos++;
	            }
	            return +(text.substring(start, pos));
	        }
	        /**
	         * Scans the given number of hexadecimal digits in the text,
	         * returning -1 if the given number is unavailable.
	         */
	        function scanExactNumberOfHexDigits(count) {
	            return scanHexDigits(/*minCount*/ count, /*scanAsManyAsPossible*/ false);
	        }
	        /**
	         * Scans as many hexadecimal digits as are available in the text,
	         * returning -1 if the given number of digits was unavailable.
	         */
	        function scanMinimumNumberOfHexDigits(count) {
	            return scanHexDigits(/*minCount*/ count, /*scanAsManyAsPossible*/ true);
	        }
	        function scanHexDigits(minCount, scanAsManyAsPossible) {
	            var digits = 0;
	            var value = 0;
	            while (digits < minCount || scanAsManyAsPossible) {
	                var ch = text.charCodeAt(pos);
	                if (ch >= 48 /* _0 */ && ch <= 57 /* _9 */) {
	                    value = value * 16 + ch - 48 /* _0 */;
	                }
	                else if (ch >= 65 /* A */ && ch <= 70 /* F */) {
	                    value = value * 16 + ch - 65 /* A */ + 10;
	                }
	                else if (ch >= 97 /* a */ && ch <= 102 /* f */) {
	                    value = value * 16 + ch - 97 /* a */ + 10;
	                }
	                else {
	                    break;
	                }
	                pos++;
	                digits++;
	            }
	            if (digits < minCount) {
	                value = -1;
	            }
	            return value;
	        }
	        function scanString() {
	            var quote = text.charCodeAt(pos);
	            pos++;
	            var result = "";
	            var start = pos;
	            while (true) {
	                if (pos >= end) {
	                    result += text.substring(start, pos);
	                    tokenIsUnterminated = true;
	                    error(ts.Diagnostics.Unterminated_string_literal);
	                    break;
	                }
	                var ch = text.charCodeAt(pos);
	                if (ch === quote) {
	                    result += text.substring(start, pos);
	                    pos++;
	                    break;
	                }
	                if (ch === 92 /* backslash */) {
	                    result += text.substring(start, pos);
	                    result += scanEscapeSequence();
	                    start = pos;
	                    continue;
	                }
	                if (isLineBreak(ch)) {
	                    result += text.substring(start, pos);
	                    tokenIsUnterminated = true;
	                    error(ts.Diagnostics.Unterminated_string_literal);
	                    break;
	                }
	                pos++;
	            }
	            return result;
	        }
	        /**
	         * Sets the current 'tokenValue' and returns a NoSubstitutionTemplateLiteral or
	         * a literal component of a TemplateExpression.
	         */
	        function scanTemplateAndSetTokenValue() {
	            var startedWithBacktick = text.charCodeAt(pos) === 96 /* backtick */;
	            pos++;
	            var start = pos;
	            var contents = "";
	            var resultingToken;
	            while (true) {
	                if (pos >= end) {
	                    contents += text.substring(start, pos);
	                    tokenIsUnterminated = true;
	                    error(ts.Diagnostics.Unterminated_template_literal);
	                    resultingToken = startedWithBacktick ? 11 /* NoSubstitutionTemplateLiteral */ : 14 /* TemplateTail */;
	                    break;
	                }
	                var currChar = text.charCodeAt(pos);
	                // '`'
	                if (currChar === 96 /* backtick */) {
	                    contents += text.substring(start, pos);
	                    pos++;
	                    resultingToken = startedWithBacktick ? 11 /* NoSubstitutionTemplateLiteral */ : 14 /* TemplateTail */;
	                    break;
	                }
	                // '${'
	                if (currChar === 36 /* $ */ && pos + 1 < end && text.charCodeAt(pos + 1) === 123 /* openBrace */) {
	                    contents += text.substring(start, pos);
	                    pos += 2;
	                    resultingToken = startedWithBacktick ? 12 /* TemplateHead */ : 13 /* TemplateMiddle */;
	                    break;
	                }
	                // Escape character
	                if (currChar === 92 /* backslash */) {
	                    contents += text.substring(start, pos);
	                    contents += scanEscapeSequence();
	                    start = pos;
	                    continue;
	                }
	                // Speculated ECMAScript 6 Spec 11.8.6.1:
	                // <CR><LF> and <CR> LineTerminatorSequences are normalized to <LF> for Template Values
	                if (currChar === 13 /* carriageReturn */) {
	                    contents += text.substring(start, pos);
	                    pos++;
	                    if (pos < end && text.charCodeAt(pos) === 10 /* lineFeed */) {
	                        pos++;
	                    }
	                    contents += "\n";
	                    start = pos;
	                    continue;
	                }
	                pos++;
	            }
	            ts.Debug.assert(resultingToken !== undefined);
	            tokenValue = contents;
	            return resultingToken;
	        }
	        function scanEscapeSequence() {
	            pos++;
	            if (pos >= end) {
	                error(ts.Diagnostics.Unexpected_end_of_text);
	                return "";
	            }
	            var ch = text.charCodeAt(pos);
	            pos++;
	            switch (ch) {
	                case 48 /* _0 */:
	                    return "\0";
	                case 98 /* b */:
	                    return "\b";
	                case 116 /* t */:
	                    return "\t";
	                case 110 /* n */:
	                    return "\n";
	                case 118 /* v */:
	                    return "\v";
	                case 102 /* f */:
	                    return "\f";
	                case 114 /* r */:
	                    return "\r";
	                case 39 /* singleQuote */:
	                    return "\'";
	                case 34 /* doubleQuote */:
	                    return "\"";
	                case 117 /* u */:
	                    // '\u{DDDDDDDD}'
	                    if (pos < end && text.charCodeAt(pos) === 123 /* openBrace */) {
	                        hasExtendedUnicodeEscape = true;
	                        pos++;
	                        return scanExtendedUnicodeEscape();
	                    }
	                    // '\uDDDD'
	                    return scanHexadecimalEscape(/*numDigits*/ 4);
	                case 120 /* x */:
	                    // '\xDD'
	                    return scanHexadecimalEscape(/*numDigits*/ 2);
	                // when encountering a LineContinuation (i.e. a backslash and a line terminator sequence),
	                // the line terminator is interpreted to be "the empty code unit sequence".
	                case 13 /* carriageReturn */:
	                    if (pos < end && text.charCodeAt(pos) === 10 /* lineFeed */) {
	                        pos++;
	                    }
	                // fall through
	                case 10 /* lineFeed */:
	                case 8232 /* lineSeparator */:
	                case 8233 /* paragraphSeparator */:
	                    return "";
	                default:
	                    return String.fromCharCode(ch);
	            }
	        }
	        function scanHexadecimalEscape(numDigits) {
	            var escapedValue = scanExactNumberOfHexDigits(numDigits);
	            if (escapedValue >= 0) {
	                return String.fromCharCode(escapedValue);
	            }
	            else {
	                error(ts.Diagnostics.Hexadecimal_digit_expected);
	                return "";
	            }
	        }
	        function scanExtendedUnicodeEscape() {
	            var escapedValue = scanMinimumNumberOfHexDigits(1);
	            var isInvalidExtendedEscape = false;
	            // Validate the value of the digit
	            if (escapedValue < 0) {
	                error(ts.Diagnostics.Hexadecimal_digit_expected);
	                isInvalidExtendedEscape = true;
	            }
	            else if (escapedValue > 0x10FFFF) {
	                error(ts.Diagnostics.An_extended_Unicode_escape_value_must_be_between_0x0_and_0x10FFFF_inclusive);
	                isInvalidExtendedEscape = true;
	            }
	            if (pos >= end) {
	                error(ts.Diagnostics.Unexpected_end_of_text);
	                isInvalidExtendedEscape = true;
	            }
	            else if (text.charCodeAt(pos) === 125 /* closeBrace */) {
	                // Only swallow the following character up if it's a '}'.
	                pos++;
	            }
	            else {
	                error(ts.Diagnostics.Unterminated_Unicode_escape_sequence);
	                isInvalidExtendedEscape = true;
	            }
	            if (isInvalidExtendedEscape) {
	                return "";
	            }
	            return utf16EncodeAsString(escapedValue);
	        }
	        // Derived from the 10.1.1 UTF16Encoding of the ES6 Spec.
	        function utf16EncodeAsString(codePoint) {
	            ts.Debug.assert(0x0 <= codePoint && codePoint <= 0x10FFFF);
	            if (codePoint <= 65535) {
	                return String.fromCharCode(codePoint);
	            }
	            var codeUnit1 = Math.floor((codePoint - 65536) / 1024) + 0xD800;
	            var codeUnit2 = ((codePoint - 65536) % 1024) + 0xDC00;
	            return String.fromCharCode(codeUnit1, codeUnit2);
	        }
	        // Current character is known to be a backslash. Check for Unicode escape of the form '\uXXXX'
	        // and return code point value if valid Unicode escape is found. Otherwise return -1.
	        function peekUnicodeEscape() {
	            if (pos + 5 < end && text.charCodeAt(pos + 1) === 117 /* u */) {
	                var start_1 = pos;
	                pos += 2;
	                var value = scanExactNumberOfHexDigits(4);
	                pos = start_1;
	                return value;
	            }
	            return -1;
	        }
	        function scanIdentifierParts() {
	            var result = "";
	            var start = pos;
	            while (pos < end) {
	                var ch = text.charCodeAt(pos);
	                if (isIdentifierPart(ch, languageVersion)) {
	                    pos++;
	                }
	                else if (ch === 92 /* backslash */) {
	                    ch = peekUnicodeEscape();
	                    if (!(ch >= 0 && isIdentifierPart(ch, languageVersion))) {
	                        break;
	                    }
	                    result += text.substring(start, pos);
	                    result += String.fromCharCode(ch);
	                    // Valid Unicode escape is always six characters
	                    pos += 6;
	                    start = pos;
	                }
	                else {
	                    break;
	                }
	            }
	            result += text.substring(start, pos);
	            return result;
	        }
	        function getIdentifierToken() {
	            // Reserved words are between 2 and 11 characters long and start with a lowercase letter
	            var len = tokenValue.length;
	            if (len >= 2 && len <= 11) {
	                var ch = tokenValue.charCodeAt(0);
	                if (ch >= 97 /* a */ && ch <= 122 /* z */ && hasOwnProperty.call(textToToken, tokenValue)) {
	                    return token = textToToken[tokenValue];
	                }
	            }
	            return token = 69 /* Identifier */;
	        }
	        function scanBinaryOrOctalDigits(base) {
	            ts.Debug.assert(base !== 2 || base !== 8, "Expected either base 2 or base 8");
	            var value = 0;
	            // For counting number of digits; Valid binaryIntegerLiteral must have at least one binary digit following B or b.
	            // Similarly valid octalIntegerLiteral must have at least one octal digit following o or O.
	            var numberOfDigits = 0;
	            while (true) {
	                var ch = text.charCodeAt(pos);
	                var valueOfCh = ch - 48 /* _0 */;
	                if (!isDigit(ch) || valueOfCh >= base) {
	                    break;
	                }
	                value = value * base + valueOfCh;
	                pos++;
	                numberOfDigits++;
	            }
	            // Invalid binaryIntegerLiteral or octalIntegerLiteral
	            if (numberOfDigits === 0) {
	                return -1;
	            }
	            return value;
	        }
	        function scan() {
	            startPos = pos;
	            hasExtendedUnicodeEscape = false;
	            precedingLineBreak = false;
	            tokenIsUnterminated = false;
	            while (true) {
	                tokenPos = pos;
	                if (pos >= end) {
	                    return token = 1 /* EndOfFileToken */;
	                }
	                var ch = text.charCodeAt(pos);
	                // Special handling for shebang
	                if (ch === 35 /* hash */ && pos === 0 && isShebangTrivia(text, pos)) {
	                    pos = scanShebangTrivia(text, pos);
	                    if (skipTrivia) {
	                        continue;
	                    }
	                    else {
	                        return token = 6 /* ShebangTrivia */;
	                    }
	                }
	                switch (ch) {
	                    case 10 /* lineFeed */:
	                    case 13 /* carriageReturn */:
	                        precedingLineBreak = true;
	                        if (skipTrivia) {
	                            pos++;
	                            continue;
	                        }
	                        else {
	                            if (ch === 13 /* carriageReturn */ && pos + 1 < end && text.charCodeAt(pos + 1) === 10 /* lineFeed */) {
	                                // consume both CR and LF
	                                pos += 2;
	                            }
	                            else {
	                                pos++;
	                            }
	                            return token = 4 /* NewLineTrivia */;
	                        }
	                    case 9 /* tab */:
	                    case 11 /* verticalTab */:
	                    case 12 /* formFeed */:
	                    case 32 /* space */:
	                        if (skipTrivia) {
	                            pos++;
	                            continue;
	                        }
	                        else {
	                            while (pos < end && isWhiteSpace(text.charCodeAt(pos))) {
	                                pos++;
	                            }
	                            return token = 5 /* WhitespaceTrivia */;
	                        }
	                    case 33 /* exclamation */:
	                        if (text.charCodeAt(pos + 1) === 61 /* equals */) {
	                            if (text.charCodeAt(pos + 2) === 61 /* equals */) {
	                                return pos += 3, token = 33 /* ExclamationEqualsEqualsToken */;
	                            }
	                            return pos += 2, token = 31 /* ExclamationEqualsToken */;
	                        }
	                        pos++;
	                        return token = 49 /* ExclamationToken */;
	                    case 34 /* doubleQuote */:
	                    case 39 /* singleQuote */:
	                        tokenValue = scanString();
	                        return token = 9 /* StringLiteral */;
	                    case 96 /* backtick */:
	                        return token = scanTemplateAndSetTokenValue();
	                    case 37 /* percent */:
	                        if (text.charCodeAt(pos + 1) === 61 /* equals */) {
	                            return pos += 2, token = 62 /* PercentEqualsToken */;
	                        }
	                        pos++;
	                        return token = 40 /* PercentToken */;
	                    case 38 /* ampersand */:
	                        if (text.charCodeAt(pos + 1) === 38 /* ampersand */) {
	                            return pos += 2, token = 51 /* AmpersandAmpersandToken */;
	                        }
	                        if (text.charCodeAt(pos + 1) === 61 /* equals */) {
	                            return pos += 2, token = 66 /* AmpersandEqualsToken */;
	                        }
	                        pos++;
	                        return token = 46 /* AmpersandToken */;
	                    case 40 /* openParen */:
	                        pos++;
	                        return token = 17 /* OpenParenToken */;
	                    case 41 /* closeParen */:
	                        pos++;
	                        return token = 18 /* CloseParenToken */;
	                    case 42 /* asterisk */:
	                        if (text.charCodeAt(pos + 1) === 61 /* equals */) {
	                            return pos += 2, token = 59 /* AsteriskEqualsToken */;
	                        }
	                        if (text.charCodeAt(pos + 1) === 42 /* asterisk */) {
	                            if (text.charCodeAt(pos + 2) === 61 /* equals */) {
	                                return pos += 3, token = 60 /* AsteriskAsteriskEqualsToken */;
	                            }
	                            return pos += 2, token = 38 /* AsteriskAsteriskToken */;
	                        }
	                        pos++;
	                        return token = 37 /* AsteriskToken */;
	                    case 43 /* plus */:
	                        if (text.charCodeAt(pos + 1) === 43 /* plus */) {
	                            return pos += 2, token = 41 /* PlusPlusToken */;
	                        }
	                        if (text.charCodeAt(pos + 1) === 61 /* equals */) {
	                            return pos += 2, token = 57 /* PlusEqualsToken */;
	                        }
	                        pos++;
	                        return token = 35 /* PlusToken */;
	                    case 44 /* comma */:
	                        pos++;
	                        return token = 24 /* CommaToken */;
	                    case 45 /* minus */:
	                        if (text.charCodeAt(pos + 1) === 45 /* minus */) {
	                            return pos += 2, token = 42 /* MinusMinusToken */;
	                        }
	                        if (text.charCodeAt(pos + 1) === 61 /* equals */) {
	                            return pos += 2, token = 58 /* MinusEqualsToken */;
	                        }
	                        pos++;
	                        return token = 36 /* MinusToken */;
	                    case 46 /* dot */:
	                        if (isDigit(text.charCodeAt(pos + 1))) {
	                            tokenValue = scanNumber();
	                            return token = 8 /* NumericLiteral */;
	                        }
	                        if (text.charCodeAt(pos + 1) === 46 /* dot */ && text.charCodeAt(pos + 2) === 46 /* dot */) {
	                            return pos += 3, token = 22 /* DotDotDotToken */;
	                        }
	                        pos++;
	                        return token = 21 /* DotToken */;
	                    case 47 /* slash */:
	                        // Single-line comment
	                        if (text.charCodeAt(pos + 1) === 47 /* slash */) {
	                            pos += 2;
	                            while (pos < end) {
	                                if (isLineBreak(text.charCodeAt(pos))) {
	                                    break;
	                                }
	                                pos++;
	                            }
	                            if (skipTrivia) {
	                                continue;
	                            }
	                            else {
	                                return token = 2 /* SingleLineCommentTrivia */;
	                            }
	                        }
	                        // Multi-line comment
	                        if (text.charCodeAt(pos + 1) === 42 /* asterisk */) {
	                            pos += 2;
	                            var commentClosed = false;
	                            while (pos < end) {
	                                var ch_2 = text.charCodeAt(pos);
	                                if (ch_2 === 42 /* asterisk */ && text.charCodeAt(pos + 1) === 47 /* slash */) {
	                                    pos += 2;
	                                    commentClosed = true;
	                                    break;
	                                }
	                                if (isLineBreak(ch_2)) {
	                                    precedingLineBreak = true;
	                                }
	                                pos++;
	                            }
	                            if (!commentClosed) {
	                                error(ts.Diagnostics.Asterisk_Slash_expected);
	                            }
	                            if (skipTrivia) {
	                                continue;
	                            }
	                            else {
	                                tokenIsUnterminated = !commentClosed;
	                                return token = 3 /* MultiLineCommentTrivia */;
	                            }
	                        }
	                        if (text.charCodeAt(pos + 1) === 61 /* equals */) {
	                            return pos += 2, token = 61 /* SlashEqualsToken */;
	                        }
	                        pos++;
	                        return token = 39 /* SlashToken */;
	                    case 48 /* _0 */:
	                        if (pos + 2 < end && (text.charCodeAt(pos + 1) === 88 /* X */ || text.charCodeAt(pos + 1) === 120 /* x */)) {
	                            pos += 2;
	                            var value = scanMinimumNumberOfHexDigits(1);
	                            if (value < 0) {
	                                error(ts.Diagnostics.Hexadecimal_digit_expected);
	                                value = 0;
	                            }
	                            tokenValue = "" + value;
	                            return token = 8 /* NumericLiteral */;
	                        }
	                        else if (pos + 2 < end && (text.charCodeAt(pos + 1) === 66 /* B */ || text.charCodeAt(pos + 1) === 98 /* b */)) {
	                            pos += 2;
	                            var value = scanBinaryOrOctalDigits(/* base */ 2);
	                            if (value < 0) {
	                                error(ts.Diagnostics.Binary_digit_expected);
	                                value = 0;
	                            }
	                            tokenValue = "" + value;
	                            return token = 8 /* NumericLiteral */;
	                        }
	                        else if (pos + 2 < end && (text.charCodeAt(pos + 1) === 79 /* O */ || text.charCodeAt(pos + 1) === 111 /* o */)) {
	                            pos += 2;
	                            var value = scanBinaryOrOctalDigits(/* base */ 8);
	                            if (value < 0) {
	                                error(ts.Diagnostics.Octal_digit_expected);
	                                value = 0;
	                            }
	                            tokenValue = "" + value;
	                            return token = 8 /* NumericLiteral */;
	                        }
	                        // Try to parse as an octal
	                        if (pos + 1 < end && isOctalDigit(text.charCodeAt(pos + 1))) {
	                            tokenValue = "" + scanOctalDigits();
	                            return token = 8 /* NumericLiteral */;
	                        }
	                    // This fall-through is a deviation from the EcmaScript grammar. The grammar says that a leading zero
	                    // can only be followed by an octal digit, a dot, or the end of the number literal. However, we are being
	                    // permissive and allowing decimal digits of the form 08* and 09* (which many browsers also do).
	                    case 49 /* _1 */:
	                    case 50 /* _2 */:
	                    case 51 /* _3 */:
	                    case 52 /* _4 */:
	                    case 53 /* _5 */:
	                    case 54 /* _6 */:
	                    case 55 /* _7 */:
	                    case 56 /* _8 */:
	                    case 57 /* _9 */:
	                        tokenValue = scanNumber();
	                        return token = 8 /* NumericLiteral */;
	                    case 58 /* colon */:
	                        pos++;
	                        return token = 54 /* ColonToken */;
	                    case 59 /* semicolon */:
	                        pos++;
	                        return token = 23 /* SemicolonToken */;
	                    case 60 /* lessThan */:
	                        if (isConflictMarkerTrivia(text, pos)) {
	                            pos = scanConflictMarkerTrivia(text, pos, error);
	                            if (skipTrivia) {
	                                continue;
	                            }
	                            else {
	                                return token = 7 /* ConflictMarkerTrivia */;
	                            }
	                        }
	                        if (text.charCodeAt(pos + 1) === 60 /* lessThan */) {
	                            if (text.charCodeAt(pos + 2) === 61 /* equals */) {
	                                return pos += 3, token = 63 /* LessThanLessThanEqualsToken */;
	                            }
	                            return pos += 2, token = 43 /* LessThanLessThanToken */;
	                        }
	                        if (text.charCodeAt(pos + 1) === 61 /* equals */) {
	                            return pos += 2, token = 28 /* LessThanEqualsToken */;
	                        }
	                        if (languageVariant === 1 /* JSX */ &&
	                            text.charCodeAt(pos + 1) === 47 /* slash */ &&
	                            text.charCodeAt(pos + 2) !== 42 /* asterisk */) {
	                            return pos += 2, token = 26 /* LessThanSlashToken */;
	                        }
	                        pos++;
	                        return token = 25 /* LessThanToken */;
	                    case 61 /* equals */:
	                        if (isConflictMarkerTrivia(text, pos)) {
	                            pos = scanConflictMarkerTrivia(text, pos, error);
	                            if (skipTrivia) {
	                                continue;
	                            }
	                            else {
	                                return token = 7 /* ConflictMarkerTrivia */;
	                            }
	                        }
	                        if (text.charCodeAt(pos + 1) === 61 /* equals */) {
	                            if (text.charCodeAt(pos + 2) === 61 /* equals */) {
	                                return pos += 3, token = 32 /* EqualsEqualsEqualsToken */;
	                            }
	                            return pos += 2, token = 30 /* EqualsEqualsToken */;
	                        }
	                        if (text.charCodeAt(pos + 1) === 62 /* greaterThan */) {
	                            return pos += 2, token = 34 /* EqualsGreaterThanToken */;
	                        }
	                        pos++;
	                        return token = 56 /* EqualsToken */;
	                    case 62 /* greaterThan */:
	                        if (isConflictMarkerTrivia(text, pos)) {
	                            pos = scanConflictMarkerTrivia(text, pos, error);
	                            if (skipTrivia) {
	                                continue;
	                            }
	                            else {
	                                return token = 7 /* ConflictMarkerTrivia */;
	                            }
	                        }
	                        pos++;
	                        return token = 27 /* GreaterThanToken */;
	                    case 63 /* question */:
	                        pos++;
	                        return token = 53 /* QuestionToken */;
	                    case 91 /* openBracket */:
	                        pos++;
	                        return token = 19 /* OpenBracketToken */;
	                    case 93 /* closeBracket */:
	                        pos++;
	                        return token = 20 /* CloseBracketToken */;
	                    case 94 /* caret */:
	                        if (text.charCodeAt(pos + 1) === 61 /* equals */) {
	                            return pos += 2, token = 68 /* CaretEqualsToken */;
	                        }
	                        pos++;
	                        return token = 48 /* CaretToken */;
	                    case 123 /* openBrace */:
	                        pos++;
	                        return token = 15 /* OpenBraceToken */;
	                    case 124 /* bar */:
	                        if (text.charCodeAt(pos + 1) === 124 /* bar */) {
	                            return pos += 2, token = 52 /* BarBarToken */;
	                        }
	                        if (text.charCodeAt(pos + 1) === 61 /* equals */) {
	                            return pos += 2, token = 67 /* BarEqualsToken */;
	                        }
	                        pos++;
	                        return token = 47 /* BarToken */;
	                    case 125 /* closeBrace */:
	                        pos++;
	                        return token = 16 /* CloseBraceToken */;
	                    case 126 /* tilde */:
	                        pos++;
	                        return token = 50 /* TildeToken */;
	                    case 64 /* at */:
	                        pos++;
	                        return token = 55 /* AtToken */;
	                    case 92 /* backslash */:
	                        var cookedChar = peekUnicodeEscape();
	                        if (cookedChar >= 0 && isIdentifierStart(cookedChar, languageVersion)) {
	                            pos += 6;
	                            tokenValue = String.fromCharCode(cookedChar) + scanIdentifierParts();
	                            return token = getIdentifierToken();
	                        }
	                        error(ts.Diagnostics.Invalid_character);
	                        pos++;
	                        return token = 0 /* Unknown */;
	                    default:
	                        if (isIdentifierStart(ch, languageVersion)) {
	                            pos++;
	                            while (pos < end && isIdentifierPart(ch = text.charCodeAt(pos), languageVersion))
	                                pos++;
	                            tokenValue = text.substring(tokenPos, pos);
	                            if (ch === 92 /* backslash */) {
	                                tokenValue += scanIdentifierParts();
	                            }
	                            return token = getIdentifierToken();
	                        }
	                        else if (isWhiteSpace(ch)) {
	                            pos++;
	                            continue;
	                        }
	                        else if (isLineBreak(ch)) {
	                            precedingLineBreak = true;
	                            pos++;
	                            continue;
	                        }
	                        error(ts.Diagnostics.Invalid_character);
	                        pos++;
	                        return token = 0 /* Unknown */;
	                }
	            }
	        }
	        function reScanGreaterToken() {
	            if (token === 27 /* GreaterThanToken */) {
	                if (text.charCodeAt(pos) === 62 /* greaterThan */) {
	                    if (text.charCodeAt(pos + 1) === 62 /* greaterThan */) {
	                        if (text.charCodeAt(pos + 2) === 61 /* equals */) {
	                            return pos += 3, token = 65 /* GreaterThanGreaterThanGreaterThanEqualsToken */;
	                        }
	                        return pos += 2, token = 45 /* GreaterThanGreaterThanGreaterThanToken */;
	                    }
	                    if (text.charCodeAt(pos + 1) === 61 /* equals */) {
	                        return pos += 2, token = 64 /* GreaterThanGreaterThanEqualsToken */;
	                    }
	                    pos++;
	                    return token = 44 /* GreaterThanGreaterThanToken */;
	                }
	                if (text.charCodeAt(pos) === 61 /* equals */) {
	                    pos++;
	                    return token = 29 /* GreaterThanEqualsToken */;
	                }
	            }
	            return token;
	        }
	        function reScanSlashToken() {
	            if (token === 39 /* SlashToken */ || token === 61 /* SlashEqualsToken */) {
	                var p = tokenPos + 1;
	                var inEscape = false;
	                var inCharacterClass = false;
	                while (true) {
	                    // If we reach the end of a file, or hit a newline, then this is an unterminated
	                    // regex.  Report error and return what we have so far.
	                    if (p >= end) {
	                        tokenIsUnterminated = true;
	                        error(ts.Diagnostics.Unterminated_regular_expression_literal);
	                        break;
	                    }
	                    var ch = text.charCodeAt(p);
	                    if (isLineBreak(ch)) {
	                        tokenIsUnterminated = true;
	                        error(ts.Diagnostics.Unterminated_regular_expression_literal);
	                        break;
	                    }
	                    if (inEscape) {
	                        // Parsing an escape character;
	                        // reset the flag and just advance to the next char.
	                        inEscape = false;
	                    }
	                    else if (ch === 47 /* slash */ && !inCharacterClass) {
	                        // A slash within a character class is permissible,
	                        // but in general it signals the end of the regexp literal.
	                        p++;
	                        break;
	                    }
	                    else if (ch === 91 /* openBracket */) {
	                        inCharacterClass = true;
	                    }
	                    else if (ch === 92 /* backslash */) {
	                        inEscape = true;
	                    }
	                    else if (ch === 93 /* closeBracket */) {
	                        inCharacterClass = false;
	                    }
	                    p++;
	                }
	                while (p < end && isIdentifierPart(text.charCodeAt(p), languageVersion)) {
	                    p++;
	                }
	                pos = p;
	                tokenValue = text.substring(tokenPos, pos);
	                token = 10 /* RegularExpressionLiteral */;
	            }
	            return token;
	        }
	        /**
	         * Unconditionally back up and scan a template expression portion.
	         */
	        function reScanTemplateToken() {
	            ts.Debug.assert(token === 16 /* CloseBraceToken */, "'reScanTemplateToken' should only be called on a '}'");
	            pos = tokenPos;
	            return token = scanTemplateAndSetTokenValue();
	        }
	        function reScanJsxToken() {
	            pos = tokenPos = startPos;
	            return token = scanJsxToken();
	        }
	        function scanJsxToken() {
	            startPos = tokenPos = pos;
	            if (pos >= end) {
	                return token = 1 /* EndOfFileToken */;
	            }
	            var char = text.charCodeAt(pos);
	            if (char === 60 /* lessThan */) {
	                if (text.charCodeAt(pos + 1) === 47 /* slash */) {
	                    pos += 2;
	                    return token = 26 /* LessThanSlashToken */;
	                }
	                pos++;
	                return token = 25 /* LessThanToken */;
	            }
	            if (char === 123 /* openBrace */) {
	                pos++;
	                return token = 15 /* OpenBraceToken */;
	            }
	            while (pos < end) {
	                pos++;
	                char = text.charCodeAt(pos);
	                if ((char === 123 /* openBrace */) || (char === 60 /* lessThan */)) {
	                    break;
	                }
	            }
	            return token = 239 /* JsxText */;
	        }
	        // Scans a JSX identifier; these differ from normal identifiers in that
	        // they allow dashes
	        function scanJsxIdentifier() {
	            if (tokenIsIdentifierOrKeyword(token)) {
	                var firstCharPosition = pos;
	                while (pos < end) {
	                    var ch = text.charCodeAt(pos);
	                    if (ch === 45 /* minus */ || ((firstCharPosition === pos) ? isIdentifierStart(ch, languageVersion) : isIdentifierPart(ch, languageVersion))) {
	                        pos++;
	                    }
	                    else {
	                        break;
	                    }
	                }
	                tokenValue += text.substr(firstCharPosition, pos - firstCharPosition);
	            }
	            return token;
	        }
	        function scanJSDocToken() {
	            if (pos >= end) {
	                return token = 1 /* EndOfFileToken */;
	            }
	            startPos = pos;
	            // Eat leading whitespace
	            var ch = text.charCodeAt(pos);
	            while (pos < end) {
	                ch = text.charCodeAt(pos);
	                if (isWhiteSpace(ch)) {
	                    pos++;
	                }
	                else {
	                    break;
	                }
	            }
	            tokenPos = pos;
	            switch (ch) {
	                case 64 /* at */:
	                    return pos += 1, token = 55 /* AtToken */;
	                case 10 /* lineFeed */:
	                case 13 /* carriageReturn */:
	                    return pos += 1, token = 4 /* NewLineTrivia */;
	                case 42 /* asterisk */:
	                    return pos += 1, token = 37 /* AsteriskToken */;
	                case 123 /* openBrace */:
	                    return pos += 1, token = 15 /* OpenBraceToken */;
	                case 125 /* closeBrace */:
	                    return pos += 1, token = 16 /* CloseBraceToken */;
	                case 91 /* openBracket */:
	                    return pos += 1, token = 19 /* OpenBracketToken */;
	                case 93 /* closeBracket */:
	                    return pos += 1, token = 20 /* CloseBracketToken */;
	                case 61 /* equals */:
	                    return pos += 1, token = 56 /* EqualsToken */;
	                case 44 /* comma */:
	                    return pos += 1, token = 24 /* CommaToken */;
	            }
	            if (isIdentifierStart(ch, 2 /* Latest */)) {
	                pos++;
	                while (isIdentifierPart(text.charCodeAt(pos), 2 /* Latest */) && pos < end) {
	                    pos++;
	                }
	                return token = 69 /* Identifier */;
	            }
	            else {
	                return pos += 1, token = 0 /* Unknown */;
	            }
	        }
	        function speculationHelper(callback, isLookahead) {
	            var savePos = pos;
	            var saveStartPos = startPos;
	            var saveTokenPos = tokenPos;
	            var saveToken = token;
	            var saveTokenValue = tokenValue;
	            var savePrecedingLineBreak = precedingLineBreak;
	            var result = callback();
	            // If our callback returned something 'falsy' or we're just looking ahead,
	            // then unconditionally restore us to where we were.
	            if (!result || isLookahead) {
	                pos = savePos;
	                startPos = saveStartPos;
	                tokenPos = saveTokenPos;
	                token = saveToken;
	                tokenValue = saveTokenValue;
	                precedingLineBreak = savePrecedingLineBreak;
	            }
	            return result;
	        }
	        function scanRange(start, length, callback) {
	            var saveEnd = end;
	            var savePos = pos;
	            var saveStartPos = startPos;
	            var saveTokenPos = tokenPos;
	            var saveToken = token;
	            var savePrecedingLineBreak = precedingLineBreak;
	            var saveTokenValue = tokenValue;
	            var saveHasExtendedUnicodeEscape = hasExtendedUnicodeEscape;
	            var saveTokenIsUnterminated = tokenIsUnterminated;
	            setText(text, start, length);
	            var result = callback();
	            end = saveEnd;
	            pos = savePos;
	            startPos = saveStartPos;
	            tokenPos = saveTokenPos;
	            token = saveToken;
	            precedingLineBreak = savePrecedingLineBreak;
	            tokenValue = saveTokenValue;
	            hasExtendedUnicodeEscape = saveHasExtendedUnicodeEscape;
	            tokenIsUnterminated = saveTokenIsUnterminated;
	            return result;
	        }
	        function lookAhead(callback) {
	            return speculationHelper(callback, /*isLookahead*/ true);
	        }
	        function tryScan(callback) {
	            return speculationHelper(callback, /*isLookahead*/ false);
	        }
	        function setText(newText, start, length) {
	            text = newText || "";
	            end = length === undefined ? text.length : start + length;
	            setTextPos(start || 0);
	        }
	        function setOnError(errorCallback) {
	            onError = errorCallback;
	        }
	        function setScriptTarget(scriptTarget) {
	            languageVersion = scriptTarget;
	        }
	        function setLanguageVariant(variant) {
	            languageVariant = variant;
	        }
	        function setTextPos(textPos) {
	            ts.Debug.assert(textPos >= 0);
	            pos = textPos;
	            startPos = textPos;
	            tokenPos = textPos;
	            token = 0 /* Unknown */;
	            precedingLineBreak = false;
	            tokenValue = undefined;
	            hasExtendedUnicodeEscape = false;
	            tokenIsUnterminated = false;
	        }
	    }
	    ts.createScanner = createScanner;
	})(ts || (ts = {}));
	/// <reference path="sys.ts" />
	/* @internal */
	var ts;
	(function (ts) {
	    function getDeclarationOfKind(symbol, kind) {
	        var declarations = symbol.declarations;
	        if (declarations) {
	            for (var _i = 0, declarations_1 = declarations; _i < declarations_1.length; _i++) {
	                var declaration = declarations_1[_i];
	                if (declaration.kind === kind) {
	                    return declaration;
	                }
	            }
	        }
	        return undefined;
	    }
	    ts.getDeclarationOfKind = getDeclarationOfKind;
	    // Pool writers to avoid needing to allocate them for every symbol we write.
	    var stringWriters = [];
	    function getSingleLineStringWriter() {
	        if (stringWriters.length === 0) {
	            var str_1 = "";
	            var writeText = function (text) { return str_1 += text; };
	            return {
	                string: function () { return str_1; },
	                writeKeyword: writeText,
	                writeOperator: writeText,
	                writePunctuation: writeText,
	                writeSpace: writeText,
	                writeStringLiteral: writeText,
	                writeParameter: writeText,
	                writeSymbol: writeText,
	                // Completely ignore indentation for string writers.  And map newlines to
	                // a single space.
	                writeLine: function () { return str_1 += " "; },
	                increaseIndent: function () { },
	                decreaseIndent: function () { },
	                clear: function () { return str_1 = ""; },
	                trackSymbol: function () { },
	                reportInaccessibleThisError: function () { }
	            };
	        }
	        return stringWriters.pop();
	    }
	    ts.getSingleLineStringWriter = getSingleLineStringWriter;
	    function releaseStringWriter(writer) {
	        writer.clear();
	        stringWriters.push(writer);
	    }
	    ts.releaseStringWriter = releaseStringWriter;
	    function getFullWidth(node) {
	        return node.end - node.pos;
	    }
	    ts.getFullWidth = getFullWidth;
	    function arrayIsEqualTo(array1, array2, equaler) {
	        if (!array1 || !array2) {
	            return array1 === array2;
	        }
	        if (array1.length !== array2.length) {
	            return false;
	        }
	        for (var i = 0; i < array1.length; i++) {
	            var equals = equaler ? equaler(array1[i], array2[i]) : array1[i] === array2[i];
	            if (!equals) {
	                return false;
	            }
	        }
	        return true;
	    }
	    ts.arrayIsEqualTo = arrayIsEqualTo;
	    function hasResolvedModule(sourceFile, moduleNameText) {
	        return sourceFile.resolvedModules && ts.hasProperty(sourceFile.resolvedModules, moduleNameText);
	    }
	    ts.hasResolvedModule = hasResolvedModule;
	    function getResolvedModule(sourceFile, moduleNameText) {
	        return hasResolvedModule(sourceFile, moduleNameText) ? sourceFile.resolvedModules[moduleNameText] : undefined;
	    }
	    ts.getResolvedModule = getResolvedModule;
	    function setResolvedModule(sourceFile, moduleNameText, resolvedModule) {
	        if (!sourceFile.resolvedModules) {
	            sourceFile.resolvedModules = {};
	        }
	        sourceFile.resolvedModules[moduleNameText] = resolvedModule;
	    }
	    ts.setResolvedModule = setResolvedModule;
	    // Returns true if this node contains a parse error anywhere underneath it.
	    function containsParseError(node) {
	        aggregateChildData(node);
	        return (node.parserContextFlags & 64 /* ThisNodeOrAnySubNodesHasError */) !== 0;
	    }
	    ts.containsParseError = containsParseError;
	    function aggregateChildData(node) {
	        if (!(node.parserContextFlags & 128 /* HasAggregatedChildData */)) {
	            // A node is considered to contain a parse error if:
	            //  a) the parser explicitly marked that it had an error
	            //  b) any of it's children reported that it had an error.
	            var thisNodeOrAnySubNodesHasError = ((node.parserContextFlags & 16 /* ThisNodeHasError */) !== 0) ||
	                ts.forEachChild(node, containsParseError);
	            // If so, mark ourselves accordingly.
	            if (thisNodeOrAnySubNodesHasError) {
	                node.parserContextFlags |= 64 /* ThisNodeOrAnySubNodesHasError */;
	            }
	            // Also mark that we've propogated the child information to this node.  This way we can
	            // always consult the bit directly on this node without needing to check its children
	            // again.
	            node.parserContextFlags |= 128 /* HasAggregatedChildData */;
	        }
	    }
	    function getSourceFileOfNode(node) {
	        while (node && node.kind !== 251 /* SourceFile */) {
	            node = node.parent;
	        }
	        return node;
	    }
	    ts.getSourceFileOfNode = getSourceFileOfNode;
	    function isStatementWithLocals(node) {
	        switch (node.kind) {
	            case 195 /* Block */:
	            case 223 /* CaseBlock */:
	            case 202 /* ForStatement */:
	            case 203 /* ForInStatement */:
	            case 204 /* ForOfStatement */:
	                return true;
	        }
	        return false;
	    }
	    ts.isStatementWithLocals = isStatementWithLocals;
	    function getStartPositionOfLine(line, sourceFile) {
	        ts.Debug.assert(line >= 0);
	        return ts.getLineStarts(sourceFile)[line];
	    }
	    ts.getStartPositionOfLine = getStartPositionOfLine;
	    // This is a useful function for debugging purposes.
	    function nodePosToString(node) {
	        var file = getSourceFileOfNode(node);
	        var loc = ts.getLineAndCharacterOfPosition(file, node.pos);
	        return file.fileName + "(" + (loc.line + 1) + "," + (loc.character + 1) + ")";
	    }
	    ts.nodePosToString = nodePosToString;
	    function getStartPosOfNode(node) {
	        return node.pos;
	    }
	    ts.getStartPosOfNode = getStartPosOfNode;
	    // Returns true if this node is missing from the actual source code. A 'missing' node is different
	    // from 'undefined/defined'. When a node is undefined (which can happen for optional nodes
	    // in the tree), it is definitely missing. However, a node may be defined, but still be
	    // missing.  This happens whenever the parser knows it needs to parse something, but can't
	    // get anything in the source code that it expects at that location. For example:
	    //
	    //          let a: ;
	    //
	    // Here, the Type in the Type-Annotation is not-optional (as there is a colon in the source
	    // code). So the parser will attempt to parse out a type, and will create an actual node.
	    // However, this node will be 'missing' in the sense that no actual source-code/tokens are
	    // contained within it.
	    function nodeIsMissing(node) {
	        if (!node) {
	            return true;
	        }
	        return node.pos === node.end && node.pos >= 0 && node.kind !== 1 /* EndOfFileToken */;
	    }
	    ts.nodeIsMissing = nodeIsMissing;
	    function nodeIsPresent(node) {
	        return !nodeIsMissing(node);
	    }
	    ts.nodeIsPresent = nodeIsPresent;
	    function getTokenPosOfNode(node, sourceFile) {
	        // With nodes that have no width (i.e. 'Missing' nodes), we actually *don't*
	        // want to skip trivia because this will launch us forward to the next token.
	        if (nodeIsMissing(node)) {
	            return node.pos;
	        }
	        return ts.skipTrivia((sourceFile || getSourceFileOfNode(node)).text, node.pos);
	    }
	    ts.getTokenPosOfNode = getTokenPosOfNode;
	    function getNonDecoratorTokenPosOfNode(node, sourceFile) {
	        if (nodeIsMissing(node) || !node.decorators) {
	            return getTokenPosOfNode(node, sourceFile);
	        }
	        return ts.skipTrivia((sourceFile || getSourceFileOfNode(node)).text, node.decorators.end);
	    }
	    ts.getNonDecoratorTokenPosOfNode = getNonDecoratorTokenPosOfNode;
	    function getSourceTextOfNodeFromSourceFile(sourceFile, node, includeTrivia) {
	        if (includeTrivia === void 0) { includeTrivia = false; }
	        if (nodeIsMissing(node)) {
	            return "";
	        }
	        var text = sourceFile.text;
	        return text.substring(includeTrivia ? node.pos : ts.skipTrivia(text, node.pos), node.end);
	    }
	    ts.getSourceTextOfNodeFromSourceFile = getSourceTextOfNodeFromSourceFile;
	    function getTextOfNodeFromSourceText(sourceText, node) {
	        if (nodeIsMissing(node)) {
	            return "";
	        }
	        return sourceText.substring(ts.skipTrivia(sourceText, node.pos), node.end);
	    }
	    ts.getTextOfNodeFromSourceText = getTextOfNodeFromSourceText;
	    function getTextOfNode(node, includeTrivia) {
	        if (includeTrivia === void 0) { includeTrivia = false; }
	        return getSourceTextOfNodeFromSourceFile(getSourceFileOfNode(node), node, includeTrivia);
	    }
	    ts.getTextOfNode = getTextOfNode;
	    // Add an extra underscore to identifiers that start with two underscores to avoid issues with magic names like '__proto__'
	    function escapeIdentifier(identifier) {
	        return identifier.length >= 2 && identifier.charCodeAt(0) === 95 /* _ */ && identifier.charCodeAt(1) === 95 /* _ */ ? "_" + identifier : identifier;
	    }
	    ts.escapeIdentifier = escapeIdentifier;
	    // Remove extra underscore from escaped identifier
	    function unescapeIdentifier(identifier) {
	        return identifier.length >= 3 && identifier.charCodeAt(0) === 95 /* _ */ && identifier.charCodeAt(1) === 95 /* _ */ && identifier.charCodeAt(2) === 95 /* _ */ ? identifier.substr(1) : identifier;
	    }
	    ts.unescapeIdentifier = unescapeIdentifier;
	    // Make an identifier from an external module name by extracting the string after the last "/" and replacing
	    // all non-alphanumeric characters with underscores
	    function makeIdentifierFromModuleName(moduleName) {
	        return ts.getBaseFileName(moduleName).replace(/^(\d)/, "_$1").replace(/\W/g, "_");
	    }
	    ts.makeIdentifierFromModuleName = makeIdentifierFromModuleName;
	    function isBlockOrCatchScoped(declaration) {
	        return (getCombinedNodeFlags(declaration) & 24576 /* BlockScoped */) !== 0 ||
	            isCatchClauseVariableDeclaration(declaration);
	    }
	    ts.isBlockOrCatchScoped = isBlockOrCatchScoped;
	    function isAmbientModule(node) {
	        return node && node.kind === 221 /* ModuleDeclaration */ &&
	            (node.name.kind === 9 /* StringLiteral */ || isGlobalScopeAugmentation(node));
	    }
	    ts.isAmbientModule = isAmbientModule;
	    function isBlockScopedContainerTopLevel(node) {
	        return node.kind === 251 /* SourceFile */ ||
	            node.kind === 221 /* ModuleDeclaration */ ||
	            isFunctionLike(node) ||
	            isFunctionBlock(node);
	    }
	    ts.isBlockScopedContainerTopLevel = isBlockScopedContainerTopLevel;
	    function isGlobalScopeAugmentation(module) {
	        return !!(module.flags & 2097152 /* GlobalAugmentation */);
	    }
	    ts.isGlobalScopeAugmentation = isGlobalScopeAugmentation;
	    function isExternalModuleAugmentation(node) {
	        // external module augmentation is a ambient module declaration that is either:
	        // - defined in the top level scope and source file is an external module
	        // - defined inside ambient module declaration located in the top level scope and source file not an external module
	        if (!node || !isAmbientModule(node)) {
	            return false;
	        }
	        switch (node.parent.kind) {
	            case 251 /* SourceFile */:
	                return isExternalModule(node.parent);
	            case 222 /* ModuleBlock */:
	                return isAmbientModule(node.parent.parent) && !isExternalModule(node.parent.parent.parent);
	        }
	        return false;
	    }
	    ts.isExternalModuleAugmentation = isExternalModuleAugmentation;
	    // Gets the nearest enclosing block scope container that has the provided node
	    // as a descendant, that is not the provided node.
	    function getEnclosingBlockScopeContainer(node) {
	        var current = node.parent;
	        while (current) {
	            if (isFunctionLike(current)) {
	                return current;
	            }
	            switch (current.kind) {
	                case 251 /* SourceFile */:
	                case 223 /* CaseBlock */:
	                case 247 /* CatchClause */:
	                case 221 /* ModuleDeclaration */:
	                case 202 /* ForStatement */:
	                case 203 /* ForInStatement */:
	                case 204 /* ForOfStatement */:
	                    return current;
	                case 195 /* Block */:
	                    // function block is not considered block-scope container
	                    // see comment in binder.ts: bind(...), case for SyntaxKind.Block
	                    if (!isFunctionLike(current.parent)) {
	                        return current;
	                    }
	            }
	            current = current.parent;
	        }
	    }
	    ts.getEnclosingBlockScopeContainer = getEnclosingBlockScopeContainer;
	    function isCatchClauseVariableDeclaration(declaration) {
	        return declaration &&
	            declaration.kind === 214 /* VariableDeclaration */ &&
	            declaration.parent &&
	            declaration.parent.kind === 247 /* CatchClause */;
	    }
	    ts.isCatchClauseVariableDeclaration = isCatchClauseVariableDeclaration;
	    // Return display name of an identifier
	    // Computed property names will just be emitted as "[<expr>]", where <expr> is the source
	    // text of the expression in the computed property.
	    function declarationNameToString(name) {
	        return getFullWidth(name) === 0 ? "(Missing)" : getTextOfNode(name);
	    }
	    ts.declarationNameToString = declarationNameToString;
	    function createDiagnosticForNode(node, message, arg0, arg1, arg2) {
	        var sourceFile = getSourceFileOfNode(node);
	        var span = getErrorSpanForNode(sourceFile, node);
	        return ts.createFileDiagnostic(sourceFile, span.start, span.length, message, arg0, arg1, arg2);
	    }
	    ts.createDiagnosticForNode = createDiagnosticForNode;
	    function createDiagnosticForNodeFromMessageChain(node, messageChain) {
	        var sourceFile = getSourceFileOfNode(node);
	        var span = getErrorSpanForNode(sourceFile, node);
	        return {
	            file: sourceFile,
	            start: span.start,
	            length: span.length,
	            code: messageChain.code,
	            category: messageChain.category,
	            messageText: messageChain.next ? messageChain : messageChain.messageText
	        };
	    }
	    ts.createDiagnosticForNodeFromMessageChain = createDiagnosticForNodeFromMessageChain;
	    function getSpanOfTokenAtPosition(sourceFile, pos) {
	        var scanner = ts.createScanner(sourceFile.languageVersion, /*skipTrivia*/ true, sourceFile.languageVariant, sourceFile.text, /*onError:*/ undefined, pos);
	        scanner.scan();
	        var start = scanner.getTokenPos();
	        return ts.createTextSpanFromBounds(start, scanner.getTextPos());
	    }
	    ts.getSpanOfTokenAtPosition = getSpanOfTokenAtPosition;
	    function getErrorSpanForNode(sourceFile, node) {
	        var errorNode = node;
	        switch (node.kind) {
	            case 251 /* SourceFile */:
	                var pos_1 = ts.skipTrivia(sourceFile.text, 0, /*stopAfterLineBreak*/ false);
	                if (pos_1 === sourceFile.text.length) {
	                    // file is empty - return span for the beginning of the file
	                    return ts.createTextSpan(0, 0);
	                }
	                return getSpanOfTokenAtPosition(sourceFile, pos_1);
	            // This list is a work in progress. Add missing node kinds to improve their error
	            // spans.
	            case 214 /* VariableDeclaration */:
	            case 166 /* BindingElement */:
	            case 217 /* ClassDeclaration */:
	            case 189 /* ClassExpression */:
	            case 218 /* InterfaceDeclaration */:
	            case 221 /* ModuleDeclaration */:
	            case 220 /* EnumDeclaration */:
	            case 250 /* EnumMember */:
	            case 216 /* FunctionDeclaration */:
	            case 176 /* FunctionExpression */:
	            case 144 /* MethodDeclaration */:
	            case 219 /* TypeAliasDeclaration */:
	                errorNode = node.name;
	                break;
	        }
	        if (errorNode === undefined) {
	            // If we don't have a better node, then just set the error on the first token of
	            // construct.
	            return getSpanOfTokenAtPosition(sourceFile, node.pos);
	        }
	        var pos = nodeIsMissing(errorNode)
	            ? errorNode.pos
	            : ts.skipTrivia(sourceFile.text, errorNode.pos);
	        return ts.createTextSpanFromBounds(pos, errorNode.end);
	    }
	    ts.getErrorSpanForNode = getErrorSpanForNode;
	    function isExternalModule(file) {
	        return file.externalModuleIndicator !== undefined;
	    }
	    ts.isExternalModule = isExternalModule;
	    function isExternalOrCommonJsModule(file) {
	        return (file.externalModuleIndicator || file.commonJsModuleIndicator) !== undefined;
	    }
	    ts.isExternalOrCommonJsModule = isExternalOrCommonJsModule;
	    function isDeclarationFile(file) {
	        return (file.flags & 4096 /* DeclarationFile */) !== 0;
	    }
	    ts.isDeclarationFile = isDeclarationFile;
	    function isConstEnumDeclaration(node) {
	        return node.kind === 220 /* EnumDeclaration */ && isConst(node);
	    }
	    ts.isConstEnumDeclaration = isConstEnumDeclaration;
	    function walkUpBindingElementsAndPatterns(node) {
	        while (node && (node.kind === 166 /* BindingElement */ || isBindingPattern(node))) {
	            node = node.parent;
	        }
	        return node;
	    }
	    // Returns the node flags for this node and all relevant parent nodes.  This is done so that
	    // nodes like variable declarations and binding elements can returned a view of their flags
	    // that includes the modifiers from their container.  i.e. flags like export/declare aren't
	    // stored on the variable declaration directly, but on the containing variable statement
	    // (if it has one).  Similarly, flags for let/const are store on the variable declaration
	    // list.  By calling this function, all those flags are combined so that the client can treat
	    // the node as if it actually had those flags.
	    function getCombinedNodeFlags(node) {
	        node = walkUpBindingElementsAndPatterns(node);
	        var flags = node.flags;
	        if (node.kind === 214 /* VariableDeclaration */) {
	            node = node.parent;
	        }
	        if (node && node.kind === 215 /* VariableDeclarationList */) {
	            flags |= node.flags;
	            node = node.parent;
	        }
	        if (node && node.kind === 196 /* VariableStatement */) {
	            flags |= node.flags;
	        }
	        return flags;
	    }
	    ts.getCombinedNodeFlags = getCombinedNodeFlags;
	    function isConst(node) {
	        return !!(getCombinedNodeFlags(node) & 16384 /* Const */);
	    }
	    ts.isConst = isConst;
	    function isLet(node) {
	        return !!(getCombinedNodeFlags(node) & 8192 /* Let */);
	    }
	    ts.isLet = isLet;
	    function isSuperCallExpression(n) {
	        return n.kind === 171 /* CallExpression */ && n.expression.kind === 95 /* SuperKeyword */;
	    }
	    ts.isSuperCallExpression = isSuperCallExpression;
	    function isPrologueDirective(node) {
	        return node.kind === 198 /* ExpressionStatement */ && node.expression.kind === 9 /* StringLiteral */;
	    }
	    ts.isPrologueDirective = isPrologueDirective;
	    function getLeadingCommentRangesOfNode(node, sourceFileOfNode) {
	        return ts.getLeadingCommentRanges(sourceFileOfNode.text, node.pos);
	    }
	    ts.getLeadingCommentRangesOfNode = getLeadingCommentRangesOfNode;
	    function getLeadingCommentRangesOfNodeFromText(node, text) {
	        return ts.getLeadingCommentRanges(text, node.pos);
	    }
	    ts.getLeadingCommentRangesOfNodeFromText = getLeadingCommentRangesOfNodeFromText;
	    function getJsDocComments(node, sourceFileOfNode) {
	        return getJsDocCommentsFromText(node, sourceFileOfNode.text);
	    }
	    ts.getJsDocComments = getJsDocComments;
	    function getJsDocCommentsFromText(node, text) {
	        var commentRanges = (node.kind === 139 /* Parameter */ || node.kind === 138 /* TypeParameter */) ?
	            ts.concatenate(ts.getTrailingCommentRanges(text, node.pos), ts.getLeadingCommentRanges(text, node.pos)) :
	            getLeadingCommentRangesOfNodeFromText(node, text);
	        return ts.filter(commentRanges, isJsDocComment);
	        function isJsDocComment(comment) {
	            // True if the comment starts with '/**' but not if it is '/**/'
	            return text.charCodeAt(comment.pos + 1) === 42 /* asterisk */ &&
	                text.charCodeAt(comment.pos + 2) === 42 /* asterisk */ &&
	                text.charCodeAt(comment.pos + 3) !== 47 /* slash */;
	        }
	    }
	    ts.getJsDocCommentsFromText = getJsDocCommentsFromText;
	    ts.fullTripleSlashReferencePathRegEx = /^(\/\/\/\s*<reference\s+path\s*=\s*)('|")(.+?)\2.*?\/>/;
	    ts.fullTripleSlashAMDReferencePathRegEx = /^(\/\/\/\s*<amd-dependency\s+path\s*=\s*)('|")(.+?)\2.*?\/>/;
	    function isTypeNode(node) {
	        if (151 /* FirstTypeNode */ <= node.kind && node.kind <= 163 /* LastTypeNode */) {
	            return true;
	        }
	        switch (node.kind) {
	            case 117 /* AnyKeyword */:
	            case 128 /* NumberKeyword */:
	            case 130 /* StringKeyword */:
	            case 120 /* BooleanKeyword */:
	            case 131 /* SymbolKeyword */:
	                return true;
	            case 103 /* VoidKeyword */:
	                return node.parent.kind !== 180 /* VoidExpression */;
	            case 191 /* ExpressionWithTypeArguments */:
	                return !isExpressionWithTypeArgumentsInClassExtendsClause(node);
	            // Identifiers and qualified names may be type nodes, depending on their context. Climb
	            // above them to find the lowest container
	            case 69 /* Identifier */:
	                // If the identifier is the RHS of a qualified name, then it's a type iff its parent is.
	                if (node.parent.kind === 136 /* QualifiedName */ && node.parent.right === node) {
	                    node = node.parent;
	                }
	                else if (node.parent.kind === 169 /* PropertyAccessExpression */ && node.parent.name === node) {
	                    node = node.parent;
	                }
	                // At this point, node is either a qualified name or an identifier
	                ts.Debug.assert(node.kind === 69 /* Identifier */ || node.kind === 136 /* QualifiedName */ || node.kind === 169 /* PropertyAccessExpression */, "'node' was expected to be a qualified name, identifier or property access in 'isTypeNode'.");
	            case 136 /* QualifiedName */:
	            case 169 /* PropertyAccessExpression */:
	            case 97 /* ThisKeyword */:
	                var parent_1 = node.parent;
	                if (parent_1.kind === 155 /* TypeQuery */) {
	                    return false;
	                }
	                // Do not recursively call isTypeNode on the parent. In the example:
	                //
	                //     let a: A.B.C;
	                //
	                // Calling isTypeNode would consider the qualified name A.B a type node. Only C or
	                // A.B.C is a type node.
	                if (151 /* FirstTypeNode */ <= parent_1.kind && parent_1.kind <= 163 /* LastTypeNode */) {
	                    return true;
	                }
	                switch (parent_1.kind) {
	                    case 191 /* ExpressionWithTypeArguments */:
	                        return !isExpressionWithTypeArgumentsInClassExtendsClause(parent_1);
	                    case 138 /* TypeParameter */:
	                        return node === parent_1.constraint;
	                    case 142 /* PropertyDeclaration */:
	                    case 141 /* PropertySignature */:
	                    case 139 /* Parameter */:
	                    case 214 /* VariableDeclaration */:
	                        return node === parent_1.type;
	                    case 216 /* FunctionDeclaration */:
	                    case 176 /* FunctionExpression */:
	                    case 177 /* ArrowFunction */:
	                    case 145 /* Constructor */:
	                    case 144 /* MethodDeclaration */:
	                    case 143 /* MethodSignature */:
	                    case 146 /* GetAccessor */:
	                    case 147 /* SetAccessor */:
	                        return node === parent_1.type;
	                    case 148 /* CallSignature */:
	                    case 149 /* ConstructSignature */:
	                    case 150 /* IndexSignature */:
	                        return node === parent_1.type;
	                    case 174 /* TypeAssertionExpression */:
	                        return node === parent_1.type;
	                    case 171 /* CallExpression */:
	                    case 172 /* NewExpression */:
	                        return parent_1.typeArguments && ts.indexOf(parent_1.typeArguments, node) >= 0;
	                    case 173 /* TaggedTemplateExpression */:
	                        // TODO (drosen): TaggedTemplateExpressions may eventually support type arguments.
	                        return false;
	                }
	        }
	        return false;
	    }
	    ts.isTypeNode = isTypeNode;
	    // Warning: This has the same semantics as the forEach family of functions,
	    //          in that traversal terminates in the event that 'visitor' supplies a truthy value.
	    function forEachReturnStatement(body, visitor) {
	        return traverse(body);
	        function traverse(node) {
	            switch (node.kind) {
	                case 207 /* ReturnStatement */:
	                    return visitor(node);
	                case 223 /* CaseBlock */:
	                case 195 /* Block */:
	                case 199 /* IfStatement */:
	                case 200 /* DoStatement */:
	                case 201 /* WhileStatement */:
	                case 202 /* ForStatement */:
	                case 203 /* ForInStatement */:
	                case 204 /* ForOfStatement */:
	                case 208 /* WithStatement */:
	                case 209 /* SwitchStatement */:
	                case 244 /* CaseClause */:
	                case 245 /* DefaultClause */:
	                case 210 /* LabeledStatement */:
	                case 212 /* TryStatement */:
	                case 247 /* CatchClause */:
	                    return ts.forEachChild(node, traverse);
	            }
	        }
	    }
	    ts.forEachReturnStatement = forEachReturnStatement;
	    function forEachYieldExpression(body, visitor) {
	        return traverse(body);
	        function traverse(node) {
	            switch (node.kind) {
	                case 187 /* YieldExpression */:
	                    visitor(node);
	                    var operand = node.expression;
	                    if (operand) {
	                        traverse(operand);
	                    }
	                case 220 /* EnumDeclaration */:
	                case 218 /* InterfaceDeclaration */:
	                case 221 /* ModuleDeclaration */:
	                case 219 /* TypeAliasDeclaration */:
	                case 217 /* ClassDeclaration */:
	                case 189 /* ClassExpression */:
	                    // These are not allowed inside a generator now, but eventually they may be allowed
	                    // as local types. Regardless, any yield statements contained within them should be
	                    // skipped in this traversal.
	                    return;
	                default:
	                    if (isFunctionLike(node)) {
	                        var name_5 = node.name;
	                        if (name_5 && name_5.kind === 137 /* ComputedPropertyName */) {
	                            // Note that we will not include methods/accessors of a class because they would require
	                            // first descending into the class. This is by design.
	                            traverse(name_5.expression);
	                            return;
	                        }
	                    }
	                    else if (!isTypeNode(node)) {
	                        // This is the general case, which should include mostly expressions and statements.
	                        // Also includes NodeArrays.
	                        ts.forEachChild(node, traverse);
	                    }
	            }
	        }
	    }
	    ts.forEachYieldExpression = forEachYieldExpression;
	    function isVariableLike(node) {
	        if (node) {
	            switch (node.kind) {
	                case 166 /* BindingElement */:
	                case 250 /* EnumMember */:
	                case 139 /* Parameter */:
	                case 248 /* PropertyAssignment */:
	                case 142 /* PropertyDeclaration */:
	                case 141 /* PropertySignature */:
	                case 249 /* ShorthandPropertyAssignment */:
	                case 214 /* VariableDeclaration */:
	                    return true;
	            }
	        }
	        return false;
	    }
	    ts.isVariableLike = isVariableLike;
	    function isAccessor(node) {
	        return node && (node.kind === 146 /* GetAccessor */ || node.kind === 147 /* SetAccessor */);
	    }
	    ts.isAccessor = isAccessor;
	    function isClassLike(node) {
	        return node && (node.kind === 217 /* ClassDeclaration */ || node.kind === 189 /* ClassExpression */);
	    }
	    ts.isClassLike = isClassLike;
	    function isFunctionLike(node) {
	        return node && isFunctionLikeKind(node.kind);
	    }
	    ts.isFunctionLike = isFunctionLike;
	    function isFunctionLikeKind(kind) {
	        switch (kind) {
	            case 145 /* Constructor */:
	            case 176 /* FunctionExpression */:
	            case 216 /* FunctionDeclaration */:
	            case 177 /* ArrowFunction */:
	            case 144 /* MethodDeclaration */:
	            case 143 /* MethodSignature */:
	            case 146 /* GetAccessor */:
	            case 147 /* SetAccessor */:
	            case 148 /* CallSignature */:
	            case 149 /* ConstructSignature */:
	            case 150 /* IndexSignature */:
	            case 153 /* FunctionType */:
	            case 154 /* ConstructorType */:
	                return true;
	        }
	    }
	    ts.isFunctionLikeKind = isFunctionLikeKind;
	    function introducesArgumentsExoticObject(node) {
	        switch (node.kind) {
	            case 144 /* MethodDeclaration */:
	            case 143 /* MethodSignature */:
	            case 145 /* Constructor */:
	            case 146 /* GetAccessor */:
	            case 147 /* SetAccessor */:
	            case 216 /* FunctionDeclaration */:
	            case 176 /* FunctionExpression */:
	                return true;
	        }
	        return false;
	    }
	    ts.introducesArgumentsExoticObject = introducesArgumentsExoticObject;
	    function isIterationStatement(node, lookInLabeledStatements) {
	        switch (node.kind) {
	            case 202 /* ForStatement */:
	            case 203 /* ForInStatement */:
	            case 204 /* ForOfStatement */:
	            case 200 /* DoStatement */:
	            case 201 /* WhileStatement */:
	                return true;
	            case 210 /* LabeledStatement */:
	                return lookInLabeledStatements && isIterationStatement(node.statement, lookInLabeledStatements);
	        }
	        return false;
	    }
	    ts.isIterationStatement = isIterationStatement;
	    function isFunctionBlock(node) {
	        return node && node.kind === 195 /* Block */ && isFunctionLike(node.parent);
	    }
	    ts.isFunctionBlock = isFunctionBlock;
	    function isObjectLiteralMethod(node) {
	        return node && node.kind === 144 /* MethodDeclaration */ && node.parent.kind === 168 /* ObjectLiteralExpression */;
	    }
	    ts.isObjectLiteralMethod = isObjectLiteralMethod;
	    function isIdentifierTypePredicate(predicate) {
	        return predicate && predicate.kind === 1 /* Identifier */;
	    }
	    ts.isIdentifierTypePredicate = isIdentifierTypePredicate;
	    function isThisTypePredicate(predicate) {
	        return predicate && predicate.kind === 0 /* This */;
	    }
	    ts.isThisTypePredicate = isThisTypePredicate;
	    function getContainingFunction(node) {
	        while (true) {
	            node = node.parent;
	            if (!node || isFunctionLike(node)) {
	                return node;
	            }
	        }
	    }
	    ts.getContainingFunction = getContainingFunction;
	    function getContainingClass(node) {
	        while (true) {
	            node = node.parent;
	            if (!node || isClassLike(node)) {
	                return node;
	            }
	        }
	    }
	    ts.getContainingClass = getContainingClass;
	    function getThisContainer(node, includeArrowFunctions) {
	        while (true) {
	            node = node.parent;
	            if (!node) {
	                return undefined;
	            }
	            switch (node.kind) {
	                case 137 /* ComputedPropertyName */:
	                    // If the grandparent node is an object literal (as opposed to a class),
	                    // then the computed property is not a 'this' container.
	                    // A computed property name in a class needs to be a this container
	                    // so that we can error on it.
	                    if (isClassLike(node.parent.parent)) {
	                        return node;
	                    }
	                    // If this is a computed property, then the parent should not
	                    // make it a this container. The parent might be a property
	                    // in an object literal, like a method or accessor. But in order for
	                    // such a parent to be a this container, the reference must be in
	                    // the *body* of the container.
	                    node = node.parent;
	                    break;
	                case 140 /* Decorator */:
	                    // Decorators are always applied outside of the body of a class or method.
	                    if (node.parent.kind === 139 /* Parameter */ && isClassElement(node.parent.parent)) {
	                        // If the decorator's parent is a Parameter, we resolve the this container from
	                        // the grandparent class declaration.
	                        node = node.parent.parent;
	                    }
	                    else if (isClassElement(node.parent)) {
	                        // If the decorator's parent is a class element, we resolve the 'this' container
	                        // from the parent class declaration.
	                        node = node.parent;
	                    }
	                    break;
	                case 177 /* ArrowFunction */:
	                    if (!includeArrowFunctions) {
	                        continue;
	                    }
	                // Fall through
	                case 216 /* FunctionDeclaration */:
	                case 176 /* FunctionExpression */:
	                case 221 /* ModuleDeclaration */:
	                case 142 /* PropertyDeclaration */:
	                case 141 /* PropertySignature */:
	                case 144 /* MethodDeclaration */:
	                case 143 /* MethodSignature */:
	                case 145 /* Constructor */:
	                case 146 /* GetAccessor */:
	                case 147 /* SetAccessor */:
	                case 148 /* CallSignature */:
	                case 149 /* ConstructSignature */:
	                case 150 /* IndexSignature */:
	                case 220 /* EnumDeclaration */:
	                case 251 /* SourceFile */:
	                    return node;
	            }
	        }
	    }
	    ts.getThisContainer = getThisContainer;
	    /**
	      * Given an super call\property node returns a closest node where either
	      * - super call\property is legal in the node and not legal in the parent node the node.
	      *   i.e. super call is legal in constructor but not legal in the class body.
	      * - node is arrow function (so caller might need to call getSuperContainer in case it needs to climb higher)
	      * - super call\property is definitely illegal in the node (but might be legal in some subnode)
	      *   i.e. super property access is illegal in function declaration but can be legal in the statement list
	      */
	    function getSuperContainer(node, stopOnFunctions) {
	        while (true) {
	            node = node.parent;
	            if (!node) {
	                return node;
	            }
	            switch (node.kind) {
	                case 137 /* ComputedPropertyName */:
	                    node = node.parent;
	                    break;
	                case 216 /* FunctionDeclaration */:
	                case 176 /* FunctionExpression */:
	                case 177 /* ArrowFunction */:
	                    if (!stopOnFunctions) {
	                        continue;
	                    }
	                case 142 /* PropertyDeclaration */:
	                case 141 /* PropertySignature */:
	                case 144 /* MethodDeclaration */:
	                case 143 /* MethodSignature */:
	                case 145 /* Constructor */:
	                case 146 /* GetAccessor */:
	                case 147 /* SetAccessor */:
	                    return node;
	                case 140 /* Decorator */:
	                    // Decorators are always applied outside of the body of a class or method.
	                    if (node.parent.kind === 139 /* Parameter */ && isClassElement(node.parent.parent)) {
	                        // If the decorator's parent is a Parameter, we resolve the this container from
	                        // the grandparent class declaration.
	                        node = node.parent.parent;
	                    }
	                    else if (isClassElement(node.parent)) {
	                        // If the decorator's parent is a class element, we resolve the 'this' container
	                        // from the parent class declaration.
	                        node = node.parent;
	                    }
	                    break;
	            }
	        }
	    }
	    ts.getSuperContainer = getSuperContainer;
	    /**
	     * Determines whether a node is a property or element access expression for super.
	     */
	    function isSuperPropertyOrElementAccess(node) {
	        return (node.kind === 169 /* PropertyAccessExpression */
	            || node.kind === 170 /* ElementAccessExpression */)
	            && node.expression.kind === 95 /* SuperKeyword */;
	    }
	    ts.isSuperPropertyOrElementAccess = isSuperPropertyOrElementAccess;
	    function getEntityNameFromTypeNode(node) {
	        if (node) {
	            switch (node.kind) {
	                case 152 /* TypeReference */:
	                    return node.typeName;
	                case 191 /* ExpressionWithTypeArguments */:
	                    return node.expression;
	                case 69 /* Identifier */:
	                case 136 /* QualifiedName */:
	                    return node;
	            }
	        }
	        return undefined;
	    }
	    ts.getEntityNameFromTypeNode = getEntityNameFromTypeNode;
	    function getInvokedExpression(node) {
	        if (node.kind === 173 /* TaggedTemplateExpression */) {
	            return node.tag;
	        }
	        // Will either be a CallExpression, NewExpression, or Decorator.
	        return node.expression;
	    }
	    ts.getInvokedExpression = getInvokedExpression;
	    function nodeCanBeDecorated(node) {
	        switch (node.kind) {
	            case 217 /* ClassDeclaration */:
	                // classes are valid targets
	                return true;
	            case 142 /* PropertyDeclaration */:
	                // property declarations are valid if their parent is a class declaration.
	                return node.parent.kind === 217 /* ClassDeclaration */;
	            case 146 /* GetAccessor */:
	            case 147 /* SetAccessor */:
	            case 144 /* MethodDeclaration */:
	                // if this method has a body and its parent is a class declaration, this is a valid target.
	                return node.body !== undefined
	                    && node.parent.kind === 217 /* ClassDeclaration */;
	            case 139 /* Parameter */:
	                // if the parameter's parent has a body and its grandparent is a class declaration, this is a valid target;
	                return node.parent.body !== undefined
	                    && (node.parent.kind === 145 /* Constructor */
	                        || node.parent.kind === 144 /* MethodDeclaration */
	                        || node.parent.kind === 147 /* SetAccessor */)
	                    && node.parent.parent.kind === 217 /* ClassDeclaration */;
	        }
	        return false;
	    }
	    ts.nodeCanBeDecorated = nodeCanBeDecorated;
	    function nodeIsDecorated(node) {
	        return node.decorators !== undefined
	            && nodeCanBeDecorated(node);
	    }
	    ts.nodeIsDecorated = nodeIsDecorated;
	    function isPropertyAccessExpression(node) {
	        return node.kind === 169 /* PropertyAccessExpression */;
	    }
	    ts.isPropertyAccessExpression = isPropertyAccessExpression;
	    function isElementAccessExpression(node) {
	        return node.kind === 170 /* ElementAccessExpression */;
	    }
	    ts.isElementAccessExpression = isElementAccessExpression;
	    function isExpression(node) {
	        switch (node.kind) {
	            case 95 /* SuperKeyword */:
	            case 93 /* NullKeyword */:
	            case 99 /* TrueKeyword */:
	            case 84 /* FalseKeyword */:
	            case 10 /* RegularExpressionLiteral */:
	            case 167 /* ArrayLiteralExpression */:
	            case 168 /* ObjectLiteralExpression */:
	            case 169 /* PropertyAccessExpression */:
	            case 170 /* ElementAccessExpression */:
	            case 171 /* CallExpression */:
	            case 172 /* NewExpression */:
	            case 173 /* TaggedTemplateExpression */:
	            case 192 /* AsExpression */:
	            case 174 /* TypeAssertionExpression */:
	            case 175 /* ParenthesizedExpression */:
	            case 176 /* FunctionExpression */:
	            case 189 /* ClassExpression */:
	            case 177 /* ArrowFunction */:
	            case 180 /* VoidExpression */:
	            case 178 /* DeleteExpression */:
	            case 179 /* TypeOfExpression */:
	            case 182 /* PrefixUnaryExpression */:
	            case 183 /* PostfixUnaryExpression */:
	            case 184 /* BinaryExpression */:
	            case 185 /* ConditionalExpression */:
	            case 188 /* SpreadElementExpression */:
	            case 186 /* TemplateExpression */:
	            case 11 /* NoSubstitutionTemplateLiteral */:
	            case 190 /* OmittedExpression */:
	            case 236 /* JsxElement */:
	            case 237 /* JsxSelfClosingElement */:
	            case 187 /* YieldExpression */:
	            case 181 /* AwaitExpression */:
	                return true;
	            case 136 /* QualifiedName */:
	                while (node.parent.kind === 136 /* QualifiedName */) {
	                    node = node.parent;
	                }
	                return node.parent.kind === 155 /* TypeQuery */;
	            case 69 /* Identifier */:
	                if (node.parent.kind === 155 /* TypeQuery */) {
	                    return true;
	                }
	            // fall through
	            case 8 /* NumericLiteral */:
	            case 9 /* StringLiteral */:
	            case 97 /* ThisKeyword */:
	                var parent_2 = node.parent;
	                switch (parent_2.kind) {
	                    case 214 /* VariableDeclaration */:
	                    case 139 /* Parameter */:
	                    case 142 /* PropertyDeclaration */:
	                    case 141 /* PropertySignature */:
	                    case 250 /* EnumMember */:
	                    case 248 /* PropertyAssignment */:
	                    case 166 /* BindingElement */:
	                        return parent_2.initializer === node;
	                    case 198 /* ExpressionStatement */:
	                    case 199 /* IfStatement */:
	                    case 200 /* DoStatement */:
	                    case 201 /* WhileStatement */:
	                    case 207 /* ReturnStatement */:
	                    case 208 /* WithStatement */:
	                    case 209 /* SwitchStatement */:
	                    case 244 /* CaseClause */:
	                    case 211 /* ThrowStatement */:
	                    case 209 /* SwitchStatement */:
	                        return parent_2.expression === node;
	                    case 202 /* ForStatement */:
	                        var forStatement = parent_2;
	                        return (forStatement.initializer === node && forStatement.initializer.kind !== 215 /* VariableDeclarationList */) ||
	                            forStatement.condition === node ||
	                            forStatement.incrementor === node;
	                    case 203 /* ForInStatement */:
	                    case 204 /* ForOfStatement */:
	                        var forInStatement = parent_2;
	                        return (forInStatement.initializer === node && forInStatement.initializer.kind !== 215 /* VariableDeclarationList */) ||
	                            forInStatement.expression === node;
	                    case 174 /* TypeAssertionExpression */:
	                    case 192 /* AsExpression */:
	                        return node === parent_2.expression;
	                    case 193 /* TemplateSpan */:
	                        return node === parent_2.expression;
	                    case 137 /* ComputedPropertyName */:
	                        return node === parent_2.expression;
	                    case 140 /* Decorator */:
	                    case 243 /* JsxExpression */:
	                    case 242 /* JsxSpreadAttribute */:
	                        return true;
	                    case 191 /* ExpressionWithTypeArguments */:
	                        return parent_2.expression === node && isExpressionWithTypeArgumentsInClassExtendsClause(parent_2);
	                    default:
	                        if (isExpression(parent_2)) {
	                            return true;
	                        }
	                }
	        }
	        return false;
	    }
	    ts.isExpression = isExpression;
	    function isExternalModuleNameRelative(moduleName) {
	        // TypeScript 1.0 spec (April 2014): 11.2.1
	        // An external module name is "relative" if the first term is "." or "..".
	        return moduleName.substr(0, 2) === "./" || moduleName.substr(0, 3) === "../" || moduleName.substr(0, 2) === ".\\" || moduleName.substr(0, 3) === "..\\";
	    }
	    ts.isExternalModuleNameRelative = isExternalModuleNameRelative;
	    function isInstantiatedModule(node, preserveConstEnums) {
	        var moduleState = ts.getModuleInstanceState(node);
	        return moduleState === 1 /* Instantiated */ ||
	            (preserveConstEnums && moduleState === 2 /* ConstEnumOnly */);
	    }
	    ts.isInstantiatedModule = isInstantiatedModule;
	    function isExternalModuleImportEqualsDeclaration(node) {
	        return node.kind === 224 /* ImportEqualsDeclaration */ && node.moduleReference.kind === 235 /* ExternalModuleReference */;
	    }
	    ts.isExternalModuleImportEqualsDeclaration = isExternalModuleImportEqualsDeclaration;
	    function getExternalModuleImportEqualsDeclarationExpression(node) {
	        ts.Debug.assert(isExternalModuleImportEqualsDeclaration(node));
	        return node.moduleReference.expression;
	    }
	    ts.getExternalModuleImportEqualsDeclarationExpression = getExternalModuleImportEqualsDeclarationExpression;
	    function isInternalModuleImportEqualsDeclaration(node) {
	        return node.kind === 224 /* ImportEqualsDeclaration */ && node.moduleReference.kind !== 235 /* ExternalModuleReference */;
	    }
	    ts.isInternalModuleImportEqualsDeclaration = isInternalModuleImportEqualsDeclaration;
	    function isSourceFileJavaScript(file) {
	        return isInJavaScriptFile(file);
	    }
	    ts.isSourceFileJavaScript = isSourceFileJavaScript;
	    function isInJavaScriptFile(node) {
	        return node && !!(node.parserContextFlags & 32 /* JavaScriptFile */);
	    }
	    ts.isInJavaScriptFile = isInJavaScriptFile;
	    /**
	     * Returns true if the node is a CallExpression to the identifier 'require' with
	     * exactly one argument.
	     * This function does not test if the node is in a JavaScript file or not.
	    */
	    function isRequireCall(expression, checkArgumentIsStringLiteral) {
	        // of the form 'require("name")'
	        var isRequire = expression.kind === 171 /* CallExpression */ &&
	            expression.expression.kind === 69 /* Identifier */ &&
	            expression.expression.text === "require" &&
	            expression.arguments.length === 1;
	        return isRequire && (!checkArgumentIsStringLiteral || expression.arguments[0].kind === 9 /* StringLiteral */);
	    }
	    ts.isRequireCall = isRequireCall;
	    /// Given a BinaryExpression, returns SpecialPropertyAssignmentKind for the various kinds of property
	    /// assignments we treat as special in the binder
	    function getSpecialPropertyAssignmentKind(expression) {
	        if (expression.kind !== 184 /* BinaryExpression */) {
	            return 0 /* None */;
	        }
	        var expr = expression;
	        if (expr.operatorToken.kind !== 56 /* EqualsToken */ || expr.left.kind !== 169 /* PropertyAccessExpression */) {
	            return 0 /* None */;
	        }
	        var lhs = expr.left;
	        if (lhs.expression.kind === 69 /* Identifier */) {
	            var lhsId = lhs.expression;
	            if (lhsId.text === "exports") {
	                // exports.name = expr
	                return 1 /* ExportsProperty */;
	            }
	            else if (lhsId.text === "module" && lhs.name.text === "exports") {
	                // module.exports = expr
	                return 2 /* ModuleExports */;
	            }
	        }
	        else if (lhs.expression.kind === 97 /* ThisKeyword */) {
	            return 4 /* ThisProperty */;
	        }
	        else if (lhs.expression.kind === 169 /* PropertyAccessExpression */) {
	            // chained dot, e.g. x.y.z = expr; this var is the 'x.y' part
	            var innerPropertyAccess = lhs.expression;
	            if (innerPropertyAccess.expression.kind === 69 /* Identifier */ && innerPropertyAccess.name.text === "prototype") {
	                return 3 /* PrototypeProperty */;
	            }
	        }
	        return 0 /* None */;
	    }
	    ts.getSpecialPropertyAssignmentKind = getSpecialPropertyAssignmentKind;
	    function getExternalModuleName(node) {
	        if (node.kind === 225 /* ImportDeclaration */) {
	            return node.moduleSpecifier;
	        }
	        if (node.kind === 224 /* ImportEqualsDeclaration */) {
	            var reference = node.moduleReference;
	            if (reference.kind === 235 /* ExternalModuleReference */) {
	                return reference.expression;
	            }
	        }
	        if (node.kind === 231 /* ExportDeclaration */) {
	            return node.moduleSpecifier;
	        }
	        if (node.kind === 221 /* ModuleDeclaration */ && node.name.kind === 9 /* StringLiteral */) {
	            return node.name;
	        }
	    }
	    ts.getExternalModuleName = getExternalModuleName;
	    function hasQuestionToken(node) {
	        if (node) {
	            switch (node.kind) {
	                case 139 /* Parameter */:
	                case 144 /* MethodDeclaration */:
	                case 143 /* MethodSignature */:
	                case 249 /* ShorthandPropertyAssignment */:
	                case 248 /* PropertyAssignment */:
	                case 142 /* PropertyDeclaration */:
	                case 141 /* PropertySignature */:
	                    return node.questionToken !== undefined;
	            }
	        }
	        return false;
	    }
	    ts.hasQuestionToken = hasQuestionToken;
	    function isJSDocConstructSignature(node) {
	        return node.kind === 264 /* JSDocFunctionType */ &&
	            node.parameters.length > 0 &&
	            node.parameters[0].type.kind === 266 /* JSDocConstructorType */;
	    }
	    ts.isJSDocConstructSignature = isJSDocConstructSignature;
	    function getJSDocTag(node, kind, checkParentVariableStatement) {
	        if (!node) {
	            return undefined;
	        }
	        var jsDocComment = getJSDocComment(node, checkParentVariableStatement);
	        if (!jsDocComment) {
	            return undefined;
	        }
	        for (var _i = 0, _a = jsDocComment.tags; _i < _a.length; _i++) {
	            var tag = _a[_i];
	            if (tag.kind === kind) {
	                return tag;
	            }
	        }
	    }
	    function getJSDocComment(node, checkParentVariableStatement) {
	        if (node.jsDocComment) {
	            return node.jsDocComment;
	        }
	        // Try to recognize this pattern when node is initializer of variable declaration and JSDoc comments are on containing variable statement. 
	        // /** 
	        //   * @param {number} name
	        //   * @returns {number} 
	        //   */
	        // var x = function(name) { return name.length; }
	        if (checkParentVariableStatement) {
	            var isInitializerOfVariableDeclarationInStatement = node.parent.kind === 214 /* VariableDeclaration */ &&
	                node.parent.initializer === node &&
	                node.parent.parent.parent.kind === 196 /* VariableStatement */;
	            var variableStatementNode = isInitializerOfVariableDeclarationInStatement ? node.parent.parent.parent : undefined;
	            if (variableStatementNode) {
	                return variableStatementNode.jsDocComment;
	            }
	            // Also recognize when the node is the RHS of an assignment expression
	            var parent_3 = node.parent;
	            var isSourceOfAssignmentExpressionStatement = parent_3 && parent_3.parent &&
	                parent_3.kind === 184 /* BinaryExpression */ &&
	                parent_3.operatorToken.kind === 56 /* EqualsToken */ &&
	                parent_3.parent.kind === 198 /* ExpressionStatement */;
	            if (isSourceOfAssignmentExpressionStatement) {
	                return parent_3.parent.jsDocComment;
	            }
	            var isPropertyAssignmentExpression = parent_3 && parent_3.kind === 248 /* PropertyAssignment */;
	            if (isPropertyAssignmentExpression) {
	                return parent_3.jsDocComment;
	            }
	        }
	        return undefined;
	    }
	    function getJSDocTypeTag(node) {
	        return getJSDocTag(node, 272 /* JSDocTypeTag */, /*checkParentVariableStatement*/ false);
	    }
	    ts.getJSDocTypeTag = getJSDocTypeTag;
	    function getJSDocReturnTag(node) {
	        return getJSDocTag(node, 271 /* JSDocReturnTag */, /*checkParentVariableStatement*/ true);
	    }
	    ts.getJSDocReturnTag = getJSDocReturnTag;
	    function getJSDocTemplateTag(node) {
	        return getJSDocTag(node, 273 /* JSDocTemplateTag */, /*checkParentVariableStatement*/ false);
	    }
	    ts.getJSDocTemplateTag = getJSDocTemplateTag;
	    function getCorrespondingJSDocParameterTag(parameter) {
	        if (parameter.name && parameter.name.kind === 69 /* Identifier */) {
	            // If it's a parameter, see if the parent has a jsdoc comment with an @param
	            // annotation.
	            var parameterName = parameter.name.text;
	            var jsDocComment = getJSDocComment(parameter.parent, /*checkParentVariableStatement*/ true);
	            if (jsDocComment) {
	                for (var _i = 0, _a = jsDocComment.tags; _i < _a.length; _i++) {
	                    var tag = _a[_i];
	                    if (tag.kind === 270 /* JSDocParameterTag */) {
	                        var parameterTag = tag;
	                        var name_6 = parameterTag.preParameterName || parameterTag.postParameterName;
	                        if (name_6.text === parameterName) {
	                            return parameterTag;
	                        }
	                    }
	                }
	            }
	        }
	        return undefined;
	    }
	    ts.getCorrespondingJSDocParameterTag = getCorrespondingJSDocParameterTag;
	    function hasRestParameter(s) {
	        return isRestParameter(ts.lastOrUndefined(s.parameters));
	    }
	    ts.hasRestParameter = hasRestParameter;
	    function isRestParameter(node) {
	        if (node) {
	            if (node.parserContextFlags & 32 /* JavaScriptFile */) {
	                if (node.type && node.type.kind === 265 /* JSDocVariadicType */) {
	                    return true;
	                }
	                var paramTag = getCorrespondingJSDocParameterTag(node);
	                if (paramTag && paramTag.typeExpression) {
	                    return paramTag.typeExpression.type.kind === 265 /* JSDocVariadicType */;
	                }
	            }
	            return node.dotDotDotToken !== undefined;
	        }
	        return false;
	    }
	    ts.isRestParameter = isRestParameter;
	    function isLiteralKind(kind) {
	        return 8 /* FirstLiteralToken */ <= kind && kind <= 11 /* LastLiteralToken */;
	    }
	    ts.isLiteralKind = isLiteralKind;
	    function isTextualLiteralKind(kind) {
	        return kind === 9 /* StringLiteral */ || kind === 11 /* NoSubstitutionTemplateLiteral */;
	    }
	    ts.isTextualLiteralKind = isTextualLiteralKind;
	    function isTemplateLiteralKind(kind) {
	        return 11 /* FirstTemplateToken */ <= kind && kind <= 14 /* LastTemplateToken */;
	    }
	    ts.isTemplateLiteralKind = isTemplateLiteralKind;
	    function isBindingPattern(node) {
	        return !!node && (node.kind === 165 /* ArrayBindingPattern */ || node.kind === 164 /* ObjectBindingPattern */);
	    }
	    ts.isBindingPattern = isBindingPattern;
	    function isNodeDescendentOf(node, ancestor) {
	        while (node) {
	            if (node === ancestor)
	                return true;
	            node = node.parent;
	        }
	        return false;
	    }
	    ts.isNodeDescendentOf = isNodeDescendentOf;
	    function isInAmbientContext(node) {
	        while (node) {
	            if (node.flags & (4 /* Ambient */ | 4096 /* DeclarationFile */)) {
	                return true;
	            }
	            node = node.parent;
	        }
	        return false;
	    }
	    ts.isInAmbientContext = isInAmbientContext;
	    function isDeclaration(node) {
	        switch (node.kind) {
	            case 177 /* ArrowFunction */:
	            case 166 /* BindingElement */:
	            case 217 /* ClassDeclaration */:
	            case 189 /* ClassExpression */:
	            case 145 /* Constructor */:
	            case 220 /* EnumDeclaration */:
	            case 250 /* EnumMember */:
	            case 233 /* ExportSpecifier */:
	            case 216 /* FunctionDeclaration */:
	            case 176 /* FunctionExpression */:
	            case 146 /* GetAccessor */:
	            case 226 /* ImportClause */:
	            case 224 /* ImportEqualsDeclaration */:
	            case 229 /* ImportSpecifier */:
	            case 218 /* InterfaceDeclaration */:
	            case 144 /* MethodDeclaration */:
	            case 143 /* MethodSignature */:
	            case 221 /* ModuleDeclaration */:
	            case 227 /* NamespaceImport */:
	            case 139 /* Parameter */:
	            case 248 /* PropertyAssignment */:
	            case 142 /* PropertyDeclaration */:
	            case 141 /* PropertySignature */:
	            case 147 /* SetAccessor */:
	            case 249 /* ShorthandPropertyAssignment */:
	            case 219 /* TypeAliasDeclaration */:
	            case 138 /* TypeParameter */:
	            case 214 /* VariableDeclaration */:
	                return true;
	        }
	        return false;
	    }
	    ts.isDeclaration = isDeclaration;
	    function isStatement(n) {
	        switch (n.kind) {
	            case 206 /* BreakStatement */:
	            case 205 /* ContinueStatement */:
	            case 213 /* DebuggerStatement */:
	            case 200 /* DoStatement */:
	            case 198 /* ExpressionStatement */:
	            case 197 /* EmptyStatement */:
	            case 203 /* ForInStatement */:
	            case 204 /* ForOfStatement */:
	            case 202 /* ForStatement */:
	            case 199 /* IfStatement */:
	            case 210 /* LabeledStatement */:
	            case 207 /* ReturnStatement */:
	            case 209 /* SwitchStatement */:
	            case 211 /* ThrowStatement */:
	            case 212 /* TryStatement */:
	            case 196 /* VariableStatement */:
	            case 201 /* WhileStatement */:
	            case 208 /* WithStatement */:
	            case 230 /* ExportAssignment */:
	                return true;
	            default:
	                return false;
	        }
	    }
	    ts.isStatement = isStatement;
	    function isClassElement(n) {
	        switch (n.kind) {
	            case 145 /* Constructor */:
	            case 142 /* PropertyDeclaration */:
	            case 144 /* MethodDeclaration */:
	            case 146 /* GetAccessor */:
	            case 147 /* SetAccessor */:
	            case 143 /* MethodSignature */:
	            case 150 /* IndexSignature */:
	                return true;
	            default:
	                return false;
	        }
	    }
	    ts.isClassElement = isClassElement;
	    // True if the given identifier, string literal, or number literal is the name of a declaration node
	    function isDeclarationName(name) {
	        if (name.kind !== 69 /* Identifier */ && name.kind !== 9 /* StringLiteral */ && name.kind !== 8 /* NumericLiteral */) {
	            return false;
	        }
	        var parent = name.parent;
	        if (parent.kind === 229 /* ImportSpecifier */ || parent.kind === 233 /* ExportSpecifier */) {
	            if (parent.propertyName) {
	                return true;
	            }
	        }
	        if (isDeclaration(parent)) {
	            return parent.name === name;
	        }
	        return false;
	    }
	    ts.isDeclarationName = isDeclarationName;
	    // Return true if the given identifier is classified as an IdentifierName
	    function isIdentifierName(node) {
	        var parent = node.parent;
	        switch (parent.kind) {
	            case 142 /* PropertyDeclaration */:
	            case 141 /* PropertySignature */:
	            case 144 /* MethodDeclaration */:
	            case 143 /* MethodSignature */:
	            case 146 /* GetAccessor */:
	            case 147 /* SetAccessor */:
	            case 250 /* EnumMember */:
	            case 248 /* PropertyAssignment */:
	            case 169 /* PropertyAccessExpression */:
	                // Name in member declaration or property name in property access
	                return parent.name === node;
	            case 136 /* QualifiedName */:
	                // Name on right hand side of dot in a type query
	                if (parent.right === node) {
	                    while (parent.kind === 136 /* QualifiedName */) {
	                        parent = parent.parent;
	                    }
	                    return parent.kind === 155 /* TypeQuery */;
	                }
	                return false;
	            case 166 /* BindingElement */:
	            case 229 /* ImportSpecifier */:
	                // Property name in binding element or import specifier
	                return parent.propertyName === node;
	            case 233 /* ExportSpecifier */:
	                // Any name in an export specifier
	                return true;
	        }
	        return false;
	    }
	    ts.isIdentifierName = isIdentifierName;
	    // An alias symbol is created by one of the following declarations:
	    // import <symbol> = ...
	    // import <symbol> from ...
	    // import * as <symbol> from ...
	    // import { x as <symbol> } from ...
	    // export { x as <symbol> } from ...
	    // export = ...
	    // export default ...
	    function isAliasSymbolDeclaration(node) {
	        return node.kind === 224 /* ImportEqualsDeclaration */ ||
	            node.kind === 226 /* ImportClause */ && !!node.name ||
	            node.kind === 227 /* NamespaceImport */ ||
	            node.kind === 229 /* ImportSpecifier */ ||
	            node.kind === 233 /* ExportSpecifier */ ||
	            node.kind === 230 /* ExportAssignment */ && node.expression.kind === 69 /* Identifier */;
	    }
	    ts.isAliasSymbolDeclaration = isAliasSymbolDeclaration;
	    function getClassExtendsHeritageClauseElement(node) {
	        var heritageClause = getHeritageClause(node.heritageClauses, 83 /* ExtendsKeyword */);
	        return heritageClause && heritageClause.types.length > 0 ? heritageClause.types[0] : undefined;
	    }
	    ts.getClassExtendsHeritageClauseElement = getClassExtendsHeritageClauseElement;
	    function getClassImplementsHeritageClauseElements(node) {
	        var heritageClause = getHeritageClause(node.heritageClauses, 106 /* ImplementsKeyword */);
	        return heritageClause ? heritageClause.types : undefined;
	    }
	    ts.getClassImplementsHeritageClauseElements = getClassImplementsHeritageClauseElements;
	    function getInterfaceBaseTypeNodes(node) {
	        var heritageClause = getHeritageClause(node.heritageClauses, 83 /* ExtendsKeyword */);
	        return heritageClause ? heritageClause.types : undefined;
	    }
	    ts.getInterfaceBaseTypeNodes = getInterfaceBaseTypeNodes;
	    function getHeritageClause(clauses, kind) {
	        if (clauses) {
	            for (var _i = 0, clauses_1 = clauses; _i < clauses_1.length; _i++) {
	                var clause = clauses_1[_i];
	                if (clause.token === kind) {
	                    return clause;
	                }
	            }
	        }
	        return undefined;
	    }
	    ts.getHeritageClause = getHeritageClause;
	    function tryResolveScriptReference(host, sourceFile, reference) {
	        if (!host.getCompilerOptions().noResolve) {
	            var referenceFileName = ts.isRootedDiskPath(reference.fileName) ? reference.fileName : ts.combinePaths(ts.getDirectoryPath(sourceFile.fileName), reference.fileName);
	            return host.getSourceFile(referenceFileName);
	        }
	    }
	    ts.tryResolveScriptReference = tryResolveScriptReference;
	    function getAncestor(node, kind) {
	        while (node) {
	            if (node.kind === kind) {
	                return node;
	            }
	            node = node.parent;
	        }
	        return undefined;
	    }
	    ts.getAncestor = getAncestor;
	    function getFileReferenceFromReferencePath(comment, commentRange) {
	        var simpleReferenceRegEx = /^\/\/\/\s*<reference\s+/gim;
	        var isNoDefaultLibRegEx = /^(\/\/\/\s*<reference\s+no-default-lib\s*=\s*)('|")(.+?)\2\s*\/>/gim;
	        if (simpleReferenceRegEx.test(comment)) {
	            if (isNoDefaultLibRegEx.test(comment)) {
	                return {
	                    isNoDefaultLib: true
	                };
	            }
	            else {
	                var matchResult = ts.fullTripleSlashReferencePathRegEx.exec(comment);
	                if (matchResult) {
	                    var start = commentRange.pos;
	                    var end = commentRange.end;
	                    return {
	                        fileReference: {
	                            pos: start,
	                            end: end,
	                            fileName: matchResult[3]
	                        },
	                        isNoDefaultLib: false
	                    };
	                }
	                else {
	                    return {
	                        diagnosticMessage: ts.Diagnostics.Invalid_reference_directive_syntax,
	                        isNoDefaultLib: false
	                    };
	                }
	            }
	        }
	        return undefined;
	    }
	    ts.getFileReferenceFromReferencePath = getFileReferenceFromReferencePath;
	    function isKeyword(token) {
	        return 70 /* FirstKeyword */ <= token && token <= 135 /* LastKeyword */;
	    }
	    ts.isKeyword = isKeyword;
	    function isTrivia(token) {
	        return 2 /* FirstTriviaToken */ <= token && token <= 7 /* LastTriviaToken */;
	    }
	    ts.isTrivia = isTrivia;
	    function isAsyncFunctionLike(node) {
	        return isFunctionLike(node) && (node.flags & 256 /* Async */) !== 0 && !isAccessor(node);
	    }
	    ts.isAsyncFunctionLike = isAsyncFunctionLike;
	    function isStringOrNumericLiteral(kind) {
	        return kind === 9 /* StringLiteral */ || kind === 8 /* NumericLiteral */;
	    }
	    ts.isStringOrNumericLiteral = isStringOrNumericLiteral;
	    /**
	     * A declaration has a dynamic name if both of the following are true:
	     *   1. The declaration has a computed property name
	     *   2. The computed name is *not* expressed as Symbol.<name>, where name
	     *      is a property of the Symbol constructor that denotes a built in
	     *      Symbol.
	     */
	    function hasDynamicName(declaration) {
	        return declaration.name && isDynamicName(declaration.name);
	    }
	    ts.hasDynamicName = hasDynamicName;
	    function isDynamicName(name) {
	        return name.kind === 137 /* ComputedPropertyName */ &&
	            !isStringOrNumericLiteral(name.expression.kind) &&
	            !isWellKnownSymbolSyntactically(name.expression);
	    }
	    ts.isDynamicName = isDynamicName;
	    /**
	     * Checks if the expression is of the form:
	     *    Symbol.name
	     * where Symbol is literally the word "Symbol", and name is any identifierName
	     */
	    function isWellKnownSymbolSyntactically(node) {
	        return isPropertyAccessExpression(node) && isESSymbolIdentifier(node.expression);
	    }
	    ts.isWellKnownSymbolSyntactically = isWellKnownSymbolSyntactically;
	    function getPropertyNameForPropertyNameNode(name) {
	        if (name.kind === 69 /* Identifier */ || name.kind === 9 /* StringLiteral */ || name.kind === 8 /* NumericLiteral */) {
	            return name.text;
	        }
	        if (name.kind === 137 /* ComputedPropertyName */) {
	            var nameExpression = name.expression;
	            if (isWellKnownSymbolSyntactically(nameExpression)) {
	                var rightHandSideName = nameExpression.name.text;
	                return getPropertyNameForKnownSymbolName(rightHandSideName);
	            }
	        }
	        return undefined;
	    }
	    ts.getPropertyNameForPropertyNameNode = getPropertyNameForPropertyNameNode;
	    function getPropertyNameForKnownSymbolName(symbolName) {
	        return "__@" + symbolName;
	    }
	    ts.getPropertyNameForKnownSymbolName = getPropertyNameForKnownSymbolName;
	    /**
	     * Includes the word "Symbol" with unicode escapes
	     */
	    function isESSymbolIdentifier(node) {
	        return node.kind === 69 /* Identifier */ && node.text === "Symbol";
	    }
	    ts.isESSymbolIdentifier = isESSymbolIdentifier;
	    function isModifierKind(token) {
	        switch (token) {
	            case 115 /* AbstractKeyword */:
	            case 118 /* AsyncKeyword */:
	            case 74 /* ConstKeyword */:
	            case 122 /* DeclareKeyword */:
	            case 77 /* DefaultKeyword */:
	            case 82 /* ExportKeyword */:
	            case 112 /* PublicKeyword */:
	            case 110 /* PrivateKeyword */:
	            case 111 /* ProtectedKeyword */:
	            case 113 /* StaticKeyword */:
	                return true;
	        }
	        return false;
	    }
	    ts.isModifierKind = isModifierKind;
	    function isParameterDeclaration(node) {
	        var root = getRootDeclaration(node);
	        return root.kind === 139 /* Parameter */;
	    }
	    ts.isParameterDeclaration = isParameterDeclaration;
	    function getRootDeclaration(node) {
	        while (node.kind === 166 /* BindingElement */) {
	            node = node.parent.parent;
	        }
	        return node;
	    }
	    ts.getRootDeclaration = getRootDeclaration;
	    function nodeStartsNewLexicalEnvironment(n) {
	        return isFunctionLike(n) || n.kind === 221 /* ModuleDeclaration */ || n.kind === 251 /* SourceFile */;
	    }
	    ts.nodeStartsNewLexicalEnvironment = nodeStartsNewLexicalEnvironment;
	    /**
	     * Creates a shallow, memberwise clone of a node. The "kind", "pos", "end", "flags", and "parent"
	     * properties are excluded by default, and can be provided via the "location", "flags", and
	     * "parent" parameters.
	     * @param node The node to clone.
	     * @param location An optional TextRange to use to supply the new position.
	     * @param flags The NodeFlags to use for the cloned node.
	     * @param parent The parent for the new node.
	     */
	    function cloneNode(node, location, flags, parent) {
	        // We don't use "clone" from core.ts here, as we need to preserve the prototype chain of
	        // the original node. We also need to exclude specific properties and only include own-
	        // properties (to skip members already defined on the shared prototype).
	        var clone = location !== undefined
	            ? ts.createNode(node.kind, location.pos, location.end)
	            : createSynthesizedNode(node.kind);
	        for (var key in node) {
	            if (clone.hasOwnProperty(key) || !node.hasOwnProperty(key)) {
	                continue;
	            }
	            clone[key] = node[key];
	        }
	        if (flags !== undefined) {
	            clone.flags = flags;
	        }
	        if (parent !== undefined) {
	            clone.parent = parent;
	        }
	        return clone;
	    }
	    ts.cloneNode = cloneNode;
	    /**
	     * Creates a deep clone of an EntityName, with new parent pointers.
	     * @param node The EntityName to clone.
	     * @param parent The parent for the cloned node.
	     */
	    function cloneEntityName(node, parent) {
	        var clone = cloneNode(node, node, node.flags, parent);
	        if (isQualifiedName(clone)) {
	            var left = clone.left, right = clone.right;
	            clone.left = cloneEntityName(left, clone);
	            clone.right = cloneNode(right, right, right.flags, parent);
	        }
	        return clone;
	    }
	    ts.cloneEntityName = cloneEntityName;
	    function isQualifiedName(node) {
	        return node.kind === 136 /* QualifiedName */;
	    }
	    ts.isQualifiedName = isQualifiedName;
	    function nodeIsSynthesized(node) {
	        return node.pos === -1;
	    }
	    ts.nodeIsSynthesized = nodeIsSynthesized;
	    function createSynthesizedNode(kind, startsOnNewLine) {
	        var node = ts.createNode(kind, /* pos */ -1, /* end */ -1);
	        node.startsOnNewLine = startsOnNewLine;
	        return node;
	    }
	    ts.createSynthesizedNode = createSynthesizedNode;
	    function createSynthesizedNodeArray() {
	        var array = [];
	        array.pos = -1;
	        array.end = -1;
	        return array;
	    }
	    ts.createSynthesizedNodeArray = createSynthesizedNodeArray;
	    function createDiagnosticCollection() {
	        var nonFileDiagnostics = [];
	        var fileDiagnostics = {};
	        var diagnosticsModified = false;
	        var modificationCount = 0;
	        return {
	            add: add,
	            getGlobalDiagnostics: getGlobalDiagnostics,
	            getDiagnostics: getDiagnostics,
	            getModificationCount: getModificationCount,
	            reattachFileDiagnostics: reattachFileDiagnostics
	        };
	        function getModificationCount() {
	            return modificationCount;
	        }
	        function reattachFileDiagnostics(newFile) {
	            if (!ts.hasProperty(fileDiagnostics, newFile.fileName)) {
	                return;
	            }
	            for (var _i = 0, _a = fileDiagnostics[newFile.fileName]; _i < _a.length; _i++) {
	                var diagnostic = _a[_i];
	                diagnostic.file = newFile;
	            }
	        }
	        function add(diagnostic) {
	            var diagnostics;
	            if (diagnostic.file) {
	                diagnostics = fileDiagnostics[diagnostic.file.fileName];
	                if (!diagnostics) {
	                    diagnostics = [];
	                    fileDiagnostics[diagnostic.file.fileName] = diagnostics;
	                }
	            }
	            else {
	                diagnostics = nonFileDiagnostics;
	            }
	            diagnostics.push(diagnostic);
	            diagnosticsModified = true;
	            modificationCount++;
	        }
	        function getGlobalDiagnostics() {
	            sortAndDeduplicate();
	            return nonFileDiagnostics;
	        }
	        function getDiagnostics(fileName) {
	            sortAndDeduplicate();
	            if (fileName) {
	                return fileDiagnostics[fileName] || [];
	            }
	            var allDiagnostics = [];
	            function pushDiagnostic(d) {
	                allDiagnostics.push(d);
	            }
	            ts.forEach(nonFileDiagnostics, pushDiagnostic);
	            for (var key in fileDiagnostics) {
	                if (ts.hasProperty(fileDiagnostics, key)) {
	                    ts.forEach(fileDiagnostics[key], pushDiagnostic);
	                }
	            }
	            return ts.sortAndDeduplicateDiagnostics(allDiagnostics);
	        }
	        function sortAndDeduplicate() {
	            if (!diagnosticsModified) {
	                return;
	            }
	            diagnosticsModified = false;
	            nonFileDiagnostics = ts.sortAndDeduplicateDiagnostics(nonFileDiagnostics);
	            for (var key in fileDiagnostics) {
	                if (ts.hasProperty(fileDiagnostics, key)) {
	                    fileDiagnostics[key] = ts.sortAndDeduplicateDiagnostics(fileDiagnostics[key]);
	                }
	            }
	        }
	    }
	    ts.createDiagnosticCollection = createDiagnosticCollection;
	    // This consists of the first 19 unprintable ASCII characters, canonical escapes, lineSeparator,
	    // paragraphSeparator, and nextLine. The latter three are just desirable to suppress new lines in
	    // the language service. These characters should be escaped when printing, and if any characters are added,
	    // the map below must be updated. Note that this regexp *does not* include the 'delete' character.
	    // There is no reason for this other than that JSON.stringify does not handle it either.
	    var escapedCharsRegExp = /[\\\"\u0000-\u001f\t\v\f\b\r\n\u2028\u2029\u0085]/g;
	    var escapedCharsMap = {
	        "\0": "\\0",
	        "\t": "\\t",
	        "\v": "\\v",
	        "\f": "\\f",
	        "\b": "\\b",
	        "\r": "\\r",
	        "\n": "\\n",
	        "\\": "\\\\",
	        "\"": "\\\"",
	        "\u2028": "\\u2028",
	        "\u2029": "\\u2029",
	        "\u0085": "\\u0085" // nextLine
	    };
	    /**
	     * Based heavily on the abstract 'Quote'/'QuoteJSONString' operation from ECMA-262 (24.3.2.2),
	     * but augmented for a few select characters (e.g. lineSeparator, paragraphSeparator, nextLine)
	     * Note that this doesn't actually wrap the input in double quotes.
	     */
	    function escapeString(s) {
	        s = escapedCharsRegExp.test(s) ? s.replace(escapedCharsRegExp, getReplacement) : s;
	        return s;
	        function getReplacement(c) {
	            return escapedCharsMap[c] || get16BitUnicodeEscapeSequence(c.charCodeAt(0));
	        }
	    }
	    ts.escapeString = escapeString;
	    function isIntrinsicJsxName(name) {
	        var ch = name.substr(0, 1);
	        return ch.toLowerCase() === ch;
	    }
	    ts.isIntrinsicJsxName = isIntrinsicJsxName;
	    function get16BitUnicodeEscapeSequence(charCode) {
	        var hexCharCode = charCode.toString(16).toUpperCase();
	        var paddedHexCode = ("0000" + hexCharCode).slice(-4);
	        return "\\u" + paddedHexCode;
	    }
	    var nonAsciiCharacters = /[^\u0000-\u007F]/g;
	    function escapeNonAsciiCharacters(s) {
	        // Replace non-ASCII characters with '\uNNNN' escapes if any exist.
	        // Otherwise just return the original string.
	        return nonAsciiCharacters.test(s) ?
	            s.replace(nonAsciiCharacters, function (c) { return get16BitUnicodeEscapeSequence(c.charCodeAt(0)); }) :
	            s;
	    }
	    ts.escapeNonAsciiCharacters = escapeNonAsciiCharacters;
	    var indentStrings = ["", "    "];
	    function getIndentString(level) {
	        if (indentStrings[level] === undefined) {
	            indentStrings[level] = getIndentString(level - 1) + indentStrings[1];
	        }
	        return indentStrings[level];
	    }
	    ts.getIndentString = getIndentString;
	    function getIndentSize() {
	        return indentStrings[1].length;
	    }
	    ts.getIndentSize = getIndentSize;
	    function createTextWriter(newLine) {
	        var output;
	        var indent;
	        var lineStart;
	        var lineCount;
	        var linePos;
	        function write(s) {
	            if (s && s.length) {
	                if (lineStart) {
	                    output += getIndentString(indent);
	                    lineStart = false;
	                }
	                output += s;
	            }
	        }
	        function reset() {
	            output = "";
	            indent = 0;
	            lineStart = true;
	            lineCount = 0;
	            linePos = 0;
	        }
	        function rawWrite(s) {
	            if (s !== undefined) {
	                if (lineStart) {
	                    lineStart = false;
	                }
	                output += s;
	            }
	        }
	        function writeLiteral(s) {
	            if (s && s.length) {
	                write(s);
	                var lineStartsOfS = ts.computeLineStarts(s);
	                if (lineStartsOfS.length > 1) {
	                    lineCount = lineCount + lineStartsOfS.length - 1;
	                    linePos = output.length - s.length + ts.lastOrUndefined(lineStartsOfS);
	                }
	            }
	        }
	        function writeLine() {
	            if (!lineStart) {
	                output += newLine;
	                lineCount++;
	                linePos = output.length;
	                lineStart = true;
	            }
	        }
	        function writeTextOfNode(text, node) {
	            write(getTextOfNodeFromSourceText(text, node));
	        }
	        reset();
	        return {
	            write: write,
	            rawWrite: rawWrite,
	            writeTextOfNode: writeTextOfNode,
	            writeLiteral: writeLiteral,
	            writeLine: writeLine,
	            increaseIndent: function () { indent++; },
	            decreaseIndent: function () { indent--; },
	            getIndent: function () { return indent; },
	            getTextPos: function () { return output.length; },
	            getLine: function () { return lineCount + 1; },
	            getColumn: function () { return lineStart ? indent * getIndentSize() + 1 : output.length - linePos + 1; },
	            getText: function () { return output; },
	            reset: reset
	        };
	    }
	    ts.createTextWriter = createTextWriter;
	    /**
	     * Resolves a local path to a path which is absolute to the base of the emit
	     */
	    function getExternalModuleNameFromPath(host, fileName) {
	        var getCanonicalFileName = function (f) { return host.getCanonicalFileName(f); };
	        var dir = ts.toPath(host.getCommonSourceDirectory(), host.getCurrentDirectory(), getCanonicalFileName);
	        var filePath = ts.getNormalizedAbsolutePath(fileName, host.getCurrentDirectory());
	        var relativePath = ts.getRelativePathToDirectoryOrUrl(dir, filePath, dir, getCanonicalFileName, /*isAbsolutePathAnUrl*/ false);
	        return ts.removeFileExtension(relativePath);
	    }
	    ts.getExternalModuleNameFromPath = getExternalModuleNameFromPath;
	    function getOwnEmitOutputFilePath(sourceFile, host, extension) {
	        var compilerOptions = host.getCompilerOptions();
	        var emitOutputFilePathWithoutExtension;
	        if (compilerOptions.outDir) {
	            emitOutputFilePathWithoutExtension = ts.removeFileExtension(getSourceFilePathInNewDir(sourceFile, host, compilerOptions.outDir));
	        }
	        else {
	            emitOutputFilePathWithoutExtension = ts.removeFileExtension(sourceFile.fileName);
	        }
	        return emitOutputFilePathWithoutExtension + extension;
	    }
	    ts.getOwnEmitOutputFilePath = getOwnEmitOutputFilePath;
	    function getEmitScriptTarget(compilerOptions) {
	        return compilerOptions.target || 0 /* ES3 */;
	    }
	    ts.getEmitScriptTarget = getEmitScriptTarget;
	    function getEmitModuleKind(compilerOptions) {
	        return typeof compilerOptions.module === "number" ?
	            compilerOptions.module :
	            getEmitScriptTarget(compilerOptions) === 2 /* ES6 */ ? 5 /* ES6 */ : 1 /* CommonJS */;
	    }
	    ts.getEmitModuleKind = getEmitModuleKind;
	    function forEachExpectedEmitFile(host, action, targetSourceFile) {
	        var options = host.getCompilerOptions();
	        // Emit on each source file
	        if (options.outFile || options.out) {
	            onBundledEmit(host);
	        }
	        else {
	            var sourceFiles = targetSourceFile === undefined ? host.getSourceFiles() : [targetSourceFile];
	            for (var _i = 0, sourceFiles_1 = sourceFiles; _i < sourceFiles_1.length; _i++) {
	                var sourceFile = sourceFiles_1[_i];
	                if (!isDeclarationFile(sourceFile)) {
	                    onSingleFileEmit(host, sourceFile);
	                }
	            }
	        }
	        function onSingleFileEmit(host, sourceFile) {
	            // JavaScript files are always LanguageVariant.JSX, as JSX syntax is allowed in .js files also.
	            // So for JavaScript files, '.jsx' is only emitted if the input was '.jsx', and JsxEmit.Preserve.
	            // For TypeScript, the only time to emit with a '.jsx' extension, is on JSX input, and JsxEmit.Preserve
	            var extension = ".js";
	            if (options.jsx === 1 /* Preserve */) {
	                if (isSourceFileJavaScript(sourceFile)) {
	                    if (ts.fileExtensionIs(sourceFile.fileName, ".jsx")) {
	                        extension = ".jsx";
	                    }
	                }
	                else if (sourceFile.languageVariant === 1 /* JSX */) {
	                    // TypeScript source file preserving JSX syntax
	                    extension = ".jsx";
	                }
	            }
	            var jsFilePath = getOwnEmitOutputFilePath(sourceFile, host, extension);
	            var emitFileNames = {
	                jsFilePath: jsFilePath,
	                sourceMapFilePath: getSourceMapFilePath(jsFilePath, options),
	                declarationFilePath: !isSourceFileJavaScript(sourceFile) ? getDeclarationEmitFilePath(jsFilePath, options) : undefined
	            };
	            action(emitFileNames, [sourceFile], /*isBundledEmit*/ false);
	        }
	        function onBundledEmit(host) {
	            // Can emit only sources that are not declaration file and are either non module code or module with --module or --target es6 specified
	            var bundledSources = ts.filter(host.getSourceFiles(), function (sourceFile) { return !isDeclarationFile(sourceFile) &&
	                (!isExternalModule(sourceFile) ||
	                    (getEmitModuleKind(options) && isExternalModule(sourceFile))); }); // module that can emit - note falsy value from getEmitModuleKind means the module kind that shouldn't be emitted
	            if (bundledSources.length) {
	                var jsFilePath = options.outFile || options.out;
	                var emitFileNames = {
	                    jsFilePath: jsFilePath,
	                    sourceMapFilePath: getSourceMapFilePath(jsFilePath, options),
	                    declarationFilePath: getDeclarationEmitFilePath(jsFilePath, options)
	                };
	                action(emitFileNames, bundledSources, /*isBundledEmit*/ true);
	            }
	        }
	        function getSourceMapFilePath(jsFilePath, options) {
	            return options.sourceMap ? jsFilePath + ".map" : undefined;
	        }
	        function getDeclarationEmitFilePath(jsFilePath, options) {
	            return options.declaration ? ts.removeFileExtension(jsFilePath) + ".d.ts" : undefined;
	        }
	    }
	    ts.forEachExpectedEmitFile = forEachExpectedEmitFile;
	    function getSourceFilePathInNewDir(sourceFile, host, newDirPath) {
	        var sourceFilePath = ts.getNormalizedAbsolutePath(sourceFile.fileName, host.getCurrentDirectory());
	        sourceFilePath = sourceFilePath.replace(host.getCommonSourceDirectory(), "");
	        return ts.combinePaths(newDirPath, sourceFilePath);
	    }
	    ts.getSourceFilePathInNewDir = getSourceFilePathInNewDir;
	    function writeFile(host, diagnostics, fileName, data, writeByteOrderMark) {
	        host.writeFile(fileName, data, writeByteOrderMark, function (hostErrorMessage) {
	            diagnostics.add(ts.createCompilerDiagnostic(ts.Diagnostics.Could_not_write_file_0_Colon_1, fileName, hostErrorMessage));
	        });
	    }
	    ts.writeFile = writeFile;
	    function getLineOfLocalPosition(currentSourceFile, pos) {
	        return ts.getLineAndCharacterOfPosition(currentSourceFile, pos).line;
	    }
	    ts.getLineOfLocalPosition = getLineOfLocalPosition;
	    function getLineOfLocalPositionFromLineMap(lineMap, pos) {
	        return ts.computeLineAndCharacterOfPosition(lineMap, pos).line;
	    }
	    ts.getLineOfLocalPositionFromLineMap = getLineOfLocalPositionFromLineMap;
	    function getFirstConstructorWithBody(node) {
	        return ts.forEach(node.members, function (member) {
	            if (member.kind === 145 /* Constructor */ && nodeIsPresent(member.body)) {
	                return member;
	            }
	        });
	    }
	    ts.getFirstConstructorWithBody = getFirstConstructorWithBody;
	    function getSetAccessorTypeAnnotationNode(accessor) {
	        return accessor && accessor.parameters.length > 0 && accessor.parameters[0].type;
	    }
	    ts.getSetAccessorTypeAnnotationNode = getSetAccessorTypeAnnotationNode;
	    function getAllAccessorDeclarations(declarations, accessor) {
	        var firstAccessor;
	        var secondAccessor;
	        var getAccessor;
	        var setAccessor;
	        if (hasDynamicName(accessor)) {
	            firstAccessor = accessor;
	            if (accessor.kind === 146 /* GetAccessor */) {
	                getAccessor = accessor;
	            }
	            else if (accessor.kind === 147 /* SetAccessor */) {
	                setAccessor = accessor;
	            }
	            else {
	                ts.Debug.fail("Accessor has wrong kind");
	            }
	        }
	        else {
	            ts.forEach(declarations, function (member) {
	                if ((member.kind === 146 /* GetAccessor */ || member.kind === 147 /* SetAccessor */)
	                    && (member.flags & 64 /* Static */) === (accessor.flags & 64 /* Static */)) {
	                    var memberName = getPropertyNameForPropertyNameNode(member.name);
	                    var accessorName = getPropertyNameForPropertyNameNode(accessor.name);
	                    if (memberName === accessorName) {
	                        if (!firstAccessor) {
	                            firstAccessor = member;
	                        }
	                        else if (!secondAccessor) {
	                            secondAccessor = member;
	                        }
	                        if (member.kind === 146 /* GetAccessor */ && !getAccessor) {
	                            getAccessor = member;
	                        }
	                        if (member.kind === 147 /* SetAccessor */ && !setAccessor) {
	                            setAccessor = member;
	                        }
	                    }
	                }
	            });
	        }
	        return {
	            firstAccessor: firstAccessor,
	            secondAccessor: secondAccessor,
	            getAccessor: getAccessor,
	            setAccessor: setAccessor
	        };
	    }
	    ts.getAllAccessorDeclarations = getAllAccessorDeclarations;
	    function emitNewLineBeforeLeadingComments(lineMap, writer, node, leadingComments) {
	        // If the leading comments start on different line than the start of node, write new line
	        if (leadingComments && leadingComments.length && node.pos !== leadingComments[0].pos &&
	            getLineOfLocalPositionFromLineMap(lineMap, node.pos) !== getLineOfLocalPositionFromLineMap(lineMap, leadingComments[0].pos)) {
	            writer.writeLine();
	        }
	    }
	    ts.emitNewLineBeforeLeadingComments = emitNewLineBeforeLeadingComments;
	    function emitComments(text, lineMap, writer, comments, trailingSeparator, newLine, writeComment) {
	        var emitLeadingSpace = !trailingSeparator;
	        ts.forEach(comments, function (comment) {
	            if (emitLeadingSpace) {
	                writer.write(" ");
	                emitLeadingSpace = false;
	            }
	            writeComment(text, lineMap, writer, comment, newLine);
	            if (comment.hasTrailingNewLine) {
	                writer.writeLine();
	            }
	            else if (trailingSeparator) {
	                writer.write(" ");
	            }
	            else {
	                // Emit leading space to separate comment during next comment emit
	                emitLeadingSpace = true;
	            }
	        });
	    }
	    ts.emitComments = emitComments;
	    /**
	     * Detached comment is a comment at the top of file or function body that is separated from
	     * the next statement by space.
	     */
	    function emitDetachedComments(text, lineMap, writer, writeComment, node, newLine, removeComments) {
	        var leadingComments;
	        var currentDetachedCommentInfo;
	        if (removeComments) {
	            // removeComments is true, only reserve pinned comment at the top of file
	            // For example:
	            //      /*! Pinned Comment */
	            //
	            //      var x = 10;
	            if (node.pos === 0) {
	                leadingComments = ts.filter(ts.getLeadingCommentRanges(text, node.pos), isPinnedComment);
	            }
	        }
	        else {
	            // removeComments is false, just get detached as normal and bypass the process to filter comment
	            leadingComments = ts.getLeadingCommentRanges(text, node.pos);
	        }
	        if (leadingComments) {
	            var detachedComments = [];
	            var lastComment = void 0;
	            for (var _i = 0, leadingComments_1 = leadingComments; _i < leadingComments_1.length; _i++) {
	                var comment = leadingComments_1[_i];
	                if (lastComment) {
	                    var lastCommentLine = getLineOfLocalPositionFromLineMap(lineMap, lastComment.end);
	                    var commentLine = getLineOfLocalPositionFromLineMap(lineMap, comment.pos);
	                    if (commentLine >= lastCommentLine + 2) {
	                        // There was a blank line between the last comment and this comment.  This
	                        // comment is not part of the copyright comments.  Return what we have so
	                        // far.
	                        break;
	                    }
	                }
	                detachedComments.push(comment);
	                lastComment = comment;
	            }
	            if (detachedComments.length) {
	                // All comments look like they could have been part of the copyright header.  Make
	                // sure there is at least one blank line between it and the node.  If not, it's not
	                // a copyright header.
	                var lastCommentLine = getLineOfLocalPositionFromLineMap(lineMap, ts.lastOrUndefined(detachedComments).end);
	                var nodeLine = getLineOfLocalPositionFromLineMap(lineMap, ts.skipTrivia(text, node.pos));
	                if (nodeLine >= lastCommentLine + 2) {
	                    // Valid detachedComments
	                    emitNewLineBeforeLeadingComments(lineMap, writer, node, leadingComments);
	                    emitComments(text, lineMap, writer, detachedComments, /*trailingSeparator*/ true, newLine, writeComment);
	                    currentDetachedCommentInfo = { nodePos: node.pos, detachedCommentEndPos: ts.lastOrUndefined(detachedComments).end };
	                }
	            }
	        }
	        return currentDetachedCommentInfo;
	        function isPinnedComment(comment) {
	            return text.charCodeAt(comment.pos + 1) === 42 /* asterisk */ &&
	                text.charCodeAt(comment.pos + 2) === 33 /* exclamation */;
	        }
	    }
	    ts.emitDetachedComments = emitDetachedComments;
	    function writeCommentRange(text, lineMap, writer, comment, newLine) {
	        if (text.charCodeAt(comment.pos + 1) === 42 /* asterisk */) {
	            var firstCommentLineAndCharacter = ts.computeLineAndCharacterOfPosition(lineMap, comment.pos);
	            var lineCount = lineMap.length;
	            var firstCommentLineIndent = void 0;
	            for (var pos = comment.pos, currentLine = firstCommentLineAndCharacter.line; pos < comment.end; currentLine++) {
	                var nextLineStart = (currentLine + 1) === lineCount
	                    ? text.length + 1
	                    : lineMap[currentLine + 1];
	                if (pos !== comment.pos) {
	                    // If we are not emitting first line, we need to write the spaces to adjust the alignment
	                    if (firstCommentLineIndent === undefined) {
	                        firstCommentLineIndent = calculateIndent(text, lineMap[firstCommentLineAndCharacter.line], comment.pos);
	                    }
	                    // These are number of spaces writer is going to write at current indent
	                    var currentWriterIndentSpacing = writer.getIndent() * getIndentSize();
	                    // Number of spaces we want to be writing
	                    // eg: Assume writer indent
	                    // module m {
	                    //         /* starts at character 9 this is line 1
	                    //    * starts at character pos 4 line                        --1  = 8 - 8 + 3
	                    //   More left indented comment */                            --2  = 8 - 8 + 2
	                    //     class c { }
	                    // }
	                    // module m {
	                    //     /* this is line 1 -- Assume current writer indent 8
	                    //      * line                                                --3 = 8 - 4 + 5
	                    //            More right indented comment */                  --4 = 8 - 4 + 11
	                    //     class c { }
	                    // }
	                    var spacesToEmit = currentWriterIndentSpacing - firstCommentLineIndent + calculateIndent(text, pos, nextLineStart);
	                    if (spacesToEmit > 0) {
	                        var numberOfSingleSpacesToEmit = spacesToEmit % getIndentSize();
	                        var indentSizeSpaceString = getIndentString((spacesToEmit - numberOfSingleSpacesToEmit) / getIndentSize());
	                        // Write indent size string ( in eg 1: = "", 2: "" , 3: string with 8 spaces 4: string with 12 spaces
	                        writer.rawWrite(indentSizeSpaceString);
	                        // Emit the single spaces (in eg: 1: 3 spaces, 2: 2 spaces, 3: 1 space, 4: 3 spaces)
	                        while (numberOfSingleSpacesToEmit) {
	                            writer.rawWrite(" ");
	                            numberOfSingleSpacesToEmit--;
	                        }
	                    }
	                    else {
	                        // No spaces to emit write empty string
	                        writer.rawWrite("");
	                    }
	                }
	                // Write the comment line text
	                writeTrimmedCurrentLine(text, comment, writer, newLine, pos, nextLineStart);
	                pos = nextLineStart;
	            }
	        }
	        else {
	            // Single line comment of style //....
	            writer.write(text.substring(comment.pos, comment.end));
	        }
	    }
	    ts.writeCommentRange = writeCommentRange;
	    function writeTrimmedCurrentLine(text, comment, writer, newLine, pos, nextLineStart) {
	        var end = Math.min(comment.end, nextLineStart - 1);
	        var currentLineText = text.substring(pos, end).replace(/^\s+|\s+$/g, "");
	        if (currentLineText) {
	            // trimmed forward and ending spaces text
	            writer.write(currentLineText);
	            if (end !== comment.end) {
	                writer.writeLine();
	            }
	        }
	        else {
	            // Empty string - make sure we write empty line
	            writer.writeLiteral(newLine);
	        }
	    }
	    function calculateIndent(text, pos, end) {
	        var currentLineIndent = 0;
	        for (; pos < end && ts.isWhiteSpace(text.charCodeAt(pos)); pos++) {
	            if (text.charCodeAt(pos) === 9 /* tab */) {
	                // Tabs = TabSize = indent size and go to next tabStop
	                currentLineIndent += getIndentSize() - (currentLineIndent % getIndentSize());
	            }
	            else {
	                // Single space
	                currentLineIndent++;
	            }
	        }
	        return currentLineIndent;
	    }
	    function modifierToFlag(token) {
	        switch (token) {
	            case 113 /* StaticKeyword */: return 64 /* Static */;
	            case 112 /* PublicKeyword */: return 8 /* Public */;
	            case 111 /* ProtectedKeyword */: return 32 /* Protected */;
	            case 110 /* PrivateKeyword */: return 16 /* Private */;
	            case 115 /* AbstractKeyword */: return 128 /* Abstract */;
	            case 82 /* ExportKeyword */: return 2 /* Export */;
	            case 122 /* DeclareKeyword */: return 4 /* Ambient */;
	            case 74 /* ConstKeyword */: return 16384 /* Const */;
	            case 77 /* DefaultKeyword */: return 512 /* Default */;
	            case 118 /* AsyncKeyword */: return 256 /* Async */;
	        }
	        return 0;
	    }
	    ts.modifierToFlag = modifierToFlag;
	    function isLeftHandSideExpression(expr) {
	        if (expr) {
	            switch (expr.kind) {
	                case 169 /* PropertyAccessExpression */:
	                case 170 /* ElementAccessExpression */:
	                case 172 /* NewExpression */:
	                case 171 /* CallExpression */:
	                case 236 /* JsxElement */:
	                case 237 /* JsxSelfClosingElement */:
	                case 173 /* TaggedTemplateExpression */:
	                case 167 /* ArrayLiteralExpression */:
	                case 175 /* ParenthesizedExpression */:
	                case 168 /* ObjectLiteralExpression */:
	                case 189 /* ClassExpression */:
	                case 176 /* FunctionExpression */:
	                case 69 /* Identifier */:
	                case 10 /* RegularExpressionLiteral */:
	                case 8 /* NumericLiteral */:
	                case 9 /* StringLiteral */:
	                case 11 /* NoSubstitutionTemplateLiteral */:
	                case 186 /* TemplateExpression */:
	                case 84 /* FalseKeyword */:
	                case 93 /* NullKeyword */:
	                case 97 /* ThisKeyword */:
	                case 99 /* TrueKeyword */:
	                case 95 /* SuperKeyword */:
	                    return true;
	            }
	        }
	        return false;
	    }
	    ts.isLeftHandSideExpression = isLeftHandSideExpression;
	    function isAssignmentOperator(token) {
	        return token >= 56 /* FirstAssignment */ && token <= 68 /* LastAssignment */;
	    }
	    ts.isAssignmentOperator = isAssignmentOperator;
	    function isExpressionWithTypeArgumentsInClassExtendsClause(node) {
	        return node.kind === 191 /* ExpressionWithTypeArguments */ &&
	            node.parent.token === 83 /* ExtendsKeyword */ &&
	            isClassLike(node.parent.parent);
	    }
	    ts.isExpressionWithTypeArgumentsInClassExtendsClause = isExpressionWithTypeArgumentsInClassExtendsClause;
	    // Returns false if this heritage clause element's expression contains something unsupported
	    // (i.e. not a name or dotted name).
	    function isSupportedExpressionWithTypeArguments(node) {
	        return isSupportedExpressionWithTypeArgumentsRest(node.expression);
	    }
	    ts.isSupportedExpressionWithTypeArguments = isSupportedExpressionWithTypeArguments;
	    function isSupportedExpressionWithTypeArgumentsRest(node) {
	        if (node.kind === 69 /* Identifier */) {
	            return true;
	        }
	        else if (isPropertyAccessExpression(node)) {
	            return isSupportedExpressionWithTypeArgumentsRest(node.expression);
	        }
	        else {
	            return false;
	        }
	    }
	    function isRightSideOfQualifiedNameOrPropertyAccess(node) {
	        return (node.parent.kind === 136 /* QualifiedName */ && node.parent.right === node) ||
	            (node.parent.kind === 169 /* PropertyAccessExpression */ && node.parent.name === node);
	    }
	    ts.isRightSideOfQualifiedNameOrPropertyAccess = isRightSideOfQualifiedNameOrPropertyAccess;
	    function isEmptyObjectLiteralOrArrayLiteral(expression) {
	        var kind = expression.kind;
	        if (kind === 168 /* ObjectLiteralExpression */) {
	            return expression.properties.length === 0;
	        }
	        if (kind === 167 /* ArrayLiteralExpression */) {
	            return expression.elements.length === 0;
	        }
	        return false;
	    }
	    ts.isEmptyObjectLiteralOrArrayLiteral = isEmptyObjectLiteralOrArrayLiteral;
	    function getLocalSymbolForExportDefault(symbol) {
	        return symbol && symbol.valueDeclaration && (symbol.valueDeclaration.flags & 512 /* Default */) ? symbol.valueDeclaration.localSymbol : undefined;
	    }
	    ts.getLocalSymbolForExportDefault = getLocalSymbolForExportDefault;
	    function hasJavaScriptFileExtension(fileName) {
	        return ts.forEach(ts.supportedJavascriptExtensions, function (extension) { return ts.fileExtensionIs(fileName, extension); });
	    }
	    ts.hasJavaScriptFileExtension = hasJavaScriptFileExtension;
	    /**
	     * Replace each instance of non-ascii characters by one, two, three, or four escape sequences
	     * representing the UTF-8 encoding of the character, and return the expanded char code list.
	     */
	    function getExpandedCharCodes(input) {
	        var output = [];
	        var length = input.length;
	        for (var i = 0; i < length; i++) {
	            var charCode = input.charCodeAt(i);
	            // handel utf8
	            if (charCode < 0x80) {
	                output.push(charCode);
	            }
	            else if (charCode < 0x800) {
	                output.push((charCode >> 6) | 192);
	                output.push((charCode & 63) | 128);
	            }
	            else if (charCode < 0x10000) {
	                output.push((charCode >> 12) | 224);
	                output.push(((charCode >> 6) & 63) | 128);
	                output.push((charCode & 63) | 128);
	            }
	            else if (charCode < 0x20000) {
	                output.push((charCode >> 18) | 240);
	                output.push(((charCode >> 12) & 63) | 128);
	                output.push(((charCode >> 6) & 63) | 128);
	                output.push((charCode & 63) | 128);
	            }
	            else {
	                ts.Debug.assert(false, "Unexpected code point");
	            }
	        }
	        return output;
	    }
	    /**
	     * Serialize an object graph into a JSON string. This is intended only for use on an acyclic graph
	     * as the fallback implementation does not check for circular references by default.
	     */
	    ts.stringify = typeof JSON !== "undefined" && JSON.stringify
	        ? JSON.stringify
	        : stringifyFallback;
	    /**
	     * Serialize an object graph into a JSON string.
	     */
	    function stringifyFallback(value) {
	        // JSON.stringify returns `undefined` here, instead of the string "undefined".
	        return value === undefined ? undefined : stringifyValue(value);
	    }
	    function stringifyValue(value) {
	        return typeof value === "string" ? "\"" + escapeString(value) + "\""
	            : typeof value === "number" ? isFinite(value) ? String(value) : "null"
	                : typeof value === "boolean" ? value ? "true" : "false"
	                    : typeof value === "object" && value ? ts.isArray(value) ? cycleCheck(stringifyArray, value) : cycleCheck(stringifyObject, value)
	                        : "null";
	    }
	    function cycleCheck(cb, value) {
	        ts.Debug.assert(!value.hasOwnProperty("__cycle"), "Converting circular structure to JSON");
	        value.__cycle = true;
	        var result = cb(value);
	        delete value.__cycle;
	        return result;
	    }
	    function stringifyArray(value) {
	        return "[" + ts.reduceLeft(value, stringifyElement, "") + "]";
	    }
	    function stringifyElement(memo, value) {
	        return (memo ? memo + "," : memo) + stringifyValue(value);
	    }
	    function stringifyObject(value) {
	        return "{" + ts.reduceProperties(value, stringifyProperty, "") + "}";
	    }
	    function stringifyProperty(memo, value, key) {
	        return value === undefined || typeof value === "function" || key === "__cycle" ? memo
	            : (memo ? memo + "," : memo) + ("\"" + escapeString(key) + "\":" + stringifyValue(value));
	    }
	    var base64Digits = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=";
	    /**
	     * Converts a string to a base-64 encoded ASCII string.
	     */
	    function convertToBase64(input) {
	        var result = "";
	        var charCodes = getExpandedCharCodes(input);
	        var i = 0;
	        var length = charCodes.length;
	        var byte1, byte2, byte3, byte4;
	        while (i < length) {
	            // Convert every 6-bits in the input 3 character points
	            // into a base64 digit
	            byte1 = charCodes[i] >> 2;
	            byte2 = (charCodes[i] & 3) << 4 | charCodes[i + 1] >> 4;
	            byte3 = (charCodes[i + 1] & 15) << 2 | charCodes[i + 2] >> 6;
	            byte4 = charCodes[i + 2] & 63;
	            // We are out of characters in the input, set the extra
	            // digits to 64 (padding character).
	            if (i + 1 >= length) {
	                byte3 = byte4 = 64;
	            }
	            else if (i + 2 >= length) {
	                byte4 = 64;
	            }
	            // Write to the ouput
	            result += base64Digits.charAt(byte1) + base64Digits.charAt(byte2) + base64Digits.charAt(byte3) + base64Digits.charAt(byte4);
	            i += 3;
	        }
	        return result;
	    }
	    ts.convertToBase64 = convertToBase64;
	    function convertToRelativePath(absoluteOrRelativePath, basePath, getCanonicalFileName) {
	        return !ts.isRootedDiskPath(absoluteOrRelativePath)
	            ? absoluteOrRelativePath
	            : ts.getRelativePathToDirectoryOrUrl(basePath, absoluteOrRelativePath, basePath, getCanonicalFileName, /* isAbsolutePathAnUrl */ false);
	    }
	    ts.convertToRelativePath = convertToRelativePath;
	    var carriageReturnLineFeed = "\r\n";
	    var lineFeed = "\n";
	    function getNewLineCharacter(options) {
	        if (options.newLine === 0 /* CarriageReturnLineFeed */) {
	            return carriageReturnLineFeed;
	        }
	        else if (options.newLine === 1 /* LineFeed */) {
	            return lineFeed;
	        }
	        else if (ts.sys) {
	            return ts.sys.newLine;
	        }
	        return carriageReturnLineFeed;
	    }
	    ts.getNewLineCharacter = getNewLineCharacter;
	})(ts || (ts = {}));
	var ts;
	(function (ts) {
	    function getDefaultLibFileName(options) {
	        return options.target === 2 /* ES6 */ ? "lib.es6.d.ts" : "lib.d.ts";
	    }
	    ts.getDefaultLibFileName = getDefaultLibFileName;
	    function textSpanEnd(span) {
	        return span.start + span.length;
	    }
	    ts.textSpanEnd = textSpanEnd;
	    function textSpanIsEmpty(span) {
	        return span.length === 0;
	    }
	    ts.textSpanIsEmpty = textSpanIsEmpty;
	    function textSpanContainsPosition(span, position) {
	        return position >= span.start && position < textSpanEnd(span);
	    }
	    ts.textSpanContainsPosition = textSpanContainsPosition;
	    // Returns true if 'span' contains 'other'.
	    function textSpanContainsTextSpan(span, other) {
	        return other.start >= span.start && textSpanEnd(other) <= textSpanEnd(span);
	    }
	    ts.textSpanContainsTextSpan = textSpanContainsTextSpan;
	    function textSpanOverlapsWith(span, other) {
	        var overlapStart = Math.max(span.start, other.start);
	        var overlapEnd = Math.min(textSpanEnd(span), textSpanEnd(other));
	        return overlapStart < overlapEnd;
	    }
	    ts.textSpanOverlapsWith = textSpanOverlapsWith;
	    function textSpanOverlap(span1, span2) {
	        var overlapStart = Math.max(span1.start, span2.start);
	        var overlapEnd = Math.min(textSpanEnd(span1), textSpanEnd(span2));
	        if (overlapStart < overlapEnd) {
	            return createTextSpanFromBounds(overlapStart, overlapEnd);
	        }
	        return undefined;
	    }
	    ts.textSpanOverlap = textSpanOverlap;
	    function textSpanIntersectsWithTextSpan(span, other) {
	        return other.start <= textSpanEnd(span) && textSpanEnd(other) >= span.start;
	    }
	    ts.textSpanIntersectsWithTextSpan = textSpanIntersectsWithTextSpan;
	    function textSpanIntersectsWith(span, start, length) {
	        var end = start + length;
	        return start <= textSpanEnd(span) && end >= span.start;
	    }
	    ts.textSpanIntersectsWith = textSpanIntersectsWith;
	    function decodedTextSpanIntersectsWith(start1, length1, start2, length2) {
	        var end1 = start1 + length1;
	        var end2 = start2 + length2;
	        return start2 <= end1 && end2 >= start1;
	    }
	    ts.decodedTextSpanIntersectsWith = decodedTextSpanIntersectsWith;
	    function textSpanIntersectsWithPosition(span, position) {
	        return position <= textSpanEnd(span) && position >= span.start;
	    }
	    ts.textSpanIntersectsWithPosition = textSpanIntersectsWithPosition;
	    function textSpanIntersection(span1, span2) {
	        var intersectStart = Math.max(span1.start, span2.start);
	        var intersectEnd = Math.min(textSpanEnd(span1), textSpanEnd(span2));
	        if (intersectStart <= intersectEnd) {
	            return createTextSpanFromBounds(intersectStart, intersectEnd);
	        }
	        return undefined;
	    }
	    ts.textSpanIntersection = textSpanIntersection;
	    function createTextSpan(start, length) {
	        if (start < 0) {
	            throw new Error("start < 0");
	        }
	        if (length < 0) {
	            throw new Error("length < 0");
	        }
	        return { start: start, length: length };
	    }
	    ts.createTextSpan = createTextSpan;
	    function createTextSpanFromBounds(start, end) {
	        return createTextSpan(start, end - start);
	    }
	    ts.createTextSpanFromBounds = createTextSpanFromBounds;
	    function textChangeRangeNewSpan(range) {
	        return createTextSpan(range.span.start, range.newLength);
	    }
	    ts.textChangeRangeNewSpan = textChangeRangeNewSpan;
	    function textChangeRangeIsUnchanged(range) {
	        return textSpanIsEmpty(range.span) && range.newLength === 0;
	    }
	    ts.textChangeRangeIsUnchanged = textChangeRangeIsUnchanged;
	    function createTextChangeRange(span, newLength) {
	        if (newLength < 0) {
	            throw new Error("newLength < 0");
	        }
	        return { span: span, newLength: newLength };
	    }
	    ts.createTextChangeRange = createTextChangeRange;
	    ts.unchangedTextChangeRange = createTextChangeRange(createTextSpan(0, 0), 0);
	    /**
	     * Called to merge all the changes that occurred across several versions of a script snapshot
	     * into a single change.  i.e. if a user keeps making successive edits to a script we will
	     * have a text change from V1 to V2, V2 to V3, ..., Vn.
	     *
	     * This function will then merge those changes into a single change range valid between V1 and
	     * Vn.
	     */
	    function collapseTextChangeRangesAcrossMultipleVersions(changes) {
	        if (changes.length === 0) {
	            return ts.unchangedTextChangeRange;
	        }
	        if (changes.length === 1) {
	            return changes[0];
	        }
	        // We change from talking about { { oldStart, oldLength }, newLength } to { oldStart, oldEnd, newEnd }
	        // as it makes things much easier to reason about.
	        var change0 = changes[0];
	        var oldStartN = change0.span.start;
	        var oldEndN = textSpanEnd(change0.span);
	        var newEndN = oldStartN + change0.newLength;
	        for (var i = 1; i < changes.length; i++) {
	            var nextChange = changes[i];
	            // Consider the following case:
	            // i.e. two edits.  The first represents the text change range { { 10, 50 }, 30 }.  i.e. The span starting
	            // at 10, with length 50 is reduced to length 30.  The second represents the text change range { { 30, 30 }, 40 }.
	            // i.e. the span starting at 30 with length 30 is increased to length 40.
	            //
	            //      0         10        20        30        40        50        60        70        80        90        100
	            //      -------------------------------------------------------------------------------------------------------
	            //                |                                                 /
	            //                |                                            /----
	            //  T1            |                                       /----
	            //                |                                  /----
	            //                |                             /----
	            //      -------------------------------------------------------------------------------------------------------
	            //                                     |                            \
	            //                                     |                               \
	            //   T2                                |                                 \
	            //                                     |                                   \
	            //                                     |                                      \
	            //      -------------------------------------------------------------------------------------------------------
	            //
	            // Merging these turns out to not be too difficult.  First, determining the new start of the change is trivial
	            // it's just the min of the old and new starts.  i.e.:
	            //
	            //      0         10        20        30        40        50        60        70        80        90        100
	            //      ------------------------------------------------------------*------------------------------------------
	            //                |                                                 /
	            //                |                                            /----
	            //  T1            |                                       /----
	            //                |                                  /----
	            //                |                             /----
	            //      ----------------------------------------$-------------------$------------------------------------------
	            //                .                    |                            \
	            //                .                    |                               \
	            //   T2           .                    |                                 \
	            //                .                    |                                   \
	            //                .                    |                                      \
	            //      ----------------------------------------------------------------------*--------------------------------
	            //
	            // (Note the dots represent the newly inferrred start.
	            // Determining the new and old end is also pretty simple.  Basically it boils down to paying attention to the
	            // absolute positions at the asterixes, and the relative change between the dollar signs. Basically, we see
	            // which if the two $'s precedes the other, and we move that one forward until they line up.  in this case that
	            // means:
	            //
	            //      0         10        20        30        40        50        60        70        80        90        100
	            //      --------------------------------------------------------------------------------*----------------------
	            //                |                                                                     /
	            //                |                                                                /----
	            //  T1            |                                                           /----
	            //                |                                                      /----
	            //                |                                                 /----
	            //      ------------------------------------------------------------$------------------------------------------
	            //                .                    |                            \
	            //                .                    |                               \
	            //   T2           .                    |                                 \
	            //                .                    |                                   \
	            //                .                    |                                      \
	            //      ----------------------------------------------------------------------*--------------------------------
	            //
	            // In other words (in this case), we're recognizing that the second edit happened after where the first edit
	            // ended with a delta of 20 characters (60 - 40).  Thus, if we go back in time to where the first edit started
	            // that's the same as if we started at char 80 instead of 60.
	            //
	            // As it so happens, the same logic applies if the second edit precedes the first edit.  In that case rahter
	            // than pusing the first edit forward to match the second, we'll push the second edit forward to match the
	            // first.
	            //
	            // In this case that means we have { oldStart: 10, oldEnd: 80, newEnd: 70 } or, in TextChangeRange
	            // semantics: { { start: 10, length: 70 }, newLength: 60 }
	            //
	            // The math then works out as follows.
	            // If we have { oldStart1, oldEnd1, newEnd1 } and { oldStart2, oldEnd2, newEnd2 } then we can compute the
	            // final result like so:
	            //
	            // {
	            //      oldStart3: Min(oldStart1, oldStart2),
	            //      oldEnd3  : Max(oldEnd1, oldEnd1 + (oldEnd2 - newEnd1)),
	            //      newEnd3  : Max(newEnd2, newEnd2 + (newEnd1 - oldEnd2))
	            // }
	            var oldStart1 = oldStartN;
	            var oldEnd1 = oldEndN;
	            var newEnd1 = newEndN;
	            var oldStart2 = nextChange.span.start;
	            var oldEnd2 = textSpanEnd(nextChange.span);
	            var newEnd2 = oldStart2 + nextChange.newLength;
	            oldStartN = Math.min(oldStart1, oldStart2);
	            oldEndN = Math.max(oldEnd1, oldEnd1 + (oldEnd2 - newEnd1));
	            newEndN = Math.max(newEnd2, newEnd2 + (newEnd1 - oldEnd2));
	        }
	        return createTextChangeRange(createTextSpanFromBounds(oldStartN, oldEndN), /*newLength:*/ newEndN - oldStartN);
	    }
	    ts.collapseTextChangeRangesAcrossMultipleVersions = collapseTextChangeRangesAcrossMultipleVersions;
	    function getTypeParameterOwner(d) {
	        if (d && d.kind === 138 /* TypeParameter */) {
	            for (var current = d; current; current = current.parent) {
	                if (ts.isFunctionLike(current) || ts.isClassLike(current) || current.kind === 218 /* InterfaceDeclaration */) {
	                    return current;
	                }
	            }
	        }
	    }
	    ts.getTypeParameterOwner = getTypeParameterOwner;
	    function isParameterPropertyDeclaration(node) {
	        return node.flags & 56 /* AccessibilityModifier */ && node.parent.kind === 145 /* Constructor */ && ts.isClassLike(node.parent.parent);
	    }
	    ts.isParameterPropertyDeclaration = isParameterPropertyDeclaration;
	})(ts || (ts = {}));
	/// <reference path="utilities.ts"/>
	/// <reference path="scanner.ts"/>
	var ts;
	(function (ts) {
	    /* @internal */ ts.parseTime = 0;
	    var NodeConstructor;
	    var SourceFileConstructor;
	    function createNode(kind, pos, end) {
	        if (kind === 251 /* SourceFile */) {
	            return new (SourceFileConstructor || (SourceFileConstructor = ts.objectAllocator.getSourceFileConstructor()))(kind, pos, end);
	        }
	        else {
	            return new (NodeConstructor || (NodeConstructor = ts.objectAllocator.getNodeConstructor()))(kind, pos, end);
	        }
	    }
	    ts.createNode = createNode;
	    function visitNode(cbNode, node) {
	        if (node) {
	            return cbNode(node);
	        }
	    }
	    function visitNodeArray(cbNodes, nodes) {
	        if (nodes) {
	            return cbNodes(nodes);
	        }
	    }
	    function visitEachNode(cbNode, nodes) {
	        if (nodes) {
	            for (var _i = 0, nodes_1 = nodes; _i < nodes_1.length; _i++) {
	                var node = nodes_1[_i];
	                var result = cbNode(node);
	                if (result) {
	                    return result;
	                }
	            }
	        }
	    }
	    // Invokes a callback for each child of the given node. The 'cbNode' callback is invoked for all child nodes
	    // stored in properties. If a 'cbNodes' callback is specified, it is invoked for embedded arrays; otherwise,
	    // embedded arrays are flattened and the 'cbNode' callback is invoked for each element. If a callback returns
	    // a truthy value, iteration stops and that value is returned. Otherwise, undefined is returned.
	    function forEachChild(node, cbNode, cbNodeArray) {
	        if (!node) {
	            return;
	        }
	        // The visitXXX functions could be written as local functions that close over the cbNode and cbNodeArray
	        // callback parameters, but that causes a closure allocation for each invocation with noticeable effects
	        // on performance.
	        var visitNodes = cbNodeArray ? visitNodeArray : visitEachNode;
	        var cbNodes = cbNodeArray || cbNode;
	        switch (node.kind) {
	            case 136 /* QualifiedName */:
	                return visitNode(cbNode, node.left) ||
	                    visitNode(cbNode, node.right);
	            case 138 /* TypeParameter */:
	                return visitNode(cbNode, node.name) ||
	                    visitNode(cbNode, node.constraint) ||
	                    visitNode(cbNode, node.expression);
	            case 249 /* ShorthandPropertyAssignment */:
	                return visitNodes(cbNodes, node.decorators) ||
	                    visitNodes(cbNodes, node.modifiers) ||
	                    visitNode(cbNode, node.name) ||
	                    visitNode(cbNode, node.questionToken) ||
	                    visitNode(cbNode, node.equalsToken) ||
	                    visitNode(cbNode, node.objectAssignmentInitializer);
	            case 139 /* Parameter */:
	            case 142 /* PropertyDeclaration */:
	            case 141 /* PropertySignature */:
	            case 248 /* PropertyAssignment */:
	            case 214 /* VariableDeclaration */:
	            case 166 /* BindingElement */:
	                return visitNodes(cbNodes, node.decorators) ||
	                    visitNodes(cbNodes, node.modifiers) ||
	                    visitNode(cbNode, node.propertyName) ||
	                    visitNode(cbNode, node.dotDotDotToken) ||
	                    visitNode(cbNode, node.name) ||
	                    visitNode(cbNode, node.questionToken) ||
	                    visitNode(cbNode, node.type) ||
	                    visitNode(cbNode, node.initializer);
	            case 153 /* FunctionType */:
	            case 154 /* ConstructorType */:
	            case 148 /* CallSignature */:
	            case 149 /* ConstructSignature */:
	            case 150 /* IndexSignature */:
	                return visitNodes(cbNodes, node.decorators) ||
	                    visitNodes(cbNodes, node.modifiers) ||
	                    visitNodes(cbNodes, node.typeParameters) ||
	                    visitNodes(cbNodes, node.parameters) ||
	                    visitNode(cbNode, node.type);
	            case 144 /* MethodDeclaration */:
	            case 143 /* MethodSignature */:
	            case 145 /* Constructor */:
	            case 146 /* GetAccessor */:
	            case 147 /* SetAccessor */:
	            case 176 /* FunctionExpression */:
	            case 216 /* FunctionDeclaration */:
	            case 177 /* ArrowFunction */:
	                return visitNodes(cbNodes, node.decorators) ||
	                    visitNodes(cbNodes, node.modifiers) ||
	                    visitNode(cbNode, node.asteriskToken) ||
	                    visitNode(cbNode, node.name) ||
	                    visitNode(cbNode, node.questionToken) ||
	                    visitNodes(cbNodes, node.typeParameters) ||
	                    visitNodes(cbNodes, node.parameters) ||
	                    visitNode(cbNode, node.type) ||
	                    visitNode(cbNode, node.equalsGreaterThanToken) ||
	                    visitNode(cbNode, node.body);
	            case 152 /* TypeReference */:
	                return visitNode(cbNode, node.typeName) ||
	                    visitNodes(cbNodes, node.typeArguments);
	            case 151 /* TypePredicate */:
	                return visitNode(cbNode, node.parameterName) ||
	                    visitNode(cbNode, node.type);
	            case 155 /* TypeQuery */:
	                return visitNode(cbNode, node.exprName);
	            case 156 /* TypeLiteral */:
	                return visitNodes(cbNodes, node.members);
	            case 157 /* ArrayType */:
	                return visitNode(cbNode, node.elementType);
	            case 158 /* TupleType */:
	                return visitNodes(cbNodes, node.elementTypes);
	            case 159 /* UnionType */:
	            case 160 /* IntersectionType */:
	                return visitNodes(cbNodes, node.types);
	            case 161 /* ParenthesizedType */:
	                return visitNode(cbNode, node.type);
	            case 164 /* ObjectBindingPattern */:
	            case 165 /* ArrayBindingPattern */:
	                return visitNodes(cbNodes, node.elements);
	            case 167 /* ArrayLiteralExpression */:
	                return visitNodes(cbNodes, node.elements);
	            case 168 /* ObjectLiteralExpression */:
	                return visitNodes(cbNodes, node.properties);
	            case 169 /* PropertyAccessExpression */:
	                return visitNode(cbNode, node.expression) ||
	                    visitNode(cbNode, node.dotToken) ||
	                    visitNode(cbNode, node.name);
	            case 170 /* ElementAccessExpression */:
	                return visitNode(cbNode, node.expression) ||
	                    visitNode(cbNode, node.argumentExpression);
	            case 171 /* CallExpression */:
	            case 172 /* NewExpression */:
	                return visitNode(cbNode, node.expression) ||
	                    visitNodes(cbNodes, node.typeArguments) ||
	                    visitNodes(cbNodes, node.arguments);
	            case 173 /* TaggedTemplateExpression */:
	                return visitNode(cbNode, node.tag) ||
	                    visitNode(cbNode, node.template);
	            case 174 /* TypeAssertionExpression */:
	                return visitNode(cbNode, node.type) ||
	                    visitNode(cbNode, node.expression);
	            case 175 /* ParenthesizedExpression */:
	                return visitNode(cbNode, node.expression);
	            case 178 /* DeleteExpression */:
	                return visitNode(cbNode, node.expression);
	            case 179 /* TypeOfExpression */:
	                return visitNode(cbNode, node.expression);
	            case 180 /* VoidExpression */:
	                return visitNode(cbNode, node.expression);
	            case 182 /* PrefixUnaryExpression */:
	                return visitNode(cbNode, node.operand);
	            case 187 /* YieldExpression */:
	                return visitNode(cbNode, node.asteriskToken) ||
	                    visitNode(cbNode, node.expression);
	            case 181 /* AwaitExpression */:
	                return visitNode(cbNode, node.expression);
	            case 183 /* PostfixUnaryExpression */:
	                return visitNode(cbNode, node.operand);
	            case 184 /* BinaryExpression */:
	                return visitNode(cbNode, node.left) ||
	                    visitNode(cbNode, node.operatorToken) ||
	                    visitNode(cbNode, node.right);
	            case 192 /* AsExpression */:
	                return visitNode(cbNode, node.expression) ||
	                    visitNode(cbNode, node.type);
	            case 185 /* ConditionalExpression */:
	                return visitNode(cbNode, node.condition) ||
	                    visitNode(cbNode, node.questionToken) ||
	                    visitNode(cbNode, node.whenTrue) ||
	                    visitNode(cbNode, node.colonToken) ||
	                    visitNode(cbNode, node.whenFalse);
	            case 188 /* SpreadElementExpression */:
	                return visitNode(cbNode, node.expression);
	            case 195 /* Block */:
	            case 222 /* ModuleBlock */:
	                return visitNodes(cbNodes, node.statements);
	            case 251 /* SourceFile */:
	                return visitNodes(cbNodes, node.statements) ||
	                    visitNode(cbNode, node.endOfFileToken);
	            case 196 /* VariableStatement */:
	                return visitNodes(cbNodes, node.decorators) ||
	                    visitNodes(cbNodes, node.modifiers) ||
	                    visitNode(cbNode, node.declarationList);
	            case 215 /* VariableDeclarationList */:
	                return visitNodes(cbNodes, node.declarations);
	            case 198 /* ExpressionStatement */:
	                return visitNode(cbNode, node.expression);
	            case 199 /* IfStatement */:
	                return visitNode(cbNode, node.expression) ||
	                    visitNode(cbNode, node.thenStatement) ||
	                    visitNode(cbNode, node.elseStatement);
	            case 200 /* DoStatement */:
	                return visitNode(cbNode, node.statement) ||
	                    visitNode(cbNode, node.expression);
	            case 201 /* WhileStatement */:
	                return visitNode(cbNode, node.expression) ||
	                    visitNode(cbNode, node.statement);
	            case 202 /* ForStatement */:
	                return visitNode(cbNode, node.initializer) ||
	                    visitNode(cbNode, node.condition) ||
	                    visitNode(cbNode, node.incrementor) ||
	                    visitNode(cbNode, node.statement);
	            case 203 /* ForInStatement */:
	                return visitNode(cbNode, node.initializer) ||
	                    visitNode(cbNode, node.expression) ||
	                    visitNode(cbNode, node.statement);
	            case 204 /* ForOfStatement */:
	                return visitNode(cbNode, node.initializer) ||
	                    visitNode(cbNode, node.expression) ||
	                    visitNode(cbNode, node.statement);
	            case 205 /* ContinueStatement */:
	            case 206 /* BreakStatement */:
	                return visitNode(cbNode, node.label);
	            case 207 /* ReturnStatement */:
	                return visitNode(cbNode, node.expression);
	            case 208 /* WithStatement */:
	                return visitNode(cbNode, node.expression) ||
	                    visitNode(cbNode, node.statement);
	            case 209 /* SwitchStatement */:
	                return visitNode(cbNode, node.expression) ||
	                    visitNode(cbNode, node.caseBlock);
	            case 223 /* CaseBlock */:
	                return visitNodes(cbNodes, node.clauses);
	            case 244 /* CaseClause */:
	                return visitNode(cbNode, node.expression) ||
	                    visitNodes(cbNodes, node.statements);
	            case 245 /* DefaultClause */:
	                return visitNodes(cbNodes, node.statements);
	            case 210 /* LabeledStatement */:
	                return visitNode(cbNode, node.label) ||
	                    visitNode(cbNode, node.statement);
	            case 211 /* ThrowStatement */:
	                return visitNode(cbNode, node.expression);
	            case 212 /* TryStatement */:
	                return visitNode(cbNode, node.tryBlock) ||
	                    visitNode(cbNode, node.catchClause) ||
	                    visitNode(cbNode, node.finallyBlock);
	            case 247 /* CatchClause */:
	                return visitNode(cbNode, node.variableDeclaration) ||
	                    visitNode(cbNode, node.block);
	            case 140 /* Decorator */:
	                return visitNode(cbNode, node.expression);
	            case 217 /* ClassDeclaration */:
	            case 189 /* ClassExpression */:
	                return visitNodes(cbNodes, node.decorators) ||
	                    visitNodes(cbNodes, node.modifiers) ||
	                    visitNode(cbNode, node.name) ||
	                    visitNodes(cbNodes, node.typeParameters) ||
	                    visitNodes(cbNodes, node.heritageClauses) ||
	                    visitNodes(cbNodes, node.members);
	            case 218 /* InterfaceDeclaration */:
	                return visitNodes(cbNodes, node.decorators) ||
	                    visitNodes(cbNodes, node.modifiers) ||
	                    visitNode(cbNode, node.name) ||
	                    visitNodes(cbNodes, node.typeParameters) ||
	                    visitNodes(cbNodes, node.heritageClauses) ||
	                    visitNodes(cbNodes, node.members);
	            case 219 /* TypeAliasDeclaration */:
	                return visitNodes(cbNodes, node.decorators) ||
	                    visitNodes(cbNodes, node.modifiers) ||
	                    visitNode(cbNode, node.name) ||
	                    visitNodes(cbNodes, node.typeParameters) ||
	                    visitNode(cbNode, node.type);
	            case 220 /* EnumDeclaration */:
	                return visitNodes(cbNodes, node.decorators) ||
	                    visitNodes(cbNodes, node.modifiers) ||
	                    visitNode(cbNode, node.name) ||
	                    visitNodes(cbNodes, node.members);
	            case 250 /* EnumMember */:
	                return visitNode(cbNode, node.name) ||
	                    visitNode(cbNode, node.initializer);
	            case 221 /* ModuleDeclaration */:
	                return visitNodes(cbNodes, node.decorators) ||
	                    visitNodes(cbNodes, node.modifiers) ||
	                    visitNode(cbNode, node.name) ||
	                    visitNode(cbNode, node.body);
	            case 224 /* ImportEqualsDeclaration */:
	                return visitNodes(cbNodes, node.decorators) ||
	                    visitNodes(cbNodes, node.modifiers) ||
	                    visitNode(cbNode, node.name) ||
	                    visitNode(cbNode, node.moduleReference);
	            case 225 /* ImportDeclaration */:
	                return visitNodes(cbNodes, node.decorators) ||
	                    visitNodes(cbNodes, node.modifiers) ||
	                    visitNode(cbNode, node.importClause) ||
	                    visitNode(cbNode, node.moduleSpecifier);
	            case 226 /* ImportClause */:
	                return visitNode(cbNode, node.name) ||
	                    visitNode(cbNode, node.namedBindings);
	            case 227 /* NamespaceImport */:
	                return visitNode(cbNode, node.name);
	            case 228 /* NamedImports */:
	            case 232 /* NamedExports */:
	                return visitNodes(cbNodes, node.elements);
	            case 231 /* ExportDeclaration */:
	                return visitNodes(cbNodes, node.decorators) ||
	                    visitNodes(cbNodes, node.modifiers) ||
	                    visitNode(cbNode, node.exportClause) ||
	                    visitNode(cbNode, node.moduleSpecifier);
	            case 229 /* ImportSpecifier */:
	            case 233 /* ExportSpecifier */:
	                return visitNode(cbNode, node.propertyName) ||
	                    visitNode(cbNode, node.name);
	            case 230 /* ExportAssignment */:
	                return visitNodes(cbNodes, node.decorators) ||
	                    visitNodes(cbNodes, node.modifiers) ||
	                    visitNode(cbNode, node.expression);
	            case 186 /* TemplateExpression */:
	                return visitNode(cbNode, node.head) || visitNodes(cbNodes, node.templateSpans);
	            case 193 /* TemplateSpan */:
	                return visitNode(cbNode, node.expression) || visitNode(cbNode, node.literal);
	            case 137 /* ComputedPropertyName */:
	                return visitNode(cbNode, node.expression);
	            case 246 /* HeritageClause */:
	                return visitNodes(cbNodes, node.types);
	            case 191 /* ExpressionWithTypeArguments */:
	                return visitNode(cbNode, node.expression) ||
	                    visitNodes(cbNodes, node.typeArguments);
	            case 235 /* ExternalModuleReference */:
	                return visitNode(cbNode, node.expression);
	            case 234 /* MissingDeclaration */:
	                return visitNodes(cbNodes, node.decorators);
	            case 236 /* JsxElement */:
	                return visitNode(cbNode, node.openingElement) ||
	                    visitNodes(cbNodes, node.children) ||
	                    visitNode(cbNode, node.closingElement);
	            case 237 /* JsxSelfClosingElement */:
	            case 238 /* JsxOpeningElement */:
	                return visitNode(cbNode, node.tagName) ||
	                    visitNodes(cbNodes, node.attributes);
	            case 241 /* JsxAttribute */:
	                return visitNode(cbNode, node.name) ||
	                    visitNode(cbNode, node.initializer);
	            case 242 /* JsxSpreadAttribute */:
	                return visitNode(cbNode, node.expression);
	            case 243 /* JsxExpression */:
	                return visitNode(cbNode, node.expression);
	            case 240 /* JsxClosingElement */:
	                return visitNode(cbNode, node.tagName);
	            case 252 /* JSDocTypeExpression */:
	                return visitNode(cbNode, node.type);
	            case 256 /* JSDocUnionType */:
	                return visitNodes(cbNodes, node.types);
	            case 257 /* JSDocTupleType */:
	                return visitNodes(cbNodes, node.types);
	            case 255 /* JSDocArrayType */:
	                return visitNode(cbNode, node.elementType);
	            case 259 /* JSDocNonNullableType */:
	                return visitNode(cbNode, node.type);
	            case 258 /* JSDocNullableType */:
	                return visitNode(cbNode, node.type);
	            case 260 /* JSDocRecordType */:
	                return visitNodes(cbNodes, node.members);
	            case 262 /* JSDocTypeReference */:
	                return visitNode(cbNode, node.name) ||
	                    visitNodes(cbNodes, node.typeArguments);
	            case 263 /* JSDocOptionalType */:
	                return visitNode(cbNode, node.type);
	            case 264 /* JSDocFunctionType */:
	                return visitNodes(cbNodes, node.parameters) ||
	                    visitNode(cbNode, node.type);
	            case 265 /* JSDocVariadicType */:
	                return visitNode(cbNode, node.type);
	            case 266 /* JSDocConstructorType */:
	                return visitNode(cbNode, node.type);
	            case 267 /* JSDocThisType */:
	                return visitNode(cbNode, node.type);
	            case 261 /* JSDocRecordMember */:
	                return visitNode(cbNode, node.name) ||
	                    visitNode(cbNode, node.type);
	            case 268 /* JSDocComment */:
	                return visitNodes(cbNodes, node.tags);
	            case 270 /* JSDocParameterTag */:
	                return visitNode(cbNode, node.preParameterName) ||
	                    visitNode(cbNode, node.typeExpression) ||
	                    visitNode(cbNode, node.postParameterName);
	            case 271 /* JSDocReturnTag */:
	                return visitNode(cbNode, node.typeExpression);
	            case 272 /* JSDocTypeTag */:
	                return visitNode(cbNode, node.typeExpression);
	            case 273 /* JSDocTemplateTag */:
	                return visitNodes(cbNodes, node.typeParameters);
	        }
	    }
	    ts.forEachChild = forEachChild;
	    function createSourceFile(fileName, sourceText, languageVersion, setParentNodes) {
	        if (setParentNodes === void 0) { setParentNodes = false; }
	        var start = new Date().getTime();
	        var result = Parser.parseSourceFile(fileName, sourceText, languageVersion, /*syntaxCursor*/ undefined, setParentNodes);
	        ts.parseTime += new Date().getTime() - start;
	        return result;
	    }
	    ts.createSourceFile = createSourceFile;
	    // Produces a new SourceFile for the 'newText' provided. The 'textChangeRange' parameter
	    // indicates what changed between the 'text' that this SourceFile has and the 'newText'.
	    // The SourceFile will be created with the compiler attempting to reuse as many nodes from
	    // this file as possible.
	    //
	    // Note: this function mutates nodes from this SourceFile. That means any existing nodes
	    // from this SourceFile that are being held onto may change as a result (including
	    // becoming detached from any SourceFile).  It is recommended that this SourceFile not
	    // be used once 'update' is called on it.
	    function updateSourceFile(sourceFile, newText, textChangeRange, aggressiveChecks) {
	        return IncrementalParser.updateSourceFile(sourceFile, newText, textChangeRange, aggressiveChecks);
	    }
	    ts.updateSourceFile = updateSourceFile;
	    /* @internal */
	    function parseIsolatedJSDocComment(content, start, length) {
	        return Parser.JSDocParser.parseIsolatedJSDocComment(content, start, length);
	    }
	    ts.parseIsolatedJSDocComment = parseIsolatedJSDocComment;
	    /* @internal */
	    // Exposed only for testing.
	    function parseJSDocTypeExpressionForTests(content, start, length) {
	        return Parser.JSDocParser.parseJSDocTypeExpressionForTests(content, start, length);
	    }
	    ts.parseJSDocTypeExpressionForTests = parseJSDocTypeExpressionForTests;
	    // Implement the parser as a singleton module.  We do this for perf reasons because creating
	    // parser instances can actually be expensive enough to impact us on projects with many source
	    // files.
	    var Parser;
	    (function (Parser) {
	        // Share a single scanner across all calls to parse a source file.  This helps speed things
	        // up by avoiding the cost of creating/compiling scanners over and over again.
	        var scanner = ts.createScanner(2 /* Latest */, /*skipTrivia*/ true);
	        var disallowInAndDecoratorContext = 1 /* DisallowIn */ | 4 /* Decorator */;
	        // capture constructors in 'initializeState' to avoid null checks
	        var NodeConstructor;
	        var SourceFileConstructor;
	        var sourceFile;
	        var parseDiagnostics;
	        var syntaxCursor;
	        var token;
	        var sourceText;
	        var nodeCount;
	        var identifiers;
	        var identifierCount;
	        var parsingContext;
	        // Flags that dictate what parsing context we're in.  For example:
	        // Whether or not we are in strict parsing mode.  All that changes in strict parsing mode is
	        // that some tokens that would be considered identifiers may be considered keywords.
	        //
	        // When adding more parser context flags, consider which is the more common case that the
	        // flag will be in.  This should be the 'false' state for that flag.  The reason for this is
	        // that we don't store data in our nodes unless the value is in the *non-default* state.  So,
	        // for example, more often than code 'allows-in' (or doesn't 'disallow-in').  We opt for
	        // 'disallow-in' set to 'false'.  Otherwise, if we had 'allowsIn' set to 'true', then almost
	        // all nodes would need extra state on them to store this info.
	        //
	        // Note:  'allowIn' and 'allowYield' track 1:1 with the [in] and [yield] concepts in the ES6
	        // grammar specification.
	        //
	        // An important thing about these context concepts.  By default they are effectively inherited
	        // while parsing through every grammar production.  i.e. if you don't change them, then when
	        // you parse a sub-production, it will have the same context values as the parent production.
	        // This is great most of the time.  After all, consider all the 'expression' grammar productions
	        // and how nearly all of them pass along the 'in' and 'yield' context values:
	        //
	        // EqualityExpression[In, Yield] :
	        //      RelationalExpression[?In, ?Yield]
	        //      EqualityExpression[?In, ?Yield] == RelationalExpression[?In, ?Yield]
	        //      EqualityExpression[?In, ?Yield] != RelationalExpression[?In, ?Yield]
	        //      EqualityExpression[?In, ?Yield] === RelationalExpression[?In, ?Yield]
	        //      EqualityExpression[?In, ?Yield] !== RelationalExpression[?In, ?Yield]
	        //
	        // Where you have to be careful is then understanding what the points are in the grammar
	        // where the values are *not* passed along.  For example:
	        //
	        // SingleNameBinding[Yield,GeneratorParameter]
	        //      [+GeneratorParameter]BindingIdentifier[Yield] Initializer[In]opt
	        //      [~GeneratorParameter]BindingIdentifier[?Yield]Initializer[In, ?Yield]opt
	        //
	        // Here this is saying that if the GeneratorParameter context flag is set, that we should
	        // explicitly set the 'yield' context flag to false before calling into the BindingIdentifier
	        // and we should explicitly unset the 'yield' context flag before calling into the Initializer.
	        // production.  Conversely, if the GeneratorParameter context flag is not set, then we
	        // should leave the 'yield' context flag alone.
	        //
	        // Getting this all correct is tricky and requires careful reading of the grammar to
	        // understand when these values should be changed versus when they should be inherited.
	        //
	        // Note: it should not be necessary to save/restore these flags during speculative/lookahead
	        // parsing.  These context flags are naturally stored and restored through normal recursive
	        // descent parsing and unwinding.
	        var contextFlags;
	        // Whether or not we've had a parse error since creating the last AST node.  If we have
	        // encountered an error, it will be stored on the next AST node we create.  Parse errors
	        // can be broken down into three categories:
	        //
	        // 1) An error that occurred during scanning.  For example, an unterminated literal, or a
	        //    character that was completely not understood.
	        //
	        // 2) A token was expected, but was not present.  This type of error is commonly produced
	        //    by the 'parseExpected' function.
	        //
	        // 3) A token was present that no parsing function was able to consume.  This type of error
	        //    only occurs in the 'abortParsingListOrMoveToNextToken' function when the parser
	        //    decides to skip the token.
	        //
	        // In all of these cases, we want to mark the next node as having had an error before it.
	        // With this mark, we can know in incremental settings if this node can be reused, or if
	        // we have to reparse it.  If we don't keep this information around, we may just reuse the
	        // node.  in that event we would then not produce the same errors as we did before, causing
	        // significant confusion problems.
	        //
	        // Note: it is necessary that this value be saved/restored during speculative/lookahead
	        // parsing.  During lookahead parsing, we will often create a node.  That node will have
	        // this value attached, and then this value will be set back to 'false'.  If we decide to
	        // rewind, we must get back to the same value we had prior to the lookahead.
	        //
	        // Note: any errors at the end of the file that do not precede a regular node, should get
	        // attached to the EOF token.
	        var parseErrorBeforeNextFinishedNode = false;
	        function parseSourceFile(fileName, _sourceText, languageVersion, _syntaxCursor, setParentNodes) {
	            var isJavaScriptFile = ts.hasJavaScriptFileExtension(fileName) || _sourceText.lastIndexOf("// @language=javascript", 0) === 0;
	            initializeState(fileName, _sourceText, languageVersion, isJavaScriptFile, _syntaxCursor);
	            var result = parseSourceFileWorker(fileName, languageVersion, setParentNodes);
	            clearState();
	            return result;
	        }
	        Parser.parseSourceFile = parseSourceFile;
	        function getLanguageVariant(fileName) {
	            // .tsx and .jsx files are treated as jsx language variant.
	            return ts.fileExtensionIs(fileName, ".tsx") || ts.fileExtensionIs(fileName, ".jsx") || ts.fileExtensionIs(fileName, ".js") ? 1 /* JSX */ : 0 /* Standard */;
	        }
	        function initializeState(fileName, _sourceText, languageVersion, isJavaScriptFile, _syntaxCursor) {
	            NodeConstructor = ts.objectAllocator.getNodeConstructor();
	            SourceFileConstructor = ts.objectAllocator.getSourceFileConstructor();
	            sourceText = _sourceText;
	            syntaxCursor = _syntaxCursor;
	            parseDiagnostics = [];
	            parsingContext = 0;
	            identifiers = {};
	            identifierCount = 0;
	            nodeCount = 0;
	            contextFlags = isJavaScriptFile ? 32 /* JavaScriptFile */ : 0 /* None */;
	            parseErrorBeforeNextFinishedNode = false;
	            // Initialize and prime the scanner before parsing the source elements.
	            scanner.setText(sourceText);
	            scanner.setOnError(scanError);
	            scanner.setScriptTarget(languageVersion);
	            scanner.setLanguageVariant(getLanguageVariant(fileName));
	        }
	        function clearState() {
	            // Clear out the text the scanner is pointing at, so it doesn't keep anything alive unnecessarily.
	            scanner.setText("");
	            scanner.setOnError(undefined);
	            // Clear any data.  We don't want to accidently hold onto it for too long.
	            parseDiagnostics = undefined;
	            sourceFile = undefined;
	            identifiers = undefined;
	            syntaxCursor = undefined;
	            sourceText = undefined;
	        }
	        function parseSourceFileWorker(fileName, languageVersion, setParentNodes) {
	            sourceFile = createSourceFile(fileName, languageVersion);
	            if (contextFlags & 32 /* JavaScriptFile */) {
	                sourceFile.parserContextFlags = 32 /* JavaScriptFile */;
	            }
	            // Prime the scanner.
	            token = nextToken();
	            processReferenceComments(sourceFile);
	            sourceFile.statements = parseList(0 /* SourceElements */, parseStatement);
	            ts.Debug.assert(token === 1 /* EndOfFileToken */);
	            sourceFile.endOfFileToken = parseTokenNode();
	            setExternalModuleIndicator(sourceFile);
	            sourceFile.nodeCount = nodeCount;
	            sourceFile.identifierCount = identifierCount;
	            sourceFile.identifiers = identifiers;
	            sourceFile.parseDiagnostics = parseDiagnostics;
	            if (setParentNodes) {
	                fixupParentReferences(sourceFile);
	            }
	            return sourceFile;
	        }
	        function addJSDocComment(node) {
	            if (contextFlags & 32 /* JavaScriptFile */) {
	                var comments = ts.getLeadingCommentRangesOfNode(node, sourceFile);
	                if (comments) {
	                    for (var _i = 0, comments_1 = comments; _i < comments_1.length; _i++) {
	                        var comment = comments_1[_i];
	                        var jsDocComment = JSDocParser.parseJSDocComment(node, comment.pos, comment.end - comment.pos);
	                        if (jsDocComment) {
	                            node.jsDocComment = jsDocComment;
	                        }
	                    }
	                }
	            }
	            return node;
	        }
	        function fixupParentReferences(sourceFile) {
	            // normally parent references are set during binding. However, for clients that only need
	            // a syntax tree, and no semantic features, then the binding process is an unnecessary
	            // overhead.  This functions allows us to set all the parents, without all the expense of
	            // binding.
	            var parent = sourceFile;
	            forEachChild(sourceFile, visitNode);
	            return;
	            function visitNode(n) {
	                // walk down setting parents that differ from the parent we think it should be.  This
	                // allows us to quickly bail out of setting parents for subtrees during incremental
	                // parsing
	                if (n.parent !== parent) {
	                    n.parent = parent;
	                    var saveParent = parent;
	                    parent = n;
	                    forEachChild(n, visitNode);
	                    parent = saveParent;
	                }
	            }
	        }
	        Parser.fixupParentReferences = fixupParentReferences;
	        function createSourceFile(fileName, languageVersion) {
	            // code from createNode is inlined here so createNode won't have to deal with special case of creating source files
	            // this is quite rare comparing to other nodes and createNode should be as fast as possible
	            var sourceFile = new SourceFileConstructor(251 /* SourceFile */, /*pos*/ 0, /* end */ sourceText.length);
	            nodeCount++;
	            sourceFile.text = sourceText;
	            sourceFile.bindDiagnostics = [];
	            sourceFile.languageVersion = languageVersion;
	            sourceFile.fileName = ts.normalizePath(fileName);
	            sourceFile.flags = ts.fileExtensionIs(sourceFile.fileName, ".d.ts") ? 4096 /* DeclarationFile */ : 0;
	            sourceFile.languageVariant = getLanguageVariant(sourceFile.fileName);
	            return sourceFile;
	        }
	        function setContextFlag(val, flag) {
	            if (val) {
	                contextFlags |= flag;
	            }
	            else {
	                contextFlags &= ~flag;
	            }
	        }
	        function setDisallowInContext(val) {
	            setContextFlag(val, 1 /* DisallowIn */);
	        }
	        function setYieldContext(val) {
	            setContextFlag(val, 2 /* Yield */);
	        }
	        function setDecoratorContext(val) {
	            setContextFlag(val, 4 /* Decorator */);
	        }
	        function setAwaitContext(val) {
	            setContextFlag(val, 8 /* Await */);
	        }
	        function doOutsideOfContext(context, func) {
	            // contextFlagsToClear will contain only the context flags that are
	            // currently set that we need to temporarily clear
	            // We don't just blindly reset to the previous flags to ensure
	            // that we do not mutate cached flags for the incremental
	            // parser (ThisNodeHasError, ThisNodeOrAnySubNodesHasError, and
	            // HasAggregatedChildData).
	            var contextFlagsToClear = context & contextFlags;
	            if (contextFlagsToClear) {
	                // clear the requested context flags
	                setContextFlag(/*val*/ false, contextFlagsToClear);
	                var result = func();
	                // restore the context flags we just cleared
	                setContextFlag(/*val*/ true, contextFlagsToClear);
	                return result;
	            }
	            // no need to do anything special as we are not in any of the requested contexts
	            return func();
	        }
	        function doInsideOfContext(context, func) {
	            // contextFlagsToSet will contain only the context flags that
	            // are not currently set that we need to temporarily enable.
	            // We don't just blindly reset to the previous flags to ensure
	            // that we do not mutate cached flags for the incremental
	            // parser (ThisNodeHasError, ThisNodeOrAnySubNodesHasError, and
	            // HasAggregatedChildData).
	            var contextFlagsToSet = context & ~contextFlags;
	            if (contextFlagsToSet) {
	                // set the requested context flags
	                setContextFlag(/*val*/ true, contextFlagsToSet);
	                var result = func();
	                // reset the context flags we just set
	                setContextFlag(/*val*/ false, contextFlagsToSet);
	                return result;
	            }
	            // no need to do anything special as we are already in all of the requested contexts
	            return func();
	        }
	        function allowInAnd(func) {
	            return doOutsideOfContext(1 /* DisallowIn */, func);
	        }
	        function disallowInAnd(func) {
	            return doInsideOfContext(1 /* DisallowIn */, func);
	        }
	        function doInYieldContext(func) {
	            return doInsideOfContext(2 /* Yield */, func);
	        }
	        function doInDecoratorContext(func) {
	            return doInsideOfContext(4 /* Decorator */, func);
	        }
	        function doInAwaitContext(func) {
	            return doInsideOfContext(8 /* Await */, func);
	        }
	        function doOutsideOfAwaitContext(func) {
	            return doOutsideOfContext(8 /* Await */, func);
	        }
	        function doInYieldAndAwaitContext(func) {
	            return doInsideOfContext(2 /* Yield */ | 8 /* Await */, func);
	        }
	        function inContext(flags) {
	            return (contextFlags & flags) !== 0;
	        }
	        function inYieldContext() {
	            return inContext(2 /* Yield */);
	        }
	        function inDisallowInContext() {
	            return inContext(1 /* DisallowIn */);
	        }
	        function inDecoratorContext() {
	            return inContext(4 /* Decorator */);
	        }
	        function inAwaitContext() {
	            return inContext(8 /* Await */);
	        }
	        function parseErrorAtCurrentToken(message, arg0) {
	            var start = scanner.getTokenPos();
	            var length = scanner.getTextPos() - start;
	            parseErrorAtPosition(start, length, message, arg0);
	        }
	        function parseErrorAtPosition(start, length, message, arg0) {
	            // Don't report another error if it would just be at the same position as the last error.
	            var lastError = ts.lastOrUndefined(parseDiagnostics);
	            if (!lastError || start !== lastError.start) {
	                parseDiagnostics.push(ts.createFileDiagnostic(sourceFile, start, length, message, arg0));
	            }
	            // Mark that we've encountered an error.  We'll set an appropriate bit on the next
	            // node we finish so that it can't be reused incrementally.
	            parseErrorBeforeNextFinishedNode = true;
	        }
	        function scanError(message, length) {
	            var pos = scanner.getTextPos();
	            parseErrorAtPosition(pos, length || 0, message);
	        }
	        function getNodePos() {
	            return scanner.getStartPos();
	        }
	        function getNodeEnd() {
	            return scanner.getStartPos();
	        }
	        function nextToken() {
	            return token = scanner.scan();
	        }
	        function reScanGreaterToken() {
	            return token = scanner.reScanGreaterToken();
	        }
	        function reScanSlashToken() {
	            return token = scanner.reScanSlashToken();
	        }
	        function reScanTemplateToken() {
	            return token = scanner.reScanTemplateToken();
	        }
	        function scanJsxIdentifier() {
	            return token = scanner.scanJsxIdentifier();
	        }
	        function scanJsxText() {
	            return token = scanner.scanJsxToken();
	        }
	        function speculationHelper(callback, isLookAhead) {
	            // Keep track of the state we'll need to rollback to if lookahead fails (or if the
	            // caller asked us to always reset our state).
	            var saveToken = token;
	            var saveParseDiagnosticsLength = parseDiagnostics.length;
	            var saveParseErrorBeforeNextFinishedNode = parseErrorBeforeNextFinishedNode;
	            // Note: it is not actually necessary to save/restore the context flags here.  That's
	            // because the saving/restoring of these flags happens naturally through the recursive
	            // descent nature of our parser.  However, we still store this here just so we can
	            // assert that that invariant holds.
	            var saveContextFlags = contextFlags;
	            // If we're only looking ahead, then tell the scanner to only lookahead as well.
	            // Otherwise, if we're actually speculatively parsing, then tell the scanner to do the
	            // same.
	            var result = isLookAhead
	                ? scanner.lookAhead(callback)
	                : scanner.tryScan(callback);
	            ts.Debug.assert(saveContextFlags === contextFlags);
	            // If our callback returned something 'falsy' or we're just looking ahead,
	            // then unconditionally restore us to where we were.
	            if (!result || isLookAhead) {
	                token = saveToken;
	                parseDiagnostics.length = saveParseDiagnosticsLength;
	                parseErrorBeforeNextFinishedNode = saveParseErrorBeforeNextFinishedNode;
	            }
	            return result;
	        }
	        /** Invokes the provided callback then unconditionally restores the parser to the state it
	         * was in immediately prior to invoking the callback.  The result of invoking the callback
	         * is returned from this function.
	         */
	        function lookAhead(callback) {
	            return speculationHelper(callback, /*isLookAhead*/ true);
	        }
	        /** Invokes the provided callback.  If the callback returns something falsy, then it restores
	         * the parser to the state it was in immediately prior to invoking the callback.  If the
	         * callback returns something truthy, then the parser state is not rolled back.  The result
	         * of invoking the callback is returned from this function.
	         */
	        function tryParse(callback) {
	            return speculationHelper(callback, /*isLookAhead*/ false);
	        }
	        // Ignore strict mode flag because we will report an error in type checker instead.
	        function isIdentifier() {
	            if (token === 69 /* Identifier */) {
	                return true;
	            }
	            // If we have a 'yield' keyword, and we're in the [yield] context, then 'yield' is
	            // considered a keyword and is not an identifier.
	            if (token === 114 /* YieldKeyword */ && inYieldContext()) {
	                return false;
	            }
	            // If we have a 'await' keyword, and we're in the [Await] context, then 'await' is
	            // considered a keyword and is not an identifier.
	            if (token === 119 /* AwaitKeyword */ && inAwaitContext()) {
	                return false;
	            }
	            return token > 105 /* LastReservedWord */;
	        }
	        function parseExpected(kind, diagnosticMessage, shouldAdvance) {
	            if (shouldAdvance === void 0) { shouldAdvance = true; }
	            if (token === kind) {
	                if (shouldAdvance) {
	                    nextToken();
	                }
	                return true;
	            }
	            // Report specific message if provided with one.  Otherwise, report generic fallback message.
	            if (diagnosticMessage) {
	                parseErrorAtCurrentToken(diagnosticMessage);
	            }
	            else {
	                parseErrorAtCurrentToken(ts.Diagnostics._0_expected, ts.tokenToString(kind));
	            }
	            return false;
	        }
	        function parseOptional(t) {
	            if (token === t) {
	                nextToken();
	                return true;
	            }
	            return false;
	        }
	        function parseOptionalToken(t) {
	            if (token === t) {
	                return parseTokenNode();
	            }
	            return undefined;
	        }
	        function parseExpectedToken(t, reportAtCurrentPosition, diagnosticMessage, arg0) {
	            return parseOptionalToken(t) ||
	                createMissingNode(t, reportAtCurrentPosition, diagnosticMessage, arg0);
	        }
	        function parseTokenNode() {
	            var node = createNode(token);
	            nextToken();
	            return finishNode(node);
	        }
	        function canParseSemicolon() {
	            // If there's a real semicolon, then we can always parse it out.
	            if (token === 23 /* SemicolonToken */) {
	                return true;
	            }
	            // We can parse out an optional semicolon in ASI cases in the following cases.
	            return token === 16 /* CloseBraceToken */ || token === 1 /* EndOfFileToken */ || scanner.hasPrecedingLineBreak();
	        }
	        function parseSemicolon() {
	            if (canParseSemicolon()) {
	                if (token === 23 /* SemicolonToken */) {
	                    // consume the semicolon if it was explicitly provided.
	                    nextToken();
	                }
	                return true;
	            }
	            else {
	                return parseExpected(23 /* SemicolonToken */);
	            }
	        }
	        // note: this function creates only node
	        function createNode(kind, pos) {
	            nodeCount++;
	            if (!(pos >= 0)) {
	                pos = scanner.getStartPos();
	            }
	            return new NodeConstructor(kind, pos, pos);
	        }
	        function finishNode(node, end) {
	            node.end = end === undefined ? scanner.getStartPos() : end;
	            if (contextFlags) {
	                node.parserContextFlags = contextFlags;
	            }
	            // Keep track on the node if we encountered an error while parsing it.  If we did, then
	            // we cannot reuse the node incrementally.  Once we've marked this node, clear out the
	            // flag so that we don't mark any subsequent nodes.
	            if (parseErrorBeforeNextFinishedNode) {
	                parseErrorBeforeNextFinishedNode = false;
	                node.parserContextFlags |= 16 /* ThisNodeHasError */;
	            }
	            return node;
	        }
	        function createMissingNode(kind, reportAtCurrentPosition, diagnosticMessage, arg0) {
	            if (reportAtCurrentPosition) {
	                parseErrorAtPosition(scanner.getStartPos(), 0, diagnosticMessage, arg0);
	            }
	            else {
	                parseErrorAtCurrentToken(diagnosticMessage, arg0);
	            }
	            var result = createNode(kind, scanner.getStartPos());
	            result.text = "";
	            return finishNode(result);
	        }
	        function internIdentifier(text) {
	            text = ts.escapeIdentifier(text);
	            return ts.hasProperty(identifiers, text) ? identifiers[text] : (identifiers[text] = text);
	        }
	        // An identifier that starts with two underscores has an extra underscore character prepended to it to avoid issues
	        // with magic property names like '__proto__'. The 'identifiers' object is used to share a single string instance for
	        // each identifier in order to reduce memory consumption.
	        function createIdentifier(isIdentifier, diagnosticMessage) {
	            identifierCount++;
	            if (isIdentifier) {
	                var node = createNode(69 /* Identifier */);
	                // Store original token kind if it is not just an Identifier so we can report appropriate error later in type checker
	                if (token !== 69 /* Identifier */) {
	                    node.originalKeywordKind = token;
	                }
	                node.text = internIdentifier(scanner.getTokenValue());
	                nextToken();
	                return finishNode(node);
	            }
	            return createMissingNode(69 /* Identifier */, /*reportAtCurrentPosition*/ false, diagnosticMessage || ts.Diagnostics.Identifier_expected);
	        }
	        function parseIdentifier(diagnosticMessage) {
	            return createIdentifier(isIdentifier(), diagnosticMessage);
	        }
	        function parseIdentifierName() {
	            return createIdentifier(ts.tokenIsIdentifierOrKeyword(token));
	        }
	        function isLiteralPropertyName() {
	            return ts.tokenIsIdentifierOrKeyword(token) ||
	                token === 9 /* StringLiteral */ ||
	                token === 8 /* NumericLiteral */;
	        }
	        function parsePropertyNameWorker(allowComputedPropertyNames) {
	            if (token === 9 /* StringLiteral */ || token === 8 /* NumericLiteral */) {
	                return parseLiteralNode(/*internName*/ true);
	            }
	            if (allowComputedPropertyNames && token === 19 /* OpenBracketToken */) {
	                return parseComputedPropertyName();
	            }
	            return parseIdentifierName();
	        }
	        function parsePropertyName() {
	            return parsePropertyNameWorker(/*allowComputedPropertyNames*/ true);
	        }
	        function parseSimplePropertyName() {
	            return parsePropertyNameWorker(/*allowComputedPropertyNames*/ false);
	        }
	        function isSimplePropertyName() {
	            return token === 9 /* StringLiteral */ || token === 8 /* NumericLiteral */ || ts.tokenIsIdentifierOrKeyword(token);
	        }
	        function parseComputedPropertyName() {
	            // PropertyName [Yield]:
	            //      LiteralPropertyName
	            //      ComputedPropertyName[?Yield]
	            var node = createNode(137 /* ComputedPropertyName */);
	            parseExpected(19 /* OpenBracketToken */);
	            // We parse any expression (including a comma expression). But the grammar
	            // says that only an assignment expression is allowed, so the grammar checker
	            // will error if it sees a comma expression.
	            node.expression = allowInAnd(parseExpression);
	            parseExpected(20 /* CloseBracketToken */);
	            return finishNode(node);
	        }
	        function parseContextualModifier(t) {
	            return token === t && tryParse(nextTokenCanFollowModifier);
	        }
	        function nextTokenIsOnSameLineAndCanFollowModifier() {
	            nextToken();
	            if (scanner.hasPrecedingLineBreak()) {
	                return false;
	            }
	            return canFollowModifier();
	        }
	        function nextTokenCanFollowModifier() {
	            if (token === 74 /* ConstKeyword */) {
	                // 'const' is only a modifier if followed by 'enum'.
	                return nextToken() === 81 /* EnumKeyword */;
	            }
	            if (token === 82 /* ExportKeyword */) {
	                nextToken();
	                if (token === 77 /* DefaultKeyword */) {
	                    return lookAhead(nextTokenIsClassOrFunction);
	                }
	                return token !== 37 /* AsteriskToken */ && token !== 15 /* OpenBraceToken */ && canFollowModifier();
	            }
	            if (token === 77 /* DefaultKeyword */) {
	                return nextTokenIsClassOrFunction();
	            }
	            if (token === 113 /* StaticKeyword */) {
	                nextToken();
	                return canFollowModifier();
	            }
	            return nextTokenIsOnSameLineAndCanFollowModifier();
	        }
	        function parseAnyContextualModifier() {
	            return ts.isModifierKind(token) && tryParse(nextTokenCanFollowModifier);
	        }
	        function canFollowModifier() {
	            return token === 19 /* OpenBracketToken */
	                || token === 15 /* OpenBraceToken */
	                || token === 37 /* AsteriskToken */
	                || isLiteralPropertyName();
	        }
	        function nextTokenIsClassOrFunction() {
	            nextToken();
	            return token === 73 /* ClassKeyword */ || token === 87 /* FunctionKeyword */;
	        }
	        // True if positioned at the start of a list element
	        function isListElement(parsingContext, inErrorRecovery) {
	            var node = currentNode(parsingContext);
	            if (node) {
	                return true;
	            }
	            switch (parsingContext) {
	                case 0 /* SourceElements */:
	                case 1 /* BlockStatements */:
	                case 3 /* SwitchClauseStatements */:
	                    // If we're in error recovery, then we don't want to treat ';' as an empty statement.
	                    // The problem is that ';' can show up in far too many contexts, and if we see one
	                    // and assume it's a statement, then we may bail out inappropriately from whatever
	                    // we're parsing.  For example, if we have a semicolon in the middle of a class, then
	                    // we really don't want to assume the class is over and we're on a statement in the
	                    // outer module.  We just want to consume and move on.
	                    return !(token === 23 /* SemicolonToken */ && inErrorRecovery) && isStartOfStatement();
	                case 2 /* SwitchClauses */:
	                    return token === 71 /* CaseKeyword */ || token === 77 /* DefaultKeyword */;
	                case 4 /* TypeMembers */:
	                    return isStartOfTypeMember();
	                case 5 /* ClassMembers */:
	                    // We allow semicolons as class elements (as specified by ES6) as long as we're
	                    // not in error recovery.  If we're in error recovery, we don't want an errant
	                    // semicolon to be treated as a class member (since they're almost always used
	                    // for statements.
	                    return lookAhead(isClassMemberStart) || (token === 23 /* SemicolonToken */ && !inErrorRecovery);
	                case 6 /* EnumMembers */:
	                    // Include open bracket computed properties. This technically also lets in indexers,
	                    // which would be a candidate for improved error reporting.
	                    return token === 19 /* OpenBracketToken */ || isLiteralPropertyName();
	                case 12 /* ObjectLiteralMembers */:
	                    return token === 19 /* OpenBracketToken */ || token === 37 /* AsteriskToken */ || isLiteralPropertyName();
	                case 9 /* ObjectBindingElements */:
	                    return token === 19 /* OpenBracketToken */ || isLiteralPropertyName();
	                case 7 /* HeritageClauseElement */:
	                    // If we see { } then only consume it as an expression if it is followed by , or {
	                    // That way we won't consume the body of a class in its heritage clause.
	                    if (token === 15 /* OpenBraceToken */) {
	                        return lookAhead(isValidHeritageClauseObjectLiteral);
	                    }
	                    if (!inErrorRecovery) {
	                        return isStartOfLeftHandSideExpression() && !isHeritageClauseExtendsOrImplementsKeyword();
	                    }
	                    else {
	                        // If we're in error recovery we tighten up what we're willing to match.
	                        // That way we don't treat something like "this" as a valid heritage clause
	                        // element during recovery.
	                        return isIdentifier() && !isHeritageClauseExtendsOrImplementsKeyword();
	                    }
	                case 8 /* VariableDeclarations */:
	                    return isIdentifierOrPattern();
	                case 10 /* ArrayBindingElements */:
	                    return token === 24 /* CommaToken */ || token === 22 /* DotDotDotToken */ || isIdentifierOrPattern();
	                case 17 /* TypeParameters */:
	                    return isIdentifier();
	                case 11 /* ArgumentExpressions */:
	                case 15 /* ArrayLiteralMembers */:
	                    return token === 24 /* CommaToken */ || token === 22 /* DotDotDotToken */ || isStartOfExpression();
	                case 16 /* Parameters */:
	                    return isStartOfParameter();
	                case 18 /* TypeArguments */:
	                case 19 /* TupleElementTypes */:
	                    return token === 24 /* CommaToken */ || isStartOfType();
	                case 20 /* HeritageClauses */:
	                    return isHeritageClause();
	                case 21 /* ImportOrExportSpecifiers */:
	                    return ts.tokenIsIdentifierOrKeyword(token);
	                case 13 /* JsxAttributes */:
	                    return ts.tokenIsIdentifierOrKeyword(token) || token === 15 /* OpenBraceToken */;
	                case 14 /* JsxChildren */:
	                    return true;
	                case 22 /* JSDocFunctionParameters */:
	                case 23 /* JSDocTypeArguments */:
	                case 25 /* JSDocTupleTypes */:
	                    return JSDocParser.isJSDocType();
	                case 24 /* JSDocRecordMembers */:
	                    return isSimplePropertyName();
	            }
	            ts.Debug.fail("Non-exhaustive case in 'isListElement'.");
	        }
	        function isValidHeritageClauseObjectLiteral() {
	            ts.Debug.assert(token === 15 /* OpenBraceToken */);
	            if (nextToken() === 16 /* CloseBraceToken */) {
	                // if we see  "extends {}" then only treat the {} as what we're extending (and not
	                // the class body) if we have:
	                //
	                //      extends {} {
	                //      extends {},
	                //      extends {} extends
	                //      extends {} implements
	                var next = nextToken();
	                return next === 24 /* CommaToken */ || next === 15 /* OpenBraceToken */ || next === 83 /* ExtendsKeyword */ || next === 106 /* ImplementsKeyword */;
	            }
	            return true;
	        }
	        function nextTokenIsIdentifier() {
	            nextToken();
	            return isIdentifier();
	        }
	        function nextTokenIsIdentifierOrKeyword() {
	            nextToken();
	            return ts.tokenIsIdentifierOrKeyword(token);
	        }
	        function isHeritageClauseExtendsOrImplementsKeyword() {
	            if (token === 106 /* ImplementsKeyword */ ||
	                token === 83 /* ExtendsKeyword */) {
	                return lookAhead(nextTokenIsStartOfExpression);
	            }
	            return false;
	        }
	        function nextTokenIsStartOfExpression() {
	            nextToken();
	            return isStartOfExpression();
	        }
	        // True if positioned at a list terminator
	        function isListTerminator(kind) {
	            if (token === 1 /* EndOfFileToken */) {
	                // Being at the end of the file ends all lists.
	                return true;
	            }
	            switch (kind) {
	                case 1 /* BlockStatements */:
	                case 2 /* SwitchClauses */:
	                case 4 /* TypeMembers */:
	                case 5 /* ClassMembers */:
	                case 6 /* EnumMembers */:
	                case 12 /* ObjectLiteralMembers */:
	                case 9 /* ObjectBindingElements */:
	                case 21 /* ImportOrExportSpecifiers */:
	                    return token === 16 /* CloseBraceToken */;
	                case 3 /* SwitchClauseStatements */:
	                    return token === 16 /* CloseBraceToken */ || token === 71 /* CaseKeyword */ || token === 77 /* DefaultKeyword */;
	                case 7 /* HeritageClauseElement */:
	                    return token === 15 /* OpenBraceToken */ || token === 83 /* ExtendsKeyword */ || token === 106 /* ImplementsKeyword */;
	                case 8 /* VariableDeclarations */:
	                    return isVariableDeclaratorListTerminator();
	                case 17 /* TypeParameters */:
	                    // Tokens other than '>' are here for better error recovery
	                    return token === 27 /* GreaterThanToken */ || token === 17 /* OpenParenToken */ || token === 15 /* OpenBraceToken */ || token === 83 /* ExtendsKeyword */ || token === 106 /* ImplementsKeyword */;
	                case 11 /* ArgumentExpressions */:
	                    // Tokens other than ')' are here for better error recovery
	                    return token === 18 /* CloseParenToken */ || token === 23 /* SemicolonToken */;
	                case 15 /* ArrayLiteralMembers */:
	                case 19 /* TupleElementTypes */:
	                case 10 /* ArrayBindingElements */:
	                    return token === 20 /* CloseBracketToken */;
	                case 16 /* Parameters */:
	                    // Tokens other than ')' and ']' (the latter for index signatures) are here for better error recovery
	                    return token === 18 /* CloseParenToken */ || token === 20 /* CloseBracketToken */ /*|| token === SyntaxKind.OpenBraceToken*/;
	                case 18 /* TypeArguments */:
	                    // Tokens other than '>' are here for better error recovery
	                    return token === 27 /* GreaterThanToken */ || token === 17 /* OpenParenToken */;
	                case 20 /* HeritageClauses */:
	                    return token === 15 /* OpenBraceToken */ || token === 16 /* CloseBraceToken */;
	                case 13 /* JsxAttributes */:
	                    return token === 27 /* GreaterThanToken */ || token === 39 /* SlashToken */;
	                case 14 /* JsxChildren */:
	                    return token === 25 /* LessThanToken */ && lookAhead(nextTokenIsSlash);
	                case 22 /* JSDocFunctionParameters */:
	                    return token === 18 /* CloseParenToken */ || token === 54 /* ColonToken */ || token === 16 /* CloseBraceToken */;
	                case 23 /* JSDocTypeArguments */:
	                    return token === 27 /* GreaterThanToken */ || token === 16 /* CloseBraceToken */;
	                case 25 /* JSDocTupleTypes */:
	                    return token === 20 /* CloseBracketToken */ || token === 16 /* CloseBraceToken */;
	                case 24 /* JSDocRecordMembers */:
	                    return token === 16 /* CloseBraceToken */;
	            }
	        }
	        function isVariableDeclaratorListTerminator() {
	            // If we can consume a semicolon (either explicitly, or with ASI), then consider us done
	            // with parsing the list of  variable declarators.
	            if (canParseSemicolon()) {
	                return true;
	            }
	            // in the case where we're parsing the variable declarator of a 'for-in' statement, we
	            // are done if we see an 'in' keyword in front of us. Same with for-of
	            if (isInOrOfKeyword(token)) {
	                return true;
	            }
	            // ERROR RECOVERY TWEAK:
	            // For better error recovery, if we see an '=>' then we just stop immediately.  We've got an
	            // arrow function here and it's going to be very unlikely that we'll resynchronize and get
	            // another variable declaration.
	            if (token === 34 /* EqualsGreaterThanToken */) {
	                return true;
	            }
	            // Keep trying to parse out variable declarators.
	            return false;
	        }
	        // True if positioned at element or terminator of the current list or any enclosing list
	        function isInSomeParsingContext() {
	            for (var kind = 0; kind < 26 /* Count */; kind++) {
	                if (parsingContext & (1 << kind)) {
	                    if (isListElement(kind, /*inErrorRecovery*/ true) || isListTerminator(kind)) {
	                        return true;
	                    }
	                }
	            }
	            return false;
	        }
	        // Parses a list of elements
	        function parseList(kind, parseElement) {
	            var saveParsingContext = parsingContext;
	            parsingContext |= 1 << kind;
	            var result = [];
	            result.pos = getNodePos();
	            while (!isListTerminator(kind)) {
	                if (isListElement(kind, /*inErrorRecovery*/ false)) {
	                    var element = parseListElement(kind, parseElement);
	                    result.push(element);
	                    continue;
	                }
	                if (abortParsingListOrMoveToNextToken(kind)) {
	                    break;
	                }
	            }
	            result.end = getNodeEnd();
	            parsingContext = saveParsingContext;
	            return result;
	        }
	        function parseListElement(parsingContext, parseElement) {
	            var node = currentNode(parsingContext);
	            if (node) {
	                return consumeNode(node);
	            }
	            return parseElement();
	        }
	        function currentNode(parsingContext) {
	            // If there is an outstanding parse error that we've encountered, but not attached to
	            // some node, then we cannot get a node from the old source tree.  This is because we
	            // want to mark the next node we encounter as being unusable.
	            //
	            // Note: This may be too conservative.  Perhaps we could reuse the node and set the bit
	            // on it (or its leftmost child) as having the error.  For now though, being conservative
	            // is nice and likely won't ever affect perf.
	            if (parseErrorBeforeNextFinishedNode) {
	                return undefined;
	            }
	            if (!syntaxCursor) {
	                // if we don't have a cursor, we could never return a node from the old tree.
	                return undefined;
	            }
	            var node = syntaxCursor.currentNode(scanner.getStartPos());
	            // Can't reuse a missing node.
	            if (ts.nodeIsMissing(node)) {
	                return undefined;
	            }
	            // Can't reuse a node that intersected the change range.
	            if (node.intersectsChange) {
	                return undefined;
	            }
	            // Can't reuse a node that contains a parse error.  This is necessary so that we
	            // produce the same set of errors again.
	            if (ts.containsParseError(node)) {
	                return undefined;
	            }
	            // We can only reuse a node if it was parsed under the same strict mode that we're
	            // currently in.  i.e. if we originally parsed a node in non-strict mode, but then
	            // the user added 'using strict' at the top of the file, then we can't use that node
	            // again as the presense of strict mode may cause us to parse the tokens in the file
	            // differetly.
	            //
	            // Note: we *can* reuse tokens when the strict mode changes.  That's because tokens
	            // are unaffected by strict mode.  It's just the parser will decide what to do with it
	            // differently depending on what mode it is in.
	            //
	            // This also applies to all our other context flags as well.
	            var nodeContextFlags = node.parserContextFlags & 31 /* ParserGeneratedFlags */;
	            if (nodeContextFlags !== contextFlags) {
	                return undefined;
	            }
	            // Ok, we have a node that looks like it could be reused.  Now verify that it is valid
	            // in the currest list parsing context that we're currently at.
	            if (!canReuseNode(node, parsingContext)) {
	                return undefined;
	            }
	            return node;
	        }
	        function consumeNode(node) {
	            // Move the scanner so it is after the node we just consumed.
	            scanner.setTextPos(node.end);
	            nextToken();
	            return node;
	        }
	        function canReuseNode(node, parsingContext) {
	            switch (parsingContext) {
	                case 5 /* ClassMembers */:
	                    return isReusableClassMember(node);
	                case 2 /* SwitchClauses */:
	                    return isReusableSwitchClause(node);
	                case 0 /* SourceElements */:
	                case 1 /* BlockStatements */:
	                case 3 /* SwitchClauseStatements */:
	                    return isReusableStatement(node);
	                case 6 /* EnumMembers */:
	                    return isReusableEnumMember(node);
	                case 4 /* TypeMembers */:
	                    return isReusableTypeMember(node);
	                case 8 /* VariableDeclarations */:
	                    return isReusableVariableDeclaration(node);
	                case 16 /* Parameters */:
	                    return isReusableParameter(node);
	                // Any other lists we do not care about reusing nodes in.  But feel free to add if
	                // you can do so safely.  Danger areas involve nodes that may involve speculative
	                // parsing.  If speculative parsing is involved with the node, then the range the
	                // parser reached while looking ahead might be in the edited range (see the example
	                // in canReuseVariableDeclaratorNode for a good case of this).
	                case 20 /* HeritageClauses */:
	                // This would probably be safe to reuse.  There is no speculative parsing with
	                // heritage clauses.
	                case 17 /* TypeParameters */:
	                // This would probably be safe to reuse.  There is no speculative parsing with
	                // type parameters.  Note that that's because type *parameters* only occur in
	                // unambiguous *type* contexts.  While type *arguments* occur in very ambiguous
	                // *expression* contexts.
	                case 19 /* TupleElementTypes */:
	                // This would probably be safe to reuse.  There is no speculative parsing with
	                // tuple types.
	                // Technically, type argument list types are probably safe to reuse.  While
	                // speculative parsing is involved with them (since type argument lists are only
	                // produced from speculative parsing a < as a type argument list), we only have
	                // the types because speculative parsing succeeded.  Thus, the lookahead never
	                // went past the end of the list and rewound.
	                case 18 /* TypeArguments */:
	                // Note: these are almost certainly not safe to ever reuse.  Expressions commonly
	                // need a large amount of lookahead, and we should not reuse them as they may
	                // have actually intersected the edit.
	                case 11 /* ArgumentExpressions */:
	                // This is not safe to reuse for the same reason as the 'AssignmentExpression'
	                // cases.  i.e. a property assignment may end with an expression, and thus might
	                // have lookahead far beyond it's old node.
	                case 12 /* ObjectLiteralMembers */:
	                // This is probably not safe to reuse.  There can be speculative parsing with
	                // type names in a heritage clause.  There can be generic names in the type
	                // name list, and there can be left hand side expressions (which can have type
	                // arguments.)
	                case 7 /* HeritageClauseElement */:
	                // Perhaps safe to reuse, but it's unlikely we'd see more than a dozen attributes
	                // on any given element. Same for children.
	                case 13 /* JsxAttributes */:
	                case 14 /* JsxChildren */:
	            }
	            return false;
	        }
	        function isReusableClassMember(node) {
	            if (node) {
	                switch (node.kind) {
	                    case 145 /* Constructor */:
	                    case 150 /* IndexSignature */:
	                    case 146 /* GetAccessor */:
	                    case 147 /* SetAccessor */:
	                    case 142 /* PropertyDeclaration */:
	                    case 194 /* SemicolonClassElement */:
	                        return true;
	                    case 144 /* MethodDeclaration */:
	                        // Method declarations are not necessarily reusable.  An object-literal
	                        // may have a method calls "constructor(...)" and we must reparse that
	                        // into an actual .ConstructorDeclaration.
	                        var methodDeclaration = node;
	                        var nameIsConstructor = methodDeclaration.name.kind === 69 /* Identifier */ &&
	                            methodDeclaration.name.originalKeywordKind === 121 /* ConstructorKeyword */;
	                        return !nameIsConstructor;
	                }
	            }
	            return false;
	        }
	        function isReusableSwitchClause(node) {
	            if (node) {
	                switch (node.kind) {
	                    case 244 /* CaseClause */:
	                    case 245 /* DefaultClause */:
	                        return true;
	                }
	            }
	            return false;
	        }
	        function isReusableStatement(node) {
	            if (node) {
	                switch (node.kind) {
	                    case 216 /* FunctionDeclaration */:
	                    case 196 /* VariableStatement */:
	                    case 195 /* Block */:
	                    case 199 /* IfStatement */:
	                    case 198 /* ExpressionStatement */:
	                    case 211 /* ThrowStatement */:
	                    case 207 /* ReturnStatement */:
	                    case 209 /* SwitchStatement */:
	                    case 206 /* BreakStatement */:
	                    case 205 /* ContinueStatement */:
	                    case 203 /* ForInStatement */:
	                    case 204 /* ForOfStatement */:
	                    case 202 /* ForStatement */:
	                    case 201 /* WhileStatement */:
	                    case 208 /* WithStatement */:
	                    case 197 /* EmptyStatement */:
	                    case 212 /* TryStatement */:
	                    case 210 /* LabeledStatement */:
	                    case 200 /* DoStatement */:
	                    case 213 /* DebuggerStatement */:
	                    case 225 /* ImportDeclaration */:
	                    case 224 /* ImportEqualsDeclaration */:
	                    case 231 /* ExportDeclaration */:
	                    case 230 /* ExportAssignment */:
	                    case 221 /* ModuleDeclaration */:
	                    case 217 /* ClassDeclaration */:
	                    case 218 /* InterfaceDeclaration */:
	                    case 220 /* EnumDeclaration */:
	                    case 219 /* TypeAliasDeclaration */:
	                        return true;
	                }
	            }
	            return false;
	        }
	        function isReusableEnumMember(node) {
	            return node.kind === 250 /* EnumMember */;
	        }
	        function isReusableTypeMember(node) {
	            if (node) {
	                switch (node.kind) {
	                    case 149 /* ConstructSignature */:
	                    case 143 /* MethodSignature */:
	                    case 150 /* IndexSignature */:
	                    case 141 /* PropertySignature */:
	                    case 148 /* CallSignature */:
	                        return true;
	                }
	            }
	            return false;
	        }
	        function isReusableVariableDeclaration(node) {
	            if (node.kind !== 214 /* VariableDeclaration */) {
	                return false;
	            }
	            // Very subtle incremental parsing bug.  Consider the following code:
	            //
	            //      let v = new List < A, B
	            //
	            // This is actually legal code.  It's a list of variable declarators "v = new List<A"
	            // on one side and "B" on the other. If you then change that to:
	            //
	            //      let v = new List < A, B >()
	            //
	            // then we have a problem.  "v = new List<A" doesn't intersect the change range, so we
	            // start reparsing at "B" and we completely fail to handle this properly.
	            //
	            // In order to prevent this, we do not allow a variable declarator to be reused if it
	            // has an initializer.
	            var variableDeclarator = node;
	            return variableDeclarator.initializer === undefined;
	        }
	        function isReusableParameter(node) {
	            if (node.kind !== 139 /* Parameter */) {
	                return false;
	            }
	            // See the comment in isReusableVariableDeclaration for why we do this.
	            var parameter = node;
	            return parameter.initializer === undefined;
	        }
	        // Returns true if we should abort parsing.
	        function abortParsingListOrMoveToNextToken(kind) {
	            parseErrorAtCurrentToken(parsingContextErrors(kind));
	            if (isInSomeParsingContext()) {
	                return true;
	            }
	            nextToken();
	            return false;
	        }
	        function parsingContextErrors(context) {
	            switch (context) {
	                case 0 /* SourceElements */: return ts.Diagnostics.Declaration_or_statement_expected;
	                case 1 /* BlockStatements */: return ts.Diagnostics.Declaration_or_statement_expected;
	                case 2 /* SwitchClauses */: return ts.Diagnostics.case_or_default_expected;
	                case 3 /* SwitchClauseStatements */: return ts.Diagnostics.Statement_expected;
	                case 4 /* TypeMembers */: return ts.Diagnostics.Property_or_signature_expected;
	                case 5 /* ClassMembers */: return ts.Diagnostics.Unexpected_token_A_constructor_method_accessor_or_property_was_expected;
	                case 6 /* EnumMembers */: return ts.Diagnostics.Enum_member_expected;
	                case 7 /* HeritageClauseElement */: return ts.Diagnostics.Expression_expected;
	                case 8 /* VariableDeclarations */: return ts.Diagnostics.Variable_declaration_expected;
	                case 9 /* ObjectBindingElements */: return ts.Diagnostics.Property_destructuring_pattern_expected;
	                case 10 /* ArrayBindingElements */: return ts.Diagnostics.Array_element_destructuring_pattern_expected;
	                case 11 /* ArgumentExpressions */: return ts.Diagnostics.Argument_expression_expected;
	                case 12 /* ObjectLiteralMembers */: return ts.Diagnostics.Property_assignment_expected;
	                case 15 /* ArrayLiteralMembers */: return ts.Diagnostics.Expression_or_comma_expected;
	                case 16 /* Parameters */: return ts.Diagnostics.Parameter_declaration_expected;
	                case 17 /* TypeParameters */: return ts.Diagnostics.Type_parameter_declaration_expected;
	                case 18 /* TypeArguments */: return ts.Diagnostics.Type_argument_expected;
	                case 19 /* TupleElementTypes */: return ts.Diagnostics.Type_expected;
	                case 20 /* HeritageClauses */: return ts.Diagnostics.Unexpected_token_expected;
	                case 21 /* ImportOrExportSpecifiers */: return ts.Diagnostics.Identifier_expected;
	                case 13 /* JsxAttributes */: return ts.Diagnostics.Identifier_expected;
	                case 14 /* JsxChildren */: return ts.Diagnostics.Identifier_expected;
	                case 22 /* JSDocFunctionParameters */: return ts.Diagnostics.Parameter_declaration_expected;
	                case 23 /* JSDocTypeArguments */: return ts.Diagnostics.Type_argument_expected;
	                case 25 /* JSDocTupleTypes */: return ts.Diagnostics.Type_expected;
	                case 24 /* JSDocRecordMembers */: return ts.Diagnostics.Property_assignment_expected;
	            }
	        }
	        ;
	        // Parses a comma-delimited list of elements
	        function parseDelimitedList(kind, parseElement, considerSemicolonAsDelimeter) {
	            var saveParsingContext = parsingContext;
	            parsingContext |= 1 << kind;
	            var result = [];
	            result.pos = getNodePos();
	            var commaStart = -1; // Meaning the previous token was not a comma
	            while (true) {
	                if (isListElement(kind, /*inErrorRecovery*/ false)) {
	                    result.push(parseListElement(kind, parseElement));
	                    commaStart = scanner.getTokenPos();
	                    if (parseOptional(24 /* CommaToken */)) {
	                        continue;
	                    }
	                    commaStart = -1; // Back to the state where the last token was not a comma
	                    if (isListTerminator(kind)) {
	                        break;
	                    }
	                    // We didn't get a comma, and the list wasn't terminated, explicitly parse
	                    // out a comma so we give a good error message.
	                    parseExpected(24 /* CommaToken */);
	                    // If the token was a semicolon, and the caller allows that, then skip it and
	                    // continue.  This ensures we get back on track and don't result in tons of
	                    // parse errors.  For example, this can happen when people do things like use
	                    // a semicolon to delimit object literal members.   Note: we'll have already
	                    // reported an error when we called parseExpected above.
	                    if (considerSemicolonAsDelimeter && token === 23 /* SemicolonToken */ && !scanner.hasPrecedingLineBreak()) {
	                        nextToken();
	                    }
	                    continue;
	                }
	                if (isListTerminator(kind)) {
	                    break;
	                }
	                if (abortParsingListOrMoveToNextToken(kind)) {
	                    break;
	                }
	            }
	            // Recording the trailing comma is deliberately done after the previous
	            // loop, and not just if we see a list terminator. This is because the list
	            // may have ended incorrectly, but it is still important to know if there
	            // was a trailing comma.
	            // Check if the last token was a comma.
	            if (commaStart >= 0) {
	                // Always preserve a trailing comma by marking it on the NodeArray
	                result.hasTrailingComma = true;
	            }
	            result.end = getNodeEnd();
	            parsingContext = saveParsingContext;
	            return result;
	        }
	        function createMissingList() {
	            var pos = getNodePos();
	            var result = [];
	            result.pos = pos;
	            result.end = pos;
	            return result;
	        }
	        function parseBracketedList(kind, parseElement, open, close) {
	            if (parseExpected(open)) {
	                var result = parseDelimitedList(kind, parseElement);
	                parseExpected(close);
	                return result;
	            }
	            return createMissingList();
	        }
	        // The allowReservedWords parameter controls whether reserved words are permitted after the first dot
	        function parseEntityName(allowReservedWords, diagnosticMessage) {
	            var entity = parseIdentifier(diagnosticMessage);
	            while (parseOptional(21 /* DotToken */)) {
	                var node = createNode(136 /* QualifiedName */, entity.pos);
	                node.left = entity;
	                node.right = parseRightSideOfDot(allowReservedWords);
	                entity = finishNode(node);
	            }
	            return entity;
	        }
	        function parseRightSideOfDot(allowIdentifierNames) {
	            // Technically a keyword is valid here as all identifiers and keywords are identifier names.
	            // However, often we'll encounter this in error situations when the identifier or keyword
	            // is actually starting another valid construct.
	            //
	            // So, we check for the following specific case:
	            //
	            //      name.
	            //      identifierOrKeyword identifierNameOrKeyword
	            //
	            // Note: the newlines are important here.  For example, if that above code
	            // were rewritten into:
	            //
	            //      name.identifierOrKeyword
	            //      identifierNameOrKeyword
	            //
	            // Then we would consider it valid.  That's because ASI would take effect and
	            // the code would be implicitly: "name.identifierOrKeyword; identifierNameOrKeyword".
	            // In the first case though, ASI will not take effect because there is not a
	            // line terminator after the identifier or keyword.
	            if (scanner.hasPrecedingLineBreak() && ts.tokenIsIdentifierOrKeyword(token)) {
	                var matchesPattern = lookAhead(nextTokenIsIdentifierOrKeywordOnSameLine);
	                if (matchesPattern) {
	                    // Report that we need an identifier.  However, report it right after the dot,
	                    // and not on the next token.  This is because the next token might actually
	                    // be an identifier and the error would be quite confusing.
	                    return createMissingNode(69 /* Identifier */, /*reportAtCurrentPosition*/ true, ts.Diagnostics.Identifier_expected);
	                }
	            }
	            return allowIdentifierNames ? parseIdentifierName() : parseIdentifier();
	        }
	        function parseTemplateExpression() {
	            var template = createNode(186 /* TemplateExpression */);
	            template.head = parseTemplateLiteralFragment();
	            ts.Debug.assert(template.head.kind === 12 /* TemplateHead */, "Template head has wrong token kind");
	            var templateSpans = [];
	            templateSpans.pos = getNodePos();
	            do {
	                templateSpans.push(parseTemplateSpan());
	            } while (ts.lastOrUndefined(templateSpans).literal.kind === 13 /* TemplateMiddle */);
	            templateSpans.end = getNodeEnd();
	            template.templateSpans = templateSpans;
	            return finishNode(template);
	        }
	        function parseTemplateSpan() {
	            var span = createNode(193 /* TemplateSpan */);
	            span.expression = allowInAnd(parseExpression);
	            var literal;
	            if (token === 16 /* CloseBraceToken */) {
	                reScanTemplateToken();
	                literal = parseTemplateLiteralFragment();
	            }
	            else {
	                literal = parseExpectedToken(14 /* TemplateTail */, /*reportAtCurrentPosition*/ false, ts.Diagnostics._0_expected, ts.tokenToString(16 /* CloseBraceToken */));
	            }
	            span.literal = literal;
	            return finishNode(span);
	        }
	        function parseStringLiteralTypeNode() {
	            return parseLiteralLikeNode(163 /* StringLiteralType */, /*internName*/ true);
	        }
	        function parseLiteralNode(internName) {
	            return parseLiteralLikeNode(token, internName);
	        }
	        function parseTemplateLiteralFragment() {
	            return parseLiteralLikeNode(token, /*internName*/ false);
	        }
	        function parseLiteralLikeNode(kind, internName) {
	            var node = createNode(kind);
	            var text = scanner.getTokenValue();
	            node.text = internName ? internIdentifier(text) : text;
	            if (scanner.hasExtendedUnicodeEscape()) {
	                node.hasExtendedUnicodeEscape = true;
	            }
	            if (scanner.isUnterminated()) {
	                node.isUnterminated = true;
	            }
	            var tokenPos = scanner.getTokenPos();
	            nextToken();
	            finishNode(node);
	            // Octal literals are not allowed in strict mode or ES5
	            // Note that theoretically the following condition would hold true literals like 009,
	            // which is not octal.But because of how the scanner separates the tokens, we would
	            // never get a token like this. Instead, we would get 00 and 9 as two separate tokens.
	            // We also do not need to check for negatives because any prefix operator would be part of a
	            // parent unary expression.
	            if (node.kind === 8 /* NumericLiteral */
	                && sourceText.charCodeAt(tokenPos) === 48 /* _0 */
	                && ts.isOctalDigit(sourceText.charCodeAt(tokenPos + 1))) {
	                node.flags |= 32768 /* OctalLiteral */;
	            }
	            return node;
	        }
	        // TYPES
	        function parseTypeReference() {
	            var typeName = parseEntityName(/*allowReservedWords*/ false, ts.Diagnostics.Type_expected);
	            var node = createNode(152 /* TypeReference */, typeName.pos);
	            node.typeName = typeName;
	            if (!scanner.hasPrecedingLineBreak() && token === 25 /* LessThanToken */) {
	                node.typeArguments = parseBracketedList(18 /* TypeArguments */, parseType, 25 /* LessThanToken */, 27 /* GreaterThanToken */);
	            }
	            return finishNode(node);
	        }
	        function parseThisTypePredicate(lhs) {
	            nextToken();
	            var node = createNode(151 /* TypePredicate */, lhs.pos);
	            node.parameterName = lhs;
	            node.type = parseType();
	            return finishNode(node);
	        }
	        function parseThisTypeNode() {
	            var node = createNode(162 /* ThisType */);
	            nextToken();
	            return finishNode(node);
	        }
	        function parseTypeQuery() {
	            var node = createNode(155 /* TypeQuery */);
	            parseExpected(101 /* TypeOfKeyword */);
	            node.exprName = parseEntityName(/*allowReservedWords*/ true);
	            return finishNode(node);
	        }
	        function parseTypeParameter() {
	            var node = createNode(138 /* TypeParameter */);
	            node.name = parseIdentifier();
	            if (parseOptional(83 /* ExtendsKeyword */)) {
	                // It's not uncommon for people to write improper constraints to a generic.  If the
	                // user writes a constraint that is an expression and not an actual type, then parse
	                // it out as an expression (so we can recover well), but report that a type is needed
	                // instead.
	                if (isStartOfType() || !isStartOfExpression()) {
	                    node.constraint = parseType();
	                }
	                else {
	                    // It was not a type, and it looked like an expression.  Parse out an expression
	                    // here so we recover well.  Note: it is important that we call parseUnaryExpression
	                    // and not parseExpression here.  If the user has:
	                    //
	                    //      <T extends "">
	                    //
	                    // We do *not* want to consume the  >  as we're consuming the expression for "".
	                    node.expression = parseUnaryExpressionOrHigher();
	                }
	            }
	            return finishNode(node);
	        }
	        function parseTypeParameters() {
	            if (token === 25 /* LessThanToken */) {
	                return parseBracketedList(17 /* TypeParameters */, parseTypeParameter, 25 /* LessThanToken */, 27 /* GreaterThanToken */);
	            }
	        }
	        function parseParameterType() {
	            if (parseOptional(54 /* ColonToken */)) {
	                return parseType();
	            }
	            return undefined;
	        }
	        function isStartOfParameter() {
	            return token === 22 /* DotDotDotToken */ || isIdentifierOrPattern() || ts.isModifierKind(token) || token === 55 /* AtToken */;
	        }
	        function setModifiers(node, modifiers) {
	            if (modifiers) {
	                node.flags |= modifiers.flags;
	                node.modifiers = modifiers;
	            }
	        }
	        function parseParameter() {
	            var node = createNode(139 /* Parameter */);
	            node.decorators = parseDecorators();
	            setModifiers(node, parseModifiers());
	            node.dotDotDotToken = parseOptionalToken(22 /* DotDotDotToken */);
	            // FormalParameter [Yield,Await]:
	            //      BindingElement[?Yield,?Await]
	            node.name = parseIdentifierOrPattern();
	            if (ts.getFullWidth(node.name) === 0 && node.flags === 0 && ts.isModifierKind(token)) {
	                // in cases like
	                // 'use strict'
	                // function foo(static)
	                // isParameter('static') === true, because of isModifier('static')
	                // however 'static' is not a legal identifier in a strict mode.
	                // so result of this function will be ParameterDeclaration (flags = 0, name = missing, type = undefined, initializer = undefined)
	                // and current token will not change => parsing of the enclosing parameter list will last till the end of time (or OOM)
	                // to avoid this we'll advance cursor to the next token.
	                nextToken();
	            }
	            node.questionToken = parseOptionalToken(53 /* QuestionToken */);
	            node.type = parseParameterType();
	            node.initializer = parseBindingElementInitializer(/*inParameter*/ true);
	            // Do not check for initializers in an ambient context for parameters. This is not
	            // a grammar error because the grammar allows arbitrary call signatures in
	            // an ambient context.
	            // It is actually not necessary for this to be an error at all. The reason is that
	            // function/constructor implementations are syntactically disallowed in ambient
	            // contexts. In addition, parameter initializers are semantically disallowed in
	            // overload signatures. So parameter initializers are transitively disallowed in
	            // ambient contexts.
	            return addJSDocComment(finishNode(node));
	        }
	        function parseBindingElementInitializer(inParameter) {
	            return inParameter ? parseParameterInitializer() : parseNonParameterInitializer();
	        }
	        function parseParameterInitializer() {
	            return parseInitializer(/*inParameter*/ true);
	        }
	        function fillSignature(returnToken, yieldContext, awaitContext, requireCompleteParameterList, signature) {
	            var returnTokenRequired = returnToken === 34 /* EqualsGreaterThanToken */;
	            signature.typeParameters = parseTypeParameters();
	            signature.parameters = parseParameterList(yieldContext, awaitContext, requireCompleteParameterList);
	            if (returnTokenRequired) {
	                parseExpected(returnToken);
	                signature.type = parseTypeOrTypePredicate();
	            }
	            else if (parseOptional(returnToken)) {
	                signature.type = parseTypeOrTypePredicate();
	            }
	        }
	        function parseParameterList(yieldContext, awaitContext, requireCompleteParameterList) {
	            // FormalParameters [Yield,Await]: (modified)
	            //      [empty]
	            //      FormalParameterList[?Yield,Await]
	            //
	            // FormalParameter[Yield,Await]: (modified)
	            //      BindingElement[?Yield,Await]
	            //
	            // BindingElement [Yield,Await]: (modified)
	            //      SingleNameBinding[?Yield,?Await]
	            //      BindingPattern[?Yield,?Await]Initializer [In, ?Yield,?Await] opt
	            //
	            // SingleNameBinding [Yield,Await]:
	            //      BindingIdentifier[?Yield,?Await]Initializer [In, ?Yield,?Await] opt
	            if (parseExpected(17 /* OpenParenToken */)) {
	                var savedYieldContext = inYieldContext();
	                var savedAwaitContext = inAwaitContext();
	                setYieldContext(yieldContext);
	                setAwaitContext(awaitContext);
	                var result = parseDelimitedList(16 /* Parameters */, parseParameter);
	                setYieldContext(savedYieldContext);
	                setAwaitContext(savedAwaitContext);
	                if (!parseExpected(18 /* CloseParenToken */) && requireCompleteParameterList) {
	                    // Caller insisted that we had to end with a )   We didn't.  So just return
	                    // undefined here.
	                    return undefined;
	                }
	                return result;
	            }
	            // We didn't even have an open paren.  If the caller requires a complete parameter list,
	            // we definitely can't provide that.  However, if they're ok with an incomplete one,
	            // then just return an empty set of parameters.
	            return requireCompleteParameterList ? undefined : createMissingList();
	        }
	        function parseTypeMemberSemicolon() {
	            // We allow type members to be separated by commas or (possibly ASI) semicolons.
	            // First check if it was a comma.  If so, we're done with the member.
	            if (parseOptional(24 /* CommaToken */)) {
	                return;
	            }
	            // Didn't have a comma.  We must have a (possible ASI) semicolon.
	            parseSemicolon();
	        }
	        function parseSignatureMember(kind) {
	            var node = createNode(kind);
	            if (kind === 149 /* ConstructSignature */) {
	                parseExpected(92 /* NewKeyword */);
	            }
	            fillSignature(54 /* ColonToken */, /*yieldContext*/ false, /*awaitContext*/ false, /*requireCompleteParameterList*/ false, node);
	            parseTypeMemberSemicolon();
	            return finishNode(node);
	        }
	        function isIndexSignature() {
	            if (token !== 19 /* OpenBracketToken */) {
	                return false;
	            }
	            return lookAhead(isUnambiguouslyIndexSignature);
	        }
	        function isUnambiguouslyIndexSignature() {
	            // The only allowed sequence is:
	            //
	            //   [id:
	            //
	            // However, for error recovery, we also check the following cases:
	            //
	            //   [...
	            //   [id,
	            //   [id?,
	            //   [id?:
	            //   [id?]
	            //   [public id
	            //   [private id
	            //   [protected id
	            //   []
	            //
	            nextToken();
	            if (token === 22 /* DotDotDotToken */ || token === 20 /* CloseBracketToken */) {
	                return true;
	            }
	            if (ts.isModifierKind(token)) {
	                nextToken();
	                if (isIdentifier()) {
	                    return true;
	                }
	            }
	            else if (!isIdentifier()) {
	                return false;
	            }
	            else {
	                // Skip the identifier
	                nextToken();
	            }
	            // A colon signifies a well formed indexer
	            // A comma should be a badly formed indexer because comma expressions are not allowed
	            // in computed properties.
	            if (token === 54 /* ColonToken */ || token === 24 /* CommaToken */) {
	                return true;
	            }
	            // Question mark could be an indexer with an optional property,
	            // or it could be a conditional expression in a computed property.
	            if (token !== 53 /* QuestionToken */) {
	                return false;
	            }
	            // If any of the following tokens are after the question mark, it cannot
	            // be a conditional expression, so treat it as an indexer.
	            nextToken();
	            return token === 54 /* ColonToken */ || token === 24 /* CommaToken */ || token === 20 /* CloseBracketToken */;
	        }
	        function parseIndexSignatureDeclaration(fullStart, decorators, modifiers) {
	            var node = createNode(150 /* IndexSignature */, fullStart);
	            node.decorators = decorators;
	            setModifiers(node, modifiers);
	            node.parameters = parseBracketedList(16 /* Parameters */, parseParameter, 19 /* OpenBracketToken */, 20 /* CloseBracketToken */);
	            node.type = parseTypeAnnotation();
	            parseTypeMemberSemicolon();
	            return finishNode(node);
	        }
	        function parsePropertyOrMethodSignature() {
	            var fullStart = scanner.getStartPos();
	            var name = parsePropertyName();
	            var questionToken = parseOptionalToken(53 /* QuestionToken */);
	            if (token === 17 /* OpenParenToken */ || token === 25 /* LessThanToken */) {
	                var method = createNode(143 /* MethodSignature */, fullStart);
	                method.name = name;
	                method.questionToken = questionToken;
	                // Method signatues don't exist in expression contexts.  So they have neither
	                // [Yield] nor [Await]
	                fillSignature(54 /* ColonToken */, /*yieldContext*/ false, /*awaitContext*/ false, /*requireCompleteParameterList*/ false, method);
	                parseTypeMemberSemicolon();
	                return finishNode(method);
	            }
	            else {
	                var property = createNode(141 /* PropertySignature */, fullStart);
	                property.name = name;
	                property.questionToken = questionToken;
	                property.type = parseTypeAnnotation();
	                if (token === 56 /* EqualsToken */) {
	                    // Although type literal properties cannot not have initializers, we attempt
	                    // to parse an initializer so we can report in the checker that an interface
	                    // property or type literal property cannot have an initializer.
	                    property.initializer = parseNonParameterInitializer();
	                }
	                parseTypeMemberSemicolon();
	                return finishNode(property);
	            }
	        }
	        function isStartOfTypeMember() {
	            switch (token) {
	                case 17 /* OpenParenToken */:
	                case 25 /* LessThanToken */:
	                case 19 /* OpenBracketToken */:
	                    return true;
	                default:
	                    if (ts.isModifierKind(token)) {
	                        var result = lookAhead(isStartOfIndexSignatureDeclaration);
	                        if (result) {
	                            return result;
	                        }
	                    }
	                    return isLiteralPropertyName() && lookAhead(isTypeMemberWithLiteralPropertyName);
	            }
	        }
	        function isStartOfIndexSignatureDeclaration() {
	            while (ts.isModifierKind(token)) {
	                nextToken();
	            }
	            return isIndexSignature();
	        }
	        function isTypeMemberWithLiteralPropertyName() {
	            nextToken();
	            return token === 17 /* OpenParenToken */ ||
	                token === 25 /* LessThanToken */ ||
	                token === 53 /* QuestionToken */ ||
	                token === 54 /* ColonToken */ ||
	                canParseSemicolon();
	        }
	        function parseTypeMember() {
	            switch (token) {
	                case 17 /* OpenParenToken */:
	                case 25 /* LessThanToken */:
	                    return parseSignatureMember(148 /* CallSignature */);
	                case 19 /* OpenBracketToken */:
	                    // Indexer or computed property
	                    return isIndexSignature()
	                        ? parseIndexSignatureDeclaration(scanner.getStartPos(), /*decorators*/ undefined, /*modifiers*/ undefined)
	                        : parsePropertyOrMethodSignature();
	                case 92 /* NewKeyword */:
	                    if (lookAhead(isStartOfConstructSignature)) {
	                        return parseSignatureMember(149 /* ConstructSignature */);
	                    }
	                // fall through.
	                case 9 /* StringLiteral */:
	                case 8 /* NumericLiteral */:
	                    return parsePropertyOrMethodSignature();
	                default:
	                    // Index declaration as allowed as a type member.  But as per the grammar,
	                    // they also allow modifiers. So we have to check for an index declaration
	                    // that might be following modifiers. This ensures that things work properly
	                    // when incrementally parsing as the parser will produce the Index declaration
	                    // if it has the same text regardless of whether it is inside a class or an
	                    // object type.
	                    if (ts.isModifierKind(token)) {
	                        var result = tryParse(parseIndexSignatureWithModifiers);
	                        if (result) {
	                            return result;
	                        }
	                    }
	                    if (ts.tokenIsIdentifierOrKeyword(token)) {
	                        return parsePropertyOrMethodSignature();
	                    }
	            }
	        }
	        function parseIndexSignatureWithModifiers() {
	            var fullStart = scanner.getStartPos();
	            var decorators = parseDecorators();
	            var modifiers = parseModifiers();
	            return isIndexSignature()
	                ? parseIndexSignatureDeclaration(fullStart, decorators, modifiers)
	                : undefined;
	        }
	        function isStartOfConstructSignature() {
	            nextToken();
	            return token === 17 /* OpenParenToken */ || token === 25 /* LessThanToken */;
	        }
	        function parseTypeLiteral() {
	            var node = createNode(156 /* TypeLiteral */);
	            node.members = parseObjectTypeMembers();
	            return finishNode(node);
	        }
	        function parseObjectTypeMembers() {
	            var members;
	            if (parseExpected(15 /* OpenBraceToken */)) {
	                members = parseList(4 /* TypeMembers */, parseTypeMember);
	                parseExpected(16 /* CloseBraceToken */);
	            }
	            else {
	                members = createMissingList();
	            }
	            return members;
	        }
	        function parseTupleType() {
	            var node = createNode(158 /* TupleType */);
	            node.elementTypes = parseBracketedList(19 /* TupleElementTypes */, parseType, 19 /* OpenBracketToken */, 20 /* CloseBracketToken */);
	            return finishNode(node);
	        }
	        function parseParenthesizedType() {
	            var node = createNode(161 /* ParenthesizedType */);
	            parseExpected(17 /* OpenParenToken */);
	            node.type = parseType();
	            parseExpected(18 /* CloseParenToken */);
	            return finishNode(node);
	        }
	        function parseFunctionOrConstructorType(kind) {
	            var node = createNode(kind);
	            if (kind === 154 /* ConstructorType */) {
	                parseExpected(92 /* NewKeyword */);
	            }
	            fillSignature(34 /* EqualsGreaterThanToken */, /*yieldContext*/ false, /*awaitContext*/ false, /*requireCompleteParameterList*/ false, node);
	            return finishNode(node);
	        }
	        function parseKeywordAndNoDot() {
	            var node = parseTokenNode();
	            return token === 21 /* DotToken */ ? undefined : node;
	        }
	        function parseNonArrayType() {
	            switch (token) {
	                case 117 /* AnyKeyword */:
	                case 130 /* StringKeyword */:
	                case 128 /* NumberKeyword */:
	                case 120 /* BooleanKeyword */:
	                case 131 /* SymbolKeyword */:
	                    // If these are followed by a dot, then parse these out as a dotted type reference instead.
	                    var node = tryParse(parseKeywordAndNoDot);
	                    return node || parseTypeReference();
	                case 9 /* StringLiteral */:
	                    return parseStringLiteralTypeNode();
	                case 103 /* VoidKeyword */:
	                    return parseTokenNode();
	                case 97 /* ThisKeyword */: {
	                    var thisKeyword = parseThisTypeNode();
	                    if (token === 124 /* IsKeyword */ && !scanner.hasPrecedingLineBreak()) {
	                        return parseThisTypePredicate(thisKeyword);
	                    }
	                    else {
	                        return thisKeyword;
	                    }
	                }
	                case 101 /* TypeOfKeyword */:
	                    return parseTypeQuery();
	                case 15 /* OpenBraceToken */:
	                    return parseTypeLiteral();
	                case 19 /* OpenBracketToken */:
	                    return parseTupleType();
	                case 17 /* OpenParenToken */:
	                    return parseParenthesizedType();
	                default:
	                    return parseTypeReference();
	            }
	        }
	        function isStartOfType() {
	            switch (token) {
	                case 117 /* AnyKeyword */:
	                case 130 /* StringKeyword */:
	                case 128 /* NumberKeyword */:
	                case 120 /* BooleanKeyword */:
	                case 131 /* SymbolKeyword */:
	                case 103 /* VoidKeyword */:
	                case 97 /* ThisKeyword */:
	                case 101 /* TypeOfKeyword */:
	                case 15 /* OpenBraceToken */:
	                case 19 /* OpenBracketToken */:
	                case 25 /* LessThanToken */:
	                case 92 /* NewKeyword */:
	                case 9 /* StringLiteral */:
	                    return true;
	                case 17 /* OpenParenToken */:
	                    // Only consider '(' the start of a type if followed by ')', '...', an identifier, a modifier,
	                    // or something that starts a type. We don't want to consider things like '(1)' a type.
	                    return lookAhead(isStartOfParenthesizedOrFunctionType);
	                default:
	                    return isIdentifier();
	            }
	        }
	        function isStartOfParenthesizedOrFunctionType() {
	            nextToken();
	            return token === 18 /* CloseParenToken */ || isStartOfParameter() || isStartOfType();
	        }
	        function parseArrayTypeOrHigher() {
	            var type = parseNonArrayType();
	            while (!scanner.hasPrecedingLineBreak() && parseOptional(19 /* OpenBracketToken */)) {
	                parseExpected(20 /* CloseBracketToken */);
	                var node = createNode(157 /* ArrayType */, type.pos);
	                node.elementType = type;
	                type = finishNode(node);
	            }
	            return type;
	        }
	        function parseUnionOrIntersectionType(kind, parseConstituentType, operator) {
	            var type = parseConstituentType();
	            if (token === operator) {
	                var types = [type];
	                types.pos = type.pos;
	                while (parseOptional(operator)) {
	                    types.push(parseConstituentType());
	                }
	                types.end = getNodeEnd();
	                var node = createNode(kind, type.pos);
	                node.types = types;
	                type = finishNode(node);
	            }
	            return type;
	        }
	        function parseIntersectionTypeOrHigher() {
	            return parseUnionOrIntersectionType(160 /* IntersectionType */, parseArrayTypeOrHigher, 46 /* AmpersandToken */);
	        }
	        function parseUnionTypeOrHigher() {
	            return parseUnionOrIntersectionType(159 /* UnionType */, parseIntersectionTypeOrHigher, 47 /* BarToken */);
	        }
	        function isStartOfFunctionType() {
	            if (token === 25 /* LessThanToken */) {
	                return true;
	            }
	            return token === 17 /* OpenParenToken */ && lookAhead(isUnambiguouslyStartOfFunctionType);
	        }
	        function isUnambiguouslyStartOfFunctionType() {
	            nextToken();
	            if (token === 18 /* CloseParenToken */ || token === 22 /* DotDotDotToken */) {
	                // ( )
	                // ( ...
	                return true;
	            }
	            if (isIdentifier() || ts.isModifierKind(token)) {
	                nextToken();
	                if (token === 54 /* ColonToken */ || token === 24 /* CommaToken */ ||
	                    token === 53 /* QuestionToken */ || token === 56 /* EqualsToken */ ||
	                    isIdentifier() || ts.isModifierKind(token)) {
	                    // ( id :
	                    // ( id ,
	                    // ( id ?
	                    // ( id =
	                    // ( modifier id
	                    return true;
	                }
	                if (token === 18 /* CloseParenToken */) {
	                    nextToken();
	                    if (token === 34 /* EqualsGreaterThanToken */) {
	                        // ( id ) =>
	                        return true;
	                    }
	                }
	            }
	            return false;
	        }
	        function parseTypeOrTypePredicate() {
	            var typePredicateVariable = isIdentifier() && tryParse(parseTypePredicatePrefix);
	            var type = parseType();
	            if (typePredicateVariable) {
	                var node = createNode(151 /* TypePredicate */, typePredicateVariable.pos);
	                node.parameterName = typePredicateVariable;
	                node.type = type;
	                return finishNode(node);
	            }
	            else {
	                return type;
	            }
	        }
	        function parseTypePredicatePrefix() {
	            var id = parseIdentifier();
	            if (token === 124 /* IsKeyword */ && !scanner.hasPrecedingLineBreak()) {
	                nextToken();
	                return id;
	            }
	        }
	        function parseType() {
	            // The rules about 'yield' only apply to actual code/expression contexts.  They don't
	            // apply to 'type' contexts.  So we disable these parameters here before moving on.
	            return doOutsideOfContext(10 /* TypeExcludesFlags */, parseTypeWorker);
	        }
	        function parseTypeWorker() {
	            if (isStartOfFunctionType()) {
	                return parseFunctionOrConstructorType(153 /* FunctionType */);
	            }
	            if (token === 92 /* NewKeyword */) {
	                return parseFunctionOrConstructorType(154 /* ConstructorType */);
	            }
	            return parseUnionTypeOrHigher();
	        }
	        function parseTypeAnnotation() {
	            return parseOptional(54 /* ColonToken */) ? parseType() : undefined;
	        }
	        // EXPRESSIONS
	        function isStartOfLeftHandSideExpression() {
	            switch (token) {
	                case 97 /* ThisKeyword */:
	                case 95 /* SuperKeyword */:
	                case 93 /* NullKeyword */:
	                case 99 /* TrueKeyword */:
	                case 84 /* FalseKeyword */:
	                case 8 /* NumericLiteral */:
	                case 9 /* StringLiteral */:
	                case 11 /* NoSubstitutionTemplateLiteral */:
	                case 12 /* TemplateHead */:
	                case 17 /* OpenParenToken */:
	                case 19 /* OpenBracketToken */:
	                case 15 /* OpenBraceToken */:
	                case 87 /* FunctionKeyword */:
	                case 73 /* ClassKeyword */:
	                case 92 /* NewKeyword */:
	                case 39 /* SlashToken */:
	                case 61 /* SlashEqualsToken */:
	                case 69 /* Identifier */:
	                    return true;
	                default:
	                    return isIdentifier();
	            }
	        }
	        function isStartOfExpression() {
	            if (isStartOfLeftHandSideExpression()) {
	                return true;
	            }
	            switch (token) {
	                case 35 /* PlusToken */:
	                case 36 /* MinusToken */:
	                case 50 /* TildeToken */:
	                case 49 /* ExclamationToken */:
	                case 78 /* DeleteKeyword */:
	                case 101 /* TypeOfKeyword */:
	                case 103 /* VoidKeyword */:
	                case 41 /* PlusPlusToken */:
	                case 42 /* MinusMinusToken */:
	                case 25 /* LessThanToken */:
	                case 119 /* AwaitKeyword */:
	                case 114 /* YieldKeyword */:
	                    // Yield/await always starts an expression.  Either it is an identifier (in which case
	                    // it is definitely an expression).  Or it's a keyword (either because we're in
	                    // a generator or async function, or in strict mode (or both)) and it started a yield or await expression.
	                    return true;
	                default:
	                    // Error tolerance.  If we see the start of some binary operator, we consider
	                    // that the start of an expression.  That way we'll parse out a missing identifier,
	                    // give a good message about an identifier being missing, and then consume the
	                    // rest of the binary expression.
	                    if (isBinaryOperator()) {
	                        return true;
	                    }
	                    return isIdentifier();
	            }
	        }
	        function isStartOfExpressionStatement() {
	            // As per the grammar, none of '{' or 'function' or 'class' can start an expression statement.
	            return token !== 15 /* OpenBraceToken */ &&
	                token !== 87 /* FunctionKeyword */ &&
	                token !== 73 /* ClassKeyword */ &&
	                token !== 55 /* AtToken */ &&
	                isStartOfExpression();
	        }
	        function parseExpression() {
	            // Expression[in]:
	            //      AssignmentExpression[in]
	            //      Expression[in] , AssignmentExpression[in]
	            // clear the decorator context when parsing Expression, as it should be unambiguous when parsing a decorator
	            var saveDecoratorContext = inDecoratorContext();
	            if (saveDecoratorContext) {
	                setDecoratorContext(/*val*/ false);
	            }
	            var expr = parseAssignmentExpressionOrHigher();
	            var operatorToken;
	            while ((operatorToken = parseOptionalToken(24 /* CommaToken */))) {
	                expr = makeBinaryExpression(expr, operatorToken, parseAssignmentExpressionOrHigher());
	            }
	            if (saveDecoratorContext) {
	                setDecoratorContext(/*val*/ true);
	            }
	            return expr;
	        }
	        function parseInitializer(inParameter) {
	            if (token !== 56 /* EqualsToken */) {
	                // It's not uncommon during typing for the user to miss writing the '=' token.  Check if
	                // there is no newline after the last token and if we're on an expression.  If so, parse
	                // this as an equals-value clause with a missing equals.
	                // NOTE: There are two places where we allow equals-value clauses.  The first is in a
	                // variable declarator.  The second is with a parameter.  For variable declarators
	                // it's more likely that a { would be a allowed (as an object literal).  While this
	                // is also allowed for parameters, the risk is that we consume the { as an object
	                // literal when it really will be for the block following the parameter.
	                if (scanner.hasPrecedingLineBreak() || (inParameter && token === 15 /* OpenBraceToken */) || !isStartOfExpression()) {
	                    // preceding line break, open brace in a parameter (likely a function body) or current token is not an expression -
	                    // do not try to parse initializer
	                    return undefined;
	                }
	            }
	            // Initializer[In, Yield] :
	            //     = AssignmentExpression[?In, ?Yield]
	            parseExpected(56 /* EqualsToken */);
	            return parseAssignmentExpressionOrHigher();
	        }
	        function parseAssignmentExpressionOrHigher() {
	            //  AssignmentExpression[in,yield]:
	            //      1) ConditionalExpression[?in,?yield]
	            //      2) LeftHandSideExpression = AssignmentExpression[?in,?yield]
	            //      3) LeftHandSideExpression AssignmentOperator AssignmentExpression[?in,?yield]
	            //      4) ArrowFunctionExpression[?in,?yield]
	            //      5) [+Yield] YieldExpression[?In]
	            //
	            // Note: for ease of implementation we treat productions '2' and '3' as the same thing.
	            // (i.e. they're both BinaryExpressions with an assignment operator in it).
	            // First, do the simple check if we have a YieldExpression (production '5').
	            if (isYieldExpression()) {
	                return parseYieldExpression();
	            }
	            // Then, check if we have an arrow function (production '4') that starts with a parenthesized
	            // parameter list. If we do, we must *not* recurse for productions 1, 2 or 3. An ArrowFunction is
	            // not a  LeftHandSideExpression, nor does it start a ConditionalExpression.  So we are done
	            // with AssignmentExpression if we see one.
	            var arrowExpression = tryParseParenthesizedArrowFunctionExpression();
	            if (arrowExpression) {
	                return arrowExpression;
	            }
	            // Now try to see if we're in production '1', '2' or '3'.  A conditional expression can
	            // start with a LogicalOrExpression, while the assignment productions can only start with
	            // LeftHandSideExpressions.
	            //
	            // So, first, we try to just parse out a BinaryExpression.  If we get something that is a
	            // LeftHandSide or higher, then we can try to parse out the assignment expression part.
	            // Otherwise, we try to parse out the conditional expression bit.  We want to allow any
	            // binary expression here, so we pass in the 'lowest' precedence here so that it matches
	            // and consumes anything.
	            var expr = parseBinaryExpressionOrHigher(/*precedence*/ 0);
	            // To avoid a look-ahead, we did not handle the case of an arrow function with a single un-parenthesized
	            // parameter ('x => ...') above. We handle it here by checking if the parsed expression was a single
	            // identifier and the current token is an arrow.
	            if (expr.kind === 69 /* Identifier */ && token === 34 /* EqualsGreaterThanToken */) {
	                return parseSimpleArrowFunctionExpression(expr);
	            }
	            // Now see if we might be in cases '2' or '3'.
	            // If the expression was a LHS expression, and we have an assignment operator, then
	            // we're in '2' or '3'. Consume the assignment and return.
	            //
	            // Note: we call reScanGreaterToken so that we get an appropriately merged token
	            // for cases like > > =  becoming >>=
	            if (ts.isLeftHandSideExpression(expr) && ts.isAssignmentOperator(reScanGreaterToken())) {
	                return makeBinaryExpression(expr, parseTokenNode(), parseAssignmentExpressionOrHigher());
	            }
	            // It wasn't an assignment or a lambda.  This is a conditional expression:
	            return parseConditionalExpressionRest(expr);
	        }
	        function isYieldExpression() {
	            if (token === 114 /* YieldKeyword */) {
	                // If we have a 'yield' keyword, and htis is a context where yield expressions are
	                // allowed, then definitely parse out a yield expression.
	                if (inYieldContext()) {
	                    return true;
	                }
	                // We're in a context where 'yield expr' is not allowed.  However, if we can
	                // definitely tell that the user was trying to parse a 'yield expr' and not
	                // just a normal expr that start with a 'yield' identifier, then parse out
	                // a 'yield expr'.  We can then report an error later that they are only
	                // allowed in generator expressions.
	                //
	                // for example, if we see 'yield(foo)', then we'll have to treat that as an
	                // invocation expression of something called 'yield'.  However, if we have
	                // 'yield foo' then that is not legal as a normal expression, so we can
	                // definitely recognize this as a yield expression.
	                //
	                // for now we just check if the next token is an identifier.  More heuristics
	                // can be added here later as necessary.  We just need to make sure that we
	                // don't accidently consume something legal.
	                return lookAhead(nextTokenIsIdentifierOrKeywordOrNumberOnSameLine);
	            }
	            return false;
	        }
	        function nextTokenIsIdentifierOnSameLine() {
	            nextToken();
	            return !scanner.hasPrecedingLineBreak() && isIdentifier();
	        }
	        function parseYieldExpression() {
	            var node = createNode(187 /* YieldExpression */);
	            // YieldExpression[In] :
	            //      yield
	            //      yield [no LineTerminator here] [Lexical goal InputElementRegExp]AssignmentExpression[?In, Yield]
	            //      yield [no LineTerminator here] * [Lexical goal InputElementRegExp]AssignmentExpression[?In, Yield]
	            nextToken();
	            if (!scanner.hasPrecedingLineBreak() &&
	                (token === 37 /* AsteriskToken */ || isStartOfExpression())) {
	                node.asteriskToken = parseOptionalToken(37 /* AsteriskToken */);
	                node.expression = parseAssignmentExpressionOrHigher();
	                return finishNode(node);
	            }
	            else {
	                // if the next token is not on the same line as yield.  or we don't have an '*' or
	                // the start of an expressin, then this is just a simple "yield" expression.
	                return finishNode(node);
	            }
	        }
	        function parseSimpleArrowFunctionExpression(identifier) {
	            ts.Debug.assert(token === 34 /* EqualsGreaterThanToken */, "parseSimpleArrowFunctionExpression should only have been called if we had a =>");
	            var node = createNode(177 /* ArrowFunction */, identifier.pos);
	            var parameter = createNode(139 /* Parameter */, identifier.pos);
	            parameter.name = identifier;
	            finishNode(parameter);
	            node.parameters = [parameter];
	            node.parameters.pos = parameter.pos;
	            node.parameters.end = parameter.end;
	            node.equalsGreaterThanToken = parseExpectedToken(34 /* EqualsGreaterThanToken */, /*reportAtCurrentPosition*/ false, ts.Diagnostics._0_expected, "=>");
	            node.body = parseArrowFunctionExpressionBody(/*isAsync*/ false);
	            return finishNode(node);
	        }
	        function tryParseParenthesizedArrowFunctionExpression() {
	            var triState = isParenthesizedArrowFunctionExpression();
	            if (triState === 0 /* False */) {
	                // It's definitely not a parenthesized arrow function expression.
	                return undefined;
	            }
	            // If we definitely have an arrow function, then we can just parse one, not requiring a
	            // following => or { token. Otherwise, we *might* have an arrow function.  Try to parse
	            // it out, but don't allow any ambiguity, and return 'undefined' if this could be an
	            // expression instead.
	            var arrowFunction = triState === 1 /* True */
	                ? parseParenthesizedArrowFunctionExpressionHead(/*allowAmbiguity*/ true)
	                : tryParse(parsePossibleParenthesizedArrowFunctionExpressionHead);
	            if (!arrowFunction) {
	                // Didn't appear to actually be a parenthesized arrow function.  Just bail out.
	                return undefined;
	            }
	            var isAsync = !!(arrowFunction.flags & 256 /* Async */);
	            // If we have an arrow, then try to parse the body. Even if not, try to parse if we
	            // have an opening brace, just in case we're in an error state.
	            var lastToken = token;
	            arrowFunction.equalsGreaterThanToken = parseExpectedToken(34 /* EqualsGreaterThanToken */, /*reportAtCurrentPosition*/ false, ts.Diagnostics._0_expected, "=>");
	            arrowFunction.body = (lastToken === 34 /* EqualsGreaterThanToken */ || lastToken === 15 /* OpenBraceToken */)
	                ? parseArrowFunctionExpressionBody(isAsync)
	                : parseIdentifier();
	            return finishNode(arrowFunction);
	        }
	        //  True        -> We definitely expect a parenthesized arrow function here.
	        //  False       -> There *cannot* be a parenthesized arrow function here.
	        //  Unknown     -> There *might* be a parenthesized arrow function here.
	        //                 Speculatively look ahead to be sure, and rollback if not.
	        function isParenthesizedArrowFunctionExpression() {
	            if (token === 17 /* OpenParenToken */ || token === 25 /* LessThanToken */ || token === 118 /* AsyncKeyword */) {
	                return lookAhead(isParenthesizedArrowFunctionExpressionWorker);
	            }
	            if (token === 34 /* EqualsGreaterThanToken */) {
	                // ERROR RECOVERY TWEAK:
	                // If we see a standalone => try to parse it as an arrow function expression as that's
	                // likely what the user intended to write.
	                return 1 /* True */;
	            }
	            // Definitely not a parenthesized arrow function.
	            return 0 /* False */;
	        }
	        function isParenthesizedArrowFunctionExpressionWorker() {
	            if (token === 118 /* AsyncKeyword */) {
	                nextToken();
	                if (scanner.hasPrecedingLineBreak()) {
	                    return 0 /* False */;
	                }
	                if (token !== 17 /* OpenParenToken */ && token !== 25 /* LessThanToken */) {
	                    return 0 /* False */;
	                }
	            }
	            var first = token;
	            var second = nextToken();
	            if (first === 17 /* OpenParenToken */) {
	                if (second === 18 /* CloseParenToken */) {
	                    // Simple cases: "() =>", "(): ", and  "() {".
	                    // This is an arrow function with no parameters.
	                    // The last one is not actually an arrow function,
	                    // but this is probably what the user intended.
	                    var third = nextToken();
	                    switch (third) {
	                        case 34 /* EqualsGreaterThanToken */:
	                        case 54 /* ColonToken */:
	                        case 15 /* OpenBraceToken */:
	                            return 1 /* True */;
	                        default:
	                            return 0 /* False */;
	                    }
	                }
	                // If encounter "([" or "({", this could be the start of a binding pattern.
	                // Examples:
	                //      ([ x ]) => { }
	                //      ({ x }) => { }
	                //      ([ x ])
	                //      ({ x })
	                if (second === 19 /* OpenBracketToken */ || second === 15 /* OpenBraceToken */) {
	                    return 2 /* Unknown */;
	                }
	                // Simple case: "(..."
	                // This is an arrow function with a rest parameter.
	                if (second === 22 /* DotDotDotToken */) {
	                    return 1 /* True */;
	                }
	                // If we had "(" followed by something that's not an identifier,
	                // then this definitely doesn't look like a lambda.
	                // Note: we could be a little more lenient and allow
	                // "(public" or "(private". These would not ever actually be allowed,
	                // but we could provide a good error message instead of bailing out.
	                if (!isIdentifier()) {
	                    return 0 /* False */;
	                }
	                // If we have something like "(a:", then we must have a
	                // type-annotated parameter in an arrow function expression.
	                if (nextToken() === 54 /* ColonToken */) {
	                    return 1 /* True */;
	                }
	                // This *could* be a parenthesized arrow function.
	                // Return Unknown to let the caller know.
	                return 2 /* Unknown */;
	            }
	            else {
	                ts.Debug.assert(first === 25 /* LessThanToken */);
	                // If we have "<" not followed by an identifier,
	                // then this definitely is not an arrow function.
	                if (!isIdentifier()) {
	                    return 0 /* False */;
	                }
	                // JSX overrides
	                if (sourceFile.languageVariant === 1 /* JSX */) {
	                    var isArrowFunctionInJsx = lookAhead(function () {
	                        var third = nextToken();
	                        if (third === 83 /* ExtendsKeyword */) {
	                            var fourth = nextToken();
	                            switch (fourth) {
	                                case 56 /* EqualsToken */:
	                                case 27 /* GreaterThanToken */:
	                                    return false;
	                                default:
	                                    return true;
	                            }
	                        }
	                        else if (third === 24 /* CommaToken */) {
	                            return true;
	                        }
	                        return false;
	                    });
	                    if (isArrowFunctionInJsx) {
	                        return 1 /* True */;
	                    }
	                    return 0 /* False */;
	                }
	                // This *could* be a parenthesized arrow function.
	                return 2 /* Unknown */;
	            }
	        }
	        function parsePossibleParenthesizedArrowFunctionExpressionHead() {
	            return parseParenthesizedArrowFunctionExpressionHead(/*allowAmbiguity*/ false);
	        }
	        function parseParenthesizedArrowFunctionExpressionHead(allowAmbiguity) {
	            var node = createNode(177 /* ArrowFunction */);
	            setModifiers(node, parseModifiersForArrowFunction());
	            var isAsync = !!(node.flags & 256 /* Async */);
	            // Arrow functions are never generators.
	            //
	            // If we're speculatively parsing a signature for a parenthesized arrow function, then
	            // we have to have a complete parameter list.  Otherwise we might see something like
	            // a => (b => c)
	            // And think that "(b =>" was actually a parenthesized arrow function with a missing
	            // close paren.
	            fillSignature(54 /* ColonToken */, /*yieldContext*/ false, /*awaitContext*/ isAsync, /*requireCompleteParameterList*/ !allowAmbiguity, node);
	            // If we couldn't get parameters, we definitely could not parse out an arrow function.
	            if (!node.parameters) {
	                return undefined;
	            }
	            // Parsing a signature isn't enough.
	            // Parenthesized arrow signatures often look like other valid expressions.
	            // For instance:
	            //  - "(x = 10)" is an assignment expression parsed as a signature with a default parameter value.
	            //  - "(x,y)" is a comma expression parsed as a signature with two parameters.
	            //  - "a ? (b): c" will have "(b):" parsed as a signature with a return type annotation.
	            //
	            // So we need just a bit of lookahead to ensure that it can only be a signature.
	            if (!allowAmbiguity && token !== 34 /* EqualsGreaterThanToken */ && token !== 15 /* OpenBraceToken */) {
	                // Returning undefined here will cause our caller to rewind to where we started from.
	                return undefined;
	            }
	            return node;
	        }
	        function parseArrowFunctionExpressionBody(isAsync) {
	            if (token === 15 /* OpenBraceToken */) {
	                return parseFunctionBlock(/*allowYield*/ false, /*allowAwait*/ isAsync, /*ignoreMissingOpenBrace*/ false);
	            }
	            if (token !== 23 /* SemicolonToken */ &&
	                token !== 87 /* FunctionKeyword */ &&
	                token !== 73 /* ClassKeyword */ &&
	                isStartOfStatement() &&
	                !isStartOfExpressionStatement()) {
	                // Check if we got a plain statement (i.e. no expression-statements, no function/class expressions/declarations)
	                //
	                // Here we try to recover from a potential error situation in the case where the
	                // user meant to supply a block. For example, if the user wrote:
	                //
	                //  a =>
	                //      let v = 0;
	                //  }
	                //
	                // they may be missing an open brace.  Check to see if that's the case so we can
	                // try to recover better.  If we don't do this, then the next close curly we see may end
	                // up preemptively closing the containing construct.
	                //
	                // Note: even when 'ignoreMissingOpenBrace' is passed as true, parseBody will still error.
	                return parseFunctionBlock(/*allowYield*/ false, /*allowAwait*/ isAsync, /*ignoreMissingOpenBrace*/ true);
	            }
	            return isAsync
	                ? doInAwaitContext(parseAssignmentExpressionOrHigher)
	                : doOutsideOfAwaitContext(parseAssignmentExpressionOrHigher);
	        }
	        function parseConditionalExpressionRest(leftOperand) {
	            // Note: we are passed in an expression which was produced from parseBinaryExpressionOrHigher.
	            var questionToken = parseOptionalToken(53 /* QuestionToken */);
	            if (!questionToken) {
	                return leftOperand;
	            }
	            // Note: we explicitly 'allowIn' in the whenTrue part of the condition expression, and
	            // we do not that for the 'whenFalse' part.
	            var node = createNode(185 /* ConditionalExpression */, leftOperand.pos);
	            node.condition = leftOperand;
	            node.questionToken = questionToken;
	            node.whenTrue = doOutsideOfContext(disallowInAndDecoratorContext, parseAssignmentExpressionOrHigher);
	            node.colonToken = parseExpectedToken(54 /* ColonToken */, /*reportAtCurrentPosition*/ false, ts.Diagnostics._0_expected, ts.tokenToString(54 /* ColonToken */));
	            node.whenFalse = parseAssignmentExpressionOrHigher();
	            return finishNode(node);
	        }
	        function parseBinaryExpressionOrHigher(precedence) {
	            var leftOperand = parseUnaryExpressionOrHigher();
	            return parseBinaryExpressionRest(precedence, leftOperand);
	        }
	        function isInOrOfKeyword(t) {
	            return t === 90 /* InKeyword */ || t === 135 /* OfKeyword */;
	        }
	        function parseBinaryExpressionRest(precedence, leftOperand) {
	            while (true) {
	                // We either have a binary operator here, or we're finished.  We call
	                // reScanGreaterToken so that we merge token sequences like > and = into >=
	                reScanGreaterToken();
	                var newPrecedence = getBinaryOperatorPrecedence();
	                // Check the precedence to see if we should "take" this operator
	                // - For left associative operator (all operator but **), consume the operator,
	                //   recursively call the function below, and parse binaryExpression as a rightOperand
	                //   of the caller if the new precendence of the operator is greater then or equal to the current precendence.
	                //   For example:
	                //      a - b - c;
	                //            ^token; leftOperand = b. Return b to the caller as a rightOperand
	                //      a * b - c
	                //            ^token; leftOperand = b. Return b to the caller as a rightOperand
	                //      a - b * c;
	                //            ^token; leftOperand = b. Return b * c to the caller as a rightOperand
	                // - For right associative operator (**), consume the operator, recursively call the function
	                //   and parse binaryExpression as a rightOperand of the caller if the new precendence of
	                //   the operator is strictly grater than the current precendence
	                //   For example:
	                //      a ** b ** c;
	                //             ^^token; leftOperand = b. Return b ** c to the caller as a rightOperand
	                //      a - b ** c;
	                //            ^^token; leftOperand = b. Return b ** c to the caller as a rightOperand
	                //      a ** b - c
	                //             ^token; leftOperand = b. Return b to the caller as a rightOperand
	                var consumeCurrentOperator = token === 38 /* AsteriskAsteriskToken */ ?
	                    newPrecedence >= precedence :
	                    newPrecedence > precedence;
	                if (!consumeCurrentOperator) {
	                    break;
	                }
	                if (token === 90 /* InKeyword */ && inDisallowInContext()) {
	                    break;
	                }
	                if (token === 116 /* AsKeyword */) {
	                    // Make sure we *do* perform ASI for constructs like this:
	                    //    var x = foo
	                    //    as (Bar)
	                    // This should be parsed as an initialized variable, followed
	                    // by a function call to 'as' with the argument 'Bar'
	                    if (scanner.hasPrecedingLineBreak()) {
	                        break;
	                    }
	                    else {
	                        nextToken();
	                        leftOperand = makeAsExpression(leftOperand, parseType());
	                    }
	                }
	                else {
	                    leftOperand = makeBinaryExpression(leftOperand, parseTokenNode(), parseBinaryExpressionOrHigher(newPrecedence));
	                }
	            }
	            return leftOperand;
	        }
	        function isBinaryOperator() {
	            if (inDisallowInContext() && token === 90 /* InKeyword */) {
	                return false;
	            }
	            return getBinaryOperatorPrecedence() > 0;
	        }
	        function getBinaryOperatorPrecedence() {
	            switch (token) {
	                case 52 /* BarBarToken */:
	                    return 1;
	                case 51 /* AmpersandAmpersandToken */:
	                    return 2;
	                case 47 /* BarToken */:
	                    return 3;
	                case 48 /* CaretToken */:
	                    return 4;
	                case 46 /* AmpersandToken */:
	                    return 5;
	                case 30 /* EqualsEqualsToken */:
	                case 31 /* ExclamationEqualsToken */:
	                case 32 /* EqualsEqualsEqualsToken */:
	                case 33 /* ExclamationEqualsEqualsToken */:
	                    return 6;
	                case 25 /* LessThanToken */:
	                case 27 /* GreaterThanToken */:
	                case 28 /* LessThanEqualsToken */:
	                case 29 /* GreaterThanEqualsToken */:
	                case 91 /* InstanceOfKeyword */:
	                case 90 /* InKeyword */:
	                case 116 /* AsKeyword */:
	                    return 7;
	                case 43 /* LessThanLessThanToken */:
	                case 44 /* GreaterThanGreaterThanToken */:
	                case 45 /* GreaterThanGreaterThanGreaterThanToken */:
	                    return 8;
	                case 35 /* PlusToken */:
	                case 36 /* MinusToken */:
	                    return 9;
	                case 37 /* AsteriskToken */:
	                case 39 /* SlashToken */:
	                case 40 /* PercentToken */:
	                    return 10;
	                case 38 /* AsteriskAsteriskToken */:
	                    return 11;
	            }
	            // -1 is lower than all other precedences.  Returning it will cause binary expression
	            // parsing to stop.
	            return -1;
	        }
	        function makeBinaryExpression(left, operatorToken, right) {
	            var node = createNode(184 /* BinaryExpression */, left.pos);
	            node.left = left;
	            node.operatorToken = operatorToken;
	            node.right = right;
	            return finishNode(node);
	        }
	        function makeAsExpression(left, right) {
	            var node = createNode(192 /* AsExpression */, left.pos);
	            node.expression = left;
	            node.type = right;
	            return finishNode(node);
	        }
	        function parsePrefixUnaryExpression() {
	            var node = createNode(182 /* PrefixUnaryExpression */);
	            node.operator = token;
	            nextToken();
	            node.operand = parseSimpleUnaryExpression();
	            return finishNode(node);
	        }
	        function parseDeleteExpression() {
	            var node = createNode(178 /* DeleteExpression */);
	            nextToken();
	            node.expression = parseSimpleUnaryExpression();
	            return finishNode(node);
	        }
	        function parseTypeOfExpression() {
	            var node = createNode(179 /* TypeOfExpression */);
	            nextToken();
	            node.expression = parseSimpleUnaryExpression();
	            return finishNode(node);
	        }
	        function parseVoidExpression() {
	            var node = createNode(180 /* VoidExpression */);
	            nextToken();
	            node.expression = parseSimpleUnaryExpression();
	            return finishNode(node);
	        }
	        function isAwaitExpression() {
	            if (token === 119 /* AwaitKeyword */) {
	                if (inAwaitContext()) {
	                    return true;
	                }
	                // here we are using similar heuristics as 'isYieldExpression'
	                return lookAhead(nextTokenIsIdentifierOnSameLine);
	            }
	            return false;
	        }
	        function parseAwaitExpression() {
	            var node = createNode(181 /* AwaitExpression */);
	            nextToken();
	            node.expression = parseSimpleUnaryExpression();
	            return finishNode(node);
	        }
	        /**
	         * Parse ES7 unary expression and await expression
	         *
	         * ES7 UnaryExpression:
	         *      1) SimpleUnaryExpression[?yield]
	         *      2) IncrementExpression[?yield] ** UnaryExpression[?yield]
	         */
	        function parseUnaryExpressionOrHigher() {
	            if (isAwaitExpression()) {
	                return parseAwaitExpression();
	            }
	            if (isIncrementExpression()) {
	                var incrementExpression = parseIncrementExpression();
	                return token === 38 /* AsteriskAsteriskToken */ ?
	                    parseBinaryExpressionRest(getBinaryOperatorPrecedence(), incrementExpression) :
	                    incrementExpression;
	            }
	            var unaryOperator = token;
	            var simpleUnaryExpression = parseSimpleUnaryExpression();
	            if (token === 38 /* AsteriskAsteriskToken */) {
	                var start = ts.skipTrivia(sourceText, simpleUnaryExpression.pos);
	                if (simpleUnaryExpression.kind === 174 /* TypeAssertionExpression */) {
	                    parseErrorAtPosition(start, simpleUnaryExpression.end - start, ts.Diagnostics.A_type_assertion_expression_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Consider_enclosing_the_expression_in_parentheses);
	                }
	                else {
	                    parseErrorAtPosition(start, simpleUnaryExpression.end - start, ts.Diagnostics.An_unary_expression_with_the_0_operator_is_not_allowed_in_the_left_hand_side_of_an_exponentiation_expression_Consider_enclosing_the_expression_in_parentheses, ts.tokenToString(unaryOperator));
	                }
	            }
	            return simpleUnaryExpression;
	        }
	        /**
	         * Parse ES7 simple-unary expression or higher:
	         *
	         * ES7 SimpleUnaryExpression:
	         *      1) IncrementExpression[?yield]
	         *      2) delete UnaryExpression[?yield]
	         *      3) void UnaryExpression[?yield]
	         *      4) typeof UnaryExpression[?yield]
	         *      5) + UnaryExpression[?yield]
	         *      6) - UnaryExpression[?yield]
	         *      7) ~ UnaryExpression[?yield]
	         *      8) ! UnaryExpression[?yield]
	         */
	        function parseSimpleUnaryExpression() {
	            switch (token) {
	                case 35 /* PlusToken */:
	                case 36 /* MinusToken */:
	                case 50 /* TildeToken */:
	                case 49 /* ExclamationToken */:
	                    return parsePrefixUnaryExpression();
	                case 78 /* DeleteKeyword */:
	                    return parseDeleteExpression();
	                case 101 /* TypeOfKeyword */:
	                    return parseTypeOfExpression();
	                case 103 /* VoidKeyword */:
	                    return parseVoidExpression();
	                case 25 /* LessThanToken */:
	                    // This is modified UnaryExpression grammar in TypeScript
	                    //  UnaryExpression (modified):
	                    //      < type > UnaryExpression
	                    return parseTypeAssertion();
	                default:
	                    return parseIncrementExpression();
	            }
	        }
	        /**
	         * Check if the current token can possibly be an ES7 increment expression.
	         *
	         * ES7 IncrementExpression:
	         *      LeftHandSideExpression[?Yield]
	         *      LeftHandSideExpression[?Yield][no LineTerminator here]++
	         *      LeftHandSideExpression[?Yield][no LineTerminator here]--
	         *      ++LeftHandSideExpression[?Yield]
	         *      --LeftHandSideExpression[?Yield]
	         */
	        function isIncrementExpression() {
	            // This function is called inside parseUnaryExpression to decide
	            // whether to call parseSimpleUnaryExpression or call parseIncrmentExpression directly
	            switch (token) {
	                case 35 /* PlusToken */:
	                case 36 /* MinusToken */:
	                case 50 /* TildeToken */:
	                case 49 /* ExclamationToken */:
	                case 78 /* DeleteKeyword */:
	                case 101 /* TypeOfKeyword */:
	                case 103 /* VoidKeyword */:
	                    return false;
	                case 25 /* LessThanToken */:
	                    // If we are not in JSX context, we are parsing TypeAssertion which is an UnaryExpression
	                    if (sourceFile.languageVariant !== 1 /* JSX */) {
	                        return false;
	                    }
	                // We are in JSX context and the token is part of JSXElement.
	                // Fall through
	                default:
	                    return true;
	            }
	        }
	        /**
	         * Parse ES7 IncrementExpression. IncrementExpression is used instead of ES6's PostFixExpression.
	         *
	         * ES7 IncrementExpression[yield]:
	         *      1) LeftHandSideExpression[?yield]
	         *      2) LeftHandSideExpression[?yield] [[no LineTerminator here]]++
	         *      3) LeftHandSideExpression[?yield] [[no LineTerminator here]]--
	         *      4) ++LeftHandSideExpression[?yield]
	         *      5) --LeftHandSideExpression[?yield]
	         * In TypeScript (2), (3) are parsed as PostfixUnaryExpression. (4), (5) are parsed as PrefixUnaryExpression
	         */
	        function parseIncrementExpression() {
	            if (token === 41 /* PlusPlusToken */ || token === 42 /* MinusMinusToken */) {
	                var node = createNode(182 /* PrefixUnaryExpression */);
	                node.operator = token;
	                nextToken();
	                node.operand = parseLeftHandSideExpressionOrHigher();
	                return finishNode(node);
	            }
	            else if (sourceFile.languageVariant === 1 /* JSX */ && token === 25 /* LessThanToken */ && lookAhead(nextTokenIsIdentifierOrKeyword)) {
	                // JSXElement is part of primaryExpression
	                return parseJsxElementOrSelfClosingElement(/*inExpressionContext*/ true);
	            }
	            var expression = parseLeftHandSideExpressionOrHigher();
	            ts.Debug.assert(ts.isLeftHandSideExpression(expression));
	            if ((token === 41 /* PlusPlusToken */ || token === 42 /* MinusMinusToken */) && !scanner.hasPrecedingLineBreak()) {
	                var node = createNode(183 /* PostfixUnaryExpression */, expression.pos);
	                node.operand = expression;
	                node.operator = token;
	                nextToken();
	                return finishNode(node);
	            }
	            return expression;
	        }
	        function parseLeftHandSideExpressionOrHigher() {
	            // Original Ecma:
	            // LeftHandSideExpression: See 11.2
	            //      NewExpression
	            //      CallExpression
	            //
	            // Our simplification:
	            //
	            // LeftHandSideExpression: See 11.2
	            //      MemberExpression
	            //      CallExpression
	            //
	            // See comment in parseMemberExpressionOrHigher on how we replaced NewExpression with
	            // MemberExpression to make our lives easier.
	            //
	            // to best understand the below code, it's important to see how CallExpression expands
	            // out into its own productions:
	            //
	            // CallExpression:
	            //      MemberExpression Arguments
	            //      CallExpression Arguments
	            //      CallExpression[Expression]
	            //      CallExpression.IdentifierName
	            //      super   (   ArgumentListopt   )
	            //      super.IdentifierName
	            //
	            // Because of the recursion in these calls, we need to bottom out first.  There are two
	            // bottom out states we can run into.  Either we see 'super' which must start either of
	            // the last two CallExpression productions.  Or we have a MemberExpression which either
	            // completes the LeftHandSideExpression, or starts the beginning of the first four
	            // CallExpression productions.
	            var expression = token === 95 /* SuperKeyword */
	                ? parseSuperExpression()
	                : parseMemberExpressionOrHigher();
	            // Now, we *may* be complete.  However, we might have consumed the start of a
	            // CallExpression.  As such, we need to consume the rest of it here to be complete.
	            return parseCallExpressionRest(expression);
	        }
	        function parseMemberExpressionOrHigher() {
	            // Note: to make our lives simpler, we decompose the the NewExpression productions and
	            // place ObjectCreationExpression and FunctionExpression into PrimaryExpression.
	            // like so:
	            //
	            //   PrimaryExpression : See 11.1
	            //      this
	            //      Identifier
	            //      Literal
	            //      ArrayLiteral
	            //      ObjectLiteral
	            //      (Expression)
	            //      FunctionExpression
	            //      new MemberExpression Arguments?
	            //
	            //   MemberExpression : See 11.2
	            //      PrimaryExpression
	            //      MemberExpression[Expression]
	            //      MemberExpression.IdentifierName
	            //
	            //   CallExpression : See 11.2
	            //      MemberExpression
	            //      CallExpression Arguments
	            //      CallExpression[Expression]
	            //      CallExpression.IdentifierName
	            //
	            // Technically this is ambiguous.  i.e. CallExpression defines:
	            //
	            //   CallExpression:
	            //      CallExpression Arguments
	            //
	            // If you see: "new Foo()"
	            //
	            // Then that could be treated as a single ObjectCreationExpression, or it could be
	            // treated as the invocation of "new Foo".  We disambiguate that in code (to match
	            // the original grammar) by making sure that if we see an ObjectCreationExpression
	            // we always consume arguments if they are there. So we treat "new Foo()" as an
	            // object creation only, and not at all as an invocation)  Another way to think
	            // about this is that for every "new" that we see, we will consume an argument list if
	            // it is there as part of the *associated* object creation node.  Any additional
	            // argument lists we see, will become invocation expressions.
	            //
	            // Because there are no other places in the grammar now that refer to FunctionExpression
	            // or ObjectCreationExpression, it is safe to push down into the PrimaryExpression
	            // production.
	            //
	            // Because CallExpression and MemberExpression are left recursive, we need to bottom out
	            // of the recursion immediately.  So we parse out a primary expression to start with.
	            var expression = parsePrimaryExpression();
	            return parseMemberExpressionRest(expression);
	        }
	        function parseSuperExpression() {
	            var expression = parseTokenNode();
	            if (token === 17 /* OpenParenToken */ || token === 21 /* DotToken */ || token === 19 /* OpenBracketToken */) {
	                return expression;
	            }
	            // If we have seen "super" it must be followed by '(' or '.'.
	            // If it wasn't then just try to parse out a '.' and report an error.
	            var node = createNode(169 /* PropertyAccessExpression */, expression.pos);
	            node.expression = expression;
	            node.dotToken = parseExpectedToken(21 /* DotToken */, /*reportAtCurrentPosition*/ false, ts.Diagnostics.super_must_be_followed_by_an_argument_list_or_member_access);
	            node.name = parseRightSideOfDot(/*allowIdentifierNames*/ true);
	            return finishNode(node);
	        }
	        function tagNamesAreEquivalent(lhs, rhs) {
	            if (lhs.kind !== rhs.kind) {
	                return false;
	            }
	            if (lhs.kind === 69 /* Identifier */) {
	                return lhs.text === rhs.text;
	            }
	            return lhs.right.text === rhs.right.text &&
	                tagNamesAreEquivalent(lhs.left, rhs.left);
	        }
	        function parseJsxElementOrSelfClosingElement(inExpressionContext) {
	            var opening = parseJsxOpeningOrSelfClosingElement(inExpressionContext);
	            var result;
	            if (opening.kind === 238 /* JsxOpeningElement */) {
	                var node = createNode(236 /* JsxElement */, opening.pos);
	                node.openingElement = opening;
	                node.children = parseJsxChildren(node.openingElement.tagName);
	                node.closingElement = parseJsxClosingElement(inExpressionContext);
	                if (!tagNamesAreEquivalent(node.openingElement.tagName, node.closingElement.tagName)) {
	                    parseErrorAtPosition(node.closingElement.pos, node.closingElement.end - node.closingElement.pos, ts.Diagnostics.Expected_corresponding_JSX_closing_tag_for_0, ts.getTextOfNodeFromSourceText(sourceText, node.openingElement.tagName));
	                }
	                result = finishNode(node);
	            }
	            else {
	                ts.Debug.assert(opening.kind === 237 /* JsxSelfClosingElement */);
	                // Nothing else to do for self-closing elements
	                result = opening;
	            }
	            // If the user writes the invalid code '<div></div><div></div>' in an expression context (i.e. not wrapped in
	            // an enclosing tag), we'll naively try to parse   ^ this as a 'less than' operator and the remainder of the tag
	            // as garbage, which will cause the formatter to badly mangle the JSX. Perform a speculative parse of a JSX
	            // element if we see a < token so that we can wrap it in a synthetic binary expression so the formatter
	            // does less damage and we can report a better error.
	            // Since JSX elements are invalid < operands anyway, this lookahead parse will only occur in error scenarios
	            // of one sort or another.
	            if (inExpressionContext && token === 25 /* LessThanToken */) {
	                var invalidElement = tryParse(function () { return parseJsxElementOrSelfClosingElement(/*inExpressionContext*/ true); });
	                if (invalidElement) {
	                    parseErrorAtCurrentToken(ts.Diagnostics.JSX_expressions_must_have_one_parent_element);
	                    var badNode = createNode(184 /* BinaryExpression */, result.pos);
	                    badNode.end = invalidElement.end;
	                    badNode.left = result;
	                    badNode.right = invalidElement;
	                    badNode.operatorToken = createMissingNode(24 /* CommaToken */, /*reportAtCurrentPosition*/ false, /*diagnosticMessage*/ undefined);
	                    badNode.operatorToken.pos = badNode.operatorToken.end = badNode.right.pos;
	                    return badNode;
	                }
	            }
	            return result;
	        }
	        function parseJsxText() {
	            var node = createNode(239 /* JsxText */, scanner.getStartPos());
	            token = scanner.scanJsxToken();
	            return finishNode(node);
	        }
	        function parseJsxChild() {
	            switch (token) {
	                case 239 /* JsxText */:
	                    return parseJsxText();
	                case 15 /* OpenBraceToken */:
	                    return parseJsxExpression(/*inExpressionContext*/ false);
	                case 25 /* LessThanToken */:
	                    return parseJsxElementOrSelfClosingElement(/*inExpressionContext*/ false);
	            }
	            ts.Debug.fail("Unknown JSX child kind " + token);
	        }
	        function parseJsxChildren(openingTagName) {
	            var result = [];
	            result.pos = scanner.getStartPos();
	            var saveParsingContext = parsingContext;
	            parsingContext |= 1 << 14 /* JsxChildren */;
	            while (true) {
	                token = scanner.reScanJsxToken();
	                if (token === 26 /* LessThanSlashToken */) {
	                    // Closing tag
	                    break;
	                }
	                else if (token === 1 /* EndOfFileToken */) {
	                    // If we hit EOF, issue the error at the tag that lacks the closing element
	                    // rather than at the end of the file (which is useless)
	                    parseErrorAtPosition(openingTagName.pos, openingTagName.end - openingTagName.pos, ts.Diagnostics.JSX_element_0_has_no_corresponding_closing_tag, ts.getTextOfNodeFromSourceText(sourceText, openingTagName));
	                    break;
	                }
	                result.push(parseJsxChild());
	            }
	            result.end = scanner.getTokenPos();
	            parsingContext = saveParsingContext;
	            return result;
	        }
	        function parseJsxOpeningOrSelfClosingElement(inExpressionContext) {
	            var fullStart = scanner.getStartPos();
	            parseExpected(25 /* LessThanToken */);
	            var tagName = parseJsxElementName();
	            var attributes = parseList(13 /* JsxAttributes */, parseJsxAttribute);
	            var node;
	            if (token === 27 /* GreaterThanToken */) {
	                // Closing tag, so scan the immediately-following text with the JSX scanning instead
	                // of regular scanning to avoid treating illegal characters (e.g. '#') as immediate
	                // scanning errors
	                node = createNode(238 /* JsxOpeningElement */, fullStart);
	                scanJsxText();
	            }
	            else {
	                parseExpected(39 /* SlashToken */);
	                if (inExpressionContext) {
	                    parseExpected(27 /* GreaterThanToken */);
	                }
	                else {
	                    parseExpected(27 /* GreaterThanToken */, /*diagnostic*/ undefined, /*shouldAdvance*/ false);
	                    scanJsxText();
	                }
	                node = createNode(237 /* JsxSelfClosingElement */, fullStart);
	            }
	            node.tagName = tagName;
	            node.attributes = attributes;
	            return finishNode(node);
	        }
	        function parseJsxElementName() {
	            scanJsxIdentifier();
	            var elementName = parseIdentifierName();
	            while (parseOptional(21 /* DotToken */)) {
	                scanJsxIdentifier();
	                var node = createNode(136 /* QualifiedName */, elementName.pos);
	                node.left = elementName;
	                node.right = parseIdentifierName();
	                elementName = finishNode(node);
	            }
	            return elementName;
	        }
	        function parseJsxExpression(inExpressionContext) {
	            var node = createNode(243 /* JsxExpression */);
	            parseExpected(15 /* OpenBraceToken */);
	            if (token !== 16 /* CloseBraceToken */) {
	                node.expression = parseAssignmentExpressionOrHigher();
	            }
	            if (inExpressionContext) {
	                parseExpected(16 /* CloseBraceToken */);
	            }
	            else {
	                parseExpected(16 /* CloseBraceToken */, /*message*/ undefined, /*shouldAdvance*/ false);
	                scanJsxText();
	            }
	            return finishNode(node);
	        }
	        function parseJsxAttribute() {
	            if (token === 15 /* OpenBraceToken */) {
	                return parseJsxSpreadAttribute();
	            }
	            scanJsxIdentifier();
	            var node = createNode(241 /* JsxAttribute */);
	            node.name = parseIdentifierName();
	            if (parseOptional(56 /* EqualsToken */)) {
	                switch (token) {
	                    case 9 /* StringLiteral */:
	                        node.initializer = parseLiteralNode();
	                        break;
	                    default:
	                        node.initializer = parseJsxExpression(/*inExpressionContext*/ true);
	                        break;
	                }
	            }
	            return finishNode(node);
	        }
	        function parseJsxSpreadAttribute() {
	            var node = createNode(242 /* JsxSpreadAttribute */);
	            parseExpected(15 /* OpenBraceToken */);
	            parseExpected(22 /* DotDotDotToken */);
	            node.expression = parseExpression();
	            parseExpected(16 /* CloseBraceToken */);
	            return finishNode(node);
	        }
	        function parseJsxClosingElement(inExpressionContext) {
	            var node = createNode(240 /* JsxClosingElement */);
	            parseExpected(26 /* LessThanSlashToken */);
	            node.tagName = parseJsxElementName();
	            if (inExpressionContext) {
	                parseExpected(27 /* GreaterThanToken */);
	            }
	            else {
	                parseExpected(27 /* GreaterThanToken */, /*diagnostic*/ undefined, /*shouldAdvance*/ false);
	                scanJsxText();
	            }
	            return finishNode(node);
	        }
	        function parseTypeAssertion() {
	            var node = createNode(174 /* TypeAssertionExpression */);
	            parseExpected(25 /* LessThanToken */);
	            node.type = parseType();
	            parseExpected(27 /* GreaterThanToken */);
	            node.expression = parseSimpleUnaryExpression();
	            return finishNode(node);
	        }
	        function parseMemberExpressionRest(expression) {
	            while (true) {
	                var dotToken = parseOptionalToken(21 /* DotToken */);
	                if (dotToken) {
	                    var propertyAccess = createNode(169 /* PropertyAccessExpression */, expression.pos);
	                    propertyAccess.expression = expression;
	                    propertyAccess.dotToken = dotToken;
	                    propertyAccess.name = parseRightSideOfDot(/*allowIdentifierNames*/ true);
	                    expression = finishNode(propertyAccess);
	                    continue;
	                }
	                // when in the [Decorator] context, we do not parse ElementAccess as it could be part of a ComputedPropertyName
	                if (!inDecoratorContext() && parseOptional(19 /* OpenBracketToken */)) {
	                    var indexedAccess = createNode(170 /* ElementAccessExpression */, expression.pos);
	                    indexedAccess.expression = expression;
	                    // It's not uncommon for a user to write: "new Type[]".
	                    // Check for that common pattern and report a better error message.
	                    if (token !== 20 /* CloseBracketToken */) {
	                        indexedAccess.argumentExpression = allowInAnd(parseExpression);
	                        if (indexedAccess.argumentExpression.kind === 9 /* StringLiteral */ || indexedAccess.argumentExpression.kind === 8 /* NumericLiteral */) {
	                            var literal = indexedAccess.argumentExpression;
	                            literal.text = internIdentifier(literal.text);
	                        }
	                    }
	                    parseExpected(20 /* CloseBracketToken */);
	                    expression = finishNode(indexedAccess);
	                    continue;
	                }
	                if (token === 11 /* NoSubstitutionTemplateLiteral */ || token === 12 /* TemplateHead */) {
	                    var tagExpression = createNode(173 /* TaggedTemplateExpression */, expression.pos);
	                    tagExpression.tag = expression;
	                    tagExpression.template = token === 11 /* NoSubstitutionTemplateLiteral */
	                        ? parseLiteralNode()
	                        : parseTemplateExpression();
	                    expression = finishNode(tagExpression);
	                    continue;
	                }
	                return expression;
	            }
	        }
	        function parseCallExpressionRest(expression) {
	            while (true) {
	                expression = parseMemberExpressionRest(expression);
	                if (token === 25 /* LessThanToken */) {
	                    // See if this is the start of a generic invocation.  If so, consume it and
	                    // keep checking for postfix expressions.  Otherwise, it's just a '<' that's
	                    // part of an arithmetic expression.  Break out so we consume it higher in the
	                    // stack.
	                    var typeArguments = tryParse(parseTypeArgumentsInExpression);
	                    if (!typeArguments) {
	                        return expression;
	                    }
	                    var callExpr = createNode(171 /* CallExpression */, expression.pos);
	                    callExpr.expression = expression;
	                    callExpr.typeArguments = typeArguments;
	                    callExpr.arguments = parseArgumentList();
	                    expression = finishNode(callExpr);
	                    continue;
	                }
	                else if (token === 17 /* OpenParenToken */) {
	                    var callExpr = createNode(171 /* CallExpression */, expression.pos);
	                    callExpr.expression = expression;
	                    callExpr.arguments = parseArgumentList();
	                    expression = finishNode(callExpr);
	                    continue;
	                }
	                return expression;
	            }
	        }
	        function parseArgumentList() {
	            parseExpected(17 /* OpenParenToken */);
	            var result = parseDelimitedList(11 /* ArgumentExpressions */, parseArgumentExpression);
	            parseExpected(18 /* CloseParenToken */);
	            return result;
	        }
	        function parseTypeArgumentsInExpression() {
	            if (!parseOptional(25 /* LessThanToken */)) {
	                return undefined;
	            }
	            var typeArguments = parseDelimitedList(18 /* TypeArguments */, parseType);
	            if (!parseExpected(27 /* GreaterThanToken */)) {
	                // If it doesn't have the closing >  then it's definitely not an type argument list.
	                return undefined;
	            }
	            // If we have a '<', then only parse this as a arugment list if the type arguments
	            // are complete and we have an open paren.  if we don't, rewind and return nothing.
	            return typeArguments && canFollowTypeArgumentsInExpression()
	                ? typeArguments
	                : undefined;
	        }
	        function canFollowTypeArgumentsInExpression() {
	            switch (token) {
	                case 17 /* OpenParenToken */: // foo<x>(
	                // this case are the only case where this token can legally follow a type argument
	                // list.  So we definitely want to treat this as a type arg list.
	                case 21 /* DotToken */: // foo<x>.
	                case 18 /* CloseParenToken */: // foo<x>)
	                case 20 /* CloseBracketToken */: // foo<x>]
	                case 54 /* ColonToken */: // foo<x>:
	                case 23 /* SemicolonToken */: // foo<x>;
	                case 53 /* QuestionToken */: // foo<x>?
	                case 30 /* EqualsEqualsToken */: // foo<x> ==
	                case 32 /* EqualsEqualsEqualsToken */: // foo<x> ===
	                case 31 /* ExclamationEqualsToken */: // foo<x> !=
	                case 33 /* ExclamationEqualsEqualsToken */: // foo<x> !==
	                case 51 /* AmpersandAmpersandToken */: // foo<x> &&
	                case 52 /* BarBarToken */: // foo<x> ||
	                case 48 /* CaretToken */: // foo<x> ^
	                case 46 /* AmpersandToken */: // foo<x> &
	                case 47 /* BarToken */: // foo<x> |
	                case 16 /* CloseBraceToken */: // foo<x> }
	                case 1 /* EndOfFileToken */:
	                    // these cases can't legally follow a type arg list.  However, they're not legal
	                    // expressions either.  The user is probably in the middle of a generic type. So
	                    // treat it as such.
	                    return true;
	                case 24 /* CommaToken */: // foo<x>,
	                case 15 /* OpenBraceToken */: // foo<x> {
	                // We don't want to treat these as type arguments.  Otherwise we'll parse this
	                // as an invocation expression.  Instead, we want to parse out the expression
	                // in isolation from the type arguments.
	                default:
	                    // Anything else treat as an expression.
	                    return false;
	            }
	        }
	        function parsePrimaryExpression() {
	            switch (token) {
	                case 8 /* NumericLiteral */:
	                case 9 /* StringLiteral */:
	                case 11 /* NoSubstitutionTemplateLiteral */:
	                    return parseLiteralNode();
	                case 97 /* ThisKeyword */:
	                case 95 /* SuperKeyword */:
	                case 93 /* NullKeyword */:
	                case 99 /* TrueKeyword */:
	                case 84 /* FalseKeyword */:
	                    return parseTokenNode();
	                case 17 /* OpenParenToken */:
	                    return parseParenthesizedExpression();
	                case 19 /* OpenBracketToken */:
	                    return parseArrayLiteralExpression();
	                case 15 /* OpenBraceToken */:
	                    return parseObjectLiteralExpression();
	                case 118 /* AsyncKeyword */:
	                    // Async arrow functions are parsed earlier in parseAssignmentExpressionOrHigher.
	                    // If we encounter `async [no LineTerminator here] function` then this is an async
	                    // function; otherwise, its an identifier.
	                    if (!lookAhead(nextTokenIsFunctionKeywordOnSameLine)) {
	                        break;
	                    }
	                    return parseFunctionExpression();
	                case 73 /* ClassKeyword */:
	                    return parseClassExpression();
	                case 87 /* FunctionKeyword */:
	                    return parseFunctionExpression();
	                case 92 /* NewKeyword */:
	                    return parseNewExpression();
	                case 39 /* SlashToken */:
	                case 61 /* SlashEqualsToken */:
	                    if (reScanSlashToken() === 10 /* RegularExpressionLiteral */) {
	                        return parseLiteralNode();
	                    }
	                    break;
	                case 12 /* TemplateHead */:
	                    return parseTemplateExpression();
	            }
	            return parseIdentifier(ts.Diagnostics.Expression_expected);
	        }
	        function parseParenthesizedExpression() {
	            var node = createNode(175 /* ParenthesizedExpression */);
	            parseExpected(17 /* OpenParenToken */);
	            node.expression = allowInAnd(parseExpression);
	            parseExpected(18 /* CloseParenToken */);
	            return finishNode(node);
	        }
	        function parseSpreadElement() {
	            var node = createNode(188 /* SpreadElementExpression */);
	            parseExpected(22 /* DotDotDotToken */);
	            node.expression = parseAssignmentExpressionOrHigher();
	            return finishNode(node);
	        }
	        function parseArgumentOrArrayLiteralElement() {
	            return token === 22 /* DotDotDotToken */ ? parseSpreadElement() :
	                token === 24 /* CommaToken */ ? createNode(190 /* OmittedExpression */) :
	                    parseAssignmentExpressionOrHigher();
	        }
	        function parseArgumentExpression() {
	            return doOutsideOfContext(disallowInAndDecoratorContext, parseArgumentOrArrayLiteralElement);
	        }
	        function parseArrayLiteralExpression() {
	            var node = createNode(167 /* ArrayLiteralExpression */);
	            parseExpected(19 /* OpenBracketToken */);
	            if (scanner.hasPrecedingLineBreak())
	                node.flags |= 1024 /* MultiLine */;
	            node.elements = parseDelimitedList(15 /* ArrayLiteralMembers */, parseArgumentOrArrayLiteralElement);
	            parseExpected(20 /* CloseBracketToken */);
	            return finishNode(node);
	        }
	        function tryParseAccessorDeclaration(fullStart, decorators, modifiers) {
	            if (parseContextualModifier(123 /* GetKeyword */)) {
	                return parseAccessorDeclaration(146 /* GetAccessor */, fullStart, decorators, modifiers);
	            }
	            else if (parseContextualModifier(129 /* SetKeyword */)) {
	                return parseAccessorDeclaration(147 /* SetAccessor */, fullStart, decorators, modifiers);
	            }
	            return undefined;
	        }
	        function parseObjectLiteralElement() {
	            var fullStart = scanner.getStartPos();
	            var decorators = parseDecorators();
	            var modifiers = parseModifiers();
	            var accessor = tryParseAccessorDeclaration(fullStart, decorators, modifiers);
	            if (accessor) {
	                return accessor;
	            }
	            var asteriskToken = parseOptionalToken(37 /* AsteriskToken */);
	            var tokenIsIdentifier = isIdentifier();
	            var propertyName = parsePropertyName();
	            // Disallowing of optional property assignments happens in the grammar checker.
	            var questionToken = parseOptionalToken(53 /* QuestionToken */);
	            if (asteriskToken || token === 17 /* OpenParenToken */ || token === 25 /* LessThanToken */) {
	                return parseMethodDeclaration(fullStart, decorators, modifiers, asteriskToken, propertyName, questionToken);
	            }
	            // check if it is short-hand property assignment or normal property assignment
	            // NOTE: if token is EqualsToken it is interpreted as CoverInitializedName production
	            // CoverInitializedName[Yield] :
	            //     IdentifierReference[?Yield] Initializer[In, ?Yield]
	            // this is necessary because ObjectLiteral productions are also used to cover grammar for ObjectAssignmentPattern
	            var isShorthandPropertyAssignment = tokenIsIdentifier && (token === 24 /* CommaToken */ || token === 16 /* CloseBraceToken */ || token === 56 /* EqualsToken */);
	            if (isShorthandPropertyAssignment) {
	                var shorthandDeclaration = createNode(249 /* ShorthandPropertyAssignment */, fullStart);
	                shorthandDeclaration.name = propertyName;
	                shorthandDeclaration.questionToken = questionToken;
	                var equalsToken = parseOptionalToken(56 /* EqualsToken */);
	                if (equalsToken) {
	                    shorthandDeclaration.equalsToken = equalsToken;
	                    shorthandDeclaration.objectAssignmentInitializer = allowInAnd(parseAssignmentExpressionOrHigher);
	                }
	                return addJSDocComment(finishNode(shorthandDeclaration));
	            }
	            else {
	                var propertyAssignment = createNode(248 /* PropertyAssignment */, fullStart);
	                propertyAssignment.modifiers = modifiers;
	                propertyAssignment.name = propertyName;
	                propertyAssignment.questionToken = questionToken;
	                parseExpected(54 /* ColonToken */);
	                propertyAssignment.initializer = allowInAnd(parseAssignmentExpressionOrHigher);
	                return addJSDocComment(finishNode(propertyAssignment));
	            }
	        }
	        function parseObjectLiteralExpression() {
	            var node = createNode(168 /* ObjectLiteralExpression */);
	            parseExpected(15 /* OpenBraceToken */);
	            if (scanner.hasPrecedingLineBreak()) {
	                node.flags |= 1024 /* MultiLine */;
	            }
	            node.properties = parseDelimitedList(12 /* ObjectLiteralMembers */, parseObjectLiteralElement, /*considerSemicolonAsDelimeter*/ true);
	            parseExpected(16 /* CloseBraceToken */);
	            return finishNode(node);
	        }
	        function parseFunctionExpression() {
	            // GeneratorExpression:
	            //      function* BindingIdentifier [Yield][opt](FormalParameters[Yield]){ GeneratorBody }
	            //
	            // FunctionExpression:
	            //      function BindingIdentifier[opt](FormalParameters){ FunctionBody }
	            var saveDecoratorContext = inDecoratorContext();
	            if (saveDecoratorContext) {
	                setDecoratorContext(/*val*/ false);
	            }
	            var node = createNode(176 /* FunctionExpression */);
	            setModifiers(node, parseModifiers());
	            parseExpected(87 /* FunctionKeyword */);
	            node.asteriskToken = parseOptionalToken(37 /* AsteriskToken */);
	            var isGenerator = !!node.asteriskToken;
	            var isAsync = !!(node.flags & 256 /* Async */);
	            node.name =
	                isGenerator && isAsync ? doInYieldAndAwaitContext(parseOptionalIdentifier) :
	                    isGenerator ? doInYieldContext(parseOptionalIdentifier) :
	                        isAsync ? doInAwaitContext(parseOptionalIdentifier) :
	                            parseOptionalIdentifier();
	            fillSignature(54 /* ColonToken */, /*yieldContext*/ isGenerator, /*awaitContext*/ isAsync, /*requireCompleteParameterList*/ false, node);
	            node.body = parseFunctionBlock(/*allowYield*/ isGenerator, /*allowAwait*/ isAsync, /*ignoreMissingOpenBrace*/ false);
	            if (saveDecoratorContext) {
	                setDecoratorContext(/*val*/ true);
	            }
	            return addJSDocComment(finishNode(node));
	        }
	        function parseOptionalIdentifier() {
	            return isIdentifier() ? parseIdentifier() : undefined;
	        }
	        function parseNewExpression() {
	            var node = createNode(172 /* NewExpression */);
	            parseExpected(92 /* NewKeyword */);
	            node.expression = parseMemberExpressionOrHigher();
	            node.typeArguments = tryParse(parseTypeArgumentsInExpression);
	            if (node.typeArguments || token === 17 /* OpenParenToken */) {
	                node.arguments = parseArgumentList();
	            }
	            return finishNode(node);
	        }
	        // STATEMENTS
	        function parseBlock(ignoreMissingOpenBrace, diagnosticMessage) {
	            var node = createNode(195 /* Block */);
	            if (parseExpected(15 /* OpenBraceToken */, diagnosticMessage) || ignoreMissingOpenBrace) {
	                node.statements = parseList(1 /* BlockStatements */, parseStatement);
	                parseExpected(16 /* CloseBraceToken */);
	            }
	            else {
	                node.statements = createMissingList();
	            }
	            return finishNode(node);
	        }
	        function parseFunctionBlock(allowYield, allowAwait, ignoreMissingOpenBrace, diagnosticMessage) {
	            var savedYieldContext = inYieldContext();
	            setYieldContext(allowYield);
	            var savedAwaitContext = inAwaitContext();
	            setAwaitContext(allowAwait);
	            // We may be in a [Decorator] context when parsing a function expression or
	            // arrow function. The body of the function is not in [Decorator] context.
	            var saveDecoratorContext = inDecoratorContext();
	            if (saveDecoratorContext) {
	                setDecoratorContext(/*val*/ false);
	            }
	            var block = parseBlock(ignoreMissingOpenBrace, diagnosticMessage);
	            if (saveDecoratorContext) {
	                setDecoratorContext(/*val*/ true);
	            }
	            setYieldContext(savedYieldContext);
	            setAwaitContext(savedAwaitContext);
	            return block;
	        }
	        function parseEmptyStatement() {
	            var node = createNode(197 /* EmptyStatement */);
	            parseExpected(23 /* SemicolonToken */);
	            return finishNode(node);
	        }
	        function parseIfStatement() {
	            var node = createNode(199 /* IfStatement */);
	            parseExpected(88 /* IfKeyword */);
	            parseExpected(17 /* OpenParenToken */);
	            node.expression = allowInAnd(parseExpression);
	            parseExpected(18 /* CloseParenToken */);
	            node.thenStatement = parseStatement();
	            node.elseStatement = parseOptional(80 /* ElseKeyword */) ? parseStatement() : undefined;
	            return finishNode(node);
	        }
	        function parseDoStatement() {
	            var node = createNode(200 /* DoStatement */);
	            parseExpected(79 /* DoKeyword */);
	            node.statement = parseStatement();
	            parseExpected(104 /* WhileKeyword */);
	            parseExpected(17 /* OpenParenToken */);
	            node.expression = allowInAnd(parseExpression);
	            parseExpected(18 /* CloseParenToken */);
	            // From: https://mail.mozilla.org/pipermail/es-discuss/2011-August/016188.html
	            // 157 min --- All allen at wirfs-brock.com CONF --- "do{;}while(false)false" prohibited in
	            // spec but allowed in consensus reality. Approved -- this is the de-facto standard whereby
	            //  do;while(0)x will have a semicolon inserted before x.
	            parseOptional(23 /* SemicolonToken */);
	            return finishNode(node);
	        }
	        function parseWhileStatement() {
	            var node = createNode(201 /* WhileStatement */);
	            parseExpected(104 /* WhileKeyword */);
	            parseExpected(17 /* OpenParenToken */);
	            node.expression = allowInAnd(parseExpression);
	            parseExpected(18 /* CloseParenToken */);
	            node.statement = parseStatement();
	            return finishNode(node);
	        }
	        function parseForOrForInOrForOfStatement() {
	            var pos = getNodePos();
	            parseExpected(86 /* ForKeyword */);
	            parseExpected(17 /* OpenParenToken */);
	            var initializer = undefined;
	            if (token !== 23 /* SemicolonToken */) {
	                if (token === 102 /* VarKeyword */ || token === 108 /* LetKeyword */ || token === 74 /* ConstKeyword */) {
	                    initializer = parseVariableDeclarationList(/*inForStatementInitializer*/ true);
	                }
	                else {
	                    initializer = disallowInAnd(parseExpression);
	                }
	            }
	            var forOrForInOrForOfStatement;
	            if (parseOptional(90 /* InKeyword */)) {
	                var forInStatement = createNode(203 /* ForInStatement */, pos);
	                forInStatement.initializer = initializer;
	                forInStatement.expression = allowInAnd(parseExpression);
	                parseExpected(18 /* CloseParenToken */);
	                forOrForInOrForOfStatement = forInStatement;
	            }
	            else if (parseOptional(135 /* OfKeyword */)) {
	                var forOfStatement = createNode(204 /* ForOfStatement */, pos);
	                forOfStatement.initializer = initializer;
	                forOfStatement.expression = allowInAnd(parseAssignmentExpressionOrHigher);
	                parseExpected(18 /* CloseParenToken */);
	                forOrForInOrForOfStatement = forOfStatement;
	            }
	            else {
	                var forStatement = createNode(202 /* ForStatement */, pos);
	                forStatement.initializer = initializer;
	                parseExpected(23 /* SemicolonToken */);
	                if (token !== 23 /* SemicolonToken */ && token !== 18 /* CloseParenToken */) {
	                    forStatement.condition = allowInAnd(parseExpression);
	                }
	                parseExpected(23 /* SemicolonToken */);
	                if (token !== 18 /* CloseParenToken */) {
	                    forStatement.incrementor = allowInAnd(parseExpression);
	                }
	                parseExpected(18 /* CloseParenToken */);
	                forOrForInOrForOfStatement = forStatement;
	            }
	            forOrForInOrForOfStatement.statement = parseStatement();
	            return finishNode(forOrForInOrForOfStatement);
	        }
	        function parseBreakOrContinueStatement(kind) {
	            var node = createNode(kind);
	            parseExpected(kind === 206 /* BreakStatement */ ? 70 /* BreakKeyword */ : 75 /* ContinueKeyword */);
	            if (!canParseSemicolon()) {
	                node.label = parseIdentifier();
	            }
	            parseSemicolon();
	            return finishNode(node);
	        }
	        function parseReturnStatement() {
	            var node = createNode(207 /* ReturnStatement */);
	            parseExpected(94 /* ReturnKeyword */);
	            if (!canParseSemicolon()) {
	                node.expression = allowInAnd(parseExpression);
	            }
	            parseSemicolon();
	            return finishNode(node);
	        }
	        function parseWithStatement() {
	            var node = createNode(208 /* WithStatement */);
	            parseExpected(105 /* WithKeyword */);
	            parseExpected(17 /* OpenParenToken */);
	            node.expression = allowInAnd(parseExpression);
	            parseExpected(18 /* CloseParenToken */);
	            node.statement = parseStatement();
	            return finishNode(node);
	        }
	        function parseCaseClause() {
	            var node = createNode(244 /* CaseClause */);
	            parseExpected(71 /* CaseKeyword */);
	            node.expression = allowInAnd(parseExpression);
	            parseExpected(54 /* ColonToken */);
	            node.statements = parseList(3 /* SwitchClauseStatements */, parseStatement);
	            return finishNode(node);
	        }
	        function parseDefaultClause() {
	            var node = createNode(245 /* DefaultClause */);
	            parseExpected(77 /* DefaultKeyword */);
	            parseExpected(54 /* ColonToken */);
	            node.statements = parseList(3 /* SwitchClauseStatements */, parseStatement);
	            return finishNode(node);
	        }
	        function parseCaseOrDefaultClause() {
	            return token === 71 /* CaseKeyword */ ? parseCaseClause() : parseDefaultClause();
	        }
	        function parseSwitchStatement() {
	            var node = createNode(209 /* SwitchStatement */);
	            parseExpected(96 /* SwitchKeyword */);
	            parseExpected(17 /* OpenParenToken */);
	            node.expression = allowInAnd(parseExpression);
	            parseExpected(18 /* CloseParenToken */);
	            var caseBlock = createNode(223 /* CaseBlock */, scanner.getStartPos());
	            parseExpected(15 /* OpenBraceToken */);
	            caseBlock.clauses = parseList(2 /* SwitchClauses */, parseCaseOrDefaultClause);
	            parseExpected(16 /* CloseBraceToken */);
	            node.caseBlock = finishNode(caseBlock);
	            return finishNode(node);
	        }
	        function parseThrowStatement() {
	            // ThrowStatement[Yield] :
	            //      throw [no LineTerminator here]Expression[In, ?Yield];
	            // Because of automatic semicolon insertion, we need to report error if this
	            // throw could be terminated with a semicolon.  Note: we can't call 'parseExpression'
	            // directly as that might consume an expression on the following line.
	            // We just return 'undefined' in that case.  The actual error will be reported in the
	            // grammar walker.
	            var node = createNode(211 /* ThrowStatement */);
	            parseExpected(98 /* ThrowKeyword */);
	            node.expression = scanner.hasPrecedingLineBreak() ? undefined : allowInAnd(parseExpression);
	            parseSemicolon();
	            return finishNode(node);
	        }
	        // TODO: Review for error recovery
	        function parseTryStatement() {
	            var node = createNode(212 /* TryStatement */);
	            parseExpected(100 /* TryKeyword */);
	            node.tryBlock = parseBlock(/*ignoreMissingOpenBrace*/ false);
	            node.catchClause = token === 72 /* CatchKeyword */ ? parseCatchClause() : undefined;
	            // If we don't have a catch clause, then we must have a finally clause.  Try to parse
	            // one out no matter what.
	            if (!node.catchClause || token === 85 /* FinallyKeyword */) {
	                parseExpected(85 /* FinallyKeyword */);
	                node.finallyBlock = parseBlock(/*ignoreMissingOpenBrace*/ false);
	            }
	            return finishNode(node);
	        }
	        function parseCatchClause() {
	            var result = createNode(247 /* CatchClause */);
	            parseExpected(72 /* CatchKeyword */);
	            if (parseExpected(17 /* OpenParenToken */)) {
	                result.variableDeclaration = parseVariableDeclaration();
	            }
	            parseExpected(18 /* CloseParenToken */);
	            result.block = parseBlock(/*ignoreMissingOpenBrace*/ false);
	            return finishNode(result);
	        }
	        function parseDebuggerStatement() {
	            var node = createNode(213 /* DebuggerStatement */);
	            parseExpected(76 /* DebuggerKeyword */);
	            parseSemicolon();
	            return finishNode(node);
	        }
	        function parseExpressionOrLabeledStatement() {
	            // Avoiding having to do the lookahead for a labeled statement by just trying to parse
	            // out an expression, seeing if it is identifier and then seeing if it is followed by
	            // a colon.
	            var fullStart = scanner.getStartPos();
	            var expression = allowInAnd(parseExpression);
	            if (expression.kind === 69 /* Identifier */ && parseOptional(54 /* ColonToken */)) {
	                var labeledStatement = createNode(210 /* LabeledStatement */, fullStart);
	                labeledStatement.label = expression;
	                labeledStatement.statement = parseStatement();
	                return addJSDocComment(finishNode(labeledStatement));
	            }
	            else {
	                var expressionStatement = createNode(198 /* ExpressionStatement */, fullStart);
	                expressionStatement.expression = expression;
	                parseSemicolon();
	                return addJSDocComment(finishNode(expressionStatement));
	            }
	        }
	        function nextTokenIsIdentifierOrKeywordOnSameLine() {
	            nextToken();
	            return ts.tokenIsIdentifierOrKeyword(token) && !scanner.hasPrecedingLineBreak();
	        }
	        function nextTokenIsFunctionKeywordOnSameLine() {
	            nextToken();
	            return token === 87 /* FunctionKeyword */ && !scanner.hasPrecedingLineBreak();
	        }
	        function nextTokenIsIdentifierOrKeywordOrNumberOnSameLine() {
	            nextToken();
	            return (ts.tokenIsIdentifierOrKeyword(token) || token === 8 /* NumericLiteral */) && !scanner.hasPrecedingLineBreak();
	        }
	        function isDeclaration() {
	            while (true) {
	                switch (token) {
	                    case 102 /* VarKeyword */:
	                    case 108 /* LetKeyword */:
	                    case 74 /* ConstKeyword */:
	                    case 87 /* FunctionKeyword */:
	                    case 73 /* ClassKeyword */:
	                    case 81 /* EnumKeyword */:
	                        return true;
	                    // 'declare', 'module', 'namespace', 'interface'* and 'type' are all legal JavaScript identifiers;
	                    // however, an identifier cannot be followed by another identifier on the same line. This is what we
	                    // count on to parse out the respective declarations. For instance, we exploit this to say that
	                    //
	                    //    namespace n
	                    //
	                    // can be none other than the beginning of a namespace declaration, but need to respect that JavaScript sees
	                    //
	                    //    namespace
	                    //    n
	                    //
	                    // as the identifier 'namespace' on one line followed by the identifier 'n' on another.
	                    // We need to look one token ahead to see if it permissible to try parsing a declaration.
	                    //
	                    // *Note*: 'interface' is actually a strict mode reserved word. So while
	                    //
	                    //   "use strict"
	                    //   interface
	                    //   I {}
	                    //
	                    // could be legal, it would add complexity for very little gain.
	                    case 107 /* InterfaceKeyword */:
	                    case 132 /* TypeKeyword */:
	                        return nextTokenIsIdentifierOnSameLine();
	                    case 125 /* ModuleKeyword */:
	                    case 126 /* NamespaceKeyword */:
	                        return nextTokenIsIdentifierOrStringLiteralOnSameLine();
	                    case 115 /* AbstractKeyword */:
	                    case 118 /* AsyncKeyword */:
	                    case 122 /* DeclareKeyword */:
	                    case 110 /* PrivateKeyword */:
	                    case 111 /* ProtectedKeyword */:
	                    case 112 /* PublicKeyword */:
	                        nextToken();
	                        // ASI takes effect for this modifier.
	                        if (scanner.hasPrecedingLineBreak()) {
	                            return false;
	                        }
	                        continue;
	                    case 134 /* GlobalKeyword */:
	                        return nextToken() === 15 /* OpenBraceToken */;
	                    case 89 /* ImportKeyword */:
	                        nextToken();
	                        return token === 9 /* StringLiteral */ || token === 37 /* AsteriskToken */ ||
	                            token === 15 /* OpenBraceToken */ || ts.tokenIsIdentifierOrKeyword(token);
	                    case 82 /* ExportKeyword */:
	                        nextToken();
	                        if (token === 56 /* EqualsToken */ || token === 37 /* AsteriskToken */ ||
	                            token === 15 /* OpenBraceToken */ || token === 77 /* DefaultKeyword */) {
	                            return true;
	                        }
	                        continue;
	                    case 113 /* StaticKeyword */:
	                        nextToken();
	                        continue;
	                    default:
	                        return false;
	                }
	            }
	        }
	        function isStartOfDeclaration() {
	            return lookAhead(isDeclaration);
	        }
	        function isStartOfStatement() {
	            switch (token) {
	                case 55 /* AtToken */:
	                case 23 /* SemicolonToken */:
	                case 15 /* OpenBraceToken */:
	                case 102 /* VarKeyword */:
	                case 108 /* LetKeyword */:
	                case 87 /* FunctionKeyword */:
	                case 73 /* ClassKeyword */:
	                case 81 /* EnumKeyword */:
	                case 88 /* IfKeyword */:
	                case 79 /* DoKeyword */:
	                case 104 /* WhileKeyword */:
	                case 86 /* ForKeyword */:
	                case 75 /* ContinueKeyword */:
	                case 70 /* BreakKeyword */:
	                case 94 /* ReturnKeyword */:
	                case 105 /* WithKeyword */:
	                case 96 /* SwitchKeyword */:
	                case 98 /* ThrowKeyword */:
	                case 100 /* TryKeyword */:
	                case 76 /* DebuggerKeyword */:
	                // 'catch' and 'finally' do not actually indicate that the code is part of a statement,
	                // however, we say they are here so that we may gracefully parse them and error later.
	                case 72 /* CatchKeyword */:
	                case 85 /* FinallyKeyword */:
	                    return true;
	                case 74 /* ConstKeyword */:
	                case 82 /* ExportKeyword */:
	                case 89 /* ImportKeyword */:
	                    return isStartOfDeclaration();
	                case 118 /* AsyncKeyword */:
	                case 122 /* DeclareKeyword */:
	                case 107 /* InterfaceKeyword */:
	                case 125 /* ModuleKeyword */:
	                case 126 /* NamespaceKeyword */:
	                case 132 /* TypeKeyword */:
	                case 134 /* GlobalKeyword */:
	                    // When these don't start a declaration, they're an identifier in an expression statement
	                    return true;
	                case 112 /* PublicKeyword */:
	                case 110 /* PrivateKeyword */:
	                case 111 /* ProtectedKeyword */:
	                case 113 /* StaticKeyword */:
	                    // When these don't start a declaration, they may be the start of a class member if an identifier
	                    // immediately follows. Otherwise they're an identifier in an expression statement.
	                    return isStartOfDeclaration() || !lookAhead(nextTokenIsIdentifierOrKeywordOnSameLine);
	                default:
	                    return isStartOfExpression();
	            }
	        }
	        function nextTokenIsIdentifierOrStartOfDestructuring() {
	            nextToken();
	            return isIdentifier() || token === 15 /* OpenBraceToken */ || token === 19 /* OpenBracketToken */;
	        }
	        function isLetDeclaration() {
	            // In ES6 'let' always starts a lexical declaration if followed by an identifier or {
	            // or [.
	            return lookAhead(nextTokenIsIdentifierOrStartOfDestructuring);
	        }
	        function parseStatement() {
	            switch (token) {
	                case 23 /* SemicolonToken */:
	                    return parseEmptyStatement();
	                case 15 /* OpenBraceToken */:
	                    return parseBlock(/*ignoreMissingOpenBrace*/ false);
	                case 102 /* VarKeyword */:
	                    return parseVariableStatement(scanner.getStartPos(), /*decorators*/ undefined, /*modifiers*/ undefined);
	                case 108 /* LetKeyword */:
	                    if (isLetDeclaration()) {
	                        return parseVariableStatement(scanner.getStartPos(), /*decorators*/ undefined, /*modifiers*/ undefined);
	                    }
	                    break;
	                case 87 /* FunctionKeyword */:
	                    return parseFunctionDeclaration(scanner.getStartPos(), /*decorators*/ undefined, /*modifiers*/ undefined);
	                case 73 /* ClassKeyword */:
	                    return parseClassDeclaration(scanner.getStartPos(), /*decorators*/ undefined, /*modifiers*/ undefined);
	                case 88 /* IfKeyword */:
	                    return parseIfStatement();
	                case 79 /* DoKeyword */:
	                    return parseDoStatement();
	                case 104 /* WhileKeyword */:
	                    return parseWhileStatement();
	                case 86 /* ForKeyword */:
	                    return parseForOrForInOrForOfStatement();
	                case 75 /* ContinueKeyword */:
	                    return parseBreakOrContinueStatement(205 /* ContinueStatement */);
	                case 70 /* BreakKeyword */:
	                    return parseBreakOrContinueStatement(206 /* BreakStatement */);
	                case 94 /* ReturnKeyword */:
	                    return parseReturnStatement();
	                case 105 /* WithKeyword */:
	                    return parseWithStatement();
	                case 96 /* SwitchKeyword */:
	                    return parseSwitchStatement();
	                case 98 /* ThrowKeyword */:
	                    return parseThrowStatement();
	                case 100 /* TryKeyword */:
	                // Include 'catch' and 'finally' for error recovery.
	                case 72 /* CatchKeyword */:
	                case 85 /* FinallyKeyword */:
	                    return parseTryStatement();
	                case 76 /* DebuggerKeyword */:
	                    return parseDebuggerStatement();
	                case 55 /* AtToken */:
	                    return parseDeclaration();
	                case 118 /* AsyncKeyword */:
	                case 107 /* InterfaceKeyword */:
	                case 132 /* TypeKeyword */:
	                case 125 /* ModuleKeyword */:
	                case 126 /* NamespaceKeyword */:
	                case 122 /* DeclareKeyword */:
	                case 74 /* ConstKeyword */:
	                case 81 /* EnumKeyword */:
	                case 82 /* ExportKeyword */:
	                case 89 /* ImportKeyword */:
	                case 110 /* PrivateKeyword */:
	                case 111 /* ProtectedKeyword */:
	                case 112 /* PublicKeyword */:
	                case 115 /* AbstractKeyword */:
	                case 113 /* StaticKeyword */:
	                case 134 /* GlobalKeyword */:
	                    if (isStartOfDeclaration()) {
	                        return parseDeclaration();
	                    }
	                    break;
	            }
	            return parseExpressionOrLabeledStatement();
	        }
	        function parseDeclaration() {
	            var fullStart = getNodePos();
	            var decorators = parseDecorators();
	            var modifiers = parseModifiers();
	            switch (token) {
	                case 102 /* VarKeyword */:
	                case 108 /* LetKeyword */:
	                case 74 /* ConstKeyword */:
	                    return parseVariableStatement(fullStart, decorators, modifiers);
	                case 87 /* FunctionKeyword */:
	                    return parseFunctionDeclaration(fullStart, decorators, modifiers);
	                case 73 /* ClassKeyword */:
	                    return parseClassDeclaration(fullStart, decorators, modifiers);
	                case 107 /* InterfaceKeyword */:
	                    return parseInterfaceDeclaration(fullStart, decorators, modifiers);
	                case 132 /* TypeKeyword */:
	                    return parseTypeAliasDeclaration(fullStart, decorators, modifiers);
	                case 81 /* EnumKeyword */:
	                    return parseEnumDeclaration(fullStart, decorators, modifiers);
	                case 134 /* GlobalKeyword */:
	                case 125 /* ModuleKeyword */:
	                case 126 /* NamespaceKeyword */:
	                    return parseModuleDeclaration(fullStart, decorators, modifiers);
	                case 89 /* ImportKeyword */:
	                    return parseImportDeclarationOrImportEqualsDeclaration(fullStart, decorators, modifiers);
	                case 82 /* ExportKeyword */:
	                    nextToken();
	                    return token === 77 /* DefaultKeyword */ || token === 56 /* EqualsToken */ ?
	                        parseExportAssignment(fullStart, decorators, modifiers) :
	                        parseExportDeclaration(fullStart, decorators, modifiers);
	                default:
	                    if (decorators || modifiers) {
	                        // We reached this point because we encountered decorators and/or modifiers and assumed a declaration
	                        // would follow. For recovery and error reporting purposes, return an incomplete declaration.
	                        var node = createMissingNode(234 /* MissingDeclaration */, /*reportAtCurrentPosition*/ true, ts.Diagnostics.Declaration_expected);
	                        node.pos = fullStart;
	                        node.decorators = decorators;
	                        setModifiers(node, modifiers);
	                        return finishNode(node);
	                    }
	            }
	        }
	        function nextTokenIsIdentifierOrStringLiteralOnSameLine() {
	            nextToken();
	            return !scanner.hasPrecedingLineBreak() && (isIdentifier() || token === 9 /* StringLiteral */);
	        }
	        function parseFunctionBlockOrSemicolon(isGenerator, isAsync, diagnosticMessage) {
	            if (token !== 15 /* OpenBraceToken */ && canParseSemicolon()) {
	                parseSemicolon();
	                return;
	            }
	            return parseFunctionBlock(isGenerator, isAsync, /*ignoreMissingOpenBrace*/ false, diagnosticMessage);
	        }
	        // DECLARATIONS
	        function parseArrayBindingElement() {
	            if (token === 24 /* CommaToken */) {
	                return createNode(190 /* OmittedExpression */);
	            }
	            var node = createNode(166 /* BindingElement */);
	            node.dotDotDotToken = parseOptionalToken(22 /* DotDotDotToken */);
	            node.name = parseIdentifierOrPattern();
	            node.initializer = parseBindingElementInitializer(/*inParameter*/ false);
	            return finishNode(node);
	        }
	        function parseObjectBindingElement() {
	            var node = createNode(166 /* BindingElement */);
	            var tokenIsIdentifier = isIdentifier();
	            var propertyName = parsePropertyName();
	            if (tokenIsIdentifier && token !== 54 /* ColonToken */) {
	                node.name = propertyName;
	            }
	            else {
	                parseExpected(54 /* ColonToken */);
	                node.propertyName = propertyName;
	                node.name = parseIdentifierOrPattern();
	            }
	            node.initializer = parseBindingElementInitializer(/*inParameter*/ false);
	            return finishNode(node);
	        }
	        function parseObjectBindingPattern() {
	            var node = createNode(164 /* ObjectBindingPattern */);
	            parseExpected(15 /* OpenBraceToken */);
	            node.elements = parseDelimitedList(9 /* ObjectBindingElements */, parseObjectBindingElement);
	            parseExpected(16 /* CloseBraceToken */);
	            return finishNode(node);
	        }
	        function parseArrayBindingPattern() {
	            var node = createNode(165 /* ArrayBindingPattern */);
	            parseExpected(19 /* OpenBracketToken */);
	            node.elements = parseDelimitedList(10 /* ArrayBindingElements */, parseArrayBindingElement);
	            parseExpected(20 /* CloseBracketToken */);
	            return finishNode(node);
	        }
	        function isIdentifierOrPattern() {
	            return token === 15 /* OpenBraceToken */ || token === 19 /* OpenBracketToken */ || isIdentifier();
	        }
	        function parseIdentifierOrPattern() {
	            if (token === 19 /* OpenBracketToken */) {
	                return parseArrayBindingPattern();
	            }
	            if (token === 15 /* OpenBraceToken */) {
	                return parseObjectBindingPattern();
	            }
	            return parseIdentifier();
	        }
	        function parseVariableDeclaration() {
	            var node = createNode(214 /* VariableDeclaration */);
	            node.name = parseIdentifierOrPattern();
	            node.type = parseTypeAnnotation();
	            if (!isInOrOfKeyword(token)) {
	                node.initializer = parseInitializer(/*inParameter*/ false);
	            }
	            return finishNode(node);
	        }
	        function parseVariableDeclarationList(inForStatementInitializer) {
	            var node = createNode(215 /* VariableDeclarationList */);
	            switch (token) {
	                case 102 /* VarKeyword */:
	                    break;
	                case 108 /* LetKeyword */:
	                    node.flags |= 8192 /* Let */;
	                    break;
	                case 74 /* ConstKeyword */:
	                    node.flags |= 16384 /* Const */;
	                    break;
	                default:
	                    ts.Debug.fail();
	            }
	            nextToken();
	            // The user may have written the following:
	            //
	            //    for (let of X) { }
	            //
	            // In this case, we want to parse an empty declaration list, and then parse 'of'
	            // as a keyword. The reason this is not automatic is that 'of' is a valid identifier.
	            // So we need to look ahead to determine if 'of' should be treated as a keyword in
	            // this context.
	            // The checker will then give an error that there is an empty declaration list.
	            if (token === 135 /* OfKeyword */ && lookAhead(canFollowContextualOfKeyword)) {
	                node.declarations = createMissingList();
	            }
	            else {
	                var savedDisallowIn = inDisallowInContext();
	                setDisallowInContext(inForStatementInitializer);
	                node.declarations = parseDelimitedList(8 /* VariableDeclarations */, parseVariableDeclaration);
	                setDisallowInContext(savedDisallowIn);
	            }
	            return finishNode(node);
	        }
	        function canFollowContextualOfKeyword() {
	            return nextTokenIsIdentifier() && nextToken() === 18 /* CloseParenToken */;
	        }
	        function parseVariableStatement(fullStart, decorators, modifiers) {
	            var node = createNode(196 /* VariableStatement */, fullStart);
	            node.decorators = decorators;
	            setModifiers(node, modifiers);
	            node.declarationList = parseVariableDeclarationList(/*inForStatementInitializer*/ false);
	            parseSemicolon();
	            return addJSDocComment(finishNode(node));
	        }
	        function parseFunctionDeclaration(fullStart, decorators, modifiers) {
	            var node = createNode(216 /* FunctionDeclaration */, fullStart);
	            node.decorators = decorators;
	            setModifiers(node, modifiers);
	            parseExpected(87 /* FunctionKeyword */);
	            node.asteriskToken = parseOptionalToken(37 /* AsteriskToken */);
	            node.name = node.flags & 512 /* Default */ ? parseOptionalIdentifier() : parseIdentifier();
	            var isGenerator = !!node.asteriskToken;
	            var isAsync = !!(node.flags & 256 /* Async */);
	            fillSignature(54 /* ColonToken */, /*yieldContext*/ isGenerator, /*awaitContext*/ isAsync, /*requireCompleteParameterList*/ false, node);
	            node.body = parseFunctionBlockOrSemicolon(isGenerator, isAsync, ts.Diagnostics.or_expected);
	            return addJSDocComment(finishNode(node));
	        }
	        function parseConstructorDeclaration(pos, decorators, modifiers) {
	            var node = createNode(145 /* Constructor */, pos);
	            node.decorators = decorators;
	            setModifiers(node, modifiers);
	            parseExpected(121 /* ConstructorKeyword */);
	            fillSignature(54 /* ColonToken */, /*yieldContext*/ false, /*awaitContext*/ false, /*requireCompleteParameterList*/ false, node);
	            node.body = parseFunctionBlockOrSemicolon(/*isGenerator*/ false, /*isAsync*/ false, ts.Diagnostics.or_expected);
	            return addJSDocComment(finishNode(node));
	        }
	        function parseMethodDeclaration(fullStart, decorators, modifiers, asteriskToken, name, questionToken, diagnosticMessage) {
	            var method = createNode(144 /* MethodDeclaration */, fullStart);
	            method.decorators = decorators;
	            setModifiers(method, modifiers);
	            method.asteriskToken = asteriskToken;
	            method.name = name;
	            method.questionToken = questionToken;
	            var isGenerator = !!asteriskToken;
	            var isAsync = !!(method.flags & 256 /* Async */);
	            fillSignature(54 /* ColonToken */, /*yieldContext*/ isGenerator, /*awaitContext*/ isAsync, /*requireCompleteParameterList*/ false, method);
	            method.body = parseFunctionBlockOrSemicolon(isGenerator, isAsync, diagnosticMessage);
	            return addJSDocComment(finishNode(method));
	        }
	        function parsePropertyDeclaration(fullStart, decorators, modifiers, name, questionToken) {
	            var property = createNode(142 /* PropertyDeclaration */, fullStart);
	            property.decorators = decorators;
	            setModifiers(property, modifiers);
	            property.name = name;
	            property.questionToken = questionToken;
	            property.type = parseTypeAnnotation();
	            // For instance properties specifically, since they are evaluated inside the constructor,
	            // we do *not * want to parse yield expressions, so we specifically turn the yield context
	            // off. The grammar would look something like this:
	            //
	            //    MemberVariableDeclaration[Yield]:
	            //        AccessibilityModifier_opt   PropertyName   TypeAnnotation_opt   Initialiser_opt[In];
	            //        AccessibilityModifier_opt  static_opt  PropertyName   TypeAnnotation_opt   Initialiser_opt[In, ?Yield];
	            //
	            // The checker may still error in the static case to explicitly disallow the yield expression.
	            property.initializer = modifiers && modifiers.flags & 64 /* Static */
	                ? allowInAnd(parseNonParameterInitializer)
	                : doOutsideOfContext(2 /* Yield */ | 1 /* DisallowIn */, parseNonParameterInitializer);
	            parseSemicolon();
	            return finishNode(property);
	        }
	        function parsePropertyOrMethodDeclaration(fullStart, decorators, modifiers) {
	            var asteriskToken = parseOptionalToken(37 /* AsteriskToken */);
	            var name = parsePropertyName();
	            // Note: this is not legal as per the grammar.  But we allow it in the parser and
	            // report an error in the grammar checker.
	            var questionToken = parseOptionalToken(53 /* QuestionToken */);
	            if (asteriskToken || token === 17 /* OpenParenToken */ || token === 25 /* LessThanToken */) {
	                return parseMethodDeclaration(fullStart, decorators, modifiers, asteriskToken, name, questionToken, ts.Diagnostics.or_expected);
	            }
	            else {
	                return parsePropertyDeclaration(fullStart, decorators, modifiers, name, questionToken);
	            }
	        }
	        function parseNonParameterInitializer() {
	            return parseInitializer(/*inParameter*/ false);
	        }
	        function parseAccessorDeclaration(kind, fullStart, decorators, modifiers) {
	            var node = createNode(kind, fullStart);
	            node.decorators = decorators;
	            setModifiers(node, modifiers);
	            node.name = parsePropertyName();
	            fillSignature(54 /* ColonToken */, /*yieldContext*/ false, /*awaitContext*/ false, /*requireCompleteParameterList*/ false, node);
	            node.body = parseFunctionBlockOrSemicolon(/*isGenerator*/ false, /*isAsync*/ false);
	            return finishNode(node);
	        }
	        function isClassMemberModifier(idToken) {
	            switch (idToken) {
	                case 112 /* PublicKeyword */:
	                case 110 /* PrivateKeyword */:
	                case 111 /* ProtectedKeyword */:
	                case 113 /* StaticKeyword */:
	                    return true;
	                default:
	                    return false;
	            }
	        }
	        function isClassMemberStart() {
	            var idToken;
	            if (token === 55 /* AtToken */) {
	                return true;
	            }
	            // Eat up all modifiers, but hold on to the last one in case it is actually an identifier.
	            while (ts.isModifierKind(token)) {
	                idToken = token;
	                // If the idToken is a class modifier (protected, private, public, and static), it is
	                // certain that we are starting to parse class member. This allows better error recovery
	                // Example:
	                //      public foo() ...     // true
	                //      public @dec blah ... // true; we will then report an error later
	                //      export public ...    // true; we will then report an error later
	                if (isClassMemberModifier(idToken)) {
	                    return true;
	                }
	                nextToken();
	            }
	            if (token === 37 /* AsteriskToken */) {
	                return true;
	            }
	            // Try to get the first property-like token following all modifiers.
	            // This can either be an identifier or the 'get' or 'set' keywords.
	            if (isLiteralPropertyName()) {
	                idToken = token;
	                nextToken();
	            }
	            // Index signatures and computed properties are class members; we can parse.
	            if (token === 19 /* OpenBracketToken */) {
	                return true;
	            }
	            // If we were able to get any potential identifier...
	            if (idToken !== undefined) {
	                // If we have a non-keyword identifier, or if we have an accessor, then it's safe to parse.
	                if (!ts.isKeyword(idToken) || idToken === 129 /* SetKeyword */ || idToken === 123 /* GetKeyword */) {
	                    return true;
	                }
	                // If it *is* a keyword, but not an accessor, check a little farther along
	                // to see if it should actually be parsed as a class member.
	                switch (token) {
	                    case 17 /* OpenParenToken */: // Method declaration
	                    case 25 /* LessThanToken */: // Generic Method declaration
	                    case 54 /* ColonToken */: // Type Annotation for declaration
	                    case 56 /* EqualsToken */: // Initializer for declaration
	                    case 53 /* QuestionToken */:
	                        return true;
	                    default:
	                        // Covers
	                        //  - Semicolons     (declaration termination)
	                        //  - Closing braces (end-of-class, must be declaration)
	                        //  - End-of-files   (not valid, but permitted so that it gets caught later on)
	                        //  - Line-breaks    (enabling *automatic semicolon insertion*)
	                        return canParseSemicolon();
	                }
	            }
	            return false;
	        }
	        function parseDecorators() {
	            var decorators;
	            while (true) {
	                var decoratorStart = getNodePos();
	                if (!parseOptional(55 /* AtToken */)) {
	                    break;
	                }
	                if (!decorators) {
	                    decorators = [];
	                    decorators.pos = decoratorStart;
	                }
	                var decorator = createNode(140 /* Decorator */, decoratorStart);
	                decorator.expression = doInDecoratorContext(parseLeftHandSideExpressionOrHigher);
	                decorators.push(finishNode(decorator));
	            }
	            if (decorators) {
	                decorators.end = getNodeEnd();
	            }
	            return decorators;
	        }
	        /*
	         * There are situations in which a modifier like 'const' will appear unexpectedly, such as on a class member.
	         * In those situations, if we are entirely sure that 'const' is not valid on its own (such as when ASI takes effect
	         * and turns it into a standalone declaration), then it is better to parse it and report an error later.
	         *
	         * In such situations, 'permitInvalidConstAsModifier' should be set to true.
	         */
	        function parseModifiers(permitInvalidConstAsModifier) {
	            var flags = 0;
	            var modifiers;
	            while (true) {
	                var modifierStart = scanner.getStartPos();
	                var modifierKind = token;
	                if (token === 74 /* ConstKeyword */ && permitInvalidConstAsModifier) {
	                    // We need to ensure that any subsequent modifiers appear on the same line
	                    // so that when 'const' is a standalone declaration, we don't issue an error.                
	                    if (!tryParse(nextTokenIsOnSameLineAndCanFollowModifier)) {
	                        break;
	                    }
	                }
	                else {
	                    if (!parseAnyContextualModifier()) {
	                        break;
	                    }
	                }
	                if (!modifiers) {
	                    modifiers = [];
	                    modifiers.pos = modifierStart;
	                }
	                flags |= ts.modifierToFlag(modifierKind);
	                modifiers.push(finishNode(createNode(modifierKind, modifierStart)));
	            }
	            if (modifiers) {
	                modifiers.flags = flags;
	                modifiers.end = scanner.getStartPos();
	            }
	            return modifiers;
	        }
	        function parseModifiersForArrowFunction() {
	            var flags = 0;
	            var modifiers;
	            if (token === 118 /* AsyncKeyword */) {
	                var modifierStart = scanner.getStartPos();
	                var modifierKind = token;
	                nextToken();
	                modifiers = [];
	                modifiers.pos = modifierStart;
	                flags |= ts.modifierToFlag(modifierKind);
	                modifiers.push(finishNode(createNode(modifierKind, modifierStart)));
	                modifiers.flags = flags;
	                modifiers.end = scanner.getStartPos();
	            }
	            return modifiers;
	        }
	        function parseClassElement() {
	            if (token === 23 /* SemicolonToken */) {
	                var result = createNode(194 /* SemicolonClassElement */);
	                nextToken();
	                return finishNode(result);
	            }
	            var fullStart = getNodePos();
	            var decorators = parseDecorators();
	            var modifiers = parseModifiers(/*permitInvalidConstAsModifier*/ true);
	            var accessor = tryParseAccessorDeclaration(fullStart, decorators, modifiers);
	            if (accessor) {
	                return accessor;
	            }
	            if (token === 121 /* ConstructorKeyword */) {
	                return parseConstructorDeclaration(fullStart, decorators, modifiers);
	            }
	            if (isIndexSignature()) {
	                return parseIndexSignatureDeclaration(fullStart, decorators, modifiers);
	            }
	            // It is very important that we check this *after* checking indexers because
	            // the [ token can start an index signature or a computed property name
	            if (ts.tokenIsIdentifierOrKeyword(token) ||
	                token === 9 /* StringLiteral */ ||
	                token === 8 /* NumericLiteral */ ||
	                token === 37 /* AsteriskToken */ ||
	                token === 19 /* OpenBracketToken */) {
	                return parsePropertyOrMethodDeclaration(fullStart, decorators, modifiers);
	            }
	            if (decorators || modifiers) {
	                // treat this as a property declaration with a missing name.
	                var name_7 = createMissingNode(69 /* Identifier */, /*reportAtCurrentPosition*/ true, ts.Diagnostics.Declaration_expected);
	                return parsePropertyDeclaration(fullStart, decorators, modifiers, name_7, /*questionToken*/ undefined);
	            }
	            // 'isClassMemberStart' should have hinted not to attempt parsing.
	            ts.Debug.fail("Should not have attempted to parse class member declaration.");
	        }
	        function parseClassExpression() {
	            return parseClassDeclarationOrExpression(
	            /*fullStart*/ scanner.getStartPos(), 
	            /*decorators*/ undefined, 
	            /*modifiers*/ undefined, 189 /* ClassExpression */);
	        }
	        function parseClassDeclaration(fullStart, decorators, modifiers) {
	            return parseClassDeclarationOrExpression(fullStart, decorators, modifiers, 217 /* ClassDeclaration */);
	        }
	        function parseClassDeclarationOrExpression(fullStart, decorators, modifiers, kind) {
	            var node = createNode(kind, fullStart);
	            node.decorators = decorators;
	            setModifiers(node, modifiers);
	            parseExpected(73 /* ClassKeyword */);
	            node.name = parseNameOfClassDeclarationOrExpression();
	            node.typeParameters = parseTypeParameters();
	            node.heritageClauses = parseHeritageClauses(/*isClassHeritageClause*/ true);
	            if (parseExpected(15 /* OpenBraceToken */)) {
	                // ClassTail[Yield,Await] : (Modified) See 14.5
	                //      ClassHeritage[?Yield,?Await]opt { ClassBody[?Yield,?Await]opt }
	                node.members = parseClassMembers();
	                parseExpected(16 /* CloseBraceToken */);
	            }
	            else {
	                node.members = createMissingList();
	            }
	            return finishNode(node);
	        }
	        function parseNameOfClassDeclarationOrExpression() {
	            // implements is a future reserved word so
	            // 'class implements' might mean either
	            // - class expression with omitted name, 'implements' starts heritage clause
	            // - class with name 'implements'
	            // 'isImplementsClause' helps to disambiguate between these two cases
	            return isIdentifier() && !isImplementsClause()
	                ? parseIdentifier()
	                : undefined;
	        }
	        function isImplementsClause() {
	            return token === 106 /* ImplementsKeyword */ && lookAhead(nextTokenIsIdentifierOrKeyword);
	        }
	        function parseHeritageClauses(isClassHeritageClause) {
	            // ClassTail[Yield,Await] : (Modified) See 14.5
	            //      ClassHeritage[?Yield,?Await]opt { ClassBody[?Yield,?Await]opt }
	            if (isHeritageClause()) {
	                return parseList(20 /* HeritageClauses */, parseHeritageClause);
	            }
	            return undefined;
	        }
	        function parseHeritageClause() {
	            if (token === 83 /* ExtendsKeyword */ || token === 106 /* ImplementsKeyword */) {
	                var node = createNode(246 /* HeritageClause */);
	                node.token = token;
	                nextToken();
	                node.types = parseDelimitedList(7 /* HeritageClauseElement */, parseExpressionWithTypeArguments);
	                return finishNode(node);
	            }
	            return undefined;
	        }
	        function parseExpressionWithTypeArguments() {
	            var node = createNode(191 /* ExpressionWithTypeArguments */);
	            node.expression = parseLeftHandSideExpressionOrHigher();
	            if (token === 25 /* LessThanToken */) {
	                node.typeArguments = parseBracketedList(18 /* TypeArguments */, parseType, 25 /* LessThanToken */, 27 /* GreaterThanToken */);
	            }
	            return finishNode(node);
	        }
	        function isHeritageClause() {
	            return token === 83 /* ExtendsKeyword */ || token === 106 /* ImplementsKeyword */;
	        }
	        function parseClassMembers() {
	            return parseList(5 /* ClassMembers */, parseClassElement);
	        }
	        function parseInterfaceDeclaration(fullStart, decorators, modifiers) {
	            var node = createNode(218 /* InterfaceDeclaration */, fullStart);
	            node.decorators = decorators;
	            setModifiers(node, modifiers);
	            parseExpected(107 /* InterfaceKeyword */);
	            node.name = parseIdentifier();
	            node.typeParameters = parseTypeParameters();
	            node.heritageClauses = parseHeritageClauses(/*isClassHeritageClause*/ false);
	            node.members = parseObjectTypeMembers();
	            return finishNode(node);
	        }
	        function parseTypeAliasDeclaration(fullStart, decorators, modifiers) {
	            var node = createNode(219 /* TypeAliasDeclaration */, fullStart);
	            node.decorators = decorators;
	            setModifiers(node, modifiers);
	            parseExpected(132 /* TypeKeyword */);
	            node.name = parseIdentifier();
	            node.typeParameters = parseTypeParameters();
	            parseExpected(56 /* EqualsToken */);
	            node.type = parseType();
	            parseSemicolon();
	            return finishNode(node);
	        }
	        // In an ambient declaration, the grammar only allows integer literals as initializers.
	        // In a non-ambient declaration, the grammar allows uninitialized members only in a
	        // ConstantEnumMemberSection, which starts at the beginning of an enum declaration
	        // or any time an integer literal initializer is encountered.
	        function parseEnumMember() {
	            var node = createNode(250 /* EnumMember */, scanner.getStartPos());
	            node.name = parsePropertyName();
	            node.initializer = allowInAnd(parseNonParameterInitializer);
	            return finishNode(node);
	        }
	        function parseEnumDeclaration(fullStart, decorators, modifiers) {
	            var node = createNode(220 /* EnumDeclaration */, fullStart);
	            node.decorators = decorators;
	            setModifiers(node, modifiers);
	            parseExpected(81 /* EnumKeyword */);
	            node.name = parseIdentifier();
	            if (parseExpected(15 /* OpenBraceToken */)) {
	                node.members = parseDelimitedList(6 /* EnumMembers */, parseEnumMember);
	                parseExpected(16 /* CloseBraceToken */);
	            }
	            else {
	                node.members = createMissingList();
	            }
	            return finishNode(node);
	        }
	        function parseModuleBlock() {
	            var node = createNode(222 /* ModuleBlock */, scanner.getStartPos());
	            if (parseExpected(15 /* OpenBraceToken */)) {
	                node.statements = parseList(1 /* BlockStatements */, parseStatement);
	                parseExpected(16 /* CloseBraceToken */);
	            }
	            else {
	                node.statements = createMissingList();
	            }
	            return finishNode(node);
	        }
	        function parseModuleOrNamespaceDeclaration(fullStart, decorators, modifiers, flags) {
	            var node = createNode(221 /* ModuleDeclaration */, fullStart);
	            // If we are parsing a dotted namespace name, we want to
	            // propagate the 'Namespace' flag across the names if set.
	            var namespaceFlag = flags & 65536 /* Namespace */;
	            node.decorators = decorators;
	            setModifiers(node, modifiers);
	            node.flags |= flags;
	            node.name = parseIdentifier();
	            node.body = parseOptional(21 /* DotToken */)
	                ? parseModuleOrNamespaceDeclaration(getNodePos(), /*decorators*/ undefined, /*modifiers*/ undefined, 2 /* Export */ | namespaceFlag)
	                : parseModuleBlock();
	            return finishNode(node);
	        }
	        function parseAmbientExternalModuleDeclaration(fullStart, decorators, modifiers) {
	            var node = createNode(221 /* ModuleDeclaration */, fullStart);
	            node.decorators = decorators;
	            setModifiers(node, modifiers);
	            if (token === 134 /* GlobalKeyword */) {
	                // parse 'global' as name of global scope augmentation 
	                node.name = parseIdentifier();
	                node.flags |= 2097152 /* GlobalAugmentation */;
	            }
	            else {
	                node.name = parseLiteralNode(/*internName*/ true);
	            }
	            node.body = parseModuleBlock();
	            return finishNode(node);
	        }
	        function parseModuleDeclaration(fullStart, decorators, modifiers) {
	            var flags = modifiers ? modifiers.flags : 0;
	            if (token === 134 /* GlobalKeyword */) {
	                // global augmentation
	                return parseAmbientExternalModuleDeclaration(fullStart, decorators, modifiers);
	            }
	            else if (parseOptional(126 /* NamespaceKeyword */)) {
	                flags |= 65536 /* Namespace */;
	            }
	            else {
	                parseExpected(125 /* ModuleKeyword */);
	                if (token === 9 /* StringLiteral */) {
	                    return parseAmbientExternalModuleDeclaration(fullStart, decorators, modifiers);
	                }
	            }
	            return parseModuleOrNamespaceDeclaration(fullStart, decorators, modifiers, flags);
	        }
	        function isExternalModuleReference() {
	            return token === 127 /* RequireKeyword */ &&
	                lookAhead(nextTokenIsOpenParen);
	        }
	        function nextTokenIsOpenParen() {
	            return nextToken() === 17 /* OpenParenToken */;
	        }
	        function nextTokenIsSlash() {
	            return nextToken() === 39 /* SlashToken */;
	        }
	        function parseImportDeclarationOrImportEqualsDeclaration(fullStart, decorators, modifiers) {
	            parseExpected(89 /* ImportKeyword */);
	            var afterImportPos = scanner.getStartPos();
	            var identifier;
	            if (isIdentifier()) {
	                identifier = parseIdentifier();
	                if (token !== 24 /* CommaToken */ && token !== 133 /* FromKeyword */) {
	                    // ImportEquals declaration of type:
	                    // import x = require("mod"); or
	                    // import x = M.x;
	                    var importEqualsDeclaration = createNode(224 /* ImportEqualsDeclaration */, fullStart);
	                    importEqualsDeclaration.decorators = decorators;
	                    setModifiers(importEqualsDeclaration, modifiers);
	                    importEqualsDeclaration.name = identifier;
	                    parseExpected(56 /* EqualsToken */);
	                    importEqualsDeclaration.moduleReference = parseModuleReference();
	                    parseSemicolon();
	                    return finishNode(importEqualsDeclaration);
	                }
	            }
	            // Import statement
	            var importDeclaration = createNode(225 /* ImportDeclaration */, fullStart);
	            importDeclaration.decorators = decorators;
	            setModifiers(importDeclaration, modifiers);
	            // ImportDeclaration:
	            //  import ImportClause from ModuleSpecifier ;
	            //  import ModuleSpecifier;
	            if (identifier ||
	                token === 37 /* AsteriskToken */ ||
	                token === 15 /* OpenBraceToken */) {
	                importDeclaration.importClause = parseImportClause(identifier, afterImportPos);
	                parseExpected(133 /* FromKeyword */);
	            }
	            importDeclaration.moduleSpecifier = parseModuleSpecifier();
	            parseSemicolon();
	            return finishNode(importDeclaration);
	        }
	        function parseImportClause(identifier, fullStart) {
	            // ImportClause:
	            //  ImportedDefaultBinding
	            //  NameSpaceImport
	            //  NamedImports
	            //  ImportedDefaultBinding, NameSpaceImport
	            //  ImportedDefaultBinding, NamedImports
	            var importClause = createNode(226 /* ImportClause */, fullStart);
	            if (identifier) {
	                // ImportedDefaultBinding:
	                //  ImportedBinding
	                importClause.name = identifier;
	            }
	            // If there was no default import or if there is comma token after default import
	            // parse namespace or named imports
	            if (!importClause.name ||
	                parseOptional(24 /* CommaToken */)) {
	                importClause.namedBindings = token === 37 /* AsteriskToken */ ? parseNamespaceImport() : parseNamedImportsOrExports(228 /* NamedImports */);
	            }
	            return finishNode(importClause);
	        }
	        function parseModuleReference() {
	            return isExternalModuleReference()
	                ? parseExternalModuleReference()
	                : parseEntityName(/*allowReservedWords*/ false);
	        }
	        function parseExternalModuleReference() {
	            var node = createNode(235 /* ExternalModuleReference */);
	            parseExpected(127 /* RequireKeyword */);
	            parseExpected(17 /* OpenParenToken */);
	            node.expression = parseModuleSpecifier();
	            parseExpected(18 /* CloseParenToken */);
	            return finishNode(node);
	        }
	        function parseModuleSpecifier() {
	            if (token === 9 /* StringLiteral */) {
	                var result = parseLiteralNode();
	                internIdentifier(result.text);
	                return result;
	            }
	            else {
	                // We allow arbitrary expressions here, even though the grammar only allows string
	                // literals.  We check to ensure that it is only a string literal later in the grammar
	                // check pass.
	                return parseExpression();
	            }
	        }
	        function parseNamespaceImport() {
	            // NameSpaceImport:
	            //  * as ImportedBinding
	            var namespaceImport = createNode(227 /* NamespaceImport */);
	            parseExpected(37 /* AsteriskToken */);
	            parseExpected(116 /* AsKeyword */);
	            namespaceImport.name = parseIdentifier();
	            return finishNode(namespaceImport);
	        }
	        function parseNamedImportsOrExports(kind) {
	            var node = createNode(kind);
	            // NamedImports:
	            //  { }
	            //  { ImportsList }
	            //  { ImportsList, }
	            // ImportsList:
	            //  ImportSpecifier
	            //  ImportsList, ImportSpecifier
	            node.elements = parseBracketedList(21 /* ImportOrExportSpecifiers */, kind === 228 /* NamedImports */ ? parseImportSpecifier : parseExportSpecifier, 15 /* OpenBraceToken */, 16 /* CloseBraceToken */);
	            return finishNode(node);
	        }
	        function parseExportSpecifier() {
	            return parseImportOrExportSpecifier(233 /* ExportSpecifier */);
	        }
	        function parseImportSpecifier() {
	            return parseImportOrExportSpecifier(229 /* ImportSpecifier */);
	        }
	        function parseImportOrExportSpecifier(kind) {
	            var node = createNode(kind);
	            // ImportSpecifier:
	            //   BindingIdentifier
	            //   IdentifierName as BindingIdentifier
	            // ExportSpecififer:
	            //   IdentifierName
	            //   IdentifierName as IdentifierName
	            var checkIdentifierIsKeyword = ts.isKeyword(token) && !isIdentifier();
	            var checkIdentifierStart = scanner.getTokenPos();
	            var checkIdentifierEnd = scanner.getTextPos();
	            var identifierName = parseIdentifierName();
	            if (token === 116 /* AsKeyword */) {
	                node.propertyName = identifierName;
	                parseExpected(116 /* AsKeyword */);
	                checkIdentifierIsKeyword = ts.isKeyword(token) && !isIdentifier();
	                checkIdentifierStart = scanner.getTokenPos();
	                checkIdentifierEnd = scanner.getTextPos();
	                node.name = parseIdentifierName();
	            }
	            else {
	                node.name = identifierName;
	            }
	            if (kind === 229 /* ImportSpecifier */ && checkIdentifierIsKeyword) {
	                // Report error identifier expected
	                parseErrorAtPosition(checkIdentifierStart, checkIdentifierEnd - checkIdentifierStart, ts.Diagnostics.Identifier_expected);
	            }
	            return finishNode(node);
	        }
	        function parseExportDeclaration(fullStart, decorators, modifiers) {
	            var node = createNode(231 /* ExportDeclaration */, fullStart);
	            node.decorators = decorators;
	            setModifiers(node, modifiers);
	            if (parseOptional(37 /* AsteriskToken */)) {
	                parseExpected(133 /* FromKeyword */);
	                node.moduleSpecifier = parseModuleSpecifier();
	            }
	            else {
	                node.exportClause = parseNamedImportsOrExports(232 /* NamedExports */);
	                // It is not uncommon to accidentally omit the 'from' keyword. Additionally, in editing scenarios,
	                // the 'from' keyword can be parsed as a named export when the export clause is unterminated (i.e. `export { from "moduleName";`)
	                // If we don't have a 'from' keyword, see if we have a string literal such that ASI won't take effect.
	                if (token === 133 /* FromKeyword */ || (token === 9 /* StringLiteral */ && !scanner.hasPrecedingLineBreak())) {
	                    parseExpected(133 /* FromKeyword */);
	                    node.moduleSpecifier = parseModuleSpecifier();
	                }
	            }
	            parseSemicolon();
	            return finishNode(node);
	        }
	        function parseExportAssignment(fullStart, decorators, modifiers) {
	            var node = createNode(230 /* ExportAssignment */, fullStart);
	            node.decorators = decorators;
	            setModifiers(node, modifiers);
	            if (parseOptional(56 /* EqualsToken */)) {
	                node.isExportEquals = true;
	            }
	            else {
	                parseExpected(77 /* DefaultKeyword */);
	            }
	            node.expression = parseAssignmentExpressionOrHigher();
	            parseSemicolon();
	            return finishNode(node);
	        }
	        function processReferenceComments(sourceFile) {
	            var triviaScanner = ts.createScanner(sourceFile.languageVersion, /*skipTrivia*/ false, 0 /* Standard */, sourceText);
	            var referencedFiles = [];
	            var amdDependencies = [];
	            var amdModuleName;
	            // Keep scanning all the leading trivia in the file until we get to something that
	            // isn't trivia.  Any single line comment will be analyzed to see if it is a
	            // reference comment.
	            while (true) {
	                var kind = triviaScanner.scan();
	                if (kind !== 2 /* SingleLineCommentTrivia */) {
	                    if (ts.isTrivia(kind)) {
	                        continue;
	                    }
	                    else {
	                        break;
	                    }
	                }
	                var range = { pos: triviaScanner.getTokenPos(), end: triviaScanner.getTextPos(), kind: triviaScanner.getToken() };
	                var comment = sourceText.substring(range.pos, range.end);
	                var referencePathMatchResult = ts.getFileReferenceFromReferencePath(comment, range);
	                if (referencePathMatchResult) {
	                    var fileReference = referencePathMatchResult.fileReference;
	                    sourceFile.hasNoDefaultLib = referencePathMatchResult.isNoDefaultLib;
	                    var diagnosticMessage = referencePathMatchResult.diagnosticMessage;
	                    if (fileReference) {
	                        referencedFiles.push(fileReference);
	                    }
	                    if (diagnosticMessage) {
	                        parseDiagnostics.push(ts.createFileDiagnostic(sourceFile, range.pos, range.end - range.pos, diagnosticMessage));
	                    }
	                }
	                else {
	                    var amdModuleNameRegEx = /^\/\/\/\s*<amd-module\s+name\s*=\s*('|")(.+?)\1/gim;
	                    var amdModuleNameMatchResult = amdModuleNameRegEx.exec(comment);
	                    if (amdModuleNameMatchResult) {
	                        if (amdModuleName) {
	                            parseDiagnostics.push(ts.createFileDiagnostic(sourceFile, range.pos, range.end - range.pos, ts.Diagnostics.An_AMD_module_cannot_have_multiple_name_assignments));
	                        }
	                        amdModuleName = amdModuleNameMatchResult[2];
	                    }
	                    var amdDependencyRegEx = /^\/\/\/\s*<amd-dependency\s/gim;
	                    var pathRegex = /\spath\s*=\s*('|")(.+?)\1/gim;
	                    var nameRegex = /\sname\s*=\s*('|")(.+?)\1/gim;
	                    var amdDependencyMatchResult = amdDependencyRegEx.exec(comment);
	                    if (amdDependencyMatchResult) {
	                        var pathMatchResult = pathRegex.exec(comment);
	                        var nameMatchResult = nameRegex.exec(comment);
	                        if (pathMatchResult) {
	                            var amdDependency = { path: pathMatchResult[2], name: nameMatchResult ? nameMatchResult[2] : undefined };
	                            amdDependencies.push(amdDependency);
	                        }
	                    }
	                }
	            }
	            sourceFile.referencedFiles = referencedFiles;
	            sourceFile.amdDependencies = amdDependencies;
	            sourceFile.moduleName = amdModuleName;
	        }
	        function setExternalModuleIndicator(sourceFile) {
	            sourceFile.externalModuleIndicator = ts.forEach(sourceFile.statements, function (node) {
	                return node.flags & 2 /* Export */
	                    || node.kind === 224 /* ImportEqualsDeclaration */ && node.moduleReference.kind === 235 /* ExternalModuleReference */
	                    || node.kind === 225 /* ImportDeclaration */
	                    || node.kind === 230 /* ExportAssignment */
	                    || node.kind === 231 /* ExportDeclaration */
	                    ? node
	                    : undefined;
	            });
	        }
	        var ParsingContext;
	        (function (ParsingContext) {
	            ParsingContext[ParsingContext["SourceElements"] = 0] = "SourceElements";
	            ParsingContext[ParsingContext["BlockStatements"] = 1] = "BlockStatements";
	            ParsingContext[ParsingContext["SwitchClauses"] = 2] = "SwitchClauses";
	            ParsingContext[ParsingContext["SwitchClauseStatements"] = 3] = "SwitchClauseStatements";
	            ParsingContext[ParsingContext["TypeMembers"] = 4] = "TypeMembers";
	            ParsingContext[ParsingContext["ClassMembers"] = 5] = "ClassMembers";
	            ParsingContext[ParsingContext["EnumMembers"] = 6] = "EnumMembers";
	            ParsingContext[ParsingContext["HeritageClauseElement"] = 7] = "HeritageClauseElement";
	            ParsingContext[ParsingContext["VariableDeclarations"] = 8] = "VariableDeclarations";
	            ParsingContext[ParsingContext["ObjectBindingElements"] = 9] = "ObjectBindingElements";
	            ParsingContext[ParsingContext["ArrayBindingElements"] = 10] = "ArrayBindingElements";
	            ParsingContext[ParsingContext["ArgumentExpressions"] = 11] = "ArgumentExpressions";
	            ParsingContext[ParsingContext["ObjectLiteralMembers"] = 12] = "ObjectLiteralMembers";
	            ParsingContext[ParsingContext["JsxAttributes"] = 13] = "JsxAttributes";
	            ParsingContext[ParsingContext["JsxChildren"] = 14] = "JsxChildren";
	            ParsingContext[ParsingContext["ArrayLiteralMembers"] = 15] = "ArrayLiteralMembers";
	            ParsingContext[ParsingContext["Parameters"] = 16] = "Parameters";
	            ParsingContext[ParsingContext["TypeParameters"] = 17] = "TypeParameters";
	            ParsingContext[ParsingContext["TypeArguments"] = 18] = "TypeArguments";
	            ParsingContext[ParsingContext["TupleElementTypes"] = 19] = "TupleElementTypes";
	            ParsingContext[ParsingContext["HeritageClauses"] = 20] = "HeritageClauses";
	            ParsingContext[ParsingContext["ImportOrExportSpecifiers"] = 21] = "ImportOrExportSpecifiers";
	            ParsingContext[ParsingContext["JSDocFunctionParameters"] = 22] = "JSDocFunctionParameters";
	            ParsingContext[ParsingContext["JSDocTypeArguments"] = 23] = "JSDocTypeArguments";
	            ParsingContext[ParsingContext["JSDocRecordMembers"] = 24] = "JSDocRecordMembers";
	            ParsingContext[ParsingContext["JSDocTupleTypes"] = 25] = "JSDocTupleTypes";
	            ParsingContext[ParsingContext["Count"] = 26] = "Count"; // Number of parsing contexts
	        })(ParsingContext || (ParsingContext = {}));
	        var Tristate;
	        (function (Tristate) {
	            Tristate[Tristate["False"] = 0] = "False";
	            Tristate[Tristate["True"] = 1] = "True";
	            Tristate[Tristate["Unknown"] = 2] = "Unknown";
	        })(Tristate || (Tristate = {}));
	        var JSDocParser;
	        (function (JSDocParser) {
	            function isJSDocType() {
	                switch (token) {
	                    case 37 /* AsteriskToken */:
	                    case 53 /* QuestionToken */:
	                    case 17 /* OpenParenToken */:
	                    case 19 /* OpenBracketToken */:
	                    case 49 /* ExclamationToken */:
	                    case 15 /* OpenBraceToken */:
	                    case 87 /* FunctionKeyword */:
	                    case 22 /* DotDotDotToken */:
	                    case 92 /* NewKeyword */:
	                    case 97 /* ThisKeyword */:
	                        return true;
	                }
	                return ts.tokenIsIdentifierOrKeyword(token);
	            }
	            JSDocParser.isJSDocType = isJSDocType;
	            function parseJSDocTypeExpressionForTests(content, start, length) {
	                initializeState("file.js", content, 2 /* Latest */, /*isJavaScriptFile*/ true, /*_syntaxCursor:*/ undefined);
	                scanner.setText(content, start, length);
	                token = scanner.scan();
	                var jsDocTypeExpression = parseJSDocTypeExpression();
	                var diagnostics = parseDiagnostics;
	                clearState();
	                return jsDocTypeExpression ? { jsDocTypeExpression: jsDocTypeExpression, diagnostics: diagnostics } : undefined;
	            }
	            JSDocParser.parseJSDocTypeExpressionForTests = parseJSDocTypeExpressionForTests;
	            // Parses out a JSDoc type expression.
	            /* @internal */
	            function parseJSDocTypeExpression() {
	                var result = createNode(252 /* JSDocTypeExpression */, scanner.getTokenPos());
	                parseExpected(15 /* OpenBraceToken */);
	                result.type = parseJSDocTopLevelType();
	                parseExpected(16 /* CloseBraceToken */);
	                fixupParentReferences(result);
	                return finishNode(result);
	            }
	            JSDocParser.parseJSDocTypeExpression = parseJSDocTypeExpression;
	            function parseJSDocTopLevelType() {
	                var type = parseJSDocType();
	                if (token === 47 /* BarToken */) {
	                    var unionType = createNode(256 /* JSDocUnionType */, type.pos);
	                    unionType.types = parseJSDocTypeList(type);
	                    type = finishNode(unionType);
	                }
	                if (token === 56 /* EqualsToken */) {
	                    var optionalType = createNode(263 /* JSDocOptionalType */, type.pos);
	                    nextToken();
	                    optionalType.type = type;
	                    type = finishNode(optionalType);
	                }
	                return type;
	            }
	            function parseJSDocType() {
	                var type = parseBasicTypeExpression();
	                while (true) {
	                    if (token === 19 /* OpenBracketToken */) {
	                        var arrayType = createNode(255 /* JSDocArrayType */, type.pos);
	                        arrayType.elementType = type;
	                        nextToken();
	                        parseExpected(20 /* CloseBracketToken */);
	                        type = finishNode(arrayType);
	                    }
	                    else if (token === 53 /* QuestionToken */) {
	                        var nullableType = createNode(258 /* JSDocNullableType */, type.pos);
	                        nullableType.type = type;
	                        nextToken();
	                        type = finishNode(nullableType);
	                    }
	                    else if (token === 49 /* ExclamationToken */) {
	                        var nonNullableType = createNode(259 /* JSDocNonNullableType */, type.pos);
	                        nonNullableType.type = type;
	                        nextToken();
	                        type = finishNode(nonNullableType);
	                    }
	                    else {
	                        break;
	                    }
	                }
	                return type;
	            }
	            function parseBasicTypeExpression() {
	                switch (token) {
	                    case 37 /* AsteriskToken */:
	                        return parseJSDocAllType();
	                    case 53 /* QuestionToken */:
	                        return parseJSDocUnknownOrNullableType();
	                    case 17 /* OpenParenToken */:
	                        return parseJSDocUnionType();
	                    case 19 /* OpenBracketToken */:
	                        return parseJSDocTupleType();
	                    case 49 /* ExclamationToken */:
	                        return parseJSDocNonNullableType();
	                    case 15 /* OpenBraceToken */:
	                        return parseJSDocRecordType();
	                    case 87 /* FunctionKeyword */:
	                        return parseJSDocFunctionType();
	                    case 22 /* DotDotDotToken */:
	                        return parseJSDocVariadicType();
	                    case 92 /* NewKeyword */:
	                        return parseJSDocConstructorType();
	                    case 97 /* ThisKeyword */:
	                        return parseJSDocThisType();
	                    case 117 /* AnyKeyword */:
	                    case 130 /* StringKeyword */:
	                    case 128 /* NumberKeyword */:
	                    case 120 /* BooleanKeyword */:
	                    case 131 /* SymbolKeyword */:
	                    case 103 /* VoidKeyword */:
	                        return parseTokenNode();
	                }
	                // TODO (drosen): Parse string literal types in JSDoc as well.
	                return parseJSDocTypeReference();
	            }
	            function parseJSDocThisType() {
	                var result = createNode(267 /* JSDocThisType */);
	                nextToken();
	                parseExpected(54 /* ColonToken */);
	                result.type = parseJSDocType();
	                return finishNode(result);
	            }
	            function parseJSDocConstructorType() {
	                var result = createNode(266 /* JSDocConstructorType */);
	                nextToken();
	                parseExpected(54 /* ColonToken */);
	                result.type = parseJSDocType();
	                return finishNode(result);
	            }
	            function parseJSDocVariadicType() {
	                var result = createNode(265 /* JSDocVariadicType */);
	                nextToken();
	                result.type = parseJSDocType();
	                return finishNode(result);
	            }
	            function parseJSDocFunctionType() {
	                var result = createNode(264 /* JSDocFunctionType */);
	                nextToken();
	                parseExpected(17 /* OpenParenToken */);
	                result.parameters = parseDelimitedList(22 /* JSDocFunctionParameters */, parseJSDocParameter);
	                checkForTrailingComma(result.parameters);
	                parseExpected(18 /* CloseParenToken */);
	                if (token === 54 /* ColonToken */) {
	                    nextToken();
	                    result.type = parseJSDocType();
	                }
	                return finishNode(result);
	            }
	            function parseJSDocParameter() {
	                var parameter = createNode(139 /* Parameter */);
	                parameter.type = parseJSDocType();
	                if (parseOptional(56 /* EqualsToken */)) {
	                    parameter.questionToken = createNode(56 /* EqualsToken */);
	                }
	                return finishNode(parameter);
	            }
	            function parseJSDocTypeReference() {
	                var result = createNode(262 /* JSDocTypeReference */);
	                result.name = parseSimplePropertyName();
	                if (token === 25 /* LessThanToken */) {
	                    result.typeArguments = parseTypeArguments();
	                }
	                else {
	                    while (parseOptional(21 /* DotToken */)) {
	                        if (token === 25 /* LessThanToken */) {
	                            result.typeArguments = parseTypeArguments();
	                            break;
	                        }
	                        else {
	                            result.name = parseQualifiedName(result.name);
	                        }
	                    }
	                }
	                return finishNode(result);
	            }
	            function parseTypeArguments() {
	                // Move past the <
	                nextToken();
	                var typeArguments = parseDelimitedList(23 /* JSDocTypeArguments */, parseJSDocType);
	                checkForTrailingComma(typeArguments);
	                checkForEmptyTypeArgumentList(typeArguments);
	                parseExpected(27 /* GreaterThanToken */);
	                return typeArguments;
	            }
	            function checkForEmptyTypeArgumentList(typeArguments) {
	                if (parseDiagnostics.length === 0 && typeArguments && typeArguments.length === 0) {
	                    var start = typeArguments.pos - "<".length;
	                    var end = ts.skipTrivia(sourceText, typeArguments.end) + ">".length;
	                    return parseErrorAtPosition(start, end - start, ts.Diagnostics.Type_argument_list_cannot_be_empty);
	                }
	            }
	            function parseQualifiedName(left) {
	                var result = createNode(136 /* QualifiedName */, left.pos);
	                result.left = left;
	                result.right = parseIdentifierName();
	                return finishNode(result);
	            }
	            function parseJSDocRecordType() {
	                var result = createNode(260 /* JSDocRecordType */);
	                nextToken();
	                result.members = parseDelimitedList(24 /* JSDocRecordMembers */, parseJSDocRecordMember);
	                checkForTrailingComma(result.members);
	                parseExpected(16 /* CloseBraceToken */);
	                return finishNode(result);
	            }
	            function parseJSDocRecordMember() {
	                var result = createNode(261 /* JSDocRecordMember */);
	                result.name = parseSimplePropertyName();
	                if (token === 54 /* ColonToken */) {
	                    nextToken();
	                    result.type = parseJSDocType();
	                }
	                return finishNode(result);
	            }
	            function parseJSDocNonNullableType() {
	                var result = createNode(259 /* JSDocNonNullableType */);
	                nextToken();
	                result.type = parseJSDocType();
	                return finishNode(result);
	            }
	            function parseJSDocTupleType() {
	                var result = createNode(257 /* JSDocTupleType */);
	                nextToken();
	                result.types = parseDelimitedList(25 /* JSDocTupleTypes */, parseJSDocType);
	                checkForTrailingComma(result.types);
	                parseExpected(20 /* CloseBracketToken */);
	                return finishNode(result);
	            }
	            function checkForTrailingComma(list) {
	                if (parseDiagnostics.length === 0 && list.hasTrailingComma) {
	                    var start = list.end - ",".length;
	                    parseErrorAtPosition(start, ",".length, ts.Diagnostics.Trailing_comma_not_allowed);
	                }
	            }
	            function parseJSDocUnionType() {
	                var result = createNode(256 /* JSDocUnionType */);
	                nextToken();
	                result.types = parseJSDocTypeList(parseJSDocType());
	                parseExpected(18 /* CloseParenToken */);
	                return finishNode(result);
	            }
	            function parseJSDocTypeList(firstType) {
	                ts.Debug.assert(!!firstType);
	                var types = [];
	                types.pos = firstType.pos;
	                types.push(firstType);
	                while (parseOptional(47 /* BarToken */)) {
	                    types.push(parseJSDocType());
	                }
	                types.end = scanner.getStartPos();
	                return types;
	            }
	            function parseJSDocAllType() {
	                var result = createNode(253 /* JSDocAllType */);
	                nextToken();
	                return finishNode(result);
	            }
	            function parseJSDocUnknownOrNullableType() {
	                var pos = scanner.getStartPos();
	                // skip the ?
	                nextToken();
	                // Need to lookahead to decide if this is a nullable or unknown type.
	                // Here are cases where we'll pick the unknown type:
	                //
	                //      Foo(?,
	                //      { a: ? }
	                //      Foo(?)
	                //      Foo<?>
	                //      Foo(?=
	                //      (?|
	                if (token === 24 /* CommaToken */ ||
	                    token === 16 /* CloseBraceToken */ ||
	                    token === 18 /* CloseParenToken */ ||
	                    token === 27 /* GreaterThanToken */ ||
	                    token === 56 /* EqualsToken */ ||
	                    token === 47 /* BarToken */) {
	                    var result = createNode(254 /* JSDocUnknownType */, pos);
	                    return finishNode(result);
	                }
	                else {
	                    var result = createNode(258 /* JSDocNullableType */, pos);
	                    result.type = parseJSDocType();
	                    return finishNode(result);
	                }
	            }
	            function parseIsolatedJSDocComment(content, start, length) {
	                initializeState("file.js", content, 2 /* Latest */, /*isJavaScriptFile*/ true, /*_syntaxCursor:*/ undefined);
	                sourceFile = { languageVariant: 0 /* Standard */, text: content };
	                var jsDocComment = parseJSDocCommentWorker(start, length);
	                var diagnostics = parseDiagnostics;
	                clearState();
	                return jsDocComment ? { jsDocComment: jsDocComment, diagnostics: diagnostics } : undefined;
	            }
	            JSDocParser.parseIsolatedJSDocComment = parseIsolatedJSDocComment;
	            function parseJSDocComment(parent, start, length) {
	                var saveToken = token;
	                var saveParseDiagnosticsLength = parseDiagnostics.length;
	                var saveParseErrorBeforeNextFinishedNode = parseErrorBeforeNextFinishedNode;
	                var comment = parseJSDocCommentWorker(start, length);
	                if (comment) {
	                    comment.parent = parent;
	                }
	                token = saveToken;
	                parseDiagnostics.length = saveParseDiagnosticsLength;
	                parseErrorBeforeNextFinishedNode = saveParseErrorBeforeNextFinishedNode;
	                return comment;
	            }
	            JSDocParser.parseJSDocComment = parseJSDocComment;
	            function parseJSDocCommentWorker(start, length) {
	                var content = sourceText;
	                start = start || 0;
	                var end = length === undefined ? content.length : start + length;
	                length = end - start;
	                ts.Debug.assert(start >= 0);
	                ts.Debug.assert(start <= end);
	                ts.Debug.assert(end <= content.length);
	                var tags;
	                var result;
	                // Check for /** (JSDoc opening part)
	                if (content.charCodeAt(start) === 47 /* slash */ &&
	                    content.charCodeAt(start + 1) === 42 /* asterisk */ &&
	                    content.charCodeAt(start + 2) === 42 /* asterisk */ &&
	                    content.charCodeAt(start + 3) !== 42 /* asterisk */) {
	                    // + 3 for leading /**, - 5 in total for /** */
	                    scanner.scanRange(start + 3, length - 5, function () {
	                        // Initially we can parse out a tag.  We also have seen a starting asterisk.
	                        // This is so that /** * @type */ doesn't parse.
	                        var canParseTag = true;
	                        var seenAsterisk = true;
	                        nextJSDocToken();
	                        while (token !== 1 /* EndOfFileToken */) {
	                            switch (token) {
	                                case 55 /* AtToken */:
	                                    if (canParseTag) {
	                                        parseTag();
	                                    }
	                                    // This will take us to the end of the line, so it's OK to parse a tag on the next pass through the loop
	                                    seenAsterisk = false;
	                                    break;
	                                case 4 /* NewLineTrivia */:
	                                    // After a line break, we can parse a tag, and we haven't seen an asterisk on the next line yet
	                                    canParseTag = true;
	                                    seenAsterisk = false;
	                                    break;
	                                case 37 /* AsteriskToken */:
	                                    if (seenAsterisk) {
	                                        // If we've already seen an asterisk, then we can no longer parse a tag on this line
	                                        canParseTag = false;
	                                    }
	                                    // Ignore the first asterisk on a line
	                                    seenAsterisk = true;
	                                    break;
	                                case 69 /* Identifier */:
	                                    // Anything else is doc comment text.  We can't do anything with it.  Because it
	                                    // wasn't a tag, we can no longer parse a tag on this line until we hit the next
	                                    // line break.
	                                    canParseTag = false;
	                                    break;
	                                case 1 /* EndOfFileToken */:
	                                    break;
	                            }
	                            nextJSDocToken();
	                        }
	                        result = createJSDocComment();
	                    });
	                }
	                return result;
	                function createJSDocComment() {
	                    if (!tags) {
	                        return undefined;
	                    }
	                    var result = createNode(268 /* JSDocComment */, start);
	                    result.tags = tags;
	                    return finishNode(result, end);
	                }
	                function skipWhitespace() {
	                    while (token === 5 /* WhitespaceTrivia */ || token === 4 /* NewLineTrivia */) {
	                        nextJSDocToken();
	                    }
	                }
	                function parseTag() {
	                    ts.Debug.assert(token === 55 /* AtToken */);
	                    var atToken = createNode(55 /* AtToken */, scanner.getTokenPos());
	                    atToken.end = scanner.getTextPos();
	                    nextJSDocToken();
	                    var tagName = parseJSDocIdentifier();
	                    if (!tagName) {
	                        return;
	                    }
	                    var tag = handleTag(atToken, tagName) || handleUnknownTag(atToken, tagName);
	                    addTag(tag);
	                }
	                function handleTag(atToken, tagName) {
	                    if (tagName) {
	                        switch (tagName.text) {
	                            case "param":
	                                return handleParamTag(atToken, tagName);
	                            case "return":
	                            case "returns":
	                                return handleReturnTag(atToken, tagName);
	                            case "template":
	                                return handleTemplateTag(atToken, tagName);
	                            case "type":
	                                return handleTypeTag(atToken, tagName);
	                        }
	                    }
	                    return undefined;
	                }
	                function handleUnknownTag(atToken, tagName) {
	                    var result = createNode(269 /* JSDocTag */, atToken.pos);
	                    result.atToken = atToken;
	                    result.tagName = tagName;
	                    return finishNode(result);
	                }
	                function addTag(tag) {
	                    if (tag) {
	                        if (!tags) {
	                            tags = [];
	                            tags.pos = tag.pos;
	                        }
	                        tags.push(tag);
	                        tags.end = tag.end;
	                    }
	                }
	                function tryParseTypeExpression() {
	                    if (token !== 15 /* OpenBraceToken */) {
	                        return undefined;
	                    }
	                    var typeExpression = parseJSDocTypeExpression();
	                    return typeExpression;
	                }
	                function handleParamTag(atToken, tagName) {
	                    var typeExpression = tryParseTypeExpression();
	                    skipWhitespace();
	                    var name;
	                    var isBracketed;
	                    // Looking for something like '[foo]' or 'foo'
	                    if (parseOptionalToken(19 /* OpenBracketToken */)) {
	                        name = parseJSDocIdentifier();
	                        isBracketed = true;
	                        // May have an optional default, e.g. '[foo = 42]'
	                        if (parseOptionalToken(56 /* EqualsToken */)) {
	                            parseExpression();
	                        }
	                        parseExpected(20 /* CloseBracketToken */);
	                    }
	                    else if (token === 69 /* Identifier */) {
	                        name = parseJSDocIdentifier();
	                    }
	                    if (!name) {
	                        parseErrorAtPosition(scanner.getStartPos(), 0, ts.Diagnostics.Identifier_expected);
	                        return undefined;
	                    }
	                    var preName, postName;
	                    if (typeExpression) {
	                        postName = name;
	                    }
	                    else {
	                        preName = name;
	                    }
	                    if (!typeExpression) {
	                        typeExpression = tryParseTypeExpression();
	                    }
	                    var result = createNode(270 /* JSDocParameterTag */, atToken.pos);
	                    result.atToken = atToken;
	                    result.tagName = tagName;
	                    result.preParameterName = preName;
	                    result.typeExpression = typeExpression;
	                    result.postParameterName = postName;
	                    result.isBracketed = isBracketed;
	                    return finishNode(result);
	                }
	                function handleReturnTag(atToken, tagName) {
	                    if (ts.forEach(tags, function (t) { return t.kind === 271 /* JSDocReturnTag */; })) {
	                        parseErrorAtPosition(tagName.pos, scanner.getTokenPos() - tagName.pos, ts.Diagnostics._0_tag_already_specified, tagName.text);
	                    }
	                    var result = createNode(271 /* JSDocReturnTag */, atToken.pos);
	                    result.atToken = atToken;
	                    result.tagName = tagName;
	                    result.typeExpression = tryParseTypeExpression();
	                    return finishNode(result);
	                }
	                function handleTypeTag(atToken, tagName) {
	                    if (ts.forEach(tags, function (t) { return t.kind === 272 /* JSDocTypeTag */; })) {
	                        parseErrorAtPosition(tagName.pos, scanner.getTokenPos() - tagName.pos, ts.Diagnostics._0_tag_already_specified, tagName.text);
	                    }
	                    var result = createNode(272 /* JSDocTypeTag */, atToken.pos);
	                    result.atToken = atToken;
	                    result.tagName = tagName;
	                    result.typeExpression = tryParseTypeExpression();
	                    return finishNode(result);
	                }
	                function handleTemplateTag(atToken, tagName) {
	                    if (ts.forEach(tags, function (t) { return t.kind === 273 /* JSDocTemplateTag */; })) {
	                        parseErrorAtPosition(tagName.pos, scanner.getTokenPos() - tagName.pos, ts.Diagnostics._0_tag_already_specified, tagName.text);
	                    }
	                    // Type parameter list looks like '@template T,U,V'
	                    var typeParameters = [];
	                    typeParameters.pos = scanner.getStartPos();
	                    while (true) {
	                        var name_8 = parseJSDocIdentifier();
	                        if (!name_8) {
	                            parseErrorAtPosition(scanner.getStartPos(), 0, ts.Diagnostics.Identifier_expected);
	                            return undefined;
	                        }
	                        var typeParameter = createNode(138 /* TypeParameter */, name_8.pos);
	                        typeParameter.name = name_8;
	                        finishNode(typeParameter);
	                        typeParameters.push(typeParameter);
	                        if (token === 24 /* CommaToken */) {
	                            nextJSDocToken();
	                        }
	                        else {
	                            break;
	                        }
	                    }
	                    var result = createNode(273 /* JSDocTemplateTag */, atToken.pos);
	                    result.atToken = atToken;
	                    result.tagName = tagName;
	                    result.typeParameters = typeParameters;
	                    finishNode(result);
	                    typeParameters.end = result.end;
	                    return result;
	                }
	                function nextJSDocToken() {
	                    return token = scanner.scanJSDocToken();
	                }
	                function parseJSDocIdentifier() {
	                    if (token !== 69 /* Identifier */) {
	                        parseErrorAtCurrentToken(ts.Diagnostics.Identifier_expected);
	                        return undefined;
	                    }
	                    var pos = scanner.getTokenPos();
	                    var end = scanner.getTextPos();
	                    var result = createNode(69 /* Identifier */, pos);
	                    result.text = content.substring(pos, end);
	                    finishNode(result, end);
	                    nextJSDocToken();
	                    return result;
	                }
	            }
	            JSDocParser.parseJSDocCommentWorker = parseJSDocCommentWorker;
	        })(JSDocParser = Parser.JSDocParser || (Parser.JSDocParser = {}));
	    })(Parser || (Parser = {}));
	    var IncrementalParser;
	    (function (IncrementalParser) {
	        function updateSourceFile(sourceFile, newText, textChangeRange, aggressiveChecks) {
	            aggressiveChecks = aggressiveChecks || ts.Debug.shouldAssert(2 /* Aggressive */);
	            checkChangeRange(sourceFile, newText, textChangeRange, aggressiveChecks);
	            if (ts.textChangeRangeIsUnchanged(textChangeRange)) {
	                // if the text didn't change, then we can just return our current source file as-is.
	                return sourceFile;
	            }
	            if (sourceFile.statements.length === 0) {
	                // If we don't have any statements in the current source file, then there's no real
	                // way to incrementally parse.  So just do a full parse instead.
	                return Parser.parseSourceFile(sourceFile.fileName, newText, sourceFile.languageVersion, /*syntaxCursor*/ undefined, /*setParentNodes*/ true);
	            }
	            // Make sure we're not trying to incrementally update a source file more than once.  Once
	            // we do an update the original source file is considered unusbale from that point onwards.
	            //
	            // This is because we do incremental parsing in-place.  i.e. we take nodes from the old
	            // tree and give them new positions and parents.  From that point on, trusting the old
	            // tree at all is not possible as far too much of it may violate invariants.
	            var incrementalSourceFile = sourceFile;
	            ts.Debug.assert(!incrementalSourceFile.hasBeenIncrementallyParsed);
	            incrementalSourceFile.hasBeenIncrementallyParsed = true;
	            var oldText = sourceFile.text;
	            var syntaxCursor = createSyntaxCursor(sourceFile);
	            // Make the actual change larger so that we know to reparse anything whose lookahead
	            // might have intersected the change.
	            var changeRange = extendToAffectedRange(sourceFile, textChangeRange);
	            checkChangeRange(sourceFile, newText, changeRange, aggressiveChecks);
	            // Ensure that extending the affected range only moved the start of the change range
	            // earlier in the file.
	            ts.Debug.assert(changeRange.span.start <= textChangeRange.span.start);
	            ts.Debug.assert(ts.textSpanEnd(changeRange.span) === ts.textSpanEnd(textChangeRange.span));
	            ts.Debug.assert(ts.textSpanEnd(ts.textChangeRangeNewSpan(changeRange)) === ts.textSpanEnd(ts.textChangeRangeNewSpan(textChangeRange)));
	            // The is the amount the nodes after the edit range need to be adjusted.  It can be
	            // positive (if the edit added characters), negative (if the edit deleted characters)
	            // or zero (if this was a pure overwrite with nothing added/removed).
	            var delta = ts.textChangeRangeNewSpan(changeRange).length - changeRange.span.length;
	            // If we added or removed characters during the edit, then we need to go and adjust all
	            // the nodes after the edit.  Those nodes may move forward (if we inserted chars) or they
	            // may move backward (if we deleted chars).
	            //
	            // Doing this helps us out in two ways.  First, it means that any nodes/tokens we want
	            // to reuse are already at the appropriate position in the new text.  That way when we
	            // reuse them, we don't have to figure out if they need to be adjusted.  Second, it makes
	            // it very easy to determine if we can reuse a node.  If the node's position is at where
	            // we are in the text, then we can reuse it.  Otherwise we can't.  If the node's position
	            // is ahead of us, then we'll need to rescan tokens.  If the node's position is behind
	            // us, then we'll need to skip it or crumble it as appropriate
	            //
	            // We will also adjust the positions of nodes that intersect the change range as well.
	            // By doing this, we ensure that all the positions in the old tree are consistent, not
	            // just the positions of nodes entirely before/after the change range.  By being
	            // consistent, we can then easily map from positions to nodes in the old tree easily.
	            //
	            // Also, mark any syntax elements that intersect the changed span.  We know, up front,
	            // that we cannot reuse these elements.
	            updateTokenPositionsAndMarkElements(incrementalSourceFile, changeRange.span.start, ts.textSpanEnd(changeRange.span), ts.textSpanEnd(ts.textChangeRangeNewSpan(changeRange)), delta, oldText, newText, aggressiveChecks);
	            // Now that we've set up our internal incremental state just proceed and parse the
	            // source file in the normal fashion.  When possible the parser will retrieve and
	            // reuse nodes from the old tree.
	            //
	            // Note: passing in 'true' for setNodeParents is very important.  When incrementally
	            // parsing, we will be reusing nodes from the old tree, and placing it into new
	            // parents.  If we don't set the parents now, we'll end up with an observably
	            // inconsistent tree.  Setting the parents on the new tree should be very fast.  We
	            // will immediately bail out of walking any subtrees when we can see that their parents
	            // are already correct.
	            var result = Parser.parseSourceFile(sourceFile.fileName, newText, sourceFile.languageVersion, syntaxCursor, /*setParentNodes*/ true);
	            return result;
	        }
	        IncrementalParser.updateSourceFile = updateSourceFile;
	        function moveElementEntirelyPastChangeRange(element, isArray, delta, oldText, newText, aggressiveChecks) {
	            if (isArray) {
	                visitArray(element);
	            }
	            else {
	                visitNode(element);
	            }
	            return;
	            function visitNode(node) {
	                var text = "";
	                if (aggressiveChecks && shouldCheckNode(node)) {
	                    text = oldText.substring(node.pos, node.end);
	                }
	                // Ditch any existing LS children we may have created.  This way we can avoid
	                // moving them forward.
	                if (node._children) {
	                    node._children = undefined;
	                }
	                if (node.jsDocComment) {
	                    node.jsDocComment = undefined;
	                }
	                node.pos += delta;
	                node.end += delta;
	                if (aggressiveChecks && shouldCheckNode(node)) {
	                    ts.Debug.assert(text === newText.substring(node.pos, node.end));
	                }
	                forEachChild(node, visitNode, visitArray);
	                checkNodePositions(node, aggressiveChecks);
	            }
	            function visitArray(array) {
	                array._children = undefined;
	                array.pos += delta;
	                array.end += delta;
	                for (var _i = 0, array_7 = array; _i < array_7.length; _i++) {
	                    var node = array_7[_i];
	                    visitNode(node);
	                }
	            }
	        }
	        function shouldCheckNode(node) {
	            switch (node.kind) {
	                case 9 /* StringLiteral */:
	                case 8 /* NumericLiteral */:
	                case 69 /* Identifier */:
	                    return true;
	            }
	            return false;
	        }
	        function adjustIntersectingElement(element, changeStart, changeRangeOldEnd, changeRangeNewEnd, delta) {
	            ts.Debug.assert(element.end >= changeStart, "Adjusting an element that was entirely before the change range");
	            ts.Debug.assert(element.pos <= changeRangeOldEnd, "Adjusting an element that was entirely after the change range");
	            ts.Debug.assert(element.pos <= element.end);
	            // We have an element that intersects the change range in some way.  It may have its
	            // start, or its end (or both) in the changed range.  We want to adjust any part
	            // that intersects such that the final tree is in a consistent state.  i.e. all
	            // chlidren have spans within the span of their parent, and all siblings are ordered
	            // properly.
	            // We may need to update both the 'pos' and the 'end' of the element.
	            // If the 'pos' is before the start of the change, then we don't need to touch it.
	            // If it isn't, then the 'pos' must be inside the change.  How we update it will
	            // depend if delta is  positive or negative.  If delta is positive then we have
	            // something like:
	            //
	            //  -------------------AAA-----------------
	            //  -------------------BBBCCCCCCC-----------------
	            //
	            // In this case, we consider any node that started in the change range to still be
	            // starting at the same position.
	            //
	            // however, if the delta is negative, then we instead have something like this:
	            //
	            //  -------------------XXXYYYYYYY-----------------
	            //  -------------------ZZZ-----------------
	            //
	            // In this case, any element that started in the 'X' range will keep its position.
	            // However any element htat started after that will have their pos adjusted to be
	            // at the end of the new range.  i.e. any node that started in the 'Y' range will
	            // be adjusted to have their start at the end of the 'Z' range.
	            //
	            // The element will keep its position if possible.  Or Move backward to the new-end
	            // if it's in the 'Y' range.
	            element.pos = Math.min(element.pos, changeRangeNewEnd);
	            // If the 'end' is after the change range, then we always adjust it by the delta
	            // amount.  However, if the end is in the change range, then how we adjust it
	            // will depend on if delta is  positive or negative.  If delta is positive then we
	            // have something like:
	            //
	            //  -------------------AAA-----------------
	            //  -------------------BBBCCCCCCC-----------------
	            //
	            // In this case, we consider any node that ended inside the change range to keep its
	            // end position.
	            //
	            // however, if the delta is negative, then we instead have something like this:
	            //
	            //  -------------------XXXYYYYYYY-----------------
	            //  -------------------ZZZ-----------------
	            //
	            // In this case, any element that ended in the 'X' range will keep its position.
	            // However any element htat ended after that will have their pos adjusted to be
	            // at the end of the new range.  i.e. any node that ended in the 'Y' range will
	            // be adjusted to have their end at the end of the 'Z' range.
	            if (element.end >= changeRangeOldEnd) {
	                // Element ends after the change range.  Always adjust the end pos.
	                element.end += delta;
	            }
	            else {
	                // Element ends in the change range.  The element will keep its position if
	                // possible. Or Move backward to the new-end if it's in the 'Y' range.
	                element.end = Math.min(element.end, changeRangeNewEnd);
	            }
	            ts.Debug.assert(element.pos <= element.end);
	            if (element.parent) {
	                ts.Debug.assert(element.pos >= element.parent.pos);
	                ts.Debug.assert(element.end <= element.parent.end);
	            }
	        }
	        function checkNodePositions(node, aggressiveChecks) {
	            if (aggressiveChecks) {
	                var pos_2 = node.pos;
	                forEachChild(node, function (child) {
	                    ts.Debug.assert(child.pos >= pos_2);
	                    pos_2 = child.end;
	                });
	                ts.Debug.assert(pos_2 <= node.end);
	            }
	        }
	        function updateTokenPositionsAndMarkElements(sourceFile, changeStart, changeRangeOldEnd, changeRangeNewEnd, delta, oldText, newText, aggressiveChecks) {
	            visitNode(sourceFile);
	            return;
	            function visitNode(child) {
	                ts.Debug.assert(child.pos <= child.end);
	                if (child.pos > changeRangeOldEnd) {
	                    // Node is entirely past the change range.  We need to move both its pos and
	                    // end, forward or backward appropriately.
	                    moveElementEntirelyPastChangeRange(child, /*isArray*/ false, delta, oldText, newText, aggressiveChecks);
	                    return;
	                }
	                // Check if the element intersects the change range.  If it does, then it is not
	                // reusable.  Also, we'll need to recurse to see what constituent portions we may
	                // be able to use.
	                var fullEnd = child.end;
	                if (fullEnd >= changeStart) {
	                    child.intersectsChange = true;
	                    child._children = undefined;
	                    // Adjust the pos or end (or both) of the intersecting element accordingly.
	                    adjustIntersectingElement(child, changeStart, changeRangeOldEnd, changeRangeNewEnd, delta);
	                    forEachChild(child, visitNode, visitArray);
	                    checkNodePositions(child, aggressiveChecks);
	                    return;
	                }
	                // Otherwise, the node is entirely before the change range.  No need to do anything with it.
	                ts.Debug.assert(fullEnd < changeStart);
	            }
	            function visitArray(array) {
	                ts.Debug.assert(array.pos <= array.end);
	                if (array.pos > changeRangeOldEnd) {
	                    // Array is entirely after the change range.  We need to move it, and move any of
	                    // its children.
	                    moveElementEntirelyPastChangeRange(array, /*isArray*/ true, delta, oldText, newText, aggressiveChecks);
	                    return;
	                }
	                // Check if the element intersects the change range.  If it does, then it is not
	                // reusable.  Also, we'll need to recurse to see what constituent portions we may
	                // be able to use.
	                var fullEnd = array.end;
	                if (fullEnd >= changeStart) {
	                    array.intersectsChange = true;
	                    array._children = undefined;
	                    // Adjust the pos or end (or both) of the intersecting array accordingly.
	                    adjustIntersectingElement(array, changeStart, changeRangeOldEnd, changeRangeNewEnd, delta);
	                    for (var _i = 0, array_8 = array; _i < array_8.length; _i++) {
	                        var node = array_8[_i];
	                        visitNode(node);
	                    }
	                    return;
	                }
	                // Otherwise, the array is entirely before the change range.  No need to do anything with it.
	                ts.Debug.assert(fullEnd < changeStart);
	            }
	        }
	        function extendToAffectedRange(sourceFile, changeRange) {
	            // Consider the following code:
	            //      void foo() { /; }
	            //
	            // If the text changes with an insertion of / just before the semicolon then we end up with:
	            //      void foo() { //; }
	            //
	            // If we were to just use the changeRange a is, then we would not rescan the { token
	            // (as it does not intersect the actual original change range).  Because an edit may
	            // change the token touching it, we actually need to look back *at least* one token so
	            // that the prior token sees that change.
	            var maxLookahead = 1;
	            var start = changeRange.span.start;
	            // the first iteration aligns us with the change start. subsequent iteration move us to
	            // the left by maxLookahead tokens.  We only need to do this as long as we're not at the
	            // start of the tree.
	            for (var i = 0; start > 0 && i <= maxLookahead; i++) {
	                var nearestNode = findNearestNodeStartingBeforeOrAtPosition(sourceFile, start);
	                ts.Debug.assert(nearestNode.pos <= start);
	                var position = nearestNode.pos;
	                start = Math.max(0, position - 1);
	            }
	            var finalSpan = ts.createTextSpanFromBounds(start, ts.textSpanEnd(changeRange.span));
	            var finalLength = changeRange.newLength + (changeRange.span.start - start);
	            return ts.createTextChangeRange(finalSpan, finalLength);
	        }
	        function findNearestNodeStartingBeforeOrAtPosition(sourceFile, position) {
	            var bestResult = sourceFile;
	            var lastNodeEntirelyBeforePosition;
	            forEachChild(sourceFile, visit);
	            if (lastNodeEntirelyBeforePosition) {
	                var lastChildOfLastEntireNodeBeforePosition = getLastChild(lastNodeEntirelyBeforePosition);
	                if (lastChildOfLastEntireNodeBeforePosition.pos > bestResult.pos) {
	                    bestResult = lastChildOfLastEntireNodeBeforePosition;
	                }
	            }
	            return bestResult;
	            function getLastChild(node) {
	                while (true) {
	                    var lastChild = getLastChildWorker(node);
	                    if (lastChild) {
	                        node = lastChild;
	                    }
	                    else {
	                        return node;
	                    }
	                }
	            }
	            function getLastChildWorker(node) {
	                var last = undefined;
	                forEachChild(node, function (child) {
	                    if (ts.nodeIsPresent(child)) {
	                        last = child;
	                    }
	                });
	                return last;
	            }
	            function visit(child) {
	                if (ts.nodeIsMissing(child)) {
	                    // Missing nodes are effectively invisible to us.  We never even consider them
	                    // When trying to find the nearest node before us.
	                    return;
	                }
	                // If the child intersects this position, then this node is currently the nearest
	                // node that starts before the position.
	                if (child.pos <= position) {
	                    if (child.pos >= bestResult.pos) {
	                        // This node starts before the position, and is closer to the position than
	                        // the previous best node we found.  It is now the new best node.
	                        bestResult = child;
	                    }
	                    // Now, the node may overlap the position, or it may end entirely before the
	                    // position.  If it overlaps with the position, then either it, or one of its
	                    // children must be the nearest node before the position.  So we can just
	                    // recurse into this child to see if we can find something better.
	                    if (position < child.end) {
	                        // The nearest node is either this child, or one of the children inside
	                        // of it.  We've already marked this child as the best so far.  Recurse
	                        // in case one of the children is better.
	                        forEachChild(child, visit);
	                        // Once we look at the children of this node, then there's no need to
	                        // continue any further.
	                        return true;
	                    }
	                    else {
	                        ts.Debug.assert(child.end <= position);
	                        // The child ends entirely before this position.  Say you have the following
	                        // (where $ is the position)
	                        //
	                        //      <complex expr 1> ? <complex expr 2> $ : <...> <...>
	                        //
	                        // We would want to find the nearest preceding node in "complex expr 2".
	                        // To support that, we keep track of this node, and once we're done searching
	                        // for a best node, we recurse down this node to see if we can find a good
	                        // result in it.
	                        //
	                        // This approach allows us to quickly skip over nodes that are entirely
	                        // before the position, while still allowing us to find any nodes in the
	                        // last one that might be what we want.
	                        lastNodeEntirelyBeforePosition = child;
	                    }
	                }
	                else {
	                    ts.Debug.assert(child.pos > position);
	                    // We're now at a node that is entirely past the position we're searching for.
	                    // This node (and all following nodes) could never contribute to the result,
	                    // so just skip them by returning 'true' here.
	                    return true;
	                }
	            }
	        }
	        function checkChangeRange(sourceFile, newText, textChangeRange, aggressiveChecks) {
	            var oldText = sourceFile.text;
	            if (textChangeRange) {
	                ts.Debug.assert((oldText.length - textChangeRange.span.length + textChangeRange.newLength) === newText.length);
	                if (aggressiveChecks || ts.Debug.shouldAssert(3 /* VeryAggressive */)) {
	                    var oldTextPrefix = oldText.substr(0, textChangeRange.span.start);
	                    var newTextPrefix = newText.substr(0, textChangeRange.span.start);
	                    ts.Debug.assert(oldTextPrefix === newTextPrefix);
	                    var oldTextSuffix = oldText.substring(ts.textSpanEnd(textChangeRange.span), oldText.length);
	                    var newTextSuffix = newText.substring(ts.textSpanEnd(ts.textChangeRangeNewSpan(textChangeRange)), newText.length);
	                    ts.Debug.assert(oldTextSuffix === newTextSuffix);
	                }
	            }
	        }
	        function createSyntaxCursor(sourceFile) {
	            var currentArray = sourceFile.statements;
	            var currentArrayIndex = 0;
	            ts.Debug.assert(currentArrayIndex < currentArray.length);
	            var current = currentArray[currentArrayIndex];
	            var lastQueriedPosition = -1 /* Value */;
	            return {
	                currentNode: function (position) {
	                    // Only compute the current node if the position is different than the last time
	                    // we were asked.  The parser commonly asks for the node at the same position
	                    // twice.  Once to know if can read an appropriate list element at a certain point,
	                    // and then to actually read and consume the node.
	                    if (position !== lastQueriedPosition) {
	                        // Much of the time the parser will need the very next node in the array that
	                        // we just returned a node from.So just simply check for that case and move
	                        // forward in the array instead of searching for the node again.
	                        if (current && current.end === position && currentArrayIndex < (currentArray.length - 1)) {
	                            currentArrayIndex++;
	                            current = currentArray[currentArrayIndex];
	                        }
	                        // If we don't have a node, or the node we have isn't in the right position,
	                        // then try to find a viable node at the position requested.
	                        if (!current || current.pos !== position) {
	                            findHighestListElementThatStartsAtPosition(position);
	                        }
	                    }
	                    // Cache this query so that we don't do any extra work if the parser calls back
	                    // into us.  Note: this is very common as the parser will make pairs of calls like
	                    // 'isListElement -> parseListElement'.  If we were unable to find a node when
	                    // called with 'isListElement', we don't want to redo the work when parseListElement
	                    // is called immediately after.
	                    lastQueriedPosition = position;
	                    // Either we don'd have a node, or we have a node at the position being asked for.
	                    ts.Debug.assert(!current || current.pos === position);
	                    return current;
	                }
	            };
	            // Finds the highest element in the tree we can find that starts at the provided position.
	            // The element must be a direct child of some node list in the tree.  This way after we
	            // return it, we can easily return its next sibling in the list.
	            function findHighestListElementThatStartsAtPosition(position) {
	                // Clear out any cached state about the last node we found.
	                currentArray = undefined;
	                currentArrayIndex = -1 /* Value */;
	                current = undefined;
	                // Recurse into the source file to find the highest node at this position.
	                forEachChild(sourceFile, visitNode, visitArray);
	                return;
	                function visitNode(node) {
	                    if (position >= node.pos && position < node.end) {
	                        // Position was within this node.  Keep searching deeper to find the node.
	                        forEachChild(node, visitNode, visitArray);
	                        // don't procede any futher in the search.
	                        return true;
	                    }
	                    // position wasn't in this node, have to keep searching.
	                    return false;
	                }
	                function visitArray(array) {
	                    if (position >= array.pos && position < array.end) {
	                        // position was in this array.  Search through this array to see if we find a
	                        // viable element.
	                        for (var i = 0, n = array.length; i < n; i++) {
	                            var child = array[i];
	                            if (child) {
	                                if (child.pos === position) {
	                                    // Found the right node.  We're done.
	                                    currentArray = array;
	                                    currentArrayIndex = i;
	                                    current = child;
	                                    return true;
	                                }
	                                else {
	                                    if (child.pos < position && position < child.end) {
	                                        // Position in somewhere within this child.  Search in it and
	                                        // stop searching in this array.
	                                        forEachChild(child, visitNode, visitArray);
	                                        return true;
	                                    }
	                                }
	                            }
	                        }
	                    }
	                    // position wasn't in this array, have to keep searching.
	                    return false;
	                }
	            }
	        }
	        var InvalidPosition;
	        (function (InvalidPosition) {
	            InvalidPosition[InvalidPosition["Value"] = -1] = "Value";
	        })(InvalidPosition || (InvalidPosition = {}));
	    })(IncrementalParser || (IncrementalParser = {}));
	})(ts || (ts = {}));
	/// <reference path="utilities.ts"/>
	/// <reference path="parser.ts"/>
	/* @internal */
	var ts;
	(function (ts) {
	    ts.bindTime = 0;
	    (function (ModuleInstanceState) {
	        ModuleInstanceState[ModuleInstanceState["NonInstantiated"] = 0] = "NonInstantiated";
	        ModuleInstanceState[ModuleInstanceState["Instantiated"] = 1] = "Instantiated";
	        ModuleInstanceState[ModuleInstanceState["ConstEnumOnly"] = 2] = "ConstEnumOnly";
	    })(ts.ModuleInstanceState || (ts.ModuleInstanceState = {}));
	    var ModuleInstanceState = ts.ModuleInstanceState;
	    var Reachability;
	    (function (Reachability) {
	        Reachability[Reachability["Unintialized"] = 1] = "Unintialized";
	        Reachability[Reachability["Reachable"] = 2] = "Reachable";
	        Reachability[Reachability["Unreachable"] = 4] = "Unreachable";
	        Reachability[Reachability["ReportedUnreachable"] = 8] = "ReportedUnreachable";
	    })(Reachability || (Reachability = {}));
	    function or(state1, state2) {
	        return (state1 | state2) & 2 /* Reachable */
	            ? 2 /* Reachable */
	            : (state1 & state2) & 8 /* ReportedUnreachable */
	                ? 8 /* ReportedUnreachable */
	                : 4 /* Unreachable */;
	    }
	    function getModuleInstanceState(node) {
	        // A module is uninstantiated if it contains only
	        // 1. interface declarations, type alias declarations
	        if (node.kind === 218 /* InterfaceDeclaration */ || node.kind === 219 /* TypeAliasDeclaration */) {
	            return 0 /* NonInstantiated */;
	        }
	        else if (ts.isConstEnumDeclaration(node)) {
	            return 2 /* ConstEnumOnly */;
	        }
	        else if ((node.kind === 225 /* ImportDeclaration */ || node.kind === 224 /* ImportEqualsDeclaration */) && !(node.flags & 2 /* Export */)) {
	            return 0 /* NonInstantiated */;
	        }
	        else if (node.kind === 222 /* ModuleBlock */) {
	            var state_1 = 0 /* NonInstantiated */;
	            ts.forEachChild(node, function (n) {
	                switch (getModuleInstanceState(n)) {
	                    case 0 /* NonInstantiated */:
	                        // child is non-instantiated - continue searching
	                        return false;
	                    case 2 /* ConstEnumOnly */:
	                        // child is const enum only - record state and continue searching
	                        state_1 = 2 /* ConstEnumOnly */;
	                        return false;
	                    case 1 /* Instantiated */:
	                        // child is instantiated - record state and stop
	                        state_1 = 1 /* Instantiated */;
	                        return true;
	                }
	            });
	            return state_1;
	        }
	        else if (node.kind === 221 /* ModuleDeclaration */) {
	            return getModuleInstanceState(node.body);
	        }
	        else {
	            return 1 /* Instantiated */;
	        }
	    }
	    ts.getModuleInstanceState = getModuleInstanceState;
	    var ContainerFlags;
	    (function (ContainerFlags) {
	        // The current node is not a container, and no container manipulation should happen before
	        // recursing into it.
	        ContainerFlags[ContainerFlags["None"] = 0] = "None";
	        // The current node is a container.  It should be set as the current container (and block-
	        // container) before recursing into it.  The current node does not have locals.  Examples:
	        //
	        //      Classes, ObjectLiterals, TypeLiterals, Interfaces...
	        ContainerFlags[ContainerFlags["IsContainer"] = 1] = "IsContainer";
	        // The current node is a block-scoped-container.  It should be set as the current block-
	        // container before recursing into it.  Examples:
	        //
	        //      Blocks (when not parented by functions), Catch clauses, For/For-in/For-of statements...
	        ContainerFlags[ContainerFlags["IsBlockScopedContainer"] = 2] = "IsBlockScopedContainer";
	        ContainerFlags[ContainerFlags["HasLocals"] = 4] = "HasLocals";
	        // If the current node is a container that also container that also contains locals.  Examples:
	        //
	        //      Functions, Methods, Modules, Source-files.
	        ContainerFlags[ContainerFlags["IsContainerWithLocals"] = 5] = "IsContainerWithLocals";
	    })(ContainerFlags || (ContainerFlags = {}));
	    var binder = createBinder();
	    function bindSourceFile(file, options) {
	        var start = new Date().getTime();
	        binder(file, options);
	        ts.bindTime += new Date().getTime() - start;
	    }
	    ts.bindSourceFile = bindSourceFile;
	    function createBinder() {
	        var file;
	        var options;
	        var parent;
	        var container;
	        var blockScopeContainer;
	        var lastContainer;
	        var seenThisKeyword;
	        // state used by reachability checks
	        var hasExplicitReturn;
	        var currentReachabilityState;
	        var labelStack;
	        var labelIndexMap;
	        var implicitLabels;
	        // state used for emit helpers
	        var hasClassExtends;
	        var hasAsyncFunctions;
	        var hasDecorators;
	        var hasParameterDecorators;
	        // If this file is an external module, then it is automatically in strict-mode according to
	        // ES6.  If it is not an external module, then we'll determine if it is in strict mode or
	        // not depending on if we see "use strict" in certain places (or if we hit a class/namespace).
	        var inStrictMode;
	        var symbolCount = 0;
	        var Symbol;
	        var classifiableNames;
	        function bindSourceFile(f, opts) {
	            file = f;
	            options = opts;
	            inStrictMode = !!file.externalModuleIndicator;
	            classifiableNames = {};
	            Symbol = ts.objectAllocator.getSymbolConstructor();
	            if (!file.locals) {
	                bind(file);
	                file.symbolCount = symbolCount;
	                file.classifiableNames = classifiableNames;
	            }
	            file = undefined;
	            options = undefined;
	            parent = undefined;
	            container = undefined;
	            blockScopeContainer = undefined;
	            lastContainer = undefined;
	            seenThisKeyword = false;
	            hasExplicitReturn = false;
	            labelStack = undefined;
	            labelIndexMap = undefined;
	            implicitLabels = undefined;
	            hasClassExtends = false;
	            hasAsyncFunctions = false;
	            hasDecorators = false;
	            hasParameterDecorators = false;
	        }
	        return bindSourceFile;
	        function createSymbol(flags, name) {
	            symbolCount++;
	            return new Symbol(flags, name);
	        }
	        function addDeclarationToSymbol(symbol, node, symbolFlags) {
	            symbol.flags |= symbolFlags;
	            node.symbol = symbol;
	            if (!symbol.declarations) {
	                symbol.declarations = [];
	            }
	            symbol.declarations.push(node);
	            if (symbolFlags & 1952 /* HasExports */ && !symbol.exports) {
	                symbol.exports = {};
	            }
	            if (symbolFlags & 6240 /* HasMembers */ && !symbol.members) {
	                symbol.members = {};
	            }
	            if (symbolFlags & 107455 /* Value */) {
	                var valueDeclaration = symbol.valueDeclaration;
	                if (!valueDeclaration ||
	                    (valueDeclaration.kind !== node.kind && valueDeclaration.kind === 221 /* ModuleDeclaration */)) {
	                    // other kinds of value declarations take precedence over modules
	                    symbol.valueDeclaration = node;
	                }
	            }
	        }
	        // Should not be called on a declaration with a computed property name,
	        // unless it is a well known Symbol.
	        function getDeclarationName(node) {
	            if (node.name) {
	                if (ts.isAmbientModule(node)) {
	                    return ts.isGlobalScopeAugmentation(node) ? "__global" : "\"" + node.name.text + "\"";
	                }
	                if (node.name.kind === 137 /* ComputedPropertyName */) {
	                    var nameExpression = node.name.expression;
	                    // treat computed property names where expression is string/numeric literal as just string/numeric literal
	                    if (ts.isStringOrNumericLiteral(nameExpression.kind)) {
	                        return nameExpression.text;
	                    }
	                    ts.Debug.assert(ts.isWellKnownSymbolSyntactically(nameExpression));
	                    return ts.getPropertyNameForKnownSymbolName(nameExpression.name.text);
	                }
	                return node.name.text;
	            }
	            switch (node.kind) {
	                case 145 /* Constructor */:
	                    return "__constructor";
	                case 153 /* FunctionType */:
	                case 148 /* CallSignature */:
	                    return "__call";
	                case 154 /* ConstructorType */:
	                case 149 /* ConstructSignature */:
	                    return "__new";
	                case 150 /* IndexSignature */:
	                    return "__index";
	                case 231 /* ExportDeclaration */:
	                    return "__export";
	                case 230 /* ExportAssignment */:
	                    return node.isExportEquals ? "export=" : "default";
	                case 184 /* BinaryExpression */:
	                    switch (ts.getSpecialPropertyAssignmentKind(node)) {
	                        case 2 /* ModuleExports */:
	                            // module.exports = ...
	                            return "export=";
	                        case 1 /* ExportsProperty */:
	                        case 4 /* ThisProperty */:
	                            // exports.x = ... or this.y = ...
	                            return node.left.name.text;
	                        case 3 /* PrototypeProperty */:
	                            // className.prototype.methodName = ...
	                            return node.left.expression.name.text;
	                    }
	                    ts.Debug.fail("Unknown binary declaration kind");
	                    break;
	                case 216 /* FunctionDeclaration */:
	                case 217 /* ClassDeclaration */:
	                    return node.flags & 512 /* Default */ ? "default" : undefined;
	                case 264 /* JSDocFunctionType */:
	                    return ts.isJSDocConstructSignature(node) ? "__new" : "__call";
	                case 139 /* Parameter */:
	                    // Parameters with names are handled at the top of this function.  Parameters
	                    // without names can only come from JSDocFunctionTypes.
	                    ts.Debug.assert(node.parent.kind === 264 /* JSDocFunctionType */);
	                    var functionType = node.parent;
	                    var index = ts.indexOf(functionType.parameters, node);
	                    return "p" + index;
	            }
	        }
	        function getDisplayName(node) {
	            return node.name ? ts.declarationNameToString(node.name) : getDeclarationName(node);
	        }
	        /**
	         * Declares a Symbol for the node and adds it to symbols. Reports errors for conflicting identifier names.
	         * @param symbolTable - The symbol table which node will be added to.
	         * @param parent - node's parent declaration.
	         * @param node - The declaration to be added to the symbol table
	         * @param includes - The SymbolFlags that node has in addition to its declaration type (eg: export, ambient, etc.)
	         * @param excludes - The flags which node cannot be declared alongside in a symbol table. Used to report forbidden declarations.
	         */
	        function declareSymbol(symbolTable, parent, node, includes, excludes) {
	            ts.Debug.assert(!ts.hasDynamicName(node));
	            var isDefaultExport = node.flags & 512 /* Default */;
	            // The exported symbol for an export default function/class node is always named "default"
	            var name = isDefaultExport && parent ? "default" : getDeclarationName(node);
	            var symbol;
	            if (name !== undefined) {
	                // Check and see if the symbol table already has a symbol with this name.  If not,
	                // create a new symbol with this name and add it to the table.  Note that we don't
	                // give the new symbol any flags *yet*.  This ensures that it will not conflict
	                // with the 'excludes' flags we pass in.
	                //
	                // If we do get an existing symbol, see if it conflicts with the new symbol we're
	                // creating.  For example, a 'var' symbol and a 'class' symbol will conflict within
	                // the same symbol table.  If we have a conflict, report the issue on each
	                // declaration we have for this symbol, and then create a new symbol for this
	                // declaration.
	                //
	                // If we created a new symbol, either because we didn't have a symbol with this name
	                // in the symbol table, or we conflicted with an existing symbol, then just add this
	                // node as the sole declaration of the new symbol.
	                //
	                // Otherwise, we'll be merging into a compatible existing symbol (for example when
	                // you have multiple 'vars' with the same name in the same container).  In this case
	                // just add this node into the declarations list of the symbol.
	                symbol = ts.hasProperty(symbolTable, name)
	                    ? symbolTable[name]
	                    : (symbolTable[name] = createSymbol(0 /* None */, name));
	                if (name && (includes & 788448 /* Classifiable */)) {
	                    classifiableNames[name] = name;
	                }
	                if (symbol.flags & excludes) {
	                    if (node.name) {
	                        node.name.parent = node;
	                    }
	                    // Report errors every position with duplicate declaration
	                    // Report errors on previous encountered declarations
	                    var message_1 = symbol.flags & 2 /* BlockScopedVariable */
	                        ? ts.Diagnostics.Cannot_redeclare_block_scoped_variable_0
	                        : ts.Diagnostics.Duplicate_identifier_0;
	                    ts.forEach(symbol.declarations, function (declaration) {
	                        if (declaration.flags & 512 /* Default */) {
	                            message_1 = ts.Diagnostics.A_module_cannot_have_multiple_default_exports;
	                        }
	                    });
	                    ts.forEach(symbol.declarations, function (declaration) {
	                        file.bindDiagnostics.push(ts.createDiagnosticForNode(declaration.name || declaration, message_1, getDisplayName(declaration)));
	                    });
	                    file.bindDiagnostics.push(ts.createDiagnosticForNode(node.name || node, message_1, getDisplayName(node)));
	                    symbol = createSymbol(0 /* None */, name);
	                }
	            }
	            else {
	                symbol = createSymbol(0 /* None */, "__missing");
	            }
	            addDeclarationToSymbol(symbol, node, includes);
	            symbol.parent = parent;
	            return symbol;
	        }
	        function declareModuleMember(node, symbolFlags, symbolExcludes) {
	            var hasExportModifier = ts.getCombinedNodeFlags(node) & 2 /* Export */;
	            if (symbolFlags & 8388608 /* Alias */) {
	                if (node.kind === 233 /* ExportSpecifier */ || (node.kind === 224 /* ImportEqualsDeclaration */ && hasExportModifier)) {
	                    return declareSymbol(container.symbol.exports, container.symbol, node, symbolFlags, symbolExcludes);
	                }
	                else {
	                    return declareSymbol(container.locals, undefined, node, symbolFlags, symbolExcludes);
	                }
	            }
	            else {
	                // Exported module members are given 2 symbols: A local symbol that is classified with an ExportValue,
	                // ExportType, or ExportContainer flag, and an associated export symbol with all the correct flags set
	                // on it. There are 2 main reasons:
	                //
	                //   1. We treat locals and exports of the same name as mutually exclusive within a container.
	                //      That means the binder will issue a Duplicate Identifier error if you mix locals and exports
	                //      with the same name in the same container.
	                //      TODO: Make this a more specific error and decouple it from the exclusion logic.
	                //   2. When we checkIdentifier in the checker, we set its resolved symbol to the local symbol,
	                //      but return the export symbol (by calling getExportSymbolOfValueSymbolIfExported). That way
	                //      when the emitter comes back to it, it knows not to qualify the name if it was found in a containing scope.
	                // NOTE: Nested ambient modules always should go to to 'locals' table to prevent their automatic merge
	                //       during global merging in the checker. Why? The only case when ambient module is permitted inside another module is module augmentation
	                //       and this case is specially handled. Module augmentations should only be merged with original module definition
	                //       and should never be merged directly with other augmentation, and the latter case would be possible if automatic merge is allowed.
	                if (!ts.isAmbientModule(node) && (hasExportModifier || container.flags & 131072 /* ExportContext */)) {
	                    var exportKind = (symbolFlags & 107455 /* Value */ ? 1048576 /* ExportValue */ : 0) |
	                        (symbolFlags & 793056 /* Type */ ? 2097152 /* ExportType */ : 0) |
	                        (symbolFlags & 1536 /* Namespace */ ? 4194304 /* ExportNamespace */ : 0);
	                    var local = declareSymbol(container.locals, undefined, node, exportKind, symbolExcludes);
	                    local.exportSymbol = declareSymbol(container.symbol.exports, container.symbol, node, symbolFlags, symbolExcludes);
	                    node.localSymbol = local;
	                    return local;
	                }
	                else {
	                    return declareSymbol(container.locals, undefined, node, symbolFlags, symbolExcludes);
	                }
	            }
	        }
	        // All container nodes are kept on a linked list in declaration order. This list is used by
	        // the getLocalNameOfContainer function in the type checker to validate that the local name
	        // used for a container is unique.
	        function bindChildren(node) {
	            // Before we recurse into a node's chilren, we first save the existing parent, container
	            // and block-container.  Then after we pop out of processing the children, we restore
	            // these saved values.
	            var saveParent = parent;
	            var saveContainer = container;
	            var savedBlockScopeContainer = blockScopeContainer;
	            // This node will now be set as the parent of all of its children as we recurse into them.
	            parent = node;
	            // Depending on what kind of node this is, we may have to adjust the current container
	            // and block-container.   If the current node is a container, then it is automatically
	            // considered the current block-container as well.  Also, for containers that we know
	            // may contain locals, we proactively initialize the .locals field. We do this because
	            // it's highly likely that the .locals will be needed to place some child in (for example,
	            // a parameter, or variable declaration).
	            //
	            // However, we do not proactively create the .locals for block-containers because it's
	            // totally normal and common for block-containers to never actually have a block-scoped
	            // variable in them.  We don't want to end up allocating an object for every 'block' we
	            // run into when most of them won't be necessary.
	            //
	            // Finally, if this is a block-container, then we clear out any existing .locals object
	            // it may contain within it.  This happens in incremental scenarios.  Because we can be
	            // reusing a node from a previous compilation, that node may have had 'locals' created
	            // for it.  We must clear this so we don't accidently move any stale data forward from
	            // a previous compilation.
	            var containerFlags = getContainerFlags(node);
	            if (containerFlags & 1 /* IsContainer */) {
	                container = blockScopeContainer = node;
	                if (containerFlags & 4 /* HasLocals */) {
	                    container.locals = {};
	                }
	                addToContainerChain(container);
	            }
	            else if (containerFlags & 2 /* IsBlockScopedContainer */) {
	                blockScopeContainer = node;
	                blockScopeContainer.locals = undefined;
	            }
	            var savedReachabilityState;
	            var savedLabelStack;
	            var savedLabels;
	            var savedImplicitLabels;
	            var savedHasExplicitReturn;
	            var kind = node.kind;
	            var flags = node.flags;
	            // reset all reachability check related flags on node (for incremental scenarios)
	            flags &= ~1572864 /* ReachabilityCheckFlags */;
	            // reset all emit helper flags on node (for incremental scenarios)
	            flags &= ~62914560 /* EmitHelperFlags */;
	            if (kind === 218 /* InterfaceDeclaration */) {
	                seenThisKeyword = false;
	            }
	            var saveState = kind === 251 /* SourceFile */ || kind === 222 /* ModuleBlock */ || ts.isFunctionLikeKind(kind);
	            if (saveState) {
	                savedReachabilityState = currentReachabilityState;
	                savedLabelStack = labelStack;
	                savedLabels = labelIndexMap;
	                savedImplicitLabels = implicitLabels;
	                savedHasExplicitReturn = hasExplicitReturn;
	                currentReachabilityState = 2 /* Reachable */;
	                hasExplicitReturn = false;
	                labelStack = labelIndexMap = implicitLabels = undefined;
	            }
	            if (ts.isInJavaScriptFile(node) && node.jsDocComment) {
	                bind(node.jsDocComment);
	            }
	            bindReachableStatement(node);
	            if (currentReachabilityState === 2 /* Reachable */ && ts.isFunctionLikeKind(kind) && ts.nodeIsPresent(node.body)) {
	                flags |= 524288 /* HasImplicitReturn */;
	                if (hasExplicitReturn) {
	                    flags |= 1048576 /* HasExplicitReturn */;
	                }
	            }
	            if (kind === 218 /* InterfaceDeclaration */) {
	                flags = seenThisKeyword ? flags | 262144 /* ContainsThis */ : flags & ~262144 /* ContainsThis */;
	            }
	            if (kind === 251 /* SourceFile */) {
	                if (hasClassExtends) {
	                    flags |= 4194304 /* HasClassExtends */;
	                }
	                if (hasDecorators) {
	                    flags |= 8388608 /* HasDecorators */;
	                }
	                if (hasParameterDecorators) {
	                    flags |= 16777216 /* HasParamDecorators */;
	                }
	                if (hasAsyncFunctions) {
	                    flags |= 33554432 /* HasAsyncFunctions */;
	                }
	            }
	            node.flags = flags;
	            if (saveState) {
	                hasExplicitReturn = savedHasExplicitReturn;
	                currentReachabilityState = savedReachabilityState;
	                labelStack = savedLabelStack;
	                labelIndexMap = savedLabels;
	                implicitLabels = savedImplicitLabels;
	            }
	            container = saveContainer;
	            parent = saveParent;
	            blockScopeContainer = savedBlockScopeContainer;
	        }
	        /**
	         * Returns true if node and its subnodes were successfully traversed.
	         * Returning false means that node was not examined and caller needs to dive into the node himself.
	         */
	        function bindReachableStatement(node) {
	            if (checkUnreachable(node)) {
	                ts.forEachChild(node, bind);
	                return;
	            }
	            switch (node.kind) {
	                case 201 /* WhileStatement */:
	                    bindWhileStatement(node);
	                    break;
	                case 200 /* DoStatement */:
	                    bindDoStatement(node);
	                    break;
	                case 202 /* ForStatement */:
	                    bindForStatement(node);
	                    break;
	                case 203 /* ForInStatement */:
	                case 204 /* ForOfStatement */:
	                    bindForInOrForOfStatement(node);
	                    break;
	                case 199 /* IfStatement */:
	                    bindIfStatement(node);
	                    break;
	                case 207 /* ReturnStatement */:
	                case 211 /* ThrowStatement */:
	                    bindReturnOrThrow(node);
	                    break;
	                case 206 /* BreakStatement */:
	                case 205 /* ContinueStatement */:
	                    bindBreakOrContinueStatement(node);
	                    break;
	                case 212 /* TryStatement */:
	                    bindTryStatement(node);
	                    break;
	                case 209 /* SwitchStatement */:
	                    bindSwitchStatement(node);
	                    break;
	                case 223 /* CaseBlock */:
	                    bindCaseBlock(node);
	                    break;
	                case 210 /* LabeledStatement */:
	                    bindLabeledStatement(node);
	                    break;
	                default:
	                    ts.forEachChild(node, bind);
	                    break;
	            }
	        }
	        function bindWhileStatement(n) {
	            var preWhileState = n.expression.kind === 84 /* FalseKeyword */ ? 4 /* Unreachable */ : currentReachabilityState;
	            var postWhileState = n.expression.kind === 99 /* TrueKeyword */ ? 4 /* Unreachable */ : currentReachabilityState;
	            // bind expressions (don't affect reachability)
	            bind(n.expression);
	            currentReachabilityState = preWhileState;
	            var postWhileLabel = pushImplicitLabel();
	            bind(n.statement);
	            popImplicitLabel(postWhileLabel, postWhileState);
	        }
	        function bindDoStatement(n) {
	            var preDoState = currentReachabilityState;
	            var postDoLabel = pushImplicitLabel();
	            bind(n.statement);
	            var postDoState = n.expression.kind === 99 /* TrueKeyword */ ? 4 /* Unreachable */ : preDoState;
	            popImplicitLabel(postDoLabel, postDoState);
	            // bind expressions (don't affect reachability)
	            bind(n.expression);
	        }
	        function bindForStatement(n) {
	            var preForState = currentReachabilityState;
	            var postForLabel = pushImplicitLabel();
	            // bind expressions (don't affect reachability)
	            bind(n.initializer);
	            bind(n.condition);
	            bind(n.incrementor);
	            bind(n.statement);
	            // for statement is considered infinite when it condition is either omitted or is true keyword
	            // - for(..;;..)
	            // - for(..;true;..)
	            var isInfiniteLoop = (!n.condition || n.condition.kind === 99 /* TrueKeyword */);
	            var postForState = isInfiniteLoop ? 4 /* Unreachable */ : preForState;
	            popImplicitLabel(postForLabel, postForState);
	        }
	        function bindForInOrForOfStatement(n) {
	            var preStatementState = currentReachabilityState;
	            var postStatementLabel = pushImplicitLabel();
	            // bind expressions (don't affect reachability)
	            bind(n.initializer);
	            bind(n.expression);
	            bind(n.statement);
	            popImplicitLabel(postStatementLabel, preStatementState);
	        }
	        function bindIfStatement(n) {
	            // denotes reachability state when entering 'thenStatement' part of the if statement:
	            // i.e. if condition is false then thenStatement is unreachable
	            var ifTrueState = n.expression.kind === 84 /* FalseKeyword */ ? 4 /* Unreachable */ : currentReachabilityState;
	            // denotes reachability state when entering 'elseStatement':
	            // i.e. if condition is true then elseStatement is unreachable
	            var ifFalseState = n.expression.kind === 99 /* TrueKeyword */ ? 4 /* Unreachable */ : currentReachabilityState;
	            currentReachabilityState = ifTrueState;
	            // bind expression (don't affect reachability)
	            bind(n.expression);
	            bind(n.thenStatement);
	            if (n.elseStatement) {
	                var preElseState = currentReachabilityState;
	                currentReachabilityState = ifFalseState;
	                bind(n.elseStatement);
	                currentReachabilityState = or(currentReachabilityState, preElseState);
	            }
	            else {
	                currentReachabilityState = or(currentReachabilityState, ifFalseState);
	            }
	        }
	        function bindReturnOrThrow(n) {
	            // bind expression (don't affect reachability)
	            bind(n.expression);
	            if (n.kind === 207 /* ReturnStatement */) {
	                hasExplicitReturn = true;
	            }
	            currentReachabilityState = 4 /* Unreachable */;
	        }
	        function bindBreakOrContinueStatement(n) {
	            // call bind on label (don't affect reachability)
	            bind(n.label);
	            // for continue case touch label so it will be marked a used
	            var isValidJump = jumpToLabel(n.label, n.kind === 206 /* BreakStatement */ ? currentReachabilityState : 4 /* Unreachable */);
	            if (isValidJump) {
	                currentReachabilityState = 4 /* Unreachable */;
	            }
	        }
	        function bindTryStatement(n) {
	            // catch\finally blocks has the same reachability as try block
	            var preTryState = currentReachabilityState;
	            bind(n.tryBlock);
	            var postTryState = currentReachabilityState;
	            currentReachabilityState = preTryState;
	            bind(n.catchClause);
	            var postCatchState = currentReachabilityState;
	            currentReachabilityState = preTryState;
	            bind(n.finallyBlock);
	            // post catch/finally state is reachable if
	            // - post try state is reachable - control flow can fall out of try block
	            // - post catch state is reachable - control flow can fall out of catch block
	            currentReachabilityState = or(postTryState, postCatchState);
	        }
	        function bindSwitchStatement(n) {
	            var preSwitchState = currentReachabilityState;
	            var postSwitchLabel = pushImplicitLabel();
	            // bind expression (don't affect reachability)
	            bind(n.expression);
	            bind(n.caseBlock);
	            var hasDefault = ts.forEach(n.caseBlock.clauses, function (c) { return c.kind === 245 /* DefaultClause */; });
	            // post switch state is unreachable if switch is exaustive (has a default case ) and does not have fallthrough from the last case
	            var postSwitchState = hasDefault && currentReachabilityState !== 2 /* Reachable */ ? 4 /* Unreachable */ : preSwitchState;
	            popImplicitLabel(postSwitchLabel, postSwitchState);
	        }
	        function bindCaseBlock(n) {
	            var startState = currentReachabilityState;
	            for (var _i = 0, _a = n.clauses; _i < _a.length; _i++) {
	                var clause = _a[_i];
	                currentReachabilityState = startState;
	                bind(clause);
	                if (clause.statements.length && currentReachabilityState === 2 /* Reachable */ && options.noFallthroughCasesInSwitch) {
	                    errorOnFirstToken(clause, ts.Diagnostics.Fallthrough_case_in_switch);
	                }
	            }
	        }
	        function bindLabeledStatement(n) {
	            // call bind on label (don't affect reachability)
	            bind(n.label);
	            var ok = pushNamedLabel(n.label);
	            bind(n.statement);
	            if (ok) {
	                popNamedLabel(n.label, currentReachabilityState);
	            }
	        }
	        function getContainerFlags(node) {
	            switch (node.kind) {
	                case 189 /* ClassExpression */:
	                case 217 /* ClassDeclaration */:
	                case 218 /* InterfaceDeclaration */:
	                case 220 /* EnumDeclaration */:
	                case 168 /* ObjectLiteralExpression */:
	                case 156 /* TypeLiteral */:
	                case 260 /* JSDocRecordType */:
	                    return 1 /* IsContainer */;
	                case 148 /* CallSignature */:
	                case 149 /* ConstructSignature */:
	                case 150 /* IndexSignature */:
	                case 144 /* MethodDeclaration */:
	                case 143 /* MethodSignature */:
	                case 216 /* FunctionDeclaration */:
	                case 145 /* Constructor */:
	                case 146 /* GetAccessor */:
	                case 147 /* SetAccessor */:
	                case 153 /* FunctionType */:
	                case 154 /* ConstructorType */:
	                case 176 /* FunctionExpression */:
	                case 177 /* ArrowFunction */:
	                case 221 /* ModuleDeclaration */:
	                case 251 /* SourceFile */:
	                case 219 /* TypeAliasDeclaration */:
	                    return 5 /* IsContainerWithLocals */;
	                case 247 /* CatchClause */:
	                case 202 /* ForStatement */:
	                case 203 /* ForInStatement */:
	                case 204 /* ForOfStatement */:
	                case 223 /* CaseBlock */:
	                    return 2 /* IsBlockScopedContainer */;
	                case 195 /* Block */:
	                    // do not treat blocks directly inside a function as a block-scoped-container.
	                    // Locals that reside in this block should go to the function locals. Othewise 'x'
	                    // would not appear to be a redeclaration of a block scoped local in the following
	                    // example:
	                    //
	                    //      function foo() {
	                    //          var x;
	                    //          let x;
	                    //      }
	                    //
	                    // If we placed 'var x' into the function locals and 'let x' into the locals of
	                    // the block, then there would be no collision.
	                    //
	                    // By not creating a new block-scoped-container here, we ensure that both 'var x'
	                    // and 'let x' go into the Function-container's locals, and we do get a collision
	                    // conflict.
	                    return ts.isFunctionLike(node.parent) ? 0 /* None */ : 2 /* IsBlockScopedContainer */;
	            }
	            return 0 /* None */;
	        }
	        function addToContainerChain(next) {
	            if (lastContainer) {
	                lastContainer.nextContainer = next;
	            }
	            lastContainer = next;
	        }
	        function declareSymbolAndAddToSymbolTable(node, symbolFlags, symbolExcludes) {
	            // Just call this directly so that the return type of this function stays "void".
	            declareSymbolAndAddToSymbolTableWorker(node, symbolFlags, symbolExcludes);
	        }
	        function declareSymbolAndAddToSymbolTableWorker(node, symbolFlags, symbolExcludes) {
	            switch (container.kind) {
	                // Modules, source files, and classes need specialized handling for how their
	                // members are declared (for example, a member of a class will go into a specific
	                // symbol table depending on if it is static or not). We defer to specialized
	                // handlers to take care of declaring these child members.
	                case 221 /* ModuleDeclaration */:
	                    return declareModuleMember(node, symbolFlags, symbolExcludes);
	                case 251 /* SourceFile */:
	                    return declareSourceFileMember(node, symbolFlags, symbolExcludes);
	                case 189 /* ClassExpression */:
	                case 217 /* ClassDeclaration */:
	                    return declareClassMember(node, symbolFlags, symbolExcludes);
	                case 220 /* EnumDeclaration */:
	                    return declareSymbol(container.symbol.exports, container.symbol, node, symbolFlags, symbolExcludes);
	                case 156 /* TypeLiteral */:
	                case 168 /* ObjectLiteralExpression */:
	                case 218 /* InterfaceDeclaration */:
	                case 260 /* JSDocRecordType */:
	                    // Interface/Object-types always have their children added to the 'members' of
	                    // their container. They are only accessible through an instance of their
	                    // container, and are never in scope otherwise (even inside the body of the
	                    // object / type / interface declaring them). An exception is type parameters,
	                    // which are in scope without qualification (similar to 'locals').
	                    return declareSymbol(container.symbol.members, container.symbol, node, symbolFlags, symbolExcludes);
	                case 153 /* FunctionType */:
	                case 154 /* ConstructorType */:
	                case 148 /* CallSignature */:
	                case 149 /* ConstructSignature */:
	                case 150 /* IndexSignature */:
	                case 144 /* MethodDeclaration */:
	                case 143 /* MethodSignature */:
	                case 145 /* Constructor */:
	                case 146 /* GetAccessor */:
	                case 147 /* SetAccessor */:
	                case 216 /* FunctionDeclaration */:
	                case 176 /* FunctionExpression */:
	                case 177 /* ArrowFunction */:
	                case 264 /* JSDocFunctionType */:
	                case 219 /* TypeAliasDeclaration */:
	                    // All the children of these container types are never visible through another
	                    // symbol (i.e. through another symbol's 'exports' or 'members').  Instead,
	                    // they're only accessed 'lexically' (i.e. from code that exists underneath
	                    // their container in the tree.  To accomplish this, we simply add their declared
	                    // symbol to the 'locals' of the container.  These symbols can then be found as
	                    // the type checker walks up the containers, checking them for matching names.
	                    return declareSymbol(container.locals, undefined, node, symbolFlags, symbolExcludes);
	            }
	        }
	        function declareClassMember(node, symbolFlags, symbolExcludes) {
	            return node.flags & 64 /* Static */
	                ? declareSymbol(container.symbol.exports, container.symbol, node, symbolFlags, symbolExcludes)
	                : declareSymbol(container.symbol.members, container.symbol, node, symbolFlags, symbolExcludes);
	        }
	        function declareSourceFileMember(node, symbolFlags, symbolExcludes) {
	            return ts.isExternalModule(file)
	                ? declareModuleMember(node, symbolFlags, symbolExcludes)
	                : declareSymbol(file.locals, undefined, node, symbolFlags, symbolExcludes);
	        }
	        function hasExportDeclarations(node) {
	            var body = node.kind === 251 /* SourceFile */ ? node : node.body;
	            if (body.kind === 251 /* SourceFile */ || body.kind === 222 /* ModuleBlock */) {
	                for (var _i = 0, _a = body.statements; _i < _a.length; _i++) {
	                    var stat = _a[_i];
	                    if (stat.kind === 231 /* ExportDeclaration */ || stat.kind === 230 /* ExportAssignment */) {
	                        return true;
	                    }
	                }
	            }
	            return false;
	        }
	        function setExportContextFlag(node) {
	            // A declaration source file or ambient module declaration that contains no export declarations (but possibly regular
	            // declarations with export modifiers) is an export context in which declarations are implicitly exported.
	            if (ts.isInAmbientContext(node) && !hasExportDeclarations(node)) {
	                node.flags |= 131072 /* ExportContext */;
	            }
	            else {
	                node.flags &= ~131072 /* ExportContext */;
	            }
	        }
	        function bindModuleDeclaration(node) {
	            setExportContextFlag(node);
	            if (ts.isAmbientModule(node)) {
	                if (node.flags & 2 /* Export */) {
	                    errorOnFirstToken(node, ts.Diagnostics.export_modifier_cannot_be_applied_to_ambient_modules_and_module_augmentations_since_they_are_always_visible);
	                }
	                declareSymbolAndAddToSymbolTable(node, 512 /* ValueModule */, 106639 /* ValueModuleExcludes */);
	            }
	            else {
	                var state = getModuleInstanceState(node);
	                if (state === 0 /* NonInstantiated */) {
	                    declareSymbolAndAddToSymbolTable(node, 1024 /* NamespaceModule */, 0 /* NamespaceModuleExcludes */);
	                }
	                else {
	                    declareSymbolAndAddToSymbolTable(node, 512 /* ValueModule */, 106639 /* ValueModuleExcludes */);
	                    if (node.symbol.flags & (16 /* Function */ | 32 /* Class */ | 256 /* RegularEnum */)) {
	                        // if module was already merged with some function, class or non-const enum
	                        // treat is a non-const-enum-only
	                        node.symbol.constEnumOnlyModule = false;
	                    }
	                    else {
	                        var currentModuleIsConstEnumOnly = state === 2 /* ConstEnumOnly */;
	                        if (node.symbol.constEnumOnlyModule === undefined) {
	                            // non-merged case - use the current state
	                            node.symbol.constEnumOnlyModule = currentModuleIsConstEnumOnly;
	                        }
	                        else {
	                            // merged case: module is const enum only if all its pieces are non-instantiated or const enum
	                            node.symbol.constEnumOnlyModule = node.symbol.constEnumOnlyModule && currentModuleIsConstEnumOnly;
	                        }
	                    }
	                }
	            }
	        }
	        function bindFunctionOrConstructorType(node) {
	            // For a given function symbol "<...>(...) => T" we want to generate a symbol identical
	            // to the one we would get for: { <...>(...): T }
	            //
	            // We do that by making an anonymous type literal symbol, and then setting the function
	            // symbol as its sole member. To the rest of the system, this symbol will be  indistinguishable
	            // from an actual type literal symbol you would have gotten had you used the long form.
	            var symbol = createSymbol(131072 /* Signature */, getDeclarationName(node));
	            addDeclarationToSymbol(symbol, node, 131072 /* Signature */);
	            var typeLiteralSymbol = createSymbol(2048 /* TypeLiteral */, "__type");
	            addDeclarationToSymbol(typeLiteralSymbol, node, 2048 /* TypeLiteral */);
	            typeLiteralSymbol.members = (_a = {}, _a[symbol.name] = symbol, _a);
	            var _a;
	        }
	        function bindObjectLiteralExpression(node) {
	            var ElementKind;
	            (function (ElementKind) {
	                ElementKind[ElementKind["Property"] = 1] = "Property";
	                ElementKind[ElementKind["Accessor"] = 2] = "Accessor";
	            })(ElementKind || (ElementKind = {}));
	            if (inStrictMode) {
	                var seen = {};
	                for (var _i = 0, _a = node.properties; _i < _a.length; _i++) {
	                    var prop = _a[_i];
	                    if (prop.name.kind !== 69 /* Identifier */) {
	                        continue;
	                    }
	                    var identifier = prop.name;
	                    // ECMA-262 11.1.5 Object Initialiser
	                    // If previous is not undefined then throw a SyntaxError exception if any of the following conditions are true
	                    // a.This production is contained in strict code and IsDataDescriptor(previous) is true and
	                    // IsDataDescriptor(propId.descriptor) is true.
	                    //    b.IsDataDescriptor(previous) is true and IsAccessorDescriptor(propId.descriptor) is true.
	                    //    c.IsAccessorDescriptor(previous) is true and IsDataDescriptor(propId.descriptor) is true.
	                    //    d.IsAccessorDescriptor(previous) is true and IsAccessorDescriptor(propId.descriptor) is true
	                    // and either both previous and propId.descriptor have[[Get]] fields or both previous and propId.descriptor have[[Set]] fields
	                    var currentKind = prop.kind === 248 /* PropertyAssignment */ || prop.kind === 249 /* ShorthandPropertyAssignment */ || prop.kind === 144 /* MethodDeclaration */
	                        ? 1 /* Property */
	                        : 2 /* Accessor */;
	                    var existingKind = seen[identifier.text];
	                    if (!existingKind) {
	                        seen[identifier.text] = currentKind;
	                        continue;
	                    }
	                    if (currentKind === 1 /* Property */ && existingKind === 1 /* Property */) {
	                        var span = ts.getErrorSpanForNode(file, identifier);
	                        file.bindDiagnostics.push(ts.createFileDiagnostic(file, span.start, span.length, ts.Diagnostics.An_object_literal_cannot_have_multiple_properties_with_the_same_name_in_strict_mode));
	                    }
	                }
	            }
	            return bindAnonymousDeclaration(node, 4096 /* ObjectLiteral */, "__object");
	        }
	        function bindAnonymousDeclaration(node, symbolFlags, name) {
	            var symbol = createSymbol(symbolFlags, name);
	            addDeclarationToSymbol(symbol, node, symbolFlags);
	        }
	        function bindBlockScopedDeclaration(node, symbolFlags, symbolExcludes) {
	            switch (blockScopeContainer.kind) {
	                case 221 /* ModuleDeclaration */:
	                    declareModuleMember(node, symbolFlags, symbolExcludes);
	                    break;
	                case 251 /* SourceFile */:
	                    if (ts.isExternalModule(container)) {
	                        declareModuleMember(node, symbolFlags, symbolExcludes);
	                        break;
	                    }
	                // fall through.
	                default:
	                    if (!blockScopeContainer.locals) {
	                        blockScopeContainer.locals = {};
	                        addToContainerChain(blockScopeContainer);
	                    }
	                    declareSymbol(blockScopeContainer.locals, undefined, node, symbolFlags, symbolExcludes);
	            }
	        }
	        function bindBlockScopedVariableDeclaration(node) {
	            bindBlockScopedDeclaration(node, 2 /* BlockScopedVariable */, 107455 /* BlockScopedVariableExcludes */);
	        }
	        // The binder visits every node in the syntax tree so it is a convenient place to perform a single localized
	        // check for reserved words used as identifiers in strict mode code.
	        function checkStrictModeIdentifier(node) {
	            if (inStrictMode &&
	                node.originalKeywordKind >= 106 /* FirstFutureReservedWord */ &&
	                node.originalKeywordKind <= 114 /* LastFutureReservedWord */ &&
	                !ts.isIdentifierName(node)) {
	                // Report error only if there are no parse errors in file
	                if (!file.parseDiagnostics.length) {
	                    file.bindDiagnostics.push(ts.createDiagnosticForNode(node, getStrictModeIdentifierMessage(node), ts.declarationNameToString(node)));
	                }
	            }
	        }
	        function getStrictModeIdentifierMessage(node) {
	            // Provide specialized messages to help the user understand why we think they're in
	            // strict mode.
	            if (ts.getContainingClass(node)) {
	                return ts.Diagnostics.Identifier_expected_0_is_a_reserved_word_in_strict_mode_Class_definitions_are_automatically_in_strict_mode;
	            }
	            if (file.externalModuleIndicator) {
	                return ts.Diagnostics.Identifier_expected_0_is_a_reserved_word_in_strict_mode_Modules_are_automatically_in_strict_mode;
	            }
	            return ts.Diagnostics.Identifier_expected_0_is_a_reserved_word_in_strict_mode;
	        }
	        function checkStrictModeBinaryExpression(node) {
	            if (inStrictMode && ts.isLeftHandSideExpression(node.left) && ts.isAssignmentOperator(node.operatorToken.kind)) {
	                // ECMA 262 (Annex C) The identifier eval or arguments may not appear as the LeftHandSideExpression of an
	                // Assignment operator(11.13) or of a PostfixExpression(11.3)
	                checkStrictModeEvalOrArguments(node, node.left);
	            }
	        }
	        function checkStrictModeCatchClause(node) {
	            // It is a SyntaxError if a TryStatement with a Catch occurs within strict code and the Identifier of the
	            // Catch production is eval or arguments
	            if (inStrictMode && node.variableDeclaration) {
	                checkStrictModeEvalOrArguments(node, node.variableDeclaration.name);
	            }
	        }
	        function checkStrictModeDeleteExpression(node) {
	            // Grammar checking
	            if (inStrictMode && node.expression.kind === 69 /* Identifier */) {
	                // When a delete operator occurs within strict mode code, a SyntaxError is thrown if its
	                // UnaryExpression is a direct reference to a variable, function argument, or function name
	                var span = ts.getErrorSpanForNode(file, node.expression);
	                file.bindDiagnostics.push(ts.createFileDiagnostic(file, span.start, span.length, ts.Diagnostics.delete_cannot_be_called_on_an_identifier_in_strict_mode));
	            }
	        }
	        function isEvalOrArgumentsIdentifier(node) {
	            return node.kind === 69 /* Identifier */ &&
	                (node.text === "eval" || node.text === "arguments");
	        }
	        function checkStrictModeEvalOrArguments(contextNode, name) {
	            if (name && name.kind === 69 /* Identifier */) {
	                var identifier = name;
	                if (isEvalOrArgumentsIdentifier(identifier)) {
	                    // We check first if the name is inside class declaration or class expression; if so give explicit message
	                    // otherwise report generic error message.
	                    var span = ts.getErrorSpanForNode(file, name);
	                    file.bindDiagnostics.push(ts.createFileDiagnostic(file, span.start, span.length, getStrictModeEvalOrArgumentsMessage(contextNode), identifier.text));
	                }
	            }
	        }
	        function getStrictModeEvalOrArgumentsMessage(node) {
	            // Provide specialized messages to help the user understand why we think they're in
	            // strict mode.
	            if (ts.getContainingClass(node)) {
	                return ts.Diagnostics.Invalid_use_of_0_Class_definitions_are_automatically_in_strict_mode;
	            }
	            if (file.externalModuleIndicator) {
	                return ts.Diagnostics.Invalid_use_of_0_Modules_are_automatically_in_strict_mode;
	            }
	            return ts.Diagnostics.Invalid_use_of_0_in_strict_mode;
	        }
	        function checkStrictModeFunctionName(node) {
	            if (inStrictMode) {
	                // It is a SyntaxError if the identifier eval or arguments appears within a FormalParameterList of a strict mode FunctionDeclaration or FunctionExpression (13.1))
	                checkStrictModeEvalOrArguments(node, node.name);
	            }
	        }
	        function checkStrictModeNumericLiteral(node) {
	            if (inStrictMode && node.flags & 32768 /* OctalLiteral */) {
	                file.bindDiagnostics.push(ts.createDiagnosticForNode(node, ts.Diagnostics.Octal_literals_are_not_allowed_in_strict_mode));
	            }
	        }
	        function checkStrictModePostfixUnaryExpression(node) {
	            // Grammar checking
	            // The identifier eval or arguments may not appear as the LeftHandSideExpression of an
	            // Assignment operator(11.13) or of a PostfixExpression(11.3) or as the UnaryExpression
	            // operated upon by a Prefix Increment(11.4.4) or a Prefix Decrement(11.4.5) operator.
	            if (inStrictMode) {
	                checkStrictModeEvalOrArguments(node, node.operand);
	            }
	        }
	        function checkStrictModePrefixUnaryExpression(node) {
	            // Grammar checking
	            if (inStrictMode) {
	                if (node.operator === 41 /* PlusPlusToken */ || node.operator === 42 /* MinusMinusToken */) {
	                    checkStrictModeEvalOrArguments(node, node.operand);
	                }
	            }
	        }
	        function checkStrictModeWithStatement(node) {
	            // Grammar checking for withStatement
	            if (inStrictMode) {
	                errorOnFirstToken(node, ts.Diagnostics.with_statements_are_not_allowed_in_strict_mode);
	            }
	        }
	        function errorOnFirstToken(node, message, arg0, arg1, arg2) {
	            var span = ts.getSpanOfTokenAtPosition(file, node.pos);
	            file.bindDiagnostics.push(ts.createFileDiagnostic(file, span.start, span.length, message, arg0, arg1, arg2));
	        }
	        function getDestructuringParameterName(node) {
	            return "__" + ts.indexOf(node.parent.parameters, node);
	        }
	        function bind(node) {
	            if (!node) {
	                return;
	            }
	            node.parent = parent;
	            var savedInStrictMode = inStrictMode;
	            if (!savedInStrictMode) {
	                updateStrictMode(node);
	            }
	            // First we bind declaration nodes to a symbol if possible.  We'll both create a symbol
	            // and then potentially add the symbol to an appropriate symbol table. Possible
	            // destination symbol tables are:
	            //
	            //  1) The 'exports' table of the current container's symbol.
	            //  2) The 'members' table of the current container's symbol.
	            //  3) The 'locals' table of the current container.
	            //
	            // However, not all symbols will end up in any of these tables.  'Anonymous' symbols
	            // (like TypeLiterals for example) will not be put in any table.
	            bindWorker(node);
	            // Then we recurse into the children of the node to bind them as well.  For certain
	            // symbols we do specialized work when we recurse.  For example, we'll keep track of
	            // the current 'container' node when it changes.  This helps us know which symbol table
	            // a local should go into for example.
	            bindChildren(node);
	            inStrictMode = savedInStrictMode;
	        }
	        function updateStrictMode(node) {
	            switch (node.kind) {
	                case 251 /* SourceFile */:
	                case 222 /* ModuleBlock */:
	                    updateStrictModeStatementList(node.statements);
	                    return;
	                case 195 /* Block */:
	                    if (ts.isFunctionLike(node.parent)) {
	                        updateStrictModeStatementList(node.statements);
	                    }
	                    return;
	                case 217 /* ClassDeclaration */:
	                case 189 /* ClassExpression */:
	                    // All classes are automatically in strict mode in ES6.
	                    inStrictMode = true;
	                    return;
	            }
	        }
	        function updateStrictModeStatementList(statements) {
	            for (var _i = 0, statements_1 = statements; _i < statements_1.length; _i++) {
	                var statement = statements_1[_i];
	                if (!ts.isPrologueDirective(statement)) {
	                    return;
	                }
	                if (isUseStrictPrologueDirective(statement)) {
	                    inStrictMode = true;
	                    return;
	                }
	            }
	        }
	        /// Should be called only on prologue directives (isPrologueDirective(node) should be true)
	        function isUseStrictPrologueDirective(node) {
	            var nodeText = ts.getTextOfNodeFromSourceText(file.text, node.expression);
	            // Note: the node text must be exactly "use strict" or 'use strict'.  It is not ok for the
	            // string to contain unicode escapes (as per ES5).
	            return nodeText === "\"use strict\"" || nodeText === "'use strict'";
	        }
	        function bindWorker(node) {
	            switch (node.kind) {
	                /* Strict mode checks */
	                case 69 /* Identifier */:
	                    return checkStrictModeIdentifier(node);
	                case 184 /* BinaryExpression */:
	                    if (ts.isInJavaScriptFile(node)) {
	                        var specialKind = ts.getSpecialPropertyAssignmentKind(node);
	                        switch (specialKind) {
	                            case 1 /* ExportsProperty */:
	                                bindExportsPropertyAssignment(node);
	                                break;
	                            case 2 /* ModuleExports */:
	                                bindModuleExportsAssignment(node);
	                                break;
	                            case 3 /* PrototypeProperty */:
	                                bindPrototypePropertyAssignment(node);
	                                break;
	                            case 4 /* ThisProperty */:
	                                bindThisPropertyAssignment(node);
	                                break;
	                            case 0 /* None */:
	                                // Nothing to do
	                                break;
	                            default:
	                                ts.Debug.fail("Unknown special property assignment kind");
	                        }
	                    }
	                    return checkStrictModeBinaryExpression(node);
	                case 247 /* CatchClause */:
	                    return checkStrictModeCatchClause(node);
	                case 178 /* DeleteExpression */:
	                    return checkStrictModeDeleteExpression(node);
	                case 8 /* NumericLiteral */:
	                    return checkStrictModeNumericLiteral(node);
	                case 183 /* PostfixUnaryExpression */:
	                    return checkStrictModePostfixUnaryExpression(node);
	                case 182 /* PrefixUnaryExpression */:
	                    return checkStrictModePrefixUnaryExpression(node);
	                case 208 /* WithStatement */:
	                    return checkStrictModeWithStatement(node);
	                case 162 /* ThisType */:
	                    seenThisKeyword = true;
	                    return;
	                case 151 /* TypePredicate */:
	                    return checkTypePredicate(node);
	                case 138 /* TypeParameter */:
	                    return declareSymbolAndAddToSymbolTable(node, 262144 /* TypeParameter */, 530912 /* TypeParameterExcludes */);
	                case 139 /* Parameter */:
	                    return bindParameter(node);
	                case 214 /* VariableDeclaration */:
	                case 166 /* BindingElement */:
	                    return bindVariableDeclarationOrBindingElement(node);
	                case 142 /* PropertyDeclaration */:
	                case 141 /* PropertySignature */:
	                case 261 /* JSDocRecordMember */:
	                    return bindPropertyOrMethodOrAccessor(node, 4 /* Property */ | (node.questionToken ? 536870912 /* Optional */ : 0 /* None */), 107455 /* PropertyExcludes */);
	                case 248 /* PropertyAssignment */:
	                case 249 /* ShorthandPropertyAssignment */:
	                    return bindPropertyOrMethodOrAccessor(node, 4 /* Property */, 107455 /* PropertyExcludes */);
	                case 250 /* EnumMember */:
	                    return bindPropertyOrMethodOrAccessor(node, 8 /* EnumMember */, 107455 /* EnumMemberExcludes */);
	                case 148 /* CallSignature */:
	                case 149 /* ConstructSignature */:
	                case 150 /* IndexSignature */:
	                    return declareSymbolAndAddToSymbolTable(node, 131072 /* Signature */, 0 /* None */);
	                case 144 /* MethodDeclaration */:
	                case 143 /* MethodSignature */:
	                    // If this is an ObjectLiteralExpression method, then it sits in the same space
	                    // as other properties in the object literal.  So we use SymbolFlags.PropertyExcludes
	                    // so that it will conflict with any other object literal members with the same
	                    // name.
	                    return bindPropertyOrMethodOrAccessor(node, 8192 /* Method */ | (node.questionToken ? 536870912 /* Optional */ : 0 /* None */), ts.isObjectLiteralMethod(node) ? 107455 /* PropertyExcludes */ : 99263 /* MethodExcludes */);
	                case 216 /* FunctionDeclaration */:
	                    return bindFunctionDeclaration(node);
	                case 145 /* Constructor */:
	                    return declareSymbolAndAddToSymbolTable(node, 16384 /* Constructor */, /*symbolExcludes:*/ 0 /* None */);
	                case 146 /* GetAccessor */:
	                    return bindPropertyOrMethodOrAccessor(node, 32768 /* GetAccessor */, 41919 /* GetAccessorExcludes */);
	                case 147 /* SetAccessor */:
	                    return bindPropertyOrMethodOrAccessor(node, 65536 /* SetAccessor */, 74687 /* SetAccessorExcludes */);
	                case 153 /* FunctionType */:
	                case 154 /* ConstructorType */:
	                case 264 /* JSDocFunctionType */:
	                    return bindFunctionOrConstructorType(node);
	                case 156 /* TypeLiteral */:
	                case 260 /* JSDocRecordType */:
	                    return bindAnonymousDeclaration(node, 2048 /* TypeLiteral */, "__type");
	                case 168 /* ObjectLiteralExpression */:
	                    return bindObjectLiteralExpression(node);
	                case 176 /* FunctionExpression */:
	                case 177 /* ArrowFunction */:
	                    return bindFunctionExpression(node);
	                case 171 /* CallExpression */:
	                    if (ts.isInJavaScriptFile(node)) {
	                        bindCallExpression(node);
	                    }
	                    break;
	                // Members of classes, interfaces, and modules
	                case 189 /* ClassExpression */:
	                case 217 /* ClassDeclaration */:
	                    return bindClassLikeDeclaration(node);
	                case 218 /* InterfaceDeclaration */:
	                    return bindBlockScopedDeclaration(node, 64 /* Interface */, 792960 /* InterfaceExcludes */);
	                case 219 /* TypeAliasDeclaration */:
	                    return bindBlockScopedDeclaration(node, 524288 /* TypeAlias */, 793056 /* TypeAliasExcludes */);
	                case 220 /* EnumDeclaration */:
	                    return bindEnumDeclaration(node);
	                case 221 /* ModuleDeclaration */:
	                    return bindModuleDeclaration(node);
	                // Imports and exports
	                case 224 /* ImportEqualsDeclaration */:
	                case 227 /* NamespaceImport */:
	                case 229 /* ImportSpecifier */:
	                case 233 /* ExportSpecifier */:
	                    return declareSymbolAndAddToSymbolTable(node, 8388608 /* Alias */, 8388608 /* AliasExcludes */);
	                case 226 /* ImportClause */:
	                    return bindImportClause(node);
	                case 231 /* ExportDeclaration */:
	                    return bindExportDeclaration(node);
	                case 230 /* ExportAssignment */:
	                    return bindExportAssignment(node);
	                case 251 /* SourceFile */:
	                    return bindSourceFileIfExternalModule();
	            }
	        }
	        function checkTypePredicate(node) {
	            var parameterName = node.parameterName, type = node.type;
	            if (parameterName && parameterName.kind === 69 /* Identifier */) {
	                checkStrictModeIdentifier(parameterName);
	            }
	            if (parameterName && parameterName.kind === 162 /* ThisType */) {
	                seenThisKeyword = true;
	            }
	            bind(type);
	        }
	        function bindSourceFileIfExternalModule() {
	            setExportContextFlag(file);
	            if (ts.isExternalModule(file)) {
	                bindSourceFileAsExternalModule();
	            }
	        }
	        function bindSourceFileAsExternalModule() {
	            bindAnonymousDeclaration(file, 512 /* ValueModule */, "\"" + ts.removeFileExtension(file.fileName) + "\"");
	        }
	        function bindExportAssignment(node) {
	            var boundExpression = node.kind === 230 /* ExportAssignment */ ? node.expression : node.right;
	            if (!container.symbol || !container.symbol.exports) {
	                // Export assignment in some sort of block construct
	                bindAnonymousDeclaration(node, 8388608 /* Alias */, getDeclarationName(node));
	            }
	            else if (boundExpression.kind === 69 /* Identifier */ && node.kind === 230 /* ExportAssignment */) {
	                // An export default clause with an identifier exports all meanings of that identifier
	                declareSymbol(container.symbol.exports, container.symbol, node, 8388608 /* Alias */, 107455 /* PropertyExcludes */ | 8388608 /* AliasExcludes */);
	            }
	            else {
	                // An export default clause with an expression exports a value
	                declareSymbol(container.symbol.exports, container.symbol, node, 4 /* Property */, 107455 /* PropertyExcludes */ | 8388608 /* AliasExcludes */);
	            }
	        }
	        function bindExportDeclaration(node) {
	            if (!container.symbol || !container.symbol.exports) {
	                // Export * in some sort of block construct
	                bindAnonymousDeclaration(node, 1073741824 /* ExportStar */, getDeclarationName(node));
	            }
	            else if (!node.exportClause) {
	                // All export * declarations are collected in an __export symbol
	                declareSymbol(container.symbol.exports, container.symbol, node, 1073741824 /* ExportStar */, 0 /* None */);
	            }
	        }
	        function bindImportClause(node) {
	            if (node.name) {
	                declareSymbolAndAddToSymbolTable(node, 8388608 /* Alias */, 8388608 /* AliasExcludes */);
	            }
	        }
	        function setCommonJsModuleIndicator(node) {
	            if (!file.commonJsModuleIndicator) {
	                file.commonJsModuleIndicator = node;
	                bindSourceFileAsExternalModule();
	            }
	        }
	        function bindExportsPropertyAssignment(node) {
	            // When we create a property via 'exports.foo = bar', the 'exports.foo' property access
	            // expression is the declaration
	            setCommonJsModuleIndicator(node);
	            declareSymbol(file.symbol.exports, file.symbol, node.left, 4 /* Property */ | 7340032 /* Export */, 0 /* None */);
	        }
	        function bindModuleExportsAssignment(node) {
	            // 'module.exports = expr' assignment
	            setCommonJsModuleIndicator(node);
	            bindExportAssignment(node);
	        }
	        function bindThisPropertyAssignment(node) {
	            // Declare a 'member' in case it turns out the container was an ES5 class
	            if (container.kind === 176 /* FunctionExpression */ || container.kind === 216 /* FunctionDeclaration */) {
	                container.symbol.members = container.symbol.members || {};
	                // It's acceptable for multiple 'this' assignments of the same identifier to occur
	                declareSymbol(container.symbol.members, container.symbol, node, 4 /* Property */, 107455 /* PropertyExcludes */ & ~4 /* Property */);
	            }
	        }
	        function bindPrototypePropertyAssignment(node) {
	            // We saw a node of the form 'x.prototype.y = z'. Declare a 'member' y on x if x was a function.
	            // Look up the function in the local scope, since prototype assignments should
	            // follow the function declaration
	            var leftSideOfAssignment = node.left;
	            var classPrototype = leftSideOfAssignment.expression;
	            var constructorFunction = classPrototype.expression;
	            // Fix up parent pointers since we're going to use these nodes before we bind into them
	            leftSideOfAssignment.parent = node;
	            constructorFunction.parent = classPrototype;
	            classPrototype.parent = leftSideOfAssignment;
	            var funcSymbol = container.locals[constructorFunction.text];
	            if (!funcSymbol || !(funcSymbol.flags & 16 /* Function */)) {
	                return;
	            }
	            // Set up the members collection if it doesn't exist already
	            if (!funcSymbol.members) {
	                funcSymbol.members = {};
	            }
	            // Declare the method/property
	            declareSymbol(funcSymbol.members, funcSymbol, leftSideOfAssignment, 4 /* Property */, 107455 /* PropertyExcludes */);
	        }
	        function bindCallExpression(node) {
	            // We're only inspecting call expressions to detect CommonJS modules, so we can skip
	            // this check if we've already seen the module indicator
	            if (!file.commonJsModuleIndicator && ts.isRequireCall(node, /*checkArgumentIsStringLiteral*/ false)) {
	                setCommonJsModuleIndicator(node);
	            }
	        }
	        function bindClassLikeDeclaration(node) {
	            if (!ts.isDeclarationFile(file) && !ts.isInAmbientContext(node)) {
	                if (ts.getClassExtendsHeritageClauseElement(node) !== undefined) {
	                    hasClassExtends = true;
	                }
	                if (ts.nodeIsDecorated(node)) {
	                    hasDecorators = true;
	                }
	            }
	            if (node.kind === 217 /* ClassDeclaration */) {
	                bindBlockScopedDeclaration(node, 32 /* Class */, 899519 /* ClassExcludes */);
	            }
	            else {
	                var bindingName = node.name ? node.name.text : "__class";
	                bindAnonymousDeclaration(node, 32 /* Class */, bindingName);
	                // Add name of class expression into the map for semantic classifier
	                if (node.name) {
	                    classifiableNames[node.name.text] = node.name.text;
	                }
	            }
	            var symbol = node.symbol;
	            // TypeScript 1.0 spec (April 2014): 8.4
	            // Every class automatically contains a static property member named 'prototype', the
	            // type of which is an instantiation of the class type with type Any supplied as a type
	            // argument for each type parameter. It is an error to explicitly declare a static
	            // property member with the name 'prototype'.
	            //
	            // Note: we check for this here because this class may be merging into a module.  The
	            // module might have an exported variable called 'prototype'.  We can't allow that as
	            // that would clash with the built-in 'prototype' for the class.
	            var prototypeSymbol = createSymbol(4 /* Property */ | 134217728 /* Prototype */, "prototype");
	            if (ts.hasProperty(symbol.exports, prototypeSymbol.name)) {
	                if (node.name) {
	                    node.name.parent = node;
	                }
	                file.bindDiagnostics.push(ts.createDiagnosticForNode(symbol.exports[prototypeSymbol.name].declarations[0], ts.Diagnostics.Duplicate_identifier_0, prototypeSymbol.name));
	            }
	            symbol.exports[prototypeSymbol.name] = prototypeSymbol;
	            prototypeSymbol.parent = symbol;
	        }
	        function bindEnumDeclaration(node) {
	            return ts.isConst(node)
	                ? bindBlockScopedDeclaration(node, 128 /* ConstEnum */, 899967 /* ConstEnumExcludes */)
	                : bindBlockScopedDeclaration(node, 256 /* RegularEnum */, 899327 /* RegularEnumExcludes */);
	        }
	        function bindVariableDeclarationOrBindingElement(node) {
	            if (inStrictMode) {
	                checkStrictModeEvalOrArguments(node, node.name);
	            }
	            if (!ts.isBindingPattern(node.name)) {
	                if (ts.isBlockOrCatchScoped(node)) {
	                    bindBlockScopedVariableDeclaration(node);
	                }
	                else if (ts.isParameterDeclaration(node)) {
	                    // It is safe to walk up parent chain to find whether the node is a destructing parameter declaration
	                    // because its parent chain has already been set up, since parents are set before descending into children.
	                    //
	                    // If node is a binding element in parameter declaration, we need to use ParameterExcludes.
	                    // Using ParameterExcludes flag allows the compiler to report an error on duplicate identifiers in Parameter Declaration
	                    // For example:
	                    //      function foo([a,a]) {} // Duplicate Identifier error
	                    //      function bar(a,a) {}   // Duplicate Identifier error, parameter declaration in this case is handled in bindParameter
	                    //                             // which correctly set excluded symbols
	                    declareSymbolAndAddToSymbolTable(node, 1 /* FunctionScopedVariable */, 107455 /* ParameterExcludes */);
	                }
	                else {
	                    declareSymbolAndAddToSymbolTable(node, 1 /* FunctionScopedVariable */, 107454 /* FunctionScopedVariableExcludes */);
	                }
	            }
	        }
	        function bindParameter(node) {
	            if (!ts.isDeclarationFile(file) &&
	                !ts.isInAmbientContext(node) &&
	                ts.nodeIsDecorated(node)) {
	                hasDecorators = true;
	                hasParameterDecorators = true;
	            }
	            if (inStrictMode) {
	                // It is a SyntaxError if the identifier eval or arguments appears within a FormalParameterList of a
	                // strict mode FunctionLikeDeclaration or FunctionExpression(13.1)
	                checkStrictModeEvalOrArguments(node, node.name);
	            }
	            if (ts.isBindingPattern(node.name)) {
	                bindAnonymousDeclaration(node, 1 /* FunctionScopedVariable */, getDestructuringParameterName(node));
	            }
	            else {
	                declareSymbolAndAddToSymbolTable(node, 1 /* FunctionScopedVariable */, 107455 /* ParameterExcludes */);
	            }
	            // If this is a property-parameter, then also declare the property symbol into the
	            // containing class.
	            if (ts.isParameterPropertyDeclaration(node)) {
	                var classDeclaration = node.parent.parent;
	                declareSymbol(classDeclaration.symbol.members, classDeclaration.symbol, node, 4 /* Property */, 107455 /* PropertyExcludes */);
	            }
	        }
	        function bindFunctionDeclaration(node) {
	            if (!ts.isDeclarationFile(file) && !ts.isInAmbientContext(node)) {
	                if (ts.isAsyncFunctionLike(node)) {
	                    hasAsyncFunctions = true;
	                }
	            }
	            checkStrictModeFunctionName(node);
	            return declareSymbolAndAddToSymbolTable(node, 16 /* Function */, 106927 /* FunctionExcludes */);
	        }
	        function bindFunctionExpression(node) {
	            if (!ts.isDeclarationFile(file) && !ts.isInAmbientContext(node)) {
	                if (ts.isAsyncFunctionLike(node)) {
	                    hasAsyncFunctions = true;
	                }
	            }
	            checkStrictModeFunctionName(node);
	            var bindingName = node.name ? node.name.text : "__function";
	            return bindAnonymousDeclaration(node, 16 /* Function */, bindingName);
	        }
	        function bindPropertyOrMethodOrAccessor(node, symbolFlags, symbolExcludes) {
	            if (!ts.isDeclarationFile(file) && !ts.isInAmbientContext(node)) {
	                if (ts.isAsyncFunctionLike(node)) {
	                    hasAsyncFunctions = true;
	                }
	                if (ts.nodeIsDecorated(node)) {
	                    hasDecorators = true;
	                }
	            }
	            return ts.hasDynamicName(node)
	                ? bindAnonymousDeclaration(node, symbolFlags, "__computed")
	                : declareSymbolAndAddToSymbolTable(node, symbolFlags, symbolExcludes);
	        }
	        // reachability checks
	        function pushNamedLabel(name) {
	            initializeReachabilityStateIfNecessary();
	            if (ts.hasProperty(labelIndexMap, name.text)) {
	                return false;
	            }
	            labelIndexMap[name.text] = labelStack.push(1 /* Unintialized */) - 1;
	            return true;
	        }
	        function pushImplicitLabel() {
	            initializeReachabilityStateIfNecessary();
	            var index = labelStack.push(1 /* Unintialized */) - 1;
	            implicitLabels.push(index);
	            return index;
	        }
	        function popNamedLabel(label, outerState) {
	            var index = labelIndexMap[label.text];
	            ts.Debug.assert(index !== undefined);
	            ts.Debug.assert(labelStack.length == index + 1);
	            labelIndexMap[label.text] = undefined;
	            setCurrentStateAtLabel(labelStack.pop(), outerState, label);
	        }
	        function popImplicitLabel(implicitLabelIndex, outerState) {
	            if (labelStack.length !== implicitLabelIndex + 1) {
	                ts.Debug.assert(false, "Label stack: " + labelStack.length + ", index:" + implicitLabelIndex);
	            }
	            var i = implicitLabels.pop();
	            if (implicitLabelIndex !== i) {
	                ts.Debug.assert(false, "i: " + i + ", index: " + implicitLabelIndex);
	            }
	            setCurrentStateAtLabel(labelStack.pop(), outerState, /*name*/ undefined);
	        }
	        function setCurrentStateAtLabel(innerMergedState, outerState, label) {
	            if (innerMergedState === 1 /* Unintialized */) {
	                if (label && !options.allowUnusedLabels) {
	                    file.bindDiagnostics.push(ts.createDiagnosticForNode(label, ts.Diagnostics.Unused_label));
	                }
	                currentReachabilityState = outerState;
	            }
	            else {
	                currentReachabilityState = or(innerMergedState, outerState);
	            }
	        }
	        function jumpToLabel(label, outerState) {
	            initializeReachabilityStateIfNecessary();
	            var index = label ? labelIndexMap[label.text] : ts.lastOrUndefined(implicitLabels);
	            if (index === undefined) {
	                // reference to unknown label or
	                // break/continue used outside of loops
	                return false;
	            }
	            var stateAtLabel = labelStack[index];
	            labelStack[index] = stateAtLabel === 1 /* Unintialized */ ? outerState : or(stateAtLabel, outerState);
	            return true;
	        }
	        function checkUnreachable(node) {
	            switch (currentReachabilityState) {
	                case 4 /* Unreachable */:
	                    var reportError = 
	                    // report error on all statements except empty ones
	                    (ts.isStatement(node) && node.kind !== 197 /* EmptyStatement */) ||
	                        // report error on class declarations
	                        node.kind === 217 /* ClassDeclaration */ ||
	                        // report error on instantiated modules or const-enums only modules if preserveConstEnums is set
	                        (node.kind === 221 /* ModuleDeclaration */ && shouldReportErrorOnModuleDeclaration(node)) ||
	                        // report error on regular enums and const enums if preserveConstEnums is set
	                        (node.kind === 220 /* EnumDeclaration */ && (!ts.isConstEnumDeclaration(node) || options.preserveConstEnums));
	                    if (reportError) {
	                        currentReachabilityState = 8 /* ReportedUnreachable */;
	                        // unreachable code is reported if
	                        // - user has explicitly asked about it AND
	                        // - statement is in not ambient context (statements in ambient context is already an error
	                        //   so we should not report extras) AND
	                        //   - node is not variable statement OR
	                        //   - node is block scoped variable statement OR
	                        //   - node is not block scoped variable statement and at least one variable declaration has initializer
	                        //   Rationale: we don't want to report errors on non-initialized var's since they are hoisted
	                        //   On the other side we do want to report errors on non-initialized 'lets' because of TDZ
	                        var reportUnreachableCode = !options.allowUnreachableCode &&
	                            !ts.isInAmbientContext(node) &&
	                            (node.kind !== 196 /* VariableStatement */ ||
	                                ts.getCombinedNodeFlags(node.declarationList) & 24576 /* BlockScoped */ ||
	                                ts.forEach(node.declarationList.declarations, function (d) { return d.initializer; }));
	                        if (reportUnreachableCode) {
	                            errorOnFirstToken(node, ts.Diagnostics.Unreachable_code_detected);
	                        }
	                    }
	                case 8 /* ReportedUnreachable */:
	                    return true;
	                default:
	                    return false;
	            }
	            function shouldReportErrorOnModuleDeclaration(node) {
	                var instanceState = getModuleInstanceState(node);
	                return instanceState === 1 /* Instantiated */ || (instanceState === 2 /* ConstEnumOnly */ && options.preserveConstEnums);
	            }
	        }
	        function initializeReachabilityStateIfNecessary() {
	            if (labelIndexMap) {
	                return;
	            }
	            currentReachabilityState = 2 /* Reachable */;
	            labelIndexMap = {};
	            labelStack = [];
	            implicitLabels = [];
	        }
	    }
	})(ts || (ts = {}));
	/// <reference path="binder.ts"/>
	/* @internal */
	var ts;
	(function (ts) {
	    var nextSymbolId = 1;
	    var nextNodeId = 1;
	    var nextMergeId = 1;
	    function getNodeId(node) {
	        if (!node.id) {
	            node.id = nextNodeId;
	            nextNodeId++;
	        }
	        return node.id;
	    }
	    ts.getNodeId = getNodeId;
	    ts.checkTime = 0;
	    function getSymbolId(symbol) {
	        if (!symbol.id) {
	            symbol.id = nextSymbolId;
	            nextSymbolId++;
	        }
	        return symbol.id;
	    }
	    ts.getSymbolId = getSymbolId;
	    function createTypeChecker(host, produceDiagnostics) {
	        // Cancellation that controls whether or not we can cancel in the middle of type checking.
	        // In general cancelling is *not* safe for the type checker.  We might be in the middle of
	        // computing something, and we will leave our internals in an inconsistent state.  Callers
	        // who set the cancellation token should catch if a cancellation exception occurs, and
	        // should throw away and create a new TypeChecker.
	        //
	        // Currently we only support setting the cancellation token when getting diagnostics.  This
	        // is because diagnostics can be quite expensive, and we want to allow hosts to bail out if
	        // they no longer need the information (for example, if the user started editing again).
	        var cancellationToken;
	        var Symbol = ts.objectAllocator.getSymbolConstructor();
	        var Type = ts.objectAllocator.getTypeConstructor();
	        var Signature = ts.objectAllocator.getSignatureConstructor();
	        var typeCount = 0;
	        var symbolCount = 0;
	        var emptyArray = [];
	        var emptySymbols = {};
	        var compilerOptions = host.getCompilerOptions();
	        var languageVersion = compilerOptions.target || 0 /* ES3 */;
	        var modulekind = ts.getEmitModuleKind(compilerOptions);
	        var allowSyntheticDefaultImports = typeof compilerOptions.allowSyntheticDefaultImports !== "undefined" ? compilerOptions.allowSyntheticDefaultImports : modulekind === 4 /* System */;
	        var emitResolver = createResolver();
	        var undefinedSymbol = createSymbol(4 /* Property */ | 67108864 /* Transient */, "undefined");
	        undefinedSymbol.declarations = [];
	        var argumentsSymbol = createSymbol(4 /* Property */ | 67108864 /* Transient */, "arguments");
	        var checker = {
	            getNodeCount: function () { return ts.sum(host.getSourceFiles(), "nodeCount"); },
	            getIdentifierCount: function () { return ts.sum(host.getSourceFiles(), "identifierCount"); },
	            getSymbolCount: function () { return ts.sum(host.getSourceFiles(), "symbolCount") + symbolCount; },
	            getTypeCount: function () { return typeCount; },
	            isUndefinedSymbol: function (symbol) { return symbol === undefinedSymbol; },
	            isArgumentsSymbol: function (symbol) { return symbol === argumentsSymbol; },
	            isUnknownSymbol: function (symbol) { return symbol === unknownSymbol; },
	            getDiagnostics: getDiagnostics,
	            getGlobalDiagnostics: getGlobalDiagnostics,
	            // The language service will always care about the narrowed type of a symbol, because that is
	            // the type the language says the symbol should have.
	            getTypeOfSymbolAtLocation: getNarrowedTypeOfSymbol,
	            getSymbolsOfParameterPropertyDeclaration: getSymbolsOfParameterPropertyDeclaration,
	            getDeclaredTypeOfSymbol: getDeclaredTypeOfSymbol,
	            getPropertiesOfType: getPropertiesOfType,
	            getPropertyOfType: getPropertyOfType,
	            getSignaturesOfType: getSignaturesOfType,
	            getIndexTypeOfType: getIndexTypeOfType,
	            getBaseTypes: getBaseTypes,
	            getReturnTypeOfSignature: getReturnTypeOfSignature,
	            getSymbolsInScope: getSymbolsInScope,
	            getSymbolAtLocation: getSymbolAtLocation,
	            getShorthandAssignmentValueSymbol: getShorthandAssignmentValueSymbol,
	            getExportSpecifierLocalTargetSymbol: getExportSpecifierLocalTargetSymbol,
	            getTypeAtLocation: getTypeOfNode,
	            typeToString: typeToString,
	            getSymbolDisplayBuilder: getSymbolDisplayBuilder,
	            symbolToString: symbolToString,
	            getAugmentedPropertiesOfType: getAugmentedPropertiesOfType,
	            getRootSymbols: getRootSymbols,
	            getContextualType: getContextualType,
	            getFullyQualifiedName: getFullyQualifiedName,
	            getResolvedSignature: getResolvedSignature,
	            getConstantValue: getConstantValue,
	            isValidPropertyAccess: isValidPropertyAccess,
	            getSignatureFromDeclaration: getSignatureFromDeclaration,
	            isImplementationOfOverload: isImplementationOfOverload,
	            getAliasedSymbol: resolveAlias,
	            getEmitResolver: getEmitResolver,
	            getExportsOfModule: getExportsOfModuleAsArray,
	            getJsxElementAttributesType: getJsxElementAttributesType,
	            getJsxIntrinsicTagNames: getJsxIntrinsicTagNames,
	            isOptionalParameter: isOptionalParameter
	        };
	        var unknownSymbol = createSymbol(4 /* Property */ | 67108864 /* Transient */, "unknown");
	        var resolvingSymbol = createSymbol(67108864 /* Transient */, "__resolving__");
	        var anyType = createIntrinsicType(1 /* Any */, "any");
	        var stringType = createIntrinsicType(2 /* String */, "string");
	        var numberType = createIntrinsicType(4 /* Number */, "number");
	        var booleanType = createIntrinsicType(8 /* Boolean */, "boolean");
	        var esSymbolType = createIntrinsicType(16777216 /* ESSymbol */, "symbol");
	        var voidType = createIntrinsicType(16 /* Void */, "void");
	        var undefinedType = createIntrinsicType(32 /* Undefined */ | 2097152 /* ContainsUndefinedOrNull */, "undefined");
	        var nullType = createIntrinsicType(64 /* Null */ | 2097152 /* ContainsUndefinedOrNull */, "null");
	        var unknownType = createIntrinsicType(1 /* Any */, "unknown");
	        var emptyObjectType = createAnonymousType(undefined, emptySymbols, emptyArray, emptyArray, undefined, undefined);
	        var emptyUnionType = emptyObjectType;
	        var emptyGenericType = createAnonymousType(undefined, emptySymbols, emptyArray, emptyArray, undefined, undefined);
	        emptyGenericType.instantiations = {};
	        var anyFunctionType = createAnonymousType(undefined, emptySymbols, emptyArray, emptyArray, undefined, undefined);
	        // The anyFunctionType contains the anyFunctionType by definition. The flag is further propagated
	        // in getPropagatingFlagsOfTypes, and it is checked in inferFromTypes.
	        anyFunctionType.flags |= 8388608 /* ContainsAnyFunctionType */;
	        var noConstraintType = createAnonymousType(undefined, emptySymbols, emptyArray, emptyArray, undefined, undefined);
	        var anySignature = createSignature(undefined, undefined, emptyArray, anyType, /*typePredicate*/ undefined, 0, /*hasRestParameter*/ false, /*hasStringLiterals*/ false);
	        var unknownSignature = createSignature(undefined, undefined, emptyArray, unknownType, /*typePredicate*/ undefined, 0, /*hasRestParameter*/ false, /*hasStringLiterals*/ false);
	        var globals = {};
	        var globalESSymbolConstructorSymbol;
	        var getGlobalPromiseConstructorSymbol;
	        var globalObjectType;
	        var globalFunctionType;
	        var globalArrayType;
	        var globalStringType;
	        var globalNumberType;
	        var globalBooleanType;
	        var globalRegExpType;
	        var globalTemplateStringsArrayType;
	        var globalESSymbolType;
	        var globalIterableType;
	        var globalIteratorType;
	        var globalIterableIteratorType;
	        var anyArrayType;
	        var getGlobalClassDecoratorType;
	        var getGlobalParameterDecoratorType;
	        var getGlobalPropertyDecoratorType;
	        var getGlobalMethodDecoratorType;
	        var getGlobalTypedPropertyDescriptorType;
	        var getGlobalPromiseType;
	        var tryGetGlobalPromiseType;
	        var getGlobalPromiseLikeType;
	        var getInstantiatedGlobalPromiseLikeType;
	        var getGlobalPromiseConstructorLikeType;
	        var getGlobalThenableType;
	        var jsxElementClassType;
	        var deferredNodes;
	        var tupleTypes = {};
	        var unionTypes = {};
	        var intersectionTypes = {};
	        var stringLiteralTypes = {};
	        var resolutionTargets = [];
	        var resolutionResults = [];
	        var resolutionPropertyNames = [];
	        var mergedSymbols = [];
	        var symbolLinks = [];
	        var nodeLinks = [];
	        var potentialThisCollisions = [];
	        var awaitedTypeStack = [];
	        var diagnostics = ts.createDiagnosticCollection();
	        var primitiveTypeInfo = {
	            "string": {
	                type: stringType,
	                flags: 258 /* StringLike */
	            },
	            "number": {
	                type: numberType,
	                flags: 132 /* NumberLike */
	            },
	            "boolean": {
	                type: booleanType,
	                flags: 8 /* Boolean */
	            },
	            "symbol": {
	                type: esSymbolType,
	                flags: 16777216 /* ESSymbol */
	            },
	            "undefined": {
	                type: undefinedType,
	                flags: 2097152 /* ContainsUndefinedOrNull */
	            }
	        };
	        var jsxElementType;
	        /** Things we lazy load from the JSX namespace */
	        var jsxTypes = {};
	        var JsxNames = {
	            JSX: "JSX",
	            IntrinsicElements: "IntrinsicElements",
	            ElementClass: "ElementClass",
	            ElementAttributesPropertyNameContainer: "ElementAttributesProperty",
	            Element: "Element",
	            IntrinsicAttributes: "IntrinsicAttributes",
	            IntrinsicClassAttributes: "IntrinsicClassAttributes"
	        };
	        var subtypeRelation = {};
	        var assignableRelation = {};
	        var identityRelation = {};
	        // This is for caching the result of getSymbolDisplayBuilder. Do not access directly.
	        var _displayBuilder;
	        var TypeSystemPropertyName;
	        (function (TypeSystemPropertyName) {
	            TypeSystemPropertyName[TypeSystemPropertyName["Type"] = 0] = "Type";
	            TypeSystemPropertyName[TypeSystemPropertyName["ResolvedBaseConstructorType"] = 1] = "ResolvedBaseConstructorType";
	            TypeSystemPropertyName[TypeSystemPropertyName["DeclaredType"] = 2] = "DeclaredType";
	            TypeSystemPropertyName[TypeSystemPropertyName["ResolvedReturnType"] = 3] = "ResolvedReturnType";
	        })(TypeSystemPropertyName || (TypeSystemPropertyName = {}));
	        var builtinGlobals = (_a = {},
	            _a[undefinedSymbol.name] = undefinedSymbol,
	            _a
	        );
	        initializeTypeChecker();
	        return checker;
	        function getEmitResolver(sourceFile, cancellationToken) {
	            // Ensure we have all the type information in place for this file so that all the
	            // emitter questions of this resolver will return the right information.
	            getDiagnostics(sourceFile, cancellationToken);
	            return emitResolver;
	        }
	        function error(location, message, arg0, arg1, arg2) {
	            var diagnostic = location
	                ? ts.createDiagnosticForNode(location, message, arg0, arg1, arg2)
	                : ts.createCompilerDiagnostic(message, arg0, arg1, arg2);
	            diagnostics.add(diagnostic);
	        }
	        function createSymbol(flags, name) {
	            symbolCount++;
	            return new Symbol(flags, name);
	        }
	        function getExcludedSymbolFlags(flags) {
	            var result = 0;
	            if (flags & 2 /* BlockScopedVariable */)
	                result |= 107455 /* BlockScopedVariableExcludes */;
	            if (flags & 1 /* FunctionScopedVariable */)
	                result |= 107454 /* FunctionScopedVariableExcludes */;
	            if (flags & 4 /* Property */)
	                result |= 107455 /* PropertyExcludes */;
	            if (flags & 8 /* EnumMember */)
	                result |= 107455 /* EnumMemberExcludes */;
	            if (flags & 16 /* Function */)
	                result |= 106927 /* FunctionExcludes */;
	            if (flags & 32 /* Class */)
	                result |= 899519 /* ClassExcludes */;
	            if (flags & 64 /* Interface */)
	                result |= 792960 /* InterfaceExcludes */;
	            if (flags & 256 /* RegularEnum */)
	                result |= 899327 /* RegularEnumExcludes */;
	            if (flags & 128 /* ConstEnum */)
	                result |= 899967 /* ConstEnumExcludes */;
	            if (flags & 512 /* ValueModule */)
	                result |= 106639 /* ValueModuleExcludes */;
	            if (flags & 8192 /* Method */)
	                result |= 99263 /* MethodExcludes */;
	            if (flags & 32768 /* GetAccessor */)
	                result |= 41919 /* GetAccessorExcludes */;
	            if (flags & 65536 /* SetAccessor */)
	                result |= 74687 /* SetAccessorExcludes */;
	            if (flags & 262144 /* TypeParameter */)
	                result |= 530912 /* TypeParameterExcludes */;
	            if (flags & 524288 /* TypeAlias */)
	                result |= 793056 /* TypeAliasExcludes */;
	            if (flags & 8388608 /* Alias */)
	                result |= 8388608 /* AliasExcludes */;
	            return result;
	        }
	        function recordMergedSymbol(target, source) {
	            if (!source.mergeId) {
	                source.mergeId = nextMergeId;
	                nextMergeId++;
	            }
	            mergedSymbols[source.mergeId] = target;
	        }
	        function cloneSymbol(symbol) {
	            var result = createSymbol(symbol.flags | 33554432 /* Merged */, symbol.name);
	            result.declarations = symbol.declarations.slice(0);
	            result.parent = symbol.parent;
	            if (symbol.valueDeclaration)
	                result.valueDeclaration = symbol.valueDeclaration;
	            if (symbol.constEnumOnlyModule)
	                result.constEnumOnlyModule = true;
	            if (symbol.members)
	                result.members = cloneSymbolTable(symbol.members);
	            if (symbol.exports)
	                result.exports = cloneSymbolTable(symbol.exports);
	            recordMergedSymbol(result, symbol);
	            return result;
	        }
	        function mergeSymbol(target, source) {
	            if (!(target.flags & getExcludedSymbolFlags(source.flags))) {
	                if (source.flags & 512 /* ValueModule */ && target.flags & 512 /* ValueModule */ && target.constEnumOnlyModule && !source.constEnumOnlyModule) {
	                    // reset flag when merging instantiated module into value module that has only const enums
	                    target.constEnumOnlyModule = false;
	                }
	                target.flags |= source.flags;
	                if (source.valueDeclaration &&
	                    (!target.valueDeclaration ||
	                        (target.valueDeclaration.kind === 221 /* ModuleDeclaration */ && source.valueDeclaration.kind !== 221 /* ModuleDeclaration */))) {
	                    // other kinds of value declarations take precedence over modules
	                    target.valueDeclaration = source.valueDeclaration;
	                }
	                ts.forEach(source.declarations, function (node) {
	                    target.declarations.push(node);
	                });
	                if (source.members) {
	                    if (!target.members)
	                        target.members = {};
	                    mergeSymbolTable(target.members, source.members);
	                }
	                if (source.exports) {
	                    if (!target.exports)
	                        target.exports = {};
	                    mergeSymbolTable(target.exports, source.exports);
	                }
	                recordMergedSymbol(target, source);
	            }
	            else {
	                var message_2 = target.flags & 2 /* BlockScopedVariable */ || source.flags & 2 /* BlockScopedVariable */
	                    ? ts.Diagnostics.Cannot_redeclare_block_scoped_variable_0 : ts.Diagnostics.Duplicate_identifier_0;
	                ts.forEach(source.declarations, function (node) {
	                    error(node.name ? node.name : node, message_2, symbolToString(source));
	                });
	                ts.forEach(target.declarations, function (node) {
	                    error(node.name ? node.name : node, message_2, symbolToString(source));
	                });
	            }
	        }
	        function cloneSymbolTable(symbolTable) {
	            var result = {};
	            for (var id in symbolTable) {
	                if (ts.hasProperty(symbolTable, id)) {
	                    result[id] = symbolTable[id];
	                }
	            }
	            return result;
	        }
	        function mergeSymbolTable(target, source) {
	            for (var id in source) {
	                if (ts.hasProperty(source, id)) {
	                    if (!ts.hasProperty(target, id)) {
	                        target[id] = source[id];
	                    }
	                    else {
	                        var symbol = target[id];
	                        if (!(symbol.flags & 33554432 /* Merged */)) {
	                            target[id] = symbol = cloneSymbol(symbol);
	                        }
	                        mergeSymbol(symbol, source[id]);
	                    }
	                }
	            }
	        }
	        function mergeModuleAugmentation(moduleName) {
	            var moduleAugmentation = moduleName.parent;
	            if (moduleAugmentation.symbol.valueDeclaration !== moduleAugmentation) {
	                // this is a combined symbol for multiple augmentations within the same file.
	                // its symbol already has accumulated information for all declarations
	                // so we need to add it just once - do the work only for first declaration
	                ts.Debug.assert(moduleAugmentation.symbol.declarations.length > 1);
	                return;
	            }
	            if (ts.isGlobalScopeAugmentation(moduleAugmentation)) {
	                mergeSymbolTable(globals, moduleAugmentation.symbol.exports);
	            }
	            else {
	                // find a module that about to be augmented
	                var mainModule = resolveExternalModuleNameWorker(moduleName, moduleName, ts.Diagnostics.Invalid_module_name_in_augmentation_module_0_cannot_be_found);
	                if (!mainModule) {
	                    return;
	                }
	                // obtain item referenced by 'export='
	                mainModule = resolveExternalModuleSymbol(mainModule);
	                if (mainModule.flags & 1536 /* Namespace */) {
	                    // if module symbol has already been merged - it is safe to use it.
	                    // otherwise clone it
	                    mainModule = mainModule.flags & 33554432 /* Merged */ ? mainModule : cloneSymbol(mainModule);
	                    mergeSymbol(mainModule, moduleAugmentation.symbol);
	                }
	                else {
	                    error(moduleName, ts.Diagnostics.Cannot_augment_module_0_because_it_resolves_to_a_non_module_entity, moduleName.text);
	                }
	            }
	        }
	        function addToSymbolTable(target, source, message) {
	            for (var id in source) {
	                if (ts.hasProperty(source, id)) {
	                    if (ts.hasProperty(target, id)) {
	                        // Error on redeclarations
	                        ts.forEach(target[id].declarations, addDeclarationDiagnostic(id, message));
	                    }
	                    else {
	                        target[id] = source[id];
	                    }
	                }
	            }
	            function addDeclarationDiagnostic(id, message) {
	                return function (declaration) { return diagnostics.add(ts.createDiagnosticForNode(declaration, message, id)); };
	            }
	        }
	        function getSymbolLinks(symbol) {
	            if (symbol.flags & 67108864 /* Transient */)
	                return symbol;
	            var id = getSymbolId(symbol);
	            return symbolLinks[id] || (symbolLinks[id] = {});
	        }
	        function getNodeLinks(node) {
	            var nodeId = getNodeId(node);
	            return nodeLinks[nodeId] || (nodeLinks[nodeId] = {});
	        }
	        function isGlobalSourceFile(node) {
	            return node.kind === 251 /* SourceFile */ && !ts.isExternalOrCommonJsModule(node);
	        }
	        function getSymbol(symbols, name, meaning) {
	            if (meaning && ts.hasProperty(symbols, name)) {
	                var symbol = symbols[name];
	                ts.Debug.assert((symbol.flags & 16777216 /* Instantiated */) === 0, "Should never get an instantiated symbol here.");
	                if (symbol.flags & meaning) {
	                    return symbol;
	                }
	                if (symbol.flags & 8388608 /* Alias */) {
	                    var target = resolveAlias(symbol);
	                    // Unknown symbol means an error occurred in alias resolution, treat it as positive answer to avoid cascading errors
	                    if (target === unknownSymbol || target.flags & meaning) {
	                        return symbol;
	                    }
	                }
	            }
	            // return undefined if we can't find a symbol.
	        }
	        /**
	         * Get symbols that represent parameter-property-declaration as parameter and as property declaration
	         * @param parameter a parameterDeclaration node
	         * @param parameterName a name of the parameter to get the symbols for.
	         * @return a tuple of two symbols
	         */
	        function getSymbolsOfParameterPropertyDeclaration(parameter, parameterName) {
	            var constructoDeclaration = parameter.parent;
	            var classDeclaration = parameter.parent.parent;
	            var parameterSymbol = getSymbol(constructoDeclaration.locals, parameterName, 107455 /* Value */);
	            var propertySymbol = getSymbol(classDeclaration.symbol.members, parameterName, 107455 /* Value */);
	            if (parameterSymbol && propertySymbol) {
	                return [parameterSymbol, propertySymbol];
	            }
	            ts.Debug.fail("There should exist two symbols, one as property declaration and one as parameter declaration");
	        }
	        function isBlockScopedNameDeclaredBeforeUse(declaration, usage) {
	            var declarationFile = ts.getSourceFileOfNode(declaration);
	            var useFile = ts.getSourceFileOfNode(usage);
	            if (declarationFile !== useFile) {
	                if (modulekind || (!compilerOptions.outFile && !compilerOptions.out)) {
	                    // nodes are in different files and order cannot be determines
	                    return true;
	                }
	                var sourceFiles = host.getSourceFiles();
	                return ts.indexOf(sourceFiles, declarationFile) <= ts.indexOf(sourceFiles, useFile);
	            }
	            if (declaration.pos <= usage.pos) {
	                // declaration is before usage
	                // still might be illegal if usage is in the initializer of the variable declaration
	                return declaration.kind !== 214 /* VariableDeclaration */ ||
	                    !isImmediatelyUsedInInitializerOfBlockScopedVariable(declaration, usage);
	            }
	            // declaration is after usage
	            // can be legal if usage is deferred (i.e. inside function or in initializer of instance property)
	            return isUsedInFunctionOrNonStaticProperty(declaration, usage);
	            function isImmediatelyUsedInInitializerOfBlockScopedVariable(declaration, usage) {
	                var container = ts.getEnclosingBlockScopeContainer(declaration);
	                if (declaration.parent.parent.kind === 196 /* VariableStatement */ ||
	                    declaration.parent.parent.kind === 202 /* ForStatement */) {
	                    // variable statement/for statement case,
	                    // use site should not be inside variable declaration (initializer of declaration or binding element)
	                    return isSameScopeDescendentOf(usage, declaration, container);
	                }
	                else if (declaration.parent.parent.kind === 204 /* ForOfStatement */ ||
	                    declaration.parent.parent.kind === 203 /* ForInStatement */) {
	                    // ForIn/ForOf case - use site should not be used in expression part
	                    var expression = declaration.parent.parent.expression;
	                    return isSameScopeDescendentOf(usage, expression, container);
	                }
	            }
	            function isUsedInFunctionOrNonStaticProperty(declaration, usage) {
	                var container = ts.getEnclosingBlockScopeContainer(declaration);
	                var current = usage;
	                while (current) {
	                    if (current === container) {
	                        return false;
	                    }
	                    if (ts.isFunctionLike(current)) {
	                        return true;
	                    }
	                    var initializerOfNonStaticProperty = current.parent &&
	                        current.parent.kind === 142 /* PropertyDeclaration */ &&
	                        (current.parent.flags & 64 /* Static */) === 0 &&
	                        current.parent.initializer === current;
	                    if (initializerOfNonStaticProperty) {
	                        return true;
	                    }
	                    current = current.parent;
	                }
	                return false;
	            }
	        }
	        // Resolve a given name for a given meaning at a given location. An error is reported if the name was not found and
	        // the nameNotFoundMessage argument is not undefined. Returns the resolved symbol, or undefined if no symbol with
	        // the given name can be found.
	        function resolveName(location, name, meaning, nameNotFoundMessage, nameArg) {
	            var result;
	            var lastLocation;
	            var propertyWithInvalidInitializer;
	            var errorLocation = location;
	            var grandparent;
	            loop: while (location) {
	                // Locals of a source file are not in scope (because they get merged into the global symbol table)
	                if (location.locals && !isGlobalSourceFile(location)) {
	                    if (result = getSymbol(location.locals, name, meaning)) {
	                        var useResult = true;
	                        if (ts.isFunctionLike(location) && lastLocation && lastLocation !== location.body) {
	                            // symbol lookup restrictions for function-like declarations
	                            // - Type parameters of a function are in scope in the entire function declaration, including the parameter
	                            //   list and return type. However, local types are only in scope in the function body.
	                            // - parameters are only in the scope of function body
	                            // This restriction does not apply to JSDoc comment types because they are parented
	                            // at a higher level than type parameters would normally be
	                            if (meaning & result.flags & 793056 /* Type */ && lastLocation.kind !== 268 /* JSDocComment */) {
	                                useResult = result.flags & 262144 /* TypeParameter */
	                                    ? lastLocation === location.type ||
	                                        lastLocation.kind === 139 /* Parameter */ ||
	                                        lastLocation.kind === 138 /* TypeParameter */
	                                    : false;
	                            }
	                            if (meaning & 107455 /* Value */ && result.flags & 1 /* FunctionScopedVariable */) {
	                                // parameters are visible only inside function body, parameter list and return type
	                                // technically for parameter list case here we might mix parameters and variables declared in function,
	                                // however it is detected separately when checking initializers of parameters
	                                // to make sure that they reference no variables declared after them.
	                                useResult =
	                                    lastLocation.kind === 139 /* Parameter */ ||
	                                        (lastLocation === location.type &&
	                                            result.valueDeclaration.kind === 139 /* Parameter */);
	                            }
	                        }
	                        if (useResult) {
	                            break loop;
	                        }
	                        else {
	                            result = undefined;
	                        }
	                    }
	                }
	                switch (location.kind) {
	                    case 251 /* SourceFile */:
	                        if (!ts.isExternalOrCommonJsModule(location))
	                            break;
	                    case 221 /* ModuleDeclaration */:
	                        var moduleExports = getSymbolOfNode(location).exports;
	                        if (location.kind === 251 /* SourceFile */ || ts.isAmbientModule(location)) {
	                            // It's an external module. First see if the module has an export default and if the local
	                            // name of that export default matches.
	                            if (result = moduleExports["default"]) {
	                                var localSymbol = ts.getLocalSymbolForExportDefault(result);
	                                if (localSymbol && (result.flags & meaning) && localSymbol.name === name) {
	                                    break loop;
	                                }
	                                result = undefined;
	                            }
	                            // Because of module/namespace merging, a module's exports are in scope,
	                            // yet we never want to treat an export specifier as putting a member in scope.
	                            // Therefore, if the name we find is purely an export specifier, it is not actually considered in scope.
	                            // Two things to note about this:
	                            //     1. We have to check this without calling getSymbol. The problem with calling getSymbol
	                            //        on an export specifier is that it might find the export specifier itself, and try to
	                            //        resolve it as an alias. This will cause the checker to consider the export specifier
	                            //        a circular alias reference when it might not be.
	                            //     2. We check === SymbolFlags.Alias in order to check that the symbol is *purely*
	                            //        an alias. If we used &, we'd be throwing out symbols that have non alias aspects,
	                            //        which is not the desired behavior.
	                            if (ts.hasProperty(moduleExports, name) &&
	                                moduleExports[name].flags === 8388608 /* Alias */ &&
	                                ts.getDeclarationOfKind(moduleExports[name], 233 /* ExportSpecifier */)) {
	                                break;
	                            }
	                        }
	                        if (result = getSymbol(moduleExports, name, meaning & 8914931 /* ModuleMember */)) {
	                            break loop;
	                        }
	                        break;
	                    case 220 /* EnumDeclaration */:
	                        if (result = getSymbol(getSymbolOfNode(location).exports, name, meaning & 8 /* EnumMember */)) {
	                            break loop;
	                        }
	                        break;
	                    case 142 /* PropertyDeclaration */:
	                    case 141 /* PropertySignature */:
	                        // TypeScript 1.0 spec (April 2014): 8.4.1
	                        // Initializer expressions for instance member variables are evaluated in the scope
	                        // of the class constructor body but are not permitted to reference parameters or
	                        // local variables of the constructor. This effectively means that entities from outer scopes
	                        // by the same name as a constructor parameter or local variable are inaccessible
	                        // in initializer expressions for instance member variables.
	                        if (ts.isClassLike(location.parent) && !(location.flags & 64 /* Static */)) {
	                            var ctor = findConstructorDeclaration(location.parent);
	                            if (ctor && ctor.locals) {
	                                if (getSymbol(ctor.locals, name, meaning & 107455 /* Value */)) {
	                                    // Remember the property node, it will be used later to report appropriate error
	                                    propertyWithInvalidInitializer = location;
	                                }
	                            }
	                        }
	                        break;
	                    case 217 /* ClassDeclaration */:
	                    case 189 /* ClassExpression */:
	                    case 218 /* InterfaceDeclaration */:
	                        if (result = getSymbol(getSymbolOfNode(location).members, name, meaning & 793056 /* Type */)) {
	                            if (lastLocation && lastLocation.flags & 64 /* Static */) {
	                                // TypeScript 1.0 spec (April 2014): 3.4.1
	                                // The scope of a type parameter extends over the entire declaration with which the type
	                                // parameter list is associated, with the exception of static member declarations in classes.
	                                error(errorLocation, ts.Diagnostics.Static_members_cannot_reference_class_type_parameters);
	                                return undefined;
	                            }
	                            break loop;
	                        }
	                        if (location.kind === 189 /* ClassExpression */ && meaning & 32 /* Class */) {
	                            var className = location.name;
	                            if (className && name === className.text) {
	                                result = location.symbol;
	                                break loop;
	                            }
	                        }
	                        break;
	                    // It is not legal to reference a class's own type parameters from a computed property name that
	                    // belongs to the class. For example:
	                    //
	                    //   function foo<T>() { return '' }
	                    //   class C<T> { // <-- Class's own type parameter T
	                    //       [foo<T>()]() { } // <-- Reference to T from class's own computed property
	                    //   }
	                    //
	                    case 137 /* ComputedPropertyName */:
	                        grandparent = location.parent.parent;
	                        if (ts.isClassLike(grandparent) || grandparent.kind === 218 /* InterfaceDeclaration */) {
	                            // A reference to this grandparent's type parameters would be an error
	                            if (result = getSymbol(getSymbolOfNode(grandparent).members, name, meaning & 793056 /* Type */)) {
	                                error(errorLocation, ts.Diagnostics.A_computed_property_name_cannot_reference_a_type_parameter_from_its_containing_type);
	                                return undefined;
	                            }
	                        }
	                        break;
	                    case 144 /* MethodDeclaration */:
	                    case 143 /* MethodSignature */:
	                    case 145 /* Constructor */:
	                    case 146 /* GetAccessor */:
	                    case 147 /* SetAccessor */:
	                    case 216 /* FunctionDeclaration */:
	                    case 177 /* ArrowFunction */:
	                        if (meaning & 3 /* Variable */ && name === "arguments") {
	                            result = argumentsSymbol;
	                            break loop;
	                        }
	                        break;
	                    case 176 /* FunctionExpression */:
	                        if (meaning & 3 /* Variable */ && name === "arguments") {
	                            result = argumentsSymbol;
	                            break loop;
	                        }
	                        if (meaning & 16 /* Function */) {
	                            var functionName = location.name;
	                            if (functionName && name === functionName.text) {
	                                result = location.symbol;
	                                break loop;
	                            }
	                        }
	                        break;
	                    case 140 /* Decorator */:
	                        // Decorators are resolved at the class declaration. Resolving at the parameter
	                        // or member would result in looking up locals in the method.
	                        //
	                        //   function y() {}
	                        //   class C {
	                        //       method(@y x, y) {} // <-- decorator y should be resolved at the class declaration, not the parameter.
	                        //   }
	                        //
	                        if (location.parent && location.parent.kind === 139 /* Parameter */) {
	                            location = location.parent;
	                        }
	                        //
	                        //   function y() {}
	                        //   class C {
	                        //       @y method(x, y) {} // <-- decorator y should be resolved at the class declaration, not the method.
	                        //   }
	                        //
	                        if (location.parent && ts.isClassElement(location.parent)) {
	                            location = location.parent;
	                        }
	                        break;
	                }
	                lastLocation = location;
	                location = location.parent;
	            }
	            if (!result) {
	                result = getSymbol(globals, name, meaning);
	            }
	            if (!result) {
	                if (nameNotFoundMessage) {
	                    if (!checkAndReportErrorForMissingPrefix(errorLocation, name, nameArg)) {
	                        error(errorLocation, nameNotFoundMessage, typeof nameArg === "string" ? nameArg : ts.declarationNameToString(nameArg));
	                    }
	                }
	                return undefined;
	            }
	            // Perform extra checks only if error reporting was requested
	            if (nameNotFoundMessage) {
	                if (propertyWithInvalidInitializer) {
	                    // We have a match, but the reference occurred within a property initializer and the identifier also binds
	                    // to a local variable in the constructor where the code will be emitted.
	                    var propertyName = propertyWithInvalidInitializer.name;
	                    error(errorLocation, ts.Diagnostics.Initializer_of_instance_member_variable_0_cannot_reference_identifier_1_declared_in_the_constructor, ts.declarationNameToString(propertyName), typeof nameArg === "string" ? nameArg : ts.declarationNameToString(nameArg));
	                    return undefined;
	                }
	                // Only check for block-scoped variable if we are looking for the
	                // name with variable meaning
	                //      For example,
	                //          declare module foo {
	                //              interface bar {}
	                //          }
	                //      const foo/*1*/: foo/*2*/.bar;
	                // The foo at /*1*/ and /*2*/ will share same symbol with two meaning
	                // block - scope variable and namespace module. However, only when we
	                // try to resolve name in /*1*/ which is used in variable position,
	                // we want to check for block- scoped
	                if (meaning & 2 /* BlockScopedVariable */) {
	                    var exportOrLocalSymbol = getExportSymbolOfValueSymbolIfExported(result);
	                    if (exportOrLocalSymbol.flags & 2 /* BlockScopedVariable */) {
	                        checkResolvedBlockScopedVariable(exportOrLocalSymbol, errorLocation);
	                    }
	                }
	            }
	            return result;
	        }
	        function checkAndReportErrorForMissingPrefix(errorLocation, name, nameArg) {
	            if (!errorLocation || (errorLocation.kind === 69 /* Identifier */ && (isTypeReferenceIdentifier(errorLocation)) || isInTypeQuery(errorLocation))) {
	                return false;
	            }
	            var container = ts.getThisContainer(errorLocation, /* includeArrowFunctions */ true);
	            var location = container;
	            while (location) {
	                if (ts.isClassLike(location.parent)) {
	                    var classSymbol = getSymbolOfNode(location.parent);
	                    if (!classSymbol) {
	                        break;
	                    }
	                    // Check to see if a static member exists.
	                    var constructorType = getTypeOfSymbol(classSymbol);
	                    if (getPropertyOfType(constructorType, name)) {
	                        error(errorLocation, ts.Diagnostics.Cannot_find_name_0_Did_you_mean_the_static_member_1_0, typeof nameArg === "string" ? nameArg : ts.declarationNameToString(nameArg), symbolToString(classSymbol));
	                        return true;
	                    }
	                    // No static member is present.
	                    // Check if we're in an instance method and look for a relevant instance member.
	                    if (location === container && !(location.flags & 64 /* Static */)) {
	                        var instanceType = getDeclaredTypeOfSymbol(classSymbol).thisType;
	                        if (getPropertyOfType(instanceType, name)) {
	                            error(errorLocation, ts.Diagnostics.Cannot_find_name_0_Did_you_mean_the_instance_member_this_0, typeof nameArg === "string" ? nameArg : ts.declarationNameToString(nameArg));
	                            return true;
	                        }
	                    }
	                }
	                location = location.parent;
	            }
	            return false;
	        }
	        function checkResolvedBlockScopedVariable(result, errorLocation) {
	            ts.Debug.assert((result.flags & 2 /* BlockScopedVariable */) !== 0);
	            // Block-scoped variables cannot be used before their definition
	            var declaration = ts.forEach(result.declarations, function (d) { return ts.isBlockOrCatchScoped(d) ? d : undefined; });
	            ts.Debug.assert(declaration !== undefined, "Block-scoped variable declaration is undefined");
	            if (!isBlockScopedNameDeclaredBeforeUse(ts.getAncestor(declaration, 214 /* VariableDeclaration */), errorLocation)) {
	                error(errorLocation, ts.Diagnostics.Block_scoped_variable_0_used_before_its_declaration, ts.declarationNameToString(declaration.name));
	            }
	        }
	        /* Starting from 'initial' node walk up the parent chain until 'stopAt' node is reached.
	         * If at any point current node is equal to 'parent' node - return true.
	         * Return false if 'stopAt' node is reached or isFunctionLike(current) === true.
	         */
	        function isSameScopeDescendentOf(initial, parent, stopAt) {
	            if (!parent) {
	                return false;
	            }
	            for (var current = initial; current && current !== stopAt && !ts.isFunctionLike(current); current = current.parent) {
	                if (current === parent) {
	                    return true;
	                }
	            }
	            return false;
	        }
	        function getAnyImportSyntax(node) {
	            if (ts.isAliasSymbolDeclaration(node)) {
	                if (node.kind === 224 /* ImportEqualsDeclaration */) {
	                    return node;
	                }
	                while (node && node.kind !== 225 /* ImportDeclaration */) {
	                    node = node.parent;
	                }
	                return node;
	            }
	        }
	        function getDeclarationOfAliasSymbol(symbol) {
	            return ts.forEach(symbol.declarations, function (d) { return ts.isAliasSymbolDeclaration(d) ? d : undefined; });
	        }
	        function getTargetOfImportEqualsDeclaration(node) {
	            if (node.moduleReference.kind === 235 /* ExternalModuleReference */) {
	                return resolveExternalModuleSymbol(resolveExternalModuleName(node, ts.getExternalModuleImportEqualsDeclarationExpression(node)));
	            }
	            return getSymbolOfPartOfRightHandSideOfImportEquals(node.moduleReference, node);
	        }
	        function getTargetOfImportClause(node) {
	            var moduleSymbol = resolveExternalModuleName(node, node.parent.moduleSpecifier);
	            if (moduleSymbol) {
	                var exportDefaultSymbol = resolveSymbol(moduleSymbol.exports["default"]);
	                if (!exportDefaultSymbol && !allowSyntheticDefaultImports) {
	                    error(node.name, ts.Diagnostics.Module_0_has_no_default_export, symbolToString(moduleSymbol));
	                }
	                else if (!exportDefaultSymbol && allowSyntheticDefaultImports) {
	                    return resolveExternalModuleSymbol(moduleSymbol) || resolveSymbol(moduleSymbol);
	                }
	                return exportDefaultSymbol;
	            }
	        }
	        function getTargetOfNamespaceImport(node) {
	            var moduleSpecifier = node.parent.parent.moduleSpecifier;
	            return resolveESModuleSymbol(resolveExternalModuleName(node, moduleSpecifier), moduleSpecifier);
	        }
	        // This function creates a synthetic symbol that combines the value side of one symbol with the
	        // type/namespace side of another symbol. Consider this example:
	        //
	        //   declare module graphics {
	        //       interface Point {
	        //           x: number;
	        //           y: number;
	        //       }
	        //   }
	        //   declare var graphics: {
	        //       Point: new (x: number, y: number) => graphics.Point;
	        //   }
	        //   declare module "graphics" {
	        //       export = graphics;
	        //   }
	        //
	        // An 'import { Point } from "graphics"' needs to create a symbol that combines the value side 'Point'
	        // property with the type/namespace side interface 'Point'.
	        function combineValueAndTypeSymbols(valueSymbol, typeSymbol) {
	            if (valueSymbol.flags & (793056 /* Type */ | 1536 /* Namespace */)) {
	                return valueSymbol;
	            }
	            var result = createSymbol(valueSymbol.flags | typeSymbol.flags, valueSymbol.name);
	            result.declarations = ts.concatenate(valueSymbol.declarations, typeSymbol.declarations);
	            result.parent = valueSymbol.parent || typeSymbol.parent;
	            if (valueSymbol.valueDeclaration)
	                result.valueDeclaration = valueSymbol.valueDeclaration;
	            if (typeSymbol.members)
	                result.members = typeSymbol.members;
	            if (valueSymbol.exports)
	                result.exports = valueSymbol.exports;
	            return result;
	        }
	        function getExportOfModule(symbol, name) {
	            if (symbol.flags & 1536 /* Module */) {
	                var exports = getExportsOfSymbol(symbol);
	                if (ts.hasProperty(exports, name)) {
	                    return resolveSymbol(exports[name]);
	                }
	            }
	        }
	        function getPropertyOfVariable(symbol, name) {
	            if (symbol.flags & 3 /* Variable */) {
	                var typeAnnotation = symbol.valueDeclaration.type;
	                if (typeAnnotation) {
	                    return resolveSymbol(getPropertyOfType(getTypeFromTypeNode(typeAnnotation), name));
	                }
	            }
	        }
	        function getExternalModuleMember(node, specifier) {
	            var moduleSymbol = resolveExternalModuleName(node, node.moduleSpecifier);
	            var targetSymbol = resolveESModuleSymbol(moduleSymbol, node.moduleSpecifier);
	            if (targetSymbol) {
	                var name_9 = specifier.propertyName || specifier.name;
	                if (name_9.text) {
	                    var symbolFromModule = getExportOfModule(targetSymbol, name_9.text);
	                    var symbolFromVariable = getPropertyOfVariable(targetSymbol, name_9.text);
	                    var symbol = symbolFromModule && symbolFromVariable ?
	                        combineValueAndTypeSymbols(symbolFromVariable, symbolFromModule) :
	                        symbolFromModule || symbolFromVariable;
	                    if (!symbol) {
	                        error(name_9, ts.Diagnostics.Module_0_has_no_exported_member_1, getFullyQualifiedName(moduleSymbol), ts.declarationNameToString(name_9));
	                    }
	                    return symbol;
	                }
	            }
	        }
	        function getTargetOfImportSpecifier(node) {
	            return getExternalModuleMember(node.parent.parent.parent, node);
	        }
	        function getTargetOfExportSpecifier(node) {
	            return node.parent.parent.moduleSpecifier ?
	                getExternalModuleMember(node.parent.parent, node) :
	                resolveEntityName(node.propertyName || node.name, 107455 /* Value */ | 793056 /* Type */ | 1536 /* Namespace */);
	        }
	        function getTargetOfExportAssignment(node) {
	            return resolveEntityName(node.expression, 107455 /* Value */ | 793056 /* Type */ | 1536 /* Namespace */);
	        }
	        function getTargetOfAliasDeclaration(node) {
	            switch (node.kind) {
	                case 224 /* ImportEqualsDeclaration */:
	                    return getTargetOfImportEqualsDeclaration(node);
	                case 226 /* ImportClause */:
	                    return getTargetOfImportClause(node);
	                case 227 /* NamespaceImport */:
	                    return getTargetOfNamespaceImport(node);
	                case 229 /* ImportSpecifier */:
	                    return getTargetOfImportSpecifier(node);
	                case 233 /* ExportSpecifier */:
	                    return getTargetOfExportSpecifier(node);
	                case 230 /* ExportAssignment */:
	                    return getTargetOfExportAssignment(node);
	            }
	        }
	        function resolveSymbol(symbol) {
	            return symbol && symbol.flags & 8388608 /* Alias */ && !(symbol.flags & (107455 /* Value */ | 793056 /* Type */ | 1536 /* Namespace */)) ? resolveAlias(symbol) : symbol;
	        }
	        function resolveAlias(symbol) {
	            ts.Debug.assert((symbol.flags & 8388608 /* Alias */) !== 0, "Should only get Alias here.");
	            var links = getSymbolLinks(symbol);
	            if (!links.target) {
	                links.target = resolvingSymbol;
	                var node = getDeclarationOfAliasSymbol(symbol);
	                var target = getTargetOfAliasDeclaration(node);
	                if (links.target === resolvingSymbol) {
	                    links.target = target || unknownSymbol;
	                }
	                else {
	                    error(node, ts.Diagnostics.Circular_definition_of_import_alias_0, symbolToString(symbol));
	                }
	            }
	            else if (links.target === resolvingSymbol) {
	                links.target = unknownSymbol;
	            }
	            return links.target;
	        }
	        function markExportAsReferenced(node) {
	            var symbol = getSymbolOfNode(node);
	            var target = resolveAlias(symbol);
	            if (target) {
	                var markAlias = (target === unknownSymbol && compilerOptions.isolatedModules) ||
	                    (target !== unknownSymbol && (target.flags & 107455 /* Value */) && !isConstEnumOrConstEnumOnlyModule(target));
	                if (markAlias) {
	                    markAliasSymbolAsReferenced(symbol);
	                }
	            }
	        }
	        // When an alias symbol is referenced, we need to mark the entity it references as referenced and in turn repeat that until
	        // we reach a non-alias or an exported entity (which is always considered referenced). We do this by checking the target of
	        // the alias as an expression (which recursively takes us back here if the target references another alias).
	        function markAliasSymbolAsReferenced(symbol) {
	            var links = getSymbolLinks(symbol);
	            if (!links.referenced) {
	                links.referenced = true;
	                var node = getDeclarationOfAliasSymbol(symbol);
	                if (node.kind === 230 /* ExportAssignment */) {
	                    // export default <symbol>
	                    checkExpressionCached(node.expression);
	                }
	                else if (node.kind === 233 /* ExportSpecifier */) {
	                    // export { <symbol> } or export { <symbol> as foo }
	                    checkExpressionCached(node.propertyName || node.name);
	                }
	                else if (ts.isInternalModuleImportEqualsDeclaration(node)) {
	                    // import foo = <symbol>
	                    checkExpressionCached(node.moduleReference);
	                }
	            }
	        }
	        // This function is only for imports with entity names
	        function getSymbolOfPartOfRightHandSideOfImportEquals(entityName, importDeclaration) {
	            if (!importDeclaration) {
	                importDeclaration = ts.getAncestor(entityName, 224 /* ImportEqualsDeclaration */);
	                ts.Debug.assert(importDeclaration !== undefined);
	            }
	            // There are three things we might try to look for. In the following examples,
	            // the search term is enclosed in |...|:
	            //
	            //     import a = |b|; // Namespace
	            //     import a = |b.c|; // Value, type, namespace
	            //     import a = |b.c|.d; // Namespace
	            if (entityName.kind === 69 /* Identifier */ && ts.isRightSideOfQualifiedNameOrPropertyAccess(entityName)) {
	                entityName = entityName.parent;
	            }
	            // Check for case 1 and 3 in the above example
	            if (entityName.kind === 69 /* Identifier */ || entityName.parent.kind === 136 /* QualifiedName */) {
	                return resolveEntityName(entityName, 1536 /* Namespace */);
	            }
	            else {
	                // Case 2 in above example
	                // entityName.kind could be a QualifiedName or a Missing identifier
	                ts.Debug.assert(entityName.parent.kind === 224 /* ImportEqualsDeclaration */);
	                return resolveEntityName(entityName, 107455 /* Value */ | 793056 /* Type */ | 1536 /* Namespace */);
	            }
	        }
	        function getFullyQualifiedName(symbol) {
	            return symbol.parent ? getFullyQualifiedName(symbol.parent) + "." + symbolToString(symbol) : symbolToString(symbol);
	        }
	        // Resolves a qualified name and any involved aliases
	        function resolveEntityName(name, meaning, ignoreErrors) {
	            if (ts.nodeIsMissing(name)) {
	                return undefined;
	            }
	            var symbol;
	            if (name.kind === 69 /* Identifier */) {
	                var message = meaning === 1536 /* Namespace */ ? ts.Diagnostics.Cannot_find_namespace_0 : ts.Diagnostics.Cannot_find_name_0;
	                symbol = resolveName(name, name.text, meaning, ignoreErrors ? undefined : message, name);
	                if (!symbol) {
	                    return undefined;
	                }
	            }
	            else if (name.kind === 136 /* QualifiedName */ || name.kind === 169 /* PropertyAccessExpression */) {
	                var left = name.kind === 136 /* QualifiedName */ ? name.left : name.expression;
	                var right = name.kind === 136 /* QualifiedName */ ? name.right : name.name;
	                var namespace = resolveEntityName(left, 1536 /* Namespace */, ignoreErrors);
	                if (!namespace || namespace === unknownSymbol || ts.nodeIsMissing(right)) {
	                    return undefined;
	                }
	                symbol = getSymbol(getExportsOfSymbol(namespace), right.text, meaning);
	                if (!symbol) {
	                    if (!ignoreErrors) {
	                        error(right, ts.Diagnostics.Module_0_has_no_exported_member_1, getFullyQualifiedName(namespace), ts.declarationNameToString(right));
	                    }
	                    return undefined;
	                }
	            }
	            else {
	                ts.Debug.fail("Unknown entity name kind.");
	            }
	            ts.Debug.assert((symbol.flags & 16777216 /* Instantiated */) === 0, "Should never get an instantiated symbol here.");
	            return symbol.flags & meaning ? symbol : resolveAlias(symbol);
	        }
	        function resolveExternalModuleName(location, moduleReferenceExpression) {
	            return resolveExternalModuleNameWorker(location, moduleReferenceExpression, ts.Diagnostics.Cannot_find_module_0);
	        }
	        function resolveExternalModuleNameWorker(location, moduleReferenceExpression, moduleNotFoundError) {
	            if (moduleReferenceExpression.kind !== 9 /* StringLiteral */) {
	                return;
	            }
	            var moduleReferenceLiteral = moduleReferenceExpression;
	            // Module names are escaped in our symbol table.  However, string literal values aren't.
	            // Escape the name in the "require(...)" clause to ensure we find the right symbol.
	            var moduleName = ts.escapeIdentifier(moduleReferenceLiteral.text);
	            if (moduleName === undefined) {
	                return;
	            }
	            var isRelative = ts.isExternalModuleNameRelative(moduleName);
	            if (!isRelative) {
	                var symbol = getSymbol(globals, "\"" + moduleName + "\"", 512 /* ValueModule */);
	                if (symbol) {
	                    // merged symbol is module declaration symbol combined with all augmentations
	                    return getMergedSymbol(symbol);
	                }
	            }
	            var resolvedModule = ts.getResolvedModule(ts.getSourceFileOfNode(location), moduleReferenceLiteral.text);
	            var sourceFile = resolvedModule && host.getSourceFile(resolvedModule.resolvedFileName);
	            if (sourceFile) {
	                if (sourceFile.symbol) {
	                    // merged symbol is module declaration symbol combined with all augmentations
	                    return getMergedSymbol(sourceFile.symbol);
	                }
	                if (moduleNotFoundError) {
	                    // report errors only if it was requested
	                    error(moduleReferenceLiteral, ts.Diagnostics.File_0_is_not_a_module, sourceFile.fileName);
	                }
	                return undefined;
	            }
	            if (moduleNotFoundError) {
	                // report errors only if it was requested
	                error(moduleReferenceLiteral, moduleNotFoundError, moduleName);
	            }
	            return undefined;
	        }
	        // An external module with an 'export =' declaration resolves to the target of the 'export =' declaration,
	        // and an external module with no 'export =' declaration resolves to the module itself.
	        function resolveExternalModuleSymbol(moduleSymbol) {
	            return moduleSymbol && getMergedSymbol(resolveSymbol(moduleSymbol.exports["export="])) || moduleSymbol;
	        }
	        // An external module with an 'export =' declaration may be referenced as an ES6 module provided the 'export ='
	        // references a symbol that is at least declared as a module or a variable. The target of the 'export =' may
	        // combine other declarations with the module or variable (e.g. a class/module, function/module, interface/variable).
	        function resolveESModuleSymbol(moduleSymbol, moduleReferenceExpression) {
	            var symbol = resolveExternalModuleSymbol(moduleSymbol);
	            if (symbol && !(symbol.flags & (1536 /* Module */ | 3 /* Variable */))) {
	                error(moduleReferenceExpression, ts.Diagnostics.Module_0_resolves_to_a_non_module_entity_and_cannot_be_imported_using_this_construct, symbolToString(moduleSymbol));
	                symbol = undefined;
	            }
	            return symbol;
	        }
	        function hasExportAssignmentSymbol(moduleSymbol) {
	            return moduleSymbol.exports["export="] !== undefined;
	        }
	        function getExportsOfModuleAsArray(moduleSymbol) {
	            return symbolsToArray(getExportsOfModule(moduleSymbol));
	        }
	        function getExportsOfSymbol(symbol) {
	            return symbol.flags & 1536 /* Module */ ? getExportsOfModule(symbol) : symbol.exports || emptySymbols;
	        }
	        function getExportsOfModule(moduleSymbol) {
	            var links = getSymbolLinks(moduleSymbol);
	            return links.resolvedExports || (links.resolvedExports = getExportsForModule(moduleSymbol));
	        }
	        /**
	         * Extends one symbol table with another while collecting information on name collisions for error message generation into the `lookupTable` argument
	         * Not passing `lookupTable` and `exportNode` disables this collection, and just extends the tables
	         */
	        function extendExportSymbols(target, source, lookupTable, exportNode) {
	            for (var id in source) {
	                if (id !== "default" && !ts.hasProperty(target, id)) {
	                    target[id] = source[id];
	                    if (lookupTable && exportNode) {
	                        lookupTable[id] = {
	                            specifierText: ts.getTextOfNode(exportNode.moduleSpecifier)
	                        };
	                    }
	                }
	                else if (lookupTable && exportNode && id !== "default" && ts.hasProperty(target, id) && resolveSymbol(target[id]) !== resolveSymbol(source[id])) {
	                    if (!lookupTable[id].exportsWithDuplicate) {
	                        lookupTable[id].exportsWithDuplicate = [exportNode];
	                    }
	                    else {
	                        lookupTable[id].exportsWithDuplicate.push(exportNode);
	                    }
	                }
	            }
	        }
	        function getExportsForModule(moduleSymbol) {
	            var visitedSymbols = [];
	            return visit(moduleSymbol) || moduleSymbol.exports;
	            // The ES6 spec permits export * declarations in a module to circularly reference the module itself. For example,
	            // module 'a' can 'export * from "b"' and 'b' can 'export * from "a"' without error.
	            function visit(symbol) {
	                if (!(symbol && symbol.flags & 1952 /* HasExports */ && !ts.contains(visitedSymbols, symbol))) {
	                    return;
	                }
	                visitedSymbols.push(symbol);
	                var symbols = cloneSymbolTable(symbol.exports);
	                // All export * declarations are collected in an __export symbol by the binder
	                var exportStars = symbol.exports["__export"];
	                if (exportStars) {
	                    var nestedSymbols = {};
	                    var lookupTable = {};
	                    for (var _i = 0, _a = exportStars.declarations; _i < _a.length; _i++) {
	                        var node = _a[_i];
	                        var resolvedModule = resolveExternalModuleName(node, node.moduleSpecifier);
	                        var exportedSymbols = visit(resolvedModule);
	                        extendExportSymbols(nestedSymbols, exportedSymbols, lookupTable, node);
	                    }
	                    for (var id in lookupTable) {
	                        var exportsWithDuplicate = lookupTable[id].exportsWithDuplicate;
	                        // It's not an error if the file with multiple `export *`s with duplicate names exports a member with that name itself
	                        if (id === "export=" || !(exportsWithDuplicate && exportsWithDuplicate.length) || ts.hasProperty(symbols, id)) {
	                            continue;
	                        }
	                        for (var _b = 0, exportsWithDuplicate_1 = exportsWithDuplicate; _b < exportsWithDuplicate_1.length; _b++) {
	                            var node = exportsWithDuplicate_1[_b];
	                            diagnostics.add(ts.createDiagnosticForNode(node, ts.Diagnostics.Module_0_has_already_exported_a_member_named_1_Consider_explicitly_re_exporting_to_resolve_the_ambiguity, lookupTable[id].specifierText, id));
	                        }
	                    }
	                    extendExportSymbols(symbols, nestedSymbols);
	                }
	                return symbols;
	            }
	        }
	        function getMergedSymbol(symbol) {
	            var merged;
	            return symbol && symbol.mergeId && (merged = mergedSymbols[symbol.mergeId]) ? merged : symbol;
	        }
	        function getSymbolOfNode(node) {
	            return getMergedSymbol(node.symbol);
	        }
	        function getParentOfSymbol(symbol) {
	            return getMergedSymbol(symbol.parent);
	        }
	        function getExportSymbolOfValueSymbolIfExported(symbol) {
	            return symbol && (symbol.flags & 1048576 /* ExportValue */) !== 0
	                ? getMergedSymbol(symbol.exportSymbol)
	                : symbol;
	        }
	        function symbolIsValue(symbol) {
	            // If it is an instantiated symbol, then it is a value if the symbol it is an
	            // instantiation of is a value.
	            if (symbol.flags & 16777216 /* Instantiated */) {
	                return symbolIsValue(getSymbolLinks(symbol).target);
	            }
	            // If the symbol has the value flag, it is trivially a value.
	            if (symbol.flags & 107455 /* Value */) {
	                return true;
	            }
	            // If it is an alias, then it is a value if the symbol it resolves to is a value.
	            if (symbol.flags & 8388608 /* Alias */) {
	                return (resolveAlias(symbol).flags & 107455 /* Value */) !== 0;
	            }
	            return false;
	        }
	        function findConstructorDeclaration(node) {
	            var members = node.members;
	            for (var _i = 0, members_1 = members; _i < members_1.length; _i++) {
	                var member = members_1[_i];
	                if (member.kind === 145 /* Constructor */ && ts.nodeIsPresent(member.body)) {
	                    return member;
	                }
	            }
	        }
	        function createType(flags) {
	            var result = new Type(checker, flags);
	            result.id = typeCount;
	            typeCount++;
	            return result;
	        }
	        function createIntrinsicType(kind, intrinsicName) {
	            var type = createType(kind);
	            type.intrinsicName = intrinsicName;
	            return type;
	        }
	        function createObjectType(kind, symbol) {
	            var type = createType(kind);
	            type.symbol = symbol;
	            return type;
	        }
	        // A reserved member name starts with two underscores, but the third character cannot be an underscore
	        // or the @ symbol. A third underscore indicates an escaped form of an identifer that started
	        // with at least two underscores. The @ character indicates that the name is denoted by a well known ES
	        // Symbol instance.
	        function isReservedMemberName(name) {
	            return name.charCodeAt(0) === 95 /* _ */ &&
	                name.charCodeAt(1) === 95 /* _ */ &&
	                name.charCodeAt(2) !== 95 /* _ */ &&
	                name.charCodeAt(2) !== 64 /* at */;
	        }
	        function getNamedMembers(members) {
	            var result;
	            for (var id in members) {
	                if (ts.hasProperty(members, id)) {
	                    if (!isReservedMemberName(id)) {
	                        if (!result)
	                            result = [];
	                        var symbol = members[id];
	                        if (symbolIsValue(symbol)) {
	                            result.push(symbol);
	                        }
	                    }
	                }
	            }
	            return result || emptyArray;
	        }
	        function setObjectTypeMembers(type, members, callSignatures, constructSignatures, stringIndexType, numberIndexType) {
	            type.members = members;
	            type.properties = getNamedMembers(members);
	            type.callSignatures = callSignatures;
	            type.constructSignatures = constructSignatures;
	            if (stringIndexType)
	                type.stringIndexType = stringIndexType;
	            if (numberIndexType)
	                type.numberIndexType = numberIndexType;
	            return type;
	        }
	        function createAnonymousType(symbol, members, callSignatures, constructSignatures, stringIndexType, numberIndexType) {
	            return setObjectTypeMembers(createObjectType(65536 /* Anonymous */, symbol), members, callSignatures, constructSignatures, stringIndexType, numberIndexType);
	        }
	        function forEachSymbolTableInScope(enclosingDeclaration, callback) {
	            var result;
	            for (var location_1 = enclosingDeclaration; location_1; location_1 = location_1.parent) {
	                // Locals of a source file are not in scope (because they get merged into the global symbol table)
	                if (location_1.locals && !isGlobalSourceFile(location_1)) {
	                    if (result = callback(location_1.locals)) {
	                        return result;
	                    }
	                }
	                switch (location_1.kind) {
	                    case 251 /* SourceFile */:
	                        if (!ts.isExternalOrCommonJsModule(location_1)) {
	                            break;
	                        }
	                    case 221 /* ModuleDeclaration */:
	                        if (result = callback(getSymbolOfNode(location_1).exports)) {
	                            return result;
	                        }
	                        break;
	                    case 217 /* ClassDeclaration */:
	                    case 218 /* InterfaceDeclaration */:
	                        if (result = callback(getSymbolOfNode(location_1).members)) {
	                            return result;
	                        }
	                        break;
	                }
	            }
	            return callback(globals);
	        }
	        function getQualifiedLeftMeaning(rightMeaning) {
	            // If we are looking in value space, the parent meaning is value, other wise it is namespace
	            return rightMeaning === 107455 /* Value */ ? 107455 /* Value */ : 1536 /* Namespace */;
	        }
	        function getAccessibleSymbolChain(symbol, enclosingDeclaration, meaning, useOnlyExternalAliasing) {
	            function getAccessibleSymbolChainFromSymbolTable(symbols) {
	                function canQualifySymbol(symbolFromSymbolTable, meaning) {
	                    // If the symbol is equivalent and doesn't need further qualification, this symbol is accessible
	                    if (!needsQualification(symbolFromSymbolTable, enclosingDeclaration, meaning)) {
	                        return true;
	                    }
	                    // If symbol needs qualification, make sure that parent is accessible, if it is then this symbol is accessible too
	                    var accessibleParent = getAccessibleSymbolChain(symbolFromSymbolTable.parent, enclosingDeclaration, getQualifiedLeftMeaning(meaning), useOnlyExternalAliasing);
	                    return !!accessibleParent;
	                }
	                function isAccessible(symbolFromSymbolTable, resolvedAliasSymbol) {
	                    if (symbol === (resolvedAliasSymbol || symbolFromSymbolTable)) {
	                        // if the symbolFromSymbolTable is not external module (it could be if it was determined as ambient external module and would be in globals table)
	                        // and if symbolfrom symbolTable or alias resolution matches the symbol,
	                        // check the symbol can be qualified, it is only then this symbol is accessible
	                        return !ts.forEach(symbolFromSymbolTable.declarations, hasExternalModuleSymbol) &&
	                            canQualifySymbol(symbolFromSymbolTable, meaning);
	                    }
	                }
	                // If symbol is directly available by its name in the symbol table
	                if (isAccessible(ts.lookUp(symbols, symbol.name))) {
	                    return [symbol];
	                }
	                // Check if symbol is any of the alias
	                return ts.forEachValue(symbols, function (symbolFromSymbolTable) {
	                    if (symbolFromSymbolTable.flags & 8388608 /* Alias */
	                        && symbolFromSymbolTable.name !== "export="
	                        && !ts.getDeclarationOfKind(symbolFromSymbolTable, 233 /* ExportSpecifier */)) {
	                        if (!useOnlyExternalAliasing ||
	                            // Is this external alias, then use it to name
	                            ts.forEach(symbolFromSymbolTable.declarations, ts.isExternalModuleImportEqualsDeclaration)) {
	                            var resolvedImportedSymbol = resolveAlias(symbolFromSymbolTable);
	                            if (isAccessible(symbolFromSymbolTable, resolveAlias(symbolFromSymbolTable))) {
	                                return [symbolFromSymbolTable];
	                            }
	                            // Look in the exported members, if we can find accessibleSymbolChain, symbol is accessible using this chain
	                            // but only if the symbolFromSymbolTable can be qualified
	                            var accessibleSymbolsFromExports = resolvedImportedSymbol.exports ? getAccessibleSymbolChainFromSymbolTable(resolvedImportedSymbol.exports) : undefined;
	                            if (accessibleSymbolsFromExports && canQualifySymbol(symbolFromSymbolTable, getQualifiedLeftMeaning(meaning))) {
	                                return [symbolFromSymbolTable].concat(accessibleSymbolsFromExports);
	                            }
	                        }
	                    }
	                });
	            }
	            if (symbol) {
	                return forEachSymbolTableInScope(enclosingDeclaration, getAccessibleSymbolChainFromSymbolTable);
	            }
	        }
	        function needsQualification(symbol, enclosingDeclaration, meaning) {
	            var qualify = false;
	            forEachSymbolTableInScope(enclosingDeclaration, function (symbolTable) {
	                // If symbol of this name is not available in the symbol table we are ok
	                if (!ts.hasProperty(symbolTable, symbol.name)) {
	                    // Continue to the next symbol table
	                    return false;
	                }
	                // If the symbol with this name is present it should refer to the symbol
	                var symbolFromSymbolTable = symbolTable[symbol.name];
	                if (symbolFromSymbolTable === symbol) {
	                    // No need to qualify
	                    return true;
	                }
	                // Qualify if the symbol from symbol table has same meaning as expected
	                symbolFromSymbolTable = (symbolFromSymbolTable.flags & 8388608 /* Alias */ && !ts.getDeclarationOfKind(symbolFromSymbolTable, 233 /* ExportSpecifier */)) ? resolveAlias(symbolFromSymbolTable) : symbolFromSymbolTable;
	                if (symbolFromSymbolTable.flags & meaning) {
	                    qualify = true;
	                    return true;
	                }
	                // Continue to the next symbol table
	                return false;
	            });
	            return qualify;
	        }
	        function isSymbolAccessible(symbol, enclosingDeclaration, meaning) {
	            if (symbol && enclosingDeclaration && !(symbol.flags & 262144 /* TypeParameter */)) {
	                var initialSymbol = symbol;
	                var meaningToLook = meaning;
	                while (symbol) {
	                    // Symbol is accessible if it by itself is accessible
	                    var accessibleSymbolChain = getAccessibleSymbolChain(symbol, enclosingDeclaration, meaningToLook, /*useOnlyExternalAliasing*/ false);
	                    if (accessibleSymbolChain) {
	                        var hasAccessibleDeclarations = hasVisibleDeclarations(accessibleSymbolChain[0]);
	                        if (!hasAccessibleDeclarations) {
	                            return {
	                                accessibility: 1 /* NotAccessible */,
	                                errorSymbolName: symbolToString(initialSymbol, enclosingDeclaration, meaning),
	                                errorModuleName: symbol !== initialSymbol ? symbolToString(symbol, enclosingDeclaration, 1536 /* Namespace */) : undefined
	                            };
	                        }
	                        return hasAccessibleDeclarations;
	                    }
	                    // If we haven't got the accessible symbol, it doesn't mean the symbol is actually inaccessible.
	                    // It could be a qualified symbol and hence verify the path
	                    // e.g.:
	                    // module m {
	                    //     export class c {
	                    //     }
	                    // }
	                    // const x: typeof m.c
	                    // In the above example when we start with checking if typeof m.c symbol is accessible,
	                    // we are going to see if c can be accessed in scope directly.
	                    // But it can't, hence the accessible is going to be undefined, but that doesn't mean m.c is inaccessible
	                    // It is accessible if the parent m is accessible because then m.c can be accessed through qualification
	                    meaningToLook = getQualifiedLeftMeaning(meaning);
	                    symbol = getParentOfSymbol(symbol);
	                }
	                // This could be a symbol that is not exported in the external module
	                // or it could be a symbol from different external module that is not aliased and hence cannot be named
	                var symbolExternalModule = ts.forEach(initialSymbol.declarations, getExternalModuleContainer);
	                if (symbolExternalModule) {
	                    var enclosingExternalModule = getExternalModuleContainer(enclosingDeclaration);
	                    if (symbolExternalModule !== enclosingExternalModule) {
	                        // name from different external module that is not visible
	                        return {
	                            accessibility: 2 /* CannotBeNamed */,
	                            errorSymbolName: symbolToString(initialSymbol, enclosingDeclaration, meaning),
	                            errorModuleName: symbolToString(symbolExternalModule)
	                        };
	                    }
	                }
	                // Just a local name that is not accessible
	                return {
	                    accessibility: 1 /* NotAccessible */,
	                    errorSymbolName: symbolToString(initialSymbol, enclosingDeclaration, meaning)
	                };
	            }
	            return { accessibility: 0 /* Accessible */ };
	            function getExternalModuleContainer(declaration) {
	                for (; declaration; declaration = declaration.parent) {
	                    if (hasExternalModuleSymbol(declaration)) {
	                        return getSymbolOfNode(declaration);
	                    }
	                }
	            }
	        }
	        function hasExternalModuleSymbol(declaration) {
	            return ts.isAmbientModule(declaration) || (declaration.kind === 251 /* SourceFile */ && ts.isExternalOrCommonJsModule(declaration));
	        }
	        function hasVisibleDeclarations(symbol) {
	            var aliasesToMakeVisible;
	            if (ts.forEach(symbol.declarations, function (declaration) { return !getIsDeclarationVisible(declaration); })) {
	                return undefined;
	            }
	            return { accessibility: 0 /* Accessible */, aliasesToMakeVisible: aliasesToMakeVisible };
	            function getIsDeclarationVisible(declaration) {
	                if (!isDeclarationVisible(declaration)) {
	                    // Mark the unexported alias as visible if its parent is visible
	                    // because these kind of aliases can be used to name types in declaration file
	                    var anyImportSyntax = getAnyImportSyntax(declaration);
	                    if (anyImportSyntax &&
	                        !(anyImportSyntax.flags & 2 /* Export */) &&
	                        isDeclarationVisible(anyImportSyntax.parent)) {
	                        getNodeLinks(declaration).isVisible = true;
	                        if (aliasesToMakeVisible) {
	                            if (!ts.contains(aliasesToMakeVisible, anyImportSyntax)) {
	                                aliasesToMakeVisible.push(anyImportSyntax);
	                            }
	                        }
	                        else {
	                            aliasesToMakeVisible = [anyImportSyntax];
	                        }
	                        return true;
	                    }
	                    // Declaration is not visible
	                    return false;
	                }
	                return true;
	            }
	        }
	        function isEntityNameVisible(entityName, enclosingDeclaration) {
	            // get symbol of the first identifier of the entityName
	            var meaning;
	            if (entityName.parent.kind === 155 /* TypeQuery */) {
	                // Typeof value
	                meaning = 107455 /* Value */ | 1048576 /* ExportValue */;
	            }
	            else if (entityName.kind === 136 /* QualifiedName */ || entityName.kind === 169 /* PropertyAccessExpression */ ||
	                entityName.parent.kind === 224 /* ImportEqualsDeclaration */) {
	                // Left identifier from type reference or TypeAlias
	                // Entity name of the import declaration
	                meaning = 1536 /* Namespace */;
	            }
	            else {
	                // Type Reference or TypeAlias entity = Identifier
	                meaning = 793056 /* Type */;
	            }
	            var firstIdentifier = getFirstIdentifier(entityName);
	            var symbol = resolveName(enclosingDeclaration, firstIdentifier.text, meaning, /*nodeNotFoundErrorMessage*/ undefined, /*nameArg*/ undefined);
	            // Verify if the symbol is accessible
	            return (symbol && hasVisibleDeclarations(symbol)) || {
	                accessibility: 1 /* NotAccessible */,
	                errorSymbolName: ts.getTextOfNode(firstIdentifier),
	                errorNode: firstIdentifier
	            };
	        }
	        function writeKeyword(writer, kind) {
	            writer.writeKeyword(ts.tokenToString(kind));
	        }
	        function writePunctuation(writer, kind) {
	            writer.writePunctuation(ts.tokenToString(kind));
	        }
	        function writeSpace(writer) {
	            writer.writeSpace(" ");
	        }
	        function symbolToString(symbol, enclosingDeclaration, meaning) {
	            var writer = ts.getSingleLineStringWriter();
	            getSymbolDisplayBuilder().buildSymbolDisplay(symbol, writer, enclosingDeclaration, meaning);
	            var result = writer.string();
	            ts.releaseStringWriter(writer);
	            return result;
	        }
	        function signatureToString(signature, enclosingDeclaration, flags, kind) {
	            var writer = ts.getSingleLineStringWriter();
	            getSymbolDisplayBuilder().buildSignatureDisplay(signature, writer, enclosingDeclaration, flags, kind);
	            var result = writer.string();
	            ts.releaseStringWriter(writer);
	            return result;
	        }
	        function typeToString(type, enclosingDeclaration, flags) {
	            var writer = ts.getSingleLineStringWriter();
	            getSymbolDisplayBuilder().buildTypeDisplay(type, writer, enclosingDeclaration, flags);
	            var result = writer.string();
	            ts.releaseStringWriter(writer);
	            var maxLength = compilerOptions.noErrorTruncation || flags & 4 /* NoTruncation */ ? undefined : 100;
	            if (maxLength && result.length >= maxLength) {
	                result = result.substr(0, maxLength - "...".length) + "...";
	            }
	            return result;
	        }
	        function typePredicateToString(typePredicate, enclosingDeclaration, flags) {
	            var writer = ts.getSingleLineStringWriter();
	            getSymbolDisplayBuilder().buildTypePredicateDisplay(typePredicate, writer, enclosingDeclaration, flags);
	            var result = writer.string();
	            ts.releaseStringWriter(writer);
	            return result;
	        }
	        function getTypeAliasForTypeLiteral(type) {
	            if (type.symbol && type.symbol.flags & 2048 /* TypeLiteral */) {
	                var node = type.symbol.declarations[0].parent;
	                while (node.kind === 161 /* ParenthesizedType */) {
	                    node = node.parent;
	                }
	                if (node.kind === 219 /* TypeAliasDeclaration */) {
	                    return getSymbolOfNode(node);
	                }
	            }
	            return undefined;
	        }
	        function isTopLevelInExternalModuleAugmentation(node) {
	            return node && node.parent &&
	                node.parent.kind === 222 /* ModuleBlock */ &&
	                ts.isExternalModuleAugmentation(node.parent.parent);
	        }
	        function getSymbolDisplayBuilder() {
	            function getNameOfSymbol(symbol) {
	                if (symbol.declarations && symbol.declarations.length) {
	                    var declaration = symbol.declarations[0];
	                    if (declaration.name) {
	                        return ts.declarationNameToString(declaration.name);
	                    }
	                    switch (declaration.kind) {
	                        case 189 /* ClassExpression */:
	                            return "(Anonymous class)";
	                        case 176 /* FunctionExpression */:
	                        case 177 /* ArrowFunction */:
	                            return "(Anonymous function)";
	                    }
	                }
	                return symbol.name;
	            }
	            /**
	             * Writes only the name of the symbol out to the writer. Uses the original source text
	             * for the name of the symbol if it is available to match how the user inputted the name.
	             */
	            function appendSymbolNameOnly(symbol, writer) {
	                writer.writeSymbol(getNameOfSymbol(symbol), symbol);
	            }
	            /**
	             * Enclosing declaration is optional when we don't want to get qualified name in the enclosing declaration scope
	             * Meaning needs to be specified if the enclosing declaration is given
	             */
	            function buildSymbolDisplay(symbol, writer, enclosingDeclaration, meaning, flags, typeFlags) {
	                var parentSymbol;
	                function appendParentTypeArgumentsAndSymbolName(symbol) {
	                    if (parentSymbol) {
	                        // Write type arguments of instantiated class/interface here
	                        if (flags & 1 /* WriteTypeParametersOrArguments */) {
	                            if (symbol.flags & 16777216 /* Instantiated */) {
	                                buildDisplayForTypeArgumentsAndDelimiters(getTypeParametersOfClassOrInterface(parentSymbol), symbol.mapper, writer, enclosingDeclaration);
	                            }
	                            else {
	                                buildTypeParameterDisplayFromSymbol(parentSymbol, writer, enclosingDeclaration);
	                            }
	                        }
	                        writePunctuation(writer, 21 /* DotToken */);
	                    }
	                    parentSymbol = symbol;
	                    appendSymbolNameOnly(symbol, writer);
	                }
	                // const the writer know we just wrote out a symbol.  The declaration emitter writer uses
	                // this to determine if an import it has previously seen (and not written out) needs
	                // to be written to the file once the walk of the tree is complete.
	                //
	                // NOTE(cyrusn): This approach feels somewhat unfortunate.  A simple pass over the tree
	                // up front (for example, during checking) could determine if we need to emit the imports
	                // and we could then access that data during declaration emit.
	                writer.trackSymbol(symbol, enclosingDeclaration, meaning);
	                function walkSymbol(symbol, meaning) {
	                    if (symbol) {
	                        var accessibleSymbolChain = getAccessibleSymbolChain(symbol, enclosingDeclaration, meaning, !!(flags & 2 /* UseOnlyExternalAliasing */));
	                        if (!accessibleSymbolChain ||
	                            needsQualification(accessibleSymbolChain[0], enclosingDeclaration, accessibleSymbolChain.length === 1 ? meaning : getQualifiedLeftMeaning(meaning))) {
	                            // Go up and add our parent.
	                            walkSymbol(getParentOfSymbol(accessibleSymbolChain ? accessibleSymbolChain[0] : symbol), getQualifiedLeftMeaning(meaning));
	                        }
	                        if (accessibleSymbolChain) {
	                            for (var _i = 0, accessibleSymbolChain_1 = accessibleSymbolChain; _i < accessibleSymbolChain_1.length; _i++) {
	                                var accessibleSymbol = accessibleSymbolChain_1[_i];
	                                appendParentTypeArgumentsAndSymbolName(accessibleSymbol);
	                            }
	                        }
	                        else {
	                            // If we didn't find accessible symbol chain for this symbol, break if this is external module
	                            if (!parentSymbol && ts.forEach(symbol.declarations, hasExternalModuleSymbol)) {
	                                return;
	                            }
	                            // if this is anonymous type break
	                            if (symbol.flags & 2048 /* TypeLiteral */ || symbol.flags & 4096 /* ObjectLiteral */) {
	                                return;
	                            }
	                            appendParentTypeArgumentsAndSymbolName(symbol);
	                        }
	                    }
	                }
	                // Get qualified name if the symbol is not a type parameter
	                // and there is an enclosing declaration or we specifically
	                // asked for it
	                var isTypeParameter = symbol.flags & 262144 /* TypeParameter */;
	                var typeFormatFlag = 128 /* UseFullyQualifiedType */ & typeFlags;
	                if (!isTypeParameter && (enclosingDeclaration || typeFormatFlag)) {
	                    walkSymbol(symbol, meaning);
	                    return;
	                }
	                return appendParentTypeArgumentsAndSymbolName(symbol);
	            }
	            function buildTypeDisplay(type, writer, enclosingDeclaration, globalFlags, symbolStack) {
	                var globalFlagsToPass = globalFlags & 16 /* WriteOwnNameForAnyLike */;
	                var inObjectTypeLiteral = false;
	                return writeType(type, globalFlags);
	                function writeType(type, flags) {
	                    // Write undefined/null type as any
	                    if (type.flags & 16777343 /* Intrinsic */) {
	                        // Special handling for unknown / resolving types, they should show up as any and not unknown or __resolving
	                        writer.writeKeyword(!(globalFlags & 16 /* WriteOwnNameForAnyLike */) && isTypeAny(type)
	                            ? "any"
	                            : type.intrinsicName);
	                    }
	                    else if (type.flags & 33554432 /* ThisType */) {
	                        if (inObjectTypeLiteral) {
	                            writer.reportInaccessibleThisError();
	                        }
	                        writer.writeKeyword("this");
	                    }
	                    else if (type.flags & 4096 /* Reference */) {
	                        writeTypeReference(type, flags);
	                    }
	                    else if (type.flags & (1024 /* Class */ | 2048 /* Interface */ | 128 /* Enum */ | 512 /* TypeParameter */)) {
	                        // The specified symbol flags need to be reinterpreted as type flags
	                        buildSymbolDisplay(type.symbol, writer, enclosingDeclaration, 793056 /* Type */, 0 /* None */, flags);
	                    }
	                    else if (type.flags & 8192 /* Tuple */) {
	                        writeTupleType(type);
	                    }
	                    else if (type.flags & 49152 /* UnionOrIntersection */) {
	                        writeUnionOrIntersectionType(type, flags);
	                    }
	                    else if (type.flags & 65536 /* Anonymous */) {
	                        writeAnonymousType(type, flags);
	                    }
	                    else if (type.flags & 256 /* StringLiteral */) {
	                        writer.writeStringLiteral("\"" + ts.escapeString(type.text) + "\"");
	                    }
	                    else {
	                        // Should never get here
	                        // { ... }
	                        writePunctuation(writer, 15 /* OpenBraceToken */);
	                        writeSpace(writer);
	                        writePunctuation(writer, 22 /* DotDotDotToken */);
	                        writeSpace(writer);
	                        writePunctuation(writer, 16 /* CloseBraceToken */);
	                    }
	                }
	                function writeTypeList(types, delimiter) {
	                    for (var i = 0; i < types.length; i++) {
	                        if (i > 0) {
	                            if (delimiter !== 24 /* CommaToken */) {
	                                writeSpace(writer);
	                            }
	                            writePunctuation(writer, delimiter);
	                            writeSpace(writer);
	                        }
	                        writeType(types[i], delimiter === 24 /* CommaToken */ ? 0 /* None */ : 64 /* InElementType */);
	                    }
	                }
	                function writeSymbolTypeReference(symbol, typeArguments, pos, end, flags) {
	                    // Unnamed function expressions and arrow functions have reserved names that we don't want to display
	                    if (symbol.flags & 32 /* Class */ || !isReservedMemberName(symbol.name)) {
	                        buildSymbolDisplay(symbol, writer, enclosingDeclaration, 793056 /* Type */, 0 /* None */, flags);
	                    }
	                    if (pos < end) {
	                        writePunctuation(writer, 25 /* LessThanToken */);
	                        writeType(typeArguments[pos], 0 /* None */);
	                        pos++;
	                        while (pos < end) {
	                            writePunctuation(writer, 24 /* CommaToken */);
	                            writeSpace(writer);
	                            writeType(typeArguments[pos], 0 /* None */);
	                            pos++;
	                        }
	                        writePunctuation(writer, 27 /* GreaterThanToken */);
	                    }
	                }
	                function writeTypeReference(type, flags) {
	                    var typeArguments = type.typeArguments || emptyArray;
	                    if (type.target === globalArrayType && !(flags & 1 /* WriteArrayAsGenericType */)) {
	                        writeType(typeArguments[0], 64 /* InElementType */);
	                        writePunctuation(writer, 19 /* OpenBracketToken */);
	                        writePunctuation(writer, 20 /* CloseBracketToken */);
	                    }
	                    else {
	                        // Write the type reference in the format f<A>.g<B>.C<X, Y> where A and B are type arguments
	                        // for outer type parameters, and f and g are the respective declaring containers of those
	                        // type parameters.
	                        var outerTypeParameters = type.target.outerTypeParameters;
	                        var i = 0;
	                        if (outerTypeParameters) {
	                            var length_1 = outerTypeParameters.length;
	                            while (i < length_1) {
	                                // Find group of type arguments for type parameters with the same declaring container.
	                                var start = i;
	                                var parent_4 = getParentSymbolOfTypeParameter(outerTypeParameters[i]);
	                                do {
	                                    i++;
	                                } while (i < length_1 && getParentSymbolOfTypeParameter(outerTypeParameters[i]) === parent_4);
	                                // When type parameters are their own type arguments for the whole group (i.e. we have
	                                // the default outer type arguments), we don't show the group.
	                                if (!ts.rangeEquals(outerTypeParameters, typeArguments, start, i)) {
	                                    writeSymbolTypeReference(parent_4, typeArguments, start, i, flags);
	                                    writePunctuation(writer, 21 /* DotToken */);
	                                }
	                            }
	                        }
	                        var typeParameterCount = (type.target.typeParameters || emptyArray).length;
	                        writeSymbolTypeReference(type.symbol, typeArguments, i, typeParameterCount, flags);
	                    }
	                }
	                function writeTupleType(type) {
	                    writePunctuation(writer, 19 /* OpenBracketToken */);
	                    writeTypeList(type.elementTypes, 24 /* CommaToken */);
	                    writePunctuation(writer, 20 /* CloseBracketToken */);
	                }
	                function writeUnionOrIntersectionType(type, flags) {
	                    if (flags & 64 /* InElementType */) {
	                        writePunctuation(writer, 17 /* OpenParenToken */);
	                    }
	                    writeTypeList(type.types, type.flags & 16384 /* Union */ ? 47 /* BarToken */ : 46 /* AmpersandToken */);
	                    if (flags & 64 /* InElementType */) {
	                        writePunctuation(writer, 18 /* CloseParenToken */);
	                    }
	                }
	                function writeAnonymousType(type, flags) {
	                    var symbol = type.symbol;
	                    if (symbol) {
	                        // Always use 'typeof T' for type of class, enum, and module objects
	                        if (symbol.flags & (32 /* Class */ | 384 /* Enum */ | 512 /* ValueModule */)) {
	                            writeTypeofSymbol(type, flags);
	                        }
	                        else if (shouldWriteTypeOfFunctionSymbol()) {
	                            writeTypeofSymbol(type, flags);
	                        }
	                        else if (ts.contains(symbolStack, symbol)) {
	                            // If type is an anonymous type literal in a type alias declaration, use type alias name
	                            var typeAlias = getTypeAliasForTypeLiteral(type);
	                            if (typeAlias) {
	                                // The specified symbol flags need to be reinterpreted as type flags
	                                buildSymbolDisplay(typeAlias, writer, enclosingDeclaration, 793056 /* Type */, 0 /* None */, flags);
	                            }
	                            else {
	                                // Recursive usage, use any
	                                writeKeyword(writer, 117 /* AnyKeyword */);
	                            }
	                        }
	                        else {
	                            // Since instantiations of the same anonymous type have the same symbol, tracking symbols instead
	                            // of types allows us to catch circular references to instantiations of the same anonymous type
	                            if (!symbolStack) {
	                                symbolStack = [];
	                            }
	                            symbolStack.push(symbol);
	                            writeLiteralType(type, flags);
	                            symbolStack.pop();
	                        }
	                    }
	                    else {
	                        // Anonymous types with no symbol are never circular
	                        writeLiteralType(type, flags);
	                    }
	                    function shouldWriteTypeOfFunctionSymbol() {
	                        var isStaticMethodSymbol = !!(symbol.flags & 8192 /* Method */ &&
	                            ts.forEach(symbol.declarations, function (declaration) { return declaration.flags & 64 /* Static */; }));
	                        var isNonLocalFunctionSymbol = !!(symbol.flags & 16 /* Function */) &&
	                            (symbol.parent ||
	                                ts.forEach(symbol.declarations, function (declaration) {
	                                    return declaration.parent.kind === 251 /* SourceFile */ || declaration.parent.kind === 222 /* ModuleBlock */;
	                                }));
	                        if (isStaticMethodSymbol || isNonLocalFunctionSymbol) {
	                            // typeof is allowed only for static/non local functions
	                            return !!(flags & 2 /* UseTypeOfFunction */) ||
	                                (ts.contains(symbolStack, symbol)); // it is type of the symbol uses itself recursively
	                        }
	                    }
	                }
	                function writeTypeofSymbol(type, typeFormatFlags) {
	                    writeKeyword(writer, 101 /* TypeOfKeyword */);
	                    writeSpace(writer);
	                    buildSymbolDisplay(type.symbol, writer, enclosingDeclaration, 107455 /* Value */, 0 /* None */, typeFormatFlags);
	                }
	                function getIndexerParameterName(type, indexKind, fallbackName) {
	                    var declaration = getIndexDeclarationOfSymbol(type.symbol, indexKind);
	                    if (!declaration) {
	                        // declaration might not be found if indexer was added from the contextual type.
	                        // in this case use fallback name
	                        return fallbackName;
	                    }
	                    ts.Debug.assert(declaration.parameters.length !== 0);
	                    return ts.declarationNameToString(declaration.parameters[0].name);
	                }
	                function writeLiteralType(type, flags) {
	                    var resolved = resolveStructuredTypeMembers(type);
	                    if (!resolved.properties.length && !resolved.stringIndexType && !resolved.numberIndexType) {
	                        if (!resolved.callSignatures.length && !resolved.constructSignatures.length) {
	                            writePunctuation(writer, 15 /* OpenBraceToken */);
	                            writePunctuation(writer, 16 /* CloseBraceToken */);
	                            return;
	                        }
	                        if (resolved.callSignatures.length === 1 && !resolved.constructSignatures.length) {
	                            if (flags & 64 /* InElementType */) {
	                                writePunctuation(writer, 17 /* OpenParenToken */);
	                            }
	                            buildSignatureDisplay(resolved.callSignatures[0], writer, enclosingDeclaration, globalFlagsToPass | 8 /* WriteArrowStyleSignature */, /*kind*/ undefined, symbolStack);
	                            if (flags & 64 /* InElementType */) {
	                                writePunctuation(writer, 18 /* CloseParenToken */);
	                            }
	                            return;
	                        }
	                        if (resolved.constructSignatures.length === 1 && !resolved.callSignatures.length) {
	                            if (flags & 64 /* InElementType */) {
	                                writePunctuation(writer, 17 /* OpenParenToken */);
	                            }
	                            writeKeyword(writer, 92 /* NewKeyword */);
	                            writeSpace(writer);
	                            buildSignatureDisplay(resolved.constructSignatures[0], writer, enclosingDeclaration, globalFlagsToPass | 8 /* WriteArrowStyleSignature */, /*kind*/ undefined, symbolStack);
	                            if (flags & 64 /* InElementType */) {
	                                writePunctuation(writer, 18 /* CloseParenToken */);
	                            }
	                            return;
	                        }
	                    }
	                    var saveInObjectTypeLiteral = inObjectTypeLiteral;
	                    inObjectTypeLiteral = true;
	                    writePunctuation(writer, 15 /* OpenBraceToken */);
	                    writer.writeLine();
	                    writer.increaseIndent();
	                    for (var _i = 0, _a = resolved.callSignatures; _i < _a.length; _i++) {
	                        var signature = _a[_i];
	                        buildSignatureDisplay(signature, writer, enclosingDeclaration, globalFlagsToPass, /*kind*/ undefined, symbolStack);
	                        writePunctuation(writer, 23 /* SemicolonToken */);
	                        writer.writeLine();
	                    }
	                    for (var _b = 0, _c = resolved.constructSignatures; _b < _c.length; _b++) {
	                        var signature = _c[_b];
	                        buildSignatureDisplay(signature, writer, enclosingDeclaration, globalFlagsToPass, 1 /* Construct */, symbolStack);
	                        writePunctuation(writer, 23 /* SemicolonToken */);
	                        writer.writeLine();
	                    }
	                    if (resolved.stringIndexType) {
	                        // [x: string]:
	                        writePunctuation(writer, 19 /* OpenBracketToken */);
	                        writer.writeParameter(getIndexerParameterName(resolved, 0 /* String */, /*fallbackName*/ "x"));
	                        writePunctuation(writer, 54 /* ColonToken */);
	                        writeSpace(writer);
	                        writeKeyword(writer, 130 /* StringKeyword */);
	                        writePunctuation(writer, 20 /* CloseBracketToken */);
	                        writePunctuation(writer, 54 /* ColonToken */);
	                        writeSpace(writer);
	                        writeType(resolved.stringIndexType, 0 /* None */);
	                        writePunctuation(writer, 23 /* SemicolonToken */);
	                        writer.writeLine();
	                    }
	                    if (resolved.numberIndexType) {
	                        // [x: number]:
	                        writePunctuation(writer, 19 /* OpenBracketToken */);
	                        writer.writeParameter(getIndexerParameterName(resolved, 1 /* Number */, /*fallbackName*/ "x"));
	                        writePunctuation(writer, 54 /* ColonToken */);
	                        writeSpace(writer);
	                        writeKeyword(writer, 128 /* NumberKeyword */);
	                        writePunctuation(writer, 20 /* CloseBracketToken */);
	                        writePunctuation(writer, 54 /* ColonToken */);
	                        writeSpace(writer);
	                        writeType(resolved.numberIndexType, 0 /* None */);
	                        writePunctuation(writer, 23 /* SemicolonToken */);
	                        writer.writeLine();
	                    }
	                    for (var _d = 0, _e = resolved.properties; _d < _e.length; _d++) {
	                        var p = _e[_d];
	                        var t = getTypeOfSymbol(p);
	                        if (p.flags & (16 /* Function */ | 8192 /* Method */) && !getPropertiesOfObjectType(t).length) {
	                            var signatures = getSignaturesOfType(t, 0 /* Call */);
	                            for (var _f = 0, signatures_1 = signatures; _f < signatures_1.length; _f++) {
	                                var signature = signatures_1[_f];
	                                buildSymbolDisplay(p, writer);
	                                if (p.flags & 536870912 /* Optional */) {
	                                    writePunctuation(writer, 53 /* QuestionToken */);
	                                }
	                                buildSignatureDisplay(signature, writer, enclosingDeclaration, globalFlagsToPass, /*kind*/ undefined, symbolStack);
	                                writePunctuation(writer, 23 /* SemicolonToken */);
	                                writer.writeLine();
	                            }
	                        }
	                        else {
	                            buildSymbolDisplay(p, writer);
	                            if (p.flags & 536870912 /* Optional */) {
	                                writePunctuation(writer, 53 /* QuestionToken */);
	                            }
	                            writePunctuation(writer, 54 /* ColonToken */);
	                            writeSpace(writer);
	                            writeType(t, 0 /* None */);
	                            writePunctuation(writer, 23 /* SemicolonToken */);
	                            writer.writeLine();
	                        }
	                    }
	                    writer.decreaseIndent();
	                    writePunctuation(writer, 16 /* CloseBraceToken */);
	                    inObjectTypeLiteral = saveInObjectTypeLiteral;
	                }
	            }
	            function buildTypeParameterDisplayFromSymbol(symbol, writer, enclosingDeclaration, flags) {
	                var targetSymbol = getTargetSymbol(symbol);
	                if (targetSymbol.flags & 32 /* Class */ || targetSymbol.flags & 64 /* Interface */ || targetSymbol.flags & 524288 /* TypeAlias */) {
	                    buildDisplayForTypeParametersAndDelimiters(getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(symbol), writer, enclosingDeclaration, flags);
	                }
	            }
	            function buildTypeParameterDisplay(tp, writer, enclosingDeclaration, flags, symbolStack) {
	                appendSymbolNameOnly(tp.symbol, writer);
	                var constraint = getConstraintOfTypeParameter(tp);
	                if (constraint) {
	                    writeSpace(writer);
	                    writeKeyword(writer, 83 /* ExtendsKeyword */);
	                    writeSpace(writer);
	                    buildTypeDisplay(constraint, writer, enclosingDeclaration, flags, symbolStack);
	                }
	            }
	            function buildParameterDisplay(p, writer, enclosingDeclaration, flags, symbolStack) {
	                var parameterNode = p.valueDeclaration;
	                if (ts.isRestParameter(parameterNode)) {
	                    writePunctuation(writer, 22 /* DotDotDotToken */);
	                }
	                appendSymbolNameOnly(p, writer);
	                if (isOptionalParameter(parameterNode)) {
	                    writePunctuation(writer, 53 /* QuestionToken */);
	                }
	                writePunctuation(writer, 54 /* ColonToken */);
	                writeSpace(writer);
	                buildTypeDisplay(getTypeOfSymbol(p), writer, enclosingDeclaration, flags, symbolStack);
	            }
	            function buildDisplayForTypeParametersAndDelimiters(typeParameters, writer, enclosingDeclaration, flags, symbolStack) {
	                if (typeParameters && typeParameters.length) {
	                    writePunctuation(writer, 25 /* LessThanToken */);
	                    for (var i = 0; i < typeParameters.length; i++) {
	                        if (i > 0) {
	                            writePunctuation(writer, 24 /* CommaToken */);
	                            writeSpace(writer);
	                        }
	                        buildTypeParameterDisplay(typeParameters[i], writer, enclosingDeclaration, flags, symbolStack);
	                    }
	                    writePunctuation(writer, 27 /* GreaterThanToken */);
	                }
	            }
	            function buildDisplayForTypeArgumentsAndDelimiters(typeParameters, mapper, writer, enclosingDeclaration, flags, symbolStack) {
	                if (typeParameters && typeParameters.length) {
	                    writePunctuation(writer, 25 /* LessThanToken */);
	                    for (var i = 0; i < typeParameters.length; i++) {
	                        if (i > 0) {
	                            writePunctuation(writer, 24 /* CommaToken */);
	                            writeSpace(writer);
	                        }
	                        buildTypeDisplay(mapper(typeParameters[i]), writer, enclosingDeclaration, 0 /* None */);
	                    }
	                    writePunctuation(writer, 27 /* GreaterThanToken */);
	                }
	            }
	            function buildDisplayForParametersAndDelimiters(parameters, writer, enclosingDeclaration, flags, symbolStack) {
	                writePunctuation(writer, 17 /* OpenParenToken */);
	                for (var i = 0; i < parameters.length; i++) {
	                    if (i > 0) {
	                        writePunctuation(writer, 24 /* CommaToken */);
	                        writeSpace(writer);
	                    }
	                    buildParameterDisplay(parameters[i], writer, enclosingDeclaration, flags, symbolStack);
	                }
	                writePunctuation(writer, 18 /* CloseParenToken */);
	            }
	            function buildTypePredicateDisplay(predicate, writer, enclosingDeclaration, flags, symbolStack) {
	                if (ts.isIdentifierTypePredicate(predicate)) {
	                    writer.writeParameter(predicate.parameterName);
	                }
	                else {
	                    writeKeyword(writer, 97 /* ThisKeyword */);
	                }
	                writeSpace(writer);
	                writeKeyword(writer, 124 /* IsKeyword */);
	                writeSpace(writer);
	                buildTypeDisplay(predicate.type, writer, enclosingDeclaration, flags, symbolStack);
	            }
	            function buildReturnTypeDisplay(signature, writer, enclosingDeclaration, flags, symbolStack) {
	                if (flags & 8 /* WriteArrowStyleSignature */) {
	                    writeSpace(writer);
	                    writePunctuation(writer, 34 /* EqualsGreaterThanToken */);
	                }
	                else {
	                    writePunctuation(writer, 54 /* ColonToken */);
	                }
	                writeSpace(writer);
	                if (signature.typePredicate) {
	                    buildTypePredicateDisplay(signature.typePredicate, writer, enclosingDeclaration, flags, symbolStack);
	                }
	                else {
	                    var returnType = getReturnTypeOfSignature(signature);
	                    buildTypeDisplay(returnType, writer, enclosingDeclaration, flags, symbolStack);
	                }
	            }
	            function buildSignatureDisplay(signature, writer, enclosingDeclaration, flags, kind, symbolStack) {
	                if (kind === 1 /* Construct */) {
	                    writeKeyword(writer, 92 /* NewKeyword */);
	                    writeSpace(writer);
	                }
	                if (signature.target && (flags & 32 /* WriteTypeArgumentsOfSignature */)) {
	                    // Instantiated signature, write type arguments instead
	                    // This is achieved by passing in the mapper separately
	                    buildDisplayForTypeArgumentsAndDelimiters(signature.target.typeParameters, signature.mapper, writer, enclosingDeclaration);
	                }
	                else {
	                    buildDisplayForTypeParametersAndDelimiters(signature.typeParameters, writer, enclosingDeclaration, flags, symbolStack);
	                }
	                buildDisplayForParametersAndDelimiters(signature.parameters, writer, enclosingDeclaration, flags, symbolStack);
	                buildReturnTypeDisplay(signature, writer, enclosingDeclaration, flags, symbolStack);
	            }
	            return _displayBuilder || (_displayBuilder = {
	                buildSymbolDisplay: buildSymbolDisplay,
	                buildTypeDisplay: buildTypeDisplay,
	                buildTypeParameterDisplay: buildTypeParameterDisplay,
	                buildTypePredicateDisplay: buildTypePredicateDisplay,
	                buildParameterDisplay: buildParameterDisplay,
	                buildDisplayForParametersAndDelimiters: buildDisplayForParametersAndDelimiters,
	                buildDisplayForTypeParametersAndDelimiters: buildDisplayForTypeParametersAndDelimiters,
	                buildTypeParameterDisplayFromSymbol: buildTypeParameterDisplayFromSymbol,
	                buildSignatureDisplay: buildSignatureDisplay,
	                buildReturnTypeDisplay: buildReturnTypeDisplay
	            });
	        }
	        function isDeclarationVisible(node) {
	            if (node) {
	                var links = getNodeLinks(node);
	                if (links.isVisible === undefined) {
	                    links.isVisible = !!determineIfDeclarationIsVisible();
	                }
	                return links.isVisible;
	            }
	            return false;
	            function determineIfDeclarationIsVisible() {
	                switch (node.kind) {
	                    case 166 /* BindingElement */:
	                        return isDeclarationVisible(node.parent.parent);
	                    case 214 /* VariableDeclaration */:
	                        if (ts.isBindingPattern(node.name) &&
	                            !node.name.elements.length) {
	                            // If the binding pattern is empty, this variable declaration is not visible
	                            return false;
	                        }
	                    // Otherwise fall through
	                    case 221 /* ModuleDeclaration */:
	                    case 217 /* ClassDeclaration */:
	                    case 218 /* InterfaceDeclaration */:
	                    case 219 /* TypeAliasDeclaration */:
	                    case 216 /* FunctionDeclaration */:
	                    case 220 /* EnumDeclaration */:
	                    case 224 /* ImportEqualsDeclaration */:
	                        // external module augmentation is always visible
	                        if (ts.isExternalModuleAugmentation(node)) {
	                            return true;
	                        }
	                        var parent_5 = getDeclarationContainer(node);
	                        // If the node is not exported or it is not ambient module element (except import declaration)
	                        if (!(ts.getCombinedNodeFlags(node) & 2 /* Export */) &&
	                            !(node.kind !== 224 /* ImportEqualsDeclaration */ && parent_5.kind !== 251 /* SourceFile */ && ts.isInAmbientContext(parent_5))) {
	                            return isGlobalSourceFile(parent_5);
	                        }
	                        // Exported members/ambient module elements (exception import declaration) are visible if parent is visible
	                        return isDeclarationVisible(parent_5);
	                    case 142 /* PropertyDeclaration */:
	                    case 141 /* PropertySignature */:
	                    case 146 /* GetAccessor */:
	                    case 147 /* SetAccessor */:
	                    case 144 /* MethodDeclaration */:
	                    case 143 /* MethodSignature */:
	                        if (node.flags & (16 /* Private */ | 32 /* Protected */)) {
	                            // Private/protected properties/methods are not visible
	                            return false;
	                        }
	                    // Public properties/methods are visible if its parents are visible, so const it fall into next case statement
	                    case 145 /* Constructor */:
	                    case 149 /* ConstructSignature */:
	                    case 148 /* CallSignature */:
	                    case 150 /* IndexSignature */:
	                    case 139 /* Parameter */:
	                    case 222 /* ModuleBlock */:
	                    case 153 /* FunctionType */:
	                    case 154 /* ConstructorType */:
	                    case 156 /* TypeLiteral */:
	                    case 152 /* TypeReference */:
	                    case 157 /* ArrayType */:
	                    case 158 /* TupleType */:
	                    case 159 /* UnionType */:
	                    case 160 /* IntersectionType */:
	                    case 161 /* ParenthesizedType */:
	                        return isDeclarationVisible(node.parent);
	                    // Default binding, import specifier and namespace import is visible
	                    // only on demand so by default it is not visible
	                    case 226 /* ImportClause */:
	                    case 227 /* NamespaceImport */:
	                    case 229 /* ImportSpecifier */:
	                        return false;
	                    // Type parameters are always visible
	                    case 138 /* TypeParameter */:
	                    // Source file is always visible
	                    case 251 /* SourceFile */:
	                        return true;
	                    // Export assignments do not create name bindings outside the module
	                    case 230 /* ExportAssignment */:
	                        return false;
	                    default:
	                        ts.Debug.fail("isDeclarationVisible unknown: SyntaxKind: " + node.kind);
	                }
	            }
	        }
	        function collectLinkedAliases(node) {
	            var exportSymbol;
	            if (node.parent && node.parent.kind === 230 /* ExportAssignment */) {
	                exportSymbol = resolveName(node.parent, node.text, 107455 /* Value */ | 793056 /* Type */ | 1536 /* Namespace */ | 8388608 /* Alias */, ts.Diagnostics.Cannot_find_name_0, node);
	            }
	            else if (node.parent.kind === 233 /* ExportSpecifier */) {
	                var exportSpecifier = node.parent;
	                exportSymbol = exportSpecifier.parent.parent.moduleSpecifier ?
	                    getExternalModuleMember(exportSpecifier.parent.parent, exportSpecifier) :
	                    resolveEntityName(exportSpecifier.propertyName || exportSpecifier.name, 107455 /* Value */ | 793056 /* Type */ | 1536 /* Namespace */ | 8388608 /* Alias */);
	            }
	            var result = [];
	            if (exportSymbol) {
	                buildVisibleNodeList(exportSymbol.declarations);
	            }
	            return result;
	            function buildVisibleNodeList(declarations) {
	                ts.forEach(declarations, function (declaration) {
	                    getNodeLinks(declaration).isVisible = true;
	                    var resultNode = getAnyImportSyntax(declaration) || declaration;
	                    if (!ts.contains(result, resultNode)) {
	                        result.push(resultNode);
	                    }
	                    if (ts.isInternalModuleImportEqualsDeclaration(declaration)) {
	                        // Add the referenced top container visible
	                        var internalModuleReference = declaration.moduleReference;
	                        var firstIdentifier = getFirstIdentifier(internalModuleReference);
	                        var importSymbol = resolveName(declaration, firstIdentifier.text, 107455 /* Value */ | 793056 /* Type */ | 1536 /* Namespace */, ts.Diagnostics.Cannot_find_name_0, firstIdentifier);
	                        if (importSymbol) {
	                            buildVisibleNodeList(importSymbol.declarations);
	                        }
	                    }
	                });
	            }
	        }
	        /**
	         * Push an entry on the type resolution stack. If an entry with the given target and the given property name
	         * is already on the stack, and no entries in between already have a type, then a circularity has occurred.
	         * In this case, the result values of the existing entry and all entries pushed after it are changed to false,
	         * and the value false is returned. Otherwise, the new entry is just pushed onto the stack, and true is returned.
	         * In order to see if the same query has already been done before, the target object and the propertyName both
	         * must match the one passed in.
	         *
	         * @param target The symbol, type, or signature whose type is being queried
	         * @param propertyName The property name that should be used to query the target for its type
	         */
	        function pushTypeResolution(target, propertyName) {
	            var resolutionCycleStartIndex = findResolutionCycleStartIndex(target, propertyName);
	            if (resolutionCycleStartIndex >= 0) {
	                // A cycle was found
	                var length_2 = resolutionTargets.length;
	                for (var i = resolutionCycleStartIndex; i < length_2; i++) {
	                    resolutionResults[i] = false;
	                }
	                return false;
	            }
	            resolutionTargets.push(target);
	            resolutionResults.push(/*items*/ true);
	            resolutionPropertyNames.push(propertyName);
	            return true;
	        }
	        function findResolutionCycleStartIndex(target, propertyName) {
	            for (var i = resolutionTargets.length - 1; i >= 0; i--) {
	                if (hasType(resolutionTargets[i], resolutionPropertyNames[i])) {
	                    return -1;
	                }
	                if (resolutionTargets[i] === target && resolutionPropertyNames[i] === propertyName) {
	                    return i;
	                }
	            }
	            return -1;
	        }
	        function hasType(target, propertyName) {
	            if (propertyName === 0 /* Type */) {
	                return getSymbolLinks(target).type;
	            }
	            if (propertyName === 2 /* DeclaredType */) {
	                return getSymbolLinks(target).declaredType;
	            }
	            if (propertyName === 1 /* ResolvedBaseConstructorType */) {
	                ts.Debug.assert(!!(target.flags & 1024 /* Class */));
	                return target.resolvedBaseConstructorType;
	            }
	            if (propertyName === 3 /* ResolvedReturnType */) {
	                return target.resolvedReturnType;
	            }
	            ts.Debug.fail("Unhandled TypeSystemPropertyName " + propertyName);
	        }
	        // Pop an entry from the type resolution stack and return its associated result value. The result value will
	        // be true if no circularities were detected, or false if a circularity was found.
	        function popTypeResolution() {
	            resolutionTargets.pop();
	            resolutionPropertyNames.pop();
	            return resolutionResults.pop();
	        }
	        function getDeclarationContainer(node) {
	            node = ts.getRootDeclaration(node);
	            while (node) {
	                switch (node.kind) {
	                    case 214 /* VariableDeclaration */:
	                    case 215 /* VariableDeclarationList */:
	                    case 229 /* ImportSpecifier */:
	                    case 228 /* NamedImports */:
	                    case 227 /* NamespaceImport */:
	                    case 226 /* ImportClause */:
	                        node = node.parent;
	                        break;
	                    default:
	                        return node.parent;
	                }
	            }
	        }
	        function getTypeOfPrototypeProperty(prototype) {
	            // TypeScript 1.0 spec (April 2014): 8.4
	            // Every class automatically contains a static property member named 'prototype',
	            // the type of which is an instantiation of the class type with type Any supplied as a type argument for each type parameter.
	            // It is an error to explicitly declare a static property member with the name 'prototype'.
	            var classType = getDeclaredTypeOfSymbol(getParentOfSymbol(prototype));
	            return classType.typeParameters ? createTypeReference(classType, ts.map(classType.typeParameters, function (_) { return anyType; })) : classType;
	        }
	        // Return the type of the given property in the given type, or undefined if no such property exists
	        function getTypeOfPropertyOfType(type, name) {
	            var prop = getPropertyOfType(type, name);
	            return prop ? getTypeOfSymbol(prop) : undefined;
	        }
	        function isTypeAny(type) {
	            return type && (type.flags & 1 /* Any */) !== 0;
	        }
	        // Return the type of a binding element parent. We check SymbolLinks first to see if a type has been
	        // assigned by contextual typing.
	        function getTypeForBindingElementParent(node) {
	            var symbol = getSymbolOfNode(node);
	            return symbol && getSymbolLinks(symbol).type || getTypeForVariableLikeDeclaration(node);
	        }
	        function getTextOfPropertyName(name) {
	            switch (name.kind) {
	                case 69 /* Identifier */:
	                    return name.text;
	                case 9 /* StringLiteral */:
	                case 8 /* NumericLiteral */:
	                    return name.text;
	                case 137 /* ComputedPropertyName */:
	                    if (ts.isStringOrNumericLiteral(name.expression.kind)) {
	                        return name.expression.text;
	                    }
	            }
	            return undefined;
	        }
	        function isComputedNonLiteralName(name) {
	            return name.kind === 137 /* ComputedPropertyName */ && !ts.isStringOrNumericLiteral(name.expression.kind);
	        }
	        // Return the inferred type for a binding element
	        function getTypeForBindingElement(declaration) {
	            var pattern = declaration.parent;
	            var parentType = getTypeForBindingElementParent(pattern.parent);
	            // If parent has the unknown (error) type, then so does this binding element
	            if (parentType === unknownType) {
	                return unknownType;
	            }
	            // If no type was specified or inferred for parent, or if the specified or inferred type is any,
	            // infer from the initializer of the binding element if one is present. Otherwise, go with the
	            // undefined or any type of the parent.
	            if (!parentType || isTypeAny(parentType)) {
	                if (declaration.initializer) {
	                    return checkExpressionCached(declaration.initializer);
	                }
	                return parentType;
	            }
	            var type;
	            if (pattern.kind === 164 /* ObjectBindingPattern */) {
	                // Use explicitly specified property name ({ p: xxx } form), or otherwise the implied name ({ p } form)
	                var name_10 = declaration.propertyName || declaration.name;
	                if (isComputedNonLiteralName(name_10)) {
	                    // computed properties with non-literal names are treated as 'any'
	                    return anyType;
	                }
	                // Use type of the specified property, or otherwise, for a numeric name, the type of the numeric index signature,
	                // or otherwise the type of the string index signature.
	                var text = getTextOfPropertyName(name_10);
	                type = getTypeOfPropertyOfType(parentType, text) ||
	                    isNumericLiteralName(text) && getIndexTypeOfType(parentType, 1 /* Number */) ||
	                    getIndexTypeOfType(parentType, 0 /* String */);
	                if (!type) {
	                    error(name_10, ts.Diagnostics.Type_0_has_no_property_1_and_no_string_index_signature, typeToString(parentType), ts.declarationNameToString(name_10));
	                    return unknownType;
	                }
	            }
	            else {
	                // This elementType will be used if the specific property corresponding to this index is not
	                // present (aka the tuple element property). This call also checks that the parentType is in
	                // fact an iterable or array (depending on target language).
	                var elementType = checkIteratedTypeOrElementType(parentType, pattern, /*allowStringInput*/ false);
	                if (!declaration.dotDotDotToken) {
	                    // Use specific property type when parent is a tuple or numeric index type when parent is an array
	                    var propName = "" + ts.indexOf(pattern.elements, declaration);
	                    type = isTupleLikeType(parentType)
	                        ? getTypeOfPropertyOfType(parentType, propName)
	                        : elementType;
	                    if (!type) {
	                        if (isTupleType(parentType)) {
	                            error(declaration, ts.Diagnostics.Tuple_type_0_with_length_1_cannot_be_assigned_to_tuple_with_length_2, typeToString(parentType), parentType.elementTypes.length, pattern.elements.length);
	                        }
	                        else {
	                            error(declaration, ts.Diagnostics.Type_0_has_no_property_1, typeToString(parentType), propName);
	                        }
	                        return unknownType;
	                    }
	                }
	                else {
	                    // Rest element has an array type with the same element type as the parent type
	                    type = createArrayType(elementType);
	                }
	            }
	            return type;
	        }
	        function getTypeForVariableLikeDeclarationFromJSDocComment(declaration) {
	            var jsDocType = getJSDocTypeForVariableLikeDeclarationFromJSDocComment(declaration);
	            if (jsDocType) {
	                return getTypeFromTypeNode(jsDocType);
	            }
	        }
	        function getJSDocTypeForVariableLikeDeclarationFromJSDocComment(declaration) {
	            // First, see if this node has an @type annotation on it directly.
	            var typeTag = ts.getJSDocTypeTag(declaration);
	            if (typeTag && typeTag.typeExpression) {
	                return typeTag.typeExpression.type;
	            }
	            if (declaration.kind === 214 /* VariableDeclaration */ &&
	                declaration.parent.kind === 215 /* VariableDeclarationList */ &&
	                declaration.parent.parent.kind === 196 /* VariableStatement */) {
	                // @type annotation might have been on the variable statement, try that instead.
	                var annotation = ts.getJSDocTypeTag(declaration.parent.parent);
	                if (annotation && annotation.typeExpression) {
	                    return annotation.typeExpression.type;
	                }
	            }
	            else if (declaration.kind === 139 /* Parameter */) {
	                // If it's a parameter, see if the parent has a jsdoc comment with an @param
	                // annotation.
	                var paramTag = ts.getCorrespondingJSDocParameterTag(declaration);
	                if (paramTag && paramTag.typeExpression) {
	                    return paramTag.typeExpression.type;
	                }
	            }
	            return undefined;
	        }
	        // Return the inferred type for a variable, parameter, or property declaration
	        function getTypeForVariableLikeDeclaration(declaration) {
	            if (declaration.parserContextFlags & 32 /* JavaScriptFile */) {
	                // If this is a variable in a JavaScript file, then use the JSDoc type (if it has
	                // one as its type), otherwise fallback to the below standard TS codepaths to
	                // try to figure it out.
	                var type = getTypeForVariableLikeDeclarationFromJSDocComment(declaration);
	                if (type && type !== unknownType) {
	                    return type;
	                }
	            }
	            // A variable declared in a for..in statement is always of type string
	            if (declaration.parent.parent.kind === 203 /* ForInStatement */) {
	                return stringType;
	            }
	            if (declaration.parent.parent.kind === 204 /* ForOfStatement */) {
	                // checkRightHandSideOfForOf will return undefined if the for-of expression type was
	                // missing properties/signatures required to get its iteratedType (like
	                // [Symbol.iterator] or next). This may be because we accessed properties from anyType,
	                // or it may have led to an error inside getElementTypeOfIterable.
	                return checkRightHandSideOfForOf(declaration.parent.parent.expression) || anyType;
	            }
	            if (ts.isBindingPattern(declaration.parent)) {
	                return getTypeForBindingElement(declaration);
	            }
	            // Use type from type annotation if one is present
	            if (declaration.type) {
	                return getTypeFromTypeNode(declaration.type);
	            }
	            if (declaration.kind === 139 /* Parameter */) {
	                var func = declaration.parent;
	                // For a parameter of a set accessor, use the type of the get accessor if one is present
	                if (func.kind === 147 /* SetAccessor */ && !ts.hasDynamicName(func)) {
	                    var getter = ts.getDeclarationOfKind(declaration.parent.symbol, 146 /* GetAccessor */);
	                    if (getter) {
	                        return getReturnTypeOfSignature(getSignatureFromDeclaration(getter));
	                    }
	                }
	                // Use contextual parameter type if one is available
	                var type = getContextuallyTypedParameterType(declaration);
	                if (type) {
	                    return type;
	                }
	            }
	            // Use the type of the initializer expression if one is present
	            if (declaration.initializer) {
	                return checkExpressionCached(declaration.initializer);
	            }
	            // If it is a short-hand property assignment, use the type of the identifier
	            if (declaration.kind === 249 /* ShorthandPropertyAssignment */) {
	                return checkIdentifier(declaration.name);
	            }
	            // If the declaration specifies a binding pattern, use the type implied by the binding pattern
	            if (ts.isBindingPattern(declaration.name)) {
	                return getTypeFromBindingPattern(declaration.name, /*includePatternInType*/ false);
	            }
	            // No type specified and nothing can be inferred
	            return undefined;
	        }
	        // Return the type implied by a binding pattern element. This is the type of the initializer of the element if
	        // one is present. Otherwise, if the element is itself a binding pattern, it is the type implied by the binding
	        // pattern. Otherwise, it is the type any.
	        function getTypeFromBindingElement(element, includePatternInType) {
	            if (element.initializer) {
	                return getWidenedType(checkExpressionCached(element.initializer));
	            }
	            if (ts.isBindingPattern(element.name)) {
	                return getTypeFromBindingPattern(element.name, includePatternInType);
	            }
	            return anyType;
	        }
	        // Return the type implied by an object binding pattern
	        function getTypeFromObjectBindingPattern(pattern, includePatternInType) {
	            var members = {};
	            var hasComputedProperties = false;
	            ts.forEach(pattern.elements, function (e) {
	                var name = e.propertyName || e.name;
	                if (isComputedNonLiteralName(name)) {
	                    // do not include computed properties in the implied type
	                    hasComputedProperties = true;
	                    return;
	                }
	                var text = getTextOfPropertyName(name);
	                var flags = 4 /* Property */ | 67108864 /* Transient */ | (e.initializer ? 536870912 /* Optional */ : 0);
	                var symbol = createSymbol(flags, text);
	                symbol.type = getTypeFromBindingElement(e, includePatternInType);
	                symbol.bindingElement = e;
	                members[symbol.name] = symbol;
	            });
	            var result = createAnonymousType(undefined, members, emptyArray, emptyArray, undefined, undefined);
	            if (includePatternInType) {
	                result.pattern = pattern;
	            }
	            if (hasComputedProperties) {
	                result.flags |= 67108864 /* ObjectLiteralPatternWithComputedProperties */;
	            }
	            return result;
	        }
	        // Return the type implied by an array binding pattern
	        function getTypeFromArrayBindingPattern(pattern, includePatternInType) {
	            var elements = pattern.elements;
	            if (elements.length === 0 || elements[elements.length - 1].dotDotDotToken) {
	                return languageVersion >= 2 /* ES6 */ ? createIterableType(anyType) : anyArrayType;
	            }
	            // If the pattern has at least one element, and no rest element, then it should imply a tuple type.
	            var elementTypes = ts.map(elements, function (e) { return e.kind === 190 /* OmittedExpression */ ? anyType : getTypeFromBindingElement(e, includePatternInType); });
	            if (includePatternInType) {
	                var result = createNewTupleType(elementTypes);
	                result.pattern = pattern;
	                return result;
	            }
	            return createTupleType(elementTypes);
	        }
	        // Return the type implied by a binding pattern. This is the type implied purely by the binding pattern itself
	        // and without regard to its context (i.e. without regard any type annotation or initializer associated with the
	        // declaration in which the binding pattern is contained). For example, the implied type of [x, y] is [any, any]
	        // and the implied type of { x, y: z = 1 } is { x: any; y: number; }. The type implied by a binding pattern is
	        // used as the contextual type of an initializer associated with the binding pattern. Also, for a destructuring
	        // parameter with no type annotation or initializer, the type implied by the binding pattern becomes the type of
	        // the parameter.
	        function getTypeFromBindingPattern(pattern, includePatternInType) {
	            return pattern.kind === 164 /* ObjectBindingPattern */
	                ? getTypeFromObjectBindingPattern(pattern, includePatternInType)
	                : getTypeFromArrayBindingPattern(pattern, includePatternInType);
	        }
	        // Return the type associated with a variable, parameter, or property declaration. In the simple case this is the type
	        // specified in a type annotation or inferred from an initializer. However, in the case of a destructuring declaration it
	        // is a bit more involved. For example:
	        //
	        //   var [x, s = ""] = [1, "one"];
	        //
	        // Here, the array literal [1, "one"] is contextually typed by the type [any, string], which is the implied type of the
	        // binding pattern [x, s = ""]. Because the contextual type is a tuple type, the resulting type of [1, "one"] is the
	        // tuple type [number, string]. Thus, the type inferred for 'x' is number and the type inferred for 's' is string.
	        function getWidenedTypeForVariableLikeDeclaration(declaration, reportErrors) {
	            var type = getTypeForVariableLikeDeclaration(declaration);
	            if (type) {
	                if (reportErrors) {
	                    reportErrorsFromWidening(declaration, type);
	                }
	                // During a normal type check we'll never get to here with a property assignment (the check of the containing
	                // object literal uses a different path). We exclude widening only so that language services and type verification
	                // tools see the actual type.
	                if (declaration.kind === 248 /* PropertyAssignment */) {
	                    return type;
	                }
	                return getWidenedType(type);
	            }
	            // Rest parameters default to type any[], other parameters default to type any
	            type = declaration.dotDotDotToken ? anyArrayType : anyType;
	            // Report implicit any errors unless this is a private property within an ambient declaration
	            if (reportErrors && compilerOptions.noImplicitAny) {
	                var root = ts.getRootDeclaration(declaration);
	                if (!isPrivateWithinAmbient(root) && !(root.kind === 139 /* Parameter */ && isPrivateWithinAmbient(root.parent))) {
	                    reportImplicitAnyError(declaration, type);
	                }
	            }
	            return type;
	        }
	        function getTypeOfVariableOrParameterOrProperty(symbol) {
	            var links = getSymbolLinks(symbol);
	            if (!links.type) {
	                // Handle prototype property
	                if (symbol.flags & 134217728 /* Prototype */) {
	                    return links.type = getTypeOfPrototypeProperty(symbol);
	                }
	                // Handle catch clause variables
	                var declaration = symbol.valueDeclaration;
	                if (declaration.parent.kind === 247 /* CatchClause */) {
	                    return links.type = anyType;
	                }
	                // Handle export default expressions
	                if (declaration.kind === 230 /* ExportAssignment */) {
	                    return links.type = checkExpression(declaration.expression);
	                }
	                // Handle module.exports = expr
	                if (declaration.kind === 184 /* BinaryExpression */) {
	                    return links.type = getUnionType(ts.map(symbol.declarations, function (decl) { return checkExpressionCached(decl.right); }));
	                }
	                if (declaration.kind === 169 /* PropertyAccessExpression */) {
	                    // Declarations only exist for property access expressions for certain
	                    // special assignment kinds
	                    if (declaration.parent.kind === 184 /* BinaryExpression */) {
	                        // Handle exports.p = expr or this.p = expr or className.prototype.method = expr
	                        return links.type = checkExpressionCached(declaration.parent.right);
	                    }
	                }
	                // Handle variable, parameter or property
	                if (!pushTypeResolution(symbol, 0 /* Type */)) {
	                    return unknownType;
	                }
	                var type = getWidenedTypeForVariableLikeDeclaration(declaration, /*reportErrors*/ true);
	                if (!popTypeResolution()) {
	                    if (symbol.valueDeclaration.type) {
	                        // Variable has type annotation that circularly references the variable itself
	                        type = unknownType;
	                        error(symbol.valueDeclaration, ts.Diagnostics._0_is_referenced_directly_or_indirectly_in_its_own_type_annotation, symbolToString(symbol));
	                    }
	                    else {
	                        // Variable has initializer that circularly references the variable itself
	                        type = anyType;
	                        if (compilerOptions.noImplicitAny) {
	                            error(symbol.valueDeclaration, ts.Diagnostics._0_implicitly_has_type_any_because_it_does_not_have_a_type_annotation_and_is_referenced_directly_or_indirectly_in_its_own_initializer, symbolToString(symbol));
	                        }
	                    }
	                }
	                links.type = type;
	            }
	            return links.type;
	        }
	        function getAnnotatedAccessorType(accessor) {
	            if (accessor) {
	                if (accessor.kind === 146 /* GetAccessor */) {
	                    return accessor.type && getTypeFromTypeNode(accessor.type);
	                }
	                else {
	                    var setterTypeAnnotation = ts.getSetAccessorTypeAnnotationNode(accessor);
	                    return setterTypeAnnotation && getTypeFromTypeNode(setterTypeAnnotation);
	                }
	            }
	            return undefined;
	        }
	        function getTypeOfAccessors(symbol) {
	            var links = getSymbolLinks(symbol);
	            if (!links.type) {
	                if (!pushTypeResolution(symbol, 0 /* Type */)) {
	                    return unknownType;
	                }
	                var getter = ts.getDeclarationOfKind(symbol, 146 /* GetAccessor */);
	                var setter = ts.getDeclarationOfKind(symbol, 147 /* SetAccessor */);
	                var type = void 0;
	                // First try to see if the user specified a return type on the get-accessor.
	                var getterReturnType = getAnnotatedAccessorType(getter);
	                if (getterReturnType) {
	                    type = getterReturnType;
	                }
	                else {
	                    // If the user didn't specify a return type, try to use the set-accessor's parameter type.
	                    var setterParameterType = getAnnotatedAccessorType(setter);
	                    if (setterParameterType) {
	                        type = setterParameterType;
	                    }
	                    else {
	                        // If there are no specified types, try to infer it from the body of the get accessor if it exists.
	                        if (getter && getter.body) {
	                            type = getReturnTypeFromBody(getter);
	                        }
	                        else {
	                            if (compilerOptions.noImplicitAny) {
	                                error(setter, ts.Diagnostics.Property_0_implicitly_has_type_any_because_its_set_accessor_lacks_a_type_annotation, symbolToString(symbol));
	                            }
	                            type = anyType;
	                        }
	                    }
	                }
	                if (!popTypeResolution()) {
	                    type = anyType;
	                    if (compilerOptions.noImplicitAny) {
	                        var getter_1 = ts.getDeclarationOfKind(symbol, 146 /* GetAccessor */);
	                        error(getter_1, ts.Diagnostics._0_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_referenced_directly_or_indirectly_in_one_of_its_return_expressions, symbolToString(symbol));
	                    }
	                }
	                links.type = type;
	            }
	            return links.type;
	        }
	        function getTypeOfFuncClassEnumModule(symbol) {
	            var links = getSymbolLinks(symbol);
	            if (!links.type) {
	                links.type = createObjectType(65536 /* Anonymous */, symbol);
	            }
	            return links.type;
	        }
	        function getTypeOfEnumMember(symbol) {
	            var links = getSymbolLinks(symbol);
	            if (!links.type) {
	                links.type = getDeclaredTypeOfEnum(getParentOfSymbol(symbol));
	            }
	            return links.type;
	        }
	        function getTypeOfAlias(symbol) {
	            var links = getSymbolLinks(symbol);
	            if (!links.type) {
	                var targetSymbol = resolveAlias(symbol);
	                // It only makes sense to get the type of a value symbol. If the result of resolving
	                // the alias is not a value, then it has no type. To get the type associated with a
	                // type symbol, call getDeclaredTypeOfSymbol.
	                // This check is important because without it, a call to getTypeOfSymbol could end
	                // up recursively calling getTypeOfAlias, causing a stack overflow.
	                links.type = targetSymbol.flags & 107455 /* Value */
	                    ? getTypeOfSymbol(targetSymbol)
	                    : unknownType;
	            }
	            return links.type;
	        }
	        function getTypeOfInstantiatedSymbol(symbol) {
	            var links = getSymbolLinks(symbol);
	            if (!links.type) {
	                links.type = instantiateType(getTypeOfSymbol(links.target), links.mapper);
	            }
	            return links.type;
	        }
	        function getTypeOfSymbol(symbol) {
	            if (symbol.flags & 16777216 /* Instantiated */) {
	                return getTypeOfInstantiatedSymbol(symbol);
	            }
	            if (symbol.flags & (3 /* Variable */ | 4 /* Property */)) {
	                return getTypeOfVariableOrParameterOrProperty(symbol);
	            }
	            if (symbol.flags & (16 /* Function */ | 8192 /* Method */ | 32 /* Class */ | 384 /* Enum */ | 512 /* ValueModule */)) {
	                return getTypeOfFuncClassEnumModule(symbol);
	            }
	            if (symbol.flags & 8 /* EnumMember */) {
	                return getTypeOfEnumMember(symbol);
	            }
	            if (symbol.flags & 98304 /* Accessor */) {
	                return getTypeOfAccessors(symbol);
	            }
	            if (symbol.flags & 8388608 /* Alias */) {
	                return getTypeOfAlias(symbol);
	            }
	            return unknownType;
	        }
	        function getTargetType(type) {
	            return type.flags & 4096 /* Reference */ ? type.target : type;
	        }
	        function hasBaseType(type, checkBase) {
	            return check(type);
	            function check(type) {
	                var target = getTargetType(type);
	                return target === checkBase || ts.forEach(getBaseTypes(target), check);
	            }
	        }
	        // Appends the type parameters given by a list of declarations to a set of type parameters and returns the resulting set.
	        // The function allocates a new array if the input type parameter set is undefined, but otherwise it modifies the set
	        // in-place and returns the same array.
	        function appendTypeParameters(typeParameters, declarations) {
	            for (var _i = 0, declarations_2 = declarations; _i < declarations_2.length; _i++) {
	                var declaration = declarations_2[_i];
	                var tp = getDeclaredTypeOfTypeParameter(getSymbolOfNode(declaration));
	                if (!typeParameters) {
	                    typeParameters = [tp];
	                }
	                else if (!ts.contains(typeParameters, tp)) {
	                    typeParameters.push(tp);
	                }
	            }
	            return typeParameters;
	        }
	        // Appends the outer type parameters of a node to a set of type parameters and returns the resulting set. The function
	        // allocates a new array if the input type parameter set is undefined, but otherwise it modifies the set in-place and
	        // returns the same array.
	        function appendOuterTypeParameters(typeParameters, node) {
	            while (true) {
	                node = node.parent;
	                if (!node) {
	                    return typeParameters;
	                }
	                if (node.kind === 217 /* ClassDeclaration */ || node.kind === 189 /* ClassExpression */ ||
	                    node.kind === 216 /* FunctionDeclaration */ || node.kind === 176 /* FunctionExpression */ ||
	                    node.kind === 144 /* MethodDeclaration */ || node.kind === 177 /* ArrowFunction */) {
	                    var declarations = node.typeParameters;
	                    if (declarations) {
	                        return appendTypeParameters(appendOuterTypeParameters(typeParameters, node), declarations);
	                    }
	                }
	            }
	        }
	        // The outer type parameters are those defined by enclosing generic classes, methods, or functions.
	        function getOuterTypeParametersOfClassOrInterface(symbol) {
	            var declaration = symbol.flags & 32 /* Class */ ? symbol.valueDeclaration : ts.getDeclarationOfKind(symbol, 218 /* InterfaceDeclaration */);
	            return appendOuterTypeParameters(undefined, declaration);
	        }
	        // The local type parameters are the combined set of type parameters from all declarations of the class,
	        // interface, or type alias.
	        function getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(symbol) {
	            var result;
	            for (var _i = 0, _a = symbol.declarations; _i < _a.length; _i++) {
	                var node = _a[_i];
	                if (node.kind === 218 /* InterfaceDeclaration */ || node.kind === 217 /* ClassDeclaration */ ||
	                    node.kind === 189 /* ClassExpression */ || node.kind === 219 /* TypeAliasDeclaration */) {
	                    var declaration = node;
	                    if (declaration.typeParameters) {
	                        result = appendTypeParameters(result, declaration.typeParameters);
	                    }
	                }
	            }
	            return result;
	        }
	        // The full set of type parameters for a generic class or interface type consists of its outer type parameters plus
	        // its locally declared type parameters.
	        function getTypeParametersOfClassOrInterface(symbol) {
	            return ts.concatenate(getOuterTypeParametersOfClassOrInterface(symbol), getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(symbol));
	        }
	        function isConstructorType(type) {
	            return type.flags & 80896 /* ObjectType */ && getSignaturesOfType(type, 1 /* Construct */).length > 0;
	        }
	        function getBaseTypeNodeOfClass(type) {
	            return ts.getClassExtendsHeritageClauseElement(type.symbol.valueDeclaration);
	        }
	        function getConstructorsForTypeArguments(type, typeArgumentNodes) {
	            var typeArgCount = typeArgumentNodes ? typeArgumentNodes.length : 0;
	            return ts.filter(getSignaturesOfType(type, 1 /* Construct */), function (sig) { return (sig.typeParameters ? sig.typeParameters.length : 0) === typeArgCount; });
	        }
	        function getInstantiatedConstructorsForTypeArguments(type, typeArgumentNodes) {
	            var signatures = getConstructorsForTypeArguments(type, typeArgumentNodes);
	            if (typeArgumentNodes) {
	                var typeArguments_1 = ts.map(typeArgumentNodes, getTypeFromTypeNode);
	                signatures = ts.map(signatures, function (sig) { return getSignatureInstantiation(sig, typeArguments_1); });
	            }
	            return signatures;
	        }
	        // The base constructor of a class can resolve to
	        // undefinedType if the class has no extends clause,
	        // unknownType if an error occurred during resolution of the extends expression,
	        // nullType if the extends expression is the null value, or
	        // an object type with at least one construct signature.
	        function getBaseConstructorTypeOfClass(type) {
	            if (!type.resolvedBaseConstructorType) {
	                var baseTypeNode = getBaseTypeNodeOfClass(type);
	                if (!baseTypeNode) {
	                    return type.resolvedBaseConstructorType = undefinedType;
	                }
	                if (!pushTypeResolution(type, 1 /* ResolvedBaseConstructorType */)) {
	                    return unknownType;
	                }
	                var baseConstructorType = checkExpression(baseTypeNode.expression);
	                if (baseConstructorType.flags & 80896 /* ObjectType */) {
	                    // Resolving the members of a class requires us to resolve the base class of that class.
	                    // We force resolution here such that we catch circularities now.
	                    resolveStructuredTypeMembers(baseConstructorType);
	                }
	                if (!popTypeResolution()) {
	                    error(type.symbol.valueDeclaration, ts.Diagnostics._0_is_referenced_directly_or_indirectly_in_its_own_base_expression, symbolToString(type.symbol));
	                    return type.resolvedBaseConstructorType = unknownType;
	                }
	                if (baseConstructorType !== unknownType && baseConstructorType !== nullType && !isConstructorType(baseConstructorType)) {
	                    error(baseTypeNode.expression, ts.Diagnostics.Type_0_is_not_a_constructor_function_type, typeToString(baseConstructorType));
	                    return type.resolvedBaseConstructorType = unknownType;
	                }
	                type.resolvedBaseConstructorType = baseConstructorType;
	            }
	            return type.resolvedBaseConstructorType;
	        }
	        function getBaseTypes(type) {
	            var isClass = type.symbol.flags & 32 /* Class */;
	            var isInterface = type.symbol.flags & 64 /* Interface */;
	            if (!type.resolvedBaseTypes) {
	                if (!isClass && !isInterface) {
	                    ts.Debug.fail("type must be class or interface");
	                }
	                if (isClass) {
	                    resolveBaseTypesOfClass(type);
	                }
	                if (isInterface) {
	                    resolveBaseTypesOfInterface(type);
	                }
	            }
	            return type.resolvedBaseTypes;
	        }
	        function resolveBaseTypesOfClass(type) {
	            type.resolvedBaseTypes = type.resolvedBaseTypes || emptyArray;
	            var baseConstructorType = getBaseConstructorTypeOfClass(type);
	            if (!(baseConstructorType.flags & 80896 /* ObjectType */)) {
	                return;
	            }
	            var baseTypeNode = getBaseTypeNodeOfClass(type);
	            var baseType;
	            var originalBaseType = baseConstructorType && baseConstructorType.symbol ? getDeclaredTypeOfSymbol(baseConstructorType.symbol) : undefined;
	            if (baseConstructorType.symbol && baseConstructorType.symbol.flags & 32 /* Class */ &&
	                areAllOuterTypeParametersApplied(originalBaseType)) {
	                // When base constructor type is a class with no captured type arguments we know that the constructors all have the same type parameters as the
	                // class and all return the instance type of the class. There is no need for further checks and we can apply the
	                // type arguments in the same manner as a type reference to get the same error reporting experience.
	                baseType = getTypeFromClassOrInterfaceReference(baseTypeNode, baseConstructorType.symbol);
	            }
	            else {
	                // The class derives from a "class-like" constructor function, check that we have at least one construct signature
	                // with a matching number of type parameters and use the return type of the first instantiated signature. Elsewhere
	                // we check that all instantiated signatures return the same type.
	                var constructors = getInstantiatedConstructorsForTypeArguments(baseConstructorType, baseTypeNode.typeArguments);
	                if (!constructors.length) {
	                    error(baseTypeNode.expression, ts.Diagnostics.No_base_constructor_has_the_specified_number_of_type_arguments);
	                    return;
	                }
	                baseType = getReturnTypeOfSignature(constructors[0]);
	            }
	            if (baseType === unknownType) {
	                return;
	            }
	            if (!(getTargetType(baseType).flags & (1024 /* Class */ | 2048 /* Interface */))) {
	                error(baseTypeNode.expression, ts.Diagnostics.Base_constructor_return_type_0_is_not_a_class_or_interface_type, typeToString(baseType));
	                return;
	            }
	            if (type === baseType || hasBaseType(baseType, type)) {
	                error(type.symbol.valueDeclaration, ts.Diagnostics.Type_0_recursively_references_itself_as_a_base_type, typeToString(type, /*enclosingDeclaration*/ undefined, 1 /* WriteArrayAsGenericType */));
	                return;
	            }
	            if (type.resolvedBaseTypes === emptyArray) {
	                type.resolvedBaseTypes = [baseType];
	            }
	            else {
	                type.resolvedBaseTypes.push(baseType);
	            }
	        }
	        function areAllOuterTypeParametersApplied(type) {
	            // An unapplied type parameter has its symbol still the same as the matching argument symbol.
	            // Since parameters are applied outer-to-inner, only the last outer parameter needs to be checked.
	            var outerTypeParameters = type.outerTypeParameters;
	            if (outerTypeParameters) {
	                var last = outerTypeParameters.length - 1;
	                var typeArguments = type.typeArguments;
	                return outerTypeParameters[last].symbol !== typeArguments[last].symbol;
	            }
	            return true;
	        }
	        function resolveBaseTypesOfInterface(type) {
	            type.resolvedBaseTypes = type.resolvedBaseTypes || emptyArray;
	            for (var _i = 0, _a = type.symbol.declarations; _i < _a.length; _i++) {
	                var declaration = _a[_i];
	                if (declaration.kind === 218 /* InterfaceDeclaration */ && ts.getInterfaceBaseTypeNodes(declaration)) {
	                    for (var _b = 0, _c = ts.getInterfaceBaseTypeNodes(declaration); _b < _c.length; _b++) {
	                        var node = _c[_b];
	                        var baseType = getTypeFromTypeNode(node);
	                        if (baseType !== unknownType) {
	                            if (getTargetType(baseType).flags & (1024 /* Class */ | 2048 /* Interface */)) {
	                                if (type !== baseType && !hasBaseType(baseType, type)) {
	                                    if (type.resolvedBaseTypes === emptyArray) {
	                                        type.resolvedBaseTypes = [baseType];
	                                    }
	                                    else {
	                                        type.resolvedBaseTypes.push(baseType);
	                                    }
	                                }
	                                else {
	                                    error(declaration, ts.Diagnostics.Type_0_recursively_references_itself_as_a_base_type, typeToString(type, /*enclosingDeclaration*/ undefined, 1 /* WriteArrayAsGenericType */));
	                                }
	                            }
	                            else {
	                                error(node, ts.Diagnostics.An_interface_may_only_extend_a_class_or_another_interface);
	                            }
	                        }
	                    }
	                }
	            }
	        }
	        // Returns true if the interface given by the symbol is free of "this" references. Specifically, the result is
	        // true if the interface itself contains no references to "this" in its body, if all base types are interfaces,
	        // and if none of the base interfaces have a "this" type.
	        function isIndependentInterface(symbol) {
	            for (var _i = 0, _a = symbol.declarations; _i < _a.length; _i++) {
	                var declaration = _a[_i];
	                if (declaration.kind === 218 /* InterfaceDeclaration */) {
	                    if (declaration.flags & 262144 /* ContainsThis */) {
	                        return false;
	                    }
	                    var baseTypeNodes = ts.getInterfaceBaseTypeNodes(declaration);
	                    if (baseTypeNodes) {
	                        for (var _b = 0, baseTypeNodes_1 = baseTypeNodes; _b < baseTypeNodes_1.length; _b++) {
	                            var node = baseTypeNodes_1[_b];
	                            if (ts.isSupportedExpressionWithTypeArguments(node)) {
	                                var baseSymbol = resolveEntityName(node.expression, 793056 /* Type */, /*ignoreErrors*/ true);
	                                if (!baseSymbol || !(baseSymbol.flags & 64 /* Interface */) || getDeclaredTypeOfClassOrInterface(baseSymbol).thisType) {
	                                    return false;
	                                }
	                            }
	                        }
	                    }
	                }
	            }
	            return true;
	        }
	        function getDeclaredTypeOfClassOrInterface(symbol) {
	            var links = getSymbolLinks(symbol);
	            if (!links.declaredType) {
	                var kind = symbol.flags & 32 /* Class */ ? 1024 /* Class */ : 2048 /* Interface */;
	                var type = links.declaredType = createObjectType(kind, symbol);
	                var outerTypeParameters = getOuterTypeParametersOfClassOrInterface(symbol);
	                var localTypeParameters = getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(symbol);
	                // A class or interface is generic if it has type parameters or a "this" type. We always give classes a "this" type
	                // because it is not feasible to analyze all members to determine if the "this" type escapes the class (in particular,
	                // property types inferred from initializers and method return types inferred from return statements are very hard
	                // to exhaustively analyze). We give interfaces a "this" type if we can't definitely determine that they are free of
	                // "this" references.
	                if (outerTypeParameters || localTypeParameters || kind === 1024 /* Class */ || !isIndependentInterface(symbol)) {
	                    type.flags |= 4096 /* Reference */;
	                    type.typeParameters = ts.concatenate(outerTypeParameters, localTypeParameters);
	                    type.outerTypeParameters = outerTypeParameters;
	                    type.localTypeParameters = localTypeParameters;
	                    type.instantiations = {};
	                    type.instantiations[getTypeListId(type.typeParameters)] = type;
	                    type.target = type;
	                    type.typeArguments = type.typeParameters;
	                    type.thisType = createType(512 /* TypeParameter */ | 33554432 /* ThisType */);
	                    type.thisType.symbol = symbol;
	                    type.thisType.constraint = type;
	                }
	            }
	            return links.declaredType;
	        }
	        function getDeclaredTypeOfTypeAlias(symbol) {
	            var links = getSymbolLinks(symbol);
	            if (!links.declaredType) {
	                // Note that we use the links object as the target here because the symbol object is used as the unique
	                // identity for resolution of the 'type' property in SymbolLinks.
	                if (!pushTypeResolution(symbol, 2 /* DeclaredType */)) {
	                    return unknownType;
	                }
	                var declaration = ts.getDeclarationOfKind(symbol, 219 /* TypeAliasDeclaration */);
	                var type = getTypeFromTypeNode(declaration.type);
	                if (popTypeResolution()) {
	                    links.typeParameters = getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(symbol);
	                    if (links.typeParameters) {
	                        // Initialize the instantiation cache for generic type aliases. The declared type corresponds to
	                        // an instantiation of the type alias with the type parameters supplied as type arguments.
	                        links.instantiations = {};
	                        links.instantiations[getTypeListId(links.typeParameters)] = type;
	                    }
	                }
	                else {
	                    type = unknownType;
	                    error(declaration.name, ts.Diagnostics.Type_alias_0_circularly_references_itself, symbolToString(symbol));
	                }
	                links.declaredType = type;
	            }
	            return links.declaredType;
	        }
	        function getDeclaredTypeOfEnum(symbol) {
	            var links = getSymbolLinks(symbol);
	            if (!links.declaredType) {
	                var type = createType(128 /* Enum */);
	                type.symbol = symbol;
	                links.declaredType = type;
	            }
	            return links.declaredType;
	        }
	        function getDeclaredTypeOfTypeParameter(symbol) {
	            var links = getSymbolLinks(symbol);
	            if (!links.declaredType) {
	                var type = createType(512 /* TypeParameter */);
	                type.symbol = symbol;
	                if (!ts.getDeclarationOfKind(symbol, 138 /* TypeParameter */).constraint) {
	                    type.constraint = noConstraintType;
	                }
	                links.declaredType = type;
	            }
	            return links.declaredType;
	        }
	        function getDeclaredTypeOfAlias(symbol) {
	            var links = getSymbolLinks(symbol);
	            if (!links.declaredType) {
	                links.declaredType = getDeclaredTypeOfSymbol(resolveAlias(symbol));
	            }
	            return links.declaredType;
	        }
	        function getDeclaredTypeOfSymbol(symbol) {
	            ts.Debug.assert((symbol.flags & 16777216 /* Instantiated */) === 0);
	            if (symbol.flags & (32 /* Class */ | 64 /* Interface */)) {
	                return getDeclaredTypeOfClassOrInterface(symbol);
	            }
	            if (symbol.flags & 524288 /* TypeAlias */) {
	                return getDeclaredTypeOfTypeAlias(symbol);
	            }
	            if (symbol.flags & 384 /* Enum */) {
	                return getDeclaredTypeOfEnum(symbol);
	            }
	            if (symbol.flags & 262144 /* TypeParameter */) {
	                return getDeclaredTypeOfTypeParameter(symbol);
	            }
	            if (symbol.flags & 8388608 /* Alias */) {
	                return getDeclaredTypeOfAlias(symbol);
	            }
	            return unknownType;
	        }
	        // A type reference is considered independent if each type argument is considered independent.
	        function isIndependentTypeReference(node) {
	            if (node.typeArguments) {
	                for (var _i = 0, _a = node.typeArguments; _i < _a.length; _i++) {
	                    var typeNode = _a[_i];
	                    if (!isIndependentType(typeNode)) {
	                        return false;
	                    }
	                }
	            }
	            return true;
	        }
	        // A type is considered independent if it the any, string, number, boolean, symbol, or void keyword, a string
	        // literal type, an array with an element type that is considered independent, or a type reference that is
	        // considered independent.
	        function isIndependentType(node) {
	            switch (node.kind) {
	                case 117 /* AnyKeyword */:
	                case 130 /* StringKeyword */:
	                case 128 /* NumberKeyword */:
	                case 120 /* BooleanKeyword */:
	                case 131 /* SymbolKeyword */:
	                case 103 /* VoidKeyword */:
	                case 163 /* StringLiteralType */:
	                    return true;
	                case 157 /* ArrayType */:
	                    return isIndependentType(node.elementType);
	                case 152 /* TypeReference */:
	                    return isIndependentTypeReference(node);
	            }
	            return false;
	        }
	        // A variable-like declaration is considered independent (free of this references) if it has a type annotation
	        // that specifies an independent type, or if it has no type annotation and no initializer (and thus of type any).
	        function isIndependentVariableLikeDeclaration(node) {
	            return node.type && isIndependentType(node.type) || !node.type && !node.initializer;
	        }
	        // A function-like declaration is considered independent (free of this references) if it has a return type
	        // annotation that is considered independent and if each parameter is considered independent.
	        function isIndependentFunctionLikeDeclaration(node) {
	            if (node.kind !== 145 /* Constructor */ && (!node.type || !isIndependentType(node.type))) {
	                return false;
	            }
	            for (var _i = 0, _a = node.parameters; _i < _a.length; _i++) {
	                var parameter = _a[_i];
	                if (!isIndependentVariableLikeDeclaration(parameter)) {
	                    return false;
	                }
	            }
	            return true;
	        }
	        // Returns true if the class or interface member given by the symbol is free of "this" references. The
	        // function may return false for symbols that are actually free of "this" references because it is not
	        // feasible to perform a complete analysis in all cases. In particular, property members with types
	        // inferred from their initializers and function members with inferred return types are convervatively
	        // assumed not to be free of "this" references.
	        function isIndependentMember(symbol) {
	            if (symbol.declarations && symbol.declarations.length === 1) {
	                var declaration = symbol.declarations[0];
	                if (declaration) {
	                    switch (declaration.kind) {
	                        case 142 /* PropertyDeclaration */:
	                        case 141 /* PropertySignature */:
	                            return isIndependentVariableLikeDeclaration(declaration);
	                        case 144 /* MethodDeclaration */:
	                        case 143 /* MethodSignature */:
	                        case 145 /* Constructor */:
	                            return isIndependentFunctionLikeDeclaration(declaration);
	                    }
	                }
	            }
	            return false;
	        }
	        function createSymbolTable(symbols) {
	            var result = {};
	            for (var _i = 0, symbols_1 = symbols; _i < symbols_1.length; _i++) {
	                var symbol = symbols_1[_i];
	                result[symbol.name] = symbol;
	            }
	            return result;
	        }
	        // The mappingThisOnly flag indicates that the only type parameter being mapped is "this". When the flag is true,
	        // we check symbols to see if we can quickly conclude they are free of "this" references, thus needing no instantiation.
	        function createInstantiatedSymbolTable(symbols, mapper, mappingThisOnly) {
	            var result = {};
	            for (var _i = 0, symbols_2 = symbols; _i < symbols_2.length; _i++) {
	                var symbol = symbols_2[_i];
	                result[symbol.name] = mappingThisOnly && isIndependentMember(symbol) ? symbol : instantiateSymbol(symbol, mapper);
	            }
	            return result;
	        }
	        function addInheritedMembers(symbols, baseSymbols) {
	            for (var _i = 0, baseSymbols_1 = baseSymbols; _i < baseSymbols_1.length; _i++) {
	                var s = baseSymbols_1[_i];
	                if (!ts.hasProperty(symbols, s.name)) {
	                    symbols[s.name] = s;
	                }
	            }
	        }
	        function resolveDeclaredMembers(type) {
	            if (!type.declaredProperties) {
	                var symbol = type.symbol;
	                type.declaredProperties = getNamedMembers(symbol.members);
	                type.declaredCallSignatures = getSignaturesOfSymbol(symbol.members["__call"]);
	                type.declaredConstructSignatures = getSignaturesOfSymbol(symbol.members["__new"]);
	                type.declaredStringIndexType = getIndexTypeOfSymbol(symbol, 0 /* String */);
	                type.declaredNumberIndexType = getIndexTypeOfSymbol(symbol, 1 /* Number */);
	            }
	            return type;
	        }
	        function getTypeWithThisArgument(type, thisArgument) {
	            if (type.flags & 4096 /* Reference */) {
	                return createTypeReference(type.target, ts.concatenate(type.typeArguments, [thisArgument || type.target.thisType]));
	            }
	            return type;
	        }
	        function resolveObjectTypeMembers(type, source, typeParameters, typeArguments) {
	            var mapper = identityMapper;
	            var members = source.symbol.members;
	            var callSignatures = source.declaredCallSignatures;
	            var constructSignatures = source.declaredConstructSignatures;
	            var stringIndexType = source.declaredStringIndexType;
	            var numberIndexType = source.declaredNumberIndexType;
	            if (!ts.rangeEquals(typeParameters, typeArguments, 0, typeParameters.length)) {
	                mapper = createTypeMapper(typeParameters, typeArguments);
	                members = createInstantiatedSymbolTable(source.declaredProperties, mapper, /*mappingThisOnly*/ typeParameters.length === 1);
	                callSignatures = instantiateList(source.declaredCallSignatures, mapper, instantiateSignature);
	                constructSignatures = instantiateList(source.declaredConstructSignatures, mapper, instantiateSignature);
	                stringIndexType = instantiateType(source.declaredStringIndexType, mapper);
	                numberIndexType = instantiateType(source.declaredNumberIndexType, mapper);
	            }
	            var baseTypes = getBaseTypes(source);
	            if (baseTypes.length) {
	                if (members === source.symbol.members) {
	                    members = createSymbolTable(source.declaredProperties);
	                }
	                var thisArgument = ts.lastOrUndefined(typeArguments);
	                for (var _i = 0, baseTypes_1 = baseTypes; _i < baseTypes_1.length; _i++) {
	                    var baseType = baseTypes_1[_i];
	                    var instantiatedBaseType = thisArgument ? getTypeWithThisArgument(instantiateType(baseType, mapper), thisArgument) : baseType;
	                    addInheritedMembers(members, getPropertiesOfObjectType(instantiatedBaseType));
	                    callSignatures = ts.concatenate(callSignatures, getSignaturesOfType(instantiatedBaseType, 0 /* Call */));
	                    constructSignatures = ts.concatenate(constructSignatures, getSignaturesOfType(instantiatedBaseType, 1 /* Construct */));
	                    stringIndexType = stringIndexType || getIndexTypeOfType(instantiatedBaseType, 0 /* String */);
	                    numberIndexType = numberIndexType || getIndexTypeOfType(instantiatedBaseType, 1 /* Number */);
	                }
	            }
	            setObjectTypeMembers(type, members, callSignatures, constructSignatures, stringIndexType, numberIndexType);
	        }
	        function resolveClassOrInterfaceMembers(type) {
	            resolveObjectTypeMembers(type, resolveDeclaredMembers(type), emptyArray, emptyArray);
	        }
	        function resolveTypeReferenceMembers(type) {
	            var source = resolveDeclaredMembers(type.target);
	            var typeParameters = ts.concatenate(source.typeParameters, [source.thisType]);
	            var typeArguments = type.typeArguments && type.typeArguments.length === typeParameters.length ?
	                type.typeArguments : ts.concatenate(type.typeArguments, [type]);
	            resolveObjectTypeMembers(type, source, typeParameters, typeArguments);
	        }
	        function createSignature(declaration, typeParameters, parameters, resolvedReturnType, typePredicate, minArgumentCount, hasRestParameter, hasStringLiterals) {
	            var sig = new Signature(checker);
	            sig.declaration = declaration;
	            sig.typeParameters = typeParameters;
	            sig.parameters = parameters;
	            sig.resolvedReturnType = resolvedReturnType;
	            sig.typePredicate = typePredicate;
	            sig.minArgumentCount = minArgumentCount;
	            sig.hasRestParameter = hasRestParameter;
	            sig.hasStringLiterals = hasStringLiterals;
	            return sig;
	        }
	        function cloneSignature(sig) {
	            return createSignature(sig.declaration, sig.typeParameters, sig.parameters, sig.resolvedReturnType, sig.typePredicate, sig.minArgumentCount, sig.hasRestParameter, sig.hasStringLiterals);
	        }
	        function getDefaultConstructSignatures(classType) {
	            var baseConstructorType = getBaseConstructorTypeOfClass(classType);
	            var baseSignatures = getSignaturesOfType(baseConstructorType, 1 /* Construct */);
	            if (baseSignatures.length === 0) {
	                return [createSignature(undefined, classType.localTypeParameters, emptyArray, classType, /*typePredicate*/ undefined, 0, /*hasRestParameter*/ false, /*hasStringLiterals*/ false)];
	            }
	            var baseTypeNode = getBaseTypeNodeOfClass(classType);
	            var typeArguments = ts.map(baseTypeNode.typeArguments, getTypeFromTypeNode);
	            var typeArgCount = typeArguments ? typeArguments.length : 0;
	            var result = [];
	            for (var _i = 0, baseSignatures_1 = baseSignatures; _i < baseSignatures_1.length; _i++) {
	                var baseSig = baseSignatures_1[_i];
	                var typeParamCount = baseSig.typeParameters ? baseSig.typeParameters.length : 0;
	                if (typeParamCount === typeArgCount) {
	                    var sig = typeParamCount ? getSignatureInstantiation(baseSig, typeArguments) : cloneSignature(baseSig);
	                    sig.typeParameters = classType.localTypeParameters;
	                    sig.resolvedReturnType = classType;
	                    result.push(sig);
	                }
	            }
	            return result;
	        }
	        function createTupleTypeMemberSymbols(memberTypes) {
	            var members = {};
	            for (var i = 0; i < memberTypes.length; i++) {
	                var symbol = createSymbol(4 /* Property */ | 67108864 /* Transient */, "" + i);
	                symbol.type = memberTypes[i];
	                members[i] = symbol;
	            }
	            return members;
	        }
	        function resolveTupleTypeMembers(type) {
	            var arrayElementType = getUnionType(type.elementTypes, /*noSubtypeReduction*/ true);
	            // Make the tuple type itself the 'this' type by including an extra type argument
	            var arrayType = resolveStructuredTypeMembers(createTypeFromGenericGlobalType(globalArrayType, [arrayElementType, type]));
	            var members = createTupleTypeMemberSymbols(type.elementTypes);
	            addInheritedMembers(members, arrayType.properties);
	            setObjectTypeMembers(type, members, arrayType.callSignatures, arrayType.constructSignatures, arrayType.stringIndexType, arrayType.numberIndexType);
	        }
	        function findMatchingSignature(signatureList, signature, partialMatch, ignoreReturnTypes) {
	            for (var _i = 0, signatureList_1 = signatureList; _i < signatureList_1.length; _i++) {
	                var s = signatureList_1[_i];
	                if (compareSignaturesIdentical(s, signature, partialMatch, ignoreReturnTypes, compareTypesIdentical)) {
	                    return s;
	                }
	            }
	        }
	        function findMatchingSignatures(signatureLists, signature, listIndex) {
	            if (signature.typeParameters) {
	                // We require an exact match for generic signatures, so we only return signatures from the first
	                // signature list and only if they have exact matches in the other signature lists.
	                if (listIndex > 0) {
	                    return undefined;
	                }
	                for (var i = 1; i < signatureLists.length; i++) {
	                    if (!findMatchingSignature(signatureLists[i], signature, /*partialMatch*/ false, /*ignoreReturnTypes*/ false)) {
	                        return undefined;
	                    }
	                }
	                return [signature];
	            }
	            var result = undefined;
	            for (var i = 0; i < signatureLists.length; i++) {
	                // Allow matching non-generic signatures to have excess parameters and different return types
	                var match = i === listIndex ? signature : findMatchingSignature(signatureLists[i], signature, /*partialMatch*/ true, /*ignoreReturnTypes*/ true);
	                if (!match) {
	                    return undefined;
	                }
	                if (!ts.contains(result, match)) {
	                    (result || (result = [])).push(match);
	                }
	            }
	            return result;
	        }
	        // The signatures of a union type are those signatures that are present in each of the constituent types.
	        // Generic signatures must match exactly, but non-generic signatures are allowed to have extra optional
	        // parameters and may differ in return types. When signatures differ in return types, the resulting return
	        // type is the union of the constituent return types.
	        function getUnionSignatures(types, kind) {
	            var signatureLists = ts.map(types, function (t) { return getSignaturesOfType(t, kind); });
	            var result = undefined;
	            for (var i = 0; i < signatureLists.length; i++) {
	                for (var _i = 0, _a = signatureLists[i]; _i < _a.length; _i++) {
	                    var signature = _a[_i];
	                    // Only process signatures with parameter lists that aren't already in the result list
	                    if (!result || !findMatchingSignature(result, signature, /*partialMatch*/ false, /*ignoreReturnTypes*/ true)) {
	                        var unionSignatures = findMatchingSignatures(signatureLists, signature, i);
	                        if (unionSignatures) {
	                            var s = signature;
	                            // Union the result types when more than one signature matches
	                            if (unionSignatures.length > 1) {
	                                s = cloneSignature(signature);
	                                // Clear resolved return type we possibly got from cloneSignature
	                                s.resolvedReturnType = undefined;
	                                s.unionSignatures = unionSignatures;
	                            }
	                            (result || (result = [])).push(s);
	                        }
	                    }
	                }
	            }
	            return result || emptyArray;
	        }
	        function getUnionIndexType(types, kind) {
	            var indexTypes = [];
	            for (var _i = 0, types_1 = types; _i < types_1.length; _i++) {
	                var type = types_1[_i];
	                var indexType = getIndexTypeOfType(type, kind);
	                if (!indexType) {
	                    return undefined;
	                }
	                indexTypes.push(indexType);
	            }
	            return getUnionType(indexTypes);
	        }
	        function resolveUnionTypeMembers(type) {
	            // The members and properties collections are empty for union types. To get all properties of a union
	            // type use getPropertiesOfType (only the language service uses this).
	            var callSignatures = getUnionSignatures(type.types, 0 /* Call */);
	            var constructSignatures = getUnionSignatures(type.types, 1 /* Construct */);
	            var stringIndexType = getUnionIndexType(type.types, 0 /* String */);
	            var numberIndexType = getUnionIndexType(type.types, 1 /* Number */);
	            setObjectTypeMembers(type, emptySymbols, callSignatures, constructSignatures, stringIndexType, numberIndexType);
	        }
	        function intersectTypes(type1, type2) {
	            return !type1 ? type2 : !type2 ? type1 : getIntersectionType([type1, type2]);
	        }
	        function resolveIntersectionTypeMembers(type) {
	            // The members and properties collections are empty for intersection types. To get all properties of an
	            // intersection type use getPropertiesOfType (only the language service uses this).
	            var callSignatures = emptyArray;
	            var constructSignatures = emptyArray;
	            var stringIndexType = undefined;
	            var numberIndexType = undefined;
	            for (var _i = 0, _a = type.types; _i < _a.length; _i++) {
	                var t = _a[_i];
	                callSignatures = ts.concatenate(callSignatures, getSignaturesOfType(t, 0 /* Call */));
	                constructSignatures = ts.concatenate(constructSignatures, getSignaturesOfType(t, 1 /* Construct */));
	                stringIndexType = intersectTypes(stringIndexType, getIndexTypeOfType(t, 0 /* String */));
	                numberIndexType = intersectTypes(numberIndexType, getIndexTypeOfType(t, 1 /* Number */));
	            }
	            setObjectTypeMembers(type, emptySymbols, callSignatures, constructSignatures, stringIndexType, numberIndexType);
	        }
	        function resolveAnonymousTypeMembers(type) {
	            var symbol = type.symbol;
	            if (type.target) {
	                var members = createInstantiatedSymbolTable(getPropertiesOfObjectType(type.target), type.mapper, /*mappingThisOnly*/ false);
	                var callSignatures = instantiateList(getSignaturesOfType(type.target, 0 /* Call */), type.mapper, instantiateSignature);
	                var constructSignatures = instantiateList(getSignaturesOfType(type.target, 1 /* Construct */), type.mapper, instantiateSignature);
	                var stringIndexType = instantiateType(getIndexTypeOfType(type.target, 0 /* String */), type.mapper);
	                var numberIndexType = instantiateType(getIndexTypeOfType(type.target, 1 /* Number */), type.mapper);
	                setObjectTypeMembers(type, members, callSignatures, constructSignatures, stringIndexType, numberIndexType);
	            }
	            else if (symbol.flags & 2048 /* TypeLiteral */) {
	                var members = symbol.members;
	                var callSignatures = getSignaturesOfSymbol(members["__call"]);
	                var constructSignatures = getSignaturesOfSymbol(members["__new"]);
	                var stringIndexType = getIndexTypeOfSymbol(symbol, 0 /* String */);
	                var numberIndexType = getIndexTypeOfSymbol(symbol, 1 /* Number */);
	                setObjectTypeMembers(type, members, callSignatures, constructSignatures, stringIndexType, numberIndexType);
	            }
	            else {
	                // Combinations of function, class, enum and module
	                var members = emptySymbols;
	                var constructSignatures = emptyArray;
	                if (symbol.flags & 1952 /* HasExports */) {
	                    members = getExportsOfSymbol(symbol);
	                }
	                if (symbol.flags & 32 /* Class */) {
	                    var classType = getDeclaredTypeOfClassOrInterface(symbol);
	                    constructSignatures = getSignaturesOfSymbol(symbol.members["__constructor"]);
	                    if (!constructSignatures.length) {
	                        constructSignatures = getDefaultConstructSignatures(classType);
	                    }
	                    var baseConstructorType = getBaseConstructorTypeOfClass(classType);
	                    if (baseConstructorType.flags & 80896 /* ObjectType */) {
	                        members = createSymbolTable(getNamedMembers(members));
	                        addInheritedMembers(members, getPropertiesOfObjectType(baseConstructorType));
	                    }
	                }
	                var numberIndexType = (symbol.flags & 384 /* Enum */) ? stringType : undefined;
	                setObjectTypeMembers(type, members, emptyArray, constructSignatures, undefined, numberIndexType);
	                // We resolve the members before computing the signatures because a signature may use
	                // typeof with a qualified name expression that circularly references the type we are
	                // in the process of resolving (see issue #6072). The temporarily empty signature list
	                // will never be observed because a qualified name can't reference signatures.
	                if (symbol.flags & (16 /* Function */ | 8192 /* Method */)) {
	                    type.callSignatures = getSignaturesOfSymbol(symbol);
	                }
	            }
	        }
	        function resolveStructuredTypeMembers(type) {
	            if (!type.members) {
	                if (type.flags & 4096 /* Reference */) {
	                    resolveTypeReferenceMembers(type);
	                }
	                else if (type.flags & (1024 /* Class */ | 2048 /* Interface */)) {
	                    resolveClassOrInterfaceMembers(type);
	                }
	                else if (type.flags & 65536 /* Anonymous */) {
	                    resolveAnonymousTypeMembers(type);
	                }
	                else if (type.flags & 8192 /* Tuple */) {
	                    resolveTupleTypeMembers(type);
	                }
	                else if (type.flags & 16384 /* Union */) {
	                    resolveUnionTypeMembers(type);
	                }
	                else if (type.flags & 32768 /* Intersection */) {
	                    resolveIntersectionTypeMembers(type);
	                }
	            }
	            return type;
	        }
	        /** Return properties of an object type or an empty array for other types */
	        function getPropertiesOfObjectType(type) {
	            if (type.flags & 80896 /* ObjectType */) {
	                return resolveStructuredTypeMembers(type).properties;
	            }
	            return emptyArray;
	        }
	        /** If the given type is an object type and that type has a property by the given name,
	         * return the symbol for that property. Otherwise return undefined. */
	        function getPropertyOfObjectType(type, name) {
	            if (type.flags & 80896 /* ObjectType */) {
	                var resolved = resolveStructuredTypeMembers(type);
	                if (ts.hasProperty(resolved.members, name)) {
	                    var symbol = resolved.members[name];
	                    if (symbolIsValue(symbol)) {
	                        return symbol;
	                    }
	                }
	            }
	        }
	        function getPropertiesOfUnionOrIntersectionType(type) {
	            for (var _i = 0, _a = type.types; _i < _a.length; _i++) {
	                var current = _a[_i];
	                for (var _b = 0, _c = getPropertiesOfType(current); _b < _c.length; _b++) {
	                    var prop = _c[_b];
	                    getPropertyOfUnionOrIntersectionType(type, prop.name);
	                }
	                // The properties of a union type are those that are present in all constituent types, so
	                // we only need to check the properties of the first type
	                if (type.flags & 16384 /* Union */) {
	                    break;
	                }
	            }
	            return type.resolvedProperties ? symbolsToArray(type.resolvedProperties) : emptyArray;
	        }
	        function getPropertiesOfType(type) {
	            type = getApparentType(type);
	            return type.flags & 49152 /* UnionOrIntersection */ ? getPropertiesOfUnionOrIntersectionType(type) : getPropertiesOfObjectType(type);
	        }
	        /**
	         * The apparent type of a type parameter is the base constraint instantiated with the type parameter
	         * as the type argument for the 'this' type.
	         */
	        function getApparentTypeOfTypeParameter(type) {
	            if (!type.resolvedApparentType) {
	                var constraintType = getConstraintOfTypeParameter(type);
	                while (constraintType && constraintType.flags & 512 /* TypeParameter */) {
	                    constraintType = getConstraintOfTypeParameter(constraintType);
	                }
	                type.resolvedApparentType = getTypeWithThisArgument(constraintType || emptyObjectType, type);
	            }
	            return type.resolvedApparentType;
	        }
	        /**
	         * For a type parameter, return the base constraint of the type parameter. For the string, number,
	         * boolean, and symbol primitive types, return the corresponding object types. Otherwise return the
	         * type itself. Note that the apparent type of a union type is the union type itself.
	         */
	        function getApparentType(type) {
	            if (type.flags & 512 /* TypeParameter */) {
	                type = getApparentTypeOfTypeParameter(type);
	            }
	            if (type.flags & 258 /* StringLike */) {
	                type = globalStringType;
	            }
	            else if (type.flags & 132 /* NumberLike */) {
	                type = globalNumberType;
	            }
	            else if (type.flags & 8 /* Boolean */) {
	                type = globalBooleanType;
	            }
	            else if (type.flags & 16777216 /* ESSymbol */) {
	                type = globalESSymbolType;
	            }
	            return type;
	        }
	        function createUnionOrIntersectionProperty(containingType, name) {
	            var types = containingType.types;
	            var props;
	            // Flags we want to propagate to the result if they exist in all source symbols
	            var commonFlags = (containingType.flags & 32768 /* Intersection */) ? 536870912 /* Optional */ : 0 /* None */;
	            for (var _i = 0, types_2 = types; _i < types_2.length; _i++) {
	                var current = types_2[_i];
	                var type = getApparentType(current);
	                if (type !== unknownType) {
	                    var prop = getPropertyOfType(type, name);
	                    if (prop && !(getDeclarationFlagsFromSymbol(prop) & (16 /* Private */ | 32 /* Protected */))) {
	                        commonFlags &= prop.flags;
	                        if (!props) {
	                            props = [prop];
	                        }
	                        else if (!ts.contains(props, prop)) {
	                            props.push(prop);
	                        }
	                    }
	                    else if (containingType.flags & 16384 /* Union */) {
	                        // A union type requires the property to be present in all constituent types
	                        return undefined;
	                    }
	                }
	            }
	            if (!props) {
	                return undefined;
	            }
	            if (props.length === 1) {
	                return props[0];
	            }
	            var propTypes = [];
	            var declarations = [];
	            for (var _a = 0, props_1 = props; _a < props_1.length; _a++) {
	                var prop = props_1[_a];
	                if (prop.declarations) {
	                    ts.addRange(declarations, prop.declarations);
	                }
	                propTypes.push(getTypeOfSymbol(prop));
	            }
	            var result = createSymbol(4 /* Property */ |
	                67108864 /* Transient */ |
	                268435456 /* SyntheticProperty */ |
	                commonFlags, name);
	            result.containingType = containingType;
	            result.declarations = declarations;
	            result.type = containingType.flags & 16384 /* Union */ ? getUnionType(propTypes) : getIntersectionType(propTypes);
	            return result;
	        }
	        function getPropertyOfUnionOrIntersectionType(type, name) {
	            var properties = type.resolvedProperties || (type.resolvedProperties = {});
	            if (ts.hasProperty(properties, name)) {
	                return properties[name];
	            }
	            var property = createUnionOrIntersectionProperty(type, name);
	            if (property) {
	                properties[name] = property;
	            }
	            return property;
	        }
	        // Return the symbol for the property with the given name in the given type. Creates synthetic union properties when
	        // necessary, maps primitive types and type parameters are to their apparent types, and augments with properties from
	        // Object and Function as appropriate.
	        function getPropertyOfType(type, name) {
	            type = getApparentType(type);
	            if (type.flags & 80896 /* ObjectType */) {
	                var resolved = resolveStructuredTypeMembers(type);
	                if (ts.hasProperty(resolved.members, name)) {
	                    var symbol = resolved.members[name];
	                    if (symbolIsValue(symbol)) {
	                        return symbol;
	                    }
	                }
	                if (resolved === anyFunctionType || resolved.callSignatures.length || resolved.constructSignatures.length) {
	                    var symbol = getPropertyOfObjectType(globalFunctionType, name);
	                    if (symbol) {
	                        return symbol;
	                    }
	                }
	                return getPropertyOfObjectType(globalObjectType, name);
	            }
	            if (type.flags & 49152 /* UnionOrIntersection */) {
	                return getPropertyOfUnionOrIntersectionType(type, name);
	            }
	            return undefined;
	        }
	        function getSignaturesOfStructuredType(type, kind) {
	            if (type.flags & 130048 /* StructuredType */) {
	                var resolved = resolveStructuredTypeMembers(type);
	                return kind === 0 /* Call */ ? resolved.callSignatures : resolved.constructSignatures;
	            }
	            return emptyArray;
	        }
	        /**
	         * Return the signatures of the given kind in the given type. Creates synthetic union signatures when necessary and
	         * maps primitive types and type parameters are to their apparent types.
	         */
	        function getSignaturesOfType(type, kind) {
	            return getSignaturesOfStructuredType(getApparentType(type), kind);
	        }
	        function getIndexTypeOfStructuredType(type, kind) {
	            if (type.flags & 130048 /* StructuredType */) {
	                var resolved = resolveStructuredTypeMembers(type);
	                return kind === 0 /* String */ ? resolved.stringIndexType : resolved.numberIndexType;
	            }
	        }
	        // Return the index type of the given kind in the given type. Creates synthetic union index types when necessary and
	        // maps primitive types and type parameters are to their apparent types.
	        function getIndexTypeOfType(type, kind) {
	            return getIndexTypeOfStructuredType(getApparentType(type), kind);
	        }
	        function getTypeParametersFromJSDocTemplate(declaration) {
	            if (declaration.parserContextFlags & 32 /* JavaScriptFile */) {
	                var templateTag = ts.getJSDocTemplateTag(declaration);
	                if (templateTag) {
	                    return getTypeParametersFromDeclaration(templateTag.typeParameters);
	                }
	            }
	            return undefined;
	        }
	        // Return list of type parameters with duplicates removed (duplicate identifier errors are generated in the actual
	        // type checking functions).
	        function getTypeParametersFromDeclaration(typeParameterDeclarations) {
	            var result = [];
	            ts.forEach(typeParameterDeclarations, function (node) {
	                var tp = getDeclaredTypeOfTypeParameter(node.symbol);
	                if (!ts.contains(result, tp)) {
	                    result.push(tp);
	                }
	            });
	            return result;
	        }
	        function symbolsToArray(symbols) {
	            var result = [];
	            for (var id in symbols) {
	                if (!isReservedMemberName(id)) {
	                    result.push(symbols[id]);
	                }
	            }
	            return result;
	        }
	        function isOptionalParameter(node) {
	            if (node.parserContextFlags & 32 /* JavaScriptFile */) {
	                if (node.type && node.type.kind === 263 /* JSDocOptionalType */) {
	                    return true;
	                }
	                var paramTag = ts.getCorrespondingJSDocParameterTag(node);
	                if (paramTag) {
	                    if (paramTag.isBracketed) {
	                        return true;
	                    }
	                    if (paramTag.typeExpression) {
	                        return paramTag.typeExpression.type.kind === 263 /* JSDocOptionalType */;
	                    }
	                }
	            }
	            if (ts.hasQuestionToken(node)) {
	                return true;
	            }
	            if (node.initializer) {
	                var signatureDeclaration = node.parent;
	                var signature = getSignatureFromDeclaration(signatureDeclaration);
	                var parameterIndex = ts.indexOf(signatureDeclaration.parameters, node);
	                ts.Debug.assert(parameterIndex >= 0);
	                return parameterIndex >= signature.minArgumentCount;
	            }
	            return false;
	        }
	        function createTypePredicateFromTypePredicateNode(node) {
	            if (node.parameterName.kind === 69 /* Identifier */) {
	                var parameterName = node.parameterName;
	                return {
	                    kind: 1 /* Identifier */,
	                    parameterName: parameterName ? parameterName.text : undefined,
	                    parameterIndex: parameterName ? getTypePredicateParameterIndex(node.parent.parameters, parameterName) : undefined,
	                    type: getTypeFromTypeNode(node.type)
	                };
	            }
	            else {
	                return {
	                    kind: 0 /* This */,
	                    type: getTypeFromTypeNode(node.type)
	                };
	            }
	        }
	        function getSignatureFromDeclaration(declaration) {
	            var links = getNodeLinks(declaration);
	            if (!links.resolvedSignature) {
	                var classType = declaration.kind === 145 /* Constructor */ ?
	                    getDeclaredTypeOfClassOrInterface(getMergedSymbol(declaration.parent.symbol))
	                    : undefined;
	                var typeParameters = classType ? classType.localTypeParameters :
	                    declaration.typeParameters ? getTypeParametersFromDeclaration(declaration.typeParameters) :
	                        getTypeParametersFromJSDocTemplate(declaration);
	                var parameters = [];
	                var hasStringLiterals = false;
	                var minArgumentCount = -1;
	                var isJSConstructSignature = ts.isJSDocConstructSignature(declaration);
	                var returnType = undefined;
	                var typePredicate = undefined;
	                // If this is a JSDoc construct signature, then skip the first parameter in the
	                // parameter list.  The first parameter represents the return type of the construct
	                // signature.
	                for (var i = isJSConstructSignature ? 1 : 0, n = declaration.parameters.length; i < n; i++) {
	                    var param = declaration.parameters[i];
	                    var paramSymbol = param.symbol;
	                    // Include parameter symbol instead of property symbol in the signature
	                    if (paramSymbol && !!(paramSymbol.flags & 4 /* Property */) && !ts.isBindingPattern(param.name)) {
	                        var resolvedSymbol = resolveName(param, paramSymbol.name, 107455 /* Value */, undefined, undefined);
	                        paramSymbol = resolvedSymbol;
	                    }
	                    parameters.push(paramSymbol);
	                    if (param.type && param.type.kind === 163 /* StringLiteralType */) {
	                        hasStringLiterals = true;
	                    }
	                    if (param.initializer || param.questionToken || param.dotDotDotToken) {
	                        if (minArgumentCount < 0) {
	                            minArgumentCount = i;
	                        }
	                    }
	                    else {
	                        // If we see any required parameters, it means the prior ones were not in fact optional.
	                        minArgumentCount = -1;
	                    }
	                }
	                if (minArgumentCount < 0) {
	                    minArgumentCount = declaration.parameters.length;
	                }
	                if (isJSConstructSignature) {
	                    minArgumentCount--;
	                    returnType = getTypeFromTypeNode(declaration.parameters[0].type);
	                }
	                else if (classType) {
	                    returnType = classType;
	                }
	                else if (declaration.type) {
	                    returnType = getTypeFromTypeNode(declaration.type);
	                    if (declaration.type.kind === 151 /* TypePredicate */) {
	                        typePredicate = createTypePredicateFromTypePredicateNode(declaration.type);
	                    }
	                }
	                else {
	                    if (declaration.parserContextFlags & 32 /* JavaScriptFile */) {
	                        var type = getReturnTypeFromJSDocComment(declaration);
	                        if (type && type !== unknownType) {
	                            returnType = type;
	                        }
	                    }
	                    // TypeScript 1.0 spec (April 2014):
	                    // If only one accessor includes a type annotation, the other behaves as if it had the same type annotation.
	                    if (declaration.kind === 146 /* GetAccessor */ && !ts.hasDynamicName(declaration)) {
	                        var setter = ts.getDeclarationOfKind(declaration.symbol, 147 /* SetAccessor */);
	                        returnType = getAnnotatedAccessorType(setter);
	                    }
	                    if (!returnType && ts.nodeIsMissing(declaration.body)) {
	                        returnType = anyType;
	                    }
	                }
	                links.resolvedSignature = createSignature(declaration, typeParameters, parameters, returnType, typePredicate, minArgumentCount, ts.hasRestParameter(declaration), hasStringLiterals);
	            }
	            return links.resolvedSignature;
	        }
	        function getSignaturesOfSymbol(symbol) {
	            if (!symbol)
	                return emptyArray;
	            var result = [];
	            for (var i = 0, len = symbol.declarations.length; i < len; i++) {
	                var node = symbol.declarations[i];
	                switch (node.kind) {
	                    case 153 /* FunctionType */:
	                    case 154 /* ConstructorType */:
	                    case 216 /* FunctionDeclaration */:
	                    case 144 /* MethodDeclaration */:
	                    case 143 /* MethodSignature */:
	                    case 145 /* Constructor */:
	                    case 148 /* CallSignature */:
	                    case 149 /* ConstructSignature */:
	                    case 150 /* IndexSignature */:
	                    case 146 /* GetAccessor */:
	                    case 147 /* SetAccessor */:
	                    case 176 /* FunctionExpression */:
	                    case 177 /* ArrowFunction */:
	                    case 264 /* JSDocFunctionType */:
	                        // Don't include signature if node is the implementation of an overloaded function. A node is considered
	                        // an implementation node if it has a body and the previous node is of the same kind and immediately
	                        // precedes the implementation node (i.e. has the same parent and ends where the implementation starts).
	                        if (i > 0 && node.body) {
	                            var previous = symbol.declarations[i - 1];
	                            if (node.parent === previous.parent && node.kind === previous.kind && node.pos === previous.end) {
	                                break;
	                            }
	                        }
	                        result.push(getSignatureFromDeclaration(node));
	                }
	            }
	            return result;
	        }
	        function resolveExternalModuleTypeByLiteral(name) {
	            var moduleSym = resolveExternalModuleName(name, name);
	            if (moduleSym) {
	                var resolvedModuleSymbol = resolveExternalModuleSymbol(moduleSym);
	                if (resolvedModuleSymbol) {
	                    return getTypeOfSymbol(resolvedModuleSymbol);
	                }
	            }
	            return anyType;
	        }
	        function getReturnTypeOfSignature(signature) {
	            if (!signature.resolvedReturnType) {
	                if (!pushTypeResolution(signature, 3 /* ResolvedReturnType */)) {
	                    return unknownType;
	                }
	                var type = void 0;
	                if (signature.target) {
	                    type = instantiateType(getReturnTypeOfSignature(signature.target), signature.mapper);
	                }
	                else if (signature.unionSignatures) {
	                    type = getUnionType(ts.map(signature.unionSignatures, getReturnTypeOfSignature));
	                }
	                else {
	                    type = getReturnTypeFromBody(signature.declaration);
	                }
	                if (!popTypeResolution()) {
	                    type = anyType;
	                    if (compilerOptions.noImplicitAny) {
	                        var declaration = signature.declaration;
	                        if (declaration.name) {
	                            error(declaration.name, ts.Diagnostics._0_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_referenced_directly_or_indirectly_in_one_of_its_return_expressions, ts.declarationNameToString(declaration.name));
	                        }
	                        else {
	                            error(declaration, ts.Diagnostics.Function_implicitly_has_return_type_any_because_it_does_not_have_a_return_type_annotation_and_is_referenced_directly_or_indirectly_in_one_of_its_return_expressions);
	                        }
	                    }
	                }
	                signature.resolvedReturnType = type;
	            }
	            return signature.resolvedReturnType;
	        }
	        function getRestTypeOfSignature(signature) {
	            if (signature.hasRestParameter) {
	                var type = getTypeOfSymbol(ts.lastOrUndefined(signature.parameters));
	                if (type.flags & 4096 /* Reference */ && type.target === globalArrayType) {
	                    return type.typeArguments[0];
	                }
	            }
	            return anyType;
	        }
	        function getSignatureInstantiation(signature, typeArguments) {
	            return instantiateSignature(signature, createTypeMapper(signature.typeParameters, typeArguments), /*eraseTypeParameters*/ true);
	        }
	        function getErasedSignature(signature) {
	            if (!signature.typeParameters)
	                return signature;
	            if (!signature.erasedSignatureCache) {
	                if (signature.target) {
	                    signature.erasedSignatureCache = instantiateSignature(getErasedSignature(signature.target), signature.mapper);
	                }
	                else {
	                    signature.erasedSignatureCache = instantiateSignature(signature, createTypeEraser(signature.typeParameters), /*eraseTypeParameters*/ true);
	                }
	            }
	            return signature.erasedSignatureCache;
	        }
	        function getOrCreateTypeFromSignature(signature) {
	            // There are two ways to declare a construct signature, one is by declaring a class constructor
	            // using the constructor keyword, and the other is declaring a bare construct signature in an
	            // object type literal or interface (using the new keyword). Each way of declaring a constructor
	            // will result in a different declaration kind.
	            if (!signature.isolatedSignatureType) {
	                var isConstructor = signature.declaration.kind === 145 /* Constructor */ || signature.declaration.kind === 149 /* ConstructSignature */;
	                var type = createObjectType(65536 /* Anonymous */ | 262144 /* FromSignature */);
	                type.members = emptySymbols;
	                type.properties = emptyArray;
	                type.callSignatures = !isConstructor ? [signature] : emptyArray;
	                type.constructSignatures = isConstructor ? [signature] : emptyArray;
	                signature.isolatedSignatureType = type;
	            }
	            return signature.isolatedSignatureType;
	        }
	        function getIndexSymbol(symbol) {
	            return symbol.members["__index"];
	        }
	        function getIndexDeclarationOfSymbol(symbol, kind) {
	            var syntaxKind = kind === 1 /* Number */ ? 128 /* NumberKeyword */ : 130 /* StringKeyword */;
	            var indexSymbol = getIndexSymbol(symbol);
	            if (indexSymbol) {
	                for (var _i = 0, _a = indexSymbol.declarations; _i < _a.length; _i++) {
	                    var decl = _a[_i];
	                    var node = decl;
	                    if (node.parameters.length === 1) {
	                        var parameter = node.parameters[0];
	                        if (parameter && parameter.type && parameter.type.kind === syntaxKind) {
	                            return node;
	                        }
	                    }
	                }
	            }
	            return undefined;
	        }
	        function getIndexTypeOfSymbol(symbol, kind) {
	            var declaration = getIndexDeclarationOfSymbol(symbol, kind);
	            return declaration
	                ? declaration.type ? getTypeFromTypeNode(declaration.type) : anyType
	                : undefined;
	        }
	        function getConstraintDeclaration(type) {
	            return ts.getDeclarationOfKind(type.symbol, 138 /* TypeParameter */).constraint;
	        }
	        function hasConstraintReferenceTo(type, target) {
	            var checked;
	            while (type && !(type.flags & 33554432 /* ThisType */) && type.flags & 512 /* TypeParameter */ && !ts.contains(checked, type)) {
	                if (type === target) {
	                    return true;
	                }
	                (checked || (checked = [])).push(type);
	                var constraintDeclaration = getConstraintDeclaration(type);
	                type = constraintDeclaration && getTypeFromTypeNode(constraintDeclaration);
	            }
	            return false;
	        }
	        function getConstraintOfTypeParameter(typeParameter) {
	            if (!typeParameter.constraint) {
	                if (typeParameter.target) {
	                    var targetConstraint = getConstraintOfTypeParameter(typeParameter.target);
	                    typeParameter.constraint = targetConstraint ? instantiateType(targetConstraint, typeParameter.mapper) : noConstraintType;
	                }
	                else {
	                    var constraintDeclaration = getConstraintDeclaration(typeParameter);
	                    var constraint = getTypeFromTypeNode(constraintDeclaration);
	                    if (hasConstraintReferenceTo(constraint, typeParameter)) {
	                        error(constraintDeclaration, ts.Diagnostics.Type_parameter_0_has_a_circular_constraint, typeToString(typeParameter));
	                        constraint = unknownType;
	                    }
	                    typeParameter.constraint = constraint;
	                }
	            }
	            return typeParameter.constraint === noConstraintType ? undefined : typeParameter.constraint;
	        }
	        function getParentSymbolOfTypeParameter(typeParameter) {
	            return getSymbolOfNode(ts.getDeclarationOfKind(typeParameter.symbol, 138 /* TypeParameter */).parent);
	        }
	        function getTypeListId(types) {
	            if (types) {
	                switch (types.length) {
	                    case 1:
	                        return "" + types[0].id;
	                    case 2:
	                        return types[0].id + "," + types[1].id;
	                    default:
	                        var result = "";
	                        for (var i = 0; i < types.length; i++) {
	                            if (i > 0) {
	                                result += ",";
	                            }
	                            result += types[i].id;
	                        }
	                        return result;
	                }
	            }
	            return "";
	        }
	        // This function is used to propagate certain flags when creating new object type references and union types.
	        // It is only necessary to do so if a constituent type might be the undefined type, the null type, the type
	        // of an object literal or the anyFunctionType. This is because there are operations in the type checker
	        // that care about the presence of such types at arbitrary depth in a containing type.
	        function getPropagatingFlagsOfTypes(types) {
	            var result = 0;
	            for (var _i = 0, types_3 = types; _i < types_3.length; _i++) {
	                var type = types_3[_i];
	                result |= type.flags;
	            }
	            return result & 14680064 /* PropagatingFlags */;
	        }
	        function createTypeReference(target, typeArguments) {
	            var id = getTypeListId(typeArguments);
	            var type = target.instantiations[id];
	            if (!type) {
	                var flags = 4096 /* Reference */ | (typeArguments ? getPropagatingFlagsOfTypes(typeArguments) : 0);
	                type = target.instantiations[id] = createObjectType(flags, target.symbol);
	                type.target = target;
	                type.typeArguments = typeArguments;
	            }
	            return type;
	        }
	        // Get type from reference to class or interface
	        function getTypeFromClassOrInterfaceReference(node, symbol) {
	            var type = getDeclaredTypeOfSymbol(symbol);
	            var typeParameters = type.localTypeParameters;
	            if (typeParameters) {
	                if (!node.typeArguments || node.typeArguments.length !== typeParameters.length) {
	                    error(node, ts.Diagnostics.Generic_type_0_requires_1_type_argument_s, typeToString(type, /*enclosingDeclaration*/ undefined, 1 /* WriteArrayAsGenericType */), typeParameters.length);
	                    return unknownType;
	                }
	                // In a type reference, the outer type parameters of the referenced class or interface are automatically
	                // supplied as type arguments and the type reference only specifies arguments for the local type parameters
	                // of the class or interface.
	                return createTypeReference(type, ts.concatenate(type.outerTypeParameters, ts.map(node.typeArguments, getTypeFromTypeNode)));
	            }
	            if (node.typeArguments) {
	                error(node, ts.Diagnostics.Type_0_is_not_generic, typeToString(type));
	                return unknownType;
	            }
	            return type;
	        }
	        // Get type from reference to type alias. When a type alias is generic, the declared type of the type alias may include
	        // references to the type parameters of the alias. We replace those with the actual type arguments by instantiating the
	        // declared type. Instantiations are cached using the type identities of the type arguments as the key.
	        function getTypeFromTypeAliasReference(node, symbol) {
	            var type = getDeclaredTypeOfSymbol(symbol);
	            var links = getSymbolLinks(symbol);
	            var typeParameters = links.typeParameters;
	            if (typeParameters) {
	                if (!node.typeArguments || node.typeArguments.length !== typeParameters.length) {
	                    error(node, ts.Diagnostics.Generic_type_0_requires_1_type_argument_s, symbolToString(symbol), typeParameters.length);
	                    return unknownType;
	                }
	                var typeArguments = ts.map(node.typeArguments, getTypeFromTypeNode);
	                var id = getTypeListId(typeArguments);
	                return links.instantiations[id] || (links.instantiations[id] = instantiateType(type, createTypeMapper(typeParameters, typeArguments)));
	            }
	            if (node.typeArguments) {
	                error(node, ts.Diagnostics.Type_0_is_not_generic, symbolToString(symbol));
	                return unknownType;
	            }
	            return type;
	        }
	        // Get type from reference to named type that cannot be generic (enum or type parameter)
	        function getTypeFromNonGenericTypeReference(node, symbol) {
	            if (node.typeArguments) {
	                error(node, ts.Diagnostics.Type_0_is_not_generic, symbolToString(symbol));
	                return unknownType;
	            }
	            return getDeclaredTypeOfSymbol(symbol);
	        }
	        function getTypeReferenceName(node) {
	            switch (node.kind) {
	                case 152 /* TypeReference */:
	                    return node.typeName;
	                case 262 /* JSDocTypeReference */:
	                    return node.name;
	                case 191 /* ExpressionWithTypeArguments */:
	                    // We only support expressions that are simple qualified names. For other
	                    // expressions this produces undefined.
	                    if (ts.isSupportedExpressionWithTypeArguments(node)) {
	                        return node.expression;
	                    }
	            }
	            return undefined;
	        }
	        function resolveTypeReferenceName(node, typeReferenceName) {
	            if (!typeReferenceName) {
	                return unknownSymbol;
	            }
	            return resolveEntityName(typeReferenceName, 793056 /* Type */) || unknownSymbol;
	        }
	        function getTypeReferenceType(node, symbol) {
	            if (symbol === unknownSymbol) {
	                return unknownType;
	            }
	            if (symbol.flags & (32 /* Class */ | 64 /* Interface */)) {
	                return getTypeFromClassOrInterfaceReference(node, symbol);
	            }
	            if (symbol.flags & 524288 /* TypeAlias */) {
	                return getTypeFromTypeAliasReference(node, symbol);
	            }
	            if (symbol.flags & 107455 /* Value */ && node.kind === 262 /* JSDocTypeReference */) {
	                // A JSDocTypeReference may have resolved to a value (as opposed to a type). In
	                // that case, the type of this reference is just the type of the value we resolved
	                // to.
	                return getTypeOfSymbol(symbol);
	            }
	            return getTypeFromNonGenericTypeReference(node, symbol);
	        }
	        function getTypeFromTypeReference(node) {
	            var links = getNodeLinks(node);
	            if (!links.resolvedType) {
	                var symbol = void 0;
	                var type = void 0;
	                if (node.kind === 262 /* JSDocTypeReference */) {
	                    var typeReferenceName = getTypeReferenceName(node);
	                    symbol = resolveTypeReferenceName(node, typeReferenceName);
	                    type = getTypeReferenceType(node, symbol);
	                    links.resolvedSymbol = symbol;
	                    links.resolvedType = type;
	                }
	                else {
	                    // We only support expressions that are simple qualified names. For other expressions this produces undefined.
	                    var typeNameOrExpression = node.kind === 152 /* TypeReference */ ? node.typeName :
	                        ts.isSupportedExpressionWithTypeArguments(node) ? node.expression :
	                            undefined;
	                    symbol = typeNameOrExpression && resolveEntityName(typeNameOrExpression, 793056 /* Type */) || unknownSymbol;
	                    type = symbol === unknownSymbol ? unknownType :
	                        symbol.flags & (32 /* Class */ | 64 /* Interface */) ? getTypeFromClassOrInterfaceReference(node, symbol) :
	                            symbol.flags & 524288 /* TypeAlias */ ? getTypeFromTypeAliasReference(node, symbol) :
	                                getTypeFromNonGenericTypeReference(node, symbol);
	                }
	                // Cache both the resolved symbol and the resolved type. The resolved symbol is needed in when we check the
	                // type reference in checkTypeReferenceOrExpressionWithTypeArguments.
	                links.resolvedSymbol = symbol;
	                links.resolvedType = type;
	            }
	            return links.resolvedType;
	        }
	        function getTypeFromTypeQueryNode(node) {
	            var links = getNodeLinks(node);
	            if (!links.resolvedType) {
	                // TypeScript 1.0 spec (April 2014): 3.6.3
	                // The expression is processed as an identifier expression (section 4.3)
	                // or property access expression(section 4.10),
	                // the widened type(section 3.9) of which becomes the result.
	                links.resolvedType = getWidenedType(checkExpression(node.exprName));
	            }
	            return links.resolvedType;
	        }
	        function getTypeOfGlobalSymbol(symbol, arity) {
	            function getTypeDeclaration(symbol) {
	                var declarations = symbol.declarations;
	                for (var _i = 0, declarations_3 = declarations; _i < declarations_3.length; _i++) {
	                    var declaration = declarations_3[_i];
	                    switch (declaration.kind) {
	                        case 217 /* ClassDeclaration */:
	                        case 218 /* InterfaceDeclaration */:
	                        case 220 /* EnumDeclaration */:
	                            return declaration;
	                    }
	                }
	            }
	            if (!symbol) {
	                return arity ? emptyGenericType : emptyObjectType;
	            }
	            var type = getDeclaredTypeOfSymbol(symbol);
	            if (!(type.flags & 80896 /* ObjectType */)) {
	                error(getTypeDeclaration(symbol), ts.Diagnostics.Global_type_0_must_be_a_class_or_interface_type, symbol.name);
	                return arity ? emptyGenericType : emptyObjectType;
	            }
	            if ((type.typeParameters ? type.typeParameters.length : 0) !== arity) {
	                error(getTypeDeclaration(symbol), ts.Diagnostics.Global_type_0_must_have_1_type_parameter_s, symbol.name, arity);
	                return arity ? emptyGenericType : emptyObjectType;
	            }
	            return type;
	        }
	        function getGlobalValueSymbol(name) {
	            return getGlobalSymbol(name, 107455 /* Value */, ts.Diagnostics.Cannot_find_global_value_0);
	        }
	        function getGlobalTypeSymbol(name) {
	            return getGlobalSymbol(name, 793056 /* Type */, ts.Diagnostics.Cannot_find_global_type_0);
	        }
	        function getGlobalSymbol(name, meaning, diagnostic) {
	            return resolveName(undefined, name, meaning, diagnostic, name);
	        }
	        function getGlobalType(name, arity) {
	            if (arity === void 0) { arity = 0; }
	            return getTypeOfGlobalSymbol(getGlobalTypeSymbol(name), arity);
	        }
	        /**
	         * Returns a type that is inside a namespace at the global scope, e.g.
	         * getExportedTypeFromNamespace('JSX', 'Element') returns the JSX.Element type
	         */
	        function getExportedTypeFromNamespace(namespace, name) {
	            var namespaceSymbol = getGlobalSymbol(namespace, 1536 /* Namespace */, /*diagnosticMessage*/ undefined);
	            var typeSymbol = namespaceSymbol && getSymbol(namespaceSymbol.exports, name, 793056 /* Type */);
	            return typeSymbol && getDeclaredTypeOfSymbol(typeSymbol);
	        }
	        function getGlobalESSymbolConstructorSymbol() {
	            return globalESSymbolConstructorSymbol || (globalESSymbolConstructorSymbol = getGlobalValueSymbol("Symbol"));
	        }
	        /**
	          * Creates a TypeReference for a generic `TypedPropertyDescriptor<T>`.
	          */
	        function createTypedPropertyDescriptorType(propertyType) {
	            var globalTypedPropertyDescriptorType = getGlobalTypedPropertyDescriptorType();
	            return globalTypedPropertyDescriptorType !== emptyGenericType
	                ? createTypeReference(globalTypedPropertyDescriptorType, [propertyType])
	                : emptyObjectType;
	        }
	        /**
	         * Instantiates a global type that is generic with some element type, and returns that instantiation.
	         */
	        function createTypeFromGenericGlobalType(genericGlobalType, typeArguments) {
	            return genericGlobalType !== emptyGenericType ? createTypeReference(genericGlobalType, typeArguments) : emptyObjectType;
	        }
	        function createIterableType(elementType) {
	            return createTypeFromGenericGlobalType(globalIterableType, [elementType]);
	        }
	        function createIterableIteratorType(elementType) {
	            return createTypeFromGenericGlobalType(globalIterableIteratorType, [elementType]);
	        }
	        function createArrayType(elementType) {
	            return createTypeFromGenericGlobalType(globalArrayType, [elementType]);
	        }
	        function getTypeFromArrayTypeNode(node) {
	            var links = getNodeLinks(node);
	            if (!links.resolvedType) {
	                links.resolvedType = createArrayType(getTypeFromTypeNode(node.elementType));
	            }
	            return links.resolvedType;
	        }
	        function createTupleType(elementTypes) {
	            var id = getTypeListId(elementTypes);
	            return tupleTypes[id] || (tupleTypes[id] = createNewTupleType(elementTypes));
	        }
	        function createNewTupleType(elementTypes) {
	            var type = createObjectType(8192 /* Tuple */ | getPropagatingFlagsOfTypes(elementTypes));
	            type.elementTypes = elementTypes;
	            return type;
	        }
	        function getTypeFromTupleTypeNode(node) {
	            var links = getNodeLinks(node);
	            if (!links.resolvedType) {
	                links.resolvedType = createTupleType(ts.map(node.elementTypes, getTypeFromTypeNode));
	            }
	            return links.resolvedType;
	        }
	        function addTypeToSet(typeSet, type, typeSetKind) {
	            if (type.flags & typeSetKind) {
	                addTypesToSet(typeSet, type.types, typeSetKind);
	            }
	            else if (!ts.contains(typeSet, type)) {
	                typeSet.push(type);
	            }
	        }
	        // Add the given types to the given type set. Order is preserved, duplicates are removed,
	        // and nested types of the given kind are flattened into the set.
	        function addTypesToSet(typeSet, types, typeSetKind) {
	            for (var _i = 0, types_4 = types; _i < types_4.length; _i++) {
	                var type = types_4[_i];
	                addTypeToSet(typeSet, type, typeSetKind);
	            }
	        }
	        function isSubtypeOfAny(candidate, types) {
	            for (var i = 0, len = types.length; i < len; i++) {
	                if (candidate !== types[i] && isTypeSubtypeOf(candidate, types[i])) {
	                    return true;
	                }
	            }
	            return false;
	        }
	        function removeSubtypes(types) {
	            var i = types.length;
	            while (i > 0) {
	                i--;
	                if (isSubtypeOfAny(types[i], types)) {
	                    types.splice(i, 1);
	                }
	            }
	        }
	        function containsTypeAny(types) {
	            for (var _i = 0, types_5 = types; _i < types_5.length; _i++) {
	                var type = types_5[_i];
	                if (isTypeAny(type)) {
	                    return true;
	                }
	            }
	            return false;
	        }
	        function removeAllButLast(types, typeToRemove) {
	            var i = types.length;
	            while (i > 0 && types.length > 1) {
	                i--;
	                if (types[i] === typeToRemove) {
	                    types.splice(i, 1);
	                }
	            }
	        }
	        // We reduce the constituent type set to only include types that aren't subtypes of other types, unless
	        // the noSubtypeReduction flag is specified, in which case we perform a simple deduplication based on
	        // object identity. Subtype reduction is possible only when union types are known not to circularly
	        // reference themselves (as is the case with union types created by expression constructs such as array
	        // literals and the || and ?: operators). Named types can circularly reference themselves and therefore
	        // cannot be deduplicated during their declaration. For example, "type Item = string | (() => Item" is
	        // a named type that circularly references itself.
	        function getUnionType(types, noSubtypeReduction) {
	            if (types.length === 0) {
	                return emptyUnionType;
	            }
	            var typeSet = [];
	            addTypesToSet(typeSet, types, 16384 /* Union */);
	            if (containsTypeAny(typeSet)) {
	                return anyType;
	            }
	            if (noSubtypeReduction) {
	                removeAllButLast(typeSet, undefinedType);
	                removeAllButLast(typeSet, nullType);
	            }
	            else {
	                removeSubtypes(typeSet);
	            }
	            if (typeSet.length === 1) {
	                return typeSet[0];
	            }
	            var id = getTypeListId(typeSet);
	            var type = unionTypes[id];
	            if (!type) {
	                type = unionTypes[id] = createObjectType(16384 /* Union */ | getPropagatingFlagsOfTypes(typeSet));
	                type.types = typeSet;
	            }
	            return type;
	        }
	        function getTypeFromUnionTypeNode(node) {
	            var links = getNodeLinks(node);
	            if (!links.resolvedType) {
	                links.resolvedType = getUnionType(ts.map(node.types, getTypeFromTypeNode), /*noSubtypeReduction*/ true);
	            }
	            return links.resolvedType;
	        }
	        // We do not perform structural deduplication on intersection types. Intersection types are created only by the &
	        // type operator and we can't reduce those because we want to support recursive intersection types. For example,
	        // a type alias of the form "type List<T> = T & { next: List<T> }" cannot be reduced during its declaration.
	        // Also, unlike union types, the order of the constituent types is preserved in order that overload resolution
	        // for intersections of types with signatures can be deterministic.
	        function getIntersectionType(types) {
	            if (types.length === 0) {
	                return emptyObjectType;
	            }
	            var typeSet = [];
	            addTypesToSet(typeSet, types, 32768 /* Intersection */);
	            if (containsTypeAny(typeSet)) {
	                return anyType;
	            }
	            if (typeSet.length === 1) {
	                return typeSet[0];
	            }
	            var id = getTypeListId(typeSet);
	            var type = intersectionTypes[id];
	            if (!type) {
	                type = intersectionTypes[id] = createObjectType(32768 /* Intersection */ | getPropagatingFlagsOfTypes(typeSet));
	                type.types = typeSet;
	            }
	            return type;
	        }
	        function getTypeFromIntersectionTypeNode(node) {
	            var links = getNodeLinks(node);
	            if (!links.resolvedType) {
	                links.resolvedType = getIntersectionType(ts.map(node.types, getTypeFromTypeNode));
	            }
	            return links.resolvedType;
	        }
	        function getTypeFromTypeLiteralOrFunctionOrConstructorTypeNode(node) {
	            var links = getNodeLinks(node);
	            if (!links.resolvedType) {
	                // Deferred resolution of members is handled by resolveObjectTypeMembers
	                links.resolvedType = createObjectType(65536 /* Anonymous */, node.symbol);
	            }
	            return links.resolvedType;
	        }
	        function getStringLiteralTypeForText(text) {
	            if (ts.hasProperty(stringLiteralTypes, text)) {
	                return stringLiteralTypes[text];
	            }
	            var type = stringLiteralTypes[text] = createType(256 /* StringLiteral */);
	            type.text = text;
	            return type;
	        }
	        function getTypeFromStringLiteralTypeNode(node) {
	            var links = getNodeLinks(node);
	            if (!links.resolvedType) {
	                links.resolvedType = getStringLiteralTypeForText(node.text);
	            }
	            return links.resolvedType;
	        }
	        function getTypeFromJSDocVariadicType(node) {
	            var links = getNodeLinks(node);
	            if (!links.resolvedType) {
	                var type = getTypeFromTypeNode(node.type);
	                links.resolvedType = type ? createArrayType(type) : unknownType;
	            }
	            return links.resolvedType;
	        }
	        function getTypeFromJSDocTupleType(node) {
	            var links = getNodeLinks(node);
	            if (!links.resolvedType) {
	                var types = ts.map(node.types, getTypeFromTypeNode);
	                links.resolvedType = createTupleType(types);
	            }
	            return links.resolvedType;
	        }
	        function getThisType(node) {
	            var container = ts.getThisContainer(node, /*includeArrowFunctions*/ false);
	            var parent = container && container.parent;
	            if (parent && (ts.isClassLike(parent) || parent.kind === 218 /* InterfaceDeclaration */)) {
	                if (!(container.flags & 64 /* Static */) &&
	                    (container.kind !== 145 /* Constructor */ || ts.isNodeDescendentOf(node, container.body))) {
	                    return getDeclaredTypeOfClassOrInterface(getSymbolOfNode(parent)).thisType;
	                }
	            }
	            error(node, ts.Diagnostics.A_this_type_is_available_only_in_a_non_static_member_of_a_class_or_interface);
	            return unknownType;
	        }
	        function getTypeFromThisTypeNode(node) {
	            var links = getNodeLinks(node);
	            if (!links.resolvedType) {
	                links.resolvedType = getThisType(node);
	            }
	            return links.resolvedType;
	        }
	        function getTypeFromTypeNode(node) {
	            switch (node.kind) {
	                case 117 /* AnyKeyword */:
	                case 253 /* JSDocAllType */:
	                case 254 /* JSDocUnknownType */:
	                    return anyType;
	                case 130 /* StringKeyword */:
	                    return stringType;
	                case 128 /* NumberKeyword */:
	                    return numberType;
	                case 120 /* BooleanKeyword */:
	                    return booleanType;
	                case 131 /* SymbolKeyword */:
	                    return esSymbolType;
	                case 103 /* VoidKeyword */:
	                    return voidType;
	                case 162 /* ThisType */:
	                    return getTypeFromThisTypeNode(node);
	                case 163 /* StringLiteralType */:
	                    return getTypeFromStringLiteralTypeNode(node);
	                case 152 /* TypeReference */:
	                case 262 /* JSDocTypeReference */:
	                    return getTypeFromTypeReference(node);
	                case 151 /* TypePredicate */:
	                    return booleanType;
	                case 191 /* ExpressionWithTypeArguments */:
	                    return getTypeFromTypeReference(node);
	                case 155 /* TypeQuery */:
	                    return getTypeFromTypeQueryNode(node);
	                case 157 /* ArrayType */:
	                case 255 /* JSDocArrayType */:
	                    return getTypeFromArrayTypeNode(node);
	                case 158 /* TupleType */:
	                    return getTypeFromTupleTypeNode(node);
	                case 159 /* UnionType */:
	                case 256 /* JSDocUnionType */:
	                    return getTypeFromUnionTypeNode(node);
	                case 160 /* IntersectionType */:
	                    return getTypeFromIntersectionTypeNode(node);
	                case 161 /* ParenthesizedType */:
	                case 258 /* JSDocNullableType */:
	                case 259 /* JSDocNonNullableType */:
	                case 266 /* JSDocConstructorType */:
	                case 267 /* JSDocThisType */:
	                case 263 /* JSDocOptionalType */:
	                    return getTypeFromTypeNode(node.type);
	                case 153 /* FunctionType */:
	                case 154 /* ConstructorType */:
	                case 156 /* TypeLiteral */:
	                case 264 /* JSDocFunctionType */:
	                case 260 /* JSDocRecordType */:
	                    return getTypeFromTypeLiteralOrFunctionOrConstructorTypeNode(node);
	                // This function assumes that an identifier or qualified name is a type expression
	                // Callers should first ensure this by calling isTypeNode
	                case 69 /* Identifier */:
	                case 136 /* QualifiedName */:
	                    var symbol = getSymbolAtLocation(node);
	                    return symbol && getDeclaredTypeOfSymbol(symbol);
	                case 257 /* JSDocTupleType */:
	                    return getTypeFromJSDocTupleType(node);
	                case 265 /* JSDocVariadicType */:
	                    return getTypeFromJSDocVariadicType(node);
	                default:
	                    return unknownType;
	            }
	        }
	        function instantiateList(items, mapper, instantiator) {
	            if (items && items.length) {
	                var result = [];
	                for (var _i = 0, items_1 = items; _i < items_1.length; _i++) {
	                    var v = items_1[_i];
	                    result.push(instantiator(v, mapper));
	                }
	                return result;
	            }
	            return items;
	        }
	        function createUnaryTypeMapper(source, target) {
	            return function (t) { return t === source ? target : t; };
	        }
	        function createBinaryTypeMapper(source1, target1, source2, target2) {
	            return function (t) { return t === source1 ? target1 : t === source2 ? target2 : t; };
	        }
	        function createTypeMapper(sources, targets) {
	            switch (sources.length) {
	                case 1: return createUnaryTypeMapper(sources[0], targets[0]);
	                case 2: return createBinaryTypeMapper(sources[0], targets[0], sources[1], targets[1]);
	            }
	            return function (t) {
	                for (var i = 0; i < sources.length; i++) {
	                    if (t === sources[i]) {
	                        return targets[i];
	                    }
	                }
	                return t;
	            };
	        }
	        function createUnaryTypeEraser(source) {
	            return function (t) { return t === source ? anyType : t; };
	        }
	        function createBinaryTypeEraser(source1, source2) {
	            return function (t) { return t === source1 || t === source2 ? anyType : t; };
	        }
	        function createTypeEraser(sources) {
	            switch (sources.length) {
	                case 1: return createUnaryTypeEraser(sources[0]);
	                case 2: return createBinaryTypeEraser(sources[0], sources[1]);
	            }
	            return function (t) {
	                for (var _i = 0, sources_1 = sources; _i < sources_1.length; _i++) {
	                    var source = sources_1[_i];
	                    if (t === source) {
	                        return anyType;
	                    }
	                }
	                return t;
	            };
	        }
	        function getInferenceMapper(context) {
	            if (!context.mapper) {
	                var mapper = function (t) {
	                    var typeParameters = context.typeParameters;
	                    for (var i = 0; i < typeParameters.length; i++) {
	                        if (t === typeParameters[i]) {
	                            context.inferences[i].isFixed = true;
	                            return getInferredType(context, i);
	                        }
	                    }
	                    return t;
	                };
	                mapper.context = context;
	                context.mapper = mapper;
	            }
	            return context.mapper;
	        }
	        function identityMapper(type) {
	            return type;
	        }
	        function combineTypeMappers(mapper1, mapper2) {
	            return function (t) { return instantiateType(mapper1(t), mapper2); };
	        }
	        function cloneTypeParameter(typeParameter) {
	            var result = createType(512 /* TypeParameter */);
	            result.symbol = typeParameter.symbol;
	            result.target = typeParameter;
	            return result;
	        }
	        function cloneTypePredicate(predicate, mapper) {
	            if (ts.isIdentifierTypePredicate(predicate)) {
	                return {
	                    kind: 1 /* Identifier */,
	                    parameterName: predicate.parameterName,
	                    parameterIndex: predicate.parameterIndex,
	                    type: instantiateType(predicate.type, mapper)
	                };
	            }
	            else {
	                return {
	                    kind: 0 /* This */,
	                    type: instantiateType(predicate.type, mapper)
	                };
	            }
	        }
	        function instantiateSignature(signature, mapper, eraseTypeParameters) {
	            var freshTypeParameters;
	            var freshTypePredicate;
	            if (signature.typeParameters && !eraseTypeParameters) {
	                // First create a fresh set of type parameters, then include a mapping from the old to the
	                // new type parameters in the mapper function. Finally store this mapper in the new type
	                // parameters such that we can use it when instantiating constraints.
	                freshTypeParameters = ts.map(signature.typeParameters, cloneTypeParameter);
	                mapper = combineTypeMappers(createTypeMapper(signature.typeParameters, freshTypeParameters), mapper);
	                for (var _i = 0, freshTypeParameters_1 = freshTypeParameters; _i < freshTypeParameters_1.length; _i++) {
	                    var tp = freshTypeParameters_1[_i];
	                    tp.mapper = mapper;
	                }
	            }
	            if (signature.typePredicate) {
	                freshTypePredicate = cloneTypePredicate(signature.typePredicate, mapper);
	            }
	            var result = createSignature(signature.declaration, freshTypeParameters, instantiateList(signature.parameters, mapper, instantiateSymbol), instantiateType(signature.resolvedReturnType, mapper), freshTypePredicate, signature.minArgumentCount, signature.hasRestParameter, signature.hasStringLiterals);
	            result.target = signature;
	            result.mapper = mapper;
	            return result;
	        }
	        function instantiateSymbol(symbol, mapper) {
	            if (symbol.flags & 16777216 /* Instantiated */) {
	                var links = getSymbolLinks(symbol);
	                // If symbol being instantiated is itself a instantiation, fetch the original target and combine the
	                // type mappers. This ensures that original type identities are properly preserved and that aliases
	                // always reference a non-aliases.
	                symbol = links.target;
	                mapper = combineTypeMappers(links.mapper, mapper);
	            }
	            // Keep the flags from the symbol we're instantiating.  Mark that is instantiated, and
	            // also transient so that we can just store data on it directly.
	            var result = createSymbol(16777216 /* Instantiated */ | 67108864 /* Transient */ | symbol.flags, symbol.name);
	            result.declarations = symbol.declarations;
	            result.parent = symbol.parent;
	            result.target = symbol;
	            result.mapper = mapper;
	            if (symbol.valueDeclaration) {
	                result.valueDeclaration = symbol.valueDeclaration;
	            }
	            return result;
	        }
	        function instantiateAnonymousType(type, mapper) {
	            if (mapper.instantiations) {
	                var cachedType = mapper.instantiations[type.id];
	                if (cachedType) {
	                    return cachedType;
	                }
	            }
	            else {
	                mapper.instantiations = [];
	            }
	            // Mark the anonymous type as instantiated such that our infinite instantiation detection logic can recognize it
	            var result = createObjectType(65536 /* Anonymous */ | 131072 /* Instantiated */, type.symbol);
	            result.target = type;
	            result.mapper = mapper;
	            mapper.instantiations[type.id] = result;
	            return result;
	        }
	        function instantiateType(type, mapper) {
	            if (type && mapper !== identityMapper) {
	                if (type.flags & 512 /* TypeParameter */) {
	                    return mapper(type);
	                }
	                if (type.flags & 65536 /* Anonymous */) {
	                    return type.symbol && type.symbol.flags & (16 /* Function */ | 8192 /* Method */ | 32 /* Class */ | 2048 /* TypeLiteral */ | 4096 /* ObjectLiteral */) ?
	                        instantiateAnonymousType(type, mapper) : type;
	                }
	                if (type.flags & 4096 /* Reference */) {
	                    return createTypeReference(type.target, instantiateList(type.typeArguments, mapper, instantiateType));
	                }
	                if (type.flags & 8192 /* Tuple */) {
	                    return createTupleType(instantiateList(type.elementTypes, mapper, instantiateType));
	                }
	                if (type.flags & 16384 /* Union */) {
	                    return getUnionType(instantiateList(type.types, mapper, instantiateType), /*noSubtypeReduction*/ true);
	                }
	                if (type.flags & 32768 /* Intersection */) {
	                    return getIntersectionType(instantiateList(type.types, mapper, instantiateType));
	                }
	            }
	            return type;
	        }
	        // Returns true if the given expression contains (at any level of nesting) a function or arrow expression
	        // that is subject to contextual typing.
	        function isContextSensitive(node) {
	            ts.Debug.assert(node.kind !== 144 /* MethodDeclaration */ || ts.isObjectLiteralMethod(node));
	            switch (node.kind) {
	                case 176 /* FunctionExpression */:
	                case 177 /* ArrowFunction */:
	                    return isContextSensitiveFunctionLikeDeclaration(node);
	                case 168 /* ObjectLiteralExpression */:
	                    return ts.forEach(node.properties, isContextSensitive);
	                case 167 /* ArrayLiteralExpression */:
	                    return ts.forEach(node.elements, isContextSensitive);
	                case 185 /* ConditionalExpression */:
	                    return isContextSensitive(node.whenTrue) ||
	                        isContextSensitive(node.whenFalse);
	                case 184 /* BinaryExpression */:
	                    return node.operatorToken.kind === 52 /* BarBarToken */ &&
	                        (isContextSensitive(node.left) || isContextSensitive(node.right));
	                case 248 /* PropertyAssignment */:
	                    return isContextSensitive(node.initializer);
	                case 144 /* MethodDeclaration */:
	                case 143 /* MethodSignature */:
	                    return isContextSensitiveFunctionLikeDeclaration(node);
	                case 175 /* ParenthesizedExpression */:
	                    return isContextSensitive(node.expression);
	            }
	            return false;
	        }
	        function isContextSensitiveFunctionLikeDeclaration(node) {
	            return !node.typeParameters && node.parameters.length && !ts.forEach(node.parameters, function (p) { return p.type; });
	        }
	        function getTypeWithoutSignatures(type) {
	            if (type.flags & 80896 /* ObjectType */) {
	                var resolved = resolveStructuredTypeMembers(type);
	                if (resolved.constructSignatures.length) {
	                    var result = createObjectType(65536 /* Anonymous */, type.symbol);
	                    result.members = resolved.members;
	                    result.properties = resolved.properties;
	                    result.callSignatures = emptyArray;
	                    result.constructSignatures = emptyArray;
	                    type = result;
	                }
	            }
	            return type;
	        }
	        // TYPE CHECKING
	        function isTypeIdenticalTo(source, target) {
	            return checkTypeRelatedTo(source, target, identityRelation, /*errorNode*/ undefined);
	        }
	        function compareTypesIdentical(source, target) {
	            return checkTypeRelatedTo(source, target, identityRelation, /*errorNode*/ undefined) ? -1 /* True */ : 0 /* False */;
	        }
	        function compareTypesAssignable(source, target) {
	            return checkTypeRelatedTo(source, target, assignableRelation, /*errorNode*/ undefined) ? -1 /* True */ : 0 /* False */;
	        }
	        function isTypeSubtypeOf(source, target) {
	            return checkTypeSubtypeOf(source, target, /*errorNode*/ undefined);
	        }
	        function isTypeAssignableTo(source, target) {
	            return checkTypeAssignableTo(source, target, /*errorNode*/ undefined);
	        }
	        function checkTypeSubtypeOf(source, target, errorNode, headMessage, containingMessageChain) {
	            return checkTypeRelatedTo(source, target, subtypeRelation, errorNode, headMessage, containingMessageChain);
	        }
	        function checkTypeAssignableTo(source, target, errorNode, headMessage, containingMessageChain) {
	            return checkTypeRelatedTo(source, target, assignableRelation, errorNode, headMessage, containingMessageChain);
	        }
	        function isSignatureAssignableTo(source, target, ignoreReturnTypes) {
	            return compareSignaturesRelated(source, target, ignoreReturnTypes, /*reportErrors*/ false, /*errorReporter*/ undefined, compareTypesAssignable) !== 0 /* False */;
	        }
	        /**
	         * See signatureRelatedTo, compareSignaturesIdentical
	         */
	        function compareSignaturesRelated(source, target, ignoreReturnTypes, reportErrors, errorReporter, compareTypes) {
	            // TODO (drosen): De-duplicate code between related functions.
	            if (source === target) {
	                return -1 /* True */;
	            }
	            if (!target.hasRestParameter && source.minArgumentCount > target.parameters.length) {
	                return 0 /* False */;
	            }
	            // Spec 1.0 Section 3.8.3 & 3.8.4:
	            // M and N (the signatures) are instantiated using type Any as the type argument for all type parameters declared by M and N
	            source = getErasedSignature(source);
	            target = getErasedSignature(target);
	            var result = -1 /* True */;
	            var sourceMax = getNumNonRestParameters(source);
	            var targetMax = getNumNonRestParameters(target);
	            var checkCount = getNumParametersToCheckForSignatureRelatability(source, sourceMax, target, targetMax);
	            var sourceParams = source.parameters;
	            var targetParams = target.parameters;
	            for (var i = 0; i < checkCount; i++) {
	                var s = i < sourceMax ? getTypeOfSymbol(sourceParams[i]) : getRestTypeOfSignature(source);
	                var t = i < targetMax ? getTypeOfSymbol(targetParams[i]) : getRestTypeOfSignature(target);
	                var related = compareTypes(t, s, /*reportErrors*/ false) || compareTypes(s, t, reportErrors);
	                if (!related) {
	                    if (reportErrors) {
	                        errorReporter(ts.Diagnostics.Types_of_parameters_0_and_1_are_incompatible, sourceParams[i < sourceMax ? i : sourceMax].name, targetParams[i < targetMax ? i : targetMax].name);
	                    }
	                    return 0 /* False */;
	                }
	                result &= related;
	            }
	            if (!ignoreReturnTypes) {
	                var targetReturnType = getReturnTypeOfSignature(target);
	                if (targetReturnType === voidType) {
	                    return result;
	                }
	                var sourceReturnType = getReturnTypeOfSignature(source);
	                // The following block preserves behavior forbidding boolean returning functions from being assignable to type guard returning functions
	                if (target.typePredicate) {
	                    if (source.typePredicate) {
	                        result &= compareTypePredicateRelatedTo(source.typePredicate, target.typePredicate, reportErrors, errorReporter, compareTypes);
	                    }
	                    else if (ts.isIdentifierTypePredicate(target.typePredicate)) {
	                        if (reportErrors) {
	                            errorReporter(ts.Diagnostics.Signature_0_must_have_a_type_predicate, signatureToString(source));
	                        }
	                        return 0 /* False */;
	                    }
	                }
	                else {
	                    result &= compareTypes(sourceReturnType, targetReturnType, reportErrors);
	                }
	            }
	            return result;
	        }
	        function compareTypePredicateRelatedTo(source, target, reportErrors, errorReporter, compareTypes) {
	            if (source.kind !== target.kind) {
	                if (reportErrors) {
	                    errorReporter(ts.Diagnostics.A_this_based_type_guard_is_not_compatible_with_a_parameter_based_type_guard);
	                    errorReporter(ts.Diagnostics.Type_predicate_0_is_not_assignable_to_1, typePredicateToString(source), typePredicateToString(target));
	                }
	                return 0 /* False */;
	            }
	            if (source.kind === 1 /* Identifier */) {
	                var sourceIdentifierPredicate = source;
	                var targetIdentifierPredicate = target;
	                if (sourceIdentifierPredicate.parameterIndex !== targetIdentifierPredicate.parameterIndex) {
	                    if (reportErrors) {
	                        errorReporter(ts.Diagnostics.Parameter_0_is_not_in_the_same_position_as_parameter_1, sourceIdentifierPredicate.parameterName, targetIdentifierPredicate.parameterName);
	                        errorReporter(ts.Diagnostics.Type_predicate_0_is_not_assignable_to_1, typePredicateToString(source), typePredicateToString(target));
	                    }
	                    return 0 /* False */;
	                }
	            }
	            var related = compareTypes(source.type, target.type, reportErrors);
	            if (related === 0 /* False */ && reportErrors) {
	                errorReporter(ts.Diagnostics.Type_predicate_0_is_not_assignable_to_1, typePredicateToString(source), typePredicateToString(target));
	            }
	            return related;
	        }
	        function isImplementationCompatibleWithOverload(implementation, overload) {
	            var erasedSource = getErasedSignature(implementation);
	            var erasedTarget = getErasedSignature(overload);
	            // First see if the return types are compatible in either direction.
	            var sourceReturnType = getReturnTypeOfSignature(erasedSource);
	            var targetReturnType = getReturnTypeOfSignature(erasedTarget);
	            if (targetReturnType === voidType
	                || checkTypeRelatedTo(targetReturnType, sourceReturnType, assignableRelation, /*errorNode*/ undefined)
	                || checkTypeRelatedTo(sourceReturnType, targetReturnType, assignableRelation, /*errorNode*/ undefined)) {
	                return isSignatureAssignableTo(erasedSource, erasedTarget, /*ignoreReturnTypes*/ true);
	            }
	            return false;
	        }
	        function getNumNonRestParameters(signature) {
	            var numParams = signature.parameters.length;
	            return signature.hasRestParameter ?
	                numParams - 1 :
	                numParams;
	        }
	        function getNumParametersToCheckForSignatureRelatability(source, sourceNonRestParamCount, target, targetNonRestParamCount) {
	            if (source.hasRestParameter === target.hasRestParameter) {
	                if (source.hasRestParameter) {
	                    // If both have rest parameters, get the max and add 1 to
	                    // compensate for the rest parameter.
	                    return Math.max(sourceNonRestParamCount, targetNonRestParamCount) + 1;
	                }
	                else {
	                    return Math.min(sourceNonRestParamCount, targetNonRestParamCount);
	                }
	            }
	            else {
	                // Return the count for whichever signature doesn't have rest parameters.
	                return source.hasRestParameter ?
	                    targetNonRestParamCount :
	                    sourceNonRestParamCount;
	            }
	        }
	        /**
	         * Checks if 'source' is related to 'target' (e.g.: is a assignable to).
	         * @param source The left-hand-side of the relation.
	         * @param target The right-hand-side of the relation.
	         * @param relation The relation considered. One of 'identityRelation', 'assignableRelation', or 'subTypeRelation'.
	         * Used as both to determine which checks are performed and as a cache of previously computed results.
	         * @param errorNode The suggested node upon which all errors will be reported, if defined. This may or may not be the actual node used.
	         * @param headMessage If the error chain should be prepended by a head message, then headMessage will be used.
	         * @param containingMessageChain A chain of errors to prepend any new errors found.
	         */
	        function checkTypeRelatedTo(source, target, relation, errorNode, headMessage, containingMessageChain) {
	            var errorInfo;
	            var sourceStack;
	            var targetStack;
	            var maybeStack;
	            var expandingFlags;
	            var depth = 0;
	            var overflow = false;
	            ts.Debug.assert(relation !== identityRelation || !errorNode, "no error reporting in identity checking");
	            var result = isRelatedTo(source, target, /*reportErrors*/ !!errorNode, headMessage);
	            if (overflow) {
	                error(errorNode, ts.Diagnostics.Excessive_stack_depth_comparing_types_0_and_1, typeToString(source), typeToString(target));
	            }
	            else if (errorInfo) {
	                if (containingMessageChain) {
	                    errorInfo = ts.concatenateDiagnosticMessageChains(containingMessageChain, errorInfo);
	                }
	                diagnostics.add(ts.createDiagnosticForNodeFromMessageChain(errorNode, errorInfo));
	            }
	            return result !== 0 /* False */;
	            function reportError(message, arg0, arg1, arg2) {
	                ts.Debug.assert(!!errorNode);
	                errorInfo = ts.chainDiagnosticMessages(errorInfo, message, arg0, arg1, arg2);
	            }
	            function reportRelationError(message, source, target) {
	                var sourceType = typeToString(source);
	                var targetType = typeToString(target);
	                if (sourceType === targetType) {
	                    sourceType = typeToString(source, /*enclosingDeclaration*/ undefined, 128 /* UseFullyQualifiedType */);
	                    targetType = typeToString(target, /*enclosingDeclaration*/ undefined, 128 /* UseFullyQualifiedType */);
	                }
	                reportError(message || ts.Diagnostics.Type_0_is_not_assignable_to_type_1, sourceType, targetType);
	            }
	            // Compare two types and return
	            // Ternary.True if they are related with no assumptions,
	            // Ternary.Maybe if they are related with assumptions of other relationships, or
	            // Ternary.False if they are not related.
	            function isRelatedTo(source, target, reportErrors, headMessage) {
	                var result;
	                // both types are the same - covers 'they are the same primitive type or both are Any' or the same type parameter cases
	                if (source === target)
	                    return -1 /* True */;
	                if (relation === identityRelation) {
	                    return isIdenticalTo(source, target);
	                }
	                if (isTypeAny(target))
	                    return -1 /* True */;
	                if (source === undefinedType)
	                    return -1 /* True */;
	                if (source === nullType && target !== undefinedType)
	                    return -1 /* True */;
	                if (source.flags & 128 /* Enum */ && target === numberType)
	                    return -1 /* True */;
	                if (source.flags & 128 /* Enum */ && target.flags & 128 /* Enum */) {
	                    if (result = enumRelatedTo(source, target)) {
	                        return result;
	                    }
	                }
	                if (source.flags & 256 /* StringLiteral */ && target === stringType)
	                    return -1 /* True */;
	                if (relation === assignableRelation) {
	                    if (isTypeAny(source))
	                        return -1 /* True */;
	                    if (source === numberType && target.flags & 128 /* Enum */)
	                        return -1 /* True */;
	                }
	                if (source.flags & 8 /* Boolean */ && target.flags & 8 /* Boolean */) {
	                    return -1 /* True */;
	                }
	                if (source.flags & 1048576 /* FreshObjectLiteral */) {
	                    if (hasExcessProperties(source, target, reportErrors)) {
	                        if (reportErrors) {
	                            reportRelationError(headMessage, source, target);
	                        }
	                        return 0 /* False */;
	                    }
	                    // Above we check for excess properties with respect to the entire target type. When union
	                    // and intersection types are further deconstructed on the target side, we don't want to
	                    // make the check again (as it might fail for a partial target type). Therefore we obtain
	                    // the regular source type and proceed with that.
	                    if (target.flags & 49152 /* UnionOrIntersection */) {
	                        source = getRegularTypeOfObjectLiteral(source);
	                    }
	                }
	                var saveErrorInfo = errorInfo;
	                // Note that the "each" checks must precede the "some" checks to produce the correct results
	                if (source.flags & 16384 /* Union */) {
	                    if (result = eachTypeRelatedToType(source, target, reportErrors)) {
	                        return result;
	                    }
	                }
	                else if (target.flags & 32768 /* Intersection */) {
	                    if (result = typeRelatedToEachType(source, target, reportErrors)) {
	                        return result;
	                    }
	                }
	                else {
	                    // It is necessary to try "some" checks on both sides because there may be nested "each" checks
	                    // on either side that need to be prioritized. For example, A | B = (A | B) & (C | D) or
	                    // A & B = (A & B) | (C & D).
	                    if (source.flags & 32768 /* Intersection */) {
	                        // If target is a union type the following check will report errors so we suppress them here
	                        if (result = someTypeRelatedToType(source, target, reportErrors && !(target.flags & 16384 /* Union */))) {
	                            return result;
	                        }
	                    }
	                    if (target.flags & 16384 /* Union */) {
	                        if (result = typeRelatedToSomeType(source, target, reportErrors)) {
	                            return result;
	                        }
	                    }
	                }
	                if (source.flags & 512 /* TypeParameter */) {
	                    var constraint = getConstraintOfTypeParameter(source);
	                    if (!constraint || constraint.flags & 1 /* Any */) {
	                        constraint = emptyObjectType;
	                    }
	                    // Report constraint errors only if the constraint is not the empty object type
	                    var reportConstraintErrors = reportErrors && constraint !== emptyObjectType;
	                    if (result = isRelatedTo(constraint, target, reportConstraintErrors)) {
	                        errorInfo = saveErrorInfo;
	                        return result;
	                    }
	                }
	                else {
	                    if (source.flags & 4096 /* Reference */ && target.flags & 4096 /* Reference */ && source.target === target.target) {
	                        // We have type references to same target type, see if relationship holds for all type arguments
	                        if (result = typeArgumentsRelatedTo(source, target, reportErrors)) {
	                            return result;
	                        }
	                    }
	                    // Even if relationship doesn't hold for unions, intersections, or generic type references,
	                    // it may hold in a structural comparison.
	                    var apparentSource = getApparentType(source);
	                    // In a check of the form X = A & B, we will have previously checked if A relates to X or B relates
	                    // to X. Failing both of those we want to check if the aggregation of A and B's members structurally
	                    // relates to X. Thus, we include intersection types on the source side here.
	                    if (apparentSource.flags & (80896 /* ObjectType */ | 32768 /* Intersection */) && target.flags & 80896 /* ObjectType */) {
	                        // Report structural errors only if we haven't reported any errors yet
	                        var reportStructuralErrors = reportErrors && errorInfo === saveErrorInfo && !(source.flags & 16777726 /* Primitive */);
	                        if (result = objectTypeRelatedTo(apparentSource, source, target, reportStructuralErrors)) {
	                            errorInfo = saveErrorInfo;
	                            return result;
	                        }
	                    }
	                }
	                if (reportErrors) {
	                    reportRelationError(headMessage, source, target);
	                }
	                return 0 /* False */;
	            }
	            function isIdenticalTo(source, target) {
	                var result;
	                if (source.flags & 80896 /* ObjectType */ && target.flags & 80896 /* ObjectType */) {
	                    if (source.flags & 4096 /* Reference */ && target.flags & 4096 /* Reference */ && source.target === target.target) {
	                        // We have type references to same target type, see if all type arguments are identical
	                        if (result = typeArgumentsRelatedTo(source, target, /*reportErrors*/ false)) {
	                            return result;
	                        }
	                    }
	                    return objectTypeRelatedTo(source, source, target, /*reportErrors*/ false);
	                }
	                if (source.flags & 16384 /* Union */ && target.flags & 16384 /* Union */ ||
	                    source.flags & 32768 /* Intersection */ && target.flags & 32768 /* Intersection */) {
	                    if (result = eachTypeRelatedToSomeType(source, target)) {
	                        if (result &= eachTypeRelatedToSomeType(target, source)) {
	                            return result;
	                        }
	                    }
	                }
	                return 0 /* False */;
	            }
	            // Check if a property with the given name is known anywhere in the given type. In an object type, a property
	            // is considered known if the object type is empty and the check is for assignability, if the object type has
	            // index signatures, or if the property is actually declared in the object type. In a union or intersection
	            // type, a property is considered known if it is known in any constituent type.
	            function isKnownProperty(type, name) {
	                if (type.flags & 80896 /* ObjectType */) {
	                    var resolved = resolveStructuredTypeMembers(type);
	                    if (relation === assignableRelation && (type === globalObjectType || resolved.properties.length === 0) ||
	                        resolved.stringIndexType || resolved.numberIndexType || getPropertyOfType(type, name)) {
	                        return true;
	                    }
	                }
	                else if (type.flags & 49152 /* UnionOrIntersection */) {
	                    for (var _i = 0, _a = type.types; _i < _a.length; _i++) {
	                        var t = _a[_i];
	                        if (isKnownProperty(t, name)) {
	                            return true;
	                        }
	                    }
	                }
	                return false;
	            }
	            function hasExcessProperties(source, target, reportErrors) {
	                if (!(target.flags & 67108864 /* ObjectLiteralPatternWithComputedProperties */) && someConstituentTypeHasKind(target, 80896 /* ObjectType */)) {
	                    for (var _i = 0, _a = getPropertiesOfObjectType(source); _i < _a.length; _i++) {
	                        var prop = _a[_i];
	                        if (!isKnownProperty(target, prop.name)) {
	                            if (reportErrors) {
	                                // We know *exactly* where things went wrong when comparing the types.
	                                // Use this property as the error node as this will be more helpful in
	                                // reasoning about what went wrong.
	                                ts.Debug.assert(!!errorNode);
	                                errorNode = prop.valueDeclaration;
	                                reportError(ts.Diagnostics.Object_literal_may_only_specify_known_properties_and_0_does_not_exist_in_type_1, symbolToString(prop), typeToString(target));
	                            }
	                            return true;
	                        }
	                    }
	                }
	                return false;
	            }
	            function eachTypeRelatedToSomeType(source, target) {
	                var result = -1 /* True */;
	                var sourceTypes = source.types;
	                for (var _i = 0, sourceTypes_1 = sourceTypes; _i < sourceTypes_1.length; _i++) {
	                    var sourceType = sourceTypes_1[_i];
	                    var related = typeRelatedToSomeType(sourceType, target, /*reportErrors*/ false);
	                    if (!related) {
	                        return 0 /* False */;
	                    }
	                    result &= related;
	                }
	                return result;
	            }
	            function typeRelatedToSomeType(source, target, reportErrors) {
	                var targetTypes = target.types;
	                for (var i = 0, len = targetTypes.length; i < len; i++) {
	                    var related = isRelatedTo(source, targetTypes[i], reportErrors && i === len - 1);
	                    if (related) {
	                        return related;
	                    }
	                }
	                return 0 /* False */;
	            }
	            function typeRelatedToEachType(source, target, reportErrors) {
	                var result = -1 /* True */;
	                var targetTypes = target.types;
	                for (var _i = 0, targetTypes_1 = targetTypes; _i < targetTypes_1.length; _i++) {
	                    var targetType = targetTypes_1[_i];
	                    var related = isRelatedTo(source, targetType, reportErrors);
	                    if (!related) {
	                        return 0 /* False */;
	                    }
	                    result &= related;
	                }
	                return result;
	            }
	            function someTypeRelatedToType(source, target, reportErrors) {
	                var sourceTypes = source.types;
	                for (var i = 0, len = sourceTypes.length; i < len; i++) {
	                    var related = isRelatedTo(sourceTypes[i], target, reportErrors && i === len - 1);
	                    if (related) {
	                        return related;
	                    }
	                }
	                return 0 /* False */;
	            }
	            function eachTypeRelatedToType(source, target, reportErrors) {
	                var result = -1 /* True */;
	                var sourceTypes = source.types;
	                for (var _i = 0, sourceTypes_2 = sourceTypes; _i < sourceTypes_2.length; _i++) {
	                    var sourceType = sourceTypes_2[_i];
	                    var related = isRelatedTo(sourceType, target, reportErrors);
	                    if (!related) {
	                        return 0 /* False */;
	                    }
	                    result &= related;
	                }
	                return result;
	            }
	            function typeArgumentsRelatedTo(source, target, reportErrors) {
	                var sources = source.typeArguments || emptyArray;
	                var targets = target.typeArguments || emptyArray;
	                if (sources.length !== targets.length && relation === identityRelation) {
	                    return 0 /* False */;
	                }
	                var length = sources.length <= targets.length ? sources.length : targets.length;
	                var result = -1 /* True */;
	                for (var i = 0; i < length; i++) {
	                    var related = isRelatedTo(sources[i], targets[i], reportErrors);
	                    if (!related) {
	                        return 0 /* False */;
	                    }
	                    result &= related;
	                }
	                return result;
	            }
	            // Determine if two object types are related by structure. First, check if the result is already available in the global cache.
	            // Second, check if we have already started a comparison of the given two types in which case we assume the result to be true.
	            // Third, check if both types are part of deeply nested chains of generic type instantiations and if so assume the types are
	            // equal and infinitely expanding. Fourth, if we have reached a depth of 100 nested comparisons, assume we have runaway recursion
	            // and issue an error. Otherwise, actually compare the structure of the two types.
	            function objectTypeRelatedTo(source, originalSource, target, reportErrors) {
	                if (overflow) {
	                    return 0 /* False */;
	                }
	                var id = relation !== identityRelation || source.id < target.id ? source.id + "," + target.id : target.id + "," + source.id;
	                var related = relation[id];
	                if (related !== undefined) {
	                    if (reportErrors && related === 2 /* Failed */) {
	                        // We are elaborating errors and the cached result is an unreported failure. Record the result as a reported
	                        // failure and continue computing the relation such that errors get reported.
	                        relation[id] = 3 /* FailedAndReported */;
	                    }
	                    else {
	                        return related === 1 /* Succeeded */ ? -1 /* True */ : 0 /* False */;
	                    }
	                }
	                if (depth > 0) {
	                    for (var i = 0; i < depth; i++) {
	                        // If source and target are already being compared, consider them related with assumptions
	                        if (maybeStack[i][id]) {
	                            return 1 /* Maybe */;
	                        }
	                    }
	                    if (depth === 100) {
	                        overflow = true;
	                        return 0 /* False */;
	                    }
	                }
	                else {
	                    sourceStack = [];
	                    targetStack = [];
	                    maybeStack = [];
	                    expandingFlags = 0;
	                }
	                sourceStack[depth] = source;
	                targetStack[depth] = target;
	                maybeStack[depth] = {};
	                maybeStack[depth][id] = 1 /* Succeeded */;
	                depth++;
	                var saveExpandingFlags = expandingFlags;
	                if (!(expandingFlags & 1) && isDeeplyNestedGeneric(source, sourceStack, depth))
	                    expandingFlags |= 1;
	                if (!(expandingFlags & 2) && isDeeplyNestedGeneric(target, targetStack, depth))
	                    expandingFlags |= 2;
	                var result;
	                if (expandingFlags === 3) {
	                    result = 1 /* Maybe */;
	                }
	                else {
	                    result = propertiesRelatedTo(source, target, reportErrors);
	                    if (result) {
	                        result &= signaturesRelatedTo(source, target, 0 /* Call */, reportErrors);
	                        if (result) {
	                            result &= signaturesRelatedTo(source, target, 1 /* Construct */, reportErrors);
	                            if (result) {
	                                result &= stringIndexTypesRelatedTo(source, originalSource, target, reportErrors);
	                                if (result) {
	                                    result &= numberIndexTypesRelatedTo(source, originalSource, target, reportErrors);
	                                }
	                            }
	                        }
	                    }
	                }
	                expandingFlags = saveExpandingFlags;
	                depth--;
	                if (result) {
	                    var maybeCache = maybeStack[depth];
	                    // If result is definitely true, copy assumptions to global cache, else copy to next level up
	                    var destinationCache = (result === -1 /* True */ || depth === 0) ? relation : maybeStack[depth - 1];
	                    ts.copyMap(maybeCache, destinationCache);
	                }
	                else {
	                    // A false result goes straight into global cache (when something is false under assumptions it
	                    // will also be false without assumptions)
	                    relation[id] = reportErrors ? 3 /* FailedAndReported */ : 2 /* Failed */;
	                }
	                return result;
	            }
	            function propertiesRelatedTo(source, target, reportErrors) {
	                if (relation === identityRelation) {
	                    return propertiesIdenticalTo(source, target);
	                }
	                var result = -1 /* True */;
	                var properties = getPropertiesOfObjectType(target);
	                var requireOptionalProperties = relation === subtypeRelation && !(source.flags & 524288 /* ObjectLiteral */);
	                for (var _i = 0, properties_1 = properties; _i < properties_1.length; _i++) {
	                    var targetProp = properties_1[_i];
	                    var sourceProp = getPropertyOfType(source, targetProp.name);
	                    if (sourceProp !== targetProp) {
	                        if (!sourceProp) {
	                            if (!(targetProp.flags & 536870912 /* Optional */) || requireOptionalProperties) {
	                                if (reportErrors) {
	                                    reportError(ts.Diagnostics.Property_0_is_missing_in_type_1, symbolToString(targetProp), typeToString(source));
	                                }
	                                return 0 /* False */;
	                            }
	                        }
	                        else if (!(targetProp.flags & 134217728 /* Prototype */)) {
	                            var sourcePropFlags = getDeclarationFlagsFromSymbol(sourceProp);
	                            var targetPropFlags = getDeclarationFlagsFromSymbol(targetProp);
	                            if (sourcePropFlags & 16 /* Private */ || targetPropFlags & 16 /* Private */) {
	                                if (sourceProp.valueDeclaration !== targetProp.valueDeclaration) {
	                                    if (reportErrors) {
	                                        if (sourcePropFlags & 16 /* Private */ && targetPropFlags & 16 /* Private */) {
	                                            reportError(ts.Diagnostics.Types_have_separate_declarations_of_a_private_property_0, symbolToString(targetProp));
	                                        }
	                                        else {
	                                            reportError(ts.Diagnostics.Property_0_is_private_in_type_1_but_not_in_type_2, symbolToString(targetProp), typeToString(sourcePropFlags & 16 /* Private */ ? source : target), typeToString(sourcePropFlags & 16 /* Private */ ? target : source));
	                                        }
	                                    }
	                                    return 0 /* False */;
	                                }
	                            }
	                            else if (targetPropFlags & 32 /* Protected */) {
	                                var sourceDeclaredInClass = sourceProp.parent && sourceProp.parent.flags & 32 /* Class */;
	                                var sourceClass = sourceDeclaredInClass ? getDeclaredTypeOfSymbol(getParentOfSymbol(sourceProp)) : undefined;
	                                var targetClass = getDeclaredTypeOfSymbol(getParentOfSymbol(targetProp));
	                                if (!sourceClass || !hasBaseType(sourceClass, targetClass)) {
	                                    if (reportErrors) {
	                                        reportError(ts.Diagnostics.Property_0_is_protected_but_type_1_is_not_a_class_derived_from_2, symbolToString(targetProp), typeToString(sourceClass || source), typeToString(targetClass));
	                                    }
	                                    return 0 /* False */;
	                                }
	                            }
	                            else if (sourcePropFlags & 32 /* Protected */) {
	                                if (reportErrors) {
	                                    reportError(ts.Diagnostics.Property_0_is_protected_in_type_1_but_public_in_type_2, symbolToString(targetProp), typeToString(source), typeToString(target));
	                                }
	                                return 0 /* False */;
	                            }
	                            var related = isRelatedTo(getTypeOfSymbol(sourceProp), getTypeOfSymbol(targetProp), reportErrors);
	                            if (!related) {
	                                if (reportErrors) {
	                                    reportError(ts.Diagnostics.Types_of_property_0_are_incompatible, symbolToString(targetProp));
	                                }
	                                return 0 /* False */;
	                            }
	                            result &= related;
	                            if (sourceProp.flags & 536870912 /* Optional */ && !(targetProp.flags & 536870912 /* Optional */)) {
	                                // TypeScript 1.0 spec (April 2014): 3.8.3
	                                // S is a subtype of a type T, and T is a supertype of S if ...
	                                // S' and T are object types and, for each member M in T..
	                                // M is a property and S' contains a property N where
	                                // if M is a required property, N is also a required property
	                                // (M - property in T)
	                                // (N - property in S)
	                                if (reportErrors) {
	                                    reportError(ts.Diagnostics.Property_0_is_optional_in_type_1_but_required_in_type_2, symbolToString(targetProp), typeToString(source), typeToString(target));
	                                }
	                                return 0 /* False */;
	                            }
	                        }
	                    }
	                }
	                return result;
	            }
	            function propertiesIdenticalTo(source, target) {
	                if (!(source.flags & 80896 /* ObjectType */ && target.flags & 80896 /* ObjectType */)) {
	                    return 0 /* False */;
	                }
	                var sourceProperties = getPropertiesOfObjectType(source);
	                var targetProperties = getPropertiesOfObjectType(target);
	                if (sourceProperties.length !== targetProperties.length) {
	                    return 0 /* False */;
	                }
	                var result = -1 /* True */;
	                for (var _i = 0, sourceProperties_1 = sourceProperties; _i < sourceProperties_1.length; _i++) {
	                    var sourceProp = sourceProperties_1[_i];
	                    var targetProp = getPropertyOfObjectType(target, sourceProp.name);
	                    if (!targetProp) {
	                        return 0 /* False */;
	                    }
	                    var related = compareProperties(sourceProp, targetProp, isRelatedTo);
	                    if (!related) {
	                        return 0 /* False */;
	                    }
	                    result &= related;
	                }
	                return result;
	            }
	            function signaturesRelatedTo(source, target, kind, reportErrors) {
	                if (relation === identityRelation) {
	                    return signaturesIdenticalTo(source, target, kind);
	                }
	                if (target === anyFunctionType || source === anyFunctionType) {
	                    return -1 /* True */;
	                }
	                var sourceSignatures = getSignaturesOfType(source, kind);
	                var targetSignatures = getSignaturesOfType(target, kind);
	                if (kind === 1 /* Construct */ && sourceSignatures.length && targetSignatures.length &&
	                    isAbstractConstructorType(source) && !isAbstractConstructorType(target)) {
	                    // An abstract constructor type is not assignable to a non-abstract constructor type
	                    // as it would otherwise be possible to new an abstract class. Note that the assignablity
	                    // check we perform for an extends clause excludes construct signatures from the target,
	                    // so this check never proceeds.
	                    if (reportErrors) {
	                        reportError(ts.Diagnostics.Cannot_assign_an_abstract_constructor_type_to_a_non_abstract_constructor_type);
	                    }
	                    return 0 /* False */;
	                }
	                var result = -1 /* True */;
	                var saveErrorInfo = errorInfo;
	                outer: for (var _i = 0, targetSignatures_1 = targetSignatures; _i < targetSignatures_1.length; _i++) {
	                    var t = targetSignatures_1[_i];
	                    if (!t.hasStringLiterals || target.flags & 262144 /* FromSignature */) {
	                        // Only elaborate errors from the first failure
	                        var shouldElaborateErrors = reportErrors;
	                        for (var _a = 0, sourceSignatures_1 = sourceSignatures; _a < sourceSignatures_1.length; _a++) {
	                            var s = sourceSignatures_1[_a];
	                            if (!s.hasStringLiterals || source.flags & 262144 /* FromSignature */) {
	                                var related = signatureRelatedTo(s, t, shouldElaborateErrors);
	                                if (related) {
	                                    result &= related;
	                                    errorInfo = saveErrorInfo;
	                                    continue outer;
	                                }
	                                shouldElaborateErrors = false;
	                            }
	                        }
	                        // don't elaborate the primitive apparent types (like Number)
	                        // because the actual primitives will have already been reported.
	                        if (shouldElaborateErrors) {
	                            reportError(ts.Diagnostics.Type_0_provides_no_match_for_the_signature_1, typeToString(source), signatureToString(t, /*enclosingDeclaration*/ undefined, /*flags*/ undefined, kind));
	                        }
	                        return 0 /* False */;
	                    }
	                }
	                return result;
	            }
	            /**
	             * See signatureAssignableTo, compareSignaturesIdentical
	             */
	            function signatureRelatedTo(source, target, reportErrors) {
	                return compareSignaturesRelated(source, target, /*ignoreReturnTypes*/ false, reportErrors, reportError, isRelatedTo);
	            }
	            function signaturesIdenticalTo(source, target, kind) {
	                var sourceSignatures = getSignaturesOfType(source, kind);
	                var targetSignatures = getSignaturesOfType(target, kind);
	                if (sourceSignatures.length !== targetSignatures.length) {
	                    return 0 /* False */;
	                }
	                var result = -1 /* True */;
	                for (var i = 0, len = sourceSignatures.length; i < len; i++) {
	                    var related = compareSignaturesIdentical(sourceSignatures[i], targetSignatures[i], /*partialMatch*/ false, /*ignoreReturnTypes*/ false, isRelatedTo);
	                    if (!related) {
	                        return 0 /* False */;
	                    }
	                    result &= related;
	                }
	                return result;
	            }
	            function stringIndexTypesRelatedTo(source, originalSource, target, reportErrors) {
	                if (relation === identityRelation) {
	                    return indexTypesIdenticalTo(0 /* String */, source, target);
	                }
	                var targetType = getIndexTypeOfType(target, 0 /* String */);
	                if (targetType) {
	                    if ((targetType.flags & 1 /* Any */) && !(originalSource.flags & 16777726 /* Primitive */)) {
	                        // non-primitive assignment to any is always allowed, eg
	                        //   `var x: { [index: string]: any } = { property: 12 };`
	                        return -1 /* True */;
	                    }
	                    var sourceType = getIndexTypeOfType(source, 0 /* String */);
	                    if (!sourceType) {
	                        if (reportErrors) {
	                            reportError(ts.Diagnostics.Index_signature_is_missing_in_type_0, typeToString(source));
	                        }
	                        return 0 /* False */;
	                    }
	                    var related = isRelatedTo(sourceType, targetType, reportErrors);
	                    if (!related) {
	                        if (reportErrors) {
	                            reportError(ts.Diagnostics.Index_signatures_are_incompatible);
	                        }
	                        return 0 /* False */;
	                    }
	                    return related;
	                }
	                return -1 /* True */;
	            }
	            function numberIndexTypesRelatedTo(source, originalSource, target, reportErrors) {
	                if (relation === identityRelation) {
	                    return indexTypesIdenticalTo(1 /* Number */, source, target);
	                }
	                var targetType = getIndexTypeOfType(target, 1 /* Number */);
	                if (targetType) {
	                    if ((targetType.flags & 1 /* Any */) && !(originalSource.flags & 16777726 /* Primitive */)) {
	                        // non-primitive assignment to any is always allowed, eg
	                        //   `var x: { [index: number]: any } = { property: 12 };`
	                        return -1 /* True */;
	                    }
	                    var sourceStringType = getIndexTypeOfType(source, 0 /* String */);
	                    var sourceNumberType = getIndexTypeOfType(source, 1 /* Number */);
	                    if (!(sourceStringType || sourceNumberType)) {
	                        if (reportErrors) {
	                            reportError(ts.Diagnostics.Index_signature_is_missing_in_type_0, typeToString(source));
	                        }
	                        return 0 /* False */;
	                    }
	                    var related = void 0;
	                    if (sourceStringType && sourceNumberType) {
	                        // If we know for sure we're testing both string and numeric index types then only report errors from the second one
	                        related = isRelatedTo(sourceStringType, targetType, /*reportErrors*/ false) || isRelatedTo(sourceNumberType, targetType, reportErrors);
	                    }
	                    else {
	                        related = isRelatedTo(sourceStringType || sourceNumberType, targetType, reportErrors);
	                    }
	                    if (!related) {
	                        if (reportErrors) {
	                            reportError(ts.Diagnostics.Index_signatures_are_incompatible);
	                        }
	                        return 0 /* False */;
	                    }
	                    return related;
	                }
	                return -1 /* True */;
	            }
	            function indexTypesIdenticalTo(indexKind, source, target) {
	                var targetType = getIndexTypeOfType(target, indexKind);
	                var sourceType = getIndexTypeOfType(source, indexKind);
	                if (!sourceType && !targetType) {
	                    return -1 /* True */;
	                }
	                if (sourceType && targetType) {
	                    return isRelatedTo(sourceType, targetType);
	                }
	                return 0 /* False */;
	            }
	            function enumRelatedTo(source, target) {
	                if (source.symbol.name !== target.symbol.name ||
	                    source.symbol.flags & 128 /* ConstEnum */ ||
	                    target.symbol.flags & 128 /* ConstEnum */) {
	                    return 0 /* False */;
	                }
	                var targetEnumType = getTypeOfSymbol(target.symbol);
	                for (var _i = 0, _a = getPropertiesOfType(getTypeOfSymbol(source.symbol)); _i < _a.length; _i++) {
	                    var property = _a[_i];
	                    if (property.flags & 8 /* EnumMember */) {
	                        var targetProperty = getPropertyOfType(targetEnumType, property.name);
	                        if (!targetProperty || !(targetProperty.flags & 8 /* EnumMember */)) {
	                            reportError(ts.Diagnostics.Property_0_is_missing_in_type_1, property.name, typeToString(target, /*enclosingDeclaration*/ undefined, 128 /* UseFullyQualifiedType */));
	                            return 0 /* False */;
	                        }
	                    }
	                }
	                return -1 /* True */;
	            }
	        }
	        // Return true if the given type is the constructor type for an abstract class
	        function isAbstractConstructorType(type) {
	            if (type.flags & 65536 /* Anonymous */) {
	                var symbol = type.symbol;
	                if (symbol && symbol.flags & 32 /* Class */) {
	                    var declaration = getClassLikeDeclarationOfSymbol(symbol);
	                    if (declaration && declaration.flags & 128 /* Abstract */) {
	                        return true;
	                    }
	                }
	            }
	            return false;
	        }
	        // Return true if the given type is part of a deeply nested chain of generic instantiations. We consider this to be the case
	        // when structural type comparisons have been started for 10 or more instantiations of the same generic type. It is possible,
	        // though highly unlikely, for this test to be true in a situation where a chain of instantiations is not infinitely expanding.
	        // Effectively, we will generate a false positive when two types are structurally equal to at least 10 levels, but unequal at
	        // some level beyond that.
	        function isDeeplyNestedGeneric(type, stack, depth) {
	            // We track type references (created by createTypeReference) and instantiated types (created by instantiateType)
	            if (type.flags & (4096 /* Reference */ | 131072 /* Instantiated */) && depth >= 5) {
	                var symbol = type.symbol;
	                var count = 0;
	                for (var i = 0; i < depth; i++) {
	                    var t = stack[i];
	                    if (t.flags & (4096 /* Reference */ | 131072 /* Instantiated */) && t.symbol === symbol) {
	                        count++;
	                        if (count >= 5)
	                            return true;
	                    }
	                }
	            }
	            return false;
	        }
	        function isPropertyIdenticalTo(sourceProp, targetProp) {
	            return compareProperties(sourceProp, targetProp, compareTypesIdentical) !== 0 /* False */;
	        }
	        function compareProperties(sourceProp, targetProp, compareTypes) {
	            // Two members are considered identical when
	            // - they are public properties with identical names, optionality, and types,
	            // - they are private or protected properties originating in the same declaration and having identical types
	            if (sourceProp === targetProp) {
	                return -1 /* True */;
	            }
	            var sourcePropAccessibility = getDeclarationFlagsFromSymbol(sourceProp) & (16 /* Private */ | 32 /* Protected */);
	            var targetPropAccessibility = getDeclarationFlagsFromSymbol(targetProp) & (16 /* Private */ | 32 /* Protected */);
	            if (sourcePropAccessibility !== targetPropAccessibility) {
	                return 0 /* False */;
	            }
	            if (sourcePropAccessibility) {
	                if (getTargetSymbol(sourceProp) !== getTargetSymbol(targetProp)) {
	                    return 0 /* False */;
	                }
	            }
	            else {
	                if ((sourceProp.flags & 536870912 /* Optional */) !== (targetProp.flags & 536870912 /* Optional */)) {
	                    return 0 /* False */;
	                }
	            }
	            return compareTypes(getTypeOfSymbol(sourceProp), getTypeOfSymbol(targetProp));
	        }
	        function isMatchingSignature(source, target, partialMatch) {
	            // A source signature matches a target signature if the two signatures have the same number of required,
	            // optional, and rest parameters.
	            if (source.parameters.length === target.parameters.length &&
	                source.minArgumentCount === target.minArgumentCount &&
	                source.hasRestParameter === target.hasRestParameter) {
	                return true;
	            }
	            // A source signature partially matches a target signature if the target signature has no fewer required
	            // parameters and no more overall parameters than the source signature (where a signature with a rest
	            // parameter is always considered to have more overall parameters than one without).
	            if (partialMatch && source.minArgumentCount <= target.minArgumentCount && (source.hasRestParameter && !target.hasRestParameter ||
	                source.hasRestParameter === target.hasRestParameter && source.parameters.length >= target.parameters.length)) {
	                return true;
	            }
	            return false;
	        }
	        /**
	         * See signatureRelatedTo, compareSignaturesIdentical
	         */
	        function compareSignaturesIdentical(source, target, partialMatch, ignoreReturnTypes, compareTypes) {
	            // TODO (drosen): De-duplicate code between related functions.
	            if (source === target) {
	                return -1 /* True */;
	            }
	            if (!(isMatchingSignature(source, target, partialMatch))) {
	                return 0 /* False */;
	            }
	            // Check that the two signatures have the same number of type parameters. We might consider
	            // also checking that any type parameter constraints match, but that would require instantiating
	            // the constraints with a common set of type arguments to get relatable entities in places where
	            // type parameters occur in the constraints. The complexity of doing that doesn't seem worthwhile,
	            // particularly as we're comparing erased versions of the signatures below.
	            if ((source.typeParameters ? source.typeParameters.length : 0) !== (target.typeParameters ? target.typeParameters.length : 0)) {
	                return 0 /* False */;
	            }
	            // Spec 1.0 Section 3.8.3 & 3.8.4:
	            // M and N (the signatures) are instantiated using type Any as the type argument for all type parameters declared by M and N
	            source = getErasedSignature(source);
	            target = getErasedSignature(target);
	            var result = -1 /* True */;
	            var targetLen = target.parameters.length;
	            for (var i = 0; i < targetLen; i++) {
	                var s = isRestParameterIndex(source, i) ? getRestTypeOfSignature(source) : getTypeOfSymbol(source.parameters[i]);
	                var t = isRestParameterIndex(target, i) ? getRestTypeOfSignature(target) : getTypeOfSymbol(target.parameters[i]);
	                var related = compareTypes(s, t);
	                if (!related) {
	                    return 0 /* False */;
	                }
	                result &= related;
	            }
	            if (!ignoreReturnTypes) {
	                result &= compareTypes(getReturnTypeOfSignature(source), getReturnTypeOfSignature(target));
	            }
	            return result;
	        }
	        function isRestParameterIndex(signature, parameterIndex) {
	            return signature.hasRestParameter && parameterIndex >= signature.parameters.length - 1;
	        }
	        function isSupertypeOfEach(candidate, types) {
	            for (var _i = 0, types_6 = types; _i < types_6.length; _i++) {
	                var type = types_6[_i];
	                if (candidate !== type && !isTypeSubtypeOf(type, candidate))
	                    return false;
	            }
	            return true;
	        }
	        function getCommonSupertype(types) {
	            return ts.forEach(types, function (t) { return isSupertypeOfEach(t, types) ? t : undefined; });
	        }
	        function reportNoCommonSupertypeError(types, errorLocation, errorMessageChainHead) {
	            // The downfallType/bestSupertypeDownfallType is the first type that caused a particular candidate
	            // to not be the common supertype. So if it weren't for this one downfallType (and possibly others),
	            // the type in question could have been the common supertype.
	            var bestSupertype;
	            var bestSupertypeDownfallType;
	            var bestSupertypeScore = 0;
	            for (var i = 0; i < types.length; i++) {
	                var score = 0;
	                var downfallType = undefined;
	                for (var j = 0; j < types.length; j++) {
	                    if (isTypeSubtypeOf(types[j], types[i])) {
	                        score++;
	                    }
	                    else if (!downfallType) {
	                        downfallType = types[j];
	                    }
	                }
	                ts.Debug.assert(!!downfallType, "If there is no common supertype, each type should have a downfallType");
	                if (score > bestSupertypeScore) {
	                    bestSupertype = types[i];
	                    bestSupertypeDownfallType = downfallType;
	                    bestSupertypeScore = score;
	                }
	                // types.length - 1 is the maximum score, given that getCommonSupertype returned false
	                if (bestSupertypeScore === types.length - 1) {
	                    break;
	                }
	            }
	            // In the following errors, the {1} slot is before the {0} slot because checkTypeSubtypeOf supplies the
	            // subtype as the first argument to the error
	            checkTypeSubtypeOf(bestSupertypeDownfallType, bestSupertype, errorLocation, ts.Diagnostics.Type_argument_candidate_1_is_not_a_valid_type_argument_because_it_is_not_a_supertype_of_candidate_0, errorMessageChainHead);
	        }
	        function isArrayType(type) {
	            return type.flags & 4096 /* Reference */ && type.target === globalArrayType;
	        }
	        function isArrayLikeType(type) {
	            // A type is array-like if it is not the undefined or null type and if it is assignable to any[]
	            return !(type.flags & (32 /* Undefined */ | 64 /* Null */)) && isTypeAssignableTo(type, anyArrayType);
	        }
	        function isTupleLikeType(type) {
	            return !!getPropertyOfType(type, "0");
	        }
	        function isStringLiteralType(type) {
	            return type.flags & 256 /* StringLiteral */;
	        }
	        /**
	         * Check if a Type was written as a tuple type literal.
	         * Prefer using isTupleLikeType() unless the use of `elementTypes` is required.
	         */
	        function isTupleType(type) {
	            return !!(type.flags & 8192 /* Tuple */);
	        }
	        function getRegularTypeOfObjectLiteral(type) {
	            if (type.flags & 1048576 /* FreshObjectLiteral */) {
	                var regularType = type.regularType;
	                if (!regularType) {
	                    regularType = createType(type.flags & ~1048576 /* FreshObjectLiteral */);
	                    regularType.symbol = type.symbol;
	                    regularType.members = type.members;
	                    regularType.properties = type.properties;
	                    regularType.callSignatures = type.callSignatures;
	                    regularType.constructSignatures = type.constructSignatures;
	                    regularType.stringIndexType = type.stringIndexType;
	                    regularType.numberIndexType = type.numberIndexType;
	                    type.regularType = regularType;
	                }
	                return regularType;
	            }
	            return type;
	        }
	        function getWidenedTypeOfObjectLiteral(type) {
	            var properties = getPropertiesOfObjectType(type);
	            var members = {};
	            ts.forEach(properties, function (p) {
	                var propType = getTypeOfSymbol(p);
	                var widenedType = getWidenedType(propType);
	                if (propType !== widenedType) {
	                    var symbol = createSymbol(p.flags | 67108864 /* Transient */, p.name);
	                    symbol.declarations = p.declarations;
	                    symbol.parent = p.parent;
	                    symbol.type = widenedType;
	                    symbol.target = p;
	                    if (p.valueDeclaration)
	                        symbol.valueDeclaration = p.valueDeclaration;
	                    p = symbol;
	                }
	                members[p.name] = p;
	            });
	            var stringIndexType = getIndexTypeOfType(type, 0 /* String */);
	            var numberIndexType = getIndexTypeOfType(type, 1 /* Number */);
	            if (stringIndexType)
	                stringIndexType = getWidenedType(stringIndexType);
	            if (numberIndexType)
	                numberIndexType = getWidenedType(numberIndexType);
	            return createAnonymousType(type.symbol, members, emptyArray, emptyArray, stringIndexType, numberIndexType);
	        }
	        function getWidenedType(type) {
	            if (type.flags & 6291456 /* RequiresWidening */) {
	                if (type.flags & (32 /* Undefined */ | 64 /* Null */)) {
	                    return anyType;
	                }
	                if (type.flags & 524288 /* ObjectLiteral */) {
	                    return getWidenedTypeOfObjectLiteral(type);
	                }
	                if (type.flags & 16384 /* Union */) {
	                    return getUnionType(ts.map(type.types, getWidenedType), /*noSubtypeReduction*/ true);
	                }
	                if (isArrayType(type)) {
	                    return createArrayType(getWidenedType(type.typeArguments[0]));
	                }
	                if (isTupleType(type)) {
	                    return createTupleType(ts.map(type.elementTypes, getWidenedType));
	                }
	            }
	            return type;
	        }
	        /**
	         * Reports implicit any errors that occur as a result of widening 'null' and 'undefined'
	         * to 'any'. A call to reportWideningErrorsInType is normally accompanied by a call to
	         * getWidenedType. But in some cases getWidenedType is called without reporting errors
	         * (type argument inference is an example).
	         *
	         * The return value indicates whether an error was in fact reported. The particular circumstances
	         * are on a best effort basis. Currently, if the null or undefined that causes widening is inside
	         * an object literal property (arbitrarily deeply), this function reports an error. If no error is
	         * reported, reportImplicitAnyError is a suitable fallback to report a general error.
	         */
	        function reportWideningErrorsInType(type) {
	            var errorReported = false;
	            if (type.flags & 16384 /* Union */) {
	                for (var _i = 0, _a = type.types; _i < _a.length; _i++) {
	                    var t = _a[_i];
	                    if (reportWideningErrorsInType(t)) {
	                        errorReported = true;
	                    }
	                }
	            }
	            if (isArrayType(type)) {
	                return reportWideningErrorsInType(type.typeArguments[0]);
	            }
	            if (isTupleType(type)) {
	                for (var _b = 0, _c = type.elementTypes; _b < _c.length; _b++) {
	                    var t = _c[_b];
	                    if (reportWideningErrorsInType(t)) {
	                        errorReported = true;
	                    }
	                }
	            }
	            if (type.flags & 524288 /* ObjectLiteral */) {
	                for (var _d = 0, _e = getPropertiesOfObjectType(type); _d < _e.length; _d++) {
	                    var p = _e[_d];
	                    var t = getTypeOfSymbol(p);
	                    if (t.flags & 2097152 /* ContainsUndefinedOrNull */) {
	                        if (!reportWideningErrorsInType(t)) {
	                            error(p.valueDeclaration, ts.Diagnostics.Object_literal_s_property_0_implicitly_has_an_1_type, p.name, typeToString(getWidenedType(t)));
	                        }
	                        errorReported = true;
	                    }
	                }
	            }
	            return errorReported;
	        }
	        function reportImplicitAnyError(declaration, type) {
	            var typeAsString = typeToString(getWidenedType(type));
	            var diagnostic;
	            switch (declaration.kind) {
	                case 142 /* PropertyDeclaration */:
	                case 141 /* PropertySignature */:
	                    diagnostic = ts.Diagnostics.Member_0_implicitly_has_an_1_type;
	                    break;
	                case 139 /* Parameter */:
	                    diagnostic = declaration.dotDotDotToken ?
	                        ts.Diagnostics.Rest_parameter_0_implicitly_has_an_any_type :
	                        ts.Diagnostics.Parameter_0_implicitly_has_an_1_type;
	                    break;
	                case 216 /* FunctionDeclaration */:
	                case 144 /* MethodDeclaration */:
	                case 143 /* MethodSignature */:
	                case 146 /* GetAccessor */:
	                case 147 /* SetAccessor */:
	                case 176 /* FunctionExpression */:
	                case 177 /* ArrowFunction */:
	                    if (!declaration.name) {
	                        error(declaration, ts.Diagnostics.Function_expression_which_lacks_return_type_annotation_implicitly_has_an_0_return_type, typeAsString);
	                        return;
	                    }
	                    diagnostic = ts.Diagnostics._0_which_lacks_return_type_annotation_implicitly_has_an_1_return_type;
	                    break;
	                default:
	                    diagnostic = ts.Diagnostics.Variable_0_implicitly_has_an_1_type;
	            }
	            error(declaration, diagnostic, ts.declarationNameToString(declaration.name), typeAsString);
	        }
	        function reportErrorsFromWidening(declaration, type) {
	            if (produceDiagnostics && compilerOptions.noImplicitAny && type.flags & 2097152 /* ContainsUndefinedOrNull */) {
	                // Report implicit any error within type if possible, otherwise report error on declaration
	                if (!reportWideningErrorsInType(type)) {
	                    reportImplicitAnyError(declaration, type);
	                }
	            }
	        }
	        function forEachMatchingParameterType(source, target, callback) {
	            var sourceMax = source.parameters.length;
	            var targetMax = target.parameters.length;
	            var count;
	            if (source.hasRestParameter && target.hasRestParameter) {
	                count = sourceMax > targetMax ? sourceMax : targetMax;
	                sourceMax--;
	                targetMax--;
	            }
	            else if (source.hasRestParameter) {
	                sourceMax--;
	                count = targetMax;
	            }
	            else if (target.hasRestParameter) {
	                targetMax--;
	                count = sourceMax;
	            }
	            else {
	                count = sourceMax < targetMax ? sourceMax : targetMax;
	            }
	            for (var i = 0; i < count; i++) {
	                var s = i < sourceMax ? getTypeOfSymbol(source.parameters[i]) : getRestTypeOfSignature(source);
	                var t = i < targetMax ? getTypeOfSymbol(target.parameters[i]) : getRestTypeOfSignature(target);
	                callback(s, t);
	            }
	        }
	        function createInferenceContext(typeParameters, inferUnionTypes) {
	            var inferences = ts.map(typeParameters, createTypeInferencesObject);
	            return {
	                typeParameters: typeParameters,
	                inferUnionTypes: inferUnionTypes,
	                inferences: inferences,
	                inferredTypes: new Array(typeParameters.length)
	            };
	        }
	        function createTypeInferencesObject() {
	            return {
	                primary: undefined,
	                secondary: undefined,
	                isFixed: false
	            };
	        }
	        function inferTypes(context, source, target) {
	            var sourceStack;
	            var targetStack;
	            var depth = 0;
	            var inferiority = 0;
	            inferFromTypes(source, target);
	            function isInProcess(source, target) {
	                for (var i = 0; i < depth; i++) {
	                    if (source === sourceStack[i] && target === targetStack[i]) {
	                        return true;
	                    }
	                }
	                return false;
	            }
	            function inferFromTypes(source, target) {
	                if (source.flags & 16384 /* Union */ && target.flags & 16384 /* Union */ ||
	                    source.flags & 32768 /* Intersection */ && target.flags & 32768 /* Intersection */) {
	                    // Source and target are both unions or both intersections. First, find each
	                    // target constituent type that has an identically matching source constituent
	                    // type, and for each such target constituent type infer from the type to itself.
	                    // When inferring from a type to itself we effectively find all type parameter
	                    // occurrences within that type and infer themselves as their type arguments.
	                    var matchingTypes = void 0;
	                    for (var _i = 0, _a = target.types; _i < _a.length; _i++) {
	                        var t = _a[_i];
	                        if (typeIdenticalToSomeType(t, source.types)) {
	                            (matchingTypes || (matchingTypes = [])).push(t);
	                            inferFromTypes(t, t);
	                        }
	                    }
	                    // Next, to improve the quality of inferences, reduce the source and target types by
	                    // removing the identically matched constituents. For example, when inferring from
	                    // 'string | string[]' to 'string | T' we reduce the types to 'string[]' and 'T'.
	                    if (matchingTypes) {
	                        source = removeTypesFromUnionOrIntersection(source, matchingTypes);
	                        target = removeTypesFromUnionOrIntersection(target, matchingTypes);
	                    }
	                }
	                if (target.flags & 512 /* TypeParameter */) {
	                    // If target is a type parameter, make an inference, unless the source type contains
	                    // the anyFunctionType (the wildcard type that's used to avoid contextually typing functions).
	                    // Because the anyFunctionType is internal, it should not be exposed to the user by adding
	                    // it as an inference candidate. Hopefully, a better candidate will come along that does
	                    // not contain anyFunctionType when we come back to this argument for its second round
	                    // of inference.
	                    if (source.flags & 8388608 /* ContainsAnyFunctionType */) {
	                        return;
	                    }
	                    var typeParameters = context.typeParameters;
	                    for (var i = 0; i < typeParameters.length; i++) {
	                        if (target === typeParameters[i]) {
	                            var inferences = context.inferences[i];
	                            if (!inferences.isFixed) {
	                                // Any inferences that are made to a type parameter in a union type are inferior
	                                // to inferences made to a flat (non-union) type. This is because if we infer to
	                                // T | string[], we really don't know if we should be inferring to T or not (because
	                                // the correct constituent on the target side could be string[]). Therefore, we put
	                                // such inferior inferences into a secondary bucket, and only use them if the primary
	                                // bucket is empty.
	                                var candidates = inferiority ?
	                                    inferences.secondary || (inferences.secondary = []) :
	                                    inferences.primary || (inferences.primary = []);
	                                if (!ts.contains(candidates, source)) {
	                                    candidates.push(source);
	                                }
	                            }
	                            return;
	                        }
	                    }
	                }
	                else if (source.flags & 4096 /* Reference */ && target.flags & 4096 /* Reference */ && source.target === target.target) {
	                    // If source and target are references to the same generic type, infer from type arguments
	                    var sourceTypes = source.typeArguments || emptyArray;
	                    var targetTypes = target.typeArguments || emptyArray;
	                    var count = sourceTypes.length < targetTypes.length ? sourceTypes.length : targetTypes.length;
	                    for (var i = 0; i < count; i++) {
	                        inferFromTypes(sourceTypes[i], targetTypes[i]);
	                    }
	                }
	                else if (source.flags & 8192 /* Tuple */ && target.flags & 8192 /* Tuple */ && source.elementTypes.length === target.elementTypes.length) {
	                    // If source and target are tuples of the same size, infer from element types
	                    var sourceTypes = source.elementTypes;
	                    var targetTypes = target.elementTypes;
	                    for (var i = 0; i < sourceTypes.length; i++) {
	                        inferFromTypes(sourceTypes[i], targetTypes[i]);
	                    }
	                }
	                else if (target.flags & 49152 /* UnionOrIntersection */) {
	                    var targetTypes = target.types;
	                    var typeParameterCount = 0;
	                    var typeParameter = void 0;
	                    // First infer to each type in union or intersection that isn't a type parameter
	                    for (var _b = 0, targetTypes_2 = targetTypes; _b < targetTypes_2.length; _b++) {
	                        var t = targetTypes_2[_b];
	                        if (t.flags & 512 /* TypeParameter */ && ts.contains(context.typeParameters, t)) {
	                            typeParameter = t;
	                            typeParameterCount++;
	                        }
	                        else {
	                            inferFromTypes(source, t);
	                        }
	                    }
	                    // Next, if target is a union type containing a single naked type parameter, make a
	                    // secondary inference to that type parameter. We don't do this for intersection types
	                    // because in a target type like Foo & T we don't know how which parts of the source type
	                    // should be matched by Foo and which should be inferred to T.
	                    if (target.flags & 16384 /* Union */ && typeParameterCount === 1) {
	                        inferiority++;
	                        inferFromTypes(source, typeParameter);
	                        inferiority--;
	                    }
	                }
	                else if (source.flags & 49152 /* UnionOrIntersection */) {
	                    // Source is a union or intersection type, infer from each consituent type
	                    var sourceTypes = source.types;
	                    for (var _c = 0, sourceTypes_3 = sourceTypes; _c < sourceTypes_3.length; _c++) {
	                        var sourceType = sourceTypes_3[_c];
	                        inferFromTypes(sourceType, target);
	                    }
	                }
	                else {
	                    source = getApparentType(source);
	                    if (source.flags & 80896 /* ObjectType */ && (target.flags & 4096 /* Reference */ && target.typeArguments ||
	                        target.flags & 8192 /* Tuple */ ||
	                        target.flags & 65536 /* Anonymous */ && target.symbol && target.symbol.flags & (8192 /* Method */ | 2048 /* TypeLiteral */ | 32 /* Class */))) {
	                        // If source is an object type, and target is a type reference with type arguments, a tuple type,
	                        // the type of a method, or a type literal, infer from members
	                        if (isInProcess(source, target)) {
	                            return;
	                        }
	                        if (isDeeplyNestedGeneric(source, sourceStack, depth) && isDeeplyNestedGeneric(target, targetStack, depth)) {
	                            return;
	                        }
	                        if (depth === 0) {
	                            sourceStack = [];
	                            targetStack = [];
	                        }
	                        sourceStack[depth] = source;
	                        targetStack[depth] = target;
	                        depth++;
	                        inferFromProperties(source, target);
	                        inferFromSignatures(source, target, 0 /* Call */);
	                        inferFromSignatures(source, target, 1 /* Construct */);
	                        inferFromIndexTypes(source, target, 0 /* String */, 0 /* String */);
	                        inferFromIndexTypes(source, target, 1 /* Number */, 1 /* Number */);
	                        inferFromIndexTypes(source, target, 0 /* String */, 1 /* Number */);
	                        depth--;
	                    }
	                }
	            }
	            function inferFromProperties(source, target) {
	                var properties = getPropertiesOfObjectType(target);
	                for (var _i = 0, properties_2 = properties; _i < properties_2.length; _i++) {
	                    var targetProp = properties_2[_i];
	                    var sourceProp = getPropertyOfObjectType(source, targetProp.name);
	                    if (sourceProp) {
	                        inferFromTypes(getTypeOfSymbol(sourceProp), getTypeOfSymbol(targetProp));
	                    }
	                }
	            }
	            function inferFromSignatures(source, target, kind) {
	                var sourceSignatures = getSignaturesOfType(source, kind);
	                var targetSignatures = getSignaturesOfType(target, kind);
	                var sourceLen = sourceSignatures.length;
	                var targetLen = targetSignatures.length;
	                var len = sourceLen < targetLen ? sourceLen : targetLen;
	                for (var i = 0; i < len; i++) {
	                    inferFromSignature(getErasedSignature(sourceSignatures[sourceLen - len + i]), getErasedSignature(targetSignatures[targetLen - len + i]));
	                }
	            }
	            function inferFromSignature(source, target) {
	                forEachMatchingParameterType(source, target, inferFromTypes);
	                if (source.typePredicate && target.typePredicate && source.typePredicate.kind === target.typePredicate.kind) {
	                    inferFromTypes(source.typePredicate.type, target.typePredicate.type);
	                }
	                else {
	                    inferFromTypes(getReturnTypeOfSignature(source), getReturnTypeOfSignature(target));
	                }
	            }
	            function inferFromIndexTypes(source, target, sourceKind, targetKind) {
	                var targetIndexType = getIndexTypeOfType(target, targetKind);
	                if (targetIndexType) {
	                    var sourceIndexType = getIndexTypeOfType(source, sourceKind);
	                    if (sourceIndexType) {
	                        inferFromTypes(sourceIndexType, targetIndexType);
	                    }
	                }
	            }
	        }
	        function typeIdenticalToSomeType(type, types) {
	            for (var _i = 0, types_7 = types; _i < types_7.length; _i++) {
	                var t = types_7[_i];
	                if (isTypeIdenticalTo(t, type)) {
	                    return true;
	                }
	            }
	            return false;
	        }
	        /**
	         * Return a new union or intersection type computed by removing a given set of types
	         * from a given union or intersection type.
	         */
	        function removeTypesFromUnionOrIntersection(type, typesToRemove) {
	            var reducedTypes = [];
	            for (var _i = 0, _a = type.types; _i < _a.length; _i++) {
	                var t = _a[_i];
	                if (!typeIdenticalToSomeType(t, typesToRemove)) {
	                    reducedTypes.push(t);
	                }
	            }
	            return type.flags & 16384 /* Union */ ? getUnionType(reducedTypes, /*noSubtypeReduction*/ true) : getIntersectionType(reducedTypes);
	        }
	        function getInferenceCandidates(context, index) {
	            var inferences = context.inferences[index];
	            return inferences.primary || inferences.secondary || emptyArray;
	        }
	        function getInferredType(context, index) {
	            var inferredType = context.inferredTypes[index];
	            var inferenceSucceeded;
	            if (!inferredType) {
	                var inferences = getInferenceCandidates(context, index);
	                if (inferences.length) {
	                    // Infer widened union or supertype, or the unknown type for no common supertype
	                    var unionOrSuperType = context.inferUnionTypes ? getUnionType(inferences) : getCommonSupertype(inferences);
	                    inferredType = unionOrSuperType ? getWidenedType(unionOrSuperType) : unknownType;
	                    inferenceSucceeded = !!unionOrSuperType;
	                }
	                else {
	                    // Infer the empty object type when no inferences were made. It is important to remember that
	                    // in this case, inference still succeeds, meaning there is no error for not having inference
	                    // candidates. An inference error only occurs when there are *conflicting* candidates, i.e.
	                    // candidates with no common supertype.
	                    inferredType = emptyObjectType;
	                    inferenceSucceeded = true;
	                }
	                context.inferredTypes[index] = inferredType;
	                // Only do the constraint check if inference succeeded (to prevent cascading errors)
	                if (inferenceSucceeded) {
	                    var constraint = getConstraintOfTypeParameter(context.typeParameters[index]);
	                    if (constraint) {
	                        var instantiatedConstraint = instantiateType(constraint, getInferenceMapper(context));
	                        if (!isTypeAssignableTo(inferredType, getTypeWithThisArgument(instantiatedConstraint, inferredType))) {
	                            context.inferredTypes[index] = inferredType = instantiatedConstraint;
	                        }
	                    }
	                }
	                else if (context.failedTypeParameterIndex === undefined || context.failedTypeParameterIndex > index) {
	                    // If inference failed, it is necessary to record the index of the failed type parameter (the one we are on).
	                    // It might be that inference has already failed on a later type parameter on a previous call to inferTypeArguments.
	                    // So if this failure is on preceding type parameter, this type parameter is the new failure index.
	                    context.failedTypeParameterIndex = index;
	                }
	            }
	            return inferredType;
	        }
	        function getInferredTypes(context) {
	            for (var i = 0; i < context.inferredTypes.length; i++) {
	                getInferredType(context, i);
	            }
	            return context.inferredTypes;
	        }
	        // EXPRESSION TYPE CHECKING
	        function getResolvedSymbol(node) {
	            var links = getNodeLinks(node);
	            if (!links.resolvedSymbol) {
	                links.resolvedSymbol = (!ts.nodeIsMissing(node) && resolveName(node, node.text, 107455 /* Value */ | 1048576 /* ExportValue */, ts.Diagnostics.Cannot_find_name_0, node)) || unknownSymbol;
	            }
	            return links.resolvedSymbol;
	        }
	        function isInTypeQuery(node) {
	            // TypeScript 1.0 spec (April 2014): 3.6.3
	            // A type query consists of the keyword typeof followed by an expression.
	            // The expression is restricted to a single identifier or a sequence of identifiers separated by periods
	            while (node) {
	                switch (node.kind) {
	                    case 155 /* TypeQuery */:
	                        return true;
	                    case 69 /* Identifier */:
	                    case 136 /* QualifiedName */:
	                        node = node.parent;
	                        continue;
	                    default:
	                        return false;
	                }
	            }
	            ts.Debug.fail("should not get here");
	        }
	        function hasInitializer(node) {
	            return !!(node.initializer || ts.isBindingPattern(node.parent) && hasInitializer(node.parent.parent));
	        }
	        // Check if a given variable is assigned within a given syntax node
	        function isVariableAssignedWithin(symbol, node) {
	            var links = getNodeLinks(node);
	            if (links.assignmentChecks) {
	                var cachedResult = links.assignmentChecks[symbol.id];
	                if (cachedResult !== undefined) {
	                    return cachedResult;
	                }
	            }
	            else {
	                links.assignmentChecks = {};
	            }
	            return links.assignmentChecks[symbol.id] = isAssignedIn(node);
	            function isAssignedInBinaryExpression(node) {
	                if (node.operatorToken.kind >= 56 /* FirstAssignment */ && node.operatorToken.kind <= 68 /* LastAssignment */) {
	                    var n = skipParenthesizedNodes(node.left);
	                    if (n.kind === 69 /* Identifier */ && getResolvedSymbol(n) === symbol) {
	                        return true;
	                    }
	                }
	                return ts.forEachChild(node, isAssignedIn);
	            }
	            function isAssignedInVariableDeclaration(node) {
	                if (!ts.isBindingPattern(node.name) && getSymbolOfNode(node) === symbol && hasInitializer(node)) {
	                    return true;
	                }
	                return ts.forEachChild(node, isAssignedIn);
	            }
	            function isAssignedIn(node) {
	                switch (node.kind) {
	                    case 184 /* BinaryExpression */:
	                        return isAssignedInBinaryExpression(node);
	                    case 214 /* VariableDeclaration */:
	                    case 166 /* BindingElement */:
	                        return isAssignedInVariableDeclaration(node);
	                    case 164 /* ObjectBindingPattern */:
	                    case 165 /* ArrayBindingPattern */:
	                    case 167 /* ArrayLiteralExpression */:
	                    case 168 /* ObjectLiteralExpression */:
	                    case 169 /* PropertyAccessExpression */:
	                    case 170 /* ElementAccessExpression */:
	                    case 171 /* CallExpression */:
	                    case 172 /* NewExpression */:
	                    case 174 /* TypeAssertionExpression */:
	                    case 192 /* AsExpression */:
	                    case 175 /* ParenthesizedExpression */:
	                    case 182 /* PrefixUnaryExpression */:
	                    case 178 /* DeleteExpression */:
	                    case 181 /* AwaitExpression */:
	                    case 179 /* TypeOfExpression */:
	                    case 180 /* VoidExpression */:
	                    case 183 /* PostfixUnaryExpression */:
	                    case 187 /* YieldExpression */:
	                    case 185 /* ConditionalExpression */:
	                    case 188 /* SpreadElementExpression */:
	                    case 195 /* Block */:
	                    case 196 /* VariableStatement */:
	                    case 198 /* ExpressionStatement */:
	                    case 199 /* IfStatement */:
	                    case 200 /* DoStatement */:
	                    case 201 /* WhileStatement */:
	                    case 202 /* ForStatement */:
	                    case 203 /* ForInStatement */:
	                    case 204 /* ForOfStatement */:
	                    case 207 /* ReturnStatement */:
	                    case 208 /* WithStatement */:
	                    case 209 /* SwitchStatement */:
	                    case 244 /* CaseClause */:
	                    case 245 /* DefaultClause */:
	                    case 210 /* LabeledStatement */:
	                    case 211 /* ThrowStatement */:
	                    case 212 /* TryStatement */:
	                    case 247 /* CatchClause */:
	                    case 236 /* JsxElement */:
	                    case 237 /* JsxSelfClosingElement */:
	                    case 241 /* JsxAttribute */:
	                    case 242 /* JsxSpreadAttribute */:
	                    case 238 /* JsxOpeningElement */:
	                    case 243 /* JsxExpression */:
	                        return ts.forEachChild(node, isAssignedIn);
	                }
	                return false;
	            }
	        }
	        // Get the narrowed type of a given symbol at a given location
	        function getNarrowedTypeOfSymbol(symbol, node) {
	            var type = getTypeOfSymbol(symbol);
	            // Only narrow when symbol is variable of type any or an object, union, or type parameter type
	            if (node && symbol.flags & 3 /* Variable */) {
	                if (isTypeAny(type) || type.flags & (80896 /* ObjectType */ | 16384 /* Union */ | 512 /* TypeParameter */)) {
	                    var declaration = ts.getDeclarationOfKind(symbol, 214 /* VariableDeclaration */);
	                    var top_1 = declaration && getDeclarationContainer(declaration);
	                    var originalType = type;
	                    var nodeStack = [];
	                    loop: while (node.parent) {
	                        var child = node;
	                        node = node.parent;
	                        switch (node.kind) {
	                            case 199 /* IfStatement */:
	                            case 185 /* ConditionalExpression */:
	                            case 184 /* BinaryExpression */:
	                                nodeStack.push({ node: node, child: child });
	                                break;
	                            case 251 /* SourceFile */:
	                            case 221 /* ModuleDeclaration */:
	                                // Stop at the first containing file or module declaration
	                                break loop;
	                        }
	                        if (node === top_1) {
	                            break;
	                        }
	                    }
	                    var nodes = void 0;
	                    while (nodes = nodeStack.pop()) {
	                        var node_1 = nodes.node, child = nodes.child;
	                        switch (node_1.kind) {
	                            case 199 /* IfStatement */:
	                                // In a branch of an if statement, narrow based on controlling expression
	                                if (child !== node_1.expression) {
	                                    type = narrowType(type, node_1.expression, /*assumeTrue*/ child === node_1.thenStatement);
	                                }
	                                break;
	                            case 185 /* ConditionalExpression */:
	                                // In a branch of a conditional expression, narrow based on controlling condition
	                                if (child !== node_1.condition) {
	                                    type = narrowType(type, node_1.condition, /*assumeTrue*/ child === node_1.whenTrue);
	                                }
	                                break;
	                            case 184 /* BinaryExpression */:
	                                // In the right operand of an && or ||, narrow based on left operand
	                                if (child === node_1.right) {
	                                    if (node_1.operatorToken.kind === 51 /* AmpersandAmpersandToken */) {
	                                        type = narrowType(type, node_1.left, /*assumeTrue*/ true);
	                                    }
	                                    else if (node_1.operatorToken.kind === 52 /* BarBarToken */) {
	                                        type = narrowType(type, node_1.left, /*assumeTrue*/ false);
	                                    }
	                                }
	                                break;
	                            default:
	                                ts.Debug.fail("Unreachable!");
	                        }
	                        // Use original type if construct contains assignments to variable
	                        if (type !== originalType && isVariableAssignedWithin(symbol, node_1)) {
	                            type = originalType;
	                        }
	                    }
	                    // Preserve old top-level behavior - if the branch is really an empty set, revert to prior type
	                    if (type === emptyUnionType) {
	                        type = originalType;
	                    }
	                }
	            }
	            return type;
	            function narrowTypeByEquality(type, expr, assumeTrue) {
	                // Check that we have 'typeof <symbol>' on the left and string literal on the right
	                if (expr.left.kind !== 179 /* TypeOfExpression */ || expr.right.kind !== 9 /* StringLiteral */) {
	                    return type;
	                }
	                var left = expr.left;
	                var right = expr.right;
	                if (left.expression.kind !== 69 /* Identifier */ || getResolvedSymbol(left.expression) !== symbol) {
	                    return type;
	                }
	                if (expr.operatorToken.kind === 33 /* ExclamationEqualsEqualsToken */) {
	                    assumeTrue = !assumeTrue;
	                }
	                var typeInfo = primitiveTypeInfo[right.text];
	                // Don't narrow `undefined`
	                if (typeInfo && typeInfo.type === undefinedType) {
	                    return type;
	                }
	                var flags;
	                if (typeInfo) {
	                    flags = typeInfo.flags;
	                }
	                else {
	                    assumeTrue = !assumeTrue;
	                    flags = 132 /* NumberLike */ | 258 /* StringLike */ | 16777216 /* ESSymbol */ | 8 /* Boolean */;
	                }
	                // At this point we can bail if it's not a union
	                if (!(type.flags & 16384 /* Union */)) {
	                    // If we're on the true branch and the type is a subtype, we should return the primitive type
	                    if (assumeTrue && typeInfo && isTypeSubtypeOf(typeInfo.type, type)) {
	                        return typeInfo.type;
	                    }
	                    // If the active non-union type would be removed from a union by this type guard, return an empty union
	                    return filterUnion(type) ? type : emptyUnionType;
	                }
	                return getUnionType(ts.filter(type.types, filterUnion), /*noSubtypeReduction*/ true);
	                function filterUnion(type) {
	                    return assumeTrue === !!(type.flags & flags);
	                }
	            }
	            function narrowTypeByAnd(type, expr, assumeTrue) {
	                if (assumeTrue) {
	                    // The assumed result is true, therefore we narrow assuming each operand to be true.
	                    return narrowType(narrowType(type, expr.left, /*assumeTrue*/ true), expr.right, /*assumeTrue*/ true);
	                }
	                else {
	                    // The assumed result is false. This means either the first operand was false, or the first operand was true
	                    // and the second operand was false. We narrow with those assumptions and union the two resulting types.
	                    return getUnionType([
	                        narrowType(type, expr.left, /*assumeTrue*/ false),
	                        narrowType(type, expr.right, /*assumeTrue*/ false)
	                    ]);
	                }
	            }
	            function narrowTypeByOr(type, expr, assumeTrue) {
	                if (assumeTrue) {
	                    // The assumed result is true. This means either the first operand was true, or the first operand was false
	                    // and the second operand was true. We narrow with those assumptions and union the two resulting types.
	                    return getUnionType([
	                        narrowType(type, expr.left, /*assumeTrue*/ true),
	                        narrowType(type, expr.right, /*assumeTrue*/ true)
	                    ]);
	                }
	                else {
	                    // The assumed result is false, therefore we narrow assuming each operand to be false.
	                    return narrowType(narrowType(type, expr.left, /*assumeTrue*/ false), expr.right, /*assumeTrue*/ false);
	                }
	            }
	            function narrowTypeByInstanceof(type, expr, assumeTrue) {
	                // Check that type is not any, assumed result is true, and we have variable symbol on the left
	                if (isTypeAny(type) || expr.left.kind !== 69 /* Identifier */ || getResolvedSymbol(expr.left) !== symbol) {
	                    return type;
	                }
	                // Check that right operand is a function type with a prototype property
	                var rightType = checkExpression(expr.right);
	                if (!isTypeSubtypeOf(rightType, globalFunctionType)) {
	                    return type;
	                }
	                var targetType;
	                var prototypeProperty = getPropertyOfType(rightType, "prototype");
	                if (prototypeProperty) {
	                    // Target type is type of the prototype property
	                    var prototypePropertyType = getTypeOfSymbol(prototypeProperty);
	                    if (!isTypeAny(prototypePropertyType)) {
	                        targetType = prototypePropertyType;
	                    }
	                }
	                if (!targetType) {
	                    // Target type is type of construct signature
	                    var constructSignatures = void 0;
	                    if (rightType.flags & 2048 /* Interface */) {
	                        constructSignatures = resolveDeclaredMembers(rightType).declaredConstructSignatures;
	                    }
	                    else if (rightType.flags & 65536 /* Anonymous */) {
	                        constructSignatures = getSignaturesOfType(rightType, 1 /* Construct */);
	                    }
	                    if (constructSignatures && constructSignatures.length) {
	                        targetType = getUnionType(ts.map(constructSignatures, function (signature) { return getReturnTypeOfSignature(getErasedSignature(signature)); }));
	                    }
	                }
	                if (targetType) {
	                    return getNarrowedType(type, targetType, assumeTrue);
	                }
	                return type;
	            }
	            function getNarrowedType(originalType, narrowedTypeCandidate, assumeTrue) {
	                if (!assumeTrue) {
	                    if (originalType.flags & 16384 /* Union */) {
	                        return getUnionType(ts.filter(originalType.types, function (t) { return !isTypeSubtypeOf(t, narrowedTypeCandidate); }));
	                    }
	                    return originalType;
	                }
	                // If the current type is a union type, remove all constituents that aren't assignable to target. If that produces
	                // 0 candidates, fall back to the assignability check
	                if (originalType.flags & 16384 /* Union */) {
	                    var assignableConstituents = ts.filter(originalType.types, function (t) { return isTypeAssignableTo(t, narrowedTypeCandidate); });
	                    if (assignableConstituents.length) {
	                        return getUnionType(assignableConstituents);
	                    }
	                }
	                if (isTypeAssignableTo(narrowedTypeCandidate, originalType)) {
	                    // Narrow to the target type if it's assignable to the current type
	                    return narrowedTypeCandidate;
	                }
	                return originalType;
	            }
	            function narrowTypeByTypePredicate(type, callExpression, assumeTrue) {
	                if (type.flags & 1 /* Any */) {
	                    return type;
	                }
	                var signature = getResolvedSignature(callExpression);
	                var predicate = signature.typePredicate;
	                if (!predicate) {
	                    return type;
	                }
	                if (ts.isIdentifierTypePredicate(predicate)) {
	                    if (callExpression.arguments[predicate.parameterIndex] &&
	                        getSymbolAtTypePredicatePosition(callExpression.arguments[predicate.parameterIndex]) === symbol) {
	                        return getNarrowedType(type, predicate.type, assumeTrue);
	                    }
	                }
	                else {
	                    var invokedExpression = skipParenthesizedNodes(callExpression.expression);
	                    return narrowTypeByThisTypePredicate(type, predicate, invokedExpression, assumeTrue);
	                }
	                return type;
	            }
	            function narrowTypeByThisTypePredicate(type, predicate, invokedExpression, assumeTrue) {
	                if (invokedExpression.kind === 170 /* ElementAccessExpression */ || invokedExpression.kind === 169 /* PropertyAccessExpression */) {
	                    var accessExpression = invokedExpression;
	                    var possibleIdentifier = skipParenthesizedNodes(accessExpression.expression);
	                    if (possibleIdentifier.kind === 69 /* Identifier */ && getSymbolAtTypePredicatePosition(possibleIdentifier) === symbol) {
	                        return getNarrowedType(type, predicate.type, assumeTrue);
	                    }
	                }
	                return type;
	            }
	            function getSymbolAtTypePredicatePosition(expr) {
	                expr = skipParenthesizedNodes(expr);
	                switch (expr.kind) {
	                    case 69 /* Identifier */:
	                    case 169 /* PropertyAccessExpression */:
	                        return getSymbolOfEntityNameOrPropertyAccessExpression(expr);
	                }
	            }
	            // Narrow the given type based on the given expression having the assumed boolean value. The returned type
	            // will be a subtype or the same type as the argument.
	            function narrowType(type, expr, assumeTrue) {
	                switch (expr.kind) {
	                    case 171 /* CallExpression */:
	                        return narrowTypeByTypePredicate(type, expr, assumeTrue);
	                    case 175 /* ParenthesizedExpression */:
	                        return narrowType(type, expr.expression, assumeTrue);
	                    case 184 /* BinaryExpression */:
	                        var operator = expr.operatorToken.kind;
	                        if (operator === 32 /* EqualsEqualsEqualsToken */ || operator === 33 /* ExclamationEqualsEqualsToken */) {
	                            return narrowTypeByEquality(type, expr, assumeTrue);
	                        }
	                        else if (operator === 51 /* AmpersandAmpersandToken */) {
	                            return narrowTypeByAnd(type, expr, assumeTrue);
	                        }
	                        else if (operator === 52 /* BarBarToken */) {
	                            return narrowTypeByOr(type, expr, assumeTrue);
	                        }
	                        else if (operator === 91 /* InstanceOfKeyword */) {
	                            return narrowTypeByInstanceof(type, expr, assumeTrue);
	                        }
	                        break;
	                    case 182 /* PrefixUnaryExpression */:
	                        if (expr.operator === 49 /* ExclamationToken */) {
	                            return narrowType(type, expr.operand, !assumeTrue);
	                        }
	                        break;
	                }
	                return type;
	            }
	        }
	        function skipParenthesizedNodes(expression) {
	            while (expression.kind === 175 /* ParenthesizedExpression */) {
	                expression = expression.expression;
	            }
	            return expression;
	        }
	        function checkIdentifier(node) {
	            var symbol = getResolvedSymbol(node);
	            // As noted in ECMAScript 6 language spec, arrow functions never have an arguments objects.
	            // Although in down-level emit of arrow function, we emit it using function expression which means that
	            // arguments objects will be bound to the inner object; emitting arrow function natively in ES6, arguments objects
	            // will be bound to non-arrow function that contain this arrow function. This results in inconsistent behavior.
	            // To avoid that we will give an error to users if they use arguments objects in arrow function so that they
	            // can explicitly bound arguments objects
	            if (symbol === argumentsSymbol) {
	                var container = ts.getContainingFunction(node);
	                if (container.kind === 177 /* ArrowFunction */) {
	                    if (languageVersion < 2 /* ES6 */) {
	                        error(node, ts.Diagnostics.The_arguments_object_cannot_be_referenced_in_an_arrow_function_in_ES3_and_ES5_Consider_using_a_standard_function_expression);
	                    }
	                }
	                if (node.parserContextFlags & 8 /* Await */) {
	                    getNodeLinks(container).flags |= 8192 /* CaptureArguments */;
	                }
	            }
	            if (symbol.flags & 8388608 /* Alias */ && !isInTypeQuery(node) && !isConstEnumOrConstEnumOnlyModule(resolveAlias(symbol))) {
	                markAliasSymbolAsReferenced(symbol);
	            }
	            var localOrExportSymbol = getExportSymbolOfValueSymbolIfExported(symbol);
	            // Due to the emit for class decorators, any reference to the class from inside of the class body
	            // must instead be rewritten to point to a temporary variable to avoid issues with the double-bind
	            // behavior of class names in ES6.
	            if (languageVersion === 2 /* ES6 */
	                && localOrExportSymbol.flags & 32 /* Class */
	                && localOrExportSymbol.valueDeclaration.kind === 217 /* ClassDeclaration */
	                && ts.nodeIsDecorated(localOrExportSymbol.valueDeclaration)) {
	                var container = ts.getContainingClass(node);
	                while (container !== undefined) {
	                    if (container === localOrExportSymbol.valueDeclaration && container.name !== node) {
	                        getNodeLinks(container).flags |= 524288 /* ClassWithBodyScopedClassBinding */;
	                        getNodeLinks(node).flags |= 1048576 /* BodyScopedClassBinding */;
	                        break;
	                    }
	                    container = ts.getContainingClass(container);
	                }
	            }
	            checkCollisionWithCapturedSuperVariable(node, node);
	            checkCollisionWithCapturedThisVariable(node, node);
	            checkNestedBlockScopedBinding(node, symbol);
	            return getNarrowedTypeOfSymbol(localOrExportSymbol, node);
	        }
	        function isInsideFunction(node, threshold) {
	            var current = node;
	            while (current && current !== threshold) {
	                if (ts.isFunctionLike(current)) {
	                    return true;
	                }
	                current = current.parent;
	            }
	            return false;
	        }
	        function checkNestedBlockScopedBinding(node, symbol) {
	            if (languageVersion >= 2 /* ES6 */ ||
	                (symbol.flags & (2 /* BlockScopedVariable */ | 32 /* Class */)) === 0 ||
	                symbol.valueDeclaration.parent.kind === 247 /* CatchClause */) {
	                return;
	            }
	            // 1. walk from the use site up to the declaration and check
	            // if there is anything function like between declaration and use-site (is binding/class is captured in function).
	            // 2. walk from the declaration up to the boundary of lexical environment and check
	            // if there is an iteration statement in between declaration and boundary (is binding/class declared inside iteration statement)
	            var container = ts.getEnclosingBlockScopeContainer(symbol.valueDeclaration);
	            var usedInFunction = isInsideFunction(node.parent, container);
	            var current = container;
	            var containedInIterationStatement = false;
	            while (current && !ts.nodeStartsNewLexicalEnvironment(current)) {
	                if (ts.isIterationStatement(current, /*lookInLabeledStatements*/ false)) {
	                    containedInIterationStatement = true;
	                    break;
	                }
	                current = current.parent;
	            }
	            if (containedInIterationStatement) {
	                if (usedInFunction) {
	                    // mark iteration statement as containing block-scoped binding captured in some function
	                    getNodeLinks(current).flags |= 65536 /* LoopWithCapturedBlockScopedBinding */;
	                }
	                // mark variables that are declared in loop initializer and reassigned inside the body of ForStatement.
	                // if body of ForStatement will be converted to function then we'll need a extra machinery to propagate reassigned values back.
	                if (container.kind === 202 /* ForStatement */ &&
	                    ts.getAncestor(symbol.valueDeclaration, 215 /* VariableDeclarationList */).parent === container &&
	                    isAssignedInBodyOfForStatement(node, container)) {
	                    getNodeLinks(symbol.valueDeclaration).flags |= 2097152 /* NeedsLoopOutParameter */;
	                }
	                // set 'declared inside loop' bit on the block-scoped binding
	                getNodeLinks(symbol.valueDeclaration).flags |= 262144 /* BlockScopedBindingInLoop */;
	            }
	            if (usedInFunction) {
	                getNodeLinks(symbol.valueDeclaration).flags |= 131072 /* CapturedBlockScopedBinding */;
	            }
	        }
	        function isAssignedInBodyOfForStatement(node, container) {
	            var current = node;
	            // skip parenthesized nodes
	            while (current.parent.kind === 175 /* ParenthesizedExpression */) {
	                current = current.parent;
	            }
	            // check if node is used as LHS in some assignment expression
	            var isAssigned = false;
	            if (current.parent.kind === 184 /* BinaryExpression */) {
	                isAssigned = current.parent.left === current && ts.isAssignmentOperator(current.parent.operatorToken.kind);
	            }
	            if ((current.parent.kind === 182 /* PrefixUnaryExpression */ || current.parent.kind === 183 /* PostfixUnaryExpression */)) {
	                var expr = current.parent;
	                isAssigned = expr.operator === 41 /* PlusPlusToken */ || expr.operator === 42 /* MinusMinusToken */;
	            }
	            if (!isAssigned) {
	                return false;
	            }
	            // at this point we know that node is the target of assignment
	            // now check that modification happens inside the statement part of the ForStatement
	            while (current !== container) {
	                if (current === container.statement) {
	                    return true;
	                }
	                else {
	                    current = current.parent;
	                }
	            }
	            return false;
	        }
	        function captureLexicalThis(node, container) {
	            getNodeLinks(node).flags |= 2 /* LexicalThis */;
	            if (container.kind === 142 /* PropertyDeclaration */ || container.kind === 145 /* Constructor */) {
	                var classNode = container.parent;
	                getNodeLinks(classNode).flags |= 4 /* CaptureThis */;
	            }
	            else {
	                getNodeLinks(container).flags |= 4 /* CaptureThis */;
	            }
	        }
	        function findFirstSuperCall(n) {
	            if (ts.isSuperCallExpression(n)) {
	                return n;
	            }
	            else if (ts.isFunctionLike(n)) {
	                return undefined;
	            }
	            return ts.forEachChild(n, findFirstSuperCall);
	        }
	        /**
	         * Return a cached result if super-statement is already found.
	         * Otherwise, find a super statement in a given constructor function and cache the result in the node-links of the constructor
	         *
	         * @param constructor constructor-function to look for super statement
	         */
	        function getSuperCallInConstructor(constructor) {
	            var links = getNodeLinks(constructor);
	            // Only trying to find super-call if we haven't yet tried to find one.  Once we try, we will record the result
	            if (links.hasSuperCall === undefined) {
	                links.superCall = findFirstSuperCall(constructor.body);
	                links.hasSuperCall = links.superCall ? true : false;
	            }
	            return links.superCall;
	        }
	        /**
	         * Check if the given class-declaration extends null then return true.
	         * Otherwise, return false
	         * @param classDecl a class declaration to check if it extends null
	         */
	        function classDeclarationExtendsNull(classDecl) {
	            var classSymbol = getSymbolOfNode(classDecl);
	            var classInstanceType = getDeclaredTypeOfSymbol(classSymbol);
	            var baseConstructorType = getBaseConstructorTypeOfClass(classInstanceType);
	            return baseConstructorType === nullType;
	        }
	        function checkThisExpression(node) {
	            // Stop at the first arrow function so that we can
	            // tell whether 'this' needs to be captured.
	            var container = ts.getThisContainer(node, /* includeArrowFunctions */ true);
	            var needToCaptureLexicalThis = false;
	            if (container.kind === 145 /* Constructor */) {
	                var containingClassDecl = container.parent;
	                var baseTypeNode = ts.getClassExtendsHeritageClauseElement(containingClassDecl);
	                // If a containing class does not have extends clause or the class extends null
	                // skip checking whether super statement is called before "this" accessing.
	                if (baseTypeNode && !classDeclarationExtendsNull(containingClassDecl)) {
	                    var superCall = getSuperCallInConstructor(container);
	                    // We should give an error in the following cases:
	                    //      - No super-call
	                    //      - "this" is accessing before super-call.
	                    //          i.e super(this)
	                    //              this.x; super();
	                    // We want to make sure that super-call is done before accessing "this" so that
	                    // "this" is not accessed as a parameter of the super-call.
	                    if (!superCall || superCall.end > node.pos) {
	                        // In ES6, super inside constructor of class-declaration has to precede "this" accessing
	                        error(node, ts.Diagnostics.super_must_be_called_before_accessing_this_in_the_constructor_of_a_derived_class);
	                    }
	                }
	            }
	            // Now skip arrow functions to get the "real" owner of 'this'.
	            if (container.kind === 177 /* ArrowFunction */) {
	                container = ts.getThisContainer(container, /* includeArrowFunctions */ false);
	                // When targeting es6, arrow function lexically bind "this" so we do not need to do the work of binding "this" in emitted code
	                needToCaptureLexicalThis = (languageVersion < 2 /* ES6 */);
	            }
	            switch (container.kind) {
	                case 221 /* ModuleDeclaration */:
	                    error(node, ts.Diagnostics.this_cannot_be_referenced_in_a_module_or_namespace_body);
	                    // do not return here so in case if lexical this is captured - it will be reflected in flags on NodeLinks
	                    break;
	                case 220 /* EnumDeclaration */:
	                    error(node, ts.Diagnostics.this_cannot_be_referenced_in_current_location);
	                    // do not return here so in case if lexical this is captured - it will be reflected in flags on NodeLinks
	                    break;
	                case 145 /* Constructor */:
	                    if (isInConstructorArgumentInitializer(node, container)) {
	                        error(node, ts.Diagnostics.this_cannot_be_referenced_in_constructor_arguments);
	                    }
	                    break;
	                case 142 /* PropertyDeclaration */:
	                case 141 /* PropertySignature */:
	                    if (container.flags & 64 /* Static */) {
	                        error(node, ts.Diagnostics.this_cannot_be_referenced_in_a_static_property_initializer);
	                    }
	                    break;
	                case 137 /* ComputedPropertyName */:
	                    error(node, ts.Diagnostics.this_cannot_be_referenced_in_a_computed_property_name);
	                    break;
	            }
	            if (needToCaptureLexicalThis) {
	                captureLexicalThis(node, container);
	            }
	            if (ts.isClassLike(container.parent)) {
	                var symbol = getSymbolOfNode(container.parent);
	                return container.flags & 64 /* Static */ ? getTypeOfSymbol(symbol) : getDeclaredTypeOfSymbol(symbol).thisType;
	            }
	            if (ts.isInJavaScriptFile(node)) {
	                var type = getTypeForThisExpressionFromJSDoc(container);
	                if (type && type !== unknownType) {
	                    return type;
	                }
	                // If this is a function in a JS file, it might be a class method. Check if it's the RHS
	                // of a x.prototype.y = function [name]() { .... }
	                if (container.kind === 176 /* FunctionExpression */) {
	                    if (ts.getSpecialPropertyAssignmentKind(container.parent) === 3 /* PrototypeProperty */) {
	                        // Get the 'x' of 'x.prototype.y = f' (here, 'f' is 'container')
	                        var className = container.parent // x.protoype.y = f
	                            .left // x.prototype.y
	                            .expression // x.prototype
	                            .expression; // x
	                        var classSymbol = checkExpression(className).symbol;
	                        if (classSymbol && classSymbol.members && (classSymbol.flags & 16 /* Function */)) {
	                            return getInferredClassType(classSymbol);
	                        }
	                    }
	                }
	            }
	            return anyType;
	        }
	        function getTypeForThisExpressionFromJSDoc(node) {
	            var typeTag = ts.getJSDocTypeTag(node);
	            if (typeTag && typeTag.typeExpression && typeTag.typeExpression.type && typeTag.typeExpression.type.kind === 264 /* JSDocFunctionType */) {
	                var jsDocFunctionType = typeTag.typeExpression.type;
	                if (jsDocFunctionType.parameters.length > 0 && jsDocFunctionType.parameters[0].type.kind === 267 /* JSDocThisType */) {
	                    return getTypeFromTypeNode(jsDocFunctionType.parameters[0].type);
	                }
	            }
	        }
	        function isInConstructorArgumentInitializer(node, constructorDecl) {
	            for (var n = node; n && n !== constructorDecl; n = n.parent) {
	                if (n.kind === 139 /* Parameter */) {
	                    return true;
	                }
	            }
	            return false;
	        }
	        function checkSuperExpression(node) {
	            var isCallExpression = node.parent.kind === 171 /* CallExpression */ && node.parent.expression === node;
	            var container = ts.getSuperContainer(node, /*stopOnFunctions*/ true);
	            var needToCaptureLexicalThis = false;
	            if (!isCallExpression) {
	                // adjust the container reference in case if super is used inside arrow functions with arbitrary deep nesting
	                while (container && container.kind === 177 /* ArrowFunction */) {
	                    container = ts.getSuperContainer(container, /*stopOnFunctions*/ true);
	                    needToCaptureLexicalThis = languageVersion < 2 /* ES6 */;
	                }
	            }
	            var canUseSuperExpression = isLegalUsageOfSuperExpression(container);
	            var nodeCheckFlag = 0;
	            if (!canUseSuperExpression) {
	                // issue more specific error if super is used in computed property name
	                // class A { foo() { return "1" }}
	                // class B {
	                //     [super.foo()]() {}
	                // }
	                var current = node;
	                while (current && current !== container && current.kind !== 137 /* ComputedPropertyName */) {
	                    current = current.parent;
	                }
	                if (current && current.kind === 137 /* ComputedPropertyName */) {
	                    error(node, ts.Diagnostics.super_cannot_be_referenced_in_a_computed_property_name);
	                }
	                else if (isCallExpression) {
	                    error(node, ts.Diagnostics.Super_calls_are_not_permitted_outside_constructors_or_in_nested_functions_inside_constructors);
	                }
	                else if (!container || !container.parent || !(ts.isClassLike(container.parent) || container.parent.kind === 168 /* ObjectLiteralExpression */)) {
	                    error(node, ts.Diagnostics.super_can_only_be_referenced_in_members_of_derived_classes_or_object_literal_expressions);
	                }
	                else {
	                    error(node, ts.Diagnostics.super_property_access_is_permitted_only_in_a_constructor_member_function_or_member_accessor_of_a_derived_class);
	                }
	                return unknownType;
	            }
	            if ((container.flags & 64 /* Static */) || isCallExpression) {
	                nodeCheckFlag = 512 /* SuperStatic */;
	            }
	            else {
	                nodeCheckFlag = 256 /* SuperInstance */;
	            }
	            getNodeLinks(node).flags |= nodeCheckFlag;
	            // Due to how we emit async functions, we need to specialize the emit for an async method that contains a `super` reference.
	            // This is due to the fact that we emit the body of an async function inside of a generator function. As generator
	            // functions cannot reference `super`, we emit a helper inside of the method body, but outside of the generator. This helper
	            // uses an arrow function, which is permitted to reference `super`.
	            //
	            // There are two primary ways we can access `super` from within an async method. The first is getting the value of a property
	            // or indexed access on super, either as part of a right-hand-side expression or call expression. The second is when setting the value
	            // of a property or indexed access, either as part of an assignment expression or destructuring assignment.
	            //
	            // The simplest case is reading a value, in which case we will emit something like the following:
	            //
	            //  // ts
	            //  ...
	            //  async asyncMethod() {
	            //    let x = await super.asyncMethod();
	            //    return x;
	            //  }
	            //  ...
	            //
	            //  // js
	            //  ...
	            //  asyncMethod() {
	            //      const _super = name => super[name];
	            //      return __awaiter(this, arguments, Promise, function *() {
	            //          let x = yield _super("asyncMethod").call(this);
	            //          return x;
	            //      });
	            //  }
	            //  ...
	            //
	            // The more complex case is when we wish to assign a value, especially as part of a destructuring assignment. As both cases
	            // are legal in ES6, but also likely less frequent, we emit the same more complex helper for both scenarios:
	            //
	            //  // ts
	            //  ...
	            //  async asyncMethod(ar: Promise<any[]>) {
	            //      [super.a, super.b] = await ar;
	            //  }
	            //  ...
	            //
	            //  // js
	            //  ...
	            //  asyncMethod(ar) {
	            //      const _super = (function (geti, seti) {
	            //          const cache = Object.create(null);
	            //          return name => cache[name] || (cache[name] = { get value() { return geti(name); }, set value(v) { seti(name, v); } });
	            //      })(name => super[name], (name, value) => super[name] = value);
	            //      return __awaiter(this, arguments, Promise, function *() {
	            //          [_super("a").value, _super("b").value] = yield ar;
	            //      });
	            //  }
	            //  ...
	            //
	            // This helper creates an object with a "value" property that wraps the `super` property or indexed access for both get and set.
	            // This is required for destructuring assignments, as a call expression cannot be used as the target of a destructuring assignment
	            // while a property access can.
	            if (container.kind === 144 /* MethodDeclaration */ && container.flags & 256 /* Async */) {
	                if (ts.isSuperPropertyOrElementAccess(node.parent) && isAssignmentTarget(node.parent)) {
	                    getNodeLinks(container).flags |= 4096 /* AsyncMethodWithSuperBinding */;
	                }
	                else {
	                    getNodeLinks(container).flags |= 2048 /* AsyncMethodWithSuper */;
	                }
	            }
	            if (needToCaptureLexicalThis) {
	                // call expressions are allowed only in constructors so they should always capture correct 'this'
	                // super property access expressions can also appear in arrow functions -
	                // in this case they should also use correct lexical this
	                captureLexicalThis(node.parent, container);
	            }
	            if (container.parent.kind === 168 /* ObjectLiteralExpression */) {
	                if (languageVersion < 2 /* ES6 */) {
	                    error(node, ts.Diagnostics.super_is_only_allowed_in_members_of_object_literal_expressions_when_option_target_is_ES2015_or_higher);
	                    return unknownType;
	                }
	                else {
	                    // for object literal assume that type of 'super' is 'any'
	                    return anyType;
	                }
	            }
	            // at this point the only legal case for parent is ClassLikeDeclaration
	            var classLikeDeclaration = container.parent;
	            var classType = getDeclaredTypeOfSymbol(getSymbolOfNode(classLikeDeclaration));
	            var baseClassType = classType && getBaseTypes(classType)[0];
	            if (!baseClassType) {
	                if (!ts.getClassExtendsHeritageClauseElement(classLikeDeclaration)) {
	                    error(node, ts.Diagnostics.super_can_only_be_referenced_in_a_derived_class);
	                }
	                return unknownType;
	            }
	            if (container.kind === 145 /* Constructor */ && isInConstructorArgumentInitializer(node, container)) {
	                // issue custom error message for super property access in constructor arguments (to be aligned with old compiler)
	                error(node, ts.Diagnostics.super_cannot_be_referenced_in_constructor_arguments);
	                return unknownType;
	            }
	            return nodeCheckFlag === 512 /* SuperStatic */
	                ? getBaseConstructorTypeOfClass(classType)
	                : baseClassType;
	            function isLegalUsageOfSuperExpression(container) {
	                if (!container) {
	                    return false;
	                }
	                if (isCallExpression) {
	                    // TS 1.0 SPEC (April 2014): 4.8.1
	                    // Super calls are only permitted in constructors of derived classes
	                    return container.kind === 145 /* Constructor */;
	                }
	                else {
	                    // TS 1.0 SPEC (April 2014)
	                    // 'super' property access is allowed
	                    // - In a constructor, instance member function, instance member accessor, or instance member variable initializer where this references a derived class instance
	                    // - In a static member function or static member accessor
	                    // topmost container must be something that is directly nested in the class declaration\object literal expression
	                    if (ts.isClassLike(container.parent) || container.parent.kind === 168 /* ObjectLiteralExpression */) {
	                        if (container.flags & 64 /* Static */) {
	                            return container.kind === 144 /* MethodDeclaration */ ||
	                                container.kind === 143 /* MethodSignature */ ||
	                                container.kind === 146 /* GetAccessor */ ||
	                                container.kind === 147 /* SetAccessor */;
	                        }
	                        else {
	                            return container.kind === 144 /* MethodDeclaration */ ||
	                                container.kind === 143 /* MethodSignature */ ||
	                                container.kind === 146 /* GetAccessor */ ||
	                                container.kind === 147 /* SetAccessor */ ||
	                                container.kind === 142 /* PropertyDeclaration */ ||
	                                container.kind === 141 /* PropertySignature */ ||
	                                container.kind === 145 /* Constructor */;
	                        }
	                    }
	                }
	                return false;
	            }
	        }
	        // Return contextual type of parameter or undefined if no contextual type is available
	        function getContextuallyTypedParameterType(parameter) {
	            var func = parameter.parent;
	            if (isFunctionExpressionOrArrowFunction(func) || ts.isObjectLiteralMethod(func)) {
	                if (isContextSensitive(func)) {
	                    var contextualSignature = getContextualSignature(func);
	                    if (contextualSignature) {
	                        var funcHasRestParameters = ts.hasRestParameter(func);
	                        var len = func.parameters.length - (funcHasRestParameters ? 1 : 0);
	                        var indexOfParameter = ts.indexOf(func.parameters, parameter);
	                        if (indexOfParameter < len) {
	                            return getTypeAtPosition(contextualSignature, indexOfParameter);
	                        }
	                        // If last parameter is contextually rest parameter get its type
	                        if (funcHasRestParameters &&
	                            indexOfParameter === (func.parameters.length - 1) &&
	                            isRestParameterIndex(contextualSignature, func.parameters.length - 1)) {
	                            return getTypeOfSymbol(ts.lastOrUndefined(contextualSignature.parameters));
	                        }
	                    }
	                }
	            }
	            return undefined;
	        }
	        // In a variable, parameter or property declaration with a type annotation, the contextual type of an initializer
	        // expression is the type of the variable, parameter or property. Otherwise, in a parameter declaration of a
	        // contextually typed function expression, the contextual type of an initializer expression is the contextual type
	        // of the parameter. Otherwise, in a variable or parameter declaration with a binding pattern name, the contextual
	        // type of an initializer expression is the type implied by the binding pattern.
	        function getContextualTypeForInitializerExpression(node) {
	            var declaration = node.parent;
	            if (node === declaration.initializer) {
	                if (declaration.type) {
	                    return getTypeFromTypeNode(declaration.type);
	                }
	                if (declaration.kind === 139 /* Parameter */) {
	                    var type = getContextuallyTypedParameterType(declaration);
	                    if (type) {
	                        return type;
	                    }
	                }
	                if (ts.isBindingPattern(declaration.name)) {
	                    return getTypeFromBindingPattern(declaration.name, /*includePatternInType*/ true);
	                }
	            }
	            return undefined;
	        }
	        function getContextualTypeForReturnExpression(node) {
	            var func = ts.getContainingFunction(node);
	            if (func && !func.asteriskToken) {
	                return getContextualReturnType(func);
	            }
	            return undefined;
	        }
	        function getContextualTypeForYieldOperand(node) {
	            var func = ts.getContainingFunction(node);
	            if (func) {
	                var contextualReturnType = getContextualReturnType(func);
	                if (contextualReturnType) {
	                    return node.asteriskToken
	                        ? contextualReturnType
	                        : getElementTypeOfIterableIterator(contextualReturnType);
	                }
	            }
	            return undefined;
	        }
	        function isInParameterInitializerBeforeContainingFunction(node) {
	            while (node.parent && !ts.isFunctionLike(node.parent)) {
	                if (node.parent.kind === 139 /* Parameter */ && node.parent.initializer === node) {
	                    return true;
	                }
	                node = node.parent;
	            }
	            return false;
	        }
	        function getContextualReturnType(functionDecl) {
	            // If the containing function has a return type annotation, is a constructor, or is a get accessor whose
	            // corresponding set accessor has a type annotation, return statements in the function are contextually typed
	            if (functionDecl.type ||
	                functionDecl.kind === 145 /* Constructor */ ||
	                functionDecl.kind === 146 /* GetAccessor */ && ts.getSetAccessorTypeAnnotationNode(ts.getDeclarationOfKind(functionDecl.symbol, 147 /* SetAccessor */))) {
	                return getReturnTypeOfSignature(getSignatureFromDeclaration(functionDecl));
	            }
	            // Otherwise, if the containing function is contextually typed by a function type with exactly one call signature
	            // and that call signature is non-generic, return statements are contextually typed by the return type of the signature
	            var signature = getContextualSignatureForFunctionLikeDeclaration(functionDecl);
	            if (signature) {
	                return getReturnTypeOfSignature(signature);
	            }
	            return undefined;
	        }
	        // In a typed function call, an argument or substitution expression is contextually typed by the type of the corresponding parameter.
	        function getContextualTypeForArgument(callTarget, arg) {
	            var args = getEffectiveCallArguments(callTarget);
	            var argIndex = ts.indexOf(args, arg);
	            if (argIndex >= 0) {
	                var signature = getResolvedSignature(callTarget);
	                return getTypeAtPosition(signature, argIndex);
	            }
	            return undefined;
	        }
	        function getContextualTypeForSubstitutionExpression(template, substitutionExpression) {
	            if (template.parent.kind === 173 /* TaggedTemplateExpression */) {
	                return getContextualTypeForArgument(template.parent, substitutionExpression);
	            }
	            return undefined;
	        }
	        function getContextualTypeForBinaryOperand(node) {
	            var binaryExpression = node.parent;
	            var operator = binaryExpression.operatorToken.kind;
	            if (operator >= 56 /* FirstAssignment */ && operator <= 68 /* LastAssignment */) {
	                // In an assignment expression, the right operand is contextually typed by the type of the left operand.
	                if (node === binaryExpression.right) {
	                    return checkExpression(binaryExpression.left);
	                }
	            }
	            else if (operator === 52 /* BarBarToken */) {
	                // When an || expression has a contextual type, the operands are contextually typed by that type. When an ||
	                // expression has no contextual type, the right operand is contextually typed by the type of the left operand.
	                var type = getContextualType(binaryExpression);
	                if (!type && node === binaryExpression.right) {
	                    type = checkExpression(binaryExpression.left);
	                }
	                return type;
	            }
	            else if (operator === 51 /* AmpersandAmpersandToken */ || operator === 24 /* CommaToken */) {
	                if (node === binaryExpression.right) {
	                    return getContextualType(binaryExpression);
	                }
	            }
	            return undefined;
	        }
	        // Apply a mapping function to a contextual type and return the resulting type. If the contextual type
	        // is a union type, the mapping function is applied to each constituent type and a union of the resulting
	        // types is returned.
	        function applyToContextualType(type, mapper) {
	            if (!(type.flags & 16384 /* Union */)) {
	                return mapper(type);
	            }
	            var types = type.types;
	            var mappedType;
	            var mappedTypes;
	            for (var _i = 0, types_8 = types; _i < types_8.length; _i++) {
	                var current = types_8[_i];
	                var t = mapper(current);
	                if (t) {
	                    if (!mappedType) {
	                        mappedType = t;
	                    }
	                    else if (!mappedTypes) {
	                        mappedTypes = [mappedType, t];
	                    }
	                    else {
	                        mappedTypes.push(t);
	                    }
	                }
	            }
	            return mappedTypes ? getUnionType(mappedTypes) : mappedType;
	        }
	        function getTypeOfPropertyOfContextualType(type, name) {
	            return applyToContextualType(type, function (t) {
	                var prop = t.flags & 130048 /* StructuredType */ ? getPropertyOfType(t, name) : undefined;
	                return prop ? getTypeOfSymbol(prop) : undefined;
	            });
	        }
	        function getIndexTypeOfContextualType(type, kind) {
	            return applyToContextualType(type, function (t) { return getIndexTypeOfStructuredType(t, kind); });
	        }
	        function contextualTypeIsStringLiteralType(type) {
	            return !!(type.flags & 16384 /* Union */ ? ts.forEach(type.types, isStringLiteralType) : isStringLiteralType(type));
	        }
	        // Return true if the given contextual type is a tuple-like type
	        function contextualTypeIsTupleLikeType(type) {
	            return !!(type.flags & 16384 /* Union */ ? ts.forEach(type.types, isTupleLikeType) : isTupleLikeType(type));
	        }
	        // Return true if the given contextual type provides an index signature of the given kind
	        function contextualTypeHasIndexSignature(type, kind) {
	            return !!(type.flags & 16384 /* Union */ ? ts.forEach(type.types, function (t) { return getIndexTypeOfStructuredType(t, kind); }) : getIndexTypeOfStructuredType(type, kind));
	        }
	        // In an object literal contextually typed by a type T, the contextual type of a property assignment is the type of
	        // the matching property in T, if one exists. Otherwise, it is the type of the numeric index signature in T, if one
	        // exists. Otherwise, it is the type of the string index signature in T, if one exists.
	        function getContextualTypeForObjectLiteralMethod(node) {
	            ts.Debug.assert(ts.isObjectLiteralMethod(node));
	            if (isInsideWithStatementBody(node)) {
	                // We cannot answer semantic questions within a with block, do not proceed any further
	                return undefined;
	            }
	            return getContextualTypeForObjectLiteralElement(node);
	        }
	        function getContextualTypeForObjectLiteralElement(element) {
	            var objectLiteral = element.parent;
	            var type = getApparentTypeOfContextualType(objectLiteral);
	            if (type) {
	                if (!ts.hasDynamicName(element)) {
	                    // For a (non-symbol) computed property, there is no reason to look up the name
	                    // in the type. It will just be "__computed", which does not appear in any
	                    // SymbolTable.
	                    var symbolName = getSymbolOfNode(element).name;
	                    var propertyType = getTypeOfPropertyOfContextualType(type, symbolName);
	                    if (propertyType) {
	                        return propertyType;
	                    }
	                }
	                return isNumericName(element.name) && getIndexTypeOfContextualType(type, 1 /* Number */) ||
	                    getIndexTypeOfContextualType(type, 0 /* String */);
	            }
	            return undefined;
	        }
	        // In an array literal contextually typed by a type T, the contextual type of an element expression at index N is
	        // the type of the property with the numeric name N in T, if one exists. Otherwise, if T has a numeric index signature,
	        // it is the type of the numeric index signature in T. Otherwise, in ES6 and higher, the contextual type is the iterated
	        // type of T.
	        function getContextualTypeForElementExpression(node) {
	            var arrayLiteral = node.parent;
	            var type = getApparentTypeOfContextualType(arrayLiteral);
	            if (type) {
	                var index = ts.indexOf(arrayLiteral.elements, node);
	                return getTypeOfPropertyOfContextualType(type, "" + index)
	                    || getIndexTypeOfContextualType(type, 1 /* Number */)
	                    || (languageVersion >= 2 /* ES6 */ ? getElementTypeOfIterable(type, /*errorNode*/ undefined) : undefined);
	            }
	            return undefined;
	        }
	        // In a contextually typed conditional expression, the true/false expressions are contextually typed by the same type.
	        function getContextualTypeForConditionalOperand(node) {
	            var conditional = node.parent;
	            return node === conditional.whenTrue || node === conditional.whenFalse ? getContextualType(conditional) : undefined;
	        }
	        function getContextualTypeForJsxAttribute(attribute) {
	            var kind = attribute.kind;
	            var jsxElement = attribute.parent;
	            var attrsType = getJsxElementAttributesType(jsxElement);
	            if (attribute.kind === 241 /* JsxAttribute */) {
	                if (!attrsType || isTypeAny(attrsType)) {
	                    return undefined;
	                }
	                return getTypeOfPropertyOfType(attrsType, attribute.name.text);
	            }
	            else if (attribute.kind === 242 /* JsxSpreadAttribute */) {
	                return attrsType;
	            }
	            ts.Debug.fail("Expected JsxAttribute or JsxSpreadAttribute, got ts.SyntaxKind[" + kind + "]");
	        }
	        // Return the contextual type for a given expression node. During overload resolution, a contextual type may temporarily
	        // be "pushed" onto a node using the contextualType property.
	        function getApparentTypeOfContextualType(node) {
	            var type = getContextualType(node);
	            return type && getApparentType(type);
	        }
	        /**
	         * Woah! Do you really want to use this function?
	         *
	         * Unless you're trying to get the *non-apparent* type for a
	         * value-literal type or you're authoring relevant portions of this algorithm,
	         * you probably meant to use 'getApparentTypeOfContextualType'.
	         * Otherwise this may not be very useful.
	         *
	         * In cases where you *are* working on this function, you should understand
	         * when it is appropriate to use 'getContextualType' and 'getApparentTypeOfContetxualType'.
	         *
	         *   - Use 'getContextualType' when you are simply going to propagate the result to the expression.
	         *   - Use 'getApparentTypeOfContextualType' when you're going to need the members of the type.
	         *
	         * @param node the expression whose contextual type will be returned.
	         * @returns the contextual type of an expression.
	         */
	        function getContextualType(node) {
	            if (isInsideWithStatementBody(node)) {
	                // We cannot answer semantic questions within a with block, do not proceed any further
	                return undefined;
	            }
	            if (node.contextualType) {
	                return node.contextualType;
	            }
	            var parent = node.parent;
	            switch (parent.kind) {
	                case 214 /* VariableDeclaration */:
	                case 139 /* Parameter */:
	                case 142 /* PropertyDeclaration */:
	                case 141 /* PropertySignature */:
	                case 166 /* BindingElement */:
	                    return getContextualTypeForInitializerExpression(node);
	                case 177 /* ArrowFunction */:
	                case 207 /* ReturnStatement */:
	                    return getContextualTypeForReturnExpression(node);
	                case 187 /* YieldExpression */:
	                    return getContextualTypeForYieldOperand(parent);
	                case 171 /* CallExpression */:
	                case 172 /* NewExpression */:
	                    return getContextualTypeForArgument(parent, node);
	                case 174 /* TypeAssertionExpression */:
	                case 192 /* AsExpression */:
	                    return getTypeFromTypeNode(parent.type);
	                case 184 /* BinaryExpression */:
	                    return getContextualTypeForBinaryOperand(node);
	                case 248 /* PropertyAssignment */:
	                    return getContextualTypeForObjectLiteralElement(parent);
	                case 167 /* ArrayLiteralExpression */:
	                    return getContextualTypeForElementExpression(node);
	                case 185 /* ConditionalExpression */:
	                    return getContextualTypeForConditionalOperand(node);
	                case 193 /* TemplateSpan */:
	                    ts.Debug.assert(parent.parent.kind === 186 /* TemplateExpression */);
	                    return getContextualTypeForSubstitutionExpression(parent.parent, node);
	                case 175 /* ParenthesizedExpression */:
	                    return getContextualType(parent);
	                case 243 /* JsxExpression */:
	                    return getContextualType(parent);
	                case 241 /* JsxAttribute */:
	                case 242 /* JsxSpreadAttribute */:
	                    return getContextualTypeForJsxAttribute(parent);
	            }
	            return undefined;
	        }
	        // If the given type is an object or union type, if that type has a single signature, and if
	        // that signature is non-generic, return the signature. Otherwise return undefined.
	        function getNonGenericSignature(type) {
	            var signatures = getSignaturesOfStructuredType(type, 0 /* Call */);
	            if (signatures.length === 1) {
	                var signature = signatures[0];
	                if (!signature.typeParameters) {
	                    return signature;
	                }
	            }
	        }
	        function isFunctionExpressionOrArrowFunction(node) {
	            return node.kind === 176 /* FunctionExpression */ || node.kind === 177 /* ArrowFunction */;
	        }
	        function getContextualSignatureForFunctionLikeDeclaration(node) {
	            // Only function expressions, arrow functions, and object literal methods are contextually typed.
	            return isFunctionExpressionOrArrowFunction(node) || ts.isObjectLiteralMethod(node)
	                ? getContextualSignature(node)
	                : undefined;
	        }
	        // Return the contextual signature for a given expression node. A contextual type provides a
	        // contextual signature if it has a single call signature and if that call signature is non-generic.
	        // If the contextual type is a union type, get the signature from each type possible and if they are
	        // all identical ignoring their return type, the result is same signature but with return type as
	        // union type of return types from these signatures
	        function getContextualSignature(node) {
	            ts.Debug.assert(node.kind !== 144 /* MethodDeclaration */ || ts.isObjectLiteralMethod(node));
	            var type = ts.isObjectLiteralMethod(node)
	                ? getContextualTypeForObjectLiteralMethod(node)
	                : getApparentTypeOfContextualType(node);
	            if (!type) {
	                return undefined;
	            }
	            if (!(type.flags & 16384 /* Union */)) {
	                return getNonGenericSignature(type);
	            }
	            var signatureList;
	            var types = type.types;
	            for (var _i = 0, types_9 = types; _i < types_9.length; _i++) {
	                var current = types_9[_i];
	                var signature = getNonGenericSignature(current);
	                if (signature) {
	                    if (!signatureList) {
	                        // This signature will contribute to contextual union signature
	                        signatureList = [signature];
	                    }
	                    else if (!compareSignaturesIdentical(signatureList[0], signature, /*partialMatch*/ false, /*ignoreReturnTypes*/ true, compareTypesIdentical)) {
	                        // Signatures aren't identical, do not use
	                        return undefined;
	                    }
	                    else {
	                        // Use this signature for contextual union signature
	                        signatureList.push(signature);
	                    }
	                }
	            }
	            // Result is union of signatures collected (return type is union of return types of this signature set)
	            var result;
	            if (signatureList) {
	                result = cloneSignature(signatureList[0]);
	                // Clear resolved return type we possibly got from cloneSignature
	                result.resolvedReturnType = undefined;
	                result.unionSignatures = signatureList;
	            }
	            return result;
	        }
	        /**
	         * Detect if the mapper implies an inference context. Specifically, there are 4 possible values
	         * for a mapper. Let's go through each one of them:
	         *
	         *    1. undefined - this means we are not doing inferential typing, but we may do contextual typing,
	         *       which could cause us to assign a parameter a type
	         *    2. identityMapper - means we want to avoid assigning a parameter a type, whether or not we are in
	         *       inferential typing (context is undefined for the identityMapper)
	         *    3. a mapper created by createInferenceMapper - we are doing inferential typing, we want to assign
	         *       types to parameters and fix type parameters (context is defined)
	         *    4. an instantiation mapper created by createTypeMapper or createTypeEraser - this should never be
	         *       passed as the contextual mapper when checking an expression (context is undefined for these)
	         *
	         * isInferentialContext is detecting if we are in case 3
	         */
	        function isInferentialContext(mapper) {
	            return mapper && mapper.context;
	        }
	        // A node is an assignment target if it is on the left hand side of an '=' token, if it is parented by a property
	        // assignment in an object literal that is an assignment target, or if it is parented by an array literal that is
	        // an assignment target. Examples include 'a = xxx', '{ p: a } = xxx', '[{ p: a}] = xxx'.
	        function isAssignmentTarget(node) {
	            var parent = node.parent;
	            if (parent.kind === 184 /* BinaryExpression */ && parent.operatorToken.kind === 56 /* EqualsToken */ && parent.left === node) {
	                return true;
	            }
	            if (parent.kind === 248 /* PropertyAssignment */) {
	                return isAssignmentTarget(parent.parent);
	            }
	            if (parent.kind === 167 /* ArrayLiteralExpression */) {
	                return isAssignmentTarget(parent);
	            }
	            return false;
	        }
	        function checkSpreadElementExpression(node, contextualMapper) {
	            // It is usually not safe to call checkExpressionCached if we can be contextually typing.
	            // You can tell that we are contextually typing because of the contextualMapper parameter.
	            // While it is true that a spread element can have a contextual type, it does not do anything
	            // with this type. It is neither affected by it, nor does it propagate it to its operand.
	            // So the fact that contextualMapper is passed is not important, because the operand of a spread
	            // element is not contextually typed.
	            var arrayOrIterableType = checkExpressionCached(node.expression, contextualMapper);
	            return checkIteratedTypeOrElementType(arrayOrIterableType, node.expression, /*allowStringInput*/ false);
	        }
	        function hasDefaultValue(node) {
	            return (node.kind === 166 /* BindingElement */ && !!node.initializer) ||
	                (node.kind === 184 /* BinaryExpression */ && node.operatorToken.kind === 56 /* EqualsToken */);
	        }
	        function checkArrayLiteral(node, contextualMapper) {
	            var elements = node.elements;
	            var hasSpreadElement = false;
	            var elementTypes = [];
	            var inDestructuringPattern = isAssignmentTarget(node);
	            for (var _i = 0, elements_1 = elements; _i < elements_1.length; _i++) {
	                var e = elements_1[_i];
	                if (inDestructuringPattern && e.kind === 188 /* SpreadElementExpression */) {
	                    // Given the following situation:
	                    //    var c: {};
	                    //    [...c] = ["", 0];
	                    //
	                    // c is represented in the tree as a spread element in an array literal.
	                    // But c really functions as a rest element, and its purpose is to provide
	                    // a contextual type for the right hand side of the assignment. Therefore,
	                    // instead of calling checkExpression on "...c", which will give an error
	                    // if c is not iterable/array-like, we need to act as if we are trying to
	                    // get the contextual element type from it. So we do something similar to
	                    // getContextualTypeForElementExpression, which will crucially not error
	                    // if there is no index type / iterated type.
	                    var restArrayType = checkExpression(e.expression, contextualMapper);
	                    var restElementType = getIndexTypeOfType(restArrayType, 1 /* Number */) ||
	                        (languageVersion >= 2 /* ES6 */ ? getElementTypeOfIterable(restArrayType, /*errorNode*/ undefined) : undefined);
	                    if (restElementType) {
	                        elementTypes.push(restElementType);
	                    }
	                }
	                else {
	                    var type = checkExpression(e, contextualMapper);
	                    elementTypes.push(type);
	                }
	                hasSpreadElement = hasSpreadElement || e.kind === 188 /* SpreadElementExpression */;
	            }
	            if (!hasSpreadElement) {
	                // If array literal is actually a destructuring pattern, mark it as an implied type. We do this such
	                // that we get the same behavior for "var [x, y] = []" and "[x, y] = []".
	                if (inDestructuringPattern && elementTypes.length) {
	                    var type = createNewTupleType(elementTypes);
	                    type.pattern = node;
	                    return type;
	                }
	                var contextualType = getApparentTypeOfContextualType(node);
	                if (contextualType && contextualTypeIsTupleLikeType(contextualType)) {
	                    var pattern = contextualType.pattern;
	                    // If array literal is contextually typed by a binding pattern or an assignment pattern, pad the resulting
	                    // tuple type with the corresponding binding or assignment element types to make the lengths equal.
	                    if (pattern && (pattern.kind === 165 /* ArrayBindingPattern */ || pattern.kind === 167 /* ArrayLiteralExpression */)) {
	                        var patternElements = pattern.elements;
	                        for (var i = elementTypes.length; i < patternElements.length; i++) {
	                            var patternElement = patternElements[i];
	                            if (hasDefaultValue(patternElement)) {
	                                elementTypes.push(contextualType.elementTypes[i]);
	                            }
	                            else {
	                                if (patternElement.kind !== 190 /* OmittedExpression */) {
	                                    error(patternElement, ts.Diagnostics.Initializer_provides_no_value_for_this_binding_element_and_the_binding_element_has_no_default_value);
	                                }
	                                elementTypes.push(unknownType);
	                            }
	                        }
	                    }
	                    if (elementTypes.length) {
	                        return createTupleType(elementTypes);
	                    }
	                }
	            }
	            return createArrayType(elementTypes.length ? getUnionType(elementTypes) : undefinedType);
	        }
	        function isNumericName(name) {
	            return name.kind === 137 /* ComputedPropertyName */ ? isNumericComputedName(name) : isNumericLiteralName(name.text);
	        }
	        function isNumericComputedName(name) {
	            // It seems odd to consider an expression of type Any to result in a numeric name,
	            // but this behavior is consistent with checkIndexedAccess
	            return isTypeAnyOrAllConstituentTypesHaveKind(checkComputedPropertyName(name), 132 /* NumberLike */);
	        }
	        function isTypeAnyOrAllConstituentTypesHaveKind(type, kind) {
	            return isTypeAny(type) || allConstituentTypesHaveKind(type, kind);
	        }
	        function isNumericLiteralName(name) {
	            // The intent of numeric names is that
	            //     - they are names with text in a numeric form, and that
	            //     - setting properties/indexing with them is always equivalent to doing so with the numeric literal 'numLit',
	            //         acquired by applying the abstract 'ToNumber' operation on the name's text.
	            //
	            // The subtlety is in the latter portion, as we cannot reliably say that anything that looks like a numeric literal is a numeric name.
	            // In fact, it is the case that the text of the name must be equal to 'ToString(numLit)' for this to hold.
	            //
	            // Consider the property name '"0xF00D"'. When one indexes with '0xF00D', they are actually indexing with the value of 'ToString(0xF00D)'
	            // according to the ECMAScript specification, so it is actually as if the user indexed with the string '"61453"'.
	            // Thus, the text of all numeric literals equivalent to '61543' such as '0xF00D', '0xf00D', '0170015', etc. are not valid numeric names
	            // because their 'ToString' representation is not equal to their original text.
	            // This is motivated by ECMA-262 sections 9.3.1, 9.8.1, 11.1.5, and 11.2.1.
	            //
	            // Here, we test whether 'ToString(ToNumber(name))' is exactly equal to 'name'.
	            // The '+' prefix operator is equivalent here to applying the abstract ToNumber operation.
	            // Applying the 'toString()' method on a number gives us the abstract ToString operation on a number.
	            //
	            // Note that this accepts the values 'Infinity', '-Infinity', and 'NaN', and that this is intentional.
	            // This is desired behavior, because when indexing with them as numeric entities, you are indexing
	            // with the strings '"Infinity"', '"-Infinity"', and '"NaN"' respectively.
	            return (+name).toString() === name;
	        }
	        function checkComputedPropertyName(node) {
	            var links = getNodeLinks(node.expression);
	            if (!links.resolvedType) {
	                links.resolvedType = checkExpression(node.expression);
	                // This will allow types number, string, symbol or any. It will also allow enums, the unknown
	                // type, and any union of these types (like string | number).
	                if (!isTypeAnyOrAllConstituentTypesHaveKind(links.resolvedType, 132 /* NumberLike */ | 258 /* StringLike */ | 16777216 /* ESSymbol */)) {
	                    error(node, ts.Diagnostics.A_computed_property_name_must_be_of_type_string_number_symbol_or_any);
	                }
	                else {
	                    checkThatExpressionIsProperSymbolReference(node.expression, links.resolvedType, /*reportError*/ true);
	                }
	            }
	            return links.resolvedType;
	        }
	        function checkObjectLiteral(node, contextualMapper) {
	            var inDestructuringPattern = isAssignmentTarget(node);
	            // Grammar checking
	            checkGrammarObjectLiteralExpression(node, inDestructuringPattern);
	            var propertiesTable = {};
	            var propertiesArray = [];
	            var contextualType = getApparentTypeOfContextualType(node);
	            var contextualTypeHasPattern = contextualType && contextualType.pattern &&
	                (contextualType.pattern.kind === 164 /* ObjectBindingPattern */ || contextualType.pattern.kind === 168 /* ObjectLiteralExpression */);
	            var typeFlags = 0;
	            var patternWithComputedProperties = false;
	            for (var _i = 0, _a = node.properties; _i < _a.length; _i++) {
	                var memberDecl = _a[_i];
	                var member = memberDecl.symbol;
	                if (memberDecl.kind === 248 /* PropertyAssignment */ ||
	                    memberDecl.kind === 249 /* ShorthandPropertyAssignment */ ||
	                    ts.isObjectLiteralMethod(memberDecl)) {
	                    var type = void 0;
	                    if (memberDecl.kind === 248 /* PropertyAssignment */) {
	                        type = checkPropertyAssignment(memberDecl, contextualMapper);
	                    }
	                    else if (memberDecl.kind === 144 /* MethodDeclaration */) {
	                        type = checkObjectLiteralMethod(memberDecl, contextualMapper);
	                    }
	                    else {
	                        ts.Debug.assert(memberDecl.kind === 249 /* ShorthandPropertyAssignment */);
	                        type = checkExpression(memberDecl.name, contextualMapper);
	                    }
	                    typeFlags |= type.flags;
	                    var prop = createSymbol(4 /* Property */ | 67108864 /* Transient */ | member.flags, member.name);
	                    if (inDestructuringPattern) {
	                        // If object literal is an assignment pattern and if the assignment pattern specifies a default value
	                        // for the property, make the property optional.
	                        var isOptional = (memberDecl.kind === 248 /* PropertyAssignment */ && hasDefaultValue(memberDecl.initializer)) ||
	                            (memberDecl.kind === 249 /* ShorthandPropertyAssignment */ && memberDecl.objectAssignmentInitializer);
	                        if (isOptional) {
	                            prop.flags |= 536870912 /* Optional */;
	                        }
	                        if (ts.hasDynamicName(memberDecl)) {
	                            patternWithComputedProperties = true;
	                        }
	                    }
	                    else if (contextualTypeHasPattern && !(contextualType.flags & 67108864 /* ObjectLiteralPatternWithComputedProperties */)) {
	                        // If object literal is contextually typed by the implied type of a binding pattern, and if the
	                        // binding pattern specifies a default value for the property, make the property optional.
	                        var impliedProp = getPropertyOfType(contextualType, member.name);
	                        if (impliedProp) {
	                            prop.flags |= impliedProp.flags & 536870912 /* Optional */;
	                        }
	                        else if (!compilerOptions.suppressExcessPropertyErrors) {
	                            error(memberDecl.name, ts.Diagnostics.Object_literal_may_only_specify_known_properties_and_0_does_not_exist_in_type_1, symbolToString(member), typeToString(contextualType));
	                        }
	                    }
	                    prop.declarations = member.declarations;
	                    prop.parent = member.parent;
	                    if (member.valueDeclaration) {
	                        prop.valueDeclaration = member.valueDeclaration;
	                    }
	                    prop.type = type;
	                    prop.target = member;
	                    member = prop;
	                }
	                else {
	                    // TypeScript 1.0 spec (April 2014)
	                    // A get accessor declaration is processed in the same manner as
	                    // an ordinary function declaration(section 6.1) with no parameters.
	                    // A set accessor declaration is processed in the same manner
	                    // as an ordinary function declaration with a single parameter and a Void return type.
	                    ts.Debug.assert(memberDecl.kind === 146 /* GetAccessor */ || memberDecl.kind === 147 /* SetAccessor */);
	                    checkAccessorDeclaration(memberDecl);
	                }
	                if (!ts.hasDynamicName(memberDecl)) {
	                    propertiesTable[member.name] = member;
	                }
	                propertiesArray.push(member);
	            }
	            // If object literal is contextually typed by the implied type of a binding pattern, augment the result
	            // type with those properties for which the binding pattern specifies a default value.
	            if (contextualTypeHasPattern) {
	                for (var _b = 0, _c = getPropertiesOfType(contextualType); _b < _c.length; _b++) {
	                    var prop = _c[_b];
	                    if (!ts.hasProperty(propertiesTable, prop.name)) {
	                        if (!(prop.flags & 536870912 /* Optional */)) {
	                            error(prop.valueDeclaration || prop.bindingElement, ts.Diagnostics.Initializer_provides_no_value_for_this_binding_element_and_the_binding_element_has_no_default_value);
	                        }
	                        propertiesTable[prop.name] = prop;
	                        propertiesArray.push(prop);
	                    }
	                }
	            }
	            var stringIndexType = getIndexType(0 /* String */);
	            var numberIndexType = getIndexType(1 /* Number */);
	            var result = createAnonymousType(node.symbol, propertiesTable, emptyArray, emptyArray, stringIndexType, numberIndexType);
	            var freshObjectLiteralFlag = compilerOptions.suppressExcessPropertyErrors ? 0 : 1048576 /* FreshObjectLiteral */;
	            result.flags |= 524288 /* ObjectLiteral */ | 4194304 /* ContainsObjectLiteral */ | freshObjectLiteralFlag | (typeFlags & 14680064 /* PropagatingFlags */) | (patternWithComputedProperties ? 67108864 /* ObjectLiteralPatternWithComputedProperties */ : 0);
	            if (inDestructuringPattern) {
	                result.pattern = node;
	            }
	            return result;
	            function getIndexType(kind) {
	                if (contextualType && contextualTypeHasIndexSignature(contextualType, kind)) {
	                    var propTypes = [];
	                    for (var i = 0; i < propertiesArray.length; i++) {
	                        var propertyDecl = node.properties[i];
	                        if (kind === 0 /* String */ || isNumericName(propertyDecl.name)) {
	                            // Do not call getSymbolOfNode(propertyDecl), as that will get the
	                            // original symbol for the node. We actually want to get the symbol
	                            // created by checkObjectLiteral, since that will be appropriately
	                            // contextually typed and resolved.
	                            var type = getTypeOfSymbol(propertiesArray[i]);
	                            if (!ts.contains(propTypes, type)) {
	                                propTypes.push(type);
	                            }
	                        }
	                    }
	                    var result_1 = propTypes.length ? getUnionType(propTypes) : undefinedType;
	                    typeFlags |= result_1.flags;
	                    return result_1;
	                }
	                return undefined;
	            }
	        }
	        function checkJsxSelfClosingElement(node) {
	            checkJsxOpeningLikeElement(node);
	            return jsxElementType || anyType;
	        }
	        function checkJsxElement(node) {
	            // Check attributes
	            checkJsxOpeningLikeElement(node.openingElement);
	            // Perform resolution on the closing tag so that rename/go to definition/etc work
	            getJsxElementTagSymbol(node.closingElement);
	            // Check children
	            for (var _i = 0, _a = node.children; _i < _a.length; _i++) {
	                var child = _a[_i];
	                switch (child.kind) {
	                    case 243 /* JsxExpression */:
	                        checkJsxExpression(child);
	                        break;
	                    case 236 /* JsxElement */:
	                        checkJsxElement(child);
	                        break;
	                    case 237 /* JsxSelfClosingElement */:
	                        checkJsxSelfClosingElement(child);
	                        break;
	                }
	            }
	            return jsxElementType || anyType;
	        }
	        /**
	         * Returns true iff the JSX element name would be a valid JS identifier, ignoring restrictions about keywords not being identifiers
	         */
	        function isUnhyphenatedJsxName(name) {
	            // - is the only character supported in JSX attribute names that isn't valid in JavaScript identifiers
	            return name.indexOf("-") < 0;
	        }
	        /**
	         * Returns true iff React would emit this tag name as a string rather than an identifier or qualified name
	         */
	        function isJsxIntrinsicIdentifier(tagName) {
	            if (tagName.kind === 136 /* QualifiedName */) {
	                return false;
	            }
	            else {
	                return ts.isIntrinsicJsxName(tagName.text);
	            }
	        }
	        function checkJsxAttribute(node, elementAttributesType, nameTable) {
	            var correspondingPropType = undefined;
	            // Look up the corresponding property for this attribute
	            if (elementAttributesType === emptyObjectType && isUnhyphenatedJsxName(node.name.text)) {
	                // If there is no 'props' property, you may not have non-"data-" attributes
	                error(node.parent, ts.Diagnostics.JSX_element_class_does_not_support_attributes_because_it_does_not_have_a_0_property, getJsxElementPropertiesName());
	            }
	            else if (elementAttributesType && !isTypeAny(elementAttributesType)) {
	                var correspondingPropSymbol = getPropertyOfType(elementAttributesType, node.name.text);
	                correspondingPropType = correspondingPropSymbol && getTypeOfSymbol(correspondingPropSymbol);
	                if (isUnhyphenatedJsxName(node.name.text)) {
	                    // Maybe there's a string indexer?
	                    var indexerType = getIndexTypeOfType(elementAttributesType, 0 /* String */);
	                    if (indexerType) {
	                        correspondingPropType = indexerType;
	                    }
	                    else {
	                        // If there's no corresponding property with this name, error
	                        if (!correspondingPropType) {
	                            error(node.name, ts.Diagnostics.Property_0_does_not_exist_on_type_1, node.name.text, typeToString(elementAttributesType));
	                            return unknownType;
	                        }
	                    }
	                }
	            }
	            var exprType;
	            if (node.initializer) {
	                exprType = checkExpression(node.initializer);
	            }
	            else {
	                // <Elem attr /> is sugar for <Elem attr={true} />
	                exprType = booleanType;
	            }
	            if (correspondingPropType) {
	                checkTypeAssignableTo(exprType, correspondingPropType, node);
	            }
	            nameTable[node.name.text] = true;
	            return exprType;
	        }
	        function checkJsxSpreadAttribute(node, elementAttributesType, nameTable) {
	            var type = checkExpression(node.expression);
	            var props = getPropertiesOfType(type);
	            for (var _i = 0, props_2 = props; _i < props_2.length; _i++) {
	                var prop = props_2[_i];
	                // Is there a corresponding property in the element attributes type? Skip checking of properties
	                // that have already been assigned to, as these are not actually pushed into the resulting type
	                if (!nameTable[prop.name]) {
	                    var targetPropSym = getPropertyOfType(elementAttributesType, prop.name);
	                    if (targetPropSym) {
	                        var msg = ts.chainDiagnosticMessages(undefined, ts.Diagnostics.Property_0_of_JSX_spread_attribute_is_not_assignable_to_target_property, prop.name);
	                        checkTypeAssignableTo(getTypeOfSymbol(prop), getTypeOfSymbol(targetPropSym), node, undefined, msg);
	                    }
	                    nameTable[prop.name] = true;
	                }
	            }
	            return type;
	        }
	        function getJsxType(name) {
	            if (jsxTypes[name] === undefined) {
	                return jsxTypes[name] = getExportedTypeFromNamespace(JsxNames.JSX, name) || unknownType;
	            }
	            return jsxTypes[name];
	        }
	        /// Given a JSX opening element or self-closing element, return the symbol of the property that the tag name points to if
	        /// this is an intrinsic tag. This might be a named
	        /// property of the IntrinsicElements interface, or its string indexer.
	        /// If this is a class-based tag (otherwise returns undefined), returns the symbol of the class
	        /// type or factory function.
	        /// Otherwise, returns unknownSymbol.
	        function getJsxElementTagSymbol(node) {
	            var links = getNodeLinks(node);
	            if (!links.resolvedSymbol) {
	                if (isJsxIntrinsicIdentifier(node.tagName)) {
	                    links.resolvedSymbol = lookupIntrinsicTag(node);
	                }
	                else {
	                    links.resolvedSymbol = lookupClassTag(node);
	                }
	            }
	            return links.resolvedSymbol;
	            function lookupIntrinsicTag(node) {
	                var intrinsicElementsType = getJsxType(JsxNames.IntrinsicElements);
	                if (intrinsicElementsType !== unknownType) {
	                    // Property case
	                    var intrinsicProp = getPropertyOfType(intrinsicElementsType, node.tagName.text);
	                    if (intrinsicProp) {
	                        links.jsxFlags |= 1 /* IntrinsicNamedElement */;
	                        return intrinsicProp;
	                    }
	                    // Intrinsic string indexer case
	                    var indexSignatureType = getIndexTypeOfType(intrinsicElementsType, 0 /* String */);
	                    if (indexSignatureType) {
	                        links.jsxFlags |= 2 /* IntrinsicIndexedElement */;
	                        return intrinsicElementsType.symbol;
	                    }
	                    // Wasn't found
	                    error(node, ts.Diagnostics.Property_0_does_not_exist_on_type_1, node.tagName.text, "JSX." + JsxNames.IntrinsicElements);
	                    return unknownSymbol;
	                }
	                else {
	                    if (compilerOptions.noImplicitAny) {
	                        error(node, ts.Diagnostics.JSX_element_implicitly_has_type_any_because_no_interface_JSX_0_exists, JsxNames.IntrinsicElements);
	                    }
	                    return unknownSymbol;
	                }
	            }
	            function lookupClassTag(node) {
	                var valueSymbol = resolveJsxTagName(node);
	                // Look up the value in the current scope
	                if (valueSymbol && valueSymbol !== unknownSymbol) {
	                    links.jsxFlags |= 4 /* ValueElement */;
	                    if (valueSymbol.flags & 8388608 /* Alias */) {
	                        markAliasSymbolAsReferenced(valueSymbol);
	                    }
	                }
	                return valueSymbol || unknownSymbol;
	            }
	            function resolveJsxTagName(node) {
	                if (node.tagName.kind === 69 /* Identifier */) {
	                    var tag = node.tagName;
	                    var sym = getResolvedSymbol(tag);
	                    return sym.exportSymbol || sym;
	                }
	                else {
	                    return checkQualifiedName(node.tagName).symbol;
	                }
	            }
	        }
	        /**
	         * Given a JSX element that is a class element, finds the Element Instance Type. If the
	         * element is not a class element, or the class element type cannot be determined, returns 'undefined'.
	         * For example, in the element <MyClass>, the element instance type is `MyClass` (not `typeof MyClass`).
	         */
	        function getJsxElementInstanceType(node) {
	            // There is no such thing as an instance type for a non-class element. This
	            // line shouldn't be hit.
	            ts.Debug.assert(!!(getNodeLinks(node).jsxFlags & 4 /* ValueElement */), "Should not call getJsxElementInstanceType on non-class Element");
	            var classSymbol = getJsxElementTagSymbol(node);
	            if (classSymbol === unknownSymbol) {
	                // Couldn't find the class instance type. Error has already been issued
	                return anyType;
	            }
	            var valueType = getTypeOfSymbol(classSymbol);
	            if (isTypeAny(valueType)) {
	                // Short-circuit if the class tag is using an element type 'any'
	                return anyType;
	            }
	            // Resolve the signatures, preferring constructors
	            var signatures = getSignaturesOfType(valueType, 1 /* Construct */);
	            if (signatures.length === 0) {
	                // No construct signatures, try call signatures
	                signatures = getSignaturesOfType(valueType, 0 /* Call */);
	                if (signatures.length === 0) {
	                    // We found no signatures at all, which is an error
	                    error(node.tagName, ts.Diagnostics.JSX_element_type_0_does_not_have_any_construct_or_call_signatures, ts.getTextOfNode(node.tagName));
	                    return unknownType;
	                }
	            }
	            return getUnionType(signatures.map(getReturnTypeOfSignature));
	        }
	        /// e.g. "props" for React.d.ts,
	        /// or 'undefined' if ElementAttributesPropery doesn't exist (which means all
	        ///     non-intrinsic elements' attributes type is 'any'),
	        /// or '' if it has 0 properties (which means every
	        ///     non-instrinsic elements' attributes type is the element instance type)
	        function getJsxElementPropertiesName() {
	            // JSX
	            var jsxNamespace = getGlobalSymbol(JsxNames.JSX, 1536 /* Namespace */, /*diagnosticMessage*/ undefined);
	            // JSX.ElementAttributesProperty [symbol]
	            var attribsPropTypeSym = jsxNamespace && getSymbol(jsxNamespace.exports, JsxNames.ElementAttributesPropertyNameContainer, 793056 /* Type */);
	            // JSX.ElementAttributesProperty [type]
	            var attribPropType = attribsPropTypeSym && getDeclaredTypeOfSymbol(attribsPropTypeSym);
	            // The properites of JSX.ElementAttributesProperty
	            var attribProperties = attribPropType && getPropertiesOfType(attribPropType);
	            if (attribProperties) {
	                // Element Attributes has zero properties, so the element attributes type will be the class instance type
	                if (attribProperties.length === 0) {
	                    return "";
	                }
	                else if (attribProperties.length === 1) {
	                    return attribProperties[0].name;
	                }
	                else {
	                    error(attribsPropTypeSym.declarations[0], ts.Diagnostics.The_global_type_JSX_0_may_not_have_more_than_one_property, JsxNames.ElementAttributesPropertyNameContainer);
	                    return undefined;
	                }
	            }
	            else {
	                // No interface exists, so the element attributes type will be an implicit any
	                return undefined;
	            }
	        }
	        /**
	         * Given an opening/self-closing element, get the 'element attributes type', i.e. the type that tells
	         * us which attributes are valid on a given element.
	         */
	        function getJsxElementAttributesType(node) {
	            var links = getNodeLinks(node);
	            if (!links.resolvedJsxType) {
	                var sym = getJsxElementTagSymbol(node);
	                if (links.jsxFlags & 4 /* ValueElement */) {
	                    // Get the element instance type (the result of newing or invoking this tag)
	                    var elemInstanceType = getJsxElementInstanceType(node);
	                    var elemClassType = getJsxGlobalElementClassType();
	                    if (!elemClassType || !isTypeAssignableTo(elemInstanceType, elemClassType)) {
	                        // Is this is a stateless function component? See if its single signature's return type is
	                        // assignable to the JSX Element Type
	                        var elemType = getTypeOfSymbol(sym);
	                        var callSignatures = elemType && getSignaturesOfType(elemType, 0 /* Call */);
	                        var callSignature = callSignatures && callSignatures.length > 0 && callSignatures[0];
	                        var callReturnType = callSignature && getReturnTypeOfSignature(callSignature);
	                        var paramType = callReturnType && (callSignature.parameters.length === 0 ? emptyObjectType : getTypeOfSymbol(callSignature.parameters[0]));
	                        if (callReturnType && isTypeAssignableTo(callReturnType, jsxElementType)) {
	                            // Intersect in JSX.IntrinsicAttributes if it exists
	                            var intrinsicAttributes = getJsxType(JsxNames.IntrinsicAttributes);
	                            if (intrinsicAttributes !== unknownType) {
	                                paramType = intersectTypes(intrinsicAttributes, paramType);
	                            }
	                            return links.resolvedJsxType = paramType;
	                        }
	                    }
	                    // Issue an error if this return type isn't assignable to JSX.ElementClass
	                    if (elemClassType) {
	                        checkTypeRelatedTo(elemInstanceType, elemClassType, assignableRelation, node, ts.Diagnostics.JSX_element_type_0_is_not_a_constructor_function_for_JSX_elements);
	                    }
	                    if (isTypeAny(elemInstanceType)) {
	                        return links.resolvedJsxType = elemInstanceType;
	                    }
	                    var propsName = getJsxElementPropertiesName();
	                    if (propsName === undefined) {
	                        // There is no type ElementAttributesProperty, return 'any'
	                        return links.resolvedJsxType = anyType;
	                    }
	                    else if (propsName === "") {
	                        // If there is no e.g. 'props' member in ElementAttributesProperty, use the element class type instead
	                        return links.resolvedJsxType = elemInstanceType;
	                    }
	                    else {
	                        var attributesType = getTypeOfPropertyOfType(elemInstanceType, propsName);
	                        if (!attributesType) {
	                            // There is no property named 'props' on this instance type
	                            return links.resolvedJsxType = emptyObjectType;
	                        }
	                        else if (isTypeAny(attributesType) || (attributesType === unknownType)) {
	                            // Props is of type 'any' or unknown
	                            return links.resolvedJsxType = attributesType;
	                        }
	                        else if (attributesType.flags & 16384 /* Union */) {
	                            // Props cannot be a union type
	                            error(node.tagName, ts.Diagnostics.JSX_element_attributes_type_0_may_not_be_a_union_type, typeToString(attributesType));
	                            return links.resolvedJsxType = anyType;
	                        }
	                        else {
	                            // Normal case -- add in IntrinsicClassElements<T> and IntrinsicElements
	                            var apparentAttributesType = attributesType;
	                            var intrinsicClassAttribs = getJsxType(JsxNames.IntrinsicClassAttributes);
	                            if (intrinsicClassAttribs !== unknownType) {
	                                var typeParams = getLocalTypeParametersOfClassOrInterfaceOrTypeAlias(intrinsicClassAttribs.symbol);
	                                if (typeParams) {
	                                    if (typeParams.length === 1) {
	                                        apparentAttributesType = intersectTypes(createTypeReference(intrinsicClassAttribs, [elemInstanceType]), apparentAttributesType);
	                                    }
	                                }
	                                else {
	                                    apparentAttributesType = intersectTypes(attributesType, intrinsicClassAttribs);
	                                }
	                            }
	                            var intrinsicAttribs = getJsxType(JsxNames.IntrinsicAttributes);
	                            if (intrinsicAttribs !== unknownType) {
	                                apparentAttributesType = intersectTypes(intrinsicAttribs, apparentAttributesType);
	                            }
	                            return links.resolvedJsxType = apparentAttributesType;
	                        }
	                    }
	                }
	                else if (links.jsxFlags & 1 /* IntrinsicNamedElement */) {
	                    return links.resolvedJsxType = getTypeOfSymbol(sym);
	                }
	                else if (links.jsxFlags & 2 /* IntrinsicIndexedElement */) {
	                    return links.resolvedJsxType = getIndexTypeOfSymbol(sym, 0 /* String */);
	                }
	                else {
	                    // Resolution failed, so we don't know
	                    return links.resolvedJsxType = anyType;
	                }
	            }
	            return links.resolvedJsxType;
	        }
	        /**
	         * Given a JSX attribute, returns the symbol for the corresponds property
	         * of the element attributes type. Will return unknownSymbol for attributes
	         * that have no matching element attributes type property.
	         */
	        function getJsxAttributePropertySymbol(attrib) {
	            var attributesType = getJsxElementAttributesType(attrib.parent);
	            var prop = getPropertyOfType(attributesType, attrib.name.text);
	            return prop || unknownSymbol;
	        }
	        function getJsxGlobalElementClassType() {
	            if (!jsxElementClassType) {
	                jsxElementClassType = getExportedTypeFromNamespace(JsxNames.JSX, JsxNames.ElementClass);
	            }
	            return jsxElementClassType;
	        }
	        /// Returns all the properties of the Jsx.IntrinsicElements interface
	        function getJsxIntrinsicTagNames() {
	            var intrinsics = getJsxType(JsxNames.IntrinsicElements);
	            return intrinsics ? getPropertiesOfType(intrinsics) : emptyArray;
	        }
	        function checkJsxPreconditions(errorNode) {
	            // Preconditions for using JSX
	            if ((compilerOptions.jsx || 0 /* None */) === 0 /* None */) {
	                error(errorNode, ts.Diagnostics.Cannot_use_JSX_unless_the_jsx_flag_is_provided);
	            }
	            if (jsxElementType === undefined) {
	                if (compilerOptions.noImplicitAny) {
	                    error(errorNode, ts.Diagnostics.JSX_element_implicitly_has_type_any_because_the_global_type_JSX_Element_does_not_exist);
	                }
	            }
	        }
	        function checkJsxOpeningLikeElement(node) {
	            checkGrammarJsxElement(node);
	            checkJsxPreconditions(node);
	            // The reactNamespace symbol should be marked as 'used' so we don't incorrectly elide its import. And if there
	            // is no reactNamespace symbol in scope when targeting React emit, we should issue an error.
	            var reactRefErr = compilerOptions.jsx === 2 /* React */ ? ts.Diagnostics.Cannot_find_name_0 : undefined;
	            var reactNamespace = compilerOptions.reactNamespace ? compilerOptions.reactNamespace : "React";
	            var reactSym = resolveName(node.tagName, reactNamespace, 107455 /* Value */, reactRefErr, reactNamespace);
	            if (reactSym) {
	                getSymbolLinks(reactSym).referenced = true;
	            }
	            var targetAttributesType = getJsxElementAttributesType(node);
	            var nameTable = {};
	            // Process this array in right-to-left order so we know which
	            // attributes (mostly from spreads) are being overwritten and
	            // thus should have their types ignored
	            var sawSpreadedAny = false;
	            for (var i = node.attributes.length - 1; i >= 0; i--) {
	                if (node.attributes[i].kind === 241 /* JsxAttribute */) {
	                    checkJsxAttribute((node.attributes[i]), targetAttributesType, nameTable);
	                }
	                else {
	                    ts.Debug.assert(node.attributes[i].kind === 242 /* JsxSpreadAttribute */);
	                    var spreadType = checkJsxSpreadAttribute((node.attributes[i]), targetAttributesType, nameTable);
	                    if (isTypeAny(spreadType)) {
	                        sawSpreadedAny = true;
	                    }
	                }
	            }
	            // Check that all required properties have been provided. If an 'any'
	            // was spreaded in, though, assume that it provided all required properties
	            if (targetAttributesType && !sawSpreadedAny) {
	                var targetProperties = getPropertiesOfType(targetAttributesType);
	                for (var i = 0; i < targetProperties.length; i++) {
	                    if (!(targetProperties[i].flags & 536870912 /* Optional */) &&
	                        nameTable[targetProperties[i].name] === undefined) {
	                        error(node, ts.Diagnostics.Property_0_is_missing_in_type_1, targetProperties[i].name, typeToString(targetAttributesType));
	                    }
	                }
	            }
	        }
	        function checkJsxExpression(node) {
	            if (node.expression) {
	                return checkExpression(node.expression);
	            }
	            else {
	                return unknownType;
	            }
	        }
	        // If a symbol is a synthesized symbol with no value declaration, we assume it is a property. Example of this are the synthesized
	        // '.prototype' property as well as synthesized tuple index properties.
	        function getDeclarationKindFromSymbol(s) {
	            return s.valueDeclaration ? s.valueDeclaration.kind : 142 /* PropertyDeclaration */;
	        }
	        function getDeclarationFlagsFromSymbol(s) {
	            return s.valueDeclaration ? ts.getCombinedNodeFlags(s.valueDeclaration) : s.flags & 134217728 /* Prototype */ ? 8 /* Public */ | 64 /* Static */ : 0;
	        }
	        /**
	         * Check whether the requested property access is valid.
	         * Returns true if node is a valid property access, and false otherwise.
	         * @param node The node to be checked.
	         * @param left The left hand side of the property access (e.g.: the super in `super.foo`).
	         * @param type The type of left.
	         * @param prop The symbol for the right hand side of the property access.
	         */
	        function checkClassPropertyAccess(node, left, type, prop) {
	            var flags = getDeclarationFlagsFromSymbol(prop);
	            var declaringClass = getDeclaredTypeOfSymbol(getParentOfSymbol(prop));
	            if (left.kind === 95 /* SuperKeyword */) {
	                var errorNode = node.kind === 169 /* PropertyAccessExpression */ ?
	                    node.name :
	                    node.right;
	                // TS 1.0 spec (April 2014): 4.8.2
	                // - In a constructor, instance member function, instance member accessor, or
	                //   instance member variable initializer where this references a derived class instance,
	                //   a super property access is permitted and must specify a public instance member function of the base class.
	                // - In a static member function or static member accessor
	                //   where this references the constructor function object of a derived class,
	                //   a super property access is permitted and must specify a public static member function of the base class.
	                if (languageVersion < 2 /* ES6 */ && getDeclarationKindFromSymbol(prop) !== 144 /* MethodDeclaration */) {
	                    // `prop` refers to a *property* declared in the super class
	                    // rather than a *method*, so it does not satisfy the above criteria.
	                    error(errorNode, ts.Diagnostics.Only_public_and_protected_methods_of_the_base_class_are_accessible_via_the_super_keyword);
	                    return false;
	                }
	                if (flags & 128 /* Abstract */) {
	                    // A method cannot be accessed in a super property access if the method is abstract.
	                    // This error could mask a private property access error. But, a member
	                    // cannot simultaneously be private and abstract, so this will trigger an
	                    // additional error elsewhere.
	                    error(errorNode, ts.Diagnostics.Abstract_method_0_in_class_1_cannot_be_accessed_via_super_expression, symbolToString(prop), typeToString(declaringClass));
	                    return false;
	                }
	            }
	            // Public properties are otherwise accessible.
	            if (!(flags & (16 /* Private */ | 32 /* Protected */))) {
	                return true;
	            }
	            // Property is known to be private or protected at this point
	            // Get the declaring and enclosing class instance types
	            var enclosingClassDeclaration = ts.getContainingClass(node);
	            var enclosingClass = enclosingClassDeclaration ? getDeclaredTypeOfSymbol(getSymbolOfNode(enclosingClassDeclaration)) : undefined;
	            // Private property is accessible if declaring and enclosing class are the same
	            if (flags & 16 /* Private */) {
	                if (declaringClass !== enclosingClass) {
	                    error(node, ts.Diagnostics.Property_0_is_private_and_only_accessible_within_class_1, symbolToString(prop), typeToString(declaringClass));
	                    return false;
	                }
	                return true;
	            }
	            // Property is known to be protected at this point
	            // All protected properties of a supertype are accessible in a super access
	            if (left.kind === 95 /* SuperKeyword */) {
	                return true;
	            }
	            // A protected property is accessible in the declaring class and classes derived from it
	            if (!enclosingClass || !hasBaseType(enclosingClass, declaringClass)) {
	                error(node, ts.Diagnostics.Property_0_is_protected_and_only_accessible_within_class_1_and_its_subclasses, symbolToString(prop), typeToString(declaringClass));
	                return false;
	            }
	            // No further restrictions for static properties
	            if (flags & 64 /* Static */) {
	                return true;
	            }
	            // An instance property must be accessed through an instance of the enclosing class
	            if (type.flags & 33554432 /* ThisType */) {
	                // get the original type -- represented as the type constraint of the 'this' type
	                type = getConstraintOfTypeParameter(type);
	            }
	            // TODO: why is the first part of this check here?
	            if (!(getTargetType(type).flags & (1024 /* Class */ | 2048 /* Interface */) && hasBaseType(type, enclosingClass))) {
	                error(node, ts.Diagnostics.Property_0_is_protected_and_only_accessible_through_an_instance_of_class_1, symbolToString(prop), typeToString(enclosingClass));
	                return false;
	            }
	            return true;
	        }
	        function checkPropertyAccessExpression(node) {
	            return checkPropertyAccessExpressionOrQualifiedName(node, node.expression, node.name);
	        }
	        function checkQualifiedName(node) {
	            return checkPropertyAccessExpressionOrQualifiedName(node, node.left, node.right);
	        }
	        function checkPropertyAccessExpressionOrQualifiedName(node, left, right) {
	            var type = checkExpression(left);
	            if (isTypeAny(type)) {
	                return type;
	            }
	            var apparentType = getApparentType(getWidenedType(type));
	            if (apparentType === unknownType) {
	                // handle cases when type is Type parameter with invalid constraint
	                return unknownType;
	            }
	            var prop = getPropertyOfType(apparentType, right.text);
	            if (!prop) {
	                if (right.text) {
	                    error(right, ts.Diagnostics.Property_0_does_not_exist_on_type_1, ts.declarationNameToString(right), typeToString(type.flags & 33554432 /* ThisType */ ? apparentType : type));
	                }
	                return unknownType;
	            }
	            getNodeLinks(node).resolvedSymbol = prop;
	            if (prop.parent && prop.parent.flags & 32 /* Class */) {
	                checkClassPropertyAccess(node, left, apparentType, prop);
	            }
	            return getTypeOfSymbol(prop);
	        }
	        function isValidPropertyAccess(node, propertyName) {
	            var left = node.kind === 169 /* PropertyAccessExpression */
	                ? node.expression
	                : node.left;
	            var type = checkExpression(left);
	            if (type !== unknownType && !isTypeAny(type)) {
	                var prop = getPropertyOfType(getWidenedType(type), propertyName);
	                if (prop && prop.parent && prop.parent.flags & 32 /* Class */) {
	                    return checkClassPropertyAccess(node, left, type, prop);
	                }
	            }
	            return true;
	        }
	        /**
	         * Return the symbol of the for-in variable declared or referenced by the given for-in statement.
	         */
	        function getForInVariableSymbol(node) {
	            var initializer = node.initializer;
	            if (initializer.kind === 215 /* VariableDeclarationList */) {
	                var variable = initializer.declarations[0];
	                if (variable && !ts.isBindingPattern(variable.name)) {
	                    return getSymbolOfNode(variable);
	                }
	            }
	            else if (initializer.kind === 69 /* Identifier */) {
	                return getResolvedSymbol(initializer);
	            }
	            return undefined;
	        }
	        /**
	         * Return true if the given type is considered to have numeric property names.
	         */
	        function hasNumericPropertyNames(type) {
	            return getIndexTypeOfType(type, 1 /* Number */) && !getIndexTypeOfType(type, 0 /* String */);
	        }
	        /**
	         * Return true if given node is an expression consisting of an identifier (possibly parenthesized)
	         * that references a for-in variable for an object with numeric property names.
	         */
	        function isForInVariableForNumericPropertyNames(expr) {
	            var e = skipParenthesizedNodes(expr);
	            if (e.kind === 69 /* Identifier */) {
	                var symbol = getResolvedSymbol(e);
	                if (symbol.flags & 3 /* Variable */) {
	                    var child = expr;
	                    var node = expr.parent;
	                    while (node) {
	                        if (node.kind === 203 /* ForInStatement */ &&
	                            child === node.statement &&
	                            getForInVariableSymbol(node) === symbol &&
	                            hasNumericPropertyNames(checkExpression(node.expression))) {
	                            return true;
	                        }
	                        child = node;
	                        node = node.parent;
	                    }
	                }
	            }
	            return false;
	        }
	        function checkIndexedAccess(node) {
	            // Grammar checking
	            if (!node.argumentExpression) {
	                var sourceFile = ts.getSourceFileOfNode(node);
	                if (node.parent.kind === 172 /* NewExpression */ && node.parent.expression === node) {
	                    var start = ts.skipTrivia(sourceFile.text, node.expression.end);
	                    var end = node.end;
	                    grammarErrorAtPos(sourceFile, start, end - start, ts.Diagnostics.new_T_cannot_be_used_to_create_an_array_Use_new_Array_T_instead);
	                }
	                else {
	                    var start = node.end - "]".length;
	                    var end = node.end;
	                    grammarErrorAtPos(sourceFile, start, end - start, ts.Diagnostics.Expression_expected);
	                }
	            }
	            // Obtain base constraint such that we can bail out if the constraint is an unknown type
	            var objectType = getApparentType(checkExpression(node.expression));
	            var indexType = node.argumentExpression ? checkExpression(node.argumentExpression) : unknownType;
	            if (objectType === unknownType) {
	                return unknownType;
	            }
	            var isConstEnum = isConstEnumObjectType(objectType);
	            if (isConstEnum &&
	                (!node.argumentExpression || node.argumentExpression.kind !== 9 /* StringLiteral */)) {
	                error(node.argumentExpression, ts.Diagnostics.A_const_enum_member_can_only_be_accessed_using_a_string_literal);
	                return unknownType;
	            }
	            // TypeScript 1.0 spec (April 2014): 4.10 Property Access
	            // - If IndexExpr is a string literal or a numeric literal and ObjExpr's apparent type has a property with the name
	            //    given by that literal(converted to its string representation in the case of a numeric literal), the property access is of the type of that property.
	            // - Otherwise, if ObjExpr's apparent type has a numeric index signature and IndexExpr is of type Any, the Number primitive type, or an enum type,
	            //    the property access is of the type of that index signature.
	            // - Otherwise, if ObjExpr's apparent type has a string index signature and IndexExpr is of type Any, the String or Number primitive type, or an enum type,
	            //    the property access is of the type of that index signature.
	            // - Otherwise, if IndexExpr is of type Any, the String or Number primitive type, or an enum type, the property access is of type Any.
	            // See if we can index as a property.
	            if (node.argumentExpression) {
	                var name_11 = getPropertyNameForIndexedAccess(node.argumentExpression, indexType);
	                if (name_11 !== undefined) {
	                    var prop = getPropertyOfType(objectType, name_11);
	                    if (prop) {
	                        getNodeLinks(node).resolvedSymbol = prop;
	                        return getTypeOfSymbol(prop);
	                    }
	                    else if (isConstEnum) {
	                        error(node.argumentExpression, ts.Diagnostics.Property_0_does_not_exist_on_const_enum_1, name_11, symbolToString(objectType.symbol));
	                        return unknownType;
	                    }
	                }
	            }
	            // Check for compatible indexer types.
	            if (isTypeAnyOrAllConstituentTypesHaveKind(indexType, 258 /* StringLike */ | 132 /* NumberLike */ | 16777216 /* ESSymbol */)) {
	                // Try to use a number indexer.
	                if (isTypeAnyOrAllConstituentTypesHaveKind(indexType, 132 /* NumberLike */) || isForInVariableForNumericPropertyNames(node.argumentExpression)) {
	                    var numberIndexType = getIndexTypeOfType(objectType, 1 /* Number */);
	                    if (numberIndexType) {
	                        return numberIndexType;
	                    }
	                }
	                // Try to use string indexing.
	                var stringIndexType = getIndexTypeOfType(objectType, 0 /* String */);
	                if (stringIndexType) {
	                    return stringIndexType;
	                }
	                // Fall back to any.
	                if (compilerOptions.noImplicitAny && !compilerOptions.suppressImplicitAnyIndexErrors && !isTypeAny(objectType)) {
	                    error(node, getIndexTypeOfType(objectType, 1 /* Number */) ?
	                        ts.Diagnostics.Element_implicitly_has_an_any_type_because_index_expression_is_not_of_type_number :
	                        ts.Diagnostics.Index_signature_of_object_type_implicitly_has_an_any_type);
	                }
	                return anyType;
	            }
	            // REVIEW: Users should know the type that was actually used.
	            error(node, ts.Diagnostics.An_index_expression_argument_must_be_of_type_string_number_symbol_or_any);
	            return unknownType;
	        }
	        /**
	         * If indexArgumentExpression is a string literal or number literal, returns its text.
	         * If indexArgumentExpression is a constant value, returns its string value.
	         * If indexArgumentExpression is a well known symbol, returns the property name corresponding
	         *    to this symbol, as long as it is a proper symbol reference.
	         * Otherwise, returns undefined.
	         */
	        function getPropertyNameForIndexedAccess(indexArgumentExpression, indexArgumentType) {
	            if (indexArgumentExpression.kind === 9 /* StringLiteral */ || indexArgumentExpression.kind === 8 /* NumericLiteral */) {
	                return indexArgumentExpression.text;
	            }
	            if (indexArgumentExpression.kind === 170 /* ElementAccessExpression */ || indexArgumentExpression.kind === 169 /* PropertyAccessExpression */) {
	                var value = getConstantValue(indexArgumentExpression);
	                if (value !== undefined) {
	                    return value.toString();
	                }
	            }
	            if (checkThatExpressionIsProperSymbolReference(indexArgumentExpression, indexArgumentType, /*reportError*/ false)) {
	                var rightHandSideName = indexArgumentExpression.name.text;
	                return ts.getPropertyNameForKnownSymbolName(rightHandSideName);
	            }
	            return undefined;
	        }
	        /**
	         * A proper symbol reference requires the following:
	         *   1. The property access denotes a property that exists
	         *   2. The expression is of the form Symbol.<identifier>
	         *   3. The property access is of the primitive type symbol.
	         *   4. Symbol in this context resolves to the global Symbol object
	         */
	        function checkThatExpressionIsProperSymbolReference(expression, expressionType, reportError) {
	            if (expressionType === unknownType) {
	                // There is already an error, so no need to report one.
	                return false;
	            }
	            if (!ts.isWellKnownSymbolSyntactically(expression)) {
	                return false;
	            }
	            // Make sure the property type is the primitive symbol type
	            if ((expressionType.flags & 16777216 /* ESSymbol */) === 0) {
	                if (reportError) {
	                    error(expression, ts.Diagnostics.A_computed_property_name_of_the_form_0_must_be_of_type_symbol, ts.getTextOfNode(expression));
	                }
	                return false;
	            }
	            // The name is Symbol.<someName>, so make sure Symbol actually resolves to the
	            // global Symbol object
	            var leftHandSide = expression.expression;
	            var leftHandSideSymbol = getResolvedSymbol(leftHandSide);
	            if (!leftHandSideSymbol) {
	                return false;
	            }
	            var globalESSymbol = getGlobalESSymbolConstructorSymbol();
	            if (!globalESSymbol) {
	                // Already errored when we tried to look up the symbol
	                return false;
	            }
	            if (leftHandSideSymbol !== globalESSymbol) {
	                if (reportError) {
	                    error(leftHandSide, ts.Diagnostics.Symbol_reference_does_not_refer_to_the_global_Symbol_constructor_object);
	                }
	                return false;
	            }
	            return true;
	        }
	        function resolveUntypedCall(node) {
	            if (node.kind === 173 /* TaggedTemplateExpression */) {
	                checkExpression(node.template);
	            }
	            else if (node.kind !== 140 /* Decorator */) {
	                ts.forEach(node.arguments, function (argument) {
	                    checkExpression(argument);
	                });
	            }
	            return anySignature;
	        }
	        function resolveErrorCall(node) {
	            resolveUntypedCall(node);
	            return unknownSignature;
	        }
	        // Re-order candidate signatures into the result array. Assumes the result array to be empty.
	        // The candidate list orders groups in reverse, but within a group signatures are kept in declaration order
	        // A nit here is that we reorder only signatures that belong to the same symbol,
	        // so order how inherited signatures are processed is still preserved.
	        // interface A { (x: string): void }
	        // interface B extends A { (x: 'foo'): string }
	        // const b: B;
	        // b('foo') // <- here overloads should be processed as [(x:'foo'): string, (x: string): void]
	        function reorderCandidates(signatures, result) {
	            var lastParent;
	            var lastSymbol;
	            var cutoffIndex = 0;
	            var index;
	            var specializedIndex = -1;
	            var spliceIndex;
	            ts.Debug.assert(!result.length);
	            for (var _i = 0, signatures_2 = signatures; _i < signatures_2.length; _i++) {
	                var signature = signatures_2[_i];
	                var symbol = signature.declaration && getSymbolOfNode(signature.declaration);
	                var parent_6 = signature.declaration && signature.declaration.parent;
	                if (!lastSymbol || symbol === lastSymbol) {
	                    if (lastParent && parent_6 === lastParent) {
	                        index++;
	                    }
	                    else {
	                        lastParent = parent_6;
	                        index = cutoffIndex;
	                    }
	                }
	                else {
	                    // current declaration belongs to a different symbol
	                    // set cutoffIndex so re-orderings in the future won't change result set from 0 to cutoffIndex
	                    index = cutoffIndex = result.length;
	                    lastParent = parent_6;
	                }
	                lastSymbol = symbol;
	                // specialized signatures always need to be placed before non-specialized signatures regardless
	                // of the cutoff position; see GH#1133
	                if (signature.hasStringLiterals) {
	                    specializedIndex++;
	                    spliceIndex = specializedIndex;
	                    // The cutoff index always needs to be greater than or equal to the specialized signature index
	                    // in order to prevent non-specialized signatures from being added before a specialized
	                    // signature.
	                    cutoffIndex++;
	                }
	                else {
	                    spliceIndex = index;
	                }
	                result.splice(spliceIndex, 0, signature);
	            }
	        }
	        function getSpreadArgumentIndex(args) {
	            for (var i = 0; i < args.length; i++) {
	                var arg = args[i];
	                if (arg && arg.kind === 188 /* SpreadElementExpression */) {
	                    return i;
	                }
	            }
	            return -1;
	        }
	        function hasCorrectArity(node, args, signature) {
	            var adjustedArgCount; // Apparent number of arguments we will have in this call
	            var typeArguments; // Type arguments (undefined if none)
	            var callIsIncomplete; // In incomplete call we want to be lenient when we have too few arguments
	            var isDecorator;
	            var spreadArgIndex = -1;
	            if (node.kind === 173 /* TaggedTemplateExpression */) {
	                var tagExpression = node;
	                // Even if the call is incomplete, we'll have a missing expression as our last argument,
	                // so we can say the count is just the arg list length
	                adjustedArgCount = args.length;
	                typeArguments = undefined;
	                if (tagExpression.template.kind === 186 /* TemplateExpression */) {
	                    // If a tagged template expression lacks a tail literal, the call is incomplete.
	                    // Specifically, a template only can end in a TemplateTail or a Missing literal.
	                    var templateExpression = tagExpression.template;
	                    var lastSpan = ts.lastOrUndefined(templateExpression.templateSpans);
	                    ts.Debug.assert(lastSpan !== undefined); // we should always have at least one span.
	                    callIsIncomplete = ts.nodeIsMissing(lastSpan.literal) || !!lastSpan.literal.isUnterminated;
	                }
	                else {
	                    // If the template didn't end in a backtick, or its beginning occurred right prior to EOF,
	                    // then this might actually turn out to be a TemplateHead in the future;
	                    // so we consider the call to be incomplete.
	                    var templateLiteral = tagExpression.template;
	                    ts.Debug.assert(templateLiteral.kind === 11 /* NoSubstitutionTemplateLiteral */);
	                    callIsIncomplete = !!templateLiteral.isUnterminated;
	                }
	            }
	            else if (node.kind === 140 /* Decorator */) {
	                isDecorator = true;
	                typeArguments = undefined;
	                adjustedArgCount = getEffectiveArgumentCount(node, /*args*/ undefined, signature);
	            }
	            else {
	                var callExpression = node;
	                if (!callExpression.arguments) {
	                    // This only happens when we have something of the form: 'new C'
	                    ts.Debug.assert(callExpression.kind === 172 /* NewExpression */);
	                    return signature.minArgumentCount === 0;
	                }
	                // For IDE scenarios we may have an incomplete call, so a trailing comma is tantamount to adding another argument.
	                adjustedArgCount = callExpression.arguments.hasTrailingComma ? args.length + 1 : args.length;
	                // If we are missing the close paren, the call is incomplete.
	                callIsIncomplete = callExpression.arguments.end === callExpression.end;
	                typeArguments = callExpression.typeArguments;
	                spreadArgIndex = getSpreadArgumentIndex(args);
	            }
	            // If the user supplied type arguments, but the number of type arguments does not match
	            // the declared number of type parameters, the call has an incorrect arity.
	            var hasRightNumberOfTypeArgs = !typeArguments ||
	                (signature.typeParameters && typeArguments.length === signature.typeParameters.length);
	            if (!hasRightNumberOfTypeArgs) {
	                return false;
	            }
	            // If spread arguments are present, check that they correspond to a rest parameter. If so, no
	            // further checking is necessary.
	            if (spreadArgIndex >= 0) {
	                return isRestParameterIndex(signature, spreadArgIndex);
	            }
	            // Too many arguments implies incorrect arity.
	            if (!signature.hasRestParameter && adjustedArgCount > signature.parameters.length) {
	                return false;
	            }
	            // If the call is incomplete, we should skip the lower bound check.
	            var hasEnoughArguments = adjustedArgCount >= signature.minArgumentCount;
	            return callIsIncomplete || hasEnoughArguments;
	        }
	        // If type has a single call signature and no other members, return that signature. Otherwise, return undefined.
	        function getSingleCallSignature(type) {
	            if (type.flags & 80896 /* ObjectType */) {
	                var resolved = resolveStructuredTypeMembers(type);
	                if (resolved.callSignatures.length === 1 && resolved.constructSignatures.length === 0 &&
	                    resolved.properties.length === 0 && !resolved.stringIndexType && !resolved.numberIndexType) {
	                    return resolved.callSignatures[0];
	                }
	            }
	            return undefined;
	        }
	        // Instantiate a generic signature in the context of a non-generic signature (section 3.8.5 in TypeScript spec)
	        function instantiateSignatureInContextOf(signature, contextualSignature, contextualMapper) {
	            var context = createInferenceContext(signature.typeParameters, /*inferUnionTypes*/ true);
	            forEachMatchingParameterType(contextualSignature, signature, function (source, target) {
	                // Type parameters from outer context referenced by source type are fixed by instantiation of the source type
	                inferTypes(context, instantiateType(source, contextualMapper), target);
	            });
	            return getSignatureInstantiation(signature, getInferredTypes(context));
	        }
	        function inferTypeArguments(node, signature, args, excludeArgument, context) {
	            var typeParameters = signature.typeParameters;
	            var inferenceMapper = getInferenceMapper(context);
	            // Clear out all the inference results from the last time inferTypeArguments was called on this context
	            for (var i = 0; i < typeParameters.length; i++) {
	                // As an optimization, we don't have to clear (and later recompute) inferred types
	                // for type parameters that have already been fixed on the previous call to inferTypeArguments.
	                // It would be just as correct to reset all of them. But then we'd be repeating the same work
	                // for the type parameters that were fixed, namely the work done by getInferredType.
	                if (!context.inferences[i].isFixed) {
	                    context.inferredTypes[i] = undefined;
	                }
	            }
	            // On this call to inferTypeArguments, we may get more inferences for certain type parameters that were not
	            // fixed last time. This means that a type parameter that failed inference last time may succeed this time,
	            // or vice versa. Therefore, the failedTypeParameterIndex is useless if it points to an unfixed type parameter,
	            // because it may change. So here we reset it. However, getInferredType will not revisit any type parameters
	            // that were previously fixed. So if a fixed type parameter failed previously, it will fail again because
	            // it will contain the exact same set of inferences. So if we reset the index from a fixed type parameter,
	            // we will lose information that we won't recover this time around.
	            if (context.failedTypeParameterIndex !== undefined && !context.inferences[context.failedTypeParameterIndex].isFixed) {
	                context.failedTypeParameterIndex = undefined;
	            }
	            // We perform two passes over the arguments. In the first pass we infer from all arguments, but use
	            // wildcards for all context sensitive function expressions.
	            var argCount = getEffectiveArgumentCount(node, args, signature);
	            for (var i = 0; i < argCount; i++) {
	                var arg = getEffectiveArgument(node, args, i);
	                // If the effective argument is 'undefined', then it is an argument that is present but is synthetic.
	                if (arg === undefined || arg.kind !== 190 /* OmittedExpression */) {
	                    var paramType = getTypeAtPosition(signature, i);
	                    var argType = getEffectiveArgumentType(node, i, arg);
	                    // If the effective argument type is 'undefined', there is no synthetic type
	                    // for the argument. In that case, we should check the argument.
	                    if (argType === undefined) {
	                        // For context sensitive arguments we pass the identityMapper, which is a signal to treat all
	                        // context sensitive function expressions as wildcards
	                        var mapper = excludeArgument && excludeArgument[i] !== undefined ? identityMapper : inferenceMapper;
	                        argType = checkExpressionWithContextualType(arg, paramType, mapper);
	                    }
	                    inferTypes(context, argType, paramType);
	                }
	            }
	            // In the second pass we visit only context sensitive arguments, and only those that aren't excluded, this
	            // time treating function expressions normally (which may cause previously inferred type arguments to be fixed
	            // as we construct types for contextually typed parameters)
	            // Decorators will not have `excludeArgument`, as their arguments cannot be contextually typed.
	            // Tagged template expressions will always have `undefined` for `excludeArgument[0]`.
	            if (excludeArgument) {
	                for (var i = 0; i < argCount; i++) {
	                    // No need to check for omitted args and template expressions, their exlusion value is always undefined
	                    if (excludeArgument[i] === false) {
	                        var arg = args[i];
	                        var paramType = getTypeAtPosition(signature, i);
	                        inferTypes(context, checkExpressionWithContextualType(arg, paramType, inferenceMapper), paramType);
	                    }
	                }
	            }
	            getInferredTypes(context);
	        }
	        function checkTypeArguments(signature, typeArgumentNodes, typeArgumentTypes, reportErrors, headMessage) {
	            var typeParameters = signature.typeParameters;
	            var typeArgumentsAreAssignable = true;
	            var mapper;
	            for (var i = 0; i < typeParameters.length; i++) {
	                if (typeArgumentsAreAssignable /* so far */) {
	                    var constraint = getConstraintOfTypeParameter(typeParameters[i]);
	                    if (constraint) {
	                        var errorInfo = void 0;
	                        var typeArgumentHeadMessage = ts.Diagnostics.Type_0_does_not_satisfy_the_constraint_1;
	                        if (reportErrors && headMessage) {
	                            errorInfo = ts.chainDiagnosticMessages(errorInfo, typeArgumentHeadMessage);
	                            typeArgumentHeadMessage = headMessage;
	                        }
	                        if (!mapper) {
	                            mapper = createTypeMapper(typeParameters, typeArgumentTypes);
	                        }
	                        var typeArgument = typeArgumentTypes[i];
	                        typeArgumentsAreAssignable = checkTypeAssignableTo(typeArgument, getTypeWithThisArgument(instantiateType(constraint, mapper), typeArgument), reportErrors ? typeArgumentNodes[i] : undefined, typeArgumentHeadMessage, errorInfo);
	                    }
	                }
	            }
	            return typeArgumentsAreAssignable;
	        }
	        function checkApplicableSignature(node, args, signature, relation, excludeArgument, reportErrors) {
	            var argCount = getEffectiveArgumentCount(node, args, signature);
	            for (var i = 0; i < argCount; i++) {
	                var arg = getEffectiveArgument(node, args, i);
	                // If the effective argument is 'undefined', then it is an argument that is present but is synthetic.
	                if (arg === undefined || arg.kind !== 190 /* OmittedExpression */) {
	                    // Check spread elements against rest type (from arity check we know spread argument corresponds to a rest parameter)
	                    var paramType = getTypeAtPosition(signature, i);
	                    var argType = getEffectiveArgumentType(node, i, arg);
	                    // If the effective argument type is 'undefined', there is no synthetic type
	                    // for the argument. In that case, we should check the argument.
	                    if (argType === undefined) {
	                        argType = arg.kind === 9 /* StringLiteral */ && !reportErrors
	                            ? getStringLiteralTypeForText(arg.text)
	                            : checkExpressionWithContextualType(arg, paramType, excludeArgument && excludeArgument[i] ? identityMapper : undefined);
	                    }
	                    // Use argument expression as error location when reporting errors
	                    var errorNode = reportErrors ? getEffectiveArgumentErrorNode(node, i, arg) : undefined;
	                    var headMessage = ts.Diagnostics.Argument_of_type_0_is_not_assignable_to_parameter_of_type_1;
	                    if (!checkTypeRelatedTo(argType, paramType, relation, errorNode, headMessage)) {
	                        return false;
	                    }
	                }
	            }
	            return true;
	        }
	        /**
	         * Returns the effective arguments for an expression that works like a function invocation.
	         *
	         * If 'node' is a CallExpression or a NewExpression, then its argument list is returned.
	         * If 'node' is a TaggedTemplateExpression, a new argument list is constructed from the substitution
	         *    expressions, where the first element of the list is `undefined`.
	         * If 'node' is a Decorator, the argument list will be `undefined`, and its arguments and types
	         *    will be supplied from calls to `getEffectiveArgumentCount` and `getEffectiveArgumentType`.
	         */
	        function getEffectiveCallArguments(node) {
	            var args;
	            if (node.kind === 173 /* TaggedTemplateExpression */) {
	                var template = node.template;
	                args = [undefined];
	                if (template.kind === 186 /* TemplateExpression */) {
	                    ts.forEach(template.templateSpans, function (span) {
	                        args.push(span.expression);
	                    });
	                }
	            }
	            else if (node.kind === 140 /* Decorator */) {
	                // For a decorator, we return undefined as we will determine
	                // the number and types of arguments for a decorator using
	                // `getEffectiveArgumentCount` and `getEffectiveArgumentType` below.
	                return undefined;
	            }
	            else {
	                args = node.arguments || emptyArray;
	            }
	            return args;
	        }
	        /**
	          * Returns the effective argument count for a node that works like a function invocation.
	          * If 'node' is a Decorator, the number of arguments is derived from the decoration
	          *    target and the signature:
	          *    If 'node.target' is a class declaration or class expression, the effective argument
	          *       count is 1.
	          *    If 'node.target' is a parameter declaration, the effective argument count is 3.
	          *    If 'node.target' is a property declaration, the effective argument count is 2.
	          *    If 'node.target' is a method or accessor declaration, the effective argument count
	          *       is 3, although it can be 2 if the signature only accepts two arguments, allowing
	          *       us to match a property decorator.
	          * Otherwise, the argument count is the length of the 'args' array.
	          */
	        function getEffectiveArgumentCount(node, args, signature) {
	            if (node.kind === 140 /* Decorator */) {
	                switch (node.parent.kind) {
	                    case 217 /* ClassDeclaration */:
	                    case 189 /* ClassExpression */:
	                        // A class decorator will have one argument (see `ClassDecorator` in core.d.ts)
	                        return 1;
	                    case 142 /* PropertyDeclaration */:
	                        // A property declaration decorator will have two arguments (see
	                        // `PropertyDecorator` in core.d.ts)
	                        return 2;
	                    case 144 /* MethodDeclaration */:
	                    case 146 /* GetAccessor */:
	                    case 147 /* SetAccessor */:
	                        // A method or accessor declaration decorator will have two or three arguments (see
	                        // `PropertyDecorator` and `MethodDecorator` in core.d.ts)
	                        // If we are emitting decorators for ES3, we will only pass two arguments.
	                        if (languageVersion === 0 /* ES3 */) {
	                            return 2;
	                        }
	                        // If the method decorator signature only accepts a target and a key, we will only
	                        // type check those arguments.
	                        return signature.parameters.length >= 3 ? 3 : 2;
	                    case 139 /* Parameter */:
	                        // A parameter declaration decorator will have three arguments (see
	                        // `ParameterDecorator` in core.d.ts)
	                        return 3;
	                }
	            }
	            else {
	                return args.length;
	            }
	        }
	        /**
	          * Returns the effective type of the first argument to a decorator.
	          * If 'node' is a class declaration or class expression, the effective argument type
	          *    is the type of the static side of the class.
	          * If 'node' is a parameter declaration, the effective argument type is either the type
	          *    of the static or instance side of the class for the parameter's parent method,
	          *    depending on whether the method is declared static.
	          *    For a constructor, the type is always the type of the static side of the class.
	          * If 'node' is a property, method, or accessor declaration, the effective argument
	          *    type is the type of the static or instance side of the parent class for class
	          *    element, depending on whether the element is declared static.
	          */
	        function getEffectiveDecoratorFirstArgumentType(node) {
	            // The first argument to a decorator is its `target`.
	            if (node.kind === 217 /* ClassDeclaration */) {
	                // For a class decorator, the `target` is the type of the class (e.g. the
	                // "static" or "constructor" side of the class)
	                var classSymbol = getSymbolOfNode(node);
	                return getTypeOfSymbol(classSymbol);
	            }
	            if (node.kind === 139 /* Parameter */) {
	                // For a parameter decorator, the `target` is the parent type of the
	                // parameter's containing method.
	                node = node.parent;
	                if (node.kind === 145 /* Constructor */) {
	                    var classSymbol = getSymbolOfNode(node);
	                    return getTypeOfSymbol(classSymbol);
	                }
	            }
	            if (node.kind === 142 /* PropertyDeclaration */ ||
	                node.kind === 144 /* MethodDeclaration */ ||
	                node.kind === 146 /* GetAccessor */ ||
	                node.kind === 147 /* SetAccessor */) {
	                // For a property or method decorator, the `target` is the
	                // "static"-side type of the parent of the member if the member is
	                // declared "static"; otherwise, it is the "instance"-side type of the
	                // parent of the member.
	                return getParentTypeOfClassElement(node);
	            }
	            ts.Debug.fail("Unsupported decorator target.");
	            return unknownType;
	        }
	        /**
	          * Returns the effective type for the second argument to a decorator.
	          * If 'node' is a parameter, its effective argument type is one of the following:
	          *    If 'node.parent' is a constructor, the effective argument type is 'any', as we
	          *       will emit `undefined`.
	          *    If 'node.parent' is a member with an identifier, numeric, or string literal name,
	          *       the effective argument type will be a string literal type for the member name.
	          *    If 'node.parent' is a computed property name, the effective argument type will
	          *       either be a symbol type or the string type.
	          * If 'node' is a member with an identifier, numeric, or string literal name, the
	          *    effective argument type will be a string literal type for the member name.
	          * If 'node' is a computed property name, the effective argument type will either
	          *    be a symbol type or the string type.
	          * A class decorator does not have a second argument type.
	          */
	        function getEffectiveDecoratorSecondArgumentType(node) {
	            // The second argument to a decorator is its `propertyKey`
	            if (node.kind === 217 /* ClassDeclaration */) {
	                ts.Debug.fail("Class decorators should not have a second synthetic argument.");
	                return unknownType;
	            }
	            if (node.kind === 139 /* Parameter */) {
	                node = node.parent;
	                if (node.kind === 145 /* Constructor */) {
	                    // For a constructor parameter decorator, the `propertyKey` will be `undefined`.
	                    return anyType;
	                }
	            }
	            if (node.kind === 142 /* PropertyDeclaration */ ||
	                node.kind === 144 /* MethodDeclaration */ ||
	                node.kind === 146 /* GetAccessor */ ||
	                node.kind === 147 /* SetAccessor */) {
	                // The `propertyKey` for a property or method decorator will be a
	                // string literal type if the member name is an identifier, number, or string;
	                // otherwise, if the member name is a computed property name it will
	                // be either string or symbol.
	                var element = node;
	                switch (element.name.kind) {
	                    case 69 /* Identifier */:
	                    case 8 /* NumericLiteral */:
	                    case 9 /* StringLiteral */:
	                        return getStringLiteralTypeForText(element.name.text);
	                    case 137 /* ComputedPropertyName */:
	                        var nameType = checkComputedPropertyName(element.name);
	                        if (allConstituentTypesHaveKind(nameType, 16777216 /* ESSymbol */)) {
	                            return nameType;
	                        }
	                        else {
	                            return stringType;
	                        }
	                    default:
	                        ts.Debug.fail("Unsupported property name.");
	                        return unknownType;
	                }
	            }
	            ts.Debug.fail("Unsupported decorator target.");
	            return unknownType;
	        }
	        /**
	          * Returns the effective argument type for the third argument to a decorator.
	          * If 'node' is a parameter, the effective argument type is the number type.
	          * If 'node' is a method or accessor, the effective argument type is a
	          *    `TypedPropertyDescriptor<T>` instantiated with the type of the member.
	          * Class and property decorators do not have a third effective argument.
	          */
	        function getEffectiveDecoratorThirdArgumentType(node) {
	            // The third argument to a decorator is either its `descriptor` for a method decorator
	            // or its `parameterIndex` for a paramter decorator
	            if (node.kind === 217 /* ClassDeclaration */) {
	                ts.Debug.fail("Class decorators should not have a third synthetic argument.");
	                return unknownType;
	            }
	            if (node.kind === 139 /* Parameter */) {
	                // The `parameterIndex` for a parameter decorator is always a number
	                return numberType;
	            }
	            if (node.kind === 142 /* PropertyDeclaration */) {
	                ts.Debug.fail("Property decorators should not have a third synthetic argument.");
	                return unknownType;
	            }
	            if (node.kind === 144 /* MethodDeclaration */ ||
	                node.kind === 146 /* GetAccessor */ ||
	                node.kind === 147 /* SetAccessor */) {
	                // The `descriptor` for a method decorator will be a `TypedPropertyDescriptor<T>`
	                // for the type of the member.
	                var propertyType = getTypeOfNode(node);
	                return createTypedPropertyDescriptorType(propertyType);
	            }
	            ts.Debug.fail("Unsupported decorator target.");
	            return unknownType;
	        }
	        /**
	          * Returns the effective argument type for the provided argument to a decorator.
	          */
	        function getEffectiveDecoratorArgumentType(node, argIndex) {
	            if (argIndex === 0) {
	                return getEffectiveDecoratorFirstArgumentType(node.parent);
	            }
	            else if (argIndex === 1) {
	                return getEffectiveDecoratorSecondArgumentType(node.parent);
	            }
	            else if (argIndex === 2) {
	                return getEffectiveDecoratorThirdArgumentType(node.parent);
	            }
	            ts.Debug.fail("Decorators should not have a fourth synthetic argument.");
	            return unknownType;
	        }
	        /**
	          * Gets the effective argument type for an argument in a call expression.
	          */
	        function getEffectiveArgumentType(node, argIndex, arg) {
	            // Decorators provide special arguments, a tagged template expression provides
	            // a special first argument, and string literals get string literal types
	            // unless we're reporting errors
	            if (node.kind === 140 /* Decorator */) {
	                return getEffectiveDecoratorArgumentType(node, argIndex);
	            }
	            else if (argIndex === 0 && node.kind === 173 /* TaggedTemplateExpression */) {
	                return globalTemplateStringsArrayType;
	            }
	            // This is not a synthetic argument, so we return 'undefined'
	            // to signal that the caller needs to check the argument.
	            return undefined;
	        }
	        /**
	          * Gets the effective argument expression for an argument in a call expression.
	          */
	        function getEffectiveArgument(node, args, argIndex) {
	            // For a decorator or the first argument of a tagged template expression we return undefined.
	            if (node.kind === 140 /* Decorator */ ||
	                (argIndex === 0 && node.kind === 173 /* TaggedTemplateExpression */)) {
	                return undefined;
	            }
	            return args[argIndex];
	        }
	        /**
	          * Gets the error node to use when reporting errors for an effective argument.
	          */
	        function getEffectiveArgumentErrorNode(node, argIndex, arg) {
	            if (node.kind === 140 /* Decorator */) {
	                // For a decorator, we use the expression of the decorator for error reporting.
	                return node.expression;
	            }
	            else if (argIndex === 0 && node.kind === 173 /* TaggedTemplateExpression */) {
	                // For a the first argument of a tagged template expression, we use the template of the tag for error reporting.
	                return node.template;
	            }
	            else {
	                return arg;
	            }
	        }
	        function resolveCall(node, signatures, candidatesOutArray, headMessage) {
	            var isTaggedTemplate = node.kind === 173 /* TaggedTemplateExpression */;
	            var isDecorator = node.kind === 140 /* Decorator */;
	            var typeArguments;
	            if (!isTaggedTemplate && !isDecorator) {
	                typeArguments = node.typeArguments;
	                // We already perform checking on the type arguments on the class declaration itself.
	                if (node.expression.kind !== 95 /* SuperKeyword */) {
	                    ts.forEach(typeArguments, checkSourceElement);
	                }
	            }
	            var candidates = candidatesOutArray || [];
	            // reorderCandidates fills up the candidates array directly
	            reorderCandidates(signatures, candidates);
	            if (!candidates.length) {
	                reportError(ts.Diagnostics.Supplied_parameters_do_not_match_any_signature_of_call_target);
	                return resolveErrorCall(node);
	            }
	            var args = getEffectiveCallArguments(node);
	            // The following applies to any value of 'excludeArgument[i]':
	            //    - true:      the argument at 'i' is susceptible to a one-time permanent contextual typing.
	            //    - undefined: the argument at 'i' is *not* susceptible to permanent contextual typing.
	            //    - false:     the argument at 'i' *was* and *has been* permanently contextually typed.
	            //
	            // The idea is that we will perform type argument inference & assignability checking once
	            // without using the susceptible parameters that are functions, and once more for each of those
	            // parameters, contextually typing each as we go along.
	            //
	            // For a tagged template, then the first argument be 'undefined' if necessary
	            // because it represents a TemplateStringsArray.
	            //
	            // For a decorator, no arguments are susceptible to contextual typing due to the fact
	            // decorators are applied to a declaration by the emitter, and not to an expression.
	            var excludeArgument;
	            if (!isDecorator) {
	                // We do not need to call `getEffectiveArgumentCount` here as it only
	                // applies when calculating the number of arguments for a decorator.
	                for (var i = isTaggedTemplate ? 1 : 0; i < args.length; i++) {
	                    if (isContextSensitive(args[i])) {
	                        if (!excludeArgument) {
	                            excludeArgument = new Array(args.length);
	                        }
	                        excludeArgument[i] = true;
	                    }
	                }
	            }
	            // The following variables are captured and modified by calls to chooseOverload.
	            // If overload resolution or type argument inference fails, we want to report the
	            // best error possible. The best error is one which says that an argument was not
	            // assignable to a parameter. This implies that everything else about the overload
	            // was fine. So if there is any overload that is only incorrect because of an
	            // argument, we will report an error on that one.
	            //
	            //     function foo(s: string) {}
	            //     function foo(n: number) {} // Report argument error on this overload
	            //     function foo() {}
	            //     foo(true);
	            //
	            // If none of the overloads even made it that far, there are two possibilities.
	            // There was a problem with type arguments for some overload, in which case
	            // report an error on that. Or none of the overloads even had correct arity,
	            // in which case give an arity error.
	            //
	            //     function foo<T>(x: T, y: T) {} // Report type argument inference error
	            //     function foo() {}
	            //     foo(0, true);
	            //
	            var candidateForArgumentError;
	            var candidateForTypeArgumentError;
	            var resultOfFailedInference;
	            var result;
	            // Section 4.12.1:
	            // if the candidate list contains one or more signatures for which the type of each argument
	            // expression is a subtype of each corresponding parameter type, the return type of the first
	            // of those signatures becomes the return type of the function call.
	            // Otherwise, the return type of the first signature in the candidate list becomes the return
	            // type of the function call.
	            //
	            // Whether the call is an error is determined by assignability of the arguments. The subtype pass
	            // is just important for choosing the best signature. So in the case where there is only one
	            // signature, the subtype pass is useless. So skipping it is an optimization.
	            if (candidates.length > 1) {
	                result = chooseOverload(candidates, subtypeRelation);
	            }
	            if (!result) {
	                // Reinitialize these pointers for round two
	                candidateForArgumentError = undefined;
	                candidateForTypeArgumentError = undefined;
	                resultOfFailedInference = undefined;
	                result = chooseOverload(candidates, assignableRelation);
	            }
	            if (result) {
	                return result;
	            }
	            // No signatures were applicable. Now report errors based on the last applicable signature with
	            // no arguments excluded from assignability checks.
	            // If candidate is undefined, it means that no candidates had a suitable arity. In that case,
	            // skip the checkApplicableSignature check.
	            if (candidateForArgumentError) {
	                // excludeArgument is undefined, in this case also equivalent to [undefined, undefined, ...]
	                // The importance of excludeArgument is to prevent us from typing function expression parameters
	                // in arguments too early. If possible, we'd like to only type them once we know the correct
	                // overload. However, this matters for the case where the call is correct. When the call is
	                // an error, we don't need to exclude any arguments, although it would cause no harm to do so.
	                checkApplicableSignature(node, args, candidateForArgumentError, assignableRelation, /*excludeArgument*/ undefined, /*reportErrors*/ true);
	            }
	            else if (candidateForTypeArgumentError) {
	                if (!isTaggedTemplate && !isDecorator && typeArguments) {
	                    var typeArguments_2 = node.typeArguments;
	                    checkTypeArguments(candidateForTypeArgumentError, typeArguments_2, ts.map(typeArguments_2, getTypeFromTypeNode), /*reportErrors*/ true, headMessage);
	                }
	                else {
	                    ts.Debug.assert(resultOfFailedInference.failedTypeParameterIndex >= 0);
	                    var failedTypeParameter = candidateForTypeArgumentError.typeParameters[resultOfFailedInference.failedTypeParameterIndex];
	                    var inferenceCandidates = getInferenceCandidates(resultOfFailedInference, resultOfFailedInference.failedTypeParameterIndex);
	                    var diagnosticChainHead = ts.chainDiagnosticMessages(/*details*/ undefined, // details will be provided by call to reportNoCommonSupertypeError
	                    ts.Diagnostics.The_type_argument_for_type_parameter_0_cannot_be_inferred_from_the_usage_Consider_specifying_the_type_arguments_explicitly, typeToString(failedTypeParameter));
	                    if (headMessage) {
	                        diagnosticChainHead = ts.chainDiagnosticMessages(diagnosticChainHead, headMessage);
	                    }
	                    reportNoCommonSupertypeError(inferenceCandidates, node.expression || node.tag, diagnosticChainHead);
	                }
	            }
	            else {
	                reportError(ts.Diagnostics.Supplied_parameters_do_not_match_any_signature_of_call_target);
	            }
	            // No signature was applicable. We have already reported the errors for the invalid signature.
	            // If this is a type resolution session, e.g. Language Service, try to get better information that anySignature.
	            // Pick the first candidate that matches the arity. This way we can get a contextual type for cases like:
	            //  declare function f(a: { xa: number; xb: number; });
	            //  f({ |
	            if (!produceDiagnostics) {
	                for (var _i = 0, candidates_1 = candidates; _i < candidates_1.length; _i++) {
	                    var candidate = candidates_1[_i];
	                    if (hasCorrectArity(node, args, candidate)) {
	                        if (candidate.typeParameters && typeArguments) {
	                            candidate = getSignatureInstantiation(candidate, ts.map(typeArguments, getTypeFromTypeNode));
	                        }
	                        return candidate;
	                    }
	                }
	            }
	            return resolveErrorCall(node);
	            function reportError(message, arg0, arg1, arg2) {
	                var errorInfo;
	                errorInfo = ts.chainDiagnosticMessages(errorInfo, message, arg0, arg1, arg2);
	                if (headMessage) {
	                    errorInfo = ts.chainDiagnosticMessages(errorInfo, headMessage);
	                }
	                diagnostics.add(ts.createDiagnosticForNodeFromMessageChain(node, errorInfo));
	            }
	            function chooseOverload(candidates, relation) {
	                for (var _i = 0, candidates_2 = candidates; _i < candidates_2.length; _i++) {
	                    var originalCandidate = candidates_2[_i];
	                    if (!hasCorrectArity(node, args, originalCandidate)) {
	                        continue;
	                    }
	                    var candidate = void 0;
	                    var typeArgumentsAreValid = void 0;
	                    var inferenceContext = originalCandidate.typeParameters
	                        ? createInferenceContext(originalCandidate.typeParameters, /*inferUnionTypes*/ false)
	                        : undefined;
	                    while (true) {
	                        candidate = originalCandidate;
	                        if (candidate.typeParameters) {
	                            var typeArgumentTypes = void 0;
	                            if (typeArguments) {
	                                typeArgumentTypes = ts.map(typeArguments, getTypeFromTypeNode);
	                                typeArgumentsAreValid = checkTypeArguments(candidate, typeArguments, typeArgumentTypes, /*reportErrors*/ false);
	                            }
	                            else {
	                                inferTypeArguments(node, candidate, args, excludeArgument, inferenceContext);
	                                typeArgumentsAreValid = inferenceContext.failedTypeParameterIndex === undefined;
	                                typeArgumentTypes = inferenceContext.inferredTypes;
	                            }
	                            if (!typeArgumentsAreValid) {
	                                break;
	                            }
	                            candidate = getSignatureInstantiation(candidate, typeArgumentTypes);
	                        }
	                        if (!checkApplicableSignature(node, args, candidate, relation, excludeArgument, /*reportErrors*/ false)) {
	                            break;
	                        }
	                        var index = excludeArgument ? ts.indexOf(excludeArgument, true) : -1;
	                        if (index < 0) {
	                            return candidate;
	                        }
	                        excludeArgument[index] = false;
	                    }
	                    // A post-mortem of this iteration of the loop. The signature was not applicable,
	                    // so we want to track it as a candidate for reporting an error. If the candidate
	                    // had no type parameters, or had no issues related to type arguments, we can
	                    // report an error based on the arguments. If there was an issue with type
	                    // arguments, then we can only report an error based on the type arguments.
	                    if (originalCandidate.typeParameters) {
	                        var instantiatedCandidate = candidate;
	                        if (typeArgumentsAreValid) {
	                            candidateForArgumentError = instantiatedCandidate;
	                        }
	                        else {
	                            candidateForTypeArgumentError = originalCandidate;
	                            if (!typeArguments) {
	                                resultOfFailedInference = inferenceContext;
	                            }
	                        }
	                    }
	                    else {
	                        ts.Debug.assert(originalCandidate === candidate);
	                        candidateForArgumentError = originalCandidate;
	                    }
	                }
	                return undefined;
	            }
	        }
	        function resolveCallExpression(node, candidatesOutArray) {
	            if (node.expression.kind === 95 /* SuperKeyword */) {
	                var superType = checkSuperExpression(node.expression);
	                if (superType !== unknownType) {
	                    // In super call, the candidate signatures are the matching arity signatures of the base constructor function instantiated
	                    // with the type arguments specified in the extends clause.
	                    var baseTypeNode = ts.getClassExtendsHeritageClauseElement(ts.getContainingClass(node));
	                    var baseConstructors = getInstantiatedConstructorsForTypeArguments(superType, baseTypeNode.typeArguments);
	                    return resolveCall(node, baseConstructors, candidatesOutArray);
	                }
	                return resolveUntypedCall(node);
	            }
	            var funcType = checkExpression(node.expression);
	            var apparentType = getApparentType(funcType);
	            if (apparentType === unknownType) {
	                // Another error has already been reported
	                return resolveErrorCall(node);
	            }
	            // Technically, this signatures list may be incomplete. We are taking the apparent type,
	            // but we are not including call signatures that may have been added to the Object or
	            // Function interface, since they have none by default. This is a bit of a leap of faith
	            // that the user will not add any.
	            var callSignatures = getSignaturesOfType(apparentType, 0 /* Call */);
	            var constructSignatures = getSignaturesOfType(apparentType, 1 /* Construct */);
	            // TS 1.0 spec: 4.12
	            // If FuncExpr is of type Any, or of an object type that has no call or construct signatures
	            // but is a subtype of the Function interface, the call is an untyped function call. In an
	            // untyped function call no TypeArgs are permitted, Args can be any argument list, no contextual
	            // types are provided for the argument expressions, and the result is always of type Any.
	            // We exclude union types because we may have a union of function types that happen to have
	            // no common signatures.
	            if (isTypeAny(funcType) || (!callSignatures.length && !constructSignatures.length && !(funcType.flags & 16384 /* Union */) && isTypeAssignableTo(funcType, globalFunctionType))) {
	                // The unknownType indicates that an error already occured (and was reported).  No
	                // need to report another error in this case.
	                if (funcType !== unknownType && node.typeArguments) {
	                    error(node, ts.Diagnostics.Untyped_function_calls_may_not_accept_type_arguments);
	                }
	                return resolveUntypedCall(node);
	            }
	            // If FuncExpr's apparent type(section 3.8.1) is a function type, the call is a typed function call.
	            // TypeScript employs overload resolution in typed function calls in order to support functions
	            // with multiple call signatures.
	            if (!callSignatures.length) {
	                if (constructSignatures.length) {
	                    error(node, ts.Diagnostics.Value_of_type_0_is_not_callable_Did_you_mean_to_include_new, typeToString(funcType));
	                }
	                else {
	                    error(node, ts.Diagnostics.Cannot_invoke_an_expression_whose_type_lacks_a_call_signature);
	                }
	                return resolveErrorCall(node);
	            }
	            return resolveCall(node, callSignatures, candidatesOutArray);
	        }
	        function resolveNewExpression(node, candidatesOutArray) {
	            if (node.arguments && languageVersion < 1 /* ES5 */) {
	                var spreadIndex = getSpreadArgumentIndex(node.arguments);
	                if (spreadIndex >= 0) {
	                    error(node.arguments[spreadIndex], ts.Diagnostics.Spread_operator_in_new_expressions_is_only_available_when_targeting_ECMAScript_5_and_higher);
	                }
	            }
	            var expressionType = checkExpression(node.expression);
	            // If expressionType's apparent type(section 3.8.1) is an object type with one or
	            // more construct signatures, the expression is processed in the same manner as a
	            // function call, but using the construct signatures as the initial set of candidate
	            // signatures for overload resolution. The result type of the function call becomes
	            // the result type of the operation.
	            expressionType = getApparentType(expressionType);
	            if (expressionType === unknownType) {
	                // Another error has already been reported
	                return resolveErrorCall(node);
	            }
	            // If the expression is a class of abstract type, then it cannot be instantiated.
	            // Note, only class declarations can be declared abstract.
	            // In the case of a merged class-module or class-interface declaration,
	            // only the class declaration node will have the Abstract flag set.
	            var valueDecl = expressionType.symbol && getClassLikeDeclarationOfSymbol(expressionType.symbol);
	            if (valueDecl && valueDecl.flags & 128 /* Abstract */) {
	                error(node, ts.Diagnostics.Cannot_create_an_instance_of_the_abstract_class_0, ts.declarationNameToString(valueDecl.name));
	                return resolveErrorCall(node);
	            }
	            // TS 1.0 spec: 4.11
	            // If expressionType is of type Any, Args can be any argument
	            // list and the result of the operation is of type Any.
	            if (isTypeAny(expressionType)) {
	                if (node.typeArguments) {
	                    error(node, ts.Diagnostics.Untyped_function_calls_may_not_accept_type_arguments);
	                }
	                return resolveUntypedCall(node);
	            }
	            // Technically, this signatures list may be incomplete. We are taking the apparent type,
	            // but we are not including construct signatures that may have been added to the Object or
	            // Function interface, since they have none by default. This is a bit of a leap of faith
	            // that the user will not add any.
	            var constructSignatures = getSignaturesOfType(expressionType, 1 /* Construct */);
	            if (constructSignatures.length) {
	                return resolveCall(node, constructSignatures, candidatesOutArray);
	            }
	            // If expressionType's apparent type is an object type with no construct signatures but
	            // one or more call signatures, the expression is processed as a function call. A compile-time
	            // error occurs if the result of the function call is not Void. The type of the result of the
	            // operation is Any.
	            var callSignatures = getSignaturesOfType(expressionType, 0 /* Call */);
	            if (callSignatures.length) {
	                var signature = resolveCall(node, callSignatures, candidatesOutArray);
	                if (getReturnTypeOfSignature(signature) !== voidType) {
	                    error(node, ts.Diagnostics.Only_a_void_function_can_be_called_with_the_new_keyword);
	                }
	                return signature;
	            }
	            error(node, ts.Diagnostics.Cannot_use_new_with_an_expression_whose_type_lacks_a_call_or_construct_signature);
	            return resolveErrorCall(node);
	        }
	        function resolveTaggedTemplateExpression(node, candidatesOutArray) {
	            var tagType = checkExpression(node.tag);
	            var apparentType = getApparentType(tagType);
	            if (apparentType === unknownType) {
	                // Another error has already been reported
	                return resolveErrorCall(node);
	            }
	            var callSignatures = getSignaturesOfType(apparentType, 0 /* Call */);
	            if (isTypeAny(tagType) || (!callSignatures.length && !(tagType.flags & 16384 /* Union */) && isTypeAssignableTo(tagType, globalFunctionType))) {
	                return resolveUntypedCall(node);
	            }
	            if (!callSignatures.length) {
	                error(node, ts.Diagnostics.Cannot_invoke_an_expression_whose_type_lacks_a_call_signature);
	                return resolveErrorCall(node);
	            }
	            return resolveCall(node, callSignatures, candidatesOutArray);
	        }
	        /**
	          * Gets the localized diagnostic head message to use for errors when resolving a decorator as a call expression.
	          */
	        function getDiagnosticHeadMessageForDecoratorResolution(node) {
	            switch (node.parent.kind) {
	                case 217 /* ClassDeclaration */:
	                case 189 /* ClassExpression */:
	                    return ts.Diagnostics.Unable_to_resolve_signature_of_class_decorator_when_called_as_an_expression;
	                case 139 /* Parameter */:
	                    return ts.Diagnostics.Unable_to_resolve_signature_of_parameter_decorator_when_called_as_an_expression;
	                case 142 /* PropertyDeclaration */:
	                    return ts.Diagnostics.Unable_to_resolve_signature_of_property_decorator_when_called_as_an_expression;
	                case 144 /* MethodDeclaration */:
	                case 146 /* GetAccessor */:
	                case 147 /* SetAccessor */:
	                    return ts.Diagnostics.Unable_to_resolve_signature_of_method_decorator_when_called_as_an_expression;
	            }
	        }
	        /**
	          * Resolves a decorator as if it were a call expression.
	          */
	        function resolveDecorator(node, candidatesOutArray) {
	            var funcType = checkExpression(node.expression);
	            var apparentType = getApparentType(funcType);
	            if (apparentType === unknownType) {
	                return resolveErrorCall(node);
	            }
	            var callSignatures = getSignaturesOfType(apparentType, 0 /* Call */);
	            if (funcType === anyType || (!callSignatures.length && !(funcType.flags & 16384 /* Union */) && isTypeAssignableTo(funcType, globalFunctionType))) {
	                return resolveUntypedCall(node);
	            }
	            var headMessage = getDiagnosticHeadMessageForDecoratorResolution(node);
	            if (!callSignatures.length) {
	                var errorInfo = void 0;
	                errorInfo = ts.chainDiagnosticMessages(errorInfo, ts.Diagnostics.Cannot_invoke_an_expression_whose_type_lacks_a_call_signature);
	                errorInfo = ts.chainDiagnosticMessages(errorInfo, headMessage);
	                diagnostics.add(ts.createDiagnosticForNodeFromMessageChain(node, errorInfo));
	                return resolveErrorCall(node);
	            }
	            return resolveCall(node, callSignatures, candidatesOutArray, headMessage);
	        }
	        // candidatesOutArray is passed by signature help in the language service, and collectCandidates
	        // must fill it up with the appropriate candidate signatures
	        function getResolvedSignature(node, candidatesOutArray) {
	            var links = getNodeLinks(node);
	            // If getResolvedSignature has already been called, we will have cached the resolvedSignature.
	            // However, it is possible that either candidatesOutArray was not passed in the first time,
	            // or that a different candidatesOutArray was passed in. Therefore, we need to redo the work
	            // to correctly fill the candidatesOutArray.
	            if (!links.resolvedSignature || candidatesOutArray) {
	                links.resolvedSignature = anySignature;
	                if (node.kind === 171 /* CallExpression */) {
	                    links.resolvedSignature = resolveCallExpression(node, candidatesOutArray);
	                }
	                else if (node.kind === 172 /* NewExpression */) {
	                    links.resolvedSignature = resolveNewExpression(node, candidatesOutArray);
	                }
	                else if (node.kind === 173 /* TaggedTemplateExpression */) {
	                    links.resolvedSignature = resolveTaggedTemplateExpression(node, candidatesOutArray);
	                }
	                else if (node.kind === 140 /* Decorator */) {
	                    links.resolvedSignature = resolveDecorator(node, candidatesOutArray);
	                }
	                else {
	                    ts.Debug.fail("Branch in 'getResolvedSignature' should be unreachable.");
	                }
	            }
	            return links.resolvedSignature;
	        }
	        function getInferredClassType(symbol) {
	            var links = getSymbolLinks(symbol);
	            if (!links.inferredClassType) {
	                links.inferredClassType = createAnonymousType(undefined, symbol.members, emptyArray, emptyArray, /*stringIndexType*/ undefined, /*numberIndexType*/ undefined);
	            }
	            return links.inferredClassType;
	        }
	        /**
	         * Syntactically and semantically checks a call or new expression.
	         * @param node The call/new expression to be checked.
	         * @returns On success, the expression's signature's return type. On failure, anyType.
	         */
	        function checkCallExpression(node) {
	            // Grammar checking; stop grammar-checking if checkGrammarTypeArguments return true
	            checkGrammarTypeArguments(node, node.typeArguments) || checkGrammarArguments(node, node.arguments);
	            var signature = getResolvedSignature(node);
	            if (node.expression.kind === 95 /* SuperKeyword */) {
	                return voidType;
	            }
	            if (node.kind === 172 /* NewExpression */) {
	                var declaration = signature.declaration;
	                if (declaration &&
	                    declaration.kind !== 145 /* Constructor */ &&
	                    declaration.kind !== 149 /* ConstructSignature */ &&
	                    declaration.kind !== 154 /* ConstructorType */ &&
	                    !ts.isJSDocConstructSignature(declaration)) {
	                    // When resolved signature is a call signature (and not a construct signature) the result type is any, unless
	                    // the declaring function had members created through 'x.prototype.y = expr' or 'this.y = expr' psuedodeclarations
	                    // in a JS file
	                    var funcSymbol = checkExpression(node.expression).symbol;
	                    if (funcSymbol && funcSymbol.members && (funcSymbol.flags & 16 /* Function */)) {
	                        return getInferredClassType(funcSymbol);
	                    }
	                    else if (compilerOptions.noImplicitAny) {
	                        error(node, ts.Diagnostics.new_expression_whose_target_lacks_a_construct_signature_implicitly_has_an_any_type);
	                    }
	                    return anyType;
	                }
	            }
	            // In JavaScript files, calls to any identifier 'require' are treated as external module imports
	            if (ts.isInJavaScriptFile(node) && ts.isRequireCall(node, /*checkArgumentIsStringLiteral*/ true)) {
	                return resolveExternalModuleTypeByLiteral(node.arguments[0]);
	            }
	            return getReturnTypeOfSignature(signature);
	        }
	        function checkTaggedTemplateExpression(node) {
	            return getReturnTypeOfSignature(getResolvedSignature(node));
	        }
	        function checkAssertion(node) {
	            var exprType = getRegularTypeOfObjectLiteral(checkExpression(node.expression));
	            var targetType = getTypeFromTypeNode(node.type);
	            if (produceDiagnostics && targetType !== unknownType) {
	                var widenedType = getWidenedType(exprType);
	                // Permit 'number[] | "foo"' to be asserted to 'string'.
	                var bothAreStringLike = someConstituentTypeHasKind(targetType, 258 /* StringLike */) &&
	                    someConstituentTypeHasKind(widenedType, 258 /* StringLike */);
	                if (!bothAreStringLike && !(isTypeAssignableTo(targetType, widenedType))) {
	                    checkTypeAssignableTo(exprType, targetType, node, ts.Diagnostics.Neither_type_0_nor_type_1_is_assignable_to_the_other);
	                }
	            }
	            return targetType;
	        }
	        function getTypeAtPosition(signature, pos) {
	            return signature.hasRestParameter ?
	                pos < signature.parameters.length - 1 ? getTypeOfSymbol(signature.parameters[pos]) : getRestTypeOfSignature(signature) :
	                pos < signature.parameters.length ? getTypeOfSymbol(signature.parameters[pos]) : anyType;
	        }
	        function assignContextualParameterTypes(signature, context, mapper) {
	            var len = signature.parameters.length - (signature.hasRestParameter ? 1 : 0);
	            for (var i = 0; i < len; i++) {
	                var parameter = signature.parameters[i];
	                var contextualParameterType = getTypeAtPosition(context, i);
	                assignTypeToParameterAndFixTypeParameters(parameter, contextualParameterType, mapper);
	            }
	            if (signature.hasRestParameter && isRestParameterIndex(context, signature.parameters.length - 1)) {
	                var parameter = ts.lastOrUndefined(signature.parameters);
	                var contextualParameterType = getTypeOfSymbol(ts.lastOrUndefined(context.parameters));
	                assignTypeToParameterAndFixTypeParameters(parameter, contextualParameterType, mapper);
	            }
	        }
	        // When contextual typing assigns a type to a parameter that contains a binding pattern, we also need to push
	        // the destructured type into the contained binding elements.
	        function assignBindingElementTypes(node) {
	            if (ts.isBindingPattern(node.name)) {
	                for (var _i = 0, _a = node.name.elements; _i < _a.length; _i++) {
	                    var element = _a[_i];
	                    if (element.kind !== 190 /* OmittedExpression */) {
	                        if (element.name.kind === 69 /* Identifier */) {
	                            getSymbolLinks(getSymbolOfNode(element)).type = getTypeForBindingElement(element);
	                        }
	                        assignBindingElementTypes(element);
	                    }
	                }
	            }
	        }
	        function assignTypeToParameterAndFixTypeParameters(parameter, contextualType, mapper) {
	            var links = getSymbolLinks(parameter);
	            if (!links.type) {
	                links.type = instantiateType(contextualType, mapper);
	                assignBindingElementTypes(parameter.valueDeclaration);
	            }
	            else if (isInferentialContext(mapper)) {
	                // Even if the parameter already has a type, it might be because it was given a type while
	                // processing the function as an argument to a prior signature during overload resolution.
	                // If this was the case, it may have caused some type parameters to be fixed. So here,
	                // we need to ensure that type parameters at the same positions get fixed again. This is
	                // done by calling instantiateType to attach the mapper to the contextualType, and then
	                // calling inferTypes to force a walk of contextualType so that all the correct fixing
	                // happens. The choice to pass in links.type may seem kind of arbitrary, but it serves
	                // to make sure that all the correct positions in contextualType are reached by the walk.
	                // Here is an example:
	                //
	                //      interface Base {
	                //          baseProp;
	                //      }
	                //      interface Derived extends Base {
	                //          toBase(): Base;
	                //      }
	                //
	                //      var derived: Derived;
	                //
	                //      declare function foo<T>(x: T, func: (p: T) => T): T;
	                //      declare function foo<T>(x: T, func: (p: T) => T): T;
	                //
	                //      var result = foo(derived, d => d.toBase());
	                //
	                // We are typing d while checking the second overload. But we've already given d
	                // a type (Derived) from the first overload. However, we still want to fix the
	                // T in the second overload so that we do not infer Base as a candidate for T
	                // (inferring Base would make type argument inference inconsistent between the two
	                // overloads).
	                inferTypes(mapper.context, links.type, instantiateType(contextualType, mapper));
	            }
	        }
	        function getReturnTypeFromJSDocComment(func) {
	            var returnTag = ts.getJSDocReturnTag(func);
	            if (returnTag && returnTag.typeExpression) {
	                return getTypeFromTypeNode(returnTag.typeExpression.type);
	            }
	            return undefined;
	        }
	        function createPromiseType(promisedType) {
	            // creates a `Promise<T>` type where `T` is the promisedType argument
	            var globalPromiseType = getGlobalPromiseType();
	            if (globalPromiseType !== emptyGenericType) {
	                // if the promised type is itself a promise, get the underlying type; otherwise, fallback to the promised type
	                promisedType = getAwaitedType(promisedType);
	                return createTypeReference(globalPromiseType, [promisedType]);
	            }
	            return emptyObjectType;
	        }
	        function getReturnTypeFromBody(func, contextualMapper) {
	            var contextualSignature = getContextualSignatureForFunctionLikeDeclaration(func);
	            if (!func.body) {
	                return unknownType;
	            }
	            var isAsync = ts.isAsyncFunctionLike(func);
	            var type;
	            if (func.body.kind !== 195 /* Block */) {
	                type = checkExpressionCached(func.body, contextualMapper);
	                if (isAsync) {
	                    // From within an async function you can return either a non-promise value or a promise. Any
	                    // Promise/A+ compatible implementation will always assimilate any foreign promise, so the
	                    // return type of the body should be unwrapped to its awaited type, which we will wrap in
	                    // the native Promise<T> type later in this function.
	                    type = checkAwaitedType(type, func, ts.Diagnostics.Return_expression_in_async_function_does_not_have_a_valid_callable_then_member);
	                }
	            }
	            else {
	                var types = void 0;
	                var funcIsGenerator = !!func.asteriskToken;
	                if (funcIsGenerator) {
	                    types = checkAndAggregateYieldOperandTypes(func.body, contextualMapper);
	                    if (types.length === 0) {
	                        var iterableIteratorAny = createIterableIteratorType(anyType);
	                        if (compilerOptions.noImplicitAny) {
	                            error(func.asteriskToken, ts.Diagnostics.Generator_implicitly_has_type_0_because_it_does_not_yield_any_values_Consider_supplying_a_return_type, typeToString(iterableIteratorAny));
	                        }
	                        return iterableIteratorAny;
	                    }
	                }
	                else {
	                    types = checkAndAggregateReturnExpressionTypes(func.body, contextualMapper, isAsync);
	                    if (types.length === 0) {
	                        if (isAsync) {
	                            // For an async function, the return type will not be void, but rather a Promise for void.
	                            var promiseType = createPromiseType(voidType);
	                            if (promiseType === emptyObjectType) {
	                                error(func, ts.Diagnostics.An_async_function_or_method_must_have_a_valid_awaitable_return_type);
	                                return unknownType;
	                            }
	                            return promiseType;
	                        }
	                        else {
	                            return voidType;
	                        }
	                    }
	                }
	                // When yield/return statements are contextually typed we allow the return type to be a union type.
	                // Otherwise we require the yield/return expressions to have a best common supertype.
	                type = contextualSignature ? getUnionType(types) : getCommonSupertype(types);
	                if (!type) {
	                    if (funcIsGenerator) {
	                        error(func, ts.Diagnostics.No_best_common_type_exists_among_yield_expressions);
	                        return createIterableIteratorType(unknownType);
	                    }
	                    else {
	                        error(func, ts.Diagnostics.No_best_common_type_exists_among_return_expressions);
	                        // Defer to unioning the return types so we get a) downstream errors earlier and b) better Salsa experience
	                        return getUnionType(types);
	                    }
	                }
	                if (funcIsGenerator) {
	                    type = createIterableIteratorType(type);
	                }
	            }
	            if (!contextualSignature) {
	                reportErrorsFromWidening(func, type);
	            }
	            var widenedType = getWidenedType(type);
	            if (isAsync) {
	                // From within an async function you can return either a non-promise value or a promise. Any
	                // Promise/A+ compatible implementation will always assimilate any foreign promise, so the
	                // return type of the body is awaited type of the body, wrapped in a native Promise<T> type.
	                var promiseType = createPromiseType(widenedType);
	                if (promiseType === emptyObjectType) {
	                    error(func, ts.Diagnostics.An_async_function_or_method_must_have_a_valid_awaitable_return_type);
	                    return unknownType;
	                }
	                return promiseType;
	            }
	            else {
	                return widenedType;
	            }
	        }
	        function checkAndAggregateYieldOperandTypes(body, contextualMapper) {
	            var aggregatedTypes = [];
	            ts.forEachYieldExpression(body, function (yieldExpression) {
	                var expr = yieldExpression.expression;
	                if (expr) {
	                    var type = checkExpressionCached(expr, contextualMapper);
	                    if (yieldExpression.asteriskToken) {
	                        // A yield* expression effectively yields everything that its operand yields
	                        type = checkElementTypeOfIterable(type, yieldExpression.expression);
	                    }
	                    if (!ts.contains(aggregatedTypes, type)) {
	                        aggregatedTypes.push(type);
	                    }
	                }
	            });
	            return aggregatedTypes;
	        }
	        function checkAndAggregateReturnExpressionTypes(body, contextualMapper, isAsync) {
	            var aggregatedTypes = [];
	            ts.forEachReturnStatement(body, function (returnStatement) {
	                var expr = returnStatement.expression;
	                if (expr) {
	                    var type = checkExpressionCached(expr, contextualMapper);
	                    if (isAsync) {
	                        // From within an async function you can return either a non-promise value or a promise. Any
	                        // Promise/A+ compatible implementation will always assimilate any foreign promise, so the
	                        // return type of the body should be unwrapped to its awaited type, which should be wrapped in
	                        // the native Promise<T> type by the caller.
	                        type = checkAwaitedType(type, body.parent, ts.Diagnostics.Return_expression_in_async_function_does_not_have_a_valid_callable_then_member);
	                    }
	                    if (!ts.contains(aggregatedTypes, type)) {
	                        aggregatedTypes.push(type);
	                    }
	                }
	            });
	            return aggregatedTypes;
	        }
	        /**
	         * TypeScript Specification 1.0 (6.3) - July 2014
	         *   An explicitly typed function whose return type isn't the Void type,
	         *   the Any type, or a union type containing the Void or Any type as a constituent
	         *   must have at least one return statement somewhere in its body.
	         *   An exception to this rule is if the function implementation consists of a single 'throw' statement.
	         *
	         * @param returnType - return type of the function, can be undefined if return type is not explicitly specified
	         */
	        function checkAllCodePathsInNonVoidFunctionReturnOrThrow(func, returnType) {
	            if (!produceDiagnostics) {
	                return;
	            }
	            // Functions with with an explicitly specified 'void' or 'any' return type don't need any return expressions.
	            if (returnType === voidType || isTypeAny(returnType) || (returnType && (returnType.flags & 16384 /* Union */) && someConstituentTypeHasKind(returnType, 1 /* Any */ | 16 /* Void */))) {
	                return;
	            }
	            // If all we have is a function signature, or an arrow function with an expression body, then there is nothing to check.
	            // also if HasImplicitReturn flag is not set this means that all codepaths in function body end with return or throw
	            if (ts.nodeIsMissing(func.body) || func.body.kind !== 195 /* Block */ || !(func.flags & 524288 /* HasImplicitReturn */)) {
	                return;
	            }
	            var hasExplicitReturn = func.flags & 1048576 /* HasExplicitReturn */;
	            if (returnType && !hasExplicitReturn) {
	                // minimal check: function has syntactic return type annotation and no explicit return statements in the body
	                // this function does not conform to the specification.
	                // NOTE: having returnType !== undefined is a precondition for entering this branch so func.type will always be present
	                error(func.type, ts.Diagnostics.A_function_whose_declared_type_is_neither_void_nor_any_must_return_a_value);
	            }
	            else if (compilerOptions.noImplicitReturns) {
	                if (!returnType) {
	                    // If return type annotation is omitted check if function has any explicit return statements.
	                    // If it does not have any - its inferred return type is void - don't do any checks.
	                    // Otherwise get inferred return type from function body and report error only if it is not void / anytype
	                    var inferredReturnType = hasExplicitReturn
	                        ? getReturnTypeOfSignature(getSignatureFromDeclaration(func))
	                        : voidType;
	                    if (inferredReturnType === voidType || isTypeAny(inferredReturnType)) {
	                        return;
	                    }
	                }
	                error(func.type || func, ts.Diagnostics.Not_all_code_paths_return_a_value);
	            }
	        }
	        function checkFunctionExpressionOrObjectLiteralMethod(node, contextualMapper) {
	            ts.Debug.assert(node.kind !== 144 /* MethodDeclaration */ || ts.isObjectLiteralMethod(node));
	            // Grammar checking
	            var hasGrammarError = checkGrammarFunctionLikeDeclaration(node);
	            if (!hasGrammarError && node.kind === 176 /* FunctionExpression */) {
	                checkGrammarForGenerator(node);
	            }
	            // The identityMapper object is used to indicate that function expressions are wildcards
	            if (contextualMapper === identityMapper && isContextSensitive(node)) {
	                checkNodeDeferred(node);
	                return anyFunctionType;
	            }
	            var links = getNodeLinks(node);
	            var type = getTypeOfSymbol(node.symbol);
	            var contextSensitive = isContextSensitive(node);
	            var mightFixTypeParameters = contextSensitive && isInferentialContext(contextualMapper);
	            // Check if function expression is contextually typed and assign parameter types if so.
	            // See the comment in assignTypeToParameterAndFixTypeParameters to understand why we need to
	            // check mightFixTypeParameters.
	            if (mightFixTypeParameters || !(links.flags & 1024 /* ContextChecked */)) {
	                var contextualSignature = getContextualSignature(node);
	                // If a type check is started at a function expression that is an argument of a function call, obtaining the
	                // contextual type may recursively get back to here during overload resolution of the call. If so, we will have
	                // already assigned contextual types.
	                var contextChecked = !!(links.flags & 1024 /* ContextChecked */);
	                if (mightFixTypeParameters || !contextChecked) {
	                    links.flags |= 1024 /* ContextChecked */;
	                    if (contextualSignature) {
	                        var signature = getSignaturesOfType(type, 0 /* Call */)[0];
	                        if (contextSensitive) {
	                            assignContextualParameterTypes(signature, contextualSignature, contextualMapper || identityMapper);
	                        }
	                        if (mightFixTypeParameters || !node.type && !signature.resolvedReturnType) {
	                            var returnType = getReturnTypeFromBody(node, contextualMapper);
	                            if (!signature.resolvedReturnType) {
	                                signature.resolvedReturnType = returnType;
	                            }
	                        }
	                    }
	                    if (!contextChecked) {
	                        checkSignatureDeclaration(node);
	                        checkNodeDeferred(node);
	                    }
	                }
	            }
	            if (produceDiagnostics && node.kind !== 144 /* MethodDeclaration */ && node.kind !== 143 /* MethodSignature */) {
	                checkCollisionWithCapturedSuperVariable(node, node.name);
	                checkCollisionWithCapturedThisVariable(node, node.name);
	            }
	            return type;
	        }
	        function checkFunctionExpressionOrObjectLiteralMethodDeferred(node) {
	            ts.Debug.assert(node.kind !== 144 /* MethodDeclaration */ || ts.isObjectLiteralMethod(node));
	            var isAsync = ts.isAsyncFunctionLike(node);
	            var returnOrPromisedType = node.type && (isAsync ? checkAsyncFunctionReturnType(node) : getTypeFromTypeNode(node.type));
	            if (!node.asteriskToken) {
	                // return is not necessary in the body of generators
	                checkAllCodePathsInNonVoidFunctionReturnOrThrow(node, returnOrPromisedType);
	            }
	            if (node.body) {
	                if (!node.type) {
	                    // There are some checks that are only performed in getReturnTypeFromBody, that may produce errors
	                    // we need. An example is the noImplicitAny errors resulting from widening the return expression
	                    // of a function. Because checking of function expression bodies is deferred, there was never an
	                    // appropriate time to do this during the main walk of the file (see the comment at the top of
	                    // checkFunctionExpressionBodies). So it must be done now.
	                    getReturnTypeOfSignature(getSignatureFromDeclaration(node));
	                }
	                if (node.body.kind === 195 /* Block */) {
	                    checkSourceElement(node.body);
	                }
	                else {
	                    // From within an async function you can return either a non-promise value or a promise. Any
	                    // Promise/A+ compatible implementation will always assimilate any foreign promise, so we
	                    // should not be checking assignability of a promise to the return type. Instead, we need to
	                    // check assignability of the awaited type of the expression body against the promised type of
	                    // its return type annotation.
	                    var exprType = checkExpression(node.body);
	                    if (returnOrPromisedType) {
	                        if (isAsync) {
	                            var awaitedType = checkAwaitedType(exprType, node.body, ts.Diagnostics.Expression_body_for_async_arrow_function_does_not_have_a_valid_callable_then_member);
	                            checkTypeAssignableTo(awaitedType, returnOrPromisedType, node.body);
	                        }
	                        else {
	                            checkTypeAssignableTo(exprType, returnOrPromisedType, node.body);
	                        }
	                    }
	                }
	            }
	        }
	        function checkArithmeticOperandType(operand, type, diagnostic) {
	            if (!isTypeAnyOrAllConstituentTypesHaveKind(type, 132 /* NumberLike */)) {
	                error(operand, diagnostic);
	                return false;
	            }
	            return true;
	        }
	        function checkReferenceExpression(n, invalidReferenceMessage, constantVariableMessage) {
	            function findSymbol(n) {
	                var symbol = getNodeLinks(n).resolvedSymbol;
	                // Because we got the symbol from the resolvedSymbol property, it might be of kind
	                // SymbolFlags.ExportValue. In this case it is necessary to get the actual export
	                // symbol, which will have the correct flags set on it.
	                return symbol && getExportSymbolOfValueSymbolIfExported(symbol);
	            }
	            function isReferenceOrErrorExpression(n) {
	                // TypeScript 1.0 spec (April 2014):
	                // Expressions are classified as values or references.
	                // References are the subset of expressions that are permitted as the target of an assignment.
	                // Specifically, references are combinations of identifiers(section 4.3), parentheses(section 4.7),
	                // and property accesses(section 4.10).
	                // All other expression constructs described in this chapter are classified as values.
	                switch (n.kind) {
	                    case 69 /* Identifier */: {
	                        var symbol = findSymbol(n);
	                        // TypeScript 1.0 spec (April 2014): 4.3
	                        // An identifier expression that references a variable or parameter is classified as a reference.
	                        // An identifier expression that references any other kind of entity is classified as a value(and therefore cannot be the target of an assignment).
	                        return !symbol || symbol === unknownSymbol || symbol === argumentsSymbol || (symbol.flags & 3 /* Variable */) !== 0;
	                    }
	                    case 169 /* PropertyAccessExpression */: {
	                        var symbol = findSymbol(n);
	                        // TypeScript 1.0 spec (April 2014): 4.10
	                        // A property access expression is always classified as a reference.
	                        // NOTE (not in spec): assignment to enum members should not be allowed
	                        return !symbol || symbol === unknownSymbol || (symbol.flags & ~8 /* EnumMember */) !== 0;
	                    }
	                    case 170 /* ElementAccessExpression */:
	                        //  old compiler doesn't check indexed access
	                        return true;
	                    case 175 /* ParenthesizedExpression */:
	                        return isReferenceOrErrorExpression(n.expression);
	                    default:
	                        return false;
	                }
	            }
	            function isConstVariableReference(n) {
	                switch (n.kind) {
	                    case 69 /* Identifier */:
	                    case 169 /* PropertyAccessExpression */: {
	                        var symbol = findSymbol(n);
	                        return symbol && (symbol.flags & 3 /* Variable */) !== 0 && (getDeclarationFlagsFromSymbol(symbol) & 16384 /* Const */) !== 0;
	                    }
	                    case 170 /* ElementAccessExpression */: {
	                        var index = n.argumentExpression;
	                        var symbol = findSymbol(n.expression);
	                        if (symbol && index && index.kind === 9 /* StringLiteral */) {
	                            var name_12 = index.text;
	                            var prop = getPropertyOfType(getTypeOfSymbol(symbol), name_12);
	                            return prop && (prop.flags & 3 /* Variable */) !== 0 && (getDeclarationFlagsFromSymbol(prop) & 16384 /* Const */) !== 0;
	                        }
	                        return false;
	                    }
	                    case 175 /* ParenthesizedExpression */:
	                        return isConstVariableReference(n.expression);
	                    default:
	                        return false;
	                }
	            }
	            if (!isReferenceOrErrorExpression(n)) {
	                error(n, invalidReferenceMessage);
	                return false;
	            }
	            if (isConstVariableReference(n)) {
	                error(n, constantVariableMessage);
	                return false;
	            }
	            return true;
	        }
	        function checkDeleteExpression(node) {
	            checkExpression(node.expression);
	            return booleanType;
	        }
	        function checkTypeOfExpression(node) {
	            checkExpression(node.expression);
	            return stringType;
	        }
	        function checkVoidExpression(node) {
	            checkExpression(node.expression);
	            return undefinedType;
	        }
	        function checkAwaitExpression(node) {
	            // Grammar checking
	            if (produceDiagnostics) {
	                if (!(node.parserContextFlags & 8 /* Await */)) {
	                    grammarErrorOnFirstToken(node, ts.Diagnostics.await_expression_is_only_allowed_within_an_async_function);
	                }
	                if (isInParameterInitializerBeforeContainingFunction(node)) {
	                    error(node, ts.Diagnostics.await_expressions_cannot_be_used_in_a_parameter_initializer);
	                }
	            }
	            var operandType = checkExpression(node.expression);
	            return checkAwaitedType(operandType, node);
	        }
	        function checkPrefixUnaryExpression(node) {
	            var operandType = checkExpression(node.operand);
	            switch (node.operator) {
	                case 35 /* PlusToken */:
	                case 36 /* MinusToken */:
	                case 50 /* TildeToken */:
	                    if (someConstituentTypeHasKind(operandType, 16777216 /* ESSymbol */)) {
	                        error(node.operand, ts.Diagnostics.The_0_operator_cannot_be_applied_to_type_symbol, ts.tokenToString(node.operator));
	                    }
	                    return numberType;
	                case 49 /* ExclamationToken */:
	                    return booleanType;
	                case 41 /* PlusPlusToken */:
	                case 42 /* MinusMinusToken */:
	                    var ok = checkArithmeticOperandType(node.operand, operandType, ts.Diagnostics.An_arithmetic_operand_must_be_of_type_any_number_or_an_enum_type);
	                    if (ok) {
	                        // run check only if former checks succeeded to avoid reporting cascading errors
	                        checkReferenceExpression(node.operand, ts.Diagnostics.The_operand_of_an_increment_or_decrement_operator_must_be_a_variable_property_or_indexer, ts.Diagnostics.The_operand_of_an_increment_or_decrement_operator_cannot_be_a_constant);
	                    }
	                    return numberType;
	            }
	            return unknownType;
	        }
	        function checkPostfixUnaryExpression(node) {
	            var operandType = checkExpression(node.operand);
	            var ok = checkArithmeticOperandType(node.operand, operandType, ts.Diagnostics.An_arithmetic_operand_must_be_of_type_any_number_or_an_enum_type);
	            if (ok) {
	                // run check only if former checks succeeded to avoid reporting cascading errors
	                checkReferenceExpression(node.operand, ts.Diagnostics.The_operand_of_an_increment_or_decrement_operator_must_be_a_variable_property_or_indexer, ts.Diagnostics.The_operand_of_an_increment_or_decrement_operator_cannot_be_a_constant);
	            }
	            return numberType;
	        }
	        // Just like isTypeOfKind below, except that it returns true if *any* constituent
	        // has this kind.
	        function someConstituentTypeHasKind(type, kind) {
	            if (type.flags & kind) {
	                return true;
	            }
	            if (type.flags & 49152 /* UnionOrIntersection */) {
	                var types = type.types;
	                for (var _i = 0, types_10 = types; _i < types_10.length; _i++) {
	                    var current = types_10[_i];
	                    if (current.flags & kind) {
	                        return true;
	                    }
	                }
	                return false;
	            }
	            return false;
	        }
	        // Return true if type has the given flags, or is a union or intersection type composed of types that all have those flags.
	        function allConstituentTypesHaveKind(type, kind) {
	            if (type.flags & kind) {
	                return true;
	            }
	            if (type.flags & 49152 /* UnionOrIntersection */) {
	                var types = type.types;
	                for (var _i = 0, types_11 = types; _i < types_11.length; _i++) {
	                    var current = types_11[_i];
	                    if (!(current.flags & kind)) {
	                        return false;
	                    }
	                }
	                return true;
	            }
	            return false;
	        }
	        function isConstEnumObjectType(type) {
	            return type.flags & (80896 /* ObjectType */ | 65536 /* Anonymous */) && type.symbol && isConstEnumSymbol(type.symbol);
	        }
	        function isConstEnumSymbol(symbol) {
	            return (symbol.flags & 128 /* ConstEnum */) !== 0;
	        }
	        function checkInstanceOfExpression(left, right, leftType, rightType) {
	            // TypeScript 1.0 spec (April 2014): 4.15.4
	            // The instanceof operator requires the left operand to be of type Any, an object type, or a type parameter type,
	            // and the right operand to be of type Any or a subtype of the 'Function' interface type.
	            // The result is always of the Boolean primitive type.
	            // NOTE: do not raise error if leftType is unknown as related error was already reported
	            if (allConstituentTypesHaveKind(leftType, 16777726 /* Primitive */)) {
	                error(left, ts.Diagnostics.The_left_hand_side_of_an_instanceof_expression_must_be_of_type_any_an_object_type_or_a_type_parameter);
	            }
	            // NOTE: do not raise error if right is unknown as related error was already reported
	            if (!(isTypeAny(rightType) || isTypeSubtypeOf(rightType, globalFunctionType))) {
	                error(right, ts.Diagnostics.The_right_hand_side_of_an_instanceof_expression_must_be_of_type_any_or_of_a_type_assignable_to_the_Function_interface_type);
	            }
	            return booleanType;
	        }
	        function checkInExpression(left, right, leftType, rightType) {
	            // TypeScript 1.0 spec (April 2014): 4.15.5
	            // The in operator requires the left operand to be of type Any, the String primitive type, or the Number primitive type,
	            // and the right operand to be of type Any, an object type, or a type parameter type.
	            // The result is always of the Boolean primitive type.
	            if (!isTypeAnyOrAllConstituentTypesHaveKind(leftType, 258 /* StringLike */ | 132 /* NumberLike */ | 16777216 /* ESSymbol */)) {
	                error(left, ts.Diagnostics.The_left_hand_side_of_an_in_expression_must_be_of_type_any_string_number_or_symbol);
	            }
	            if (!isTypeAnyOrAllConstituentTypesHaveKind(rightType, 80896 /* ObjectType */ | 512 /* TypeParameter */)) {
	                error(right, ts.Diagnostics.The_right_hand_side_of_an_in_expression_must_be_of_type_any_an_object_type_or_a_type_parameter);
	            }
	            return booleanType;
	        }
	        function checkObjectLiteralAssignment(node, sourceType, contextualMapper) {
	            var properties = node.properties;
	            for (var _i = 0, properties_3 = properties; _i < properties_3.length; _i++) {
	                var p = properties_3[_i];
	                if (p.kind === 248 /* PropertyAssignment */ || p.kind === 249 /* ShorthandPropertyAssignment */) {
	                    var name_13 = p.name;
	                    if (name_13.kind === 137 /* ComputedPropertyName */) {
	                        checkComputedPropertyName(name_13);
	                    }
	                    if (isComputedNonLiteralName(name_13)) {
	                        continue;
	                    }
	                    var text = getTextOfPropertyName(name_13);
	                    var type = isTypeAny(sourceType)
	                        ? sourceType
	                        : getTypeOfPropertyOfType(sourceType, text) ||
	                            isNumericLiteralName(text) && getIndexTypeOfType(sourceType, 1 /* Number */) ||
	                            getIndexTypeOfType(sourceType, 0 /* String */);
	                    if (type) {
	                        if (p.kind === 249 /* ShorthandPropertyAssignment */) {
	                            checkDestructuringAssignment(p, type);
	                        }
	                        else {
	                            // non-shorthand property assignments should always have initializers
	                            checkDestructuringAssignment(p.initializer, type);
	                        }
	                    }
	                    else {
	                        error(name_13, ts.Diagnostics.Type_0_has_no_property_1_and_no_string_index_signature, typeToString(sourceType), ts.declarationNameToString(name_13));
	                    }
	                }
	                else {
	                    error(p, ts.Diagnostics.Property_assignment_expected);
	                }
	            }
	            return sourceType;
	        }
	        function checkArrayLiteralAssignment(node, sourceType, contextualMapper) {
	            // This elementType will be used if the specific property corresponding to this index is not
	            // present (aka the tuple element property). This call also checks that the parentType is in
	            // fact an iterable or array (depending on target language).
	            var elementType = checkIteratedTypeOrElementType(sourceType, node, /*allowStringInput*/ false) || unknownType;
	            var elements = node.elements;
	            for (var i = 0; i < elements.length; i++) {
	                var e = elements[i];
	                if (e.kind !== 190 /* OmittedExpression */) {
	                    if (e.kind !== 188 /* SpreadElementExpression */) {
	                        var propName = "" + i;
	                        var type = isTypeAny(sourceType)
	                            ? sourceType
	                            : isTupleLikeType(sourceType)
	                                ? getTypeOfPropertyOfType(sourceType, propName)
	                                : elementType;
	                        if (type) {
	                            checkDestructuringAssignment(e, type, contextualMapper);
	                        }
	                        else {
	                            if (isTupleType(sourceType)) {
	                                error(e, ts.Diagnostics.Tuple_type_0_with_length_1_cannot_be_assigned_to_tuple_with_length_2, typeToString(sourceType), sourceType.elementTypes.length, elements.length);
	                            }
	                            else {
	                                error(e, ts.Diagnostics.Type_0_has_no_property_1, typeToString(sourceType), propName);
	                            }
	                        }
	                    }
	                    else {
	                        if (i < elements.length - 1) {
	                            error(e, ts.Diagnostics.A_rest_element_must_be_last_in_an_array_destructuring_pattern);
	                        }
	                        else {
	                            var restExpression = e.expression;
	                            if (restExpression.kind === 184 /* BinaryExpression */ && restExpression.operatorToken.kind === 56 /* EqualsToken */) {
	                                error(restExpression.operatorToken, ts.Diagnostics.A_rest_element_cannot_have_an_initializer);
	                            }
	                            else {
	                                checkDestructuringAssignment(restExpression, createArrayType(elementType), contextualMapper);
	                            }
	                        }
	                    }
	                }
	            }
	            return sourceType;
	        }
	        function checkDestructuringAssignment(exprOrAssignment, sourceType, contextualMapper) {
	            var target;
	            if (exprOrAssignment.kind === 249 /* ShorthandPropertyAssignment */) {
	                var prop = exprOrAssignment;
	                if (prop.objectAssignmentInitializer) {
	                    checkBinaryLikeExpression(prop.name, prop.equalsToken, prop.objectAssignmentInitializer, contextualMapper);
	                }
	                target = exprOrAssignment.name;
	            }
	            else {
	                target = exprOrAssignment;
	            }
	            if (target.kind === 184 /* BinaryExpression */ && target.operatorToken.kind === 56 /* EqualsToken */) {
	                checkBinaryExpression(target, contextualMapper);
	                target = target.left;
	            }
	            if (target.kind === 168 /* ObjectLiteralExpression */) {
	                return checkObjectLiteralAssignment(target, sourceType, contextualMapper);
	            }
	            if (target.kind === 167 /* ArrayLiteralExpression */) {
	                return checkArrayLiteralAssignment(target, sourceType, contextualMapper);
	            }
	            return checkReferenceAssignment(target, sourceType, contextualMapper);
	        }
	        function checkReferenceAssignment(target, sourceType, contextualMapper) {
	            var targetType = checkExpression(target, contextualMapper);
	            if (checkReferenceExpression(target, ts.Diagnostics.Invalid_left_hand_side_of_assignment_expression, ts.Diagnostics.Left_hand_side_of_assignment_expression_cannot_be_a_constant)) {
	                checkTypeAssignableTo(sourceType, targetType, target, /*headMessage*/ undefined);
	            }
	            return sourceType;
	        }
	        function checkBinaryExpression(node, contextualMapper) {
	            return checkBinaryLikeExpression(node.left, node.operatorToken, node.right, contextualMapper, node);
	        }
	        function checkBinaryLikeExpression(left, operatorToken, right, contextualMapper, errorNode) {
	            var operator = operatorToken.kind;
	            if (operator === 56 /* EqualsToken */ && (left.kind === 168 /* ObjectLiteralExpression */ || left.kind === 167 /* ArrayLiteralExpression */)) {
	                return checkDestructuringAssignment(left, checkExpression(right, contextualMapper), contextualMapper);
	            }
	            var leftType = checkExpression(left, contextualMapper);
	            var rightType = checkExpression(right, contextualMapper);
	            switch (operator) {
	                case 37 /* AsteriskToken */:
	                case 38 /* AsteriskAsteriskToken */:
	                case 59 /* AsteriskEqualsToken */:
	                case 60 /* AsteriskAsteriskEqualsToken */:
	                case 39 /* SlashToken */:
	                case 61 /* SlashEqualsToken */:
	                case 40 /* PercentToken */:
	                case 62 /* PercentEqualsToken */:
	                case 36 /* MinusToken */:
	                case 58 /* MinusEqualsToken */:
	                case 43 /* LessThanLessThanToken */:
	                case 63 /* LessThanLessThanEqualsToken */:
	                case 44 /* GreaterThanGreaterThanToken */:
	                case 64 /* GreaterThanGreaterThanEqualsToken */:
	                case 45 /* GreaterThanGreaterThanGreaterThanToken */:
	                case 65 /* GreaterThanGreaterThanGreaterThanEqualsToken */:
	                case 47 /* BarToken */:
	                case 67 /* BarEqualsToken */:
	                case 48 /* CaretToken */:
	                case 68 /* CaretEqualsToken */:
	                case 46 /* AmpersandToken */:
	                case 66 /* AmpersandEqualsToken */:
	                    // TypeScript 1.0 spec (April 2014): 4.19.1
	                    // These operators require their operands to be of type Any, the Number primitive type,
	                    // or an enum type. Operands of an enum type are treated
	                    // as having the primitive type Number. If one operand is the null or undefined value,
	                    // it is treated as having the type of the other operand.
	                    // The result is always of the Number primitive type.
	                    if (leftType.flags & (32 /* Undefined */ | 64 /* Null */))
	                        leftType = rightType;
	                    if (rightType.flags & (32 /* Undefined */ | 64 /* Null */))
	                        rightType = leftType;
	                    var suggestedOperator = void 0;
	                    // if a user tries to apply a bitwise operator to 2 boolean operands
	                    // try and return them a helpful suggestion
	                    if ((leftType.flags & 8 /* Boolean */) &&
	                        (rightType.flags & 8 /* Boolean */) &&
	                        (suggestedOperator = getSuggestedBooleanOperator(operatorToken.kind)) !== undefined) {
	                        error(errorNode || operatorToken, ts.Diagnostics.The_0_operator_is_not_allowed_for_boolean_types_Consider_using_1_instead, ts.tokenToString(operatorToken.kind), ts.tokenToString(suggestedOperator));
	                    }
	                    else {
	                        // otherwise just check each operand separately and report errors as normal
	                        var leftOk = checkArithmeticOperandType(left, leftType, ts.Diagnostics.The_left_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_or_an_enum_type);
	                        var rightOk = checkArithmeticOperandType(right, rightType, ts.Diagnostics.The_right_hand_side_of_an_arithmetic_operation_must_be_of_type_any_number_or_an_enum_type);
	                        if (leftOk && rightOk) {
	                            checkAssignmentOperator(numberType);
	                        }
	                    }
	                    return numberType;
	                case 35 /* PlusToken */:
	                case 57 /* PlusEqualsToken */:
	                    // TypeScript 1.0 spec (April 2014): 4.19.2
	                    // The binary + operator requires both operands to be of the Number primitive type or an enum type,
	                    // or at least one of the operands to be of type Any or the String primitive type.
	                    // If one operand is the null or undefined value, it is treated as having the type of the other operand.
	                    if (leftType.flags & (32 /* Undefined */ | 64 /* Null */))
	                        leftType = rightType;
	                    if (rightType.flags & (32 /* Undefined */ | 64 /* Null */))
	                        rightType = leftType;
	                    var resultType = void 0;
	                    if (allConstituentTypesHaveKind(leftType, 132 /* NumberLike */) && allConstituentTypesHaveKind(rightType, 132 /* NumberLike */)) {
	                        // Operands of an enum type are treated as having the primitive type Number.
	                        // If both operands are of the Number primitive type, the result is of the Number primitive type.
	                        resultType = numberType;
	                    }
	                    else {
	                        if (allConstituentTypesHaveKind(leftType, 258 /* StringLike */) || allConstituentTypesHaveKind(rightType, 258 /* StringLike */)) {
	                            // If one or both operands are of the String primitive type, the result is of the String primitive type.
	                            resultType = stringType;
	                        }
	                        else if (isTypeAny(leftType) || isTypeAny(rightType)) {
	                            // Otherwise, the result is of type Any.
	                            // NOTE: unknown type here denotes error type. Old compiler treated this case as any type so do we.
	                            resultType = leftType === unknownType || rightType === unknownType ? unknownType : anyType;
	                        }
	                        // Symbols are not allowed at all in arithmetic expressions
	                        if (resultType && !checkForDisallowedESSymbolOperand(operator)) {
	                            return resultType;
	                        }
	                    }
	                    if (!resultType) {
	                        reportOperatorError();
	                        return anyType;
	                    }
	                    if (operator === 57 /* PlusEqualsToken */) {
	                        checkAssignmentOperator(resultType);
	                    }
	                    return resultType;
	                case 25 /* LessThanToken */:
	                case 27 /* GreaterThanToken */:
	                case 28 /* LessThanEqualsToken */:
	                case 29 /* GreaterThanEqualsToken */:
	                    if (!checkForDisallowedESSymbolOperand(operator)) {
	                        return booleanType;
	                    }
	                // Fall through
	                case 30 /* EqualsEqualsToken */:
	                case 31 /* ExclamationEqualsToken */:
	                case 32 /* EqualsEqualsEqualsToken */:
	                case 33 /* ExclamationEqualsEqualsToken */:
	                    // Permit 'number[] | "foo"' to be asserted to 'string'.
	                    if (someConstituentTypeHasKind(leftType, 258 /* StringLike */) && someConstituentTypeHasKind(rightType, 258 /* StringLike */)) {
	                        return booleanType;
	                    }
	                    if (!isTypeAssignableTo(leftType, rightType) && !isTypeAssignableTo(rightType, leftType)) {
	                        reportOperatorError();
	                    }
	                    return booleanType;
	                case 91 /* InstanceOfKeyword */:
	                    return checkInstanceOfExpression(left, right, leftType, rightType);
	                case 90 /* InKeyword */:
	                    return checkInExpression(left, right, leftType, rightType);
	                case 51 /* AmpersandAmpersandToken */:
	                    return rightType;
	                case 52 /* BarBarToken */:
	                    return getUnionType([leftType, rightType]);
	                case 56 /* EqualsToken */:
	                    checkAssignmentOperator(rightType);
	                    return getRegularTypeOfObjectLiteral(rightType);
	                case 24 /* CommaToken */:
	                    return rightType;
	            }
	            // Return true if there was no error, false if there was an error.
	            function checkForDisallowedESSymbolOperand(operator) {
	                var offendingSymbolOperand = someConstituentTypeHasKind(leftType, 16777216 /* ESSymbol */) ? left :
	                    someConstituentTypeHasKind(rightType, 16777216 /* ESSymbol */) ? right :
	                        undefined;
	                if (offendingSymbolOperand) {
	                    error(offendingSymbolOperand, ts.Diagnostics.The_0_operator_cannot_be_applied_to_type_symbol, ts.tokenToString(operator));
	                    return false;
	                }
	                return true;
	            }
	            function getSuggestedBooleanOperator(operator) {
	                switch (operator) {
	                    case 47 /* BarToken */:
	                    case 67 /* BarEqualsToken */:
	                        return 52 /* BarBarToken */;
	                    case 48 /* CaretToken */:
	                    case 68 /* CaretEqualsToken */:
	                        return 33 /* ExclamationEqualsEqualsToken */;
	                    case 46 /* AmpersandToken */:
	                    case 66 /* AmpersandEqualsToken */:
	                        return 51 /* AmpersandAmpersandToken */;
	                    default:
	                        return undefined;
	                }
	            }
	            function checkAssignmentOperator(valueType) {
	                if (produceDiagnostics && operator >= 56 /* FirstAssignment */ && operator <= 68 /* LastAssignment */) {
	                    // TypeScript 1.0 spec (April 2014): 4.17
	                    // An assignment of the form
	                    //    VarExpr = ValueExpr
	                    // requires VarExpr to be classified as a reference
	                    // A compound assignment furthermore requires VarExpr to be classified as a reference (section 4.1)
	                    // and the type of the non - compound operation to be assignable to the type of VarExpr.
	                    var ok = checkReferenceExpression(left, ts.Diagnostics.Invalid_left_hand_side_of_assignment_expression, ts.Diagnostics.Left_hand_side_of_assignment_expression_cannot_be_a_constant);
	                    // Use default messages
	                    if (ok) {
	                        // to avoid cascading errors check assignability only if 'isReference' check succeeded and no errors were reported
	                        checkTypeAssignableTo(valueType, leftType, left, /*headMessage*/ undefined);
	                    }
	                }
	            }
	            function reportOperatorError() {
	                error(errorNode || operatorToken, ts.Diagnostics.Operator_0_cannot_be_applied_to_types_1_and_2, ts.tokenToString(operatorToken.kind), typeToString(leftType), typeToString(rightType));
	            }
	        }
	        function isYieldExpressionInClass(node) {
	            var current = node;
	            var parent = node.parent;
	            while (parent) {
	                if (ts.isFunctionLike(parent) && current === parent.body) {
	                    return false;
	                }
	                else if (ts.isClassLike(current)) {
	                    return true;
	                }
	                current = parent;
	                parent = parent.parent;
	            }
	            return false;
	        }
	        function checkYieldExpression(node) {
	            // Grammar checking
	            if (produceDiagnostics) {
	                if (!(node.parserContextFlags & 2 /* Yield */) || isYieldExpressionInClass(node)) {
	                    grammarErrorOnFirstToken(node, ts.Diagnostics.A_yield_expression_is_only_allowed_in_a_generator_body);
	                }
	                if (isInParameterInitializerBeforeContainingFunction(node)) {
	                    error(node, ts.Diagnostics.yield_expressions_cannot_be_used_in_a_parameter_initializer);
	                }
	            }
	            if (node.expression) {
	                var func = ts.getContainingFunction(node);
	                // If the user's code is syntactically correct, the func should always have a star. After all,
	                // we are in a yield context.
	                if (func && func.asteriskToken) {
	                    var expressionType = checkExpressionCached(node.expression, /*contextualMapper*/ undefined);
	                    var expressionElementType = void 0;
	                    var nodeIsYieldStar = !!node.asteriskToken;
	                    if (nodeIsYieldStar) {
	                        expressionElementType = checkElementTypeOfIterable(expressionType, node.expression);
	                    }
	                    // There is no point in doing an assignability check if the function
	                    // has no explicit return type because the return type is directly computed
	                    // from the yield expressions.
	                    if (func.type) {
	                        var signatureElementType = getElementTypeOfIterableIterator(getTypeFromTypeNode(func.type)) || anyType;
	                        if (nodeIsYieldStar) {
	                            checkTypeAssignableTo(expressionElementType, signatureElementType, node.expression, /*headMessage*/ undefined);
	                        }
	                        else {
	                            checkTypeAssignableTo(expressionType, signatureElementType, node.expression, /*headMessage*/ undefined);
	                        }
	                    }
	                }
	            }
	            // Both yield and yield* expressions have type 'any'
	            return anyType;
	        }
	        function checkConditionalExpression(node, contextualMapper) {
	            checkExpression(node.condition);
	            var type1 = checkExpression(node.whenTrue, contextualMapper);
	            var type2 = checkExpression(node.whenFalse, contextualMapper);
	            return getUnionType([type1, type2]);
	        }
	        function checkStringLiteralExpression(node) {
	            var contextualType = getContextualType(node);
	            if (contextualType && contextualTypeIsStringLiteralType(contextualType)) {
	                return getStringLiteralTypeForText(node.text);
	            }
	            return stringType;
	        }
	        function checkTemplateExpression(node) {
	            // We just want to check each expressions, but we are unconcerned with
	            // the type of each expression, as any value may be coerced into a string.
	            // It is worth asking whether this is what we really want though.
	            // A place where we actually *are* concerned with the expressions' types are
	            // in tagged templates.
	            ts.forEach(node.templateSpans, function (templateSpan) {
	                checkExpression(templateSpan.expression);
	            });
	            return stringType;
	        }
	        function checkExpressionWithContextualType(node, contextualType, contextualMapper) {
	            var saveContextualType = node.contextualType;
	            node.contextualType = contextualType;
	            var result = checkExpression(node, contextualMapper);
	            node.contextualType = saveContextualType;
	            return result;
	        }
	        function checkExpressionCached(node, contextualMapper) {
	            var links = getNodeLinks(node);
	            if (!links.resolvedType) {
	                links.resolvedType = checkExpression(node, contextualMapper);
	            }
	            return links.resolvedType;
	        }
	        function checkPropertyAssignment(node, contextualMapper) {
	            // Do not use hasDynamicName here, because that returns false for well known symbols.
	            // We want to perform checkComputedPropertyName for all computed properties, including
	            // well known symbols.
	            if (node.name.kind === 137 /* ComputedPropertyName */) {
	                checkComputedPropertyName(node.name);
	            }
	            return checkExpression(node.initializer, contextualMapper);
	        }
	        function checkObjectLiteralMethod(node, contextualMapper) {
	            // Grammar checking
	            checkGrammarMethod(node);
	            // Do not use hasDynamicName here, because that returns false for well known symbols.
	            // We want to perform checkComputedPropertyName for all computed properties, including
	            // well known symbols.
	            if (node.name.kind === 137 /* ComputedPropertyName */) {
	                checkComputedPropertyName(node.name);
	            }
	            var uninstantiatedType = checkFunctionExpressionOrObjectLiteralMethod(node, contextualMapper);
	            return instantiateTypeWithSingleGenericCallSignature(node, uninstantiatedType, contextualMapper);
	        }
	        function instantiateTypeWithSingleGenericCallSignature(node, type, contextualMapper) {
	            if (isInferentialContext(contextualMapper)) {
	                var signature = getSingleCallSignature(type);
	                if (signature && signature.typeParameters) {
	                    var contextualType = getApparentTypeOfContextualType(node);
	                    if (contextualType) {
	                        var contextualSignature = getSingleCallSignature(contextualType);
	                        if (contextualSignature && !contextualSignature.typeParameters) {
	                            return getOrCreateTypeFromSignature(instantiateSignatureInContextOf(signature, contextualSignature, contextualMapper));
	                        }
	                    }
	                }
	            }
	            return type;
	        }
	        // Checks an expression and returns its type. The contextualMapper parameter serves two purposes: When
	        // contextualMapper is not undefined and not equal to the identityMapper function object it indicates that the
	        // expression is being inferentially typed (section 4.12.2 in spec) and provides the type mapper to use in
	        // conjunction with the generic contextual type. When contextualMapper is equal to the identityMapper function
	        // object, it serves as an indicator that all contained function and arrow expressions should be considered to
	        // have the wildcard function type; this form of type check is used during overload resolution to exclude
	        // contextually typed function and arrow expressions in the initial phase.
	        function checkExpression(node, contextualMapper) {
	            var type;
	            if (node.kind === 136 /* QualifiedName */) {
	                type = checkQualifiedName(node);
	            }
	            else {
	                var uninstantiatedType = checkExpressionWorker(node, contextualMapper);
	                type = instantiateTypeWithSingleGenericCallSignature(node, uninstantiatedType, contextualMapper);
	            }
	            if (isConstEnumObjectType(type)) {
	                // enum object type for const enums are only permitted in:
	                // - 'left' in property access
	                // - 'object' in indexed access
	                // - target in rhs of import statement
	                var ok = (node.parent.kind === 169 /* PropertyAccessExpression */ && node.parent.expression === node) ||
	                    (node.parent.kind === 170 /* ElementAccessExpression */ && node.parent.expression === node) ||
	                    ((node.kind === 69 /* Identifier */ || node.kind === 136 /* QualifiedName */) && isInRightSideOfImportOrExportAssignment(node));
	                if (!ok) {
	                    error(node, ts.Diagnostics.const_enums_can_only_be_used_in_property_or_index_access_expressions_or_the_right_hand_side_of_an_import_declaration_or_export_assignment);
	                }
	            }
	            return type;
	        }
	        function checkNumericLiteral(node) {
	            // Grammar checking
	            checkGrammarNumericLiteral(node);
	            return numberType;
	        }
	        function checkExpressionWorker(node, contextualMapper) {
	            switch (node.kind) {
	                case 69 /* Identifier */:
	                    return checkIdentifier(node);
	                case 97 /* ThisKeyword */:
	                    return checkThisExpression(node);
	                case 95 /* SuperKeyword */:
	                    return checkSuperExpression(node);
	                case 93 /* NullKeyword */:
	                    return nullType;
	                case 99 /* TrueKeyword */:
	                case 84 /* FalseKeyword */:
	                    return booleanType;
	                case 8 /* NumericLiteral */:
	                    return checkNumericLiteral(node);
	                case 186 /* TemplateExpression */:
	                    return checkTemplateExpression(node);
	                case 9 /* StringLiteral */:
	                    return checkStringLiteralExpression(node);
	                case 11 /* NoSubstitutionTemplateLiteral */:
	                    return stringType;
	                case 10 /* RegularExpressionLiteral */:
	                    return globalRegExpType;
	                case 167 /* ArrayLiteralExpression */:
	                    return checkArrayLiteral(node, contextualMapper);
	                case 168 /* ObjectLiteralExpression */:
	                    return checkObjectLiteral(node, contextualMapper);
	                case 169 /* PropertyAccessExpression */:
	                    return checkPropertyAccessExpression(node);
	                case 170 /* ElementAccessExpression */:
	                    return checkIndexedAccess(node);
	                case 171 /* CallExpression */:
	                case 172 /* NewExpression */:
	                    return checkCallExpression(node);
	                case 173 /* TaggedTemplateExpression */:
	                    return checkTaggedTemplateExpression(node);
	                case 175 /* ParenthesizedExpression */:
	                    return checkExpression(node.expression, contextualMapper);
	                case 189 /* ClassExpression */:
	                    return checkClassExpression(node);
	                case 176 /* FunctionExpression */:
	                case 177 /* ArrowFunction */:
	                    return checkFunctionExpressionOrObjectLiteralMethod(node, contextualMapper);
	                case 179 /* TypeOfExpression */:
	                    return checkTypeOfExpression(node);
	                case 174 /* TypeAssertionExpression */:
	                case 192 /* AsExpression */:
	                    return checkAssertion(node);
	                case 178 /* DeleteExpression */:
	                    return checkDeleteExpression(node);
	                case 180 /* VoidExpression */:
	                    return checkVoidExpression(node);
	                case 181 /* AwaitExpression */:
	                    return checkAwaitExpression(node);
	                case 182 /* PrefixUnaryExpression */:
	                    return checkPrefixUnaryExpression(node);
	                case 183 /* PostfixUnaryExpression */:
	                    return checkPostfixUnaryExpression(node);
	                case 184 /* BinaryExpression */:
	                    return checkBinaryExpression(node, contextualMapper);
	                case 185 /* ConditionalExpression */:
	                    return checkConditionalExpression(node, contextualMapper);
	                case 188 /* SpreadElementExpression */:
	                    return checkSpreadElementExpression(node, contextualMapper);
	                case 190 /* OmittedExpression */:
	                    return undefinedType;
	                case 187 /* YieldExpression */:
	                    return checkYieldExpression(node);
	                case 243 /* JsxExpression */:
	                    return checkJsxExpression(node);
	                case 236 /* JsxElement */:
	                    return checkJsxElement(node);
	                case 237 /* JsxSelfClosingElement */:
	                    return checkJsxSelfClosingElement(node);
	                case 238 /* JsxOpeningElement */:
	                    ts.Debug.fail("Shouldn't ever directly check a JsxOpeningElement");
	            }
	            return unknownType;
	        }
	        // DECLARATION AND STATEMENT TYPE CHECKING
	        function checkTypeParameter(node) {
	            // Grammar Checking
	            if (node.expression) {
	                grammarErrorOnFirstToken(node.expression, ts.Diagnostics.Type_expected);
	            }
	            checkSourceElement(node.constraint);
	            getConstraintOfTypeParameter(getDeclaredTypeOfTypeParameter(getSymbolOfNode(node)));
	            if (produceDiagnostics) {
	                checkTypeNameIsReserved(node.name, ts.Diagnostics.Type_parameter_name_cannot_be_0);
	            }
	        }
	        function checkParameter(node) {
	            // Grammar checking
	            // It is a SyntaxError if the Identifier "eval" or the Identifier "arguments" occurs as the
	            // Identifier in a PropertySetParameterList of a PropertyAssignment that is contained in strict code
	            // or if its FunctionBody is strict code(11.1.5).
	            // Grammar checking
	            checkGrammarDecorators(node) || checkGrammarModifiers(node);
	            checkVariableLikeDeclaration(node);
	            var func = ts.getContainingFunction(node);
	            if (node.flags & 56 /* AccessibilityModifier */) {
	                func = ts.getContainingFunction(node);
	                if (!(func.kind === 145 /* Constructor */ && ts.nodeIsPresent(func.body))) {
	                    error(node, ts.Diagnostics.A_parameter_property_is_only_allowed_in_a_constructor_implementation);
	                }
	            }
	            if (node.questionToken && ts.isBindingPattern(node.name) && func.body) {
	                error(node, ts.Diagnostics.A_binding_pattern_parameter_cannot_be_optional_in_an_implementation_signature);
	            }
	            // Only check rest parameter type if it's not a binding pattern. Since binding patterns are
	            // not allowed in a rest parameter, we already have an error from checkGrammarParameterList.
	            if (node.dotDotDotToken && !ts.isBindingPattern(node.name) && !isArrayType(getTypeOfSymbol(node.symbol))) {
	                error(node, ts.Diagnostics.A_rest_parameter_must_be_of_an_array_type);
	            }
	        }
	        function isSyntacticallyValidGenerator(node) {
	            if (!node.asteriskToken || !node.body) {
	                return false;
	            }
	            return node.kind === 144 /* MethodDeclaration */ ||
	                node.kind === 216 /* FunctionDeclaration */ ||
	                node.kind === 176 /* FunctionExpression */;
	        }
	        function getTypePredicateParameterIndex(parameterList, parameter) {
	            if (parameterList) {
	                for (var i = 0; i < parameterList.length; i++) {
	                    var param = parameterList[i];
	                    if (param.name.kind === 69 /* Identifier */ &&
	                        param.name.text === parameter.text) {
	                        return i;
	                    }
	                }
	            }
	            return -1;
	        }
	        function checkTypePredicate(node) {
	            var parent = getTypePredicateParent(node);
	            if (!parent) {
	                // The parent must not be valid.
	                error(node, ts.Diagnostics.A_type_predicate_is_only_allowed_in_return_type_position_for_functions_and_methods);
	                return;
	            }
	            var typePredicate = getSignatureFromDeclaration(parent).typePredicate;
	            if (!typePredicate) {
	                return;
	            }
	            var parameterName = node.parameterName;
	            if (ts.isThisTypePredicate(typePredicate)) {
	                getTypeFromThisTypeNode(parameterName);
	            }
	            else {
	                if (typePredicate.parameterIndex >= 0) {
	                    if (parent.parameters[typePredicate.parameterIndex].dotDotDotToken) {
	                        error(parameterName, ts.Diagnostics.A_type_predicate_cannot_reference_a_rest_parameter);
	                    }
	                    else {
	                        checkTypeAssignableTo(typePredicate.type, getTypeOfNode(parent.parameters[typePredicate.parameterIndex]), node.type);
	                    }
	                }
	                else if (parameterName) {
	                    var hasReportedError = false;
	                    for (var _i = 0, _a = parent.parameters; _i < _a.length; _i++) {
	                        var name_14 = _a[_i].name;
	                        if (ts.isBindingPattern(name_14) &&
	                            checkIfTypePredicateVariableIsDeclaredInBindingPattern(name_14, parameterName, typePredicate.parameterName)) {
	                            hasReportedError = true;
	                            break;
	                        }
	                    }
	                    if (!hasReportedError) {
	                        error(node.parameterName, ts.Diagnostics.Cannot_find_parameter_0, typePredicate.parameterName);
	                    }
	                }
	            }
	        }
	        function getTypePredicateParent(node) {
	            switch (node.parent.kind) {
	                case 177 /* ArrowFunction */:
	                case 148 /* CallSignature */:
	                case 216 /* FunctionDeclaration */:
	                case 176 /* FunctionExpression */:
	                case 153 /* FunctionType */:
	                case 144 /* MethodDeclaration */:
	                case 143 /* MethodSignature */:
	                    var parent_7 = node.parent;
	                    if (node === parent_7.type) {
	                        return parent_7;
	                    }
	            }
	        }
	        function checkIfTypePredicateVariableIsDeclaredInBindingPattern(pattern, predicateVariableNode, predicateVariableName) {
	            for (var _i = 0, _a = pattern.elements; _i < _a.length; _i++) {
	                var name_15 = _a[_i].name;
	                if (name_15.kind === 69 /* Identifier */ &&
	                    name_15.text === predicateVariableName) {
	                    error(predicateVariableNode, ts.Diagnostics.A_type_predicate_cannot_reference_element_0_in_a_binding_pattern, predicateVariableName);
	                    return true;
	                }
	                else if (name_15.kind === 165 /* ArrayBindingPattern */ ||
	                    name_15.kind === 164 /* ObjectBindingPattern */) {
	                    if (checkIfTypePredicateVariableIsDeclaredInBindingPattern(name_15, predicateVariableNode, predicateVariableName)) {
	                        return true;
	                    }
	                }
	            }
	        }
	        function checkSignatureDeclaration(node) {
	            // Grammar checking
	            if (node.kind === 150 /* IndexSignature */) {
	                checkGrammarIndexSignature(node);
	            }
	            else if (node.kind === 153 /* FunctionType */ || node.kind === 216 /* FunctionDeclaration */ || node.kind === 154 /* ConstructorType */ ||
	                node.kind === 148 /* CallSignature */ || node.kind === 145 /* Constructor */ ||
	                node.kind === 149 /* ConstructSignature */) {
	                checkGrammarFunctionLikeDeclaration(node);
	            }
	            checkTypeParameters(node.typeParameters);
	            ts.forEach(node.parameters, checkParameter);
	            if (node.type) {
	                checkSourceElement(node.type);
	            }
	            if (produceDiagnostics) {
	                checkCollisionWithArgumentsInGeneratedCode(node);
	                if (compilerOptions.noImplicitAny && !node.type) {
	                    switch (node.kind) {
	                        case 149 /* ConstructSignature */:
	                            error(node, ts.Diagnostics.Construct_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type);
	                            break;
	                        case 148 /* CallSignature */:
	                            error(node, ts.Diagnostics.Call_signature_which_lacks_return_type_annotation_implicitly_has_an_any_return_type);
	                            break;
	                    }
	                }
	                if (node.type) {
	                    if (languageVersion >= 2 /* ES6 */ && isSyntacticallyValidGenerator(node)) {
	                        var returnType = getTypeFromTypeNode(node.type);
	                        if (returnType === voidType) {
	                            error(node.type, ts.Diagnostics.A_generator_cannot_have_a_void_type_annotation);
	                        }
	                        else {
	                            var generatorElementType = getElementTypeOfIterableIterator(returnType) || anyType;
	                            var iterableIteratorInstantiation = createIterableIteratorType(generatorElementType);
	                            // Naively, one could check that IterableIterator<any> is assignable to the return type annotation.
	                            // However, that would not catch the error in the following case.
	                            //
	                            //    interface BadGenerator extends Iterable<number>, Iterator<string> { }
	                            //    function* g(): BadGenerator { } // Iterable and Iterator have different types!
	                            //
	                            checkTypeAssignableTo(iterableIteratorInstantiation, returnType, node.type);
	                        }
	                    }
	                    else if (ts.isAsyncFunctionLike(node)) {
	                        checkAsyncFunctionReturnType(node);
	                    }
	                }
	            }
	            checkSpecializedSignatureDeclaration(node);
	        }
	        function checkTypeForDuplicateIndexSignatures(node) {
	            if (node.kind === 218 /* InterfaceDeclaration */) {
	                var nodeSymbol = getSymbolOfNode(node);
	                // in case of merging interface declaration it is possible that we'll enter this check procedure several times for every declaration
	                // to prevent this run check only for the first declaration of a given kind
	                if (nodeSymbol.declarations.length > 0 && nodeSymbol.declarations[0] !== node) {
	                    return;
	                }
	            }
	            // TypeScript 1.0 spec (April 2014)
	            // 3.7.4: An object type can contain at most one string index signature and one numeric index signature.
	            // 8.5: A class declaration can have at most one string index member declaration and one numeric index member declaration
	            var indexSymbol = getIndexSymbol(getSymbolOfNode(node));
	            if (indexSymbol) {
	                var seenNumericIndexer = false;
	                var seenStringIndexer = false;
	                for (var _i = 0, _a = indexSymbol.declarations; _i < _a.length; _i++) {
	                    var decl = _a[_i];
	                    var declaration = decl;
	                    if (declaration.parameters.length === 1 && declaration.parameters[0].type) {
	                        switch (declaration.parameters[0].type.kind) {
	                            case 130 /* StringKeyword */:
	                                if (!seenStringIndexer) {
	                                    seenStringIndexer = true;
	                                }
	                                else {
	                                    error(declaration, ts.Diagnostics.Duplicate_string_index_signature);
	                                }
	                                break;
	                            case 128 /* NumberKeyword */:
	                                if (!seenNumericIndexer) {
	                                    seenNumericIndexer = true;
	                                }
	                                else {
	                                    error(declaration, ts.Diagnostics.Duplicate_number_index_signature);
	                                }
	                                break;
	                        }
	                    }
	                }
	            }
	        }
	        function checkPropertyDeclaration(node) {
	            // Grammar checking
	            checkGrammarDecorators(node) || checkGrammarModifiers(node) || checkGrammarProperty(node) || checkGrammarComputedPropertyName(node.name);
	            checkVariableLikeDeclaration(node);
	        }
	        function checkMethodDeclaration(node) {
	            // Grammar checking
	            checkGrammarMethod(node) || checkGrammarComputedPropertyName(node.name);
	            // Grammar checking for modifiers is done inside the function checkGrammarFunctionLikeDeclaration
	            checkFunctionOrMethodDeclaration(node);
	            // Abstract methods cannot have an implementation.
	            // Extra checks are to avoid reporting multiple errors relating to the "abstractness" of the node.
	            if (node.flags & 128 /* Abstract */ && node.body) {
	                error(node, ts.Diagnostics.Method_0_cannot_have_an_implementation_because_it_is_marked_abstract, ts.declarationNameToString(node.name));
	            }
	        }
	        function checkConstructorDeclaration(node) {
	            // Grammar check on signature of constructor and modifier of the constructor is done in checkSignatureDeclaration function.
	            checkSignatureDeclaration(node);
	            // Grammar check for checking only related to constructoDeclaration
	            checkGrammarConstructorTypeParameters(node) || checkGrammarConstructorTypeAnnotation(node);
	            checkSourceElement(node.body);
	            var symbol = getSymbolOfNode(node);
	            var firstDeclaration = ts.getDeclarationOfKind(symbol, node.kind);
	            // Only type check the symbol once
	            if (node === firstDeclaration) {
	                checkFunctionOrConstructorSymbol(symbol);
	            }
	            // exit early in the case of signature - super checks are not relevant to them
	            if (ts.nodeIsMissing(node.body)) {
	                return;
	            }
	            if (!produceDiagnostics) {
	                return;
	            }
	            function markThisReferencesAsErrors(n) {
	                if (n.kind === 97 /* ThisKeyword */) {
	                    error(n, ts.Diagnostics.this_cannot_be_referenced_in_current_location);
	                }
	                else if (n.kind !== 176 /* FunctionExpression */ && n.kind !== 216 /* FunctionDeclaration */) {
	                    ts.forEachChild(n, markThisReferencesAsErrors);
	                }
	            }
	            function isInstancePropertyWithInitializer(n) {
	                return n.kind === 142 /* PropertyDeclaration */ &&
	                    !(n.flags & 64 /* Static */) &&
	                    !!n.initializer;
	            }
	            // TS 1.0 spec (April 2014): 8.3.2
	            // Constructors of classes with no extends clause may not contain super calls, whereas
	            // constructors of derived classes must contain at least one super call somewhere in their function body.
	            var containingClassDecl = node.parent;
	            if (ts.getClassExtendsHeritageClauseElement(containingClassDecl)) {
	                var classExtendsNull = classDeclarationExtendsNull(containingClassDecl);
	                var superCall = getSuperCallInConstructor(node);
	                if (superCall) {
	                    if (classExtendsNull) {
	                        error(superCall, ts.Diagnostics.A_constructor_cannot_contain_a_super_call_when_its_class_extends_null);
	                    }
	                    // The first statement in the body of a constructor (excluding prologue directives) must be a super call
	                    // if both of the following are true:
	                    // - The containing class is a derived class.
	                    // - The constructor declares parameter properties
	                    //   or the containing class declares instance member variables with initializers.
	                    var superCallShouldBeFirst = ts.forEach(node.parent.members, isInstancePropertyWithInitializer) ||
	                        ts.forEach(node.parameters, function (p) { return p.flags & (8 /* Public */ | 16 /* Private */ | 32 /* Protected */); });
	                    // Skip past any prologue directives to find the first statement
	                    // to ensure that it was a super call.
	                    if (superCallShouldBeFirst) {
	                        var statements = node.body.statements;
	                        var superCallStatement = void 0;
	                        for (var _i = 0, statements_2 = statements; _i < statements_2.length; _i++) {
	                            var statement = statements_2[_i];
	                            if (statement.kind === 198 /* ExpressionStatement */ && ts.isSuperCallExpression(statement.expression)) {
	                                superCallStatement = statement;
	                                break;
	                            }
	                            if (!ts.isPrologueDirective(statement)) {
	                                break;
	                            }
	                        }
	                        if (!superCallStatement) {
	                            error(node, ts.Diagnostics.A_super_call_must_be_the_first_statement_in_the_constructor_when_a_class_contains_initialized_properties_or_has_parameter_properties);
	                        }
	                    }
	                }
	                else if (!classExtendsNull) {
	                    error(node, ts.Diagnostics.Constructors_for_derived_classes_must_contain_a_super_call);
	                }
	            }
	        }
	        function checkAccessorDeclaration(node) {
	            if (produceDiagnostics) {
	                // Grammar checking accessors
	                checkGrammarFunctionLikeDeclaration(node) || checkGrammarAccessor(node) || checkGrammarComputedPropertyName(node.name);
	                checkDecorators(node);
	                checkSignatureDeclaration(node);
	                if (node.kind === 146 /* GetAccessor */) {
	                    if (!ts.isInAmbientContext(node) && ts.nodeIsPresent(node.body) && (node.flags & 524288 /* HasImplicitReturn */)) {
	                        if (node.flags & 1048576 /* HasExplicitReturn */) {
	                            if (compilerOptions.noImplicitReturns) {
	                                error(node.name, ts.Diagnostics.Not_all_code_paths_return_a_value);
	                            }
	                        }
	                        else {
	                            error(node.name, ts.Diagnostics.A_get_accessor_must_return_a_value);
	                        }
	                    }
	                }
	                // Do not use hasDynamicName here, because that returns false for well known symbols.
	                // We want to perform checkComputedPropertyName for all computed properties, including
	                // well known symbols.
	                if (node.name.kind === 137 /* ComputedPropertyName */) {
	                    checkComputedPropertyName(node.name);
	                }
	                if (!ts.hasDynamicName(node)) {
	                    // TypeScript 1.0 spec (April 2014): 8.4.3
	                    // Accessors for the same member name must specify the same accessibility.
	                    var otherKind = node.kind === 146 /* GetAccessor */ ? 147 /* SetAccessor */ : 146 /* GetAccessor */;
	                    var otherAccessor = ts.getDeclarationOfKind(node.symbol, otherKind);
	                    if (otherAccessor) {
	                        if (((node.flags & 56 /* AccessibilityModifier */) !== (otherAccessor.flags & 56 /* AccessibilityModifier */))) {
	                            error(node.name, ts.Diagnostics.Getter_and_setter_accessors_do_not_agree_in_visibility);
	                        }
	                        var currentAccessorType = getAnnotatedAccessorType(node);
	                        var otherAccessorType = getAnnotatedAccessorType(otherAccessor);
	                        // TypeScript 1.0 spec (April 2014): 4.5
	                        // If both accessors include type annotations, the specified types must be identical.
	                        if (currentAccessorType && otherAccessorType) {
	                            if (!isTypeIdenticalTo(currentAccessorType, otherAccessorType)) {
	                                error(node, ts.Diagnostics.get_and_set_accessor_must_have_the_same_type);
	                            }
	                        }
	                    }
	                }
	                getTypeOfAccessors(getSymbolOfNode(node));
	            }
	            if (node.parent.kind !== 168 /* ObjectLiteralExpression */) {
	                checkSourceElement(node.body);
	            }
	            else {
	                checkNodeDeferred(node);
	            }
	        }
	        function checkAccessorDeferred(node) {
	            checkSourceElement(node.body);
	        }
	        function checkMissingDeclaration(node) {
	            checkDecorators(node);
	        }
	        function checkTypeArgumentConstraints(typeParameters, typeArgumentNodes) {
	            var typeArguments;
	            var mapper;
	            var result = true;
	            for (var i = 0; i < typeParameters.length; i++) {
	                var constraint = getConstraintOfTypeParameter(typeParameters[i]);
	                if (constraint) {
	                    if (!typeArguments) {
	                        typeArguments = ts.map(typeArgumentNodes, getTypeFromTypeNode);
	                        mapper = createTypeMapper(typeParameters, typeArguments);
	                    }
	                    var typeArgument = typeArguments[i];
	                    result = result && checkTypeAssignableTo(typeArgument, getTypeWithThisArgument(instantiateType(constraint, mapper), typeArgument), typeArgumentNodes[i], ts.Diagnostics.Type_0_does_not_satisfy_the_constraint_1);
	                }
	            }
	            return result;
	        }
	        function checkTypeReferenceNode(node) {
	            checkGrammarTypeArguments(node, node.typeArguments);
	            var type = getTypeFromTypeReference(node);
	            if (type !== unknownType && node.typeArguments) {
	                // Do type argument local checks only if referenced type is successfully resolved
	                ts.forEach(node.typeArguments, checkSourceElement);
	                if (produceDiagnostics) {
	                    var symbol = getNodeLinks(node).resolvedSymbol;
	                    var typeParameters = symbol.flags & 524288 /* TypeAlias */ ? getSymbolLinks(symbol).typeParameters : type.target.localTypeParameters;
	                    checkTypeArgumentConstraints(typeParameters, node.typeArguments);
	                }
	            }
	        }
	        function checkTypeQuery(node) {
	            getTypeFromTypeQueryNode(node);
	        }
	        function checkTypeLiteral(node) {
	            ts.forEach(node.members, checkSourceElement);
	            if (produceDiagnostics) {
	                var type = getTypeFromTypeLiteralOrFunctionOrConstructorTypeNode(node);
	                checkIndexConstraints(type);
	                checkTypeForDuplicateIndexSignatures(node);
	            }
	        }
	        function checkArrayType(node) {
	            checkSourceElement(node.elementType);
	        }
	        function checkTupleType(node) {
	            // Grammar checking
	            var hasErrorFromDisallowedTrailingComma = checkGrammarForDisallowedTrailingComma(node.elementTypes);
	            if (!hasErrorFromDisallowedTrailingComma && node.elementTypes.length === 0) {
	                grammarErrorOnNode(node, ts.Diagnostics.A_tuple_type_element_list_cannot_be_empty);
	            }
	            ts.forEach(node.elementTypes, checkSourceElement);
	        }
	        function checkUnionOrIntersectionType(node) {
	            ts.forEach(node.types, checkSourceElement);
	        }
	        function isPrivateWithinAmbient(node) {
	            return (node.flags & 16 /* Private */) && ts.isInAmbientContext(node);
	        }
	        function checkSpecializedSignatureDeclaration(signatureDeclarationNode) {
	            if (!produceDiagnostics) {
	                return;
	            }
	            var signature = getSignatureFromDeclaration(signatureDeclarationNode);
	            if (!signature.hasStringLiterals) {
	                return;
	            }
	            // TypeScript 1.0 spec (April 2014): 3.7.2.2
	            // Specialized signatures are not permitted in conjunction with a function body
	            if (ts.nodeIsPresent(signatureDeclarationNode.body)) {
	                error(signatureDeclarationNode, ts.Diagnostics.A_signature_with_an_implementation_cannot_use_a_string_literal_type);
	                return;
	            }
	            // TypeScript 1.0 spec (April 2014): 3.7.2.4
	            // Every specialized call or construct signature in an object type must be assignable
	            // to at least one non-specialized call or construct signature in the same object type
	            var signaturesToCheck;
	            // Unnamed (call\construct) signatures in interfaces are inherited and not shadowed so examining just node symbol won't give complete answer.
	            // Use declaring type to obtain full list of signatures.
	            if (!signatureDeclarationNode.name && signatureDeclarationNode.parent && signatureDeclarationNode.parent.kind === 218 /* InterfaceDeclaration */) {
	                ts.Debug.assert(signatureDeclarationNode.kind === 148 /* CallSignature */ || signatureDeclarationNode.kind === 149 /* ConstructSignature */);
	                var signatureKind = signatureDeclarationNode.kind === 148 /* CallSignature */ ? 0 /* Call */ : 1 /* Construct */;
	                var containingSymbol = getSymbolOfNode(signatureDeclarationNode.parent);
	                var containingType = getDeclaredTypeOfSymbol(containingSymbol);
	                signaturesToCheck = getSignaturesOfType(containingType, signatureKind);
	            }
	            else {
	                signaturesToCheck = getSignaturesOfSymbol(getSymbolOfNode(signatureDeclarationNode));
	            }
	            for (var _i = 0, signaturesToCheck_1 = signaturesToCheck; _i < signaturesToCheck_1.length; _i++) {
	                var otherSignature = signaturesToCheck_1[_i];
	                if (!otherSignature.hasStringLiterals && isSignatureAssignableTo(signature, otherSignature, /*ignoreReturnTypes*/ false)) {
	                    return;
	                }
	            }
	            error(signatureDeclarationNode, ts.Diagnostics.Specialized_overload_signature_is_not_assignable_to_any_non_specialized_signature);
	        }
	        function getEffectiveDeclarationFlags(n, flagsToCheck) {
	            var flags = ts.getCombinedNodeFlags(n);
	            // children of classes (even ambient classes) should not be marked as ambient or export
	            // because those flags have no useful semantics there.
	            if (n.parent.kind !== 218 /* InterfaceDeclaration */ &&
	                n.parent.kind !== 217 /* ClassDeclaration */ &&
	                n.parent.kind !== 189 /* ClassExpression */ &&
	                ts.isInAmbientContext(n)) {
	                if (!(flags & 4 /* Ambient */)) {
	                    // It is nested in an ambient context, which means it is automatically exported
	                    flags |= 2 /* Export */;
	                }
	                flags |= 4 /* Ambient */;
	            }
	            return flags & flagsToCheck;
	        }
	        function checkFunctionOrConstructorSymbol(symbol) {
	            if (!produceDiagnostics) {
	                return;
	            }
	            function getCanonicalOverload(overloads, implementation) {
	                // Consider the canonical set of flags to be the flags of the bodyDeclaration or the first declaration
	                // Error on all deviations from this canonical set of flags
	                // The caveat is that if some overloads are defined in lib.d.ts, we don't want to
	                // report the errors on those. To achieve this, we will say that the implementation is
	                // the canonical signature only if it is in the same container as the first overload
	                var implementationSharesContainerWithFirstOverload = implementation !== undefined && implementation.parent === overloads[0].parent;
	                return implementationSharesContainerWithFirstOverload ? implementation : overloads[0];
	            }
	            function checkFlagAgreementBetweenOverloads(overloads, implementation, flagsToCheck, someOverloadFlags, allOverloadFlags) {
	                // Error if some overloads have a flag that is not shared by all overloads. To find the
	                // deviations, we XOR someOverloadFlags with allOverloadFlags
	                var someButNotAllOverloadFlags = someOverloadFlags ^ allOverloadFlags;
	                if (someButNotAllOverloadFlags !== 0) {
	                    var canonicalFlags_1 = getEffectiveDeclarationFlags(getCanonicalOverload(overloads, implementation), flagsToCheck);
	                    ts.forEach(overloads, function (o) {
	                        var deviation = getEffectiveDeclarationFlags(o, flagsToCheck) ^ canonicalFlags_1;
	                        if (deviation & 2 /* Export */) {
	                            error(o.name, ts.Diagnostics.Overload_signatures_must_all_be_exported_or_not_exported);
	                        }
	                        else if (deviation & 4 /* Ambient */) {
	                            error(o.name, ts.Diagnostics.Overload_signatures_must_all_be_ambient_or_non_ambient);
	                        }
	                        else if (deviation & (16 /* Private */ | 32 /* Protected */)) {
	                            error(o.name, ts.Diagnostics.Overload_signatures_must_all_be_public_private_or_protected);
	                        }
	                        else if (deviation & 128 /* Abstract */) {
	                            error(o.name, ts.Diagnostics.Overload_signatures_must_all_be_abstract_or_not_abstract);
	                        }
	                    });
	                }
	            }
	            function checkQuestionTokenAgreementBetweenOverloads(overloads, implementation, someHaveQuestionToken, allHaveQuestionToken) {
	                if (someHaveQuestionToken !== allHaveQuestionToken) {
	                    var canonicalHasQuestionToken_1 = ts.hasQuestionToken(getCanonicalOverload(overloads, implementation));
	                    ts.forEach(overloads, function (o) {
	                        var deviation = ts.hasQuestionToken(o) !== canonicalHasQuestionToken_1;
	                        if (deviation) {
	                            error(o.name, ts.Diagnostics.Overload_signatures_must_all_be_optional_or_required);
	                        }
	                    });
	                }
	            }
	            var flagsToCheck = 2 /* Export */ | 4 /* Ambient */ | 16 /* Private */ | 32 /* Protected */ | 128 /* Abstract */;
	            var someNodeFlags = 0;
	            var allNodeFlags = flagsToCheck;
	            var someHaveQuestionToken = false;
	            var allHaveQuestionToken = true;
	            var hasOverloads = false;
	            var bodyDeclaration;
	            var lastSeenNonAmbientDeclaration;
	            var previousDeclaration;
	            var declarations = symbol.declarations;
	            var isConstructor = (symbol.flags & 16384 /* Constructor */) !== 0;
	            function reportImplementationExpectedError(node) {
	                if (node.name && ts.nodeIsMissing(node.name)) {
	                    return;
	                }
	                var seen = false;
	                var subsequentNode = ts.forEachChild(node.parent, function (c) {
	                    if (seen) {
	                        return c;
	                    }
	                    else {
	                        seen = c === node;
	                    }
	                });
	                // We may be here because of some extra junk between overloads that could not be parsed into a valid node.
	                // In this case the subsequent node is not really consecutive (.pos !== node.end), and we must ignore it here.
	                if (subsequentNode && subsequentNode.pos === node.end) {
	                    if (subsequentNode.kind === node.kind) {
	                        var errorNode_1 = subsequentNode.name || subsequentNode;
	                        // TODO(jfreeman): These are methods, so handle computed name case
	                        if (node.name && subsequentNode.name && node.name.text === subsequentNode.name.text) {
	                            var reportError = (node.kind === 144 /* MethodDeclaration */ || node.kind === 143 /* MethodSignature */) &&
	                                (node.flags & 64 /* Static */) !== (subsequentNode.flags & 64 /* Static */);
	                            // we can get here in two cases
	                            // 1. mixed static and instance class members
	                            // 2. something with the same name was defined before the set of overloads that prevents them from merging
	                            // here we'll report error only for the first case since for second we should already report error in binder
	                            if (reportError) {
	                                var diagnostic = node.flags & 64 /* Static */ ? ts.Diagnostics.Function_overload_must_be_static : ts.Diagnostics.Function_overload_must_not_be_static;
	                                error(errorNode_1, diagnostic);
	                            }
	                            return;
	                        }
	                        else if (ts.nodeIsPresent(subsequentNode.body)) {
	                            error(errorNode_1, ts.Diagnostics.Function_implementation_name_must_be_0, ts.declarationNameToString(node.name));
	                            return;
	                        }
	                    }
	                }
	                var errorNode = node.name || node;
	                if (isConstructor) {
	                    error(errorNode, ts.Diagnostics.Constructor_implementation_is_missing);
	                }
	                else {
	                    // Report different errors regarding non-consecutive blocks of declarations depending on whether
	                    // the node in question is abstract.
	                    if (node.flags & 128 /* Abstract */) {
	                        error(errorNode, ts.Diagnostics.All_declarations_of_an_abstract_method_must_be_consecutive);
	                    }
	                    else {
	                        error(errorNode, ts.Diagnostics.Function_implementation_is_missing_or_not_immediately_following_the_declaration);
	                    }
	                }
	            }
	            // when checking exported function declarations across modules check only duplicate implementations
	            // names and consistency of modifiers are verified when we check local symbol
	            var isExportSymbolInsideModule = symbol.parent && symbol.parent.flags & 1536 /* Module */;
	            var duplicateFunctionDeclaration = false;
	            var multipleConstructorImplementation = false;
	            for (var _i = 0, declarations_4 = declarations; _i < declarations_4.length; _i++) {
	                var current = declarations_4[_i];
	                var node = current;
	                var inAmbientContext = ts.isInAmbientContext(node);
	                var inAmbientContextOrInterface = node.parent.kind === 218 /* InterfaceDeclaration */ || node.parent.kind === 156 /* TypeLiteral */ || inAmbientContext;
	                if (inAmbientContextOrInterface) {
	                    // check if declarations are consecutive only if they are non-ambient
	                    // 1. ambient declarations can be interleaved
	                    // i.e. this is legal
	                    //     declare function foo();
	                    //     declare function bar();
	                    //     declare function foo();
	                    // 2. mixing ambient and non-ambient declarations is a separate error that will be reported - do not want to report an extra one
	                    previousDeclaration = undefined;
	                }
	                if (node.kind === 216 /* FunctionDeclaration */ || node.kind === 144 /* MethodDeclaration */ || node.kind === 143 /* MethodSignature */ || node.kind === 145 /* Constructor */) {
	                    var currentNodeFlags = getEffectiveDeclarationFlags(node, flagsToCheck);
	                    someNodeFlags |= currentNodeFlags;
	                    allNodeFlags &= currentNodeFlags;
	                    someHaveQuestionToken = someHaveQuestionToken || ts.hasQuestionToken(node);
	                    allHaveQuestionToken = allHaveQuestionToken && ts.hasQuestionToken(node);
	                    if (ts.nodeIsPresent(node.body) && bodyDeclaration) {
	                        if (isConstructor) {
	                            multipleConstructorImplementation = true;
	                        }
	                        else {
	                            duplicateFunctionDeclaration = true;
	                        }
	                    }
	                    else if (!isExportSymbolInsideModule && previousDeclaration && previousDeclaration.parent === node.parent && previousDeclaration.end !== node.pos) {
	                        reportImplementationExpectedError(previousDeclaration);
	                    }
	                    if (ts.nodeIsPresent(node.body)) {
	                        if (!bodyDeclaration) {
	                            bodyDeclaration = node;
	                        }
	                    }
	                    else {
	                        hasOverloads = true;
	                    }
	                    previousDeclaration = node;
	                    if (!inAmbientContextOrInterface) {
	                        lastSeenNonAmbientDeclaration = node;
	                    }
	                }
	            }
	            if (multipleConstructorImplementation) {
	                ts.forEach(declarations, function (declaration) {
	                    error(declaration, ts.Diagnostics.Multiple_constructor_implementations_are_not_allowed);
	                });
	            }
	            if (duplicateFunctionDeclaration) {
	                ts.forEach(declarations, function (declaration) {
	                    error(declaration.name, ts.Diagnostics.Duplicate_function_implementation);
	                });
	            }
	            // Abstract methods can't have an implementation -- in particular, they don't need one.
	            if (!isExportSymbolInsideModule && lastSeenNonAmbientDeclaration && !lastSeenNonAmbientDeclaration.body &&
	                !(lastSeenNonAmbientDeclaration.flags & 128 /* Abstract */)) {
	                reportImplementationExpectedError(lastSeenNonAmbientDeclaration);
	            }
	            if (hasOverloads) {
	                checkFlagAgreementBetweenOverloads(declarations, bodyDeclaration, flagsToCheck, someNodeFlags, allNodeFlags);
	                checkQuestionTokenAgreementBetweenOverloads(declarations, bodyDeclaration, someHaveQuestionToken, allHaveQuestionToken);
	                if (bodyDeclaration) {
	                    var signatures = getSignaturesOfSymbol(symbol);
	                    var bodySignature = getSignatureFromDeclaration(bodyDeclaration);
	                    // If the implementation signature has string literals, we will have reported an error in
	                    // checkSpecializedSignatureDeclaration
	                    if (!bodySignature.hasStringLiterals) {
	                        // TypeScript 1.0 spec (April 2014): 6.1
	                        // If a function declaration includes overloads, the overloads determine the call
	                        // signatures of the type given to the function object
	                        // and the function implementation signature must be assignable to that type
	                        //
	                        // TypeScript 1.0 spec (April 2014): 3.8.4
	                        // Note that specialized call and construct signatures (section 3.7.2.4) are not significant when determining assignment compatibility
	                        // Consider checking against specialized signatures too. Not doing so creates a type hole:
	                        //
	                        // function g(x: "hi", y: boolean);
	                        // function g(x: string, y: {});
	                        // function g(x: string, y: string) { }
	                        //
	                        // The implementation is completely unrelated to the specialized signature, yet we do not check this.
	                        for (var _a = 0, signatures_3 = signatures; _a < signatures_3.length; _a++) {
	                            var signature = signatures_3[_a];
	                            if (!signature.hasStringLiterals && !isImplementationCompatibleWithOverload(bodySignature, signature)) {
	                                error(signature.declaration, ts.Diagnostics.Overload_signature_is_not_compatible_with_function_implementation);
	                                break;
	                            }
	                        }
	                    }
	                }
	            }
	        }
	        function checkExportsOnMergedDeclarations(node) {
	            if (!produceDiagnostics) {
	                return;
	            }
	            // if localSymbol is defined on node then node itself is exported - check is required
	            var symbol = node.localSymbol;
	            if (!symbol) {
	                // local symbol is undefined => this declaration is non-exported.
	                // however symbol might contain other declarations that are exported
	                symbol = getSymbolOfNode(node);
	                if (!(symbol.flags & 7340032 /* Export */)) {
	                    // this is a pure local symbol (all declarations are non-exported) - no need to check anything
	                    return;
	                }
	            }
	            // run the check only for the first declaration in the list
	            if (ts.getDeclarationOfKind(symbol, node.kind) !== node) {
	                return;
	            }
	            // we use SymbolFlags.ExportValue, SymbolFlags.ExportType and SymbolFlags.ExportNamespace
	            // to denote disjoint declarationSpaces (without making new enum type).
	            var exportedDeclarationSpaces = 0 /* None */;
	            var nonExportedDeclarationSpaces = 0 /* None */;
	            var defaultExportedDeclarationSpaces = 0 /* None */;
	            for (var _i = 0, _a = symbol.declarations; _i < _a.length; _i++) {
	                var d = _a[_i];
	                var declarationSpaces = getDeclarationSpaces(d);
	                var effectiveDeclarationFlags = getEffectiveDeclarationFlags(d, 2 /* Export */ | 512 /* Default */);
	                if (effectiveDeclarationFlags & 2 /* Export */) {
	                    if (effectiveDeclarationFlags & 512 /* Default */) {
	                        defaultExportedDeclarationSpaces |= declarationSpaces;
	                    }
	                    else {
	                        exportedDeclarationSpaces |= declarationSpaces;
	                    }
	                }
	                else {
	                    nonExportedDeclarationSpaces |= declarationSpaces;
	                }
	            }
	            // Spaces for anyting not declared a 'default export'.
	            var nonDefaultExportedDeclarationSpaces = exportedDeclarationSpaces | nonExportedDeclarationSpaces;
	            var commonDeclarationSpacesForExportsAndLocals = exportedDeclarationSpaces & nonExportedDeclarationSpaces;
	            var commonDeclarationSpacesForDefaultAndNonDefault = defaultExportedDeclarationSpaces & nonDefaultExportedDeclarationSpaces;
	            if (commonDeclarationSpacesForExportsAndLocals || commonDeclarationSpacesForDefaultAndNonDefault) {
	                // declaration spaces for exported and non-exported declarations intersect
	                for (var _b = 0, _c = symbol.declarations; _b < _c.length; _b++) {
	                    var d = _c[_b];
	                    var declarationSpaces = getDeclarationSpaces(d);
	                    // Only error on the declarations that conributed to the intersecting spaces.
	                    if (declarationSpaces & commonDeclarationSpacesForDefaultAndNonDefault) {
	                        error(d.name, ts.Diagnostics.Merged_declaration_0_cannot_include_a_default_export_declaration_Consider_adding_a_separate_export_default_0_declaration_instead, ts.declarationNameToString(d.name));
	                    }
	                    else if (declarationSpaces & commonDeclarationSpacesForExportsAndLocals) {
	                        error(d.name, ts.Diagnostics.Individual_declarations_in_merged_declaration_0_must_be_all_exported_or_all_local, ts.declarationNameToString(d.name));
	                    }
	                }
	            }
	            function getDeclarationSpaces(d) {
	                switch (d.kind) {
	                    case 218 /* InterfaceDeclaration */:
	                        return 2097152 /* ExportType */;
	                    case 221 /* ModuleDeclaration */:
	                        return ts.isAmbientModule(d) || ts.getModuleInstanceState(d) !== 0 /* NonInstantiated */
	                            ? 4194304 /* ExportNamespace */ | 1048576 /* ExportValue */
	                            : 4194304 /* ExportNamespace */;
	                    case 217 /* ClassDeclaration */:
	                    case 220 /* EnumDeclaration */:
	                        return 2097152 /* ExportType */ | 1048576 /* ExportValue */;
	                    case 224 /* ImportEqualsDeclaration */:
	                        var result_2 = 0;
	                        var target = resolveAlias(getSymbolOfNode(d));
	                        ts.forEach(target.declarations, function (d) { result_2 |= getDeclarationSpaces(d); });
	                        return result_2;
	                    default:
	                        return 1048576 /* ExportValue */;
	                }
	            }
	        }
	        function checkNonThenableType(type, location, message) {
	            type = getWidenedType(type);
	            if (!isTypeAny(type) && isTypeAssignableTo(type, getGlobalThenableType())) {
	                if (location) {
	                    if (!message) {
	                        message = ts.Diagnostics.Operand_for_await_does_not_have_a_valid_callable_then_member;
	                    }
	                    error(location, message);
	                }
	                return unknownType;
	            }
	            return type;
	        }
	        /**
	          * Gets the "promised type" of a promise.
	          * @param type The type of the promise.
	          * @remarks The "promised type" of a type is the type of the "value" parameter of the "onfulfilled" callback.
	          */
	        function getPromisedType(promise) {
	            //
	            //  { // promise
	            //      then( // thenFunction
	            //          onfulfilled: ( // onfulfilledParameterType
	            //              value: T // valueParameterType
	            //          ) => any
	            //      ): any;
	            //  }
	            //
	            if (promise.flags & 1 /* Any */) {
	                return undefined;
	            }
	            if ((promise.flags & 4096 /* Reference */) && promise.target === tryGetGlobalPromiseType()) {
	                return promise.typeArguments[0];
	            }
	            var globalPromiseLikeType = getInstantiatedGlobalPromiseLikeType();
	            if (globalPromiseLikeType === emptyObjectType || !isTypeAssignableTo(promise, globalPromiseLikeType)) {
	                return undefined;
	            }
	            var thenFunction = getTypeOfPropertyOfType(promise, "then");
	            if (thenFunction && (thenFunction.flags & 1 /* Any */)) {
	                return undefined;
	            }
	            var thenSignatures = thenFunction ? getSignaturesOfType(thenFunction, 0 /* Call */) : emptyArray;
	            if (thenSignatures.length === 0) {
	                return undefined;
	            }
	            var onfulfilledParameterType = getUnionType(ts.map(thenSignatures, getTypeOfFirstParameterOfSignature));
	            if (onfulfilledParameterType.flags & 1 /* Any */) {
	                return undefined;
	            }
	            var onfulfilledParameterSignatures = getSignaturesOfType(onfulfilledParameterType, 0 /* Call */);
	            if (onfulfilledParameterSignatures.length === 0) {
	                return undefined;
	            }
	            var valueParameterType = getUnionType(ts.map(onfulfilledParameterSignatures, getTypeOfFirstParameterOfSignature));
	            return valueParameterType;
	        }
	        function getTypeOfFirstParameterOfSignature(signature) {
	            return getTypeAtPosition(signature, 0);
	        }
	        /**
	          * Gets the "awaited type" of a type.
	          * @param type The type to await.
	          * @remarks The "awaited type" of an expression is its "promised type" if the expression is a
	          * Promise-like type; otherwise, it is the type of the expression. This is used to reflect
	          * The runtime behavior of the `await` keyword.
	          */
	        function getAwaitedType(type) {
	            return checkAwaitedType(type, /*location*/ undefined, /*message*/ undefined);
	        }
	        function checkAwaitedType(type, location, message) {
	            return checkAwaitedTypeWorker(type);
	            function checkAwaitedTypeWorker(type) {
	                if (type.flags & 16384 /* Union */) {
	                    var types = [];
	                    for (var _i = 0, _a = type.types; _i < _a.length; _i++) {
	                        var constituentType = _a[_i];
	                        types.push(checkAwaitedTypeWorker(constituentType));
	                    }
	                    return getUnionType(types);
	                }
	                else {
	                    var promisedType = getPromisedType(type);
	                    if (promisedType === undefined) {
	                        // The type was not a PromiseLike, so it could not be unwrapped any further.
	                        // As long as the type does not have a callable "then" property, it is
	                        // safe to return the type; otherwise, an error will have been reported in
	                        // the call to checkNonThenableType and we will return unknownType.
	                        //
	                        // An example of a non-promise "thenable" might be:
	                        //
	                        //  await { then(): void {} }
	                        //
	                        // The "thenable" does not match the minimal definition for a PromiseLike. When
	                        // a Promise/A+-compatible or ES6 promise tries to adopt this value, the promise
	                        // will never settle. We treat this as an error to help flag an early indicator
	                        // of a runtime problem. If the user wants to return this value from an async
	                        // function, they would need to wrap it in some other value. If they want it to
	                        // be treated as a promise, they can cast to <any>.
	                        return checkNonThenableType(type, location, message);
	                    }
	                    else {
	                        if (type.id === promisedType.id || awaitedTypeStack.indexOf(promisedType.id) >= 0) {
	                            // We have a bad actor in the form of a promise whose promised type is
	                            // the same promise type, or a mutually recursive promise. Return the
	                            // unknown type as we cannot guess the shape. If this were the actual
	                            // case in the JavaScript, this Promise would never resolve.
	                            //
	                            // An example of a bad actor with a singly-recursive promise type might
	                            // be:
	                            //
	                            //  interface BadPromise {
	                            //      then(
	                            //          onfulfilled: (value: BadPromise) => any,
	                            //          onrejected: (error: any) => any): BadPromise;
	                            //  }
	                            //
	                            // The above interface will pass the PromiseLike check, and return a
	                            // promised type of `BadPromise`. Since this is a self reference, we
	                            // don't want to keep recursing ad infinitum.
	                            //
	                            // An example of a bad actor in the form of a mutually-recursive
	                            // promise type might be:
	                            //
	                            //  interface BadPromiseA {
	                            //      then(
	                            //          onfulfilled: (value: BadPromiseB) => any,
	                            //          onrejected: (error: any) => any): BadPromiseB;
	                            //  }
	                            //
	                            //  interface BadPromiseB {
	                            //      then(
	                            //          onfulfilled: (value: BadPromiseA) => any,
	                            //          onrejected: (error: any) => any): BadPromiseA;
	                            //  }
	                            //
	                            if (location) {
	                                error(location, ts.Diagnostics._0_is_referenced_directly_or_indirectly_in_the_fulfillment_callback_of_its_own_then_method, symbolToString(type.symbol));
	                            }
	                            return unknownType;
	                        }
	                        // Keep track of the type we're about to unwrap to avoid bad recursive promise types.
	                        // See the comments above for more information.
	                        awaitedTypeStack.push(type.id);
	                        var awaitedType = checkAwaitedTypeWorker(promisedType);
	                        awaitedTypeStack.pop();
	                        return awaitedType;
	                    }
	                }
	            }
	        }
	        /**
	         * Checks that the return type provided is an instantiation of the global Promise<T> type
	         * and returns the awaited type of the return type.
	         *
	         * @param returnType The return type of a FunctionLikeDeclaration
	         * @param location The node on which to report the error.
	         */
	        function checkCorrectPromiseType(returnType, location) {
	            if (returnType === unknownType) {
	                // The return type already had some other error, so we ignore and return
	                // the unknown type.
	                return unknownType;
	            }
	            var globalPromiseType = getGlobalPromiseType();
	            if (globalPromiseType === emptyGenericType
	                || globalPromiseType === getTargetType(returnType)) {
	                // Either we couldn't resolve the global promise type, which would have already
	                // reported an error, or we could resolve it and the return type is a valid type
	                // reference to the global type. In either case, we return the awaited type for
	                // the return type.
	                return checkAwaitedType(returnType, location, ts.Diagnostics.An_async_function_or_method_must_have_a_valid_awaitable_return_type);
	            }
	            // The promise type was not a valid type reference to the global promise type, so we
	            // report an error and return the unknown type.
	            error(location, ts.Diagnostics.The_return_type_of_an_async_function_or_method_must_be_the_global_Promise_T_type);
	            return unknownType;
	        }
	        /**
	          * Checks the return type of an async function to ensure it is a compatible
	          * Promise implementation.
	          * @param node The signature to check
	          * @param returnType The return type for the function
	          * @remarks
	          * This checks that an async function has a valid Promise-compatible return type,
	          * and returns the *awaited type* of the promise. An async function has a valid
	          * Promise-compatible return type if the resolved value of the return type has a
	          * construct signature that takes in an `initializer` function that in turn supplies
	          * a `resolve` function as one of its arguments and results in an object with a
	          * callable `then` signature.
	          */
	        function checkAsyncFunctionReturnType(node) {
	            if (compilerOptions.noCustomAsyncPromise && languageVersion >= 2 /* ES6 */) {
	                var returnType = getTypeFromTypeNode(node.type);
	                return checkCorrectPromiseType(returnType, node.type);
	            }
	            var globalPromiseConstructorLikeType = getGlobalPromiseConstructorLikeType();
	            if (globalPromiseConstructorLikeType === emptyObjectType) {
	                // If we couldn't resolve the global PromiseConstructorLike type we cannot verify
	                // compatibility with __awaiter.
	                return unknownType;
	            }
	            // As part of our emit for an async function, we will need to emit the entity name of
	            // the return type annotation as an expression. To meet the necessary runtime semantics
	            // for __awaiter, we must also check that the type of the declaration (e.g. the static
	            // side or "constructor" of the promise type) is compatible `PromiseConstructorLike`.
	            //
	            // An example might be (from lib.es6.d.ts):
	            //
	            //  interface Promise<T> { ... }
	            //  interface PromiseConstructor {
	            //      new <T>(...): Promise<T>;
	            //  }
	            //  declare var Promise: PromiseConstructor;
	            //
	            // When an async function declares a return type annotation of `Promise<T>`, we
	            // need to get the type of the `Promise` variable declaration above, which would
	            // be `PromiseConstructor`.
	            //
	            // The same case applies to a class:
	            //
	            //  declare class Promise<T> {
	            //      constructor(...);
	            //      then<U>(...): Promise<U>;
	            //  }
	            //
	            // When we get the type of the `Promise` symbol here, we get the type of the static
	            // side of the `Promise` class, which would be `{ new <T>(...): Promise<T> }`.
	            var promiseType = getTypeFromTypeNode(node.type);
	            if (promiseType === unknownType && compilerOptions.isolatedModules) {
	                // If we are compiling with isolatedModules, we may not be able to resolve the
	                // type as a value. As such, we will just return unknownType;
	                return unknownType;
	            }
	            var promiseConstructor = getNodeLinks(node.type).resolvedSymbol;
	            if (!promiseConstructor || !symbolIsValue(promiseConstructor)) {
	                var typeName = promiseConstructor
	                    ? symbolToString(promiseConstructor)
	                    : typeToString(promiseType);
	                error(node, ts.Diagnostics.Type_0_is_not_a_valid_async_function_return_type, typeName);
	                return unknownType;
	            }
	            // If the Promise constructor, resolved locally, is an alias symbol we should mark it as referenced.
	            checkReturnTypeAnnotationAsExpression(node);
	            // Validate the promise constructor type.
	            var promiseConstructorType = getTypeOfSymbol(promiseConstructor);
	            if (!checkTypeAssignableTo(promiseConstructorType, globalPromiseConstructorLikeType, node, ts.Diagnostics.Type_0_is_not_a_valid_async_function_return_type)) {
	                return unknownType;
	            }
	            // Verify there is no local declaration that could collide with the promise constructor.
	            var promiseName = ts.getEntityNameFromTypeNode(node.type);
	            var promiseNameOrNamespaceRoot = getFirstIdentifier(promiseName);
	            var rootSymbol = getSymbol(node.locals, promiseNameOrNamespaceRoot.text, 107455 /* Value */);
	            if (rootSymbol) {
	                error(rootSymbol.valueDeclaration, ts.Diagnostics.Duplicate_identifier_0_Compiler_uses_declaration_1_to_support_async_functions, promiseNameOrNamespaceRoot.text, getFullyQualifiedName(promiseConstructor));
	                return unknownType;
	            }
	            // Get and return the awaited type of the return type.
	            return checkAwaitedType(promiseType, node, ts.Diagnostics.An_async_function_or_method_must_have_a_valid_awaitable_return_type);
	        }
	        /** Check a decorator */
	        function checkDecorator(node) {
	            var signature = getResolvedSignature(node);
	            var returnType = getReturnTypeOfSignature(signature);
	            if (returnType.flags & 1 /* Any */) {
	                return;
	            }
	            var expectedReturnType;
	            var headMessage = getDiagnosticHeadMessageForDecoratorResolution(node);
	            var errorInfo;
	            switch (node.parent.kind) {
	                case 217 /* ClassDeclaration */:
	                    var classSymbol = getSymbolOfNode(node.parent);
	                    var classConstructorType = getTypeOfSymbol(classSymbol);
	                    expectedReturnType = getUnionType([classConstructorType, voidType]);
	                    break;
	                case 139 /* Parameter */:
	                    expectedReturnType = voidType;
	                    errorInfo = ts.chainDiagnosticMessages(errorInfo, ts.Diagnostics.The_return_type_of_a_parameter_decorator_function_must_be_either_void_or_any);
	                    break;
	                case 142 /* PropertyDeclaration */:
	                    expectedReturnType = voidType;
	                    errorInfo = ts.chainDiagnosticMessages(errorInfo, ts.Diagnostics.The_return_type_of_a_property_decorator_function_must_be_either_void_or_any);
	                    break;
	                case 144 /* MethodDeclaration */:
	                case 146 /* GetAccessor */:
	                case 147 /* SetAccessor */:
	                    var methodType = getTypeOfNode(node.parent);
	                    var descriptorType = createTypedPropertyDescriptorType(methodType);
	                    expectedReturnType = getUnionType([descriptorType, voidType]);
	                    break;
	            }
	            checkTypeAssignableTo(returnType, expectedReturnType, node, headMessage, errorInfo);
	        }
	        /** Checks a type reference node as an expression. */
	        function checkTypeNodeAsExpression(node) {
	            // When we are emitting type metadata for decorators, we need to try to check the type
	            // as if it were an expression so that we can emit the type in a value position when we
	            // serialize the type metadata.
	            if (node && node.kind === 152 /* TypeReference */) {
	                var root = getFirstIdentifier(node.typeName);
	                var meaning = root.parent.kind === 152 /* TypeReference */ ? 793056 /* Type */ : 1536 /* Namespace */;
	                // Resolve type so we know which symbol is referenced
	                var rootSymbol = resolveName(root, root.text, meaning | 8388608 /* Alias */, /*nameNotFoundMessage*/ undefined, /*nameArg*/ undefined);
	                // Resolved symbol is alias
	                if (rootSymbol && rootSymbol.flags & 8388608 /* Alias */) {
	                    var aliasTarget = resolveAlias(rootSymbol);
	                    // If alias has value symbol - mark alias as referenced
	                    if (aliasTarget.flags & 107455 /* Value */ && !isConstEnumOrConstEnumOnlyModule(resolveAlias(rootSymbol))) {
	                        markAliasSymbolAsReferenced(rootSymbol);
	                    }
	                }
	            }
	        }
	        /**
	          * Checks the type annotation of an accessor declaration or property declaration as
	          * an expression if it is a type reference to a type with a value declaration.
	          */
	        function checkTypeAnnotationAsExpression(node) {
	            checkTypeNodeAsExpression(node.type);
	        }
	        function checkReturnTypeAnnotationAsExpression(node) {
	            checkTypeNodeAsExpression(node.type);
	        }
	        /** Checks the type annotation of the parameters of a function/method or the constructor of a class as expressions */
	        function checkParameterTypeAnnotationsAsExpressions(node) {
	            // ensure all type annotations with a value declaration are checked as an expression
	            for (var _i = 0, _a = node.parameters; _i < _a.length; _i++) {
	                var parameter = _a[_i];
	                checkTypeAnnotationAsExpression(parameter);
	            }
	        }
	        /** Check the decorators of a node */
	        function checkDecorators(node) {
	            if (!node.decorators) {
	                return;
	            }
	            // skip this check for nodes that cannot have decorators. These should have already had an error reported by
	            // checkGrammarDecorators.
	            if (!ts.nodeCanBeDecorated(node)) {
	                return;
	            }
	            if (!compilerOptions.experimentalDecorators) {
	                error(node, ts.Diagnostics.Experimental_support_for_decorators_is_a_feature_that_is_subject_to_change_in_a_future_release_Set_the_experimentalDecorators_option_to_remove_this_warning);
	            }
	            if (compilerOptions.emitDecoratorMetadata) {
	                // we only need to perform these checks if we are emitting serialized type metadata for the target of a decorator.
	                switch (node.kind) {
	                    case 217 /* ClassDeclaration */:
	                        var constructor = ts.getFirstConstructorWithBody(node);
	                        if (constructor) {
	                            checkParameterTypeAnnotationsAsExpressions(constructor);
	                        }
	                        break;
	                    case 144 /* MethodDeclaration */:
	                    case 146 /* GetAccessor */:
	                    case 147 /* SetAccessor */:
	                        checkParameterTypeAnnotationsAsExpressions(node);
	                        checkReturnTypeAnnotationAsExpression(node);
	                        break;
	                    case 142 /* PropertyDeclaration */:
	                    case 139 /* Parameter */:
	                        checkTypeAnnotationAsExpression(node);
	                        break;
	                }
	            }
	            ts.forEach(node.decorators, checkDecorator);
	        }
	        function checkFunctionDeclaration(node) {
	            if (produceDiagnostics) {
	                checkFunctionOrMethodDeclaration(node) || checkGrammarForGenerator(node);
	                checkCollisionWithCapturedSuperVariable(node, node.name);
	                checkCollisionWithCapturedThisVariable(node, node.name);
	                checkCollisionWithRequireExportsInGeneratedCode(node, node.name);
	                checkCollisionWithGlobalPromiseInGeneratedCode(node, node.name);
	            }
	        }
	        function checkFunctionOrMethodDeclaration(node) {
	            checkDecorators(node);
	            checkSignatureDeclaration(node);
	            var isAsync = ts.isAsyncFunctionLike(node);
	            // Do not use hasDynamicName here, because that returns false for well known symbols.
	            // We want to perform checkComputedPropertyName for all computed properties, including
	            // well known symbols.
	            if (node.name && node.name.kind === 137 /* ComputedPropertyName */) {
	                // This check will account for methods in class/interface declarations,
	                // as well as accessors in classes/object literals
	                checkComputedPropertyName(node.name);
	            }
	            if (!ts.hasDynamicName(node)) {
	                // first we want to check the local symbol that contain this declaration
	                // - if node.localSymbol !== undefined - this is current declaration is exported and localSymbol points to the local symbol
	                // - if node.localSymbol === undefined - this node is non-exported so we can just pick the result of getSymbolOfNode
	                var symbol = getSymbolOfNode(node);
	                var localSymbol = node.localSymbol || symbol;
	                // Since the javascript won't do semantic analysis like typescript,
	                // if the javascript file comes before the typescript file and both contain same name functions,
	                // checkFunctionOrConstructorSymbol wouldn't be called if we didnt ignore javascript function.
	                var firstDeclaration = ts.forEach(localSymbol.declarations, 
	                // Get first non javascript function declaration
	                function (declaration) { return declaration.kind === node.kind && !ts.isSourceFileJavaScript(ts.getSourceFileOfNode(declaration)) ?
	                    declaration : undefined; });
	                // Only type check the symbol once
	                if (node === firstDeclaration) {
	                    checkFunctionOrConstructorSymbol(localSymbol);
	                }
	                if (symbol.parent) {
	                    // run check once for the first declaration
	                    if (ts.getDeclarationOfKind(symbol, node.kind) === node) {
	                        // run check on export symbol to check that modifiers agree across all exported declarations
	                        checkFunctionOrConstructorSymbol(symbol);
	                    }
	                }
	            }
	            checkSourceElement(node.body);
	            if (!node.asteriskToken) {
	                var returnOrPromisedType = node.type && (isAsync ? checkAsyncFunctionReturnType(node) : getTypeFromTypeNode(node.type));
	                checkAllCodePathsInNonVoidFunctionReturnOrThrow(node, returnOrPromisedType);
	            }
	            if (produceDiagnostics && !node.type) {
	                // Report an implicit any error if there is no body, no explicit return type, and node is not a private method
	                // in an ambient context
	                if (compilerOptions.noImplicitAny && ts.nodeIsMissing(node.body) && !isPrivateWithinAmbient(node)) {
	                    reportImplicitAnyError(node, anyType);
	                }
	                if (node.asteriskToken && ts.nodeIsPresent(node.body)) {
	                    // A generator with a body and no type annotation can still cause errors. It can error if the
	                    // yielded values have no common supertype, or it can give an implicit any error if it has no
	                    // yielded values. The only way to trigger these errors is to try checking its return type.
	                    getReturnTypeOfSignature(getSignatureFromDeclaration(node));
	                }
	            }
	        }
	        function checkBlock(node) {
	            // Grammar checking for SyntaxKind.Block
	            if (node.kind === 195 /* Block */) {
	                checkGrammarStatementInAmbientContext(node);
	            }
	            ts.forEach(node.statements, checkSourceElement);
	        }
	        function checkCollisionWithArgumentsInGeneratedCode(node) {
	            // no rest parameters \ declaration context \ overload - no codegen impact
	            if (!ts.hasRestParameter(node) || ts.isInAmbientContext(node) || ts.nodeIsMissing(node.body)) {
	                return;
	            }
	            ts.forEach(node.parameters, function (p) {
	                if (p.name && !ts.isBindingPattern(p.name) && p.name.text === argumentsSymbol.name) {
	                    error(p, ts.Diagnostics.Duplicate_identifier_arguments_Compiler_uses_arguments_to_initialize_rest_parameters);
	                }
	            });
	        }
	        function needCollisionCheckForIdentifier(node, identifier, name) {
	            if (!(identifier && identifier.text === name)) {
	                return false;
	            }
	            if (node.kind === 142 /* PropertyDeclaration */ ||
	                node.kind === 141 /* PropertySignature */ ||
	                node.kind === 144 /* MethodDeclaration */ ||
	                node.kind === 143 /* MethodSignature */ ||
	                node.kind === 146 /* GetAccessor */ ||
	                node.kind === 147 /* SetAccessor */) {
	                // it is ok to have member named '_super' or '_this' - member access is always qualified
	                return false;
	            }
	            if (ts.isInAmbientContext(node)) {
	                // ambient context - no codegen impact
	                return false;
	            }
	            var root = ts.getRootDeclaration(node);
	            if (root.kind === 139 /* Parameter */ && ts.nodeIsMissing(root.parent.body)) {
	                // just an overload - no codegen impact
	                return false;
	            }
	            return true;
	        }
	        function checkCollisionWithCapturedThisVariable(node, name) {
	            if (needCollisionCheckForIdentifier(node, name, "_this")) {
	                potentialThisCollisions.push(node);
	            }
	        }
	        // this function will run after checking the source file so 'CaptureThis' is correct for all nodes
	        function checkIfThisIsCapturedInEnclosingScope(node) {
	            var current = node;
	            while (current) {
	                if (getNodeCheckFlags(current) & 4 /* CaptureThis */) {
	                    var isDeclaration_1 = node.kind !== 69 /* Identifier */;
	                    if (isDeclaration_1) {
	                        error(node.name, ts.Diagnostics.Duplicate_identifier_this_Compiler_uses_variable_declaration_this_to_capture_this_reference);
	                    }
	                    else {
	                        error(node, ts.Diagnostics.Expression_resolves_to_variable_declaration_this_that_compiler_uses_to_capture_this_reference);
	                    }
	                    return;
	                }
	                current = current.parent;
	            }
	        }
	        function checkCollisionWithCapturedSuperVariable(node, name) {
	            if (!needCollisionCheckForIdentifier(node, name, "_super")) {
	                return;
	            }
	            // bubble up and find containing type
	            var enclosingClass = ts.getContainingClass(node);
	            // if containing type was not found or it is ambient - exit (no codegen)
	            if (!enclosingClass || ts.isInAmbientContext(enclosingClass)) {
	                return;
	            }
	            if (ts.getClassExtendsHeritageClauseElement(enclosingClass)) {
	                var isDeclaration_2 = node.kind !== 69 /* Identifier */;
	                if (isDeclaration_2) {
	                    error(node, ts.Diagnostics.Duplicate_identifier_super_Compiler_uses_super_to_capture_base_class_reference);
	                }
	                else {
	                    error(node, ts.Diagnostics.Expression_resolves_to_super_that_compiler_uses_to_capture_base_class_reference);
	                }
	            }
	        }
	        function checkCollisionWithRequireExportsInGeneratedCode(node, name) {
	            if (!needCollisionCheckForIdentifier(node, name, "require") && !needCollisionCheckForIdentifier(node, name, "exports")) {
	                return;
	            }
	            // Uninstantiated modules shouldnt do this check
	            if (node.kind === 221 /* ModuleDeclaration */ && ts.getModuleInstanceState(node) !== 1 /* Instantiated */) {
	                return;
	            }
	            // In case of variable declaration, node.parent is variable statement so look at the variable statement's parent
	            var parent = getDeclarationContainer(node);
	            if (parent.kind === 251 /* SourceFile */ && ts.isExternalOrCommonJsModule(parent)) {
	                // If the declaration happens to be in external module, report error that require and exports are reserved keywords
	                error(name, ts.Diagnostics.Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module, ts.declarationNameToString(name), ts.declarationNameToString(name));
	            }
	        }
	        function checkCollisionWithGlobalPromiseInGeneratedCode(node, name) {
	            if (!compilerOptions.noCustomAsyncPromise) {
	                return;
	            }
	            if (!needCollisionCheckForIdentifier(node, name, "Promise")) {
	                return;
	            }
	            // Uninstantiated modules shouldnt do this check
	            if (node.kind === 221 /* ModuleDeclaration */ && ts.getModuleInstanceState(node) !== 1 /* Instantiated */) {
	                return;
	            }
	            // In case of variable declaration, node.parent is variable statement so look at the variable statement's parent
	            var parent = getDeclarationContainer(node);
	            if (parent.kind === 251 /* SourceFile */ && ts.isExternalOrCommonJsModule(parent) && parent.flags & 33554432 /* HasAsyncFunctions */) {
	                // If the declaration happens to be in external module, report error that Promise is a reserved identifier.
	                error(name, ts.Diagnostics.Duplicate_identifier_0_Compiler_reserves_name_1_in_top_level_scope_of_a_module_containing_async_functions, ts.declarationNameToString(name), ts.declarationNameToString(name));
	            }
	        }
	        function checkVarDeclaredNamesNotShadowed(node) {
	            // - ScriptBody : StatementList
	            // It is a Syntax Error if any element of the LexicallyDeclaredNames of StatementList
	            // also occurs in the VarDeclaredNames of StatementList.
	            // - Block : { StatementList }
	            // It is a Syntax Error if any element of the LexicallyDeclaredNames of StatementList
	            // also occurs in the VarDeclaredNames of StatementList.
	            // Variable declarations are hoisted to the top of their function scope. They can shadow
	            // block scoped declarations, which bind tighter. this will not be flagged as duplicate definition
	            // by the binder as the declaration scope is different.
	            // A non-initialized declaration is a no-op as the block declaration will resolve before the var
	            // declaration. the problem is if the declaration has an initializer. this will act as a write to the
	            // block declared value. this is fine for let, but not const.
	            // Only consider declarations with initializers, uninitialized const declarations will not
	            // step on a let/const variable.
	            // Do not consider const and const declarations, as duplicate block-scoped declarations
	            // are handled by the binder.
	            // We are only looking for const declarations that step on let\const declarations from a
	            // different scope. e.g.:
	            //      {
	            //          const x = 0; // localDeclarationSymbol obtained after name resolution will correspond to this declaration
	            //          const x = 0; // symbol for this declaration will be 'symbol'
	            //      }
	            // skip block-scoped variables and parameters
	            if ((ts.getCombinedNodeFlags(node) & 24576 /* BlockScoped */) !== 0 || ts.isParameterDeclaration(node)) {
	                return;
	            }
	            // skip variable declarations that don't have initializers
	            // NOTE: in ES6 spec initializer is required in variable declarations where name is binding pattern
	            // so we'll always treat binding elements as initialized
	            if (node.kind === 214 /* VariableDeclaration */ && !node.initializer) {
	                return;
	            }
	            var symbol = getSymbolOfNode(node);
	            if (symbol.flags & 1 /* FunctionScopedVariable */) {
	                var localDeclarationSymbol = resolveName(node, node.name.text, 3 /* Variable */, /*nodeNotFoundErrorMessage*/ undefined, /*nameArg*/ undefined);
	                if (localDeclarationSymbol &&
	                    localDeclarationSymbol !== symbol &&
	                    localDeclarationSymbol.flags & 2 /* BlockScopedVariable */) {
	                    if (getDeclarationFlagsFromSymbol(localDeclarationSymbol) & 24576 /* BlockScoped */) {
	                        var varDeclList = ts.getAncestor(localDeclarationSymbol.valueDeclaration, 215 /* VariableDeclarationList */);
	                        var container = varDeclList.parent.kind === 196 /* VariableStatement */ && varDeclList.parent.parent
	                            ? varDeclList.parent.parent
	                            : undefined;
	                        // names of block-scoped and function scoped variables can collide only
	                        // if block scoped variable is defined in the function\module\source file scope (because of variable hoisting)
	                        var namesShareScope = container &&
	                            (container.kind === 195 /* Block */ && ts.isFunctionLike(container.parent) ||
	                                container.kind === 222 /* ModuleBlock */ ||
	                                container.kind === 221 /* ModuleDeclaration */ ||
	                                container.kind === 251 /* SourceFile */);
	                        // here we know that function scoped variable is shadowed by block scoped one
	                        // if they are defined in the same scope - binder has already reported redeclaration error
	                        // otherwise if variable has an initializer - show error that initialization will fail
	                        // since LHS will be block scoped name instead of function scoped
	                        if (!namesShareScope) {
	                            var name_16 = symbolToString(localDeclarationSymbol);
	                            error(node, ts.Diagnostics.Cannot_initialize_outer_scoped_variable_0_in_the_same_scope_as_block_scoped_declaration_1, name_16, name_16);
	                        }
	                    }
	                }
	            }
	        }
	        // Check that a parameter initializer contains no references to parameters declared to the right of itself
	        function checkParameterInitializer(node) {
	            if (ts.getRootDeclaration(node).kind !== 139 /* Parameter */) {
	                return;
	            }
	            var func = ts.getContainingFunction(node);
	            visit(node.initializer);
	            function visit(n) {
	                if (n.kind === 69 /* Identifier */) {
	                    var referencedSymbol = getNodeLinks(n).resolvedSymbol;
	                    // check FunctionLikeDeclaration.locals (stores parameters\function local variable)
	                    // if it contains entry with a specified name and if this entry matches the resolved symbol
	                    if (referencedSymbol && referencedSymbol !== unknownSymbol && getSymbol(func.locals, referencedSymbol.name, 107455 /* Value */) === referencedSymbol) {
	                        if (referencedSymbol.valueDeclaration.kind === 139 /* Parameter */) {
	                            if (referencedSymbol.valueDeclaration === node) {
	                                error(n, ts.Diagnostics.Parameter_0_cannot_be_referenced_in_its_initializer, ts.declarationNameToString(node.name));
	                                return;
	                            }
	                            if (referencedSymbol.valueDeclaration.pos < node.pos) {
	                                // legal case - parameter initializer references some parameter strictly on left of current parameter declaration
	                                return;
	                            }
	                        }
	                        error(n, ts.Diagnostics.Initializer_of_parameter_0_cannot_reference_identifier_1_declared_after_it, ts.declarationNameToString(node.name), ts.declarationNameToString(n));
	                    }
	                }
	                else {
	                    ts.forEachChild(n, visit);
	                }
	            }
	        }
	        // Check variable, parameter, or property declaration
	        function checkVariableLikeDeclaration(node) {
	            checkDecorators(node);
	            checkSourceElement(node.type);
	            // For a computed property, just check the initializer and exit
	            // Do not use hasDynamicName here, because that returns false for well known symbols.
	            // We want to perform checkComputedPropertyName for all computed properties, including
	            // well known symbols.
	            if (node.name.kind === 137 /* ComputedPropertyName */) {
	                checkComputedPropertyName(node.name);
	                if (node.initializer) {
	                    checkExpressionCached(node.initializer);
	                }
	            }
	            if (node.kind === 166 /* BindingElement */) {
	                // check computed properties inside property names of binding elements
	                if (node.propertyName && node.propertyName.kind === 137 /* ComputedPropertyName */) {
	                    checkComputedPropertyName(node.propertyName);
	                }
	            }
	            // For a binding pattern, check contained binding elements
	            if (ts.isBindingPattern(node.name)) {
	                ts.forEach(node.name.elements, checkSourceElement);
	            }
	            // For a parameter declaration with an initializer, error and exit if the containing function doesn't have a body
	            if (node.initializer && ts.getRootDeclaration(node).kind === 139 /* Parameter */ && ts.nodeIsMissing(ts.getContainingFunction(node).body)) {
	                error(node, ts.Diagnostics.A_parameter_initializer_is_only_allowed_in_a_function_or_constructor_implementation);
	                return;
	            }
	            // For a binding pattern, validate the initializer and exit
	            if (ts.isBindingPattern(node.name)) {
	                // Don't validate for-in initializer as it is already an error
	                if (node.initializer && node.parent.parent.kind !== 203 /* ForInStatement */) {
	                    checkTypeAssignableTo(checkExpressionCached(node.initializer), getWidenedTypeForVariableLikeDeclaration(node), node, /*headMessage*/ undefined);
	                    checkParameterInitializer(node);
	                }
	                return;
	            }
	            var symbol = getSymbolOfNode(node);
	            var type = getTypeOfVariableOrParameterOrProperty(symbol);
	            if (node === symbol.valueDeclaration) {
	                // Node is the primary declaration of the symbol, just validate the initializer
	                // Don't validate for-in initializer as it is already an error
	                if (node.initializer && node.parent.parent.kind !== 203 /* ForInStatement */) {
	                    checkTypeAssignableTo(checkExpressionCached(node.initializer), type, node, /*headMessage*/ undefined);
	                    checkParameterInitializer(node);
	                }
	            }
	            else {
	                // Node is a secondary declaration, check that type is identical to primary declaration and check that
	                // initializer is consistent with type associated with the node
	                var declarationType = getWidenedTypeForVariableLikeDeclaration(node);
	                if (type !== unknownType && declarationType !== unknownType && !isTypeIdenticalTo(type, declarationType)) {
	                    error(node.name, ts.Diagnostics.Subsequent_variable_declarations_must_have_the_same_type_Variable_0_must_be_of_type_1_but_here_has_type_2, ts.declarationNameToString(node.name), typeToString(type), typeToString(declarationType));
	                }
	                if (node.initializer) {
	                    checkTypeAssignableTo(checkExpressionCached(node.initializer), declarationType, node, /*headMessage*/ undefined);
	                }
	            }
	            if (node.kind !== 142 /* PropertyDeclaration */ && node.kind !== 141 /* PropertySignature */) {
	                // We know we don't have a binding pattern or computed name here
	                checkExportsOnMergedDeclarations(node);
	                if (node.kind === 214 /* VariableDeclaration */ || node.kind === 166 /* BindingElement */) {
	                    checkVarDeclaredNamesNotShadowed(node);
	                }
	                checkCollisionWithCapturedSuperVariable(node, node.name);
	                checkCollisionWithCapturedThisVariable(node, node.name);
	                checkCollisionWithRequireExportsInGeneratedCode(node, node.name);
	                checkCollisionWithGlobalPromiseInGeneratedCode(node, node.name);
	            }
	        }
	        function checkVariableDeclaration(node) {
	            checkGrammarVariableDeclaration(node);
	            return checkVariableLikeDeclaration(node);
	        }
	        function checkBindingElement(node) {
	            checkGrammarBindingElement(node);
	            return checkVariableLikeDeclaration(node);
	        }
	        function checkVariableStatement(node) {
	            // Grammar checking
	            checkGrammarDecorators(node) || checkGrammarModifiers(node) || checkGrammarVariableDeclarationList(node.declarationList) || checkGrammarForDisallowedLetOrConstStatement(node);
	            ts.forEach(node.declarationList.declarations, checkSourceElement);
	        }
	        function checkGrammarDisallowedModifiersOnObjectLiteralExpressionMethod(node) {
	            // We only disallow modifier on a method declaration if it is a property of object-literal-expression
	            if (node.modifiers && node.parent.kind === 168 /* ObjectLiteralExpression */) {
	                if (ts.isAsyncFunctionLike(node)) {
	                    if (node.modifiers.length > 1) {
	                        return grammarErrorOnFirstToken(node, ts.Diagnostics.Modifiers_cannot_appear_here);
	                    }
	                }
	                else {
	                    return grammarErrorOnFirstToken(node, ts.Diagnostics.Modifiers_cannot_appear_here);
	                }
	            }
	        }
	        function checkExpressionStatement(node) {
	            // Grammar checking
	            checkGrammarStatementInAmbientContext(node);
	            checkExpression(node.expression);
	        }
	        function checkIfStatement(node) {
	            // Grammar checking
	            checkGrammarStatementInAmbientContext(node);
	            checkExpression(node.expression);
	            checkSourceElement(node.thenStatement);
	            if (node.thenStatement.kind === 197 /* EmptyStatement */) {
	                error(node.thenStatement, ts.Diagnostics.The_body_of_an_if_statement_cannot_be_the_empty_statement);
	            }
	            checkSourceElement(node.elseStatement);
	        }
	        function checkDoStatement(node) {
	            // Grammar checking
	            checkGrammarStatementInAmbientContext(node);
	            checkSourceElement(node.statement);
	            checkExpression(node.expression);
	        }
	        function checkWhileStatement(node) {
	            // Grammar checking
	            checkGrammarStatementInAmbientContext(node);
	            checkExpression(node.expression);
	            checkSourceElement(node.statement);
	        }
	        function checkForStatement(node) {
	            // Grammar checking
	            if (!checkGrammarStatementInAmbientContext(node)) {
	                if (node.initializer && node.initializer.kind === 215 /* VariableDeclarationList */) {
	                    checkGrammarVariableDeclarationList(node.initializer);
	                }
	            }
	            if (node.initializer) {
	                if (node.initializer.kind === 215 /* VariableDeclarationList */) {
	                    ts.forEach(node.initializer.declarations, checkVariableDeclaration);
	                }
	                else {
	                    checkExpression(node.initializer);
	                }
	            }
	            if (node.condition)
	                checkExpression(node.condition);
	            if (node.incrementor)
	                checkExpression(node.incrementor);
	            checkSourceElement(node.statement);
	        }
	        function checkForOfStatement(node) {
	            checkGrammarForInOrForOfStatement(node);
	            // Check the LHS and RHS
	            // If the LHS is a declaration, just check it as a variable declaration, which will in turn check the RHS
	            // via checkRightHandSideOfForOf.
	            // If the LHS is an expression, check the LHS, as a destructuring assignment or as a reference.
	            // Then check that the RHS is assignable to it.
	            if (node.initializer.kind === 215 /* VariableDeclarationList */) {
	                checkForInOrForOfVariableDeclaration(node);
	            }
	            else {
	                var varExpr = node.initializer;
	                var iteratedType = checkRightHandSideOfForOf(node.expression);
	                // There may be a destructuring assignment on the left side
	                if (varExpr.kind === 167 /* ArrayLiteralExpression */ || varExpr.kind === 168 /* ObjectLiteralExpression */) {
	                    // iteratedType may be undefined. In this case, we still want to check the structure of
	                    // varExpr, in particular making sure it's a valid LeftHandSideExpression. But we'd like
	                    // to short circuit the type relation checking as much as possible, so we pass the unknownType.
	                    checkDestructuringAssignment(varExpr, iteratedType || unknownType);
	                }
	                else {
	                    var leftType = checkExpression(varExpr);
	                    checkReferenceExpression(varExpr, /*invalidReferenceMessage*/ ts.Diagnostics.Invalid_left_hand_side_in_for_of_statement, 
	                    /*constantVariableMessage*/ ts.Diagnostics.The_left_hand_side_of_a_for_of_statement_cannot_be_a_previously_defined_constant);
	                    // iteratedType will be undefined if the rightType was missing properties/signatures
	                    // required to get its iteratedType (like [Symbol.iterator] or next). This may be
	                    // because we accessed properties from anyType, or it may have led to an error inside
	                    // getElementTypeOfIterable.
	                    if (iteratedType) {
	                        checkTypeAssignableTo(iteratedType, leftType, varExpr, /*headMessage*/ undefined);
	                    }
	                }
	            }
	            checkSourceElement(node.statement);
	        }
	        function checkForInStatement(node) {
	            // Grammar checking
	            checkGrammarForInOrForOfStatement(node);
	            // TypeScript 1.0 spec  (April 2014): 5.4
	            // In a 'for-in' statement of the form
	            // for (let VarDecl in Expr) Statement
	            //   VarDecl must be a variable declaration without a type annotation that declares a variable of type Any,
	            //   and Expr must be an expression of type Any, an object type, or a type parameter type.
	            if (node.initializer.kind === 215 /* VariableDeclarationList */) {
	                var variable = node.initializer.declarations[0];
	                if (variable && ts.isBindingPattern(variable.name)) {
	                    error(variable.name, ts.Diagnostics.The_left_hand_side_of_a_for_in_statement_cannot_be_a_destructuring_pattern);
	                }
	                checkForInOrForOfVariableDeclaration(node);
	            }
	            else {
	                // In a 'for-in' statement of the form
	                // for (Var in Expr) Statement
	                //   Var must be an expression classified as a reference of type Any or the String primitive type,
	                //   and Expr must be an expression of type Any, an object type, or a type parameter type.
	                var varExpr = node.initializer;
	                var leftType = checkExpression(varExpr);
	                if (varExpr.kind === 167 /* ArrayLiteralExpression */ || varExpr.kind === 168 /* ObjectLiteralExpression */) {
	                    error(varExpr, ts.Diagnostics.The_left_hand_side_of_a_for_in_statement_cannot_be_a_destructuring_pattern);
	                }
	                else if (!isTypeAnyOrAllConstituentTypesHaveKind(leftType, 258 /* StringLike */)) {
	                    error(varExpr, ts.Diagnostics.The_left_hand_side_of_a_for_in_statement_must_be_of_type_string_or_any);
	                }
	                else {
	                    // run check only former check succeeded to avoid cascading errors
	                    checkReferenceExpression(varExpr, ts.Diagnostics.Invalid_left_hand_side_in_for_in_statement, ts.Diagnostics.The_left_hand_side_of_a_for_in_statement_cannot_be_a_previously_defined_constant);
	                }
	            }
	            var rightType = checkExpression(node.expression);
	            // unknownType is returned i.e. if node.expression is identifier whose name cannot be resolved
	            // in this case error about missing name is already reported - do not report extra one
	            if (!isTypeAnyOrAllConstituentTypesHaveKind(rightType, 80896 /* ObjectType */ | 512 /* TypeParameter */)) {
	                error(node.expression, ts.Diagnostics.The_right_hand_side_of_a_for_in_statement_must_be_of_type_any_an_object_type_or_a_type_parameter);
	            }
	            checkSourceElement(node.statement);
	        }
	        function checkForInOrForOfVariableDeclaration(iterationStatement) {
	            var variableDeclarationList = iterationStatement.initializer;
	            // checkGrammarForInOrForOfStatement will check that there is exactly one declaration.
	            if (variableDeclarationList.declarations.length >= 1) {
	                var decl = variableDeclarationList.declarations[0];
	                checkVariableDeclaration(decl);
	            }
	        }
	        function checkRightHandSideOfForOf(rhsExpression) {
	            var expressionType = getTypeOfExpression(rhsExpression);
	            return checkIteratedTypeOrElementType(expressionType, rhsExpression, /*allowStringInput*/ true);
	        }
	        function checkIteratedTypeOrElementType(inputType, errorNode, allowStringInput) {
	            if (isTypeAny(inputType)) {
	                return inputType;
	            }
	            if (languageVersion >= 2 /* ES6 */) {
	                return checkElementTypeOfIterable(inputType, errorNode);
	            }
	            if (allowStringInput) {
	                return checkElementTypeOfArrayOrString(inputType, errorNode);
	            }
	            if (isArrayLikeType(inputType)) {
	                var indexType = getIndexTypeOfType(inputType, 1 /* Number */);
	                if (indexType) {
	                    return indexType;
	                }
	            }
	            error(errorNode, ts.Diagnostics.Type_0_is_not_an_array_type, typeToString(inputType));
	            return unknownType;
	        }
	        /**
	         * When errorNode is undefined, it means we should not report any errors.
	         */
	        function checkElementTypeOfIterable(iterable, errorNode) {
	            var elementType = getElementTypeOfIterable(iterable, errorNode);
	            // Now even though we have extracted the iteratedType, we will have to validate that the type
	            // passed in is actually an Iterable.
	            if (errorNode && elementType) {
	                checkTypeAssignableTo(iterable, createIterableType(elementType), errorNode);
	            }
	            return elementType || anyType;
	        }
	        /**
	         * We want to treat type as an iterable, and get the type it is an iterable of. The iterable
	         * must have the following structure (annotated with the names of the variables below):
	         *
	         * { // iterable
	         *     [Symbol.iterator]: { // iteratorFunction
	         *         (): Iterator<T>
	         *     }
	         * }
	         *
	         * T is the type we are after. At every level that involves analyzing return types
	         * of signatures, we union the return types of all the signatures.
	         *
	         * Another thing to note is that at any step of this process, we could run into a dead end,
	         * meaning either the property is missing, or we run into the anyType. If either of these things
	         * happens, we return undefined to signal that we could not find the iterated type. If a property
	         * is missing, and the previous step did not result in 'any', then we also give an error if the
	         * caller requested it. Then the caller can decide what to do in the case where there is no iterated
	         * type. This is different from returning anyType, because that would signify that we have matched the
	         * whole pattern and that T (above) is 'any'.
	         */
	        function getElementTypeOfIterable(type, errorNode) {
	            if (isTypeAny(type)) {
	                return undefined;
	            }
	            var typeAsIterable = type;
	            if (!typeAsIterable.iterableElementType) {
	                // As an optimization, if the type is instantiated directly using the globalIterableType (Iterable<number>),
	                // then just grab its type argument.
	                if ((type.flags & 4096 /* Reference */) && type.target === globalIterableType) {
	                    typeAsIterable.iterableElementType = type.typeArguments[0];
	                }
	                else {
	                    var iteratorFunction = getTypeOfPropertyOfType(type, ts.getPropertyNameForKnownSymbolName("iterator"));
	                    if (isTypeAny(iteratorFunction)) {
	                        return undefined;
	                    }
	                    var iteratorFunctionSignatures = iteratorFunction ? getSignaturesOfType(iteratorFunction, 0 /* Call */) : emptyArray;
	                    if (iteratorFunctionSignatures.length === 0) {
	                        if (errorNode) {
	                            error(errorNode, ts.Diagnostics.Type_must_have_a_Symbol_iterator_method_that_returns_an_iterator);
	                        }
	                        return undefined;
	                    }
	                    typeAsIterable.iterableElementType = getElementTypeOfIterator(getUnionType(ts.map(iteratorFunctionSignatures, getReturnTypeOfSignature)), errorNode);
	                }
	            }
	            return typeAsIterable.iterableElementType;
	        }
	        /**
	         * This function has very similar logic as getElementTypeOfIterable, except that it operates on
	         * Iterators instead of Iterables. Here is the structure:
	         *
	         *  { // iterator
	         *      next: { // iteratorNextFunction
	         *          (): { // iteratorNextResult
	         *              value: T // iteratorNextValue
	         *          }
	         *      }
	         *  }
	         *
	         */
	        function getElementTypeOfIterator(type, errorNode) {
	            if (isTypeAny(type)) {
	                return undefined;
	            }
	            var typeAsIterator = type;
	            if (!typeAsIterator.iteratorElementType) {
	                // As an optimization, if the type is instantiated directly using the globalIteratorType (Iterator<number>),
	                // then just grab its type argument.
	                if ((type.flags & 4096 /* Reference */) && type.target === globalIteratorType) {
	                    typeAsIterator.iteratorElementType = type.typeArguments[0];
	                }
	                else {
	                    var iteratorNextFunction = getTypeOfPropertyOfType(type, "next");
	                    if (isTypeAny(iteratorNextFunction)) {
	                        return undefined;
	                    }
	                    var iteratorNextFunctionSignatures = iteratorNextFunction ? getSignaturesOfType(iteratorNextFunction, 0 /* Call */) : emptyArray;
	                    if (iteratorNextFunctionSignatures.length === 0) {
	                        if (errorNode) {
	                            error(errorNode, ts.Diagnostics.An_iterator_must_have_a_next_method);
	                        }
	                        return undefined;
	                    }
	                    var iteratorNextResult = getUnionType(ts.map(iteratorNextFunctionSignatures, getReturnTypeOfSignature));
	                    if (isTypeAny(iteratorNextResult)) {
	                        return undefined;
	                    }
	                    var iteratorNextValue = getTypeOfPropertyOfType(iteratorNextResult, "value");
	                    if (!iteratorNextValue) {
	                        if (errorNode) {
	                            error(errorNode, ts.Diagnostics.The_type_returned_by_the_next_method_of_an_iterator_must_have_a_value_property);
	                        }
	                        return undefined;
	                    }
	                    typeAsIterator.iteratorElementType = iteratorNextValue;
	                }
	            }
	            return typeAsIterator.iteratorElementType;
	        }
	        function getElementTypeOfIterableIterator(type) {
	            if (isTypeAny(type)) {
	                return undefined;
	            }
	            // As an optimization, if the type is instantiated directly using the globalIterableIteratorType (IterableIterator<number>),
	            // then just grab its type argument.
	            if ((type.flags & 4096 /* Reference */) && type.target === globalIterableIteratorType) {
	                return type.typeArguments[0];
	            }
	            return getElementTypeOfIterable(type, /*errorNode*/ undefined) ||
	                getElementTypeOfIterator(type, /*errorNode*/ undefined);
	        }
	        /**
	         * This function does the following steps:
	         *   1. Break up arrayOrStringType (possibly a union) into its string constituents and array constituents.
	         *   2. Take the element types of the array constituents.
	         *   3. Return the union of the element types, and string if there was a string constitutent.
	         *
	         * For example:
	         *     string -> string
	         *     number[] -> number
	         *     string[] | number[] -> string | number
	         *     string | number[] -> string | number
	         *     string | string[] | number[] -> string | number
	         *
	         * It also errors if:
	         *   1. Some constituent is neither a string nor an array.
	         *   2. Some constituent is a string and target is less than ES5 (because in ES3 string is not indexable).
	         */
	        function checkElementTypeOfArrayOrString(arrayOrStringType, errorNode) {
	            ts.Debug.assert(languageVersion < 2 /* ES6 */);
	            // After we remove all types that are StringLike, we will know if there was a string constituent
	            // based on whether the remaining type is the same as the initial type.
	            var arrayType = arrayOrStringType;
	            if (arrayOrStringType.flags & 16384 /* Union */) {
	                arrayType = getUnionType(ts.filter(arrayOrStringType.types, function (t) { return !(t.flags & 258 /* StringLike */); }));
	            }
	            else if (arrayOrStringType.flags & 258 /* StringLike */) {
	                arrayType = emptyUnionType;
	            }
	            var hasStringConstituent = arrayOrStringType !== arrayType;
	            var reportedError = false;
	            if (hasStringConstituent) {
	                if (languageVersion < 1 /* ES5 */) {
	                    error(errorNode, ts.Diagnostics.Using_a_string_in_a_for_of_statement_is_only_supported_in_ECMAScript_5_and_higher);
	                    reportedError = true;
	                }
	                // Now that we've removed all the StringLike types, if no constituents remain, then the entire
	                // arrayOrStringType was a string.
	                if (arrayType === emptyObjectType) {
	                    return stringType;
	                }
	            }
	            if (!isArrayLikeType(arrayType)) {
	                if (!reportedError) {
	                    // Which error we report depends on whether there was a string constituent. For example,
	                    // if the input type is number | string, we want to say that number is not an array type.
	                    // But if the input was just number, we want to say that number is not an array type
	                    // or a string type.
	                    var diagnostic = hasStringConstituent
	                        ? ts.Diagnostics.Type_0_is_not_an_array_type
	                        : ts.Diagnostics.Type_0_is_not_an_array_type_or_a_string_type;
	                    error(errorNode, diagnostic, typeToString(arrayType));
	                }
	                return hasStringConstituent ? stringType : unknownType;
	            }
	            var arrayElementType = getIndexTypeOfType(arrayType, 1 /* Number */) || unknownType;
	            if (hasStringConstituent) {
	                // This is just an optimization for the case where arrayOrStringType is string | string[]
	                if (arrayElementType.flags & 258 /* StringLike */) {
	                    return stringType;
	                }
	                return getUnionType([arrayElementType, stringType]);
	            }
	            return arrayElementType;
	        }
	        function checkBreakOrContinueStatement(node) {
	            // Grammar checking
	            checkGrammarStatementInAmbientContext(node) || checkGrammarBreakOrContinueStatement(node);
	            // TODO: Check that target label is valid
	        }
	        function isGetAccessorWithAnnotatatedSetAccessor(node) {
	            return !!(node.kind === 146 /* GetAccessor */ && ts.getSetAccessorTypeAnnotationNode(ts.getDeclarationOfKind(node.symbol, 147 /* SetAccessor */)));
	        }
	        function checkReturnStatement(node) {
	            // Grammar checking
	            if (!checkGrammarStatementInAmbientContext(node)) {
	                var functionBlock = ts.getContainingFunction(node);
	                if (!functionBlock) {
	                    grammarErrorOnFirstToken(node, ts.Diagnostics.A_return_statement_can_only_be_used_within_a_function_body);
	                }
	            }
	            if (node.expression) {
	                var func = ts.getContainingFunction(node);
	                if (func) {
	                    var signature = getSignatureFromDeclaration(func);
	                    var returnType = getReturnTypeOfSignature(signature);
	                    var exprType = checkExpressionCached(node.expression);
	                    if (func.asteriskToken) {
	                        // A generator does not need its return expressions checked against its return type.
	                        // Instead, the yield expressions are checked against the element type.
	                        // TODO: Check return expressions of generators when return type tracking is added
	                        // for generators.
	                        return;
	                    }
	                    if (func.kind === 147 /* SetAccessor */) {
	                        error(node.expression, ts.Diagnostics.Setters_cannot_return_a_value);
	                    }
	                    else if (func.kind === 145 /* Constructor */) {
	                        if (!checkTypeAssignableTo(exprType, returnType, node.expression)) {
	                            error(node.expression, ts.Diagnostics.Return_type_of_constructor_signature_must_be_assignable_to_the_instance_type_of_the_class);
	                        }
	                    }
	                    else if (func.type || isGetAccessorWithAnnotatatedSetAccessor(func)) {
	                        if (ts.isAsyncFunctionLike(func)) {
	                            var promisedType = getPromisedType(returnType);
	                            var awaitedType = checkAwaitedType(exprType, node.expression, ts.Diagnostics.Return_expression_in_async_function_does_not_have_a_valid_callable_then_member);
	                            if (promisedType) {
	                                // If the function has a return type, but promisedType is
	                                // undefined, an error will be reported in checkAsyncFunctionReturnType
	                                // so we don't need to report one here.
	                                checkTypeAssignableTo(awaitedType, promisedType, node.expression);
	                            }
	                        }
	                        else {
	                            checkTypeAssignableTo(exprType, returnType, node.expression);
	                        }
	                    }
	                }
	            }
	        }
	        function checkWithStatement(node) {
	            // Grammar checking for withStatement
	            if (!checkGrammarStatementInAmbientContext(node)) {
	                if (node.parserContextFlags & 8 /* Await */) {
	                    grammarErrorOnFirstToken(node, ts.Diagnostics.with_statements_are_not_allowed_in_an_async_function_block);
	                }
	            }
	            checkExpression(node.expression);
	            error(node.expression, ts.Diagnostics.All_symbols_within_a_with_block_will_be_resolved_to_any);
	        }
	        function checkSwitchStatement(node) {
	            // Grammar checking
	            checkGrammarStatementInAmbientContext(node);
	            var firstDefaultClause;
	            var hasDuplicateDefaultClause = false;
	            var expressionType = checkExpression(node.expression);
	            var expressionTypeIsStringLike = someConstituentTypeHasKind(expressionType, 258 /* StringLike */);
	            ts.forEach(node.caseBlock.clauses, function (clause) {
	                // Grammar check for duplicate default clauses, skip if we already report duplicate default clause
	                if (clause.kind === 245 /* DefaultClause */ && !hasDuplicateDefaultClause) {
	                    if (firstDefaultClause === undefined) {
	                        firstDefaultClause = clause;
	                    }
	                    else {
	                        var sourceFile = ts.getSourceFileOfNode(node);
	                        var start = ts.skipTrivia(sourceFile.text, clause.pos);
	                        var end = clause.statements.length > 0 ? clause.statements[0].pos : clause.end;
	                        grammarErrorAtPos(sourceFile, start, end - start, ts.Diagnostics.A_default_clause_cannot_appear_more_than_once_in_a_switch_statement);
	                        hasDuplicateDefaultClause = true;
	                    }
	                }
	                if (produceDiagnostics && clause.kind === 244 /* CaseClause */) {
	                    var caseClause = clause;
	                    // TypeScript 1.0 spec (April 2014):5.9
	                    // In a 'switch' statement, each 'case' expression must be of a type that is assignable to or from the type of the 'switch' expression.
	                    var caseType = checkExpression(caseClause.expression);
	                    var expressionTypeIsAssignableToCaseType = 
	                    // Permit 'number[] | "foo"' to be asserted to 'string'.
	                    (expressionTypeIsStringLike && someConstituentTypeHasKind(caseType, 258 /* StringLike */)) ||
	                        isTypeAssignableTo(expressionType, caseType);
	                    if (!expressionTypeIsAssignableToCaseType) {
	                        // 'expressionType is not assignable to caseType', try the reversed check and report errors if it fails
	                        checkTypeAssignableTo(caseType, expressionType, caseClause.expression, /*headMessage*/ undefined);
	                    }
	                }
	                ts.forEach(clause.statements, checkSourceElement);
	            });
	        }
	        function checkLabeledStatement(node) {
	            // Grammar checking
	            if (!checkGrammarStatementInAmbientContext(node)) {
	                var current = node.parent;
	                while (current) {
	                    if (ts.isFunctionLike(current)) {
	                        break;
	                    }
	                    if (current.kind === 210 /* LabeledStatement */ && current.label.text === node.label.text) {
	                        var sourceFile = ts.getSourceFileOfNode(node);
	                        grammarErrorOnNode(node.label, ts.Diagnostics.Duplicate_label_0, ts.getTextOfNodeFromSourceText(sourceFile.text, node.label));
	                        break;
	                    }
	                    current = current.parent;
	                }
	            }
	            // ensure that label is unique
	            checkSourceElement(node.statement);
	        }
	        function checkThrowStatement(node) {
	            // Grammar checking
	            if (!checkGrammarStatementInAmbientContext(node)) {
	                if (node.expression === undefined) {
	                    grammarErrorAfterFirstToken(node, ts.Diagnostics.Line_break_not_permitted_here);
	                }
	            }
	            if (node.expression) {
	                checkExpression(node.expression);
	            }
	        }
	        function checkTryStatement(node) {
	            // Grammar checking
	            checkGrammarStatementInAmbientContext(node);
	            checkBlock(node.tryBlock);
	            var catchClause = node.catchClause;
	            if (catchClause) {
	                // Grammar checking
	                if (catchClause.variableDeclaration) {
	                    if (catchClause.variableDeclaration.name.kind !== 69 /* Identifier */) {
	                        grammarErrorOnFirstToken(catchClause.variableDeclaration.name, ts.Diagnostics.Catch_clause_variable_name_must_be_an_identifier);
	                    }
	                    else if (catchClause.variableDeclaration.type) {
	                        grammarErrorOnFirstToken(catchClause.variableDeclaration.type, ts.Diagnostics.Catch_clause_variable_cannot_have_a_type_annotation);
	                    }
	                    else if (catchClause.variableDeclaration.initializer) {
	                        grammarErrorOnFirstToken(catchClause.variableDeclaration.initializer, ts.Diagnostics.Catch_clause_variable_cannot_have_an_initializer);
	                    }
	                    else {
	                        var identifierName = catchClause.variableDeclaration.name.text;
	                        var locals = catchClause.block.locals;
	                        if (locals && ts.hasProperty(locals, identifierName)) {
	                            var localSymbol = locals[identifierName];
	                            if (localSymbol && (localSymbol.flags & 2 /* BlockScopedVariable */) !== 0) {
	                                grammarErrorOnNode(localSymbol.valueDeclaration, ts.Diagnostics.Cannot_redeclare_identifier_0_in_catch_clause, identifierName);
	                            }
	                        }
	                    }
	                }
	                checkBlock(catchClause.block);
	            }
	            if (node.finallyBlock) {
	                checkBlock(node.finallyBlock);
	            }
	        }
	        function checkIndexConstraints(type) {
	            var declaredNumberIndexer = getIndexDeclarationOfSymbol(type.symbol, 1 /* Number */);
	            var declaredStringIndexer = getIndexDeclarationOfSymbol(type.symbol, 0 /* String */);
	            var stringIndexType = getIndexTypeOfType(type, 0 /* String */);
	            var numberIndexType = getIndexTypeOfType(type, 1 /* Number */);
	            if (stringIndexType || numberIndexType) {
	                ts.forEach(getPropertiesOfObjectType(type), function (prop) {
	                    var propType = getTypeOfSymbol(prop);
	                    checkIndexConstraintForProperty(prop, propType, type, declaredStringIndexer, stringIndexType, 0 /* String */);
	                    checkIndexConstraintForProperty(prop, propType, type, declaredNumberIndexer, numberIndexType, 1 /* Number */);
	                });
	                if (type.flags & 1024 /* Class */ && ts.isClassLike(type.symbol.valueDeclaration)) {
	                    var classDeclaration = type.symbol.valueDeclaration;
	                    for (var _i = 0, _a = classDeclaration.members; _i < _a.length; _i++) {
	                        var member = _a[_i];
	                        // Only process instance properties with computed names here.
	                        // Static properties cannot be in conflict with indexers,
	                        // and properties with literal names were already checked.
	                        if (!(member.flags & 64 /* Static */) && ts.hasDynamicName(member)) {
	                            var propType = getTypeOfSymbol(member.symbol);
	                            checkIndexConstraintForProperty(member.symbol, propType, type, declaredStringIndexer, stringIndexType, 0 /* String */);
	                            checkIndexConstraintForProperty(member.symbol, propType, type, declaredNumberIndexer, numberIndexType, 1 /* Number */);
	                        }
	                    }
	                }
	            }
	            var errorNode;
	            if (stringIndexType && numberIndexType) {
	                errorNode = declaredNumberIndexer || declaredStringIndexer;
	                // condition 'errorNode === undefined' may appear if types does not declare nor string neither number indexer
	                if (!errorNode && (type.flags & 2048 /* Interface */)) {
	                    var someBaseTypeHasBothIndexers = ts.forEach(getBaseTypes(type), function (base) { return getIndexTypeOfType(base, 0 /* String */) && getIndexTypeOfType(base, 1 /* Number */); });
	                    errorNode = someBaseTypeHasBothIndexers ? undefined : type.symbol.declarations[0];
	                }
	            }
	            if (errorNode && !isTypeAssignableTo(numberIndexType, stringIndexType)) {
	                error(errorNode, ts.Diagnostics.Numeric_index_type_0_is_not_assignable_to_string_index_type_1, typeToString(numberIndexType), typeToString(stringIndexType));
	            }
	            function checkIndexConstraintForProperty(prop, propertyType, containingType, indexDeclaration, indexType, indexKind) {
	                if (!indexType) {
	                    return;
	                }
	                // index is numeric and property name is not valid numeric literal
	                if (indexKind === 1 /* Number */ && !isNumericName(prop.valueDeclaration.name)) {
	                    return;
	                }
	                // perform property check if property or indexer is declared in 'type'
	                // this allows to rule out cases when both property and indexer are inherited from the base class
	                var errorNode;
	                if (prop.valueDeclaration.name.kind === 137 /* ComputedPropertyName */ || prop.parent === containingType.symbol) {
	                    errorNode = prop.valueDeclaration;
	                }
	                else if (indexDeclaration) {
	                    errorNode = indexDeclaration;
	                }
	                else if (containingType.flags & 2048 /* Interface */) {
	                    // for interfaces property and indexer might be inherited from different bases
	                    // check if any base class already has both property and indexer.
	                    // check should be performed only if 'type' is the first type that brings property\indexer together
	                    var someBaseClassHasBothPropertyAndIndexer = ts.forEach(getBaseTypes(containingType), function (base) { return getPropertyOfObjectType(base, prop.name) && getIndexTypeOfType(base, indexKind); });
	                    errorNode = someBaseClassHasBothPropertyAndIndexer ? undefined : containingType.symbol.declarations[0];
	                }
	                if (errorNode && !isTypeAssignableTo(propertyType, indexType)) {
	                    var errorMessage = indexKind === 0 /* String */
	                        ? ts.Diagnostics.Property_0_of_type_1_is_not_assignable_to_string_index_type_2
	                        : ts.Diagnostics.Property_0_of_type_1_is_not_assignable_to_numeric_index_type_2;
	                    error(errorNode, errorMessage, symbolToString(prop), typeToString(propertyType), typeToString(indexType));
	                }
	            }
	        }
	        function checkTypeNameIsReserved(name, message) {
	            // TS 1.0 spec (April 2014): 3.6.1
	            // The predefined type keywords are reserved and cannot be used as names of user defined types.
	            switch (name.text) {
	                case "any":
	                case "number":
	                case "boolean":
	                case "string":
	                case "symbol":
	                case "void":
	                    error(name, message, name.text);
	            }
	        }
	        // Check each type parameter and check that list has no duplicate type parameter declarations
	        function checkTypeParameters(typeParameterDeclarations) {
	            if (typeParameterDeclarations) {
	                for (var i = 0, n = typeParameterDeclarations.length; i < n; i++) {
	                    var node = typeParameterDeclarations[i];
	                    checkTypeParameter(node);
	                    if (produceDiagnostics) {
	                        for (var j = 0; j < i; j++) {
	                            if (typeParameterDeclarations[j].symbol === node.symbol) {
	                                error(node.name, ts.Diagnostics.Duplicate_identifier_0, ts.declarationNameToString(node.name));
	                            }
	                        }
	                    }
	                }
	            }
	        }
	        function checkClassExpression(node) {
	            checkClassLikeDeclaration(node);
	            checkNodeDeferred(node);
	            return getTypeOfSymbol(getSymbolOfNode(node));
	        }
	        function checkClassExpressionDeferred(node) {
	            ts.forEach(node.members, checkSourceElement);
	        }
	        function checkClassDeclaration(node) {
	            if (!node.name && !(node.flags & 512 /* Default */)) {
	                grammarErrorOnFirstToken(node, ts.Diagnostics.A_class_declaration_without_the_default_modifier_must_have_a_name);
	            }
	            checkClassLikeDeclaration(node);
	            ts.forEach(node.members, checkSourceElement);
	        }
	        function checkClassLikeDeclaration(node) {
	            checkGrammarClassDeclarationHeritageClauses(node);
	            checkDecorators(node);
	            if (node.name) {
	                checkTypeNameIsReserved(node.name, ts.Diagnostics.Class_name_cannot_be_0);
	                checkCollisionWithCapturedThisVariable(node, node.name);
	                checkCollisionWithRequireExportsInGeneratedCode(node, node.name);
	                checkCollisionWithGlobalPromiseInGeneratedCode(node, node.name);
	            }
	            checkTypeParameters(node.typeParameters);
	            checkExportsOnMergedDeclarations(node);
	            var symbol = getSymbolOfNode(node);
	            var type = getDeclaredTypeOfSymbol(symbol);
	            var typeWithThis = getTypeWithThisArgument(type);
	            var staticType = getTypeOfSymbol(symbol);
	            var baseTypeNode = ts.getClassExtendsHeritageClauseElement(node);
	            if (baseTypeNode) {
	                var baseTypes = getBaseTypes(type);
	                if (baseTypes.length && produceDiagnostics) {
	                    var baseType_1 = baseTypes[0];
	                    var staticBaseType = getBaseConstructorTypeOfClass(type);
	                    checkSourceElement(baseTypeNode.expression);
	                    if (baseTypeNode.typeArguments) {
	                        ts.forEach(baseTypeNode.typeArguments, checkSourceElement);
	                        for (var _i = 0, _a = getConstructorsForTypeArguments(staticBaseType, baseTypeNode.typeArguments); _i < _a.length; _i++) {
	                            var constructor = _a[_i];
	                            if (!checkTypeArgumentConstraints(constructor.typeParameters, baseTypeNode.typeArguments)) {
	                                break;
	                            }
	                        }
	                    }
	                    checkTypeAssignableTo(typeWithThis, getTypeWithThisArgument(baseType_1, type.thisType), node.name || node, ts.Diagnostics.Class_0_incorrectly_extends_base_class_1);
	                    checkTypeAssignableTo(staticType, getTypeWithoutSignatures(staticBaseType), node.name || node, ts.Diagnostics.Class_static_side_0_incorrectly_extends_base_class_static_side_1);
	                    if (!(staticBaseType.symbol && staticBaseType.symbol.flags & 32 /* Class */)) {
	                        // When the static base type is a "class-like" constructor function (but not actually a class), we verify
	                        // that all instantiated base constructor signatures return the same type. We can simply compare the type
	                        // references (as opposed to checking the structure of the types) because elsewhere we have already checked
	                        // that the base type is a class or interface type (and not, for example, an anonymous object type).
	                        var constructors = getInstantiatedConstructorsForTypeArguments(staticBaseType, baseTypeNode.typeArguments);
	                        if (ts.forEach(constructors, function (sig) { return getReturnTypeOfSignature(sig) !== baseType_1; })) {
	                            error(baseTypeNode.expression, ts.Diagnostics.Base_constructors_must_all_have_the_same_return_type);
	                        }
	                    }
	                    checkKindsOfPropertyMemberOverrides(type, baseType_1);
	                }
	            }
	            var implementedTypeNodes = ts.getClassImplementsHeritageClauseElements(node);
	            if (implementedTypeNodes) {
	                for (var _b = 0, implementedTypeNodes_1 = implementedTypeNodes; _b < implementedTypeNodes_1.length; _b++) {
	                    var typeRefNode = implementedTypeNodes_1[_b];
	                    if (!ts.isSupportedExpressionWithTypeArguments(typeRefNode)) {
	                        error(typeRefNode.expression, ts.Diagnostics.A_class_can_only_implement_an_identifier_Slashqualified_name_with_optional_type_arguments);
	                    }
	                    checkTypeReferenceNode(typeRefNode);
	                    if (produceDiagnostics) {
	                        var t = getTypeFromTypeNode(typeRefNode);
	                        if (t !== unknownType) {
	                            var declaredType = (t.flags & 4096 /* Reference */) ? t.target : t;
	                            if (declaredType.flags & (1024 /* Class */ | 2048 /* Interface */)) {
	                                checkTypeAssignableTo(typeWithThis, getTypeWithThisArgument(t, type.thisType), node.name || node, ts.Diagnostics.Class_0_incorrectly_implements_interface_1);
	                            }
	                            else {
	                                error(typeRefNode, ts.Diagnostics.A_class_may_only_implement_another_class_or_interface);
	                            }
	                        }
	                    }
	                }
	            }
	            if (produceDiagnostics) {
	                checkIndexConstraints(type);
	                checkTypeForDuplicateIndexSignatures(node);
	            }
	        }
	        function getTargetSymbol(s) {
	            // if symbol is instantiated its flags are not copied from the 'target'
	            // so we'll need to get back original 'target' symbol to work with correct set of flags
	            return s.flags & 16777216 /* Instantiated */ ? getSymbolLinks(s).target : s;
	        }
	        function getClassLikeDeclarationOfSymbol(symbol) {
	            return ts.forEach(symbol.declarations, function (d) { return ts.isClassLike(d) ? d : undefined; });
	        }
	        function checkKindsOfPropertyMemberOverrides(type, baseType) {
	            // TypeScript 1.0 spec (April 2014): 8.2.3
	            // A derived class inherits all members from its base class it doesn't override.
	            // Inheritance means that a derived class implicitly contains all non - overridden members of the base class.
	            // Both public and private property members are inherited, but only public property members can be overridden.
	            // A property member in a derived class is said to override a property member in a base class
	            // when the derived class property member has the same name and kind(instance or static)
	            // as the base class property member.
	            // The type of an overriding property member must be assignable(section 3.8.4)
	            // to the type of the overridden property member, or otherwise a compile - time error occurs.
	            // Base class instance member functions can be overridden by derived class instance member functions,
	            // but not by other kinds of members.
	            // Base class instance member variables and accessors can be overridden by
	            // derived class instance member variables and accessors, but not by other kinds of members.
	            // NOTE: assignability is checked in checkClassDeclaration
	            var baseProperties = getPropertiesOfObjectType(baseType);
	            for (var _i = 0, baseProperties_1 = baseProperties; _i < baseProperties_1.length; _i++) {
	                var baseProperty = baseProperties_1[_i];
	                var base = getTargetSymbol(baseProperty);
	                if (base.flags & 134217728 /* Prototype */) {
	                    continue;
	                }
	                var derived = getTargetSymbol(getPropertyOfObjectType(type, base.name));
	                var baseDeclarationFlags = getDeclarationFlagsFromSymbol(base);
	                ts.Debug.assert(!!derived, "derived should point to something, even if it is the base class' declaration.");
	                if (derived) {
	                    // In order to resolve whether the inherited method was overriden in the base class or not,
	                    // we compare the Symbols obtained. Since getTargetSymbol returns the symbol on the *uninstantiated*
	                    // type declaration, derived and base resolve to the same symbol even in the case of generic classes.
	                    if (derived === base) {
	                        // derived class inherits base without override/redeclaration
	                        var derivedClassDecl = getClassLikeDeclarationOfSymbol(type.symbol);
	                        // It is an error to inherit an abstract member without implementing it or being declared abstract.
	                        // If there is no declaration for the derived class (as in the case of class expressions),
	                        // then the class cannot be declared abstract.
	                        if (baseDeclarationFlags & 128 /* Abstract */ && (!derivedClassDecl || !(derivedClassDecl.flags & 128 /* Abstract */))) {
	                            if (derivedClassDecl.kind === 189 /* ClassExpression */) {
	                                error(derivedClassDecl, ts.Diagnostics.Non_abstract_class_expression_does_not_implement_inherited_abstract_member_0_from_class_1, symbolToString(baseProperty), typeToString(baseType));
	                            }
	                            else {
	                                error(derivedClassDecl, ts.Diagnostics.Non_abstract_class_0_does_not_implement_inherited_abstract_member_1_from_class_2, typeToString(type), symbolToString(baseProperty), typeToString(baseType));
	                            }
	                        }
	                    }
	                    else {
	                        // derived overrides base.
	                        var derivedDeclarationFlags = getDeclarationFlagsFromSymbol(derived);
	                        if ((baseDeclarationFlags & 16 /* Private */) || (derivedDeclarationFlags & 16 /* Private */)) {
	                            // either base or derived property is private - not override, skip it
	                            continue;
	                        }
	                        if ((baseDeclarationFlags & 64 /* Static */) !== (derivedDeclarationFlags & 64 /* Static */)) {
	                            // value of 'static' is not the same for properties - not override, skip it
	                            continue;
	                        }
	                        if ((base.flags & derived.flags & 8192 /* Method */) || ((base.flags & 98308 /* PropertyOrAccessor */) && (derived.flags & 98308 /* PropertyOrAccessor */))) {
	                            // method is overridden with method or property/accessor is overridden with property/accessor - correct case
	                            continue;
	                        }
	                        var errorMessage = void 0;
	                        if (base.flags & 8192 /* Method */) {
	                            if (derived.flags & 98304 /* Accessor */) {
	                                errorMessage = ts.Diagnostics.Class_0_defines_instance_member_function_1_but_extended_class_2_defines_it_as_instance_member_accessor;
	                            }
	                            else {
	                                ts.Debug.assert((derived.flags & 4 /* Property */) !== 0);
	                                errorMessage = ts.Diagnostics.Class_0_defines_instance_member_function_1_but_extended_class_2_defines_it_as_instance_member_property;
	                            }
	                        }
	                        else if (base.flags & 4 /* Property */) {
	                            ts.Debug.assert((derived.flags & 8192 /* Method */) !== 0);
	                            errorMessage = ts.Diagnostics.Class_0_defines_instance_member_property_1_but_extended_class_2_defines_it_as_instance_member_function;
	                        }
	                        else {
	                            ts.Debug.assert((base.flags & 98304 /* Accessor */) !== 0);
	                            ts.Debug.assert((derived.flags & 8192 /* Method */) !== 0);
	                            errorMessage = ts.Diagnostics.Class_0_defines_instance_member_accessor_1_but_extended_class_2_defines_it_as_instance_member_function;
	                        }
	                        error(derived.valueDeclaration.name, errorMessage, typeToString(baseType), symbolToString(base), typeToString(type));
	                    }
	                }
	            }
	        }
	        function isAccessor(kind) {
	            return kind === 146 /* GetAccessor */ || kind === 147 /* SetAccessor */;
	        }
	        function areTypeParametersIdentical(list1, list2) {
	            if (!list1 && !list2) {
	                return true;
	            }
	            if (!list1 || !list2 || list1.length !== list2.length) {
	                return false;
	            }
	            // TypeScript 1.0 spec (April 2014):
	            // When a generic interface has multiple declarations,  all declarations must have identical type parameter
	            // lists, i.e. identical type parameter names with identical constraints in identical order.
	            for (var i = 0, len = list1.length; i < len; i++) {
	                var tp1 = list1[i];
	                var tp2 = list2[i];
	                if (tp1.name.text !== tp2.name.text) {
	                    return false;
	                }
	                if (!tp1.constraint && !tp2.constraint) {
	                    continue;
	                }
	                if (!tp1.constraint || !tp2.constraint) {
	                    return false;
	                }
	                if (!isTypeIdenticalTo(getTypeFromTypeNode(tp1.constraint), getTypeFromTypeNode(tp2.constraint))) {
	                    return false;
	                }
	            }
	            return true;
	        }
	        function checkInheritedPropertiesAreIdentical(type, typeNode) {
	            var baseTypes = getBaseTypes(type);
	            if (baseTypes.length < 2) {
	                return true;
	            }
	            var seen = {};
	            ts.forEach(resolveDeclaredMembers(type).declaredProperties, function (p) { seen[p.name] = { prop: p, containingType: type }; });
	            var ok = true;
	            for (var _i = 0, baseTypes_2 = baseTypes; _i < baseTypes_2.length; _i++) {
	                var base = baseTypes_2[_i];
	                var properties = getPropertiesOfObjectType(getTypeWithThisArgument(base, type.thisType));
	                for (var _a = 0, properties_4 = properties; _a < properties_4.length; _a++) {
	                    var prop = properties_4[_a];
	                    if (!ts.hasProperty(seen, prop.name)) {
	                        seen[prop.name] = { prop: prop, containingType: base };
	                    }
	                    else {
	                        var existing = seen[prop.name];
	                        var isInheritedProperty = existing.containingType !== type;
	                        if (isInheritedProperty && !isPropertyIdenticalTo(existing.prop, prop)) {
	                            ok = false;
	                            var typeName1 = typeToString(existing.containingType);
	                            var typeName2 = typeToString(base);
	                            var errorInfo = ts.chainDiagnosticMessages(undefined, ts.Diagnostics.Named_property_0_of_types_1_and_2_are_not_identical, symbolToString(prop), typeName1, typeName2);
	                            errorInfo = ts.chainDiagnosticMessages(errorInfo, ts.Diagnostics.Interface_0_cannot_simultaneously_extend_types_1_and_2, typeToString(type), typeName1, typeName2);
	                            diagnostics.add(ts.createDiagnosticForNodeFromMessageChain(typeNode, errorInfo));
	                        }
	                    }
	                }
	            }
	            return ok;
	        }
	        function checkInterfaceDeclaration(node) {
	            // Grammar checking
	            checkGrammarDecorators(node) || checkGrammarModifiers(node) || checkGrammarInterfaceDeclaration(node);
	            checkTypeParameters(node.typeParameters);
	            if (produceDiagnostics) {
	                checkTypeNameIsReserved(node.name, ts.Diagnostics.Interface_name_cannot_be_0);
	                checkExportsOnMergedDeclarations(node);
	                var symbol = getSymbolOfNode(node);
	                var firstInterfaceDecl = ts.getDeclarationOfKind(symbol, 218 /* InterfaceDeclaration */);
	                if (symbol.declarations.length > 1) {
	                    if (node !== firstInterfaceDecl && !areTypeParametersIdentical(firstInterfaceDecl.typeParameters, node.typeParameters)) {
	                        error(node.name, ts.Diagnostics.All_declarations_of_an_interface_must_have_identical_type_parameters);
	                    }
	                }
	                // Only check this symbol once
	                if (node === firstInterfaceDecl) {
	                    var type = getDeclaredTypeOfSymbol(symbol);
	                    var typeWithThis = getTypeWithThisArgument(type);
	                    // run subsequent checks only if first set succeeded
	                    if (checkInheritedPropertiesAreIdentical(type, node.name)) {
	                        for (var _i = 0, _a = getBaseTypes(type); _i < _a.length; _i++) {
	                            var baseType = _a[_i];
	                            checkTypeAssignableTo(typeWithThis, getTypeWithThisArgument(baseType, type.thisType), node.name, ts.Diagnostics.Interface_0_incorrectly_extends_interface_1);
	                        }
	                        checkIndexConstraints(type);
	                    }
	                }
	            }
	            ts.forEach(ts.getInterfaceBaseTypeNodes(node), function (heritageElement) {
	                if (!ts.isSupportedExpressionWithTypeArguments(heritageElement)) {
	                    error(heritageElement.expression, ts.Diagnostics.An_interface_can_only_extend_an_identifier_Slashqualified_name_with_optional_type_arguments);
	                }
	                checkTypeReferenceNode(heritageElement);
	            });
	            ts.forEach(node.members, checkSourceElement);
	            if (produceDiagnostics) {
	                checkTypeForDuplicateIndexSignatures(node);
	            }
	        }
	        function checkTypeAliasDeclaration(node) {
	            // Grammar checking
	            checkGrammarDecorators(node) || checkGrammarModifiers(node);
	            checkTypeNameIsReserved(node.name, ts.Diagnostics.Type_alias_name_cannot_be_0);
	            checkSourceElement(node.type);
	        }
	        function computeEnumMemberValues(node) {
	            var nodeLinks = getNodeLinks(node);
	            if (!(nodeLinks.flags & 16384 /* EnumValuesComputed */)) {
	                var enumSymbol = getSymbolOfNode(node);
	                var enumType = getDeclaredTypeOfSymbol(enumSymbol);
	                var autoValue = 0; // set to undefined when enum member is non-constant
	                var ambient = ts.isInAmbientContext(node);
	                var enumIsConst = ts.isConst(node);
	                for (var _i = 0, _a = node.members; _i < _a.length; _i++) {
	                    var member = _a[_i];
	                    if (isComputedNonLiteralName(member.name)) {
	                        error(member.name, ts.Diagnostics.Computed_property_names_are_not_allowed_in_enums);
	                    }
	                    else {
	                        var text = getTextOfPropertyName(member.name);
	                        if (isNumericLiteralName(text)) {
	                            error(member.name, ts.Diagnostics.An_enum_member_cannot_have_a_numeric_name);
	                        }
	                    }
	                    var previousEnumMemberIsNonConstant = autoValue === undefined;
	                    var initializer = member.initializer;
	                    if (initializer) {
	                        autoValue = computeConstantValueForEnumMemberInitializer(initializer, enumType, enumIsConst, ambient);
	                    }
	                    else if (ambient && !enumIsConst) {
	                        // In ambient enum declarations that specify no const modifier, enum member declarations
	                        // that omit a value are considered computed members (as opposed to having auto-incremented values assigned).
	                        autoValue = undefined;
	                    }
	                    else if (previousEnumMemberIsNonConstant) {
	                        // If the member declaration specifies no value, the member is considered a constant enum member.
	                        // If the member is the first member in the enum declaration, it is assigned the value zero.
	                        // Otherwise, it is assigned the value of the immediately preceding member plus one,
	                        // and an error occurs if the immediately preceding member is not a constant enum member
	                        error(member.name, ts.Diagnostics.Enum_member_must_have_initializer);
	                    }
	                    if (autoValue !== undefined) {
	                        getNodeLinks(member).enumMemberValue = autoValue;
	                        autoValue++;
	                    }
	                }
	                nodeLinks.flags |= 16384 /* EnumValuesComputed */;
	            }
	            function computeConstantValueForEnumMemberInitializer(initializer, enumType, enumIsConst, ambient) {
	                // Controls if error should be reported after evaluation of constant value is completed
	                // Can be false if another more precise error was already reported during evaluation.
	                var reportError = true;
	                var value = evalConstant(initializer);
	                if (reportError) {
	                    if (value === undefined) {
	                        if (enumIsConst) {
	                            error(initializer, ts.Diagnostics.In_const_enum_declarations_member_initializer_must_be_constant_expression);
	                        }
	                        else if (ambient) {
	                            error(initializer, ts.Diagnostics.In_ambient_enum_declarations_member_initializer_must_be_constant_expression);
	                        }
	                        else {
	                            // Only here do we need to check that the initializer is assignable to the enum type.
	                            checkTypeAssignableTo(checkExpression(initializer), enumType, initializer, /*headMessage*/ undefined);
	                        }
	                    }
	                    else if (enumIsConst) {
	                        if (isNaN(value)) {
	                            error(initializer, ts.Diagnostics.const_enum_member_initializer_was_evaluated_to_disallowed_value_NaN);
	                        }
	                        else if (!isFinite(value)) {
	                            error(initializer, ts.Diagnostics.const_enum_member_initializer_was_evaluated_to_a_non_finite_value);
	                        }
	                    }
	                }
	                return value;
	                function evalConstant(e) {
	                    switch (e.kind) {
	                        case 182 /* PrefixUnaryExpression */:
	                            var value_1 = evalConstant(e.operand);
	                            if (value_1 === undefined) {
	                                return undefined;
	                            }
	                            switch (e.operator) {
	                                case 35 /* PlusToken */: return value_1;
	                                case 36 /* MinusToken */: return -value_1;
	                                case 50 /* TildeToken */: return ~value_1;
	                            }
	                            return undefined;
	                        case 184 /* BinaryExpression */:
	                            var left = evalConstant(e.left);
	                            if (left === undefined) {
	                                return undefined;
	                            }
	                            var right = evalConstant(e.right);
	                            if (right === undefined) {
	                                return undefined;
	                            }
	                            switch (e.operatorToken.kind) {
	                                case 47 /* BarToken */: return left | right;
	                                case 46 /* AmpersandToken */: return left & right;
	                                case 44 /* GreaterThanGreaterThanToken */: return left >> right;
	                                case 45 /* GreaterThanGreaterThanGreaterThanToken */: return left >>> right;
	                                case 43 /* LessThanLessThanToken */: return left << right;
	                                case 48 /* CaretToken */: return left ^ right;
	                                case 37 /* AsteriskToken */: return left * right;
	                                case 39 /* SlashToken */: return left / right;
	                                case 35 /* PlusToken */: return left + right;
	                                case 36 /* MinusToken */: return left - right;
	                                case 40 /* PercentToken */: return left % right;
	                            }
	                            return undefined;
	                        case 8 /* NumericLiteral */:
	                            return +e.text;
	                        case 175 /* ParenthesizedExpression */:
	                            return evalConstant(e.expression);
	                        case 69 /* Identifier */:
	                        case 170 /* ElementAccessExpression */:
	                        case 169 /* PropertyAccessExpression */:
	                            var member = initializer.parent;
	                            var currentType = getTypeOfSymbol(getSymbolOfNode(member.parent));
	                            var enumType_1;
	                            var propertyName = void 0;
	                            if (e.kind === 69 /* Identifier */) {
	                                // unqualified names can refer to member that reside in different declaration of the enum so just doing name resolution won't work.
	                                // instead pick current enum type and later try to fetch member from the type
	                                enumType_1 = currentType;
	                                propertyName = e.text;
	                            }
	                            else {
	                                var expression = void 0;
	                                if (e.kind === 170 /* ElementAccessExpression */) {
	                                    if (e.argumentExpression === undefined ||
	                                        e.argumentExpression.kind !== 9 /* StringLiteral */) {
	                                        return undefined;
	                                    }
	                                    expression = e.expression;
	                                    propertyName = e.argumentExpression.text;
	                                }
	                                else {
	                                    expression = e.expression;
	                                    propertyName = e.name.text;
	                                }
	                                // expression part in ElementAccess\PropertyAccess should be either identifier or dottedName
	                                var current = expression;
	                                while (current) {
	                                    if (current.kind === 69 /* Identifier */) {
	                                        break;
	                                    }
	                                    else if (current.kind === 169 /* PropertyAccessExpression */) {
	                                        current = current.expression;
	                                    }
	                                    else {
	                                        return undefined;
	                                    }
	                                }
	                                enumType_1 = checkExpression(expression);
	                                // allow references to constant members of other enums
	                                if (!(enumType_1.symbol && (enumType_1.symbol.flags & 384 /* Enum */))) {
	                                    return undefined;
	                                }
	                            }
	                            if (propertyName === undefined) {
	                                return undefined;
	                            }
	                            var property = getPropertyOfObjectType(enumType_1, propertyName);
	                            if (!property || !(property.flags & 8 /* EnumMember */)) {
	                                return undefined;
	                            }
	                            var propertyDecl = property.valueDeclaration;
	                            // self references are illegal
	                            if (member === propertyDecl) {
	                                return undefined;
	                            }
	                            // illegal case: forward reference
	                            if (!isBlockScopedNameDeclaredBeforeUse(propertyDecl, member)) {
	                                reportError = false;
	                                error(e, ts.Diagnostics.A_member_initializer_in_a_enum_declaration_cannot_reference_members_declared_after_it_including_members_defined_in_other_enums);
	                                return undefined;
	                            }
	                            return getNodeLinks(propertyDecl).enumMemberValue;
	                    }
	                }
	            }
	        }
	        function checkEnumDeclaration(node) {
	            if (!produceDiagnostics) {
	                return;
	            }
	            // Grammar checking
	            checkGrammarDecorators(node) || checkGrammarModifiers(node);
	            checkTypeNameIsReserved(node.name, ts.Diagnostics.Enum_name_cannot_be_0);
	            checkCollisionWithCapturedThisVariable(node, node.name);
	            checkCollisionWithRequireExportsInGeneratedCode(node, node.name);
	            checkCollisionWithGlobalPromiseInGeneratedCode(node, node.name);
	            checkExportsOnMergedDeclarations(node);
	            computeEnumMemberValues(node);
	            var enumIsConst = ts.isConst(node);
	            if (compilerOptions.isolatedModules && enumIsConst && ts.isInAmbientContext(node)) {
	                error(node.name, ts.Diagnostics.Ambient_const_enums_are_not_allowed_when_the_isolatedModules_flag_is_provided);
	            }
	            // Spec 2014 - Section 9.3:
	            // It isn't possible for one enum declaration to continue the automatic numbering sequence of another,
	            // and when an enum type has multiple declarations, only one declaration is permitted to omit a value
	            // for the first member.
	            //
	            // Only perform this check once per symbol
	            var enumSymbol = getSymbolOfNode(node);
	            var firstDeclaration = ts.getDeclarationOfKind(enumSymbol, node.kind);
	            if (node === firstDeclaration) {
	                if (enumSymbol.declarations.length > 1) {
	                    // check that const is placed\omitted on all enum declarations
	                    ts.forEach(enumSymbol.declarations, function (decl) {
	                        if (ts.isConstEnumDeclaration(decl) !== enumIsConst) {
	                            error(decl.name, ts.Diagnostics.Enum_declarations_must_all_be_const_or_non_const);
	                        }
	                    });
	                }
	                var seenEnumMissingInitialInitializer_1 = false;
	                ts.forEach(enumSymbol.declarations, function (declaration) {
	                    // return true if we hit a violation of the rule, false otherwise
	                    if (declaration.kind !== 220 /* EnumDeclaration */) {
	                        return false;
	                    }
	                    var enumDeclaration = declaration;
	                    if (!enumDeclaration.members.length) {
	                        return false;
	                    }
	                    var firstEnumMember = enumDeclaration.members[0];
	                    if (!firstEnumMember.initializer) {
	                        if (seenEnumMissingInitialInitializer_1) {
	                            error(firstEnumMember.name, ts.Diagnostics.In_an_enum_with_multiple_declarations_only_one_declaration_can_omit_an_initializer_for_its_first_enum_element);
	                        }
	                        else {
	                            seenEnumMissingInitialInitializer_1 = true;
	                        }
	                    }
	                });
	            }
	        }
	        function getFirstNonAmbientClassOrFunctionDeclaration(symbol) {
	            var declarations = symbol.declarations;
	            for (var _i = 0, declarations_5 = declarations; _i < declarations_5.length; _i++) {
	                var declaration = declarations_5[_i];
	                if ((declaration.kind === 217 /* ClassDeclaration */ ||
	                    (declaration.kind === 216 /* FunctionDeclaration */ && ts.nodeIsPresent(declaration.body))) &&
	                    !ts.isInAmbientContext(declaration)) {
	                    return declaration;
	                }
	            }
	            return undefined;
	        }
	        function inSameLexicalScope(node1, node2) {
	            var container1 = ts.getEnclosingBlockScopeContainer(node1);
	            var container2 = ts.getEnclosingBlockScopeContainer(node2);
	            if (isGlobalSourceFile(container1)) {
	                return isGlobalSourceFile(container2);
	            }
	            else if (isGlobalSourceFile(container2)) {
	                return false;
	            }
	            else {
	                return container1 === container2;
	            }
	        }
	        function checkModuleDeclaration(node) {
	            if (produceDiagnostics) {
	                // Grammar checking
	                var isGlobalAugmentation = ts.isGlobalScopeAugmentation(node);
	                var inAmbientContext = ts.isInAmbientContext(node);
	                if (isGlobalAugmentation && !inAmbientContext) {
	                    error(node.name, ts.Diagnostics.Augmentations_for_the_global_scope_should_have_declare_modifier_unless_they_appear_in_already_ambient_context);
	                }
	                var isAmbientExternalModule = ts.isAmbientModule(node);
	                var contextErrorMessage = isAmbientExternalModule
	                    ? ts.Diagnostics.An_ambient_module_declaration_is_only_allowed_at_the_top_level_in_a_file
	                    : ts.Diagnostics.A_namespace_declaration_is_only_allowed_in_a_namespace_or_module;
	                if (checkGrammarModuleElementContext(node, contextErrorMessage)) {
	                    // If we hit a module declaration in an illegal context, just bail out to avoid cascading errors.
	                    return;
	                }
	                if (!checkGrammarDecorators(node) && !checkGrammarModifiers(node)) {
	                    if (!inAmbientContext && node.name.kind === 9 /* StringLiteral */) {
	                        grammarErrorOnNode(node.name, ts.Diagnostics.Only_ambient_modules_can_use_quoted_names);
	                    }
	                }
	                checkCollisionWithCapturedThisVariable(node, node.name);
	                checkCollisionWithRequireExportsInGeneratedCode(node, node.name);
	                checkCollisionWithGlobalPromiseInGeneratedCode(node, node.name);
	                checkExportsOnMergedDeclarations(node);
	                var symbol = getSymbolOfNode(node);
	                // The following checks only apply on a non-ambient instantiated module declaration.
	                if (symbol.flags & 512 /* ValueModule */
	                    && symbol.declarations.length > 1
	                    && !inAmbientContext
	                    && ts.isInstantiatedModule(node, compilerOptions.preserveConstEnums || compilerOptions.isolatedModules)) {
	                    var firstNonAmbientClassOrFunc = getFirstNonAmbientClassOrFunctionDeclaration(symbol);
	                    if (firstNonAmbientClassOrFunc) {
	                        if (ts.getSourceFileOfNode(node) !== ts.getSourceFileOfNode(firstNonAmbientClassOrFunc)) {
	                            error(node.name, ts.Diagnostics.A_namespace_declaration_cannot_be_in_a_different_file_from_a_class_or_function_with_which_it_is_merged);
	                        }
	                        else if (node.pos < firstNonAmbientClassOrFunc.pos) {
	                            error(node.name, ts.Diagnostics.A_namespace_declaration_cannot_be_located_prior_to_a_class_or_function_with_which_it_is_merged);
	                        }
	                    }
	                    // if the module merges with a class declaration in the same lexical scope,
	                    // we need to track this to ensure the correct emit.
	                    var mergedClass = ts.getDeclarationOfKind(symbol, 217 /* ClassDeclaration */);
	                    if (mergedClass &&
	                        inSameLexicalScope(node, mergedClass)) {
	                        getNodeLinks(node).flags |= 32768 /* LexicalModuleMergesWithClass */;
	                    }
	                }
	                if (isAmbientExternalModule) {
	                    if (ts.isExternalModuleAugmentation(node)) {
	                        // body of the augmentation should be checked for consistency only if augmentation was applied to its target (either global scope or module)
	                        // otherwise we'll be swamped in cascading errors.
	                        // We can detect if augmentation was applied using following rules:
	                        // - augmentation for a global scope is always applied
	                        // - augmentation for some external module is applied if symbol for augmentation is merged (it was combined with target module).
	                        var checkBody = isGlobalAugmentation || (getSymbolOfNode(node).flags & 33554432 /* Merged */);
	                        if (checkBody) {
	                            // body of ambient external module is always a module block
	                            for (var _i = 0, _a = node.body.statements; _i < _a.length; _i++) {
	                                var statement = _a[_i];
	                                checkModuleAugmentationElement(statement, isGlobalAugmentation);
	                            }
	                        }
	                    }
	                    else if (isGlobalSourceFile(node.parent)) {
	                        if (isGlobalAugmentation) {
	                            error(node.name, ts.Diagnostics.Augmentations_for_the_global_scope_can_only_be_directly_nested_in_external_modules_or_ambient_module_declarations);
	                        }
	                        else if (ts.isExternalModuleNameRelative(node.name.text)) {
	                            error(node.name, ts.Diagnostics.Ambient_module_declaration_cannot_specify_relative_module_name);
	                        }
	                    }
	                    else {
	                        if (isGlobalAugmentation) {
	                            error(node.name, ts.Diagnostics.Augmentations_for_the_global_scope_can_only_be_directly_nested_in_external_modules_or_ambient_module_declarations);
	                        }
	                        else {
	                            // Node is not an augmentation and is not located on the script level.
	                            // This means that this is declaration of ambient module that is located in other module or namespace which is prohibited.
	                            error(node.name, ts.Diagnostics.Ambient_modules_cannot_be_nested_in_other_modules_or_namespaces);
	                        }
	                    }
	                }
	            }
	            checkSourceElement(node.body);
	        }
	        function checkModuleAugmentationElement(node, isGlobalAugmentation) {
	            switch (node.kind) {
	                case 196 /* VariableStatement */:
	                    // error each individual name in variable statement instead of marking the entire variable statement
	                    for (var _i = 0, _a = node.declarationList.declarations; _i < _a.length; _i++) {
	                        var decl = _a[_i];
	                        checkModuleAugmentationElement(decl, isGlobalAugmentation);
	                    }
	                    break;
	                case 230 /* ExportAssignment */:
	                case 231 /* ExportDeclaration */:
	                    grammarErrorOnFirstToken(node, ts.Diagnostics.Exports_and_export_assignments_are_not_permitted_in_module_augmentations);
	                    break;
	                case 224 /* ImportEqualsDeclaration */:
	                    if (node.moduleReference.kind !== 9 /* StringLiteral */) {
	                        error(node.name, ts.Diagnostics.Module_augmentation_cannot_introduce_new_names_in_the_top_level_scope);
	                        break;
	                    }
	                // fallthrough
	                case 225 /* ImportDeclaration */:
	                    grammarErrorOnFirstToken(node, ts.Diagnostics.Imports_are_not_permitted_in_module_augmentations_Consider_moving_them_to_the_enclosing_external_module);
	                    break;
	                case 166 /* BindingElement */:
	                case 214 /* VariableDeclaration */:
	                    var name_17 = node.name;
	                    if (ts.isBindingPattern(name_17)) {
	                        for (var _b = 0, _c = name_17.elements; _b < _c.length; _b++) {
	                            var el = _c[_b];
	                            // mark individual names in binding pattern
	                            checkModuleAugmentationElement(el, isGlobalAugmentation);
	                        }
	                        break;
	                    }
	                // fallthrough
	                case 217 /* ClassDeclaration */:
	                case 220 /* EnumDeclaration */:
	                case 216 /* FunctionDeclaration */:
	                case 218 /* InterfaceDeclaration */:
	                case 221 /* ModuleDeclaration */:
	                case 219 /* TypeAliasDeclaration */:
	                    var symbol = getSymbolOfNode(node);
	                    if (symbol) {
	                        // module augmentations cannot introduce new names on the top level scope of the module
	                        // this is done it two steps
	                        // 1. quick check - if symbol for node is not merged - this is local symbol to this augmentation - report error
	                        // 2. main check - report error if value declaration of the parent symbol is module augmentation)
	                        var reportError = !(symbol.flags & 33554432 /* Merged */);
	                        if (!reportError) {
	                            if (isGlobalAugmentation) {
	                                // global symbol should not have parent since it is not explicitly exported
	                                reportError = symbol.parent !== undefined;
	                            }
	                            else {
	                                // symbol should not originate in augmentation
	                                reportError = ts.isExternalModuleAugmentation(symbol.parent.valueDeclaration);
	                            }
	                        }
	                        if (reportError) {
	                            error(node, ts.Diagnostics.Module_augmentation_cannot_introduce_new_names_in_the_top_level_scope);
	                        }
	                    }
	                    break;
	            }
	        }
	        function getFirstIdentifier(node) {
	            while (true) {
	                if (node.kind === 136 /* QualifiedName */) {
	                    node = node.left;
	                }
	                else if (node.kind === 169 /* PropertyAccessExpression */) {
	                    node = node.expression;
	                }
	                else {
	                    break;
	                }
	            }
	            ts.Debug.assert(node.kind === 69 /* Identifier */);
	            return node;
	        }
	        function checkExternalImportOrExportDeclaration(node) {
	            var moduleName = ts.getExternalModuleName(node);
	            if (!ts.nodeIsMissing(moduleName) && moduleName.kind !== 9 /* StringLiteral */) {
	                error(moduleName, ts.Diagnostics.String_literal_expected);
	                return false;
	            }
	            var inAmbientExternalModule = node.parent.kind === 222 /* ModuleBlock */ && ts.isAmbientModule(node.parent.parent);
	            if (node.parent.kind !== 251 /* SourceFile */ && !inAmbientExternalModule) {
	                error(moduleName, node.kind === 231 /* ExportDeclaration */ ?
	                    ts.Diagnostics.Export_declarations_are_not_permitted_in_a_namespace :
	                    ts.Diagnostics.Import_declarations_in_a_namespace_cannot_reference_a_module);
	                return false;
	            }
	            if (inAmbientExternalModule && ts.isExternalModuleNameRelative(moduleName.text)) {
	                // we have already reported errors on top level imports\exports in external module augmentations in checkModuleDeclaration
	                // no need to do this again.
	                if (!isTopLevelInExternalModuleAugmentation(node)) {
	                    // TypeScript 1.0 spec (April 2013): 12.1.6
	                    // An ExternalImportDeclaration in an AmbientExternalModuleDeclaration may reference
	                    // other external modules only through top - level external module names.
	                    // Relative external module names are not permitted.
	                    error(node, ts.Diagnostics.Import_or_export_declaration_in_an_ambient_module_declaration_cannot_reference_module_through_relative_module_name);
	                    return false;
	                }
	            }
	            return true;
	        }
	        function checkAliasSymbol(node) {
	            var symbol = getSymbolOfNode(node);
	            var target = resolveAlias(symbol);
	            if (target !== unknownSymbol) {
	                var excludedMeanings = (symbol.flags & 107455 /* Value */ ? 107455 /* Value */ : 0) |
	                    (symbol.flags & 793056 /* Type */ ? 793056 /* Type */ : 0) |
	                    (symbol.flags & 1536 /* Namespace */ ? 1536 /* Namespace */ : 0);
	                if (target.flags & excludedMeanings) {
	                    var message = node.kind === 233 /* ExportSpecifier */ ?
	                        ts.Diagnostics.Export_declaration_conflicts_with_exported_declaration_of_0 :
	                        ts.Diagnostics.Import_declaration_conflicts_with_local_declaration_of_0;
	                    error(node, message, symbolToString(symbol));
	                }
	            }
	        }
	        function checkImportBinding(node) {
	            checkCollisionWithCapturedThisVariable(node, node.name);
	            checkCollisionWithRequireExportsInGeneratedCode(node, node.name);
	            checkCollisionWithGlobalPromiseInGeneratedCode(node, node.name);
	            checkAliasSymbol(node);
	        }
	        function checkImportDeclaration(node) {
	            if (checkGrammarModuleElementContext(node, ts.Diagnostics.An_import_declaration_can_only_be_used_in_a_namespace_or_module)) {
	                // If we hit an import declaration in an illegal context, just bail out to avoid cascading errors.
	                return;
	            }
	            if (!checkGrammarDecorators(node) && !checkGrammarModifiers(node) && (node.flags & 1022 /* Modifier */)) {
	                grammarErrorOnFirstToken(node, ts.Diagnostics.An_import_declaration_cannot_have_modifiers);
	            }
	            if (checkExternalImportOrExportDeclaration(node)) {
	                var importClause = node.importClause;
	                if (importClause) {
	                    if (importClause.name) {
	                        checkImportBinding(importClause);
	                    }
	                    if (importClause.namedBindings) {
	                        if (importClause.namedBindings.kind === 227 /* NamespaceImport */) {
	                            checkImportBinding(importClause.namedBindings);
	                        }
	                        else {
	                            ts.forEach(importClause.namedBindings.elements, checkImportBinding);
	                        }
	                    }
	                }
	            }
	        }
	        function checkImportEqualsDeclaration(node) {
	            if (checkGrammarModuleElementContext(node, ts.Diagnostics.An_import_declaration_can_only_be_used_in_a_namespace_or_module)) {
	                // If we hit an import declaration in an illegal context, just bail out to avoid cascading errors.
	                return;
	            }
	            checkGrammarDecorators(node) || checkGrammarModifiers(node);
	            if (ts.isInternalModuleImportEqualsDeclaration(node) || checkExternalImportOrExportDeclaration(node)) {
	                checkImportBinding(node);
	                if (node.flags & 2 /* Export */) {
	                    markExportAsReferenced(node);
	                }
	                if (ts.isInternalModuleImportEqualsDeclaration(node)) {
	                    var target = resolveAlias(getSymbolOfNode(node));
	                    if (target !== unknownSymbol) {
	                        if (target.flags & 107455 /* Value */) {
	                            // Target is a value symbol, check that it is not hidden by a local declaration with the same name
	                            var moduleName = getFirstIdentifier(node.moduleReference);
	                            if (!(resolveEntityName(moduleName, 107455 /* Value */ | 1536 /* Namespace */).flags & 1536 /* Namespace */)) {
	                                error(moduleName, ts.Diagnostics.Module_0_is_hidden_by_a_local_declaration_with_the_same_name, ts.declarationNameToString(moduleName));
	                            }
	                        }
	                        if (target.flags & 793056 /* Type */) {
	                            checkTypeNameIsReserved(node.name, ts.Diagnostics.Import_name_cannot_be_0);
	                        }
	                    }
	                }
	                else {
	                    if (modulekind === 5 /* ES6 */ && !ts.isInAmbientContext(node)) {
	                        // Import equals declaration is deprecated in es6 or above
	                        grammarErrorOnNode(node, ts.Diagnostics.Import_assignment_cannot_be_used_when_targeting_ECMAScript_6_modules_Consider_using_import_Asterisk_as_ns_from_mod_import_a_from_mod_import_d_from_mod_or_another_module_format_instead);
	                    }
	                }
	            }
	        }
	        function checkExportDeclaration(node) {
	            if (checkGrammarModuleElementContext(node, ts.Diagnostics.An_export_declaration_can_only_be_used_in_a_module)) {
	                // If we hit an export in an illegal context, just bail out to avoid cascading errors.
	                return;
	            }
	            if (!checkGrammarDecorators(node) && !checkGrammarModifiers(node) && (node.flags & 1022 /* Modifier */)) {
	                grammarErrorOnFirstToken(node, ts.Diagnostics.An_export_declaration_cannot_have_modifiers);
	            }
	            if (!node.moduleSpecifier || checkExternalImportOrExportDeclaration(node)) {
	                if (node.exportClause) {
	                    // export { x, y }
	                    // export { x, y } from "foo"
	                    ts.forEach(node.exportClause.elements, checkExportSpecifier);
	                    var inAmbientExternalModule = node.parent.kind === 222 /* ModuleBlock */ && ts.isAmbientModule(node.parent.parent);
	                    if (node.parent.kind !== 251 /* SourceFile */ && !inAmbientExternalModule) {
	                        error(node, ts.Diagnostics.Export_declarations_are_not_permitted_in_a_namespace);
	                    }
	                }
	                else {
	                    // export * from "foo"
	                    var moduleSymbol = resolveExternalModuleName(node, node.moduleSpecifier);
	                    if (moduleSymbol && hasExportAssignmentSymbol(moduleSymbol)) {
	                        error(node.moduleSpecifier, ts.Diagnostics.Module_0_uses_export_and_cannot_be_used_with_export_Asterisk, symbolToString(moduleSymbol));
	                    }
	                }
	            }
	        }
	        function checkGrammarModuleElementContext(node, errorMessage) {
	            if (node.parent.kind !== 251 /* SourceFile */ && node.parent.kind !== 222 /* ModuleBlock */ && node.parent.kind !== 221 /* ModuleDeclaration */) {
	                return grammarErrorOnFirstToken(node, errorMessage);
	            }
	        }
	        function checkExportSpecifier(node) {
	            checkAliasSymbol(node);
	            if (!node.parent.parent.moduleSpecifier) {
	                var exportedName = node.propertyName || node.name;
	                // find immediate value referenced by exported name (SymbolFlags.Alias is set so we don't chase down aliases)
	                var symbol = resolveName(exportedName, exportedName.text, 107455 /* Value */ | 793056 /* Type */ | 1536 /* Namespace */ | 8388608 /* Alias */, 
	                /*nameNotFoundMessage*/ undefined, /*nameArg*/ undefined);
	                if (symbol && (symbol === undefinedSymbol || isGlobalSourceFile(getDeclarationContainer(symbol.declarations[0])))) {
	                    error(exportedName, ts.Diagnostics.Cannot_re_export_name_that_is_not_defined_in_the_module);
	                }
	                else {
	                    markExportAsReferenced(node);
	                }
	            }
	        }
	        function checkExportAssignment(node) {
	            if (checkGrammarModuleElementContext(node, ts.Diagnostics.An_export_assignment_can_only_be_used_in_a_module)) {
	                // If we hit an export assignment in an illegal context, just bail out to avoid cascading errors.
	                return;
	            }
	            var container = node.parent.kind === 251 /* SourceFile */ ? node.parent : node.parent.parent;
	            if (container.kind === 221 /* ModuleDeclaration */ && !ts.isAmbientModule(container)) {
	                error(node, ts.Diagnostics.An_export_assignment_cannot_be_used_in_a_namespace);
	                return;
	            }
	            // Grammar checking
	            if (!checkGrammarDecorators(node) && !checkGrammarModifiers(node) && (node.flags & 1022 /* Modifier */)) {
	                grammarErrorOnFirstToken(node, ts.Diagnostics.An_export_assignment_cannot_have_modifiers);
	            }
	            if (node.expression.kind === 69 /* Identifier */) {
	                markExportAsReferenced(node);
	            }
	            else {
	                checkExpressionCached(node.expression);
	            }
	            checkExternalModuleExports(container);
	            if (node.isExportEquals && !ts.isInAmbientContext(node)) {
	                if (modulekind === 5 /* ES6 */) {
	                    // export assignment is not supported in es6 modules
	                    grammarErrorOnNode(node, ts.Diagnostics.Export_assignment_cannot_be_used_when_targeting_ECMAScript_6_modules_Consider_using_export_default_or_another_module_format_instead);
	                }
	                else if (modulekind === 4 /* System */) {
	                    // system modules does not support export assignment
	                    grammarErrorOnNode(node, ts.Diagnostics.Export_assignment_is_not_supported_when_module_flag_is_system);
	                }
	            }
	        }
	        function hasExportedMembers(moduleSymbol) {
	            for (var id in moduleSymbol.exports) {
	                if (id !== "export=") {
	                    return true;
	                }
	            }
	            return false;
	        }
	        function checkExternalModuleExports(node) {
	            var moduleSymbol = getSymbolOfNode(node);
	            var links = getSymbolLinks(moduleSymbol);
	            if (!links.exportsChecked) {
	                var exportEqualsSymbol = moduleSymbol.exports["export="];
	                if (exportEqualsSymbol && hasExportedMembers(moduleSymbol)) {
	                    var declaration = getDeclarationOfAliasSymbol(exportEqualsSymbol) || exportEqualsSymbol.valueDeclaration;
	                    if (!isTopLevelInExternalModuleAugmentation(declaration)) {
	                        error(declaration, ts.Diagnostics.An_export_assignment_cannot_be_used_in_a_module_with_other_exported_elements);
	                    }
	                }
	                // Checks for export * conflicts
	                var exports = getExportsOfModule(moduleSymbol);
	                for (var id in exports) {
	                    if (id === "__export") {
	                        continue;
	                    }
	                    var _a = exports[id], declarations = _a.declarations, flags = _a.flags;
	                    // ECMA262: 15.2.1.1 It is a Syntax Error if the ExportedNames of ModuleItemList contains any duplicate entries. (TS Exceptions: namespaces, function overloads, enums, and interfaces)
	                    if (!(flags & (1536 /* Namespace */ | 64 /* Interface */ | 384 /* Enum */)) && (flags & 524288 /* TypeAlias */ ? declarations.length - 1 : declarations.length) > 1) {
	                        var exportedDeclarations = ts.filter(declarations, isNotOverload);
	                        if (exportedDeclarations.length > 1) {
	                            for (var _i = 0, exportedDeclarations_1 = exportedDeclarations; _i < exportedDeclarations_1.length; _i++) {
	                                var declaration = exportedDeclarations_1[_i];
	                                diagnostics.add(ts.createDiagnosticForNode(declaration, ts.Diagnostics.Cannot_redeclare_exported_variable_0, id));
	                            }
	                        }
	                    }
	                }
	                links.exportsChecked = true;
	            }
	            function isNotOverload(declaration) {
	                return declaration.kind !== 216 /* FunctionDeclaration */ || !!declaration.body;
	            }
	        }
	        function checkSourceElement(node) {
	            if (!node) {
	                return;
	            }
	            var kind = node.kind;
	            if (cancellationToken) {
	                // Only bother checking on a few construct kinds.  We don't want to be excessivly
	                // hitting the cancellation token on every node we check.
	                switch (kind) {
	                    case 221 /* ModuleDeclaration */:
	                    case 217 /* ClassDeclaration */:
	                    case 218 /* InterfaceDeclaration */:
	                    case 216 /* FunctionDeclaration */:
	                        cancellationToken.throwIfCancellationRequested();
	                }
	            }
	            switch (kind) {
	                case 138 /* TypeParameter */:
	                    return checkTypeParameter(node);
	                case 139 /* Parameter */:
	                    return checkParameter(node);
	                case 142 /* PropertyDeclaration */:
	                case 141 /* PropertySignature */:
	                    return checkPropertyDeclaration(node);
	                case 153 /* FunctionType */:
	                case 154 /* ConstructorType */:
	                case 148 /* CallSignature */:
	                case 149 /* ConstructSignature */:
	                    return checkSignatureDeclaration(node);
	                case 150 /* IndexSignature */:
	                    return checkSignatureDeclaration(node);
	                case 144 /* MethodDeclaration */:
	                case 143 /* MethodSignature */:
	                    return checkMethodDeclaration(node);
	                case 145 /* Constructor */:
	                    return checkConstructorDeclaration(node);
	                case 146 /* GetAccessor */:
	                case 147 /* SetAccessor */:
	                    return checkAccessorDeclaration(node);
	                case 152 /* TypeReference */:
	                    return checkTypeReferenceNode(node);
	                case 151 /* TypePredicate */:
	                    return checkTypePredicate(node);
	                case 155 /* TypeQuery */:
	                    return checkTypeQuery(node);
	                case 156 /* TypeLiteral */:
	                    return checkTypeLiteral(node);
	                case 157 /* ArrayType */:
	                    return checkArrayType(node);
	                case 158 /* TupleType */:
	                    return checkTupleType(node);
	                case 159 /* UnionType */:
	                case 160 /* IntersectionType */:
	                    return checkUnionOrIntersectionType(node);
	                case 161 /* ParenthesizedType */:
	                    return checkSourceElement(node.type);
	                case 216 /* FunctionDeclaration */:
	                    return checkFunctionDeclaration(node);
	                case 195 /* Block */:
	                case 222 /* ModuleBlock */:
	                    return checkBlock(node);
	                case 196 /* VariableStatement */:
	                    return checkVariableStatement(node);
	                case 198 /* ExpressionStatement */:
	                    return checkExpressionStatement(node);
	                case 199 /* IfStatement */:
	                    return checkIfStatement(node);
	                case 200 /* DoStatement */:
	                    return checkDoStatement(node);
	                case 201 /* WhileStatement */:
	                    return checkWhileStatement(node);
	                case 202 /* ForStatement */:
	                    return checkForStatement(node);
	                case 203 /* ForInStatement */:
	                    return checkForInStatement(node);
	                case 204 /* ForOfStatement */:
	                    return checkForOfStatement(node);
	                case 205 /* ContinueStatement */:
	                case 206 /* BreakStatement */:
	                    return checkBreakOrContinueStatement(node);
	                case 207 /* ReturnStatement */:
	                    return checkReturnStatement(node);
	                case 208 /* WithStatement */:
	                    return checkWithStatement(node);
	                case 209 /* SwitchStatement */:
	                    return checkSwitchStatement(node);
	                case 210 /* LabeledStatement */:
	                    return checkLabeledStatement(node);
	                case 211 /* ThrowStatement */:
	                    return checkThrowStatement(node);
	                case 212 /* TryStatement */:
	                    return checkTryStatement(node);
	                case 214 /* VariableDeclaration */:
	                    return checkVariableDeclaration(node);
	                case 166 /* BindingElement */:
	                    return checkBindingElement(node);
	                case 217 /* ClassDeclaration */:
	                    return checkClassDeclaration(node);
	                case 218 /* InterfaceDeclaration */:
	                    return checkInterfaceDeclaration(node);
	                case 219 /* TypeAliasDeclaration */:
	                    return checkTypeAliasDeclaration(node);
	                case 220 /* EnumDeclaration */:
	                    return checkEnumDeclaration(node);
	                case 221 /* ModuleDeclaration */:
	                    return checkModuleDeclaration(node);
	                case 225 /* ImportDeclaration */:
	                    return checkImportDeclaration(node);
	                case 224 /* ImportEqualsDeclaration */:
	                    return checkImportEqualsDeclaration(node);
	                case 231 /* ExportDeclaration */:
	                    return checkExportDeclaration(node);
	                case 230 /* ExportAssignment */:
	                    return checkExportAssignment(node);
	                case 197 /* EmptyStatement */:
	                    checkGrammarStatementInAmbientContext(node);
	                    return;
	                case 213 /* DebuggerStatement */:
	                    checkGrammarStatementInAmbientContext(node);
	                    return;
	                case 234 /* MissingDeclaration */:
	                    return checkMissingDeclaration(node);
	            }
	        }
	        // Function and class expression bodies are checked after all statements in the enclosing body. This is
	        // to ensure constructs like the following are permitted:
	        //     const foo = function () {
	        //        const s = foo();
	        //        return "hello";
	        //     }
	        // Here, performing a full type check of the body of the function expression whilst in the process of
	        // determining the type of foo would cause foo to be given type any because of the recursive reference.
	        // Delaying the type check of the body ensures foo has been assigned a type.
	        function checkNodeDeferred(node) {
	            if (deferredNodes) {
	                deferredNodes.push(node);
	            }
	        }
	        function checkDeferredNodes() {
	            for (var _i = 0, deferredNodes_1 = deferredNodes; _i < deferredNodes_1.length; _i++) {
	                var node = deferredNodes_1[_i];
	                switch (node.kind) {
	                    case 176 /* FunctionExpression */:
	                    case 177 /* ArrowFunction */:
	                    case 144 /* MethodDeclaration */:
	                    case 143 /* MethodSignature */:
	                        checkFunctionExpressionOrObjectLiteralMethodDeferred(node);
	                        break;
	                    case 146 /* GetAccessor */:
	                    case 147 /* SetAccessor */:
	                        checkAccessorDeferred(node);
	                        break;
	                    case 189 /* ClassExpression */:
	                        checkClassExpressionDeferred(node);
	                        break;
	                }
	            }
	        }
	        function checkSourceFile(node) {
	            var start = new Date().getTime();
	            checkSourceFileWorker(node);
	            ts.checkTime += new Date().getTime() - start;
	        }
	        // Fully type check a source file and collect the relevant diagnostics.
	        function checkSourceFileWorker(node) {
	            var links = getNodeLinks(node);
	            if (!(links.flags & 1 /* TypeChecked */)) {
	                // Check whether the file has declared it is the default lib,
	                // and whether the user has specifically chosen to avoid checking it.
	                if (compilerOptions.skipDefaultLibCheck) {
	                    // If the user specified '--noLib' and a file has a '/// <reference no-default-lib="true"/>',
	                    // then we should treat that file as a default lib.
	                    if (node.hasNoDefaultLib) {
	                        return;
	                    }
	                }
	                // Grammar checking
	                checkGrammarSourceFile(node);
	                potentialThisCollisions.length = 0;
	                deferredNodes = [];
	                ts.forEach(node.statements, checkSourceElement);
	                checkDeferredNodes();
	                deferredNodes = undefined;
	                if (ts.isExternalOrCommonJsModule(node)) {
	                    checkExternalModuleExports(node);
	                }
	                if (potentialThisCollisions.length) {
	                    ts.forEach(potentialThisCollisions, checkIfThisIsCapturedInEnclosingScope);
	                    potentialThisCollisions.length = 0;
	                }
	                links.flags |= 1 /* TypeChecked */;
	            }
	        }
	        function getDiagnostics(sourceFile, ct) {
	            try {
	                // Record the cancellation token so it can be checked later on during checkSourceElement.
	                // Do this in a finally block so we can ensure that it gets reset back to nothing after
	                // this call is done.
	                cancellationToken = ct;
	                return getDiagnosticsWorker(sourceFile);
	            }
	            finally {
	                cancellationToken = undefined;
	            }
	        }
	        function getDiagnosticsWorker(sourceFile) {
	            throwIfNonDiagnosticsProducing();
	            if (sourceFile) {
	                checkSourceFile(sourceFile);
	                return diagnostics.getDiagnostics(sourceFile.fileName);
	            }
	            ts.forEach(host.getSourceFiles(), checkSourceFile);
	            return diagnostics.getDiagnostics();
	        }
	        function getGlobalDiagnostics() {
	            throwIfNonDiagnosticsProducing();
	            return diagnostics.getGlobalDiagnostics();
	        }
	        function throwIfNonDiagnosticsProducing() {
	            if (!produceDiagnostics) {
	                throw new Error("Trying to get diagnostics from a type checker that does not produce them.");
	            }
	        }
	        // Language service support
	        function isInsideWithStatementBody(node) {
	            if (node) {
	                while (node.parent) {
	                    if (node.parent.kind === 208 /* WithStatement */ && node.parent.statement === node) {
	                        return true;
	                    }
	                    node = node.parent;
	                }
	            }
	            return false;
	        }
	        function getSymbolsInScope(location, meaning) {
	            var symbols = {};
	            var memberFlags = 0;
	            if (isInsideWithStatementBody(location)) {
	                // We cannot answer semantic questions within a with block, do not proceed any further
	                return [];
	            }
	            populateSymbols();
	            return symbolsToArray(symbols);
	            function populateSymbols() {
	                while (location) {
	                    if (location.locals && !isGlobalSourceFile(location)) {
	                        copySymbols(location.locals, meaning);
	                    }
	                    switch (location.kind) {
	                        case 251 /* SourceFile */:
	                            if (!ts.isExternalOrCommonJsModule(location)) {
	                                break;
	                            }
	                        case 221 /* ModuleDeclaration */:
	                            copySymbols(getSymbolOfNode(location).exports, meaning & 8914931 /* ModuleMember */);
	                            break;
	                        case 220 /* EnumDeclaration */:
	                            copySymbols(getSymbolOfNode(location).exports, meaning & 8 /* EnumMember */);
	                            break;
	                        case 189 /* ClassExpression */:
	                            var className = location.name;
	                            if (className) {
	                                copySymbol(location.symbol, meaning);
	                            }
	                        // fall through; this fall-through is necessary because we would like to handle
	                        // type parameter inside class expression similar to how we handle it in classDeclaration and interface Declaration
	                        case 217 /* ClassDeclaration */:
	                        case 218 /* InterfaceDeclaration */:
	                            // If we didn't come from static member of class or interface,
	                            // add the type parameters into the symbol table
	                            // (type parameters of classDeclaration/classExpression and interface are in member property of the symbol.
	                            // Note: that the memberFlags come from previous iteration.
	                            if (!(memberFlags & 64 /* Static */)) {
	                                copySymbols(getSymbolOfNode(location).members, meaning & 793056 /* Type */);
	                            }
	                            break;
	                        case 176 /* FunctionExpression */:
	                            var funcName = location.name;
	                            if (funcName) {
	                                copySymbol(location.symbol, meaning);
	                            }
	                            break;
	                    }
	                    if (ts.introducesArgumentsExoticObject(location)) {
	                        copySymbol(argumentsSymbol, meaning);
	                    }
	                    memberFlags = location.flags;
	                    location = location.parent;
	                }
	                copySymbols(globals, meaning);
	            }
	            /**
	             * Copy the given symbol into symbol tables if the symbol has the given meaning
	             * and it doesn't already existed in the symbol table
	             * @param key a key for storing in symbol table; if undefined, use symbol.name
	             * @param symbol the symbol to be added into symbol table
	             * @param meaning meaning of symbol to filter by before adding to symbol table
	             */
	            function copySymbol(symbol, meaning) {
	                if (symbol.flags & meaning) {
	                    var id = symbol.name;
	                    // We will copy all symbol regardless of its reserved name because
	                    // symbolsToArray will check whether the key is a reserved name and
	                    // it will not copy symbol with reserved name to the array
	                    if (!ts.hasProperty(symbols, id)) {
	                        symbols[id] = symbol;
	                    }
	                }
	            }
	            function copySymbols(source, meaning) {
	                if (meaning) {
	                    for (var id in source) {
	                        var symbol = source[id];
	                        copySymbol(symbol, meaning);
	                    }
	                }
	            }
	        }
	        function isTypeDeclarationName(name) {
	            return name.kind === 69 /* Identifier */ &&
	                isTypeDeclaration(name.parent) &&
	                name.parent.name === name;
	        }
	        function isTypeDeclaration(node) {
	            switch (node.kind) {
	                case 138 /* TypeParameter */:
	                case 217 /* ClassDeclaration */:
	                case 218 /* InterfaceDeclaration */:
	                case 219 /* TypeAliasDeclaration */:
	                case 220 /* EnumDeclaration */:
	                    return true;
	            }
	        }
	        // True if the given identifier is part of a type reference
	        function isTypeReferenceIdentifier(entityName) {
	            var node = entityName;
	            while (node.parent && node.parent.kind === 136 /* QualifiedName */) {
	                node = node.parent;
	            }
	            return node.parent && node.parent.kind === 152 /* TypeReference */;
	        }
	        function isHeritageClauseElementIdentifier(entityName) {
	            var node = entityName;
	            while (node.parent && node.parent.kind === 169 /* PropertyAccessExpression */) {
	                node = node.parent;
	            }
	            return node.parent && node.parent.kind === 191 /* ExpressionWithTypeArguments */;
	        }
	        function getLeftSideOfImportEqualsOrExportAssignment(nodeOnRightSide) {
	            while (nodeOnRightSide.parent.kind === 136 /* QualifiedName */) {
	                nodeOnRightSide = nodeOnRightSide.parent;
	            }
	            if (nodeOnRightSide.parent.kind === 224 /* ImportEqualsDeclaration */) {
	                return nodeOnRightSide.parent.moduleReference === nodeOnRightSide && nodeOnRightSide.parent;
	            }
	            if (nodeOnRightSide.parent.kind === 230 /* ExportAssignment */) {
	                return nodeOnRightSide.parent.expression === nodeOnRightSide && nodeOnRightSide.parent;
	            }
	            return undefined;
	        }
	        function isInRightSideOfImportOrExportAssignment(node) {
	            return getLeftSideOfImportEqualsOrExportAssignment(node) !== undefined;
	        }
	        function getSymbolOfEntityNameOrPropertyAccessExpression(entityName) {
	            if (ts.isDeclarationName(entityName)) {
	                return getSymbolOfNode(entityName.parent);
	            }
	            if (ts.isInJavaScriptFile(entityName) && entityName.parent.kind === 169 /* PropertyAccessExpression */) {
	                var specialPropertyAssignmentKind = ts.getSpecialPropertyAssignmentKind(entityName.parent.parent);
	                switch (specialPropertyAssignmentKind) {
	                    case 1 /* ExportsProperty */:
	                    case 3 /* PrototypeProperty */:
	                        return getSymbolOfNode(entityName.parent);
	                    case 4 /* ThisProperty */:
	                    case 2 /* ModuleExports */:
	                        return getSymbolOfNode(entityName.parent.parent);
	                    default:
	                }
	            }
	            if (entityName.parent.kind === 230 /* ExportAssignment */) {
	                return resolveEntityName(entityName, 
	                /*all meanings*/ 107455 /* Value */ | 793056 /* Type */ | 1536 /* Namespace */ | 8388608 /* Alias */);
	            }
	            if (entityName.kind !== 169 /* PropertyAccessExpression */) {
	                if (isInRightSideOfImportOrExportAssignment(entityName)) {
	                    // Since we already checked for ExportAssignment, this really could only be an Import
	                    return getSymbolOfPartOfRightHandSideOfImportEquals(entityName);
	                }
	            }
	            if (ts.isRightSideOfQualifiedNameOrPropertyAccess(entityName)) {
	                entityName = entityName.parent;
	            }
	            if (isHeritageClauseElementIdentifier(entityName)) {
	                var meaning = 0 /* None */;
	                // In an interface or class, we're definitely interested in a type.
	                if (entityName.parent.kind === 191 /* ExpressionWithTypeArguments */) {
	                    meaning = 793056 /* Type */;
	                    // In a class 'extends' clause we are also looking for a value.
	                    if (ts.isExpressionWithTypeArgumentsInClassExtendsClause(entityName.parent)) {
	                        meaning |= 107455 /* Value */;
	                    }
	                }
	                else {
	                    meaning = 1536 /* Namespace */;
	                }
	                meaning |= 8388608 /* Alias */;
	                return resolveEntityName(entityName, meaning);
	            }
	            else if ((entityName.parent.kind === 238 /* JsxOpeningElement */) ||
	                (entityName.parent.kind === 237 /* JsxSelfClosingElement */) ||
	                (entityName.parent.kind === 240 /* JsxClosingElement */)) {
	                return getJsxElementTagSymbol(entityName.parent);
	            }
	            else if (ts.isExpression(entityName)) {
	                if (ts.nodeIsMissing(entityName)) {
	                    // Missing entity name.
	                    return undefined;
	                }
	                if (entityName.kind === 69 /* Identifier */) {
	                    // Include aliases in the meaning, this ensures that we do not follow aliases to where they point and instead
	                    // return the alias symbol.
	                    var meaning = 107455 /* Value */ | 8388608 /* Alias */;
	                    return resolveEntityName(entityName, meaning);
	                }
	                else if (entityName.kind === 169 /* PropertyAccessExpression */) {
	                    var symbol = getNodeLinks(entityName).resolvedSymbol;
	                    if (!symbol) {
	                        checkPropertyAccessExpression(entityName);
	                    }
	                    return getNodeLinks(entityName).resolvedSymbol;
	                }
	                else if (entityName.kind === 136 /* QualifiedName */) {
	                    var symbol = getNodeLinks(entityName).resolvedSymbol;
	                    if (!symbol) {
	                        checkQualifiedName(entityName);
	                    }
	                    return getNodeLinks(entityName).resolvedSymbol;
	                }
	            }
	            else if (isTypeReferenceIdentifier(entityName)) {
	                var meaning = entityName.parent.kind === 152 /* TypeReference */ ? 793056 /* Type */ : 1536 /* Namespace */;
	                // Include aliases in the meaning, this ensures that we do not follow aliases to where they point and instead
	                // return the alias symbol.
	                meaning |= 8388608 /* Alias */;
	                return resolveEntityName(entityName, meaning);
	            }
	            else if (entityName.parent.kind === 241 /* JsxAttribute */) {
	                return getJsxAttributePropertySymbol(entityName.parent);
	            }
	            if (entityName.parent.kind === 151 /* TypePredicate */) {
	                return resolveEntityName(entityName, /*meaning*/ 1 /* FunctionScopedVariable */);
	            }
	            // Do we want to return undefined here?
	            return undefined;
	        }
	        function getSymbolAtLocation(node) {
	            if (isInsideWithStatementBody(node)) {
	                // We cannot answer semantic questions within a with block, do not proceed any further
	                return undefined;
	            }
	            if (ts.isDeclarationName(node)) {
	                // This is a declaration, call getSymbolOfNode
	                return getSymbolOfNode(node.parent);
	            }
	            if (node.kind === 69 /* Identifier */) {
	                if (isInRightSideOfImportOrExportAssignment(node)) {
	                    return node.parent.kind === 230 /* ExportAssignment */
	                        ? getSymbolOfEntityNameOrPropertyAccessExpression(node)
	                        : getSymbolOfPartOfRightHandSideOfImportEquals(node);
	                }
	                else if (node.parent.kind === 166 /* BindingElement */ &&
	                    node.parent.parent.kind === 164 /* ObjectBindingPattern */ &&
	                    node === node.parent.propertyName) {
	                    var typeOfPattern = getTypeOfNode(node.parent.parent);
	                    var propertyDeclaration = typeOfPattern && getPropertyOfType(typeOfPattern, node.text);
	                    if (propertyDeclaration) {
	                        return propertyDeclaration;
	                    }
	                }
	            }
	            switch (node.kind) {
	                case 69 /* Identifier */:
	                case 169 /* PropertyAccessExpression */:
	                case 136 /* QualifiedName */:
	                    return getSymbolOfEntityNameOrPropertyAccessExpression(node);
	                case 97 /* ThisKeyword */:
	                case 95 /* SuperKeyword */:
	                    var type = ts.isExpression(node) ? checkExpression(node) : getTypeFromTypeNode(node);
	                    return type.symbol;
	                case 162 /* ThisType */:
	                    return getTypeFromTypeNode(node).symbol;
	                case 121 /* ConstructorKeyword */:
	                    // constructor keyword for an overload, should take us to the definition if it exist
	                    var constructorDeclaration = node.parent;
	                    if (constructorDeclaration && constructorDeclaration.kind === 145 /* Constructor */) {
	                        return constructorDeclaration.parent.symbol;
	                    }
	                    return undefined;
	                case 9 /* StringLiteral */:
	                    // External module name in an import declaration
	                    if ((ts.isExternalModuleImportEqualsDeclaration(node.parent.parent) &&
	                        ts.getExternalModuleImportEqualsDeclarationExpression(node.parent.parent) === node) ||
	                        ((node.parent.kind === 225 /* ImportDeclaration */ || node.parent.kind === 231 /* ExportDeclaration */) &&
	                            node.parent.moduleSpecifier === node)) {
	                        return resolveExternalModuleName(node, node);
	                    }
	                // Fall through
	                case 8 /* NumericLiteral */:
	                    // index access
	                    if (node.parent.kind === 170 /* ElementAccessExpression */ && node.parent.argumentExpression === node) {
	                        var objectType = checkExpression(node.parent.expression);
	                        if (objectType === unknownType)
	                            return undefined;
	                        var apparentType = getApparentType(objectType);
	                        if (apparentType === unknownType)
	                            return undefined;
	                        return getPropertyOfType(apparentType, node.text);
	                    }
	                    break;
	            }
	            return undefined;
	        }
	        function getShorthandAssignmentValueSymbol(location) {
	            // The function returns a value symbol of an identifier in the short-hand property assignment.
	            // This is necessary as an identifier in short-hand property assignment can contains two meaning:
	            // property name and property value.
	            if (location && location.kind === 249 /* ShorthandPropertyAssignment */) {
	                return resolveEntityName(location.name, 107455 /* Value */ | 8388608 /* Alias */);
	            }
	            return undefined;
	        }
	        /** Returns the target of an export specifier without following aliases */
	        function getExportSpecifierLocalTargetSymbol(node) {
	            return node.parent.parent.moduleSpecifier ?
	                getExternalModuleMember(node.parent.parent, node) :
	                resolveEntityName(node.propertyName || node.name, 107455 /* Value */ | 793056 /* Type */ | 1536 /* Namespace */ | 8388608 /* Alias */);
	        }
	        function getTypeOfNode(node) {
	            if (isInsideWithStatementBody(node)) {
	                // We cannot answer semantic questions within a with block, do not proceed any further
	                return unknownType;
	            }
	            if (ts.isTypeNode(node)) {
	                return getTypeFromTypeNode(node);
	            }
	            if (ts.isExpression(node)) {
	                return getTypeOfExpression(node);
	            }
	            if (ts.isExpressionWithTypeArgumentsInClassExtendsClause(node)) {
	                // A SyntaxKind.ExpressionWithTypeArguments is considered a type node, except when it occurs in the
	                // extends clause of a class. We handle that case here.
	                return getBaseTypes(getDeclaredTypeOfSymbol(getSymbolOfNode(node.parent.parent)))[0];
	            }
	            if (isTypeDeclaration(node)) {
	                // In this case, we call getSymbolOfNode instead of getSymbolAtLocation because it is a declaration
	                var symbol = getSymbolOfNode(node);
	                return getDeclaredTypeOfSymbol(symbol);
	            }
	            if (isTypeDeclarationName(node)) {
	                var symbol = getSymbolAtLocation(node);
	                return symbol && getDeclaredTypeOfSymbol(symbol);
	            }
	            if (ts.isDeclaration(node)) {
	                // In this case, we call getSymbolOfNode instead of getSymbolAtLocation because it is a declaration
	                var symbol = getSymbolOfNode(node);
	                return getTypeOfSymbol(symbol);
	            }
	            if (ts.isDeclarationName(node)) {
	                var symbol = getSymbolAtLocation(node);
	                return symbol && getTypeOfSymbol(symbol);
	            }
	            if (ts.isBindingPattern(node)) {
	                return getTypeForVariableLikeDeclaration(node.parent);
	            }
	            if (isInRightSideOfImportOrExportAssignment(node)) {
	                var symbol = getSymbolAtLocation(node);
	                var declaredType = symbol && getDeclaredTypeOfSymbol(symbol);
	                return declaredType !== unknownType ? declaredType : getTypeOfSymbol(symbol);
	            }
	            return unknownType;
	        }
	        function getTypeOfExpression(expr) {
	            if (ts.isRightSideOfQualifiedNameOrPropertyAccess(expr)) {
	                expr = expr.parent;
	            }
	            return checkExpression(expr);
	        }
	        /**
	          * Gets either the static or instance type of a class element, based on
	          * whether the element is declared as "static".
	          */
	        function getParentTypeOfClassElement(node) {
	            var classSymbol = getSymbolOfNode(node.parent);
	            return node.flags & 64 /* Static */
	                ? getTypeOfSymbol(classSymbol)
	                : getDeclaredTypeOfSymbol(classSymbol);
	        }
	        // Return the list of properties of the given type, augmented with properties from Function
	        // if the type has call or construct signatures
	        function getAugmentedPropertiesOfType(type) {
	            type = getApparentType(type);
	            var propsByName = createSymbolTable(getPropertiesOfType(type));
	            if (getSignaturesOfType(type, 0 /* Call */).length || getSignaturesOfType(type, 1 /* Construct */).length) {
	                ts.forEach(getPropertiesOfType(globalFunctionType), function (p) {
	                    if (!ts.hasProperty(propsByName, p.name)) {
	                        propsByName[p.name] = p;
	                    }
	                });
	            }
	            return getNamedMembers(propsByName);
	        }
	        function getRootSymbols(symbol) {
	            if (symbol.flags & 268435456 /* SyntheticProperty */) {
	                var symbols_3 = [];
	                var name_18 = symbol.name;
	                ts.forEach(getSymbolLinks(symbol).containingType.types, function (t) {
	                    var symbol = getPropertyOfType(t, name_18);
	                    if (symbol) {
	                        symbols_3.push(symbol);
	                    }
	                });
	                return symbols_3;
	            }
	            else if (symbol.flags & 67108864 /* Transient */) {
	                var target = getSymbolLinks(symbol).target;
	                if (target) {
	                    return [target];
	                }
	            }
	            return [symbol];
	        }
	        // Emitter support
	        function isArgumentsLocalBinding(node) {
	            return getReferencedValueSymbol(node) === argumentsSymbol;
	        }
	        function moduleExportsSomeValue(moduleReferenceExpression) {
	            var moduleSymbol = resolveExternalModuleName(moduleReferenceExpression.parent, moduleReferenceExpression);
	            if (!moduleSymbol) {
	                // module not found - be conservative
	                return true;
	            }
	            var hasExportAssignment = hasExportAssignmentSymbol(moduleSymbol);
	            // if module has export assignment then 'resolveExternalModuleSymbol' will return resolved symbol for export assignment
	            // otherwise it will return moduleSymbol itself
	            moduleSymbol = resolveExternalModuleSymbol(moduleSymbol);
	            var symbolLinks = getSymbolLinks(moduleSymbol);
	            if (symbolLinks.exportsSomeValue === undefined) {
	                // for export assignments - check if resolved symbol for RHS is itself a value
	                // otherwise - check if at least one export is value
	                symbolLinks.exportsSomeValue = hasExportAssignment
	                    ? !!(moduleSymbol.flags & 107455 /* Value */)
	                    : ts.forEachValue(getExportsOfModule(moduleSymbol), isValue);
	            }
	            return symbolLinks.exportsSomeValue;
	            function isValue(s) {
	                s = resolveSymbol(s);
	                return s && !!(s.flags & 107455 /* Value */);
	            }
	        }
	        // When resolved as an expression identifier, if the given node references an exported entity, return the declaration
	        // node of the exported entity's container. Otherwise, return undefined.
	        function getReferencedExportContainer(node) {
	            var symbol = getReferencedValueSymbol(node);
	            if (symbol) {
	                if (symbol.flags & 1048576 /* ExportValue */) {
	                    // If we reference an exported entity within the same module declaration, then whether
	                    // we prefix depends on the kind of entity. SymbolFlags.ExportHasLocal encompasses all the
	                    // kinds that we do NOT prefix.
	                    var exportSymbol = getMergedSymbol(symbol.exportSymbol);
	                    if (exportSymbol.flags & 944 /* ExportHasLocal */) {
	                        return undefined;
	                    }
	                    symbol = exportSymbol;
	                }
	                var parentSymbol = getParentOfSymbol(symbol);
	                if (parentSymbol) {
	                    if (parentSymbol.flags & 512 /* ValueModule */ && parentSymbol.valueDeclaration.kind === 251 /* SourceFile */) {
	                        return parentSymbol.valueDeclaration;
	                    }
	                    for (var n = node.parent; n; n = n.parent) {
	                        if ((n.kind === 221 /* ModuleDeclaration */ || n.kind === 220 /* EnumDeclaration */) && getSymbolOfNode(n) === parentSymbol) {
	                            return n;
	                        }
	                    }
	                }
	            }
	        }
	        // When resolved as an expression identifier, if the given node references an import, return the declaration of
	        // that import. Otherwise, return undefined.
	        function getReferencedImportDeclaration(node) {
	            var symbol = getReferencedValueSymbol(node);
	            return symbol && symbol.flags & 8388608 /* Alias */ ? getDeclarationOfAliasSymbol(symbol) : undefined;
	        }
	        function isSymbolOfDeclarationWithCollidingName(symbol) {
	            if (symbol.flags & 418 /* BlockScoped */) {
	                var links = getSymbolLinks(symbol);
	                if (links.isDeclaratonWithCollidingName === undefined) {
	                    var container = ts.getEnclosingBlockScopeContainer(symbol.valueDeclaration);
	                    if (ts.isStatementWithLocals(container)) {
	                        var nodeLinks_1 = getNodeLinks(symbol.valueDeclaration);
	                        if (!!resolveName(container.parent, symbol.name, 107455 /* Value */, /*nameNotFoundMessage*/ undefined, /*nameArg*/ undefined)) {
	                            // redeclaration - always should be renamed
	                            links.isDeclaratonWithCollidingName = true;
	                        }
	                        else if (nodeLinks_1.flags & 131072 /* CapturedBlockScopedBinding */) {
	                            // binding is captured in the function
	                            // should be renamed if:
	                            // - binding is not top level - top level bindings never collide with anything
	                            // AND
	                            //   - binding is not declared in loop, should be renamed to avoid name reuse across siblings
	                            //     let a, b
	                            //     { let x = 1; a = () => x;  }
	                            //     { let x = 100; b = () => x; }
	                            //     console.log(a()); // should print '1'
	                            //     console.log(b()); // should print '100'
	                            //     OR
	                            //   - binding is declared inside loop but not in inside initializer of iteration statement or directly inside loop body
	                            //     * variables from initializer are passed to rewritted loop body as parameters so they are not captured directly
	                            //     * variables that are declared immediately in loop body will become top level variable after loop is rewritten and thus
	                            //       they will not collide with anything
	                            var isDeclaredInLoop = nodeLinks_1.flags & 262144 /* BlockScopedBindingInLoop */;
	                            var inLoopInitializer = ts.isIterationStatement(container, /*lookInLabeledStatements*/ false);
	                            var inLoopBodyBlock = container.kind === 195 /* Block */ && ts.isIterationStatement(container.parent, /*lookInLabeledStatements*/ false);
	                            links.isDeclaratonWithCollidingName = !ts.isBlockScopedContainerTopLevel(container) && (!isDeclaredInLoop || (!inLoopInitializer && !inLoopBodyBlock));
	                        }
	                        else {
	                            links.isDeclaratonWithCollidingName = false;
	                        }
	                    }
	                }
	                return links.isDeclaratonWithCollidingName;
	            }
	            return false;
	        }
	        // When resolved as an expression identifier, if the given node references a nested block scoped entity with
	        // a name that either hides an existing name or might hide it when compiled downlevel,
	        // return the declaration of that entity. Otherwise, return undefined.
	        function getReferencedDeclarationWithCollidingName(node) {
	            var symbol = getReferencedValueSymbol(node);
	            return symbol && isSymbolOfDeclarationWithCollidingName(symbol) ? symbol.valueDeclaration : undefined;
	        }
	        // Return true if the given node is a declaration of a nested block scoped entity with a name that either hides an
	        // existing name or might hide a name when compiled downlevel
	        function isDeclarationWithCollidingName(node) {
	            return isSymbolOfDeclarationWithCollidingName(getSymbolOfNode(node));
	        }
	        function isValueAliasDeclaration(node) {
	            switch (node.kind) {
	                case 224 /* ImportEqualsDeclaration */:
	                case 226 /* ImportClause */:
	                case 227 /* NamespaceImport */:
	                case 229 /* ImportSpecifier */:
	                case 233 /* ExportSpecifier */:
	                    return isAliasResolvedToValue(getSymbolOfNode(node));
	                case 231 /* ExportDeclaration */:
	                    var exportClause = node.exportClause;
	                    return exportClause && ts.forEach(exportClause.elements, isValueAliasDeclaration);
	                case 230 /* ExportAssignment */:
	                    return node.expression && node.expression.kind === 69 /* Identifier */ ? isAliasResolvedToValue(getSymbolOfNode(node)) : true;
	            }
	            return false;
	        }
	        function isTopLevelValueImportEqualsWithEntityName(node) {
	            if (node.parent.kind !== 251 /* SourceFile */ || !ts.isInternalModuleImportEqualsDeclaration(node)) {
	                // parent is not source file or it is not reference to internal module
	                return false;
	            }
	            var isValue = isAliasResolvedToValue(getSymbolOfNode(node));
	            return isValue && node.moduleReference && !ts.nodeIsMissing(node.moduleReference);
	        }
	        function isAliasResolvedToValue(symbol) {
	            var target = resolveAlias(symbol);
	            if (target === unknownSymbol && compilerOptions.isolatedModules) {
	                return true;
	            }
	            // const enums and modules that contain only const enums are not considered values from the emit perespective
	            // unless 'preserveConstEnums' option is set to true
	            return target !== unknownSymbol &&
	                target &&
	                target.flags & 107455 /* Value */ &&
	                (compilerOptions.preserveConstEnums || !isConstEnumOrConstEnumOnlyModule(target));
	        }
	        function isConstEnumOrConstEnumOnlyModule(s) {
	            return isConstEnumSymbol(s) || s.constEnumOnlyModule;
	        }
	        function isReferencedAliasDeclaration(node, checkChildren) {
	            if (ts.isAliasSymbolDeclaration(node)) {
	                var symbol = getSymbolOfNode(node);
	                if (getSymbolLinks(symbol).referenced) {
	                    return true;
	                }
	            }
	            if (checkChildren) {
	                return ts.forEachChild(node, function (node) { return isReferencedAliasDeclaration(node, checkChildren); });
	            }
	            return false;
	        }
	        function isImplementationOfOverload(node) {
	            if (ts.nodeIsPresent(node.body)) {
	                var symbol = getSymbolOfNode(node);
	                var signaturesOfSymbol = getSignaturesOfSymbol(symbol);
	                // If this function body corresponds to function with multiple signature, it is implementation of overload
	                // e.g.: function foo(a: string): string;
	                //       function foo(a: number): number;
	                //       function foo(a: any) { // This is implementation of the overloads
	                //           return a;
	                //       }
	                return signaturesOfSymbol.length > 1 ||
	                    // If there is single signature for the symbol, it is overload if that signature isn't coming from the node
	                    // e.g.: function foo(a: string): string;
	                    //       function foo(a: any) { // This is implementation of the overloads
	                    //           return a;
	                    //       }
	                    (signaturesOfSymbol.length === 1 && signaturesOfSymbol[0].declaration !== node);
	            }
	            return false;
	        }
	        function getNodeCheckFlags(node) {
	            return getNodeLinks(node).flags;
	        }
	        function getEnumMemberValue(node) {
	            computeEnumMemberValues(node.parent);
	            return getNodeLinks(node).enumMemberValue;
	        }
	        function getConstantValue(node) {
	            if (node.kind === 250 /* EnumMember */) {
	                return getEnumMemberValue(node);
	            }
	            var symbol = getNodeLinks(node).resolvedSymbol;
	            if (symbol && (symbol.flags & 8 /* EnumMember */)) {
	                // inline property\index accesses only for const enums
	                if (ts.isConstEnumDeclaration(symbol.valueDeclaration.parent)) {
	                    return getEnumMemberValue(symbol.valueDeclaration);
	                }
	            }
	            return undefined;
	        }
	        function isFunctionType(type) {
	            return type.flags & 80896 /* ObjectType */ && getSignaturesOfType(type, 0 /* Call */).length > 0;
	        }
	        function getTypeReferenceSerializationKind(typeName) {
	            // Resolve the symbol as a value to ensure the type can be reached at runtime during emit.
	            var valueSymbol = resolveEntityName(typeName, 107455 /* Value */, /*ignoreErrors*/ true);
	            var constructorType = valueSymbol ? getTypeOfSymbol(valueSymbol) : undefined;
	            if (constructorType && isConstructorType(constructorType)) {
	                return ts.TypeReferenceSerializationKind.TypeWithConstructSignatureAndValue;
	            }
	            // Resolve the symbol as a type so that we can provide a more useful hint for the type serializer.
	            var typeSymbol = resolveEntityName(typeName, 793056 /* Type */, /*ignoreErrors*/ true);
	            // We might not be able to resolve type symbol so use unknown type in that case (eg error case)
	            if (!typeSymbol) {
	                return ts.TypeReferenceSerializationKind.ObjectType;
	            }
	            var type = getDeclaredTypeOfSymbol(typeSymbol);
	            if (type === unknownType) {
	                return ts.TypeReferenceSerializationKind.Unknown;
	            }
	            else if (type.flags & 1 /* Any */) {
	                return ts.TypeReferenceSerializationKind.ObjectType;
	            }
	            else if (allConstituentTypesHaveKind(type, 16 /* Void */)) {
	                return ts.TypeReferenceSerializationKind.VoidType;
	            }
	            else if (allConstituentTypesHaveKind(type, 8 /* Boolean */)) {
	                return ts.TypeReferenceSerializationKind.BooleanType;
	            }
	            else if (allConstituentTypesHaveKind(type, 132 /* NumberLike */)) {
	                return ts.TypeReferenceSerializationKind.NumberLikeType;
	            }
	            else if (allConstituentTypesHaveKind(type, 258 /* StringLike */)) {
	                return ts.TypeReferenceSerializationKind.StringLikeType;
	            }
	            else if (allConstituentTypesHaveKind(type, 8192 /* Tuple */)) {
	                return ts.TypeReferenceSerializationKind.ArrayLikeType;
	            }
	            else if (allConstituentTypesHaveKind(type, 16777216 /* ESSymbol */)) {
	                return ts.TypeReferenceSerializationKind.ESSymbolType;
	            }
	            else if (isFunctionType(type)) {
	                return ts.TypeReferenceSerializationKind.TypeWithCallSignature;
	            }
	            else if (isArrayType(type)) {
	                return ts.TypeReferenceSerializationKind.ArrayLikeType;
	            }
	            else {
	                return ts.TypeReferenceSerializationKind.ObjectType;
	            }
	        }
	        function writeTypeOfDeclaration(declaration, enclosingDeclaration, flags, writer) {
	            // Get type of the symbol if this is the valid symbol otherwise get type at location
	            var symbol = getSymbolOfNode(declaration);
	            var type = symbol && !(symbol.flags & (2048 /* TypeLiteral */ | 131072 /* Signature */))
	                ? getTypeOfSymbol(symbol)
	                : unknownType;
	            getSymbolDisplayBuilder().buildTypeDisplay(type, writer, enclosingDeclaration, flags);
	        }
	        function writeReturnTypeOfSignatureDeclaration(signatureDeclaration, enclosingDeclaration, flags, writer) {
	            var signature = getSignatureFromDeclaration(signatureDeclaration);
	            getSymbolDisplayBuilder().buildTypeDisplay(getReturnTypeOfSignature(signature), writer, enclosingDeclaration, flags);
	        }
	        function writeTypeOfExpression(expr, enclosingDeclaration, flags, writer) {
	            var type = getTypeOfExpression(expr);
	            getSymbolDisplayBuilder().buildTypeDisplay(type, writer, enclosingDeclaration, flags);
	        }
	        function hasGlobalName(name) {
	            return ts.hasProperty(globals, name);
	        }
	        function getReferencedValueSymbol(reference) {
	            return getNodeLinks(reference).resolvedSymbol ||
	                resolveName(reference, reference.text, 107455 /* Value */ | 1048576 /* ExportValue */ | 8388608 /* Alias */, 
	                /*nodeNotFoundMessage*/ undefined, /*nameArg*/ undefined);
	        }
	        function getReferencedValueDeclaration(reference) {
	            ts.Debug.assert(!ts.nodeIsSynthesized(reference));
	            var symbol = getReferencedValueSymbol(reference);
	            return symbol && getExportSymbolOfValueSymbolIfExported(symbol).valueDeclaration;
	        }
	        function createResolver() {
	            return {
	                getReferencedExportContainer: getReferencedExportContainer,
	                getReferencedImportDeclaration: getReferencedImportDeclaration,
	                getReferencedDeclarationWithCollidingName: getReferencedDeclarationWithCollidingName,
	                isDeclarationWithCollidingName: isDeclarationWithCollidingName,
	                isValueAliasDeclaration: isValueAliasDeclaration,
	                hasGlobalName: hasGlobalName,
	                isReferencedAliasDeclaration: isReferencedAliasDeclaration,
	                getNodeCheckFlags: getNodeCheckFlags,
	                isTopLevelValueImportEqualsWithEntityName: isTopLevelValueImportEqualsWithEntityName,
	                isDeclarationVisible: isDeclarationVisible,
	                isImplementationOfOverload: isImplementationOfOverload,
	                writeTypeOfDeclaration: writeTypeOfDeclaration,
	                writeReturnTypeOfSignatureDeclaration: writeReturnTypeOfSignatureDeclaration,
	                writeTypeOfExpression: writeTypeOfExpression,
	                isSymbolAccessible: isSymbolAccessible,
	                isEntityNameVisible: isEntityNameVisible,
	                getConstantValue: getConstantValue,
	                collectLinkedAliases: collectLinkedAliases,
	                getReferencedValueDeclaration: getReferencedValueDeclaration,
	                getTypeReferenceSerializationKind: getTypeReferenceSerializationKind,
	                isOptionalParameter: isOptionalParameter,
	                moduleExportsSomeValue: moduleExportsSomeValue,
	                isArgumentsLocalBinding: isArgumentsLocalBinding,
	                getExternalModuleFileFromDeclaration: getExternalModuleFileFromDeclaration
	            };
	        }
	        function getExternalModuleFileFromDeclaration(declaration) {
	            var specifier = ts.getExternalModuleName(declaration);
	            var moduleSymbol = resolveExternalModuleNameWorker(specifier, specifier, /*moduleNotFoundError*/ undefined);
	            if (!moduleSymbol) {
	                return undefined;
	            }
	            return ts.getDeclarationOfKind(moduleSymbol, 251 /* SourceFile */);
	        }
	        function initializeTypeChecker() {
	            // Bind all source files and propagate errors
	            ts.forEach(host.getSourceFiles(), function (file) {
	                ts.bindSourceFile(file, compilerOptions);
	            });
	            var augmentations;
	            // Initialize global symbol table
	            ts.forEach(host.getSourceFiles(), function (file) {
	                if (!ts.isExternalOrCommonJsModule(file)) {
	                    mergeSymbolTable(globals, file.locals);
	                }
	                if (file.moduleAugmentations.length) {
	                    (augmentations || (augmentations = [])).push(file.moduleAugmentations);
	                }
	            });
	            if (augmentations) {
	                // merge module augmentations.
	                // this needs to be done after global symbol table is initialized to make sure that all ambient modules are indexed
	                for (var _i = 0, augmentations_1 = augmentations; _i < augmentations_1.length; _i++) {
	                    var list = augmentations_1[_i];
	                    for (var _a = 0, list_2 = list; _a < list_2.length; _a++) {
	                        var augmentation = list_2[_a];
	                        mergeModuleAugmentation(augmentation);
	                    }
	                }
	            }
	            // Setup global builtins
	            addToSymbolTable(globals, builtinGlobals, ts.Diagnostics.Declaration_name_conflicts_with_built_in_global_identifier_0);
	            getSymbolLinks(undefinedSymbol).type = undefinedType;
	            getSymbolLinks(argumentsSymbol).type = getGlobalType("IArguments");
	            getSymbolLinks(unknownSymbol).type = unknownType;
	            // Initialize special types
	            globalArrayType = getGlobalType("Array", /*arity*/ 1);
	            globalObjectType = getGlobalType("Object");
	            globalFunctionType = getGlobalType("Function");
	            globalStringType = getGlobalType("String");
	            globalNumberType = getGlobalType("Number");
	            globalBooleanType = getGlobalType("Boolean");
	            globalRegExpType = getGlobalType("RegExp");
	            jsxElementType = getExportedTypeFromNamespace("JSX", JsxNames.Element);
	            getGlobalClassDecoratorType = ts.memoize(function () { return getGlobalType("ClassDecorator"); });
	            getGlobalPropertyDecoratorType = ts.memoize(function () { return getGlobalType("PropertyDecorator"); });
	            getGlobalMethodDecoratorType = ts.memoize(function () { return getGlobalType("MethodDecorator"); });
	            getGlobalParameterDecoratorType = ts.memoize(function () { return getGlobalType("ParameterDecorator"); });
	            getGlobalTypedPropertyDescriptorType = ts.memoize(function () { return getGlobalType("TypedPropertyDescriptor", /*arity*/ 1); });
	            getGlobalPromiseType = ts.memoize(function () { return getGlobalType("Promise", /*arity*/ 1); });
	            tryGetGlobalPromiseType = ts.memoize(function () { return getGlobalSymbol("Promise", 793056 /* Type */, /*diagnostic*/ undefined) && getGlobalPromiseType(); });
	            getGlobalPromiseLikeType = ts.memoize(function () { return getGlobalType("PromiseLike", /*arity*/ 1); });
	            getInstantiatedGlobalPromiseLikeType = ts.memoize(createInstantiatedPromiseLikeType);
	            getGlobalPromiseConstructorSymbol = ts.memoize(function () { return getGlobalValueSymbol("Promise"); });
	            getGlobalPromiseConstructorLikeType = ts.memoize(function () { return getGlobalType("PromiseConstructorLike"); });
	            getGlobalThenableType = ts.memoize(createThenableType);
	            // If we're in ES6 mode, load the TemplateStringsArray.
	            // Otherwise, default to 'unknown' for the purposes of type checking in LS scenarios.
	            if (languageVersion >= 2 /* ES6 */) {
	                globalTemplateStringsArrayType = getGlobalType("TemplateStringsArray");
	                globalESSymbolType = getGlobalType("Symbol");
	                globalESSymbolConstructorSymbol = getGlobalValueSymbol("Symbol");
	                globalIterableType = getGlobalType("Iterable", /*arity*/ 1);
	                globalIteratorType = getGlobalType("Iterator", /*arity*/ 1);
	                globalIterableIteratorType = getGlobalType("IterableIterator", /*arity*/ 1);
	            }
	            else {
	                globalTemplateStringsArrayType = unknownType;
	                // Consider putting Symbol interface in lib.d.ts. On the plus side, putting it in lib.d.ts would make it
	                // extensible for Polyfilling Symbols. But putting it into lib.d.ts could also break users that have
	                // a global Symbol already, particularly if it is a class.
	                globalESSymbolType = createAnonymousType(undefined, emptySymbols, emptyArray, emptyArray, undefined, undefined);
	                globalESSymbolConstructorSymbol = undefined;
	                globalIterableType = emptyGenericType;
	                globalIteratorType = emptyGenericType;
	                globalIterableIteratorType = emptyGenericType;
	            }
	            anyArrayType = createArrayType(anyType);
	        }
	        function createInstantiatedPromiseLikeType() {
	            var promiseLikeType = getGlobalPromiseLikeType();
	            if (promiseLikeType !== emptyGenericType) {
	                return createTypeReference(promiseLikeType, [anyType]);
	            }
	            return emptyObjectType;
	        }
	        function createThenableType() {
	            // build the thenable type that is used to verify against a non-promise "thenable" operand to `await`.
	            var thenPropertySymbol = createSymbol(67108864 /* Transient */ | 4 /* Property */, "then");
	            getSymbolLinks(thenPropertySymbol).type = globalFunctionType;
	            var thenableType = createObjectType(65536 /* Anonymous */);
	            thenableType.properties = [thenPropertySymbol];
	            thenableType.members = createSymbolTable(thenableType.properties);
	            thenableType.callSignatures = [];
	            thenableType.constructSignatures = [];
	            return thenableType;
	        }
	        // GRAMMAR CHECKING
	        function checkGrammarDecorators(node) {
	            if (!node.decorators) {
	                return false;
	            }
	            if (!ts.nodeCanBeDecorated(node)) {
	                if (node.kind === 144 /* MethodDeclaration */ && !ts.nodeIsPresent(node.body)) {
	                    return grammarErrorOnFirstToken(node, ts.Diagnostics.A_decorator_can_only_decorate_a_method_implementation_not_an_overload);
	                }
	                else {
	                    return grammarErrorOnFirstToken(node, ts.Diagnostics.Decorators_are_not_valid_here);
	                }
	            }
	            else if (node.kind === 146 /* GetAccessor */ || node.kind === 147 /* SetAccessor */) {
	                var accessors = ts.getAllAccessorDeclarations(node.parent.members, node);
	                if (accessors.firstAccessor.decorators && node === accessors.secondAccessor) {
	                    return grammarErrorOnFirstToken(node, ts.Diagnostics.Decorators_cannot_be_applied_to_multiple_get_Slashset_accessors_of_the_same_name);
	                }
	            }
	            return false;
	        }
	        function checkGrammarModifiers(node) {
	            switch (node.kind) {
	                case 146 /* GetAccessor */:
	                case 147 /* SetAccessor */:
	                case 145 /* Constructor */:
	                case 142 /* PropertyDeclaration */:
	                case 141 /* PropertySignature */:
	                case 144 /* MethodDeclaration */:
	                case 143 /* MethodSignature */:
	                case 150 /* IndexSignature */:
	                case 221 /* ModuleDeclaration */:
	                case 225 /* ImportDeclaration */:
	                case 224 /* ImportEqualsDeclaration */:
	                case 231 /* ExportDeclaration */:
	                case 230 /* ExportAssignment */:
	                case 139 /* Parameter */:
	                    break;
	                case 216 /* FunctionDeclaration */:
	                    if (node.modifiers && (node.modifiers.length > 1 || node.modifiers[0].kind !== 118 /* AsyncKeyword */) &&
	                        node.parent.kind !== 222 /* ModuleBlock */ && node.parent.kind !== 251 /* SourceFile */) {
	                        return grammarErrorOnFirstToken(node, ts.Diagnostics.Modifiers_cannot_appear_here);
	                    }
	                    break;
	                case 217 /* ClassDeclaration */:
	                case 218 /* InterfaceDeclaration */:
	                case 196 /* VariableStatement */:
	                case 219 /* TypeAliasDeclaration */:
	                    if (node.modifiers && node.parent.kind !== 222 /* ModuleBlock */ && node.parent.kind !== 251 /* SourceFile */) {
	                        return grammarErrorOnFirstToken(node, ts.Diagnostics.Modifiers_cannot_appear_here);
	                    }
	                    break;
	                case 220 /* EnumDeclaration */:
	                    if (node.modifiers && (node.modifiers.length > 1 || node.modifiers[0].kind !== 74 /* ConstKeyword */) &&
	                        node.parent.kind !== 222 /* ModuleBlock */ && node.parent.kind !== 251 /* SourceFile */) {
	                        return grammarErrorOnFirstToken(node, ts.Diagnostics.Modifiers_cannot_appear_here);
	                    }
	                    break;
	                default:
	                    return false;
	            }
	            if (!node.modifiers) {
	                return;
	            }
	            var lastStatic, lastPrivate, lastProtected, lastDeclare, lastAsync;
	            var flags = 0;
	            for (var _i = 0, _a = node.modifiers; _i < _a.length; _i++) {
	                var modifier = _a[_i];
	                switch (modifier.kind) {
	                    case 74 /* ConstKeyword */:
	                        if (node.kind !== 220 /* EnumDeclaration */ && node.parent.kind === 217 /* ClassDeclaration */) {
	                            return grammarErrorOnNode(node, ts.Diagnostics.A_class_member_cannot_have_the_0_keyword, ts.tokenToString(74 /* ConstKeyword */));
	                        }
	                        break;
	                    case 112 /* PublicKeyword */:
	                    case 111 /* ProtectedKeyword */:
	                    case 110 /* PrivateKeyword */:
	                        var text = void 0;
	                        if (modifier.kind === 112 /* PublicKeyword */) {
	                            text = "public";
	                        }
	                        else if (modifier.kind === 111 /* ProtectedKeyword */) {
	                            text = "protected";
	                            lastProtected = modifier;
	                        }
	                        else {
	                            text = "private";
	                            lastPrivate = modifier;
	                        }
	                        if (flags & 56 /* AccessibilityModifier */) {
	                            return grammarErrorOnNode(modifier, ts.Diagnostics.Accessibility_modifier_already_seen);
	                        }
	                        else if (flags & 64 /* Static */) {
	                            return grammarErrorOnNode(modifier, ts.Diagnostics._0_modifier_must_precede_1_modifier, text, "static");
	                        }
	                        else if (flags & 256 /* Async */) {
	                            return grammarErrorOnNode(modifier, ts.Diagnostics._0_modifier_must_precede_1_modifier, text, "async");
	                        }
	                        else if (node.parent.kind === 222 /* ModuleBlock */ || node.parent.kind === 251 /* SourceFile */) {
	                            return grammarErrorOnNode(modifier, ts.Diagnostics._0_modifier_cannot_appear_on_a_module_element, text);
	                        }
	                        else if (flags & 128 /* Abstract */) {
	                            if (modifier.kind === 110 /* PrivateKeyword */) {
	                                return grammarErrorOnNode(modifier, ts.Diagnostics._0_modifier_cannot_be_used_with_1_modifier, text, "abstract");
	                            }
	                            else {
	                                return grammarErrorOnNode(modifier, ts.Diagnostics._0_modifier_must_precede_1_modifier, text, "abstract");
	                            }
	                        }
	                        flags |= ts.modifierToFlag(modifier.kind);
	                        break;
	                    case 113 /* StaticKeyword */:
	                        if (flags & 64 /* Static */) {
	                            return grammarErrorOnNode(modifier, ts.Diagnostics._0_modifier_already_seen, "static");
	                        }
	                        else if (flags & 256 /* Async */) {
	                            return grammarErrorOnNode(modifier, ts.Diagnostics._0_modifier_must_precede_1_modifier, "static", "async");
	                        }
	                        else if (node.parent.kind === 222 /* ModuleBlock */ || node.parent.kind === 251 /* SourceFile */) {
	                            return grammarErrorOnNode(modifier, ts.Diagnostics._0_modifier_cannot_appear_on_a_module_element, "static");
	                        }
	                        else if (node.kind === 139 /* Parameter */) {
	                            return grammarErrorOnNode(modifier, ts.Diagnostics._0_modifier_cannot_appear_on_a_parameter, "static");
	                        }
	                        else if (flags & 128 /* Abstract */) {
	                            return grammarErrorOnNode(modifier, ts.Diagnostics._0_modifier_cannot_be_used_with_1_modifier, "static", "abstract");
	                        }
	                        flags |= 64 /* Static */;
	                        lastStatic = modifier;
	                        break;
	                    case 82 /* ExportKeyword */:
	                        if (flags & 2 /* Export */) {
	                            return grammarErrorOnNode(modifier, ts.Diagnostics._0_modifier_already_seen, "export");
	                        }
	                        else if (flags & 4 /* Ambient */) {
	                            return grammarErrorOnNode(modifier, ts.Diagnostics._0_modifier_must_precede_1_modifier, "export", "declare");
	                        }
	                        else if (flags & 128 /* Abstract */) {
	                            return grammarErrorOnNode(modifier, ts.Diagnostics._0_modifier_must_precede_1_modifier, "export", "abstract");
	                        }
	                        else if (flags & 256 /* Async */) {
	                            return grammarErrorOnNode(modifier, ts.Diagnostics._0_modifier_must_precede_1_modifier, "export", "async");
	                        }
	                        else if (node.parent.kind === 217 /* ClassDeclaration */) {
	                            return grammarErrorOnNode(modifier, ts.Diagnostics._0_modifier_cannot_appear_on_a_class_element, "export");
	                        }
	                        else if (node.kind === 139 /* Parameter */) {
	                            return grammarErrorOnNode(modifier, ts.Diagnostics._0_modifier_cannot_appear_on_a_parameter, "export");
	                        }
	                        flags |= 2 /* Export */;
	                        break;
	                    case 122 /* DeclareKeyword */:
	                        if (flags & 4 /* Ambient */) {
	                            return grammarErrorOnNode(modifier, ts.Diagnostics._0_modifier_already_seen, "declare");
	                        }
	                        else if (flags & 256 /* Async */) {
	                            return grammarErrorOnNode(modifier, ts.Diagnostics._0_modifier_cannot_be_used_in_an_ambient_context, "async");
	                        }
	                        else if (node.parent.kind === 217 /* ClassDeclaration */) {
	                            return grammarErrorOnNode(modifier, ts.Diagnostics._0_modifier_cannot_appear_on_a_class_element, "declare");
	                        }
	                        else if (node.kind === 139 /* Parameter */) {
	                            return grammarErrorOnNode(modifier, ts.Diagnostics._0_modifier_cannot_appear_on_a_parameter, "declare");
	                        }
	                        else if (ts.isInAmbientContext(node.parent) && node.parent.kind === 222 /* ModuleBlock */) {
	                            return grammarErrorOnNode(modifier, ts.Diagnostics.A_declare_modifier_cannot_be_used_in_an_already_ambient_context);
	                        }
	                        flags |= 4 /* Ambient */;
	                        lastDeclare = modifier;
	                        break;
	                    case 115 /* AbstractKeyword */:
	                        if (flags & 128 /* Abstract */) {
	                            return grammarErrorOnNode(modifier, ts.Diagnostics._0_modifier_already_seen, "abstract");
	                        }
	                        if (node.kind !== 217 /* ClassDeclaration */) {
	                            if (node.kind !== 144 /* MethodDeclaration */) {
	                                return grammarErrorOnNode(modifier, ts.Diagnostics.abstract_modifier_can_only_appear_on_a_class_or_method_declaration);
	                            }
	                            if (!(node.parent.kind === 217 /* ClassDeclaration */ && node.parent.flags & 128 /* Abstract */)) {
	                                return grammarErrorOnNode(modifier, ts.Diagnostics.Abstract_methods_can_only_appear_within_an_abstract_class);
	                            }
	                            if (flags & 64 /* Static */) {
	                                return grammarErrorOnNode(modifier, ts.Diagnostics._0_modifier_cannot_be_used_with_1_modifier, "static", "abstract");
	                            }
	                            if (flags & 16 /* Private */) {
	                                return grammarErrorOnNode(modifier, ts.Diagnostics._0_modifier_cannot_be_used_with_1_modifier, "private", "abstract");
	                            }
	                        }
	                        flags |= 128 /* Abstract */;
	                        break;
	                    case 118 /* AsyncKeyword */:
	                        if (flags & 256 /* Async */) {
	                            return grammarErrorOnNode(modifier, ts.Diagnostics._0_modifier_already_seen, "async");
	                        }
	                        else if (flags & 4 /* Ambient */ || ts.isInAmbientContext(node.parent)) {
	                            return grammarErrorOnNode(modifier, ts.Diagnostics._0_modifier_cannot_be_used_in_an_ambient_context, "async");
	                        }
	                        else if (node.kind === 139 /* Parameter */) {
	                            return grammarErrorOnNode(modifier, ts.Diagnostics._0_modifier_cannot_appear_on_a_parameter, "async");
	                        }
	                        flags |= 256 /* Async */;
	                        lastAsync = modifier;
	                        break;
	                }
	            }
	            if (node.kind === 145 /* Constructor */) {
	                if (flags & 64 /* Static */) {
	                    return grammarErrorOnNode(lastStatic, ts.Diagnostics._0_modifier_cannot_appear_on_a_constructor_declaration, "static");
	                }
	                if (flags & 128 /* Abstract */) {
	                    return grammarErrorOnNode(lastStatic, ts.Diagnostics._0_modifier_cannot_appear_on_a_constructor_declaration, "abstract");
	                }
	                else if (flags & 32 /* Protected */) {
	                    return grammarErrorOnNode(lastProtected, ts.Diagnostics._0_modifier_cannot_appear_on_a_constructor_declaration, "protected");
	                }
	                else if (flags & 16 /* Private */) {
	                    return grammarErrorOnNode(lastPrivate, ts.Diagnostics._0_modifier_cannot_appear_on_a_constructor_declaration, "private");
	                }
	                else if (flags & 256 /* Async */) {
	                    return grammarErrorOnNode(lastAsync, ts.Diagnostics._0_modifier_cannot_appear_on_a_constructor_declaration, "async");
	                }
	                return;
	            }
	            else if ((node.kind === 225 /* ImportDeclaration */ || node.kind === 224 /* ImportEqualsDeclaration */) && flags & 4 /* Ambient */) {
	                return grammarErrorOnNode(lastDeclare, ts.Diagnostics.A_0_modifier_cannot_be_used_with_an_import_declaration, "declare");
	            }
	            else if (node.kind === 139 /* Parameter */ && (flags & 56 /* AccessibilityModifier */) && ts.isBindingPattern(node.name)) {
	                return grammarErrorOnNode(node, ts.Diagnostics.A_parameter_property_may_not_be_a_binding_pattern);
	            }
	            if (flags & 256 /* Async */) {
	                return checkGrammarAsyncModifier(node, lastAsync);
	            }
	        }
	        function checkGrammarAsyncModifier(node, asyncModifier) {
	            if (languageVersion < 2 /* ES6 */) {
	                return grammarErrorOnNode(asyncModifier, ts.Diagnostics.Async_functions_are_only_available_when_targeting_ECMAScript_6_and_higher);
	            }
	            switch (node.kind) {
	                case 144 /* MethodDeclaration */:
	                case 216 /* FunctionDeclaration */:
	                case 176 /* FunctionExpression */:
	                case 177 /* ArrowFunction */:
	                    if (!node.asteriskToken) {
	                        return false;
	                    }
	                    break;
	            }
	            return grammarErrorOnNode(asyncModifier, ts.Diagnostics._0_modifier_cannot_be_used_here, "async");
	        }
	        function checkGrammarForDisallowedTrailingComma(list) {
	            if (list && list.hasTrailingComma) {
	                var start = list.end - ",".length;
	                var end = list.end;
	                var sourceFile = ts.getSourceFileOfNode(list[0]);
	                return grammarErrorAtPos(sourceFile, start, end - start, ts.Diagnostics.Trailing_comma_not_allowed);
	            }
	        }
	        function checkGrammarTypeParameterList(node, typeParameters, file) {
	            if (checkGrammarForDisallowedTrailingComma(typeParameters)) {
	                return true;
	            }
	            if (typeParameters && typeParameters.length === 0) {
	                var start = typeParameters.pos - "<".length;
	                var end = ts.skipTrivia(file.text, typeParameters.end) + ">".length;
	                return grammarErrorAtPos(file, start, end - start, ts.Diagnostics.Type_parameter_list_cannot_be_empty);
	            }
	        }
	        function checkGrammarParameterList(parameters) {
	            if (checkGrammarForDisallowedTrailingComma(parameters)) {
	                return true;
	            }
	            var seenOptionalParameter = false;
	            var parameterCount = parameters.length;
	            for (var i = 0; i < parameterCount; i++) {
	                var parameter = parameters[i];
	                if (parameter.dotDotDotToken) {
	                    if (i !== (parameterCount - 1)) {
	                        return grammarErrorOnNode(parameter.dotDotDotToken, ts.Diagnostics.A_rest_parameter_must_be_last_in_a_parameter_list);
	                    }
	                    if (ts.isBindingPattern(parameter.name)) {
	                        return grammarErrorOnNode(parameter.name, ts.Diagnostics.A_rest_element_cannot_contain_a_binding_pattern);
	                    }
	                    if (parameter.questionToken) {
	                        return grammarErrorOnNode(parameter.questionToken, ts.Diagnostics.A_rest_parameter_cannot_be_optional);
	                    }
	                    if (parameter.initializer) {
	                        return grammarErrorOnNode(parameter.name, ts.Diagnostics.A_rest_parameter_cannot_have_an_initializer);
	                    }
	                }
	                else if (parameter.questionToken) {
	                    seenOptionalParameter = true;
	                    if (parameter.initializer) {
	                        return grammarErrorOnNode(parameter.name, ts.Diagnostics.Parameter_cannot_have_question_mark_and_initializer);
	                    }
	                }
	                else if (seenOptionalParameter && !parameter.initializer) {
	                    return grammarErrorOnNode(parameter.name, ts.Diagnostics.A_required_parameter_cannot_follow_an_optional_parameter);
	                }
	            }
	        }
	        function checkGrammarFunctionLikeDeclaration(node) {
	            // Prevent cascading error by short-circuit
	            var file = ts.getSourceFileOfNode(node);
	            return checkGrammarDecorators(node) || checkGrammarModifiers(node) || checkGrammarTypeParameterList(node, node.typeParameters, file) ||
	                checkGrammarParameterList(node.parameters) || checkGrammarArrowFunction(node, file);
	        }
	        function checkGrammarArrowFunction(node, file) {
	            if (node.kind === 177 /* ArrowFunction */) {
	                var arrowFunction = node;
	                var startLine = ts.getLineAndCharacterOfPosition(file, arrowFunction.equalsGreaterThanToken.pos).line;
	                var endLine = ts.getLineAndCharacterOfPosition(file, arrowFunction.equalsGreaterThanToken.end).line;
	                if (startLine !== endLine) {
	                    return grammarErrorOnNode(arrowFunction.equalsGreaterThanToken, ts.Diagnostics.Line_terminator_not_permitted_before_arrow);
	                }
	            }
	            return false;
	        }
	        function checkGrammarIndexSignatureParameters(node) {
	            var parameter = node.parameters[0];
	            if (node.parameters.length !== 1) {
	                if (parameter) {
	                    return grammarErrorOnNode(parameter.name, ts.Diagnostics.An_index_signature_must_have_exactly_one_parameter);
	                }
	                else {
	                    return grammarErrorOnNode(node, ts.Diagnostics.An_index_signature_must_have_exactly_one_parameter);
	                }
	            }
	            if (parameter.dotDotDotToken) {
	                return grammarErrorOnNode(parameter.dotDotDotToken, ts.Diagnostics.An_index_signature_cannot_have_a_rest_parameter);
	            }
	            if (parameter.flags & 1022 /* Modifier */) {
	                return grammarErrorOnNode(parameter.name, ts.Diagnostics.An_index_signature_parameter_cannot_have_an_accessibility_modifier);
	            }
	            if (parameter.questionToken) {
	                return grammarErrorOnNode(parameter.questionToken, ts.Diagnostics.An_index_signature_parameter_cannot_have_a_question_mark);
	            }
	            if (parameter.initializer) {
	                return grammarErrorOnNode(parameter.name, ts.Diagnostics.An_index_signature_parameter_cannot_have_an_initializer);
	            }
	            if (!parameter.type) {
	                return grammarErrorOnNode(parameter.name, ts.Diagnostics.An_index_signature_parameter_must_have_a_type_annotation);
	            }
	            if (parameter.type.kind !== 130 /* StringKeyword */ && parameter.type.kind !== 128 /* NumberKeyword */) {
	                return grammarErrorOnNode(parameter.name, ts.Diagnostics.An_index_signature_parameter_type_must_be_string_or_number);
	            }
	            if (!node.type) {
	                return grammarErrorOnNode(node, ts.Diagnostics.An_index_signature_must_have_a_type_annotation);
	            }
	        }
	        function checkGrammarForIndexSignatureModifier(node) {
	            if (node.flags & 1022 /* Modifier */) {
	                grammarErrorOnFirstToken(node, ts.Diagnostics.Modifiers_not_permitted_on_index_signature_members);
	            }
	        }
	        function checkGrammarIndexSignature(node) {
	            // Prevent cascading error by short-circuit
	            return checkGrammarDecorators(node) || checkGrammarModifiers(node) || checkGrammarIndexSignatureParameters(node) || checkGrammarForIndexSignatureModifier(node);
	        }
	        function checkGrammarForAtLeastOneTypeArgument(node, typeArguments) {
	            if (typeArguments && typeArguments.length === 0) {
	                var sourceFile = ts.getSourceFileOfNode(node);
	                var start = typeArguments.pos - "<".length;
	                var end = ts.skipTrivia(sourceFile.text, typeArguments.end) + ">".length;
	                return grammarErrorAtPos(sourceFile, start, end - start, ts.Diagnostics.Type_argument_list_cannot_be_empty);
	            }
	        }
	        function checkGrammarTypeArguments(node, typeArguments) {
	            return checkGrammarForDisallowedTrailingComma(typeArguments) ||
	                checkGrammarForAtLeastOneTypeArgument(node, typeArguments);
	        }
	        function checkGrammarForOmittedArgument(node, args) {
	            if (args) {
	                var sourceFile = ts.getSourceFileOfNode(node);
	                for (var _i = 0, args_1 = args; _i < args_1.length; _i++) {
	                    var arg = args_1[_i];
	                    if (arg.kind === 190 /* OmittedExpression */) {
	                        return grammarErrorAtPos(sourceFile, arg.pos, 0, ts.Diagnostics.Argument_expression_expected);
	                    }
	                }
	            }
	        }
	        function checkGrammarArguments(node, args) {
	            return checkGrammarForDisallowedTrailingComma(args) ||
	                checkGrammarForOmittedArgument(node, args);
	        }
	        function checkGrammarHeritageClause(node) {
	            var types = node.types;
	            if (checkGrammarForDisallowedTrailingComma(types)) {
	                return true;
	            }
	            if (types && types.length === 0) {
	                var listType = ts.tokenToString(node.token);
	                var sourceFile = ts.getSourceFileOfNode(node);
	                return grammarErrorAtPos(sourceFile, types.pos, 0, ts.Diagnostics._0_list_cannot_be_empty, listType);
	            }
	        }
	        function checkGrammarClassDeclarationHeritageClauses(node) {
	            var seenExtendsClause = false;
	            var seenImplementsClause = false;
	            if (!checkGrammarDecorators(node) && !checkGrammarModifiers(node) && node.heritageClauses) {
	                for (var _i = 0, _a = node.heritageClauses; _i < _a.length; _i++) {
	                    var heritageClause = _a[_i];
	                    if (heritageClause.token === 83 /* ExtendsKeyword */) {
	                        if (seenExtendsClause) {
	                            return grammarErrorOnFirstToken(heritageClause, ts.Diagnostics.extends_clause_already_seen);
	                        }
	                        if (seenImplementsClause) {
	                            return grammarErrorOnFirstToken(heritageClause, ts.Diagnostics.extends_clause_must_precede_implements_clause);
	                        }
	                        if (heritageClause.types.length > 1) {
	                            return grammarErrorOnFirstToken(heritageClause.types[1], ts.Diagnostics.Classes_can_only_extend_a_single_class);
	                        }
	                        seenExtendsClause = true;
	                    }
	                    else {
	                        ts.Debug.assert(heritageClause.token === 106 /* ImplementsKeyword */);
	                        if (seenImplementsClause) {
	                            return grammarErrorOnFirstToken(heritageClause, ts.Diagnostics.implements_clause_already_seen);
	                        }
	                        seenImplementsClause = true;
	                    }
	                    // Grammar checking heritageClause inside class declaration
	                    checkGrammarHeritageClause(heritageClause);
	                }
	            }
	        }
	        function checkGrammarInterfaceDeclaration(node) {
	            var seenExtendsClause = false;
	            if (node.heritageClauses) {
	                for (var _i = 0, _a = node.heritageClauses; _i < _a.length; _i++) {
	                    var heritageClause = _a[_i];
	                    if (heritageClause.token === 83 /* ExtendsKeyword */) {
	                        if (seenExtendsClause) {
	                            return grammarErrorOnFirstToken(heritageClause, ts.Diagnostics.extends_clause_already_seen);
	                        }
	                        seenExtendsClause = true;
	                    }
	                    else {
	                        ts.Debug.assert(heritageClause.token === 106 /* ImplementsKeyword */);
	                        return grammarErrorOnFirstToken(heritageClause, ts.Diagnostics.Interface_declaration_cannot_have_implements_clause);
	                    }
	                    // Grammar checking heritageClause inside class declaration
	                    checkGrammarHeritageClause(heritageClause);
	                }
	            }
	            return false;
	        }
	        function checkGrammarComputedPropertyName(node) {
	            // If node is not a computedPropertyName, just skip the grammar checking
	            if (node.kind !== 137 /* ComputedPropertyName */) {
	                return false;
	            }
	            var computedPropertyName = node;
	            if (computedPropertyName.expression.kind === 184 /* BinaryExpression */ && computedPropertyName.expression.operatorToken.kind === 24 /* CommaToken */) {
	                return grammarErrorOnNode(computedPropertyName.expression, ts.Diagnostics.A_comma_expression_is_not_allowed_in_a_computed_property_name);
	            }
	        }
	        function checkGrammarForGenerator(node) {
	            if (node.asteriskToken) {
	                ts.Debug.assert(node.kind === 216 /* FunctionDeclaration */ ||
	                    node.kind === 176 /* FunctionExpression */ ||
	                    node.kind === 144 /* MethodDeclaration */);
	                if (ts.isInAmbientContext(node)) {
	                    return grammarErrorOnNode(node.asteriskToken, ts.Diagnostics.Generators_are_not_allowed_in_an_ambient_context);
	                }
	                if (!node.body) {
	                    return grammarErrorOnNode(node.asteriskToken, ts.Diagnostics.An_overload_signature_cannot_be_declared_as_a_generator);
	                }
	                if (languageVersion < 2 /* ES6 */) {
	                    return grammarErrorOnNode(node.asteriskToken, ts.Diagnostics.Generators_are_only_available_when_targeting_ECMAScript_6_or_higher);
	                }
	            }
	        }
	        function checkGrammarForInvalidQuestionMark(node, questionToken, message) {
	            if (questionToken) {
	                return grammarErrorOnNode(questionToken, message);
	            }
	        }
	        function checkGrammarObjectLiteralExpression(node, inDestructuring) {
	            var seen = {};
	            var Property = 1;
	            var GetAccessor = 2;
	            var SetAccesor = 4;
	            var GetOrSetAccessor = GetAccessor | SetAccesor;
	            var _loop_1 = function(prop) {
	                var name_19 = prop.name;
	                if (prop.kind === 190 /* OmittedExpression */ ||
	                    name_19.kind === 137 /* ComputedPropertyName */) {
	                    // If the name is not a ComputedPropertyName, the grammar checking will skip it
	                    checkGrammarComputedPropertyName(name_19);
	                    return "continue";
	                }
	                if (prop.kind === 249 /* ShorthandPropertyAssignment */ && !inDestructuring && prop.objectAssignmentInitializer) {
	                    // having objectAssignmentInitializer is only valid in ObjectAssignmentPattern
	                    // outside of destructuring it is a syntax error
	                    return { value: grammarErrorOnNode(prop.equalsToken, ts.Diagnostics.can_only_be_used_in_an_object_literal_property_inside_a_destructuring_assignment) };
	                }
	                // Modifiers are never allowed on properties except for 'async' on a method declaration
	                ts.forEach(prop.modifiers, function (mod) {
	                    if (mod.kind !== 118 /* AsyncKeyword */ || prop.kind !== 144 /* MethodDeclaration */) {
	                        grammarErrorOnNode(mod, ts.Diagnostics._0_modifier_cannot_be_used_here, ts.getTextOfNode(mod));
	                    }
	                });
	                // ECMA-262 11.1.5 Object Initialiser
	                // If previous is not undefined then throw a SyntaxError exception if any of the following conditions are true
	                // a.This production is contained in strict code and IsDataDescriptor(previous) is true and
	                // IsDataDescriptor(propId.descriptor) is true.
	                //    b.IsDataDescriptor(previous) is true and IsAccessorDescriptor(propId.descriptor) is true.
	                //    c.IsAccessorDescriptor(previous) is true and IsDataDescriptor(propId.descriptor) is true.
	                //    d.IsAccessorDescriptor(previous) is true and IsAccessorDescriptor(propId.descriptor) is true
	                // and either both previous and propId.descriptor have[[Get]] fields or both previous and propId.descriptor have[[Set]] fields
	                var currentKind = void 0;
	                if (prop.kind === 248 /* PropertyAssignment */ || prop.kind === 249 /* ShorthandPropertyAssignment */) {
	                    // Grammar checking for computedPropertName and shorthandPropertyAssignment
	                    checkGrammarForInvalidQuestionMark(prop, prop.questionToken, ts.Diagnostics.An_object_member_cannot_be_declared_optional);
	                    if (name_19.kind === 8 /* NumericLiteral */) {
	                        checkGrammarNumericLiteral(name_19);
	                    }
	                    currentKind = Property;
	                }
	                else if (prop.kind === 144 /* MethodDeclaration */) {
	                    currentKind = Property;
	                }
	                else if (prop.kind === 146 /* GetAccessor */) {
	                    currentKind = GetAccessor;
	                }
	                else if (prop.kind === 147 /* SetAccessor */) {
	                    currentKind = SetAccesor;
	                }
	                else {
	                    ts.Debug.fail("Unexpected syntax kind:" + prop.kind);
	                }
	                if (!ts.hasProperty(seen, name_19.text)) {
	                    seen[name_19.text] = currentKind;
	                }
	                else {
	                    var existingKind = seen[name_19.text];
	                    if (currentKind === Property && existingKind === Property) {
	                        return "continue";
	                    }
	                    else if ((currentKind & GetOrSetAccessor) && (existingKind & GetOrSetAccessor)) {
	                        if (existingKind !== GetOrSetAccessor && currentKind !== existingKind) {
	                            seen[name_19.text] = currentKind | existingKind;
	                        }
	                        else {
	                            return { value: grammarErrorOnNode(name_19, ts.Diagnostics.An_object_literal_cannot_have_multiple_get_Slashset_accessors_with_the_same_name) };
	                        }
	                    }
	                    else {
	                        return { value: grammarErrorOnNode(name_19, ts.Diagnostics.An_object_literal_cannot_have_property_and_accessor_with_the_same_name) };
	                    }
	                }
	            };
	            for (var _i = 0, _a = node.properties; _i < _a.length; _i++) {
	                var prop = _a[_i];
	                var state_2 = _loop_1(prop);
	                if (typeof state_2 === "object") return state_2.value;
	                if (state_2 === "continue") continue;
	            }
	        }
	        function checkGrammarJsxElement(node) {
	            var seen = {};
	            for (var _i = 0, _a = node.attributes; _i < _a.length; _i++) {
	                var attr = _a[_i];
	                if (attr.kind === 242 /* JsxSpreadAttribute */) {
	                    continue;
	                }
	                var jsxAttr = attr;
	                var name_20 = jsxAttr.name;
	                if (!ts.hasProperty(seen, name_20.text)) {
	                    seen[name_20.text] = true;
	                }
	                else {
	                    return grammarErrorOnNode(name_20, ts.Diagnostics.JSX_elements_cannot_have_multiple_attributes_with_the_same_name);
	                }
	                var initializer = jsxAttr.initializer;
	                if (initializer && initializer.kind === 243 /* JsxExpression */ && !initializer.expression) {
	                    return grammarErrorOnNode(jsxAttr.initializer, ts.Diagnostics.JSX_attributes_must_only_be_assigned_a_non_empty_expression);
	                }
	            }
	        }
	        function checkGrammarForInOrForOfStatement(forInOrOfStatement) {
	            if (checkGrammarStatementInAmbientContext(forInOrOfStatement)) {
	                return true;
	            }
	            if (forInOrOfStatement.initializer.kind === 215 /* VariableDeclarationList */) {
	                var variableList = forInOrOfStatement.initializer;
	                if (!checkGrammarVariableDeclarationList(variableList)) {
	                    var declarations = variableList.declarations;
	                    // declarations.length can be zero if there is an error in variable declaration in for-of or for-in
	                    // See http://www.ecma-international.org/ecma-262/6.0/#sec-for-in-and-for-of-statements for details
	                    // For example:
	                    //      var let = 10;
	                    //      for (let of [1,2,3]) {} // this is invalid ES6 syntax
	                    //      for (let in [1,2,3]) {} // this is invalid ES6 syntax
	                    // We will then want to skip on grammar checking on variableList declaration
	                    if (!declarations.length) {
	                        return false;
	                    }
	                    if (declarations.length > 1) {
	                        var diagnostic = forInOrOfStatement.kind === 203 /* ForInStatement */
	                            ? ts.Diagnostics.Only_a_single_variable_declaration_is_allowed_in_a_for_in_statement
	                            : ts.Diagnostics.Only_a_single_variable_declaration_is_allowed_in_a_for_of_statement;
	                        return grammarErrorOnFirstToken(variableList.declarations[1], diagnostic);
	                    }
	                    var firstDeclaration = declarations[0];
	                    if (firstDeclaration.initializer) {
	                        var diagnostic = forInOrOfStatement.kind === 203 /* ForInStatement */
	                            ? ts.Diagnostics.The_variable_declaration_of_a_for_in_statement_cannot_have_an_initializer
	                            : ts.Diagnostics.The_variable_declaration_of_a_for_of_statement_cannot_have_an_initializer;
	                        return grammarErrorOnNode(firstDeclaration.name, diagnostic);
	                    }
	                    if (firstDeclaration.type) {
	                        var diagnostic = forInOrOfStatement.kind === 203 /* ForInStatement */
	                            ? ts.Diagnostics.The_left_hand_side_of_a_for_in_statement_cannot_use_a_type_annotation
	                            : ts.Diagnostics.The_left_hand_side_of_a_for_of_statement_cannot_use_a_type_annotation;
	                        return grammarErrorOnNode(firstDeclaration, diagnostic);
	                    }
	                }
	            }
	            return false;
	        }
	        function checkGrammarAccessor(accessor) {
	            var kind = accessor.kind;
	            if (languageVersion < 1 /* ES5 */) {
	                return grammarErrorOnNode(accessor.name, ts.Diagnostics.Accessors_are_only_available_when_targeting_ECMAScript_5_and_higher);
	            }
	            else if (ts.isInAmbientContext(accessor)) {
	                return grammarErrorOnNode(accessor.name, ts.Diagnostics.An_accessor_cannot_be_declared_in_an_ambient_context);
	            }
	            else if (accessor.body === undefined) {
	                return grammarErrorAtPos(ts.getSourceFileOfNode(accessor), accessor.end - 1, ";".length, ts.Diagnostics._0_expected, "{");
	            }
	            else if (accessor.typeParameters) {
	                return grammarErrorOnNode(accessor.name, ts.Diagnostics.An_accessor_cannot_have_type_parameters);
	            }
	            else if (kind === 146 /* GetAccessor */ && accessor.parameters.length) {
	                return grammarErrorOnNode(accessor.name, ts.Diagnostics.A_get_accessor_cannot_have_parameters);
	            }
	            else if (kind === 147 /* SetAccessor */) {
	                if (accessor.type) {
	                    return grammarErrorOnNode(accessor.name, ts.Diagnostics.A_set_accessor_cannot_have_a_return_type_annotation);
	                }
	                else if (accessor.parameters.length !== 1) {
	                    return grammarErrorOnNode(accessor.name, ts.Diagnostics.A_set_accessor_must_have_exactly_one_parameter);
	                }
	                else {
	                    var parameter = accessor.parameters[0];
	                    if (parameter.dotDotDotToken) {
	                        return grammarErrorOnNode(parameter.dotDotDotToken, ts.Diagnostics.A_set_accessor_cannot_have_rest_parameter);
	                    }
	                    else if (parameter.flags & 1022 /* Modifier */) {
	                        return grammarErrorOnNode(accessor.name, ts.Diagnostics.A_parameter_property_is_only_allowed_in_a_constructor_implementation);
	                    }
	                    else if (parameter.questionToken) {
	                        return grammarErrorOnNode(parameter.questionToken, ts.Diagnostics.A_set_accessor_cannot_have_an_optional_parameter);
	                    }
	                    else if (parameter.initializer) {
	                        return grammarErrorOnNode(accessor.name, ts.Diagnostics.A_set_accessor_parameter_cannot_have_an_initializer);
	                    }
	                }
	            }
	        }
	        function checkGrammarForNonSymbolComputedProperty(node, message) {
	            if (ts.isDynamicName(node)) {
	                return grammarErrorOnNode(node, message);
	            }
	        }
	        function checkGrammarMethod(node) {
	            if (checkGrammarDisallowedModifiersOnObjectLiteralExpressionMethod(node) ||
	                checkGrammarFunctionLikeDeclaration(node) ||
	                checkGrammarForGenerator(node)) {
	                return true;
	            }
	            if (node.parent.kind === 168 /* ObjectLiteralExpression */) {
	                if (checkGrammarForInvalidQuestionMark(node, node.questionToken, ts.Diagnostics.A_class_member_cannot_be_declared_optional)) {
	                    return true;
	                }
	                else if (node.body === undefined) {
	                    return grammarErrorAtPos(ts.getSourceFileOfNode(node), node.end - 1, ";".length, ts.Diagnostics._0_expected, "{");
	                }
	            }
	            if (ts.isClassLike(node.parent)) {
	                if (checkGrammarForInvalidQuestionMark(node, node.questionToken, ts.Diagnostics.A_class_member_cannot_be_declared_optional)) {
	                    return true;
	                }
	                // Technically, computed properties in ambient contexts is disallowed
	                // for property declarations and accessors too, not just methods.
	                // However, property declarations disallow computed names in general,
	                // and accessors are not allowed in ambient contexts in general,
	                // so this error only really matters for methods.
	                if (ts.isInAmbientContext(node)) {
	                    return checkGrammarForNonSymbolComputedProperty(node.name, ts.Diagnostics.A_computed_property_name_in_an_ambient_context_must_directly_refer_to_a_built_in_symbol);
	                }
	                else if (!node.body) {
	                    return checkGrammarForNonSymbolComputedProperty(node.name, ts.Diagnostics.A_computed_property_name_in_a_method_overload_must_directly_refer_to_a_built_in_symbol);
	                }
	            }
	            else if (node.parent.kind === 218 /* InterfaceDeclaration */) {
	                return checkGrammarForNonSymbolComputedProperty(node.name, ts.Diagnostics.A_computed_property_name_in_an_interface_must_directly_refer_to_a_built_in_symbol);
	            }
	            else if (node.parent.kind === 156 /* TypeLiteral */) {
	                return checkGrammarForNonSymbolComputedProperty(node.name, ts.Diagnostics.A_computed_property_name_in_a_type_literal_must_directly_refer_to_a_built_in_symbol);
	            }
	        }
	        function checkGrammarBreakOrContinueStatement(node) {
	            var current = node;
	            while (current) {
	                if (ts.isFunctionLike(current)) {
	                    return grammarErrorOnNode(node, ts.Diagnostics.Jump_target_cannot_cross_function_boundary);
	                }
	                switch (current.kind) {
	                    case 210 /* LabeledStatement */:
	                        if (node.label && current.label.text === node.label.text) {
	                            // found matching label - verify that label usage is correct
	                            // continue can only target labels that are on iteration statements
	                            var isMisplacedContinueLabel = node.kind === 205 /* ContinueStatement */
	                                && !ts.isIterationStatement(current.statement, /*lookInLabeledStatement*/ true);
	                            if (isMisplacedContinueLabel) {
	                                return grammarErrorOnNode(node, ts.Diagnostics.A_continue_statement_can_only_jump_to_a_label_of_an_enclosing_iteration_statement);
	                            }
	                            return false;
	                        }
	                        break;
	                    case 209 /* SwitchStatement */:
	                        if (node.kind === 206 /* BreakStatement */ && !node.label) {
	                            // unlabeled break within switch statement - ok
	                            return false;
	                        }
	                        break;
	                    default:
	                        if (ts.isIterationStatement(current, /*lookInLabeledStatement*/ false) && !node.label) {
	                            // unlabeled break or continue within iteration statement - ok
	                            return false;
	                        }
	                        break;
	                }
	                current = current.parent;
	            }
	            if (node.label) {
	                var message = node.kind === 206 /* BreakStatement */
	                    ? ts.Diagnostics.A_break_statement_can_only_jump_to_a_label_of_an_enclosing_statement
	                    : ts.Diagnostics.A_continue_statement_can_only_jump_to_a_label_of_an_enclosing_iteration_statement;
	                return grammarErrorOnNode(node, message);
	            }
	            else {
	                var message = node.kind === 206 /* BreakStatement */
	                    ? ts.Diagnostics.A_break_statement_can_only_be_used_within_an_enclosing_iteration_or_switch_statement
	                    : ts.Diagnostics.A_continue_statement_can_only_be_used_within_an_enclosing_iteration_statement;
	                return grammarErrorOnNode(node, message);
	            }
	        }
	        function checkGrammarBindingElement(node) {
	            if (node.dotDotDotToken) {
	                var elements = node.parent.elements;
	                if (node !== ts.lastOrUndefined(elements)) {
	                    return grammarErrorOnNode(node, ts.Diagnostics.A_rest_element_must_be_last_in_an_array_destructuring_pattern);
	                }
	                if (node.name.kind === 165 /* ArrayBindingPattern */ || node.name.kind === 164 /* ObjectBindingPattern */) {
	                    return grammarErrorOnNode(node.name, ts.Diagnostics.A_rest_element_cannot_contain_a_binding_pattern);
	                }
	                if (node.initializer) {
	                    // Error on equals token which immediate precedes the initializer
	                    return grammarErrorAtPos(ts.getSourceFileOfNode(node), node.initializer.pos - 1, 1, ts.Diagnostics.A_rest_element_cannot_have_an_initializer);
	                }
	            }
	        }
	        function checkGrammarVariableDeclaration(node) {
	            if (node.parent.parent.kind !== 203 /* ForInStatement */ && node.parent.parent.kind !== 204 /* ForOfStatement */) {
	                if (ts.isInAmbientContext(node)) {
	                    if (node.initializer) {
	                        // Error on equals token which immediate precedes the initializer
	                        var equalsTokenLength = "=".length;
	                        return grammarErrorAtPos(ts.getSourceFileOfNode(node), node.initializer.pos - equalsTokenLength, equalsTokenLength, ts.Diagnostics.Initializers_are_not_allowed_in_ambient_contexts);
	                    }
	                }
	                else if (!node.initializer) {
	                    if (ts.isBindingPattern(node.name) && !ts.isBindingPattern(node.parent)) {
	                        return grammarErrorOnNode(node, ts.Diagnostics.A_destructuring_declaration_must_have_an_initializer);
	                    }
	                    if (ts.isConst(node)) {
	                        return grammarErrorOnNode(node, ts.Diagnostics.const_declarations_must_be_initialized);
	                    }
	                }
	            }
	            var checkLetConstNames = (ts.isLet(node) || ts.isConst(node));
	            // 1. LexicalDeclaration : LetOrConst BindingList ;
	            // It is a Syntax Error if the BoundNames of BindingList contains "let".
	            // 2. ForDeclaration: ForDeclaration : LetOrConst ForBinding
	            // It is a Syntax Error if the BoundNames of ForDeclaration contains "let".
	            // It is a SyntaxError if a VariableDeclaration or VariableDeclarationNoIn occurs within strict code
	            // and its Identifier is eval or arguments
	            return checkLetConstNames && checkGrammarNameInLetOrConstDeclarations(node.name);
	        }
	        function checkGrammarNameInLetOrConstDeclarations(name) {
	            if (name.kind === 69 /* Identifier */) {
	                if (name.originalKeywordKind === 108 /* LetKeyword */) {
	                    return grammarErrorOnNode(name, ts.Diagnostics.let_is_not_allowed_to_be_used_as_a_name_in_let_or_const_declarations);
	                }
	            }
	            else {
	                var elements = name.elements;
	                for (var _i = 0, elements_2 = elements; _i < elements_2.length; _i++) {
	                    var element = elements_2[_i];
	                    if (element.kind !== 190 /* OmittedExpression */) {
	                        checkGrammarNameInLetOrConstDeclarations(element.name);
	                    }
	                }
	            }
	        }
	        function checkGrammarVariableDeclarationList(declarationList) {
	            var declarations = declarationList.declarations;
	            if (checkGrammarForDisallowedTrailingComma(declarationList.declarations)) {
	                return true;
	            }
	            if (!declarationList.declarations.length) {
	                return grammarErrorAtPos(ts.getSourceFileOfNode(declarationList), declarations.pos, declarations.end - declarations.pos, ts.Diagnostics.Variable_declaration_list_cannot_be_empty);
	            }
	        }
	        function allowLetAndConstDeclarations(parent) {
	            switch (parent.kind) {
	                case 199 /* IfStatement */:
	                case 200 /* DoStatement */:
	                case 201 /* WhileStatement */:
	                case 208 /* WithStatement */:
	                case 202 /* ForStatement */:
	                case 203 /* ForInStatement */:
	                case 204 /* ForOfStatement */:
	                    return false;
	                case 210 /* LabeledStatement */:
	                    return allowLetAndConstDeclarations(parent.parent);
	            }
	            return true;
	        }
	        function checkGrammarForDisallowedLetOrConstStatement(node) {
	            if (!allowLetAndConstDeclarations(node.parent)) {
	                if (ts.isLet(node.declarationList)) {
	                    return grammarErrorOnNode(node, ts.Diagnostics.let_declarations_can_only_be_declared_inside_a_block);
	                }
	                else if (ts.isConst(node.declarationList)) {
	                    return grammarErrorOnNode(node, ts.Diagnostics.const_declarations_can_only_be_declared_inside_a_block);
	                }
	            }
	        }
	        function hasParseDiagnostics(sourceFile) {
	            return sourceFile.parseDiagnostics.length > 0;
	        }
	        function grammarErrorOnFirstToken(node, message, arg0, arg1, arg2) {
	            var sourceFile = ts.getSourceFileOfNode(node);
	            if (!hasParseDiagnostics(sourceFile)) {
	                var span = ts.getSpanOfTokenAtPosition(sourceFile, node.pos);
	                diagnostics.add(ts.createFileDiagnostic(sourceFile, span.start, span.length, message, arg0, arg1, arg2));
	                return true;
	            }
	        }
	        function grammarErrorAtPos(sourceFile, start, length, message, arg0, arg1, arg2) {
	            if (!hasParseDiagnostics(sourceFile)) {
	                diagnostics.add(ts.createFileDiagnostic(sourceFile, start, length, message, arg0, arg1, arg2));
	                return true;
	            }
	        }
	        function grammarErrorOnNode(node, message, arg0, arg1, arg2) {
	            var sourceFile = ts.getSourceFileOfNode(node);
	            if (!hasParseDiagnostics(sourceFile)) {
	                diagnostics.add(ts.createDiagnosticForNode(node, message, arg0, arg1, arg2));
	                return true;
	            }
	        }
	        function checkGrammarConstructorTypeParameters(node) {
	            if (node.typeParameters) {
	                return grammarErrorAtPos(ts.getSourceFileOfNode(node), node.typeParameters.pos, node.typeParameters.end - node.typeParameters.pos, ts.Diagnostics.Type_parameters_cannot_appear_on_a_constructor_declaration);
	            }
	        }
	        function checkGrammarConstructorTypeAnnotation(node) {
	            if (node.type) {
	                return grammarErrorOnNode(node.type, ts.Diagnostics.Type_annotation_cannot_appear_on_a_constructor_declaration);
	            }
	        }
	        function checkGrammarProperty(node) {
	            if (ts.isClassLike(node.parent)) {
	                if (checkGrammarForInvalidQuestionMark(node, node.questionToken, ts.Diagnostics.A_class_member_cannot_be_declared_optional) ||
	                    checkGrammarForNonSymbolComputedProperty(node.name, ts.Diagnostics.A_computed_property_name_in_a_class_property_declaration_must_directly_refer_to_a_built_in_symbol)) {
	                    return true;
	                }
	            }
	            else if (node.parent.kind === 218 /* InterfaceDeclaration */) {
	                if (checkGrammarForNonSymbolComputedProperty(node.name, ts.Diagnostics.A_computed_property_name_in_an_interface_must_directly_refer_to_a_built_in_symbol)) {
	                    return true;
	                }
	                if (node.initializer) {
	                    return grammarErrorOnNode(node.initializer, ts.Diagnostics.An_interface_property_cannot_have_an_initializer);
	                }
	            }
	            else if (node.parent.kind === 156 /* TypeLiteral */) {
	                if (checkGrammarForNonSymbolComputedProperty(node.name, ts.Diagnostics.A_computed_property_name_in_a_type_literal_must_directly_refer_to_a_built_in_symbol)) {
	                    return true;
	                }
	                if (node.initializer) {
	                    return grammarErrorOnNode(node.initializer, ts.Diagnostics.A_type_literal_property_cannot_have_an_initializer);
	                }
	            }
	            if (ts.isInAmbientContext(node) && node.initializer) {
	                return grammarErrorOnFirstToken(node.initializer, ts.Diagnostics.Initializers_are_not_allowed_in_ambient_contexts);
	            }
	        }
	        function checkGrammarTopLevelElementForRequiredDeclareModifier(node) {
	            // A declare modifier is required for any top level .d.ts declaration except export=, export default,
	            // interfaces and imports categories:
	            //
	            //  DeclarationElement:
	            //     ExportAssignment
	            //     export_opt   InterfaceDeclaration
	            //     export_opt   TypeAliasDeclaration
	            //     export_opt   ImportDeclaration
	            //     export_opt   ExternalImportDeclaration
	            //     export_opt   AmbientDeclaration
	            //
	            // TODO: The spec needs to be amended to reflect this grammar.
	            if (node.kind === 218 /* InterfaceDeclaration */ ||
	                node.kind === 219 /* TypeAliasDeclaration */ ||
	                node.kind === 225 /* ImportDeclaration */ ||
	                node.kind === 224 /* ImportEqualsDeclaration */ ||
	                node.kind === 231 /* ExportDeclaration */ ||
	                node.kind === 230 /* ExportAssignment */ ||
	                (node.flags & 4 /* Ambient */) ||
	                (node.flags & (2 /* Export */ | 512 /* Default */))) {
	                return false;
	            }
	            return grammarErrorOnFirstToken(node, ts.Diagnostics.A_declare_modifier_is_required_for_a_top_level_declaration_in_a_d_ts_file);
	        }
	        function checkGrammarTopLevelElementsForRequiredDeclareModifier(file) {
	            for (var _i = 0, _a = file.statements; _i < _a.length; _i++) {
	                var decl = _a[_i];
	                if (ts.isDeclaration(decl) || decl.kind === 196 /* VariableStatement */) {
	                    if (checkGrammarTopLevelElementForRequiredDeclareModifier(decl)) {
	                        return true;
	                    }
	                }
	            }
	        }
	        function checkGrammarSourceFile(node) {
	            return ts.isInAmbientContext(node) && checkGrammarTopLevelElementsForRequiredDeclareModifier(node);
	        }
	        function checkGrammarStatementInAmbientContext(node) {
	            if (ts.isInAmbientContext(node)) {
	                // An accessors is already reported about the ambient context
	                if (isAccessor(node.parent.kind)) {
	                    return getNodeLinks(node).hasReportedStatementInAmbientContext = true;
	                }
	                // Find containing block which is either Block, ModuleBlock, SourceFile
	                var links = getNodeLinks(node);
	                if (!links.hasReportedStatementInAmbientContext && ts.isFunctionLike(node.parent)) {
	                    return getNodeLinks(node).hasReportedStatementInAmbientContext = grammarErrorOnFirstToken(node, ts.Diagnostics.An_implementation_cannot_be_declared_in_ambient_contexts);
	                }
	                // We are either parented by another statement, or some sort of block.
	                // If we're in a block, we only want to really report an error once
	                // to prevent noisyness.  So use a bit on the block to indicate if
	                // this has already been reported, and don't report if it has.
	                //
	                if (node.parent.kind === 195 /* Block */ || node.parent.kind === 222 /* ModuleBlock */ || node.parent.kind === 251 /* SourceFile */) {
	                    var links_1 = getNodeLinks(node.parent);
	                    // Check if the containing block ever report this error
	                    if (!links_1.hasReportedStatementInAmbientContext) {
	                        return links_1.hasReportedStatementInAmbientContext = grammarErrorOnFirstToken(node, ts.Diagnostics.Statements_are_not_allowed_in_ambient_contexts);
	                    }
	                }
	                else {
	                }
	            }
	        }
	        function checkGrammarNumericLiteral(node) {
	            // Grammar checking
	            if (node.flags & 32768 /* OctalLiteral */ && languageVersion >= 1 /* ES5 */) {
	                return grammarErrorOnNode(node, ts.Diagnostics.Octal_literals_are_not_available_when_targeting_ECMAScript_5_and_higher);
	            }
	        }
	        function grammarErrorAfterFirstToken(node, message, arg0, arg1, arg2) {
	            var sourceFile = ts.getSourceFileOfNode(node);
	            if (!hasParseDiagnostics(sourceFile)) {
	                var span = ts.getSpanOfTokenAtPosition(sourceFile, node.pos);
	                diagnostics.add(ts.createFileDiagnostic(sourceFile, ts.textSpanEnd(span), /*length*/ 0, message, arg0, arg1, arg2));
	                return true;
	            }
	        }
	        var _a;
	    }
	    ts.createTypeChecker = createTypeChecker;
	})(ts || (ts = {}));
	/// <reference path="checker.ts"/>
	/* @internal */
	var ts;
	(function (ts) {
	    var nullSourceMapWriter;
	    // Used for initialize lastEncodedSourceMapSpan and reset lastEncodedSourceMapSpan when updateLastEncodedAndRecordedSpans
	    var defaultLastEncodedSourceMapSpan = {
	        emittedLine: 1,
	        emittedColumn: 1,
	        sourceLine: 1,
	        sourceColumn: 1,
	        sourceIndex: 0
	    };
	    function getNullSourceMapWriter() {
	        if (nullSourceMapWriter === undefined) {
	            nullSourceMapWriter = {
	                getSourceMapData: function () { return undefined; },
	                setSourceFile: function (sourceFile) { },
	                emitStart: function (range) { },
	                emitEnd: function (range, stopOverridingSpan) { },
	                emitPos: function (pos) { },
	                changeEmitSourcePos: function () { },
	                getText: function () { return undefined; },
	                getSourceMappingURL: function () { return undefined; },
	                initialize: function (filePath, sourceMapFilePath, sourceFiles, isBundledEmit) { },
	                reset: function () { }
	            };
	        }
	        return nullSourceMapWriter;
	    }
	    ts.getNullSourceMapWriter = getNullSourceMapWriter;
	    function createSourceMapWriter(host, writer) {
	        var compilerOptions = host.getCompilerOptions();
	        var currentSourceFile;
	        var sourceMapDir; // The directory in which sourcemap will be
	        var stopOverridingSpan = false;
	        var modifyLastSourcePos = false;
	        // Current source map file and its index in the sources list
	        var sourceMapSourceIndex;
	        // Last recorded and encoded spans
	        var lastRecordedSourceMapSpan;
	        var lastEncodedSourceMapSpan;
	        var lastEncodedNameIndex;
	        // Source map data
	        var sourceMapData;
	        return {
	            getSourceMapData: function () { return sourceMapData; },
	            setSourceFile: setSourceFile,
	            emitPos: emitPos,
	            emitStart: emitStart,
	            emitEnd: emitEnd,
	            changeEmitSourcePos: changeEmitSourcePos,
	            getText: getText,
	            getSourceMappingURL: getSourceMappingURL,
	            initialize: initialize,
	            reset: reset
	        };
	        function initialize(filePath, sourceMapFilePath, sourceFiles, isBundledEmit) {
	            if (sourceMapData) {
	                reset();
	            }
	            currentSourceFile = undefined;
	            // Current source map file and its index in the sources list
	            sourceMapSourceIndex = -1;
	            // Last recorded and encoded spans
	            lastRecordedSourceMapSpan = undefined;
	            lastEncodedSourceMapSpan = defaultLastEncodedSourceMapSpan;
	            lastEncodedNameIndex = 0;
	            // Initialize source map data
	            sourceMapData = {
	                sourceMapFilePath: sourceMapFilePath,
	                jsSourceMappingURL: !compilerOptions.inlineSourceMap ? ts.getBaseFileName(ts.normalizeSlashes(sourceMapFilePath)) : undefined,
	                sourceMapFile: ts.getBaseFileName(ts.normalizeSlashes(filePath)),
	                sourceMapSourceRoot: compilerOptions.sourceRoot || "",
	                sourceMapSources: [],
	                inputSourceFileNames: [],
	                sourceMapNames: [],
	                sourceMapMappings: "",
	                sourceMapSourcesContent: compilerOptions.inlineSources ? [] : undefined,
	                sourceMapDecodedMappings: []
	            };
	            // Normalize source root and make sure it has trailing "/" so that it can be used to combine paths with the
	            // relative paths of the sources list in the sourcemap
	            sourceMapData.sourceMapSourceRoot = ts.normalizeSlashes(sourceMapData.sourceMapSourceRoot);
	            if (sourceMapData.sourceMapSourceRoot.length && sourceMapData.sourceMapSourceRoot.charCodeAt(sourceMapData.sourceMapSourceRoot.length - 1) !== 47 /* slash */) {
	                sourceMapData.sourceMapSourceRoot += ts.directorySeparator;
	            }
	            if (compilerOptions.mapRoot) {
	                sourceMapDir = ts.normalizeSlashes(compilerOptions.mapRoot);
	                if (!isBundledEmit) {
	                    ts.Debug.assert(sourceFiles.length === 1);
	                    // For modules or multiple emit files the mapRoot will have directory structure like the sources
	                    // So if src\a.ts and src\lib\b.ts are compiled together user would be moving the maps into mapRoot\a.js.map and mapRoot\lib\b.js.map
	                    sourceMapDir = ts.getDirectoryPath(ts.getSourceFilePathInNewDir(sourceFiles[0], host, sourceMapDir));
	                }
	                if (!ts.isRootedDiskPath(sourceMapDir) && !ts.isUrl(sourceMapDir)) {
	                    // The relative paths are relative to the common directory
	                    sourceMapDir = ts.combinePaths(host.getCommonSourceDirectory(), sourceMapDir);
	                    sourceMapData.jsSourceMappingURL = ts.getRelativePathToDirectoryOrUrl(ts.getDirectoryPath(ts.normalizePath(filePath)), // get the relative sourceMapDir path based on jsFilePath
	                    ts.combinePaths(sourceMapDir, sourceMapData.jsSourceMappingURL), // this is where user expects to see sourceMap
	                    host.getCurrentDirectory(), host.getCanonicalFileName, 
	                    /*isAbsolutePathAnUrl*/ true);
	                }
	                else {
	                    sourceMapData.jsSourceMappingURL = ts.combinePaths(sourceMapDir, sourceMapData.jsSourceMappingURL);
	                }
	            }
	            else {
	                sourceMapDir = ts.getDirectoryPath(ts.normalizePath(filePath));
	            }
	        }
	        function reset() {
	            currentSourceFile = undefined;
	            sourceMapDir = undefined;
	            sourceMapSourceIndex = undefined;
	            lastRecordedSourceMapSpan = undefined;
	            lastEncodedSourceMapSpan = undefined;
	            lastEncodedNameIndex = undefined;
	            sourceMapData = undefined;
	        }
	        function updateLastEncodedAndRecordedSpans() {
	            if (modifyLastSourcePos) {
	                // Reset the source pos
	                modifyLastSourcePos = false;
	                // Change Last recorded Map with last encoded emit line and character
	                lastRecordedSourceMapSpan.emittedLine = lastEncodedSourceMapSpan.emittedLine;
	                lastRecordedSourceMapSpan.emittedColumn = lastEncodedSourceMapSpan.emittedColumn;
	                // Pop sourceMapDecodedMappings to remove last entry
	                sourceMapData.sourceMapDecodedMappings.pop();
	                // Point the lastEncodedSourceMapSpace to the previous encoded sourceMapSpan
	                // If the list is empty which indicates that we are at the beginning of the file,
	                // we have to reset it to default value (same value when we first initialize sourceMapWriter)
	                lastEncodedSourceMapSpan = sourceMapData.sourceMapDecodedMappings.length ?
	                    sourceMapData.sourceMapDecodedMappings[sourceMapData.sourceMapDecodedMappings.length - 1] :
	                    defaultLastEncodedSourceMapSpan;
	                // TODO: Update lastEncodedNameIndex 
	                // Since we dont support this any more, lets not worry about it right now.
	                // When we start supporting nameIndex, we will get back to this
	                // Change the encoded source map
	                var sourceMapMappings = sourceMapData.sourceMapMappings;
	                var lenthToSet = sourceMapMappings.length - 1;
	                for (; lenthToSet >= 0; lenthToSet--) {
	                    var currentChar = sourceMapMappings.charAt(lenthToSet);
	                    if (currentChar === ",") {
	                        // Separator for the entry found
	                        break;
	                    }
	                    if (currentChar === ";" && lenthToSet !== 0 && sourceMapMappings.charAt(lenthToSet - 1) !== ";") {
	                        // Last line separator found
	                        break;
	                    }
	                }
	                sourceMapData.sourceMapMappings = sourceMapMappings.substr(0, Math.max(0, lenthToSet));
	            }
	        }
	        // Encoding for sourcemap span
	        function encodeLastRecordedSourceMapSpan() {
	            if (!lastRecordedSourceMapSpan || lastRecordedSourceMapSpan === lastEncodedSourceMapSpan) {
	                return;
	            }
	            var prevEncodedEmittedColumn = lastEncodedSourceMapSpan.emittedColumn;
	            // Line/Comma delimiters
	            if (lastEncodedSourceMapSpan.emittedLine === lastRecordedSourceMapSpan.emittedLine) {
	                // Emit comma to separate the entry
	                if (sourceMapData.sourceMapMappings) {
	                    sourceMapData.sourceMapMappings += ",";
	                }
	            }
	            else {
	                // Emit line delimiters
	                for (var encodedLine = lastEncodedSourceMapSpan.emittedLine; encodedLine < lastRecordedSourceMapSpan.emittedLine; encodedLine++) {
	                    sourceMapData.sourceMapMappings += ";";
	                }
	                prevEncodedEmittedColumn = 1;
	            }
	            // 1. Relative Column 0 based
	            sourceMapData.sourceMapMappings += base64VLQFormatEncode(lastRecordedSourceMapSpan.emittedColumn - prevEncodedEmittedColumn);
	            // 2. Relative sourceIndex
	            sourceMapData.sourceMapMappings += base64VLQFormatEncode(lastRecordedSourceMapSpan.sourceIndex - lastEncodedSourceMapSpan.sourceIndex);
	            // 3. Relative sourceLine 0 based
	            sourceMapData.sourceMapMappings += base64VLQFormatEncode(lastRecordedSourceMapSpan.sourceLine - lastEncodedSourceMapSpan.sourceLine);
	            // 4. Relative sourceColumn 0 based
	            sourceMapData.sourceMapMappings += base64VLQFormatEncode(lastRecordedSourceMapSpan.sourceColumn - lastEncodedSourceMapSpan.sourceColumn);
	            // 5. Relative namePosition 0 based
	            if (lastRecordedSourceMapSpan.nameIndex >= 0) {
	                ts.Debug.assert(false, "We do not support name index right now, Make sure to update updateLastEncodedAndRecordedSpans when we start using this");
	                sourceMapData.sourceMapMappings += base64VLQFormatEncode(lastRecordedSourceMapSpan.nameIndex - lastEncodedNameIndex);
	                lastEncodedNameIndex = lastRecordedSourceMapSpan.nameIndex;
	            }
	            lastEncodedSourceMapSpan = lastRecordedSourceMapSpan;
	            sourceMapData.sourceMapDecodedMappings.push(lastEncodedSourceMapSpan);
	        }
	        function emitPos(pos) {
	            if (pos === -1) {
	                return;
	            }
	            var sourceLinePos = ts.getLineAndCharacterOfPosition(currentSourceFile, pos);
	            // Convert the location to be one-based.
	            sourceLinePos.line++;
	            sourceLinePos.character++;
	            var emittedLine = writer.getLine();
	            var emittedColumn = writer.getColumn();
	            // If this location wasn't recorded or the location in source is going backwards, record the span
	            if (!lastRecordedSourceMapSpan ||
	                lastRecordedSourceMapSpan.emittedLine !== emittedLine ||
	                lastRecordedSourceMapSpan.emittedColumn !== emittedColumn ||
	                (lastRecordedSourceMapSpan.sourceIndex === sourceMapSourceIndex &&
	                    (lastRecordedSourceMapSpan.sourceLine > sourceLinePos.line ||
	                        (lastRecordedSourceMapSpan.sourceLine === sourceLinePos.line && lastRecordedSourceMapSpan.sourceColumn > sourceLinePos.character)))) {
	                // Encode the last recordedSpan before assigning new
	                encodeLastRecordedSourceMapSpan();
	                // New span
	                lastRecordedSourceMapSpan = {
	                    emittedLine: emittedLine,
	                    emittedColumn: emittedColumn,
	                    sourceLine: sourceLinePos.line,
	                    sourceColumn: sourceLinePos.character,
	                    sourceIndex: sourceMapSourceIndex
	                };
	                stopOverridingSpan = false;
	            }
	            else if (!stopOverridingSpan) {
	                // Take the new pos instead since there is no change in emittedLine and column since last location
	                lastRecordedSourceMapSpan.sourceLine = sourceLinePos.line;
	                lastRecordedSourceMapSpan.sourceColumn = sourceLinePos.character;
	                lastRecordedSourceMapSpan.sourceIndex = sourceMapSourceIndex;
	            }
	            updateLastEncodedAndRecordedSpans();
	        }
	        function getStartPos(range) {
	            var rangeHasDecorators = !!range.decorators;
	            return range.pos !== -1 ? ts.skipTrivia(currentSourceFile.text, rangeHasDecorators ? range.decorators.end : range.pos) : -1;
	        }
	        function emitStart(range) {
	            emitPos(getStartPos(range));
	        }
	        function emitEnd(range, stopOverridingEnd) {
	            emitPos(range.end);
	            stopOverridingSpan = stopOverridingEnd;
	        }
	        function changeEmitSourcePos() {
	            ts.Debug.assert(!modifyLastSourcePos);
	            modifyLastSourcePos = true;
	        }
	        function setSourceFile(sourceFile) {
	            currentSourceFile = sourceFile;
	            // Add the file to tsFilePaths
	            // If sourceroot option: Use the relative path corresponding to the common directory path
	            // otherwise source locations relative to map file location
	            var sourcesDirectoryPath = compilerOptions.sourceRoot ? host.getCommonSourceDirectory() : sourceMapDir;
	            var source = ts.getRelativePathToDirectoryOrUrl(sourcesDirectoryPath, currentSourceFile.fileName, host.getCurrentDirectory(), host.getCanonicalFileName, 
	            /*isAbsolutePathAnUrl*/ true);
	            sourceMapSourceIndex = ts.indexOf(sourceMapData.sourceMapSources, source);
	            if (sourceMapSourceIndex === -1) {
	                sourceMapSourceIndex = sourceMapData.sourceMapSources.length;
	                sourceMapData.sourceMapSources.push(source);
	                // The one that can be used from program to get the actual source file
	                sourceMapData.inputSourceFileNames.push(sourceFile.fileName);
	                if (compilerOptions.inlineSources) {
	                    sourceMapData.sourceMapSourcesContent.push(sourceFile.text);
	                }
	            }
	        }
	        function getText() {
	            encodeLastRecordedSourceMapSpan();
	            return ts.stringify({
	                version: 3,
	                file: sourceMapData.sourceMapFile,
	                sourceRoot: sourceMapData.sourceMapSourceRoot,
	                sources: sourceMapData.sourceMapSources,
	                names: sourceMapData.sourceMapNames,
	                mappings: sourceMapData.sourceMapMappings,
	                sourcesContent: sourceMapData.sourceMapSourcesContent
	            });
	        }
	        function getSourceMappingURL() {
	            if (compilerOptions.inlineSourceMap) {
	                // Encode the sourceMap into the sourceMap url
	                var base64SourceMapText = ts.convertToBase64(getText());
	                return sourceMapData.jsSourceMappingURL = "data:application/json;base64," + base64SourceMapText;
	            }
	            else {
	                return sourceMapData.jsSourceMappingURL;
	            }
	        }
	    }
	    ts.createSourceMapWriter = createSourceMapWriter;
	    var base64Chars = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
	    function base64FormatEncode(inValue) {
	        if (inValue < 64) {
	            return base64Chars.charAt(inValue);
	        }
	        throw TypeError(inValue + ": not a 64 based value");
	    }
	    function base64VLQFormatEncode(inValue) {
	        // Add a new least significant bit that has the sign of the value.
	        // if negative number the least significant bit that gets added to the number has value 1
	        // else least significant bit value that gets added is 0
	        // eg. -1 changes to binary : 01 [1] => 3
	        //     +1 changes to binary : 01 [0] => 2
	        if (inValue < 0) {
	            inValue = ((-inValue) << 1) + 1;
	        }
	        else {
	            inValue = inValue << 1;
	        }
	        // Encode 5 bits at a time starting from least significant bits
	        var encodedStr = "";
	        do {
	            var currentDigit = inValue & 31; // 11111
	            inValue = inValue >> 5;
	            if (inValue > 0) {
	                // There are still more digits to decode, set the msb (6th bit)
	                currentDigit = currentDigit | 32;
	            }
	            encodedStr = encodedStr + base64FormatEncode(currentDigit);
	        } while (inValue > 0);
	        return encodedStr;
	    }
	})(ts || (ts = {}));
	/// <reference path="checker.ts"/>
	/* @internal */
	var ts;
	(function (ts) {
	    function getDeclarationDiagnostics(host, resolver, targetSourceFile) {
	        var declarationDiagnostics = ts.createDiagnosticCollection();
	        ts.forEachExpectedEmitFile(host, getDeclarationDiagnosticsFromFile, targetSourceFile);
	        return declarationDiagnostics.getDiagnostics(targetSourceFile ? targetSourceFile.fileName : undefined);
	        function getDeclarationDiagnosticsFromFile(_a, sources, isBundledEmit) {
	            var declarationFilePath = _a.declarationFilePath;
	            emitDeclarations(host, resolver, declarationDiagnostics, declarationFilePath, sources, isBundledEmit);
	        }
	    }
	    ts.getDeclarationDiagnostics = getDeclarationDiagnostics;
	    function emitDeclarations(host, resolver, emitterDiagnostics, declarationFilePath, sourceFiles, isBundledEmit) {
	        var newLine = host.getNewLine();
	        var compilerOptions = host.getCompilerOptions();
	        var write;
	        var writeLine;
	        var increaseIndent;
	        var decreaseIndent;
	        var writeTextOfNode;
	        var writer = createAndSetNewTextWriterWithSymbolWriter();
	        var enclosingDeclaration;
	        var resultHasExternalModuleIndicator;
	        var currentText;
	        var currentLineMap;
	        var currentIdentifiers;
	        var isCurrentFileExternalModule;
	        var reportedDeclarationError = false;
	        var errorNameNode;
	        var emitJsDocComments = compilerOptions.removeComments ? function (declaration) { } : writeJsDocComments;
	        var emit = compilerOptions.stripInternal ? stripInternal : emitNode;
	        var noDeclare;
	        var moduleElementDeclarationEmitInfo = [];
	        var asynchronousSubModuleDeclarationEmitInfo;
	        // Contains the reference paths that needs to go in the declaration file.
	        // Collecting this separately because reference paths need to be first thing in the declaration file
	        // and we could be collecting these paths from multiple files into single one with --out option
	        var referencePathsOutput = "";
	        // Emit references corresponding to each file
	        var emittedReferencedFiles = [];
	        var addedGlobalFileReference = false;
	        var allSourcesModuleElementDeclarationEmitInfo = [];
	        ts.forEach(sourceFiles, function (sourceFile) {
	            // Dont emit for javascript file
	            if (ts.isSourceFileJavaScript(sourceFile)) {
	                return;
	            }
	            // Check what references need to be added
	            if (!compilerOptions.noResolve) {
	                ts.forEach(sourceFile.referencedFiles, function (fileReference) {
	                    var referencedFile = ts.tryResolveScriptReference(host, sourceFile, fileReference);
	                    // Emit reference in dts, if the file reference was not already emitted
	                    if (referencedFile && !ts.contains(emittedReferencedFiles, referencedFile)) {
	                        // Add a reference to generated dts file,
	                        // global file reference is added only 
	                        //  - if it is not bundled emit (because otherwise it would be self reference)
	                        //  - and it is not already added
	                        if (writeReferencePath(referencedFile, !isBundledEmit && !addedGlobalFileReference)) {
	                            addedGlobalFileReference = true;
	                        }
	                        emittedReferencedFiles.push(referencedFile);
	                    }
	                });
	            }
	            resultHasExternalModuleIndicator = false;
	            if (!isBundledEmit || !ts.isExternalModule(sourceFile)) {
	                noDeclare = false;
	                emitSourceFile(sourceFile);
	            }
	            else if (ts.isExternalModule(sourceFile)) {
	                noDeclare = true;
	                write("declare module \"" + ts.getResolvedExternalModuleName(host, sourceFile) + "\" {");
	                writeLine();
	                increaseIndent();
	                emitSourceFile(sourceFile);
	                decreaseIndent();
	                write("}");
	                writeLine();
	            }
	            // create asynchronous output for the importDeclarations
	            if (moduleElementDeclarationEmitInfo.length) {
	                var oldWriter = writer;
	                ts.forEach(moduleElementDeclarationEmitInfo, function (aliasEmitInfo) {
	                    if (aliasEmitInfo.isVisible && !aliasEmitInfo.asynchronousOutput) {
	                        ts.Debug.assert(aliasEmitInfo.node.kind === 225 /* ImportDeclaration */);
	                        createAndSetNewTextWriterWithSymbolWriter();
	                        ts.Debug.assert(aliasEmitInfo.indent === 0 || (aliasEmitInfo.indent === 1 && isBundledEmit));
	                        for (var i = 0; i < aliasEmitInfo.indent; i++) {
	                            increaseIndent();
	                        }
	                        writeImportDeclaration(aliasEmitInfo.node);
	                        aliasEmitInfo.asynchronousOutput = writer.getText();
	                        for (var i = 0; i < aliasEmitInfo.indent; i++) {
	                            decreaseIndent();
	                        }
	                    }
	                });
	                setWriter(oldWriter);
	                allSourcesModuleElementDeclarationEmitInfo = allSourcesModuleElementDeclarationEmitInfo.concat(moduleElementDeclarationEmitInfo);
	                moduleElementDeclarationEmitInfo = [];
	            }
	            if (!isBundledEmit && ts.isExternalModule(sourceFile) && sourceFile.moduleAugmentations.length && !resultHasExternalModuleIndicator) {
	                // if file was external module with augmentations - this fact should be preserved in .d.ts as well.
	                // in case if we didn't write any external module specifiers in .d.ts we need to emit something 
	                // that will force compiler to think that this file is an external module - 'export {}' is a reasonable choice here.
	                write("export {};");
	                writeLine();
	            }
	        });
	        return {
	            reportedDeclarationError: reportedDeclarationError,
	            moduleElementDeclarationEmitInfo: allSourcesModuleElementDeclarationEmitInfo,
	            synchronousDeclarationOutput: writer.getText(),
	            referencePathsOutput: referencePathsOutput
	        };
	        function hasInternalAnnotation(range) {
	            var comment = currentText.substring(range.pos, range.end);
	            return comment.indexOf("@internal") >= 0;
	        }
	        function stripInternal(node) {
	            if (node) {
	                var leadingCommentRanges = ts.getLeadingCommentRanges(currentText, node.pos);
	                if (ts.forEach(leadingCommentRanges, hasInternalAnnotation)) {
	                    return;
	                }
	                emitNode(node);
	            }
	        }
	        function createAndSetNewTextWriterWithSymbolWriter() {
	            var writer = ts.createTextWriter(newLine);
	            writer.trackSymbol = trackSymbol;
	            writer.reportInaccessibleThisError = reportInaccessibleThisError;
	            writer.writeKeyword = writer.write;
	            writer.writeOperator = writer.write;
	            writer.writePunctuation = writer.write;
	            writer.writeSpace = writer.write;
	            writer.writeStringLiteral = writer.writeLiteral;
	            writer.writeParameter = writer.write;
	            writer.writeSymbol = writer.write;
	            setWriter(writer);
	            return writer;
	        }
	        function setWriter(newWriter) {
	            writer = newWriter;
	            write = newWriter.write;
	            writeTextOfNode = newWriter.writeTextOfNode;
	            writeLine = newWriter.writeLine;
	            increaseIndent = newWriter.increaseIndent;
	            decreaseIndent = newWriter.decreaseIndent;
	        }
	        function writeAsynchronousModuleElements(nodes) {
	            var oldWriter = writer;
	            ts.forEach(nodes, function (declaration) {
	                var nodeToCheck;
	                if (declaration.kind === 214 /* VariableDeclaration */) {
	                    nodeToCheck = declaration.parent.parent;
	                }
	                else if (declaration.kind === 228 /* NamedImports */ || declaration.kind === 229 /* ImportSpecifier */ || declaration.kind === 226 /* ImportClause */) {
	                    ts.Debug.fail("We should be getting ImportDeclaration instead to write");
	                }
	                else {
	                    nodeToCheck = declaration;
	                }
	                var moduleElementEmitInfo = ts.forEach(moduleElementDeclarationEmitInfo, function (declEmitInfo) { return declEmitInfo.node === nodeToCheck ? declEmitInfo : undefined; });
	                if (!moduleElementEmitInfo && asynchronousSubModuleDeclarationEmitInfo) {
	                    moduleElementEmitInfo = ts.forEach(asynchronousSubModuleDeclarationEmitInfo, function (declEmitInfo) { return declEmitInfo.node === nodeToCheck ? declEmitInfo : undefined; });
	                }
	                // If the alias was marked as not visible when we saw its declaration, we would have saved the aliasEmitInfo, but if we haven't yet visited the alias declaration
	                // then we don't need to write it at this point. We will write it when we actually see its declaration
	                // Eg.
	                // export function bar(a: foo.Foo) { }
	                // import foo = require("foo");
	                // Writing of function bar would mark alias declaration foo as visible but we haven't yet visited that declaration so do nothing,
	                // we would write alias foo declaration when we visit it since it would now be marked as visible
	                if (moduleElementEmitInfo) {
	                    if (moduleElementEmitInfo.node.kind === 225 /* ImportDeclaration */) {
	                        // we have to create asynchronous output only after we have collected complete information
	                        // because it is possible to enable multiple bindings as asynchronously visible
	                        moduleElementEmitInfo.isVisible = true;
	                    }
	                    else {
	                        createAndSetNewTextWriterWithSymbolWriter();
	                        for (var declarationIndent = moduleElementEmitInfo.indent; declarationIndent; declarationIndent--) {
	                            increaseIndent();
	                        }
	                        if (nodeToCheck.kind === 221 /* ModuleDeclaration */) {
	                            ts.Debug.assert(asynchronousSubModuleDeclarationEmitInfo === undefined);
	                            asynchronousSubModuleDeclarationEmitInfo = [];
	                        }
	                        writeModuleElement(nodeToCheck);
	                        if (nodeToCheck.kind === 221 /* ModuleDeclaration */) {
	                            moduleElementEmitInfo.subModuleElementDeclarationEmitInfo = asynchronousSubModuleDeclarationEmitInfo;
	                            asynchronousSubModuleDeclarationEmitInfo = undefined;
	                        }
	                        moduleElementEmitInfo.asynchronousOutput = writer.getText();
	                    }
	                }
	            });
	            setWriter(oldWriter);
	        }
	        function handleSymbolAccessibilityError(symbolAccesibilityResult) {
	            if (symbolAccesibilityResult.accessibility === 0 /* Accessible */) {
	                // write the aliases
	                if (symbolAccesibilityResult && symbolAccesibilityResult.aliasesToMakeVisible) {
	                    writeAsynchronousModuleElements(symbolAccesibilityResult.aliasesToMakeVisible);
	                }
	            }
	            else {
	                // Report error
	                reportedDeclarationError = true;
	                var errorInfo = writer.getSymbolAccessibilityDiagnostic(symbolAccesibilityResult);
	                if (errorInfo) {
	                    if (errorInfo.typeName) {
	                        emitterDiagnostics.add(ts.createDiagnosticForNode(symbolAccesibilityResult.errorNode || errorInfo.errorNode, errorInfo.diagnosticMessage, ts.getTextOfNodeFromSourceText(currentText, errorInfo.typeName), symbolAccesibilityResult.errorSymbolName, symbolAccesibilityResult.errorModuleName));
	                    }
	                    else {
	                        emitterDiagnostics.add(ts.createDiagnosticForNode(symbolAccesibilityResult.errorNode || errorInfo.errorNode, errorInfo.diagnosticMessage, symbolAccesibilityResult.errorSymbolName, symbolAccesibilityResult.errorModuleName));
	                    }
	                }
	            }
	        }
	        function trackSymbol(symbol, enclosingDeclaration, meaning) {
	            handleSymbolAccessibilityError(resolver.isSymbolAccessible(symbol, enclosingDeclaration, meaning));
	        }
	        function reportInaccessibleThisError() {
	            if (errorNameNode) {
	                reportedDeclarationError = true;
	                emitterDiagnostics.add(ts.createDiagnosticForNode(errorNameNode, ts.Diagnostics.The_inferred_type_of_0_references_an_inaccessible_this_type_A_type_annotation_is_necessary, ts.declarationNameToString(errorNameNode)));
	            }
	        }
	        function writeTypeOfDeclaration(declaration, type, getSymbolAccessibilityDiagnostic) {
	            writer.getSymbolAccessibilityDiagnostic = getSymbolAccessibilityDiagnostic;
	            write(": ");
	            if (type) {
	                // Write the type
	                emitType(type);
	            }
	            else {
	                errorNameNode = declaration.name;
	                resolver.writeTypeOfDeclaration(declaration, enclosingDeclaration, 2 /* UseTypeOfFunction */, writer);
	                errorNameNode = undefined;
	            }
	        }
	        function writeReturnTypeAtSignature(signature, getSymbolAccessibilityDiagnostic) {
	            writer.getSymbolAccessibilityDiagnostic = getSymbolAccessibilityDiagnostic;
	            write(": ");
	            if (signature.type) {
	                // Write the type
	                emitType(signature.type);
	            }
	            else {
	                errorNameNode = signature.name;
	                resolver.writeReturnTypeOfSignatureDeclaration(signature, enclosingDeclaration, 2 /* UseTypeOfFunction */, writer);
	                errorNameNode = undefined;
	            }
	        }
	        function emitLines(nodes) {
	            for (var _i = 0, nodes_2 = nodes; _i < nodes_2.length; _i++) {
	                var node = nodes_2[_i];
	                emit(node);
	            }
	        }
	        function emitSeparatedList(nodes, separator, eachNodeEmitFn, canEmitFn) {
	            var currentWriterPos = writer.getTextPos();
	            for (var _i = 0, nodes_3 = nodes; _i < nodes_3.length; _i++) {
	                var node = nodes_3[_i];
	                if (!canEmitFn || canEmitFn(node)) {
	                    if (currentWriterPos !== writer.getTextPos()) {
	                        write(separator);
	                    }
	                    currentWriterPos = writer.getTextPos();
	                    eachNodeEmitFn(node);
	                }
	            }
	        }
	        function emitCommaList(nodes, eachNodeEmitFn, canEmitFn) {
	            emitSeparatedList(nodes, ", ", eachNodeEmitFn, canEmitFn);
	        }
	        function writeJsDocComments(declaration) {
	            if (declaration) {
	                var jsDocComments = ts.getJsDocCommentsFromText(declaration, currentText);
	                ts.emitNewLineBeforeLeadingComments(currentLineMap, writer, declaration, jsDocComments);
	                // jsDoc comments are emitted at /*leading comment1 */space/*leading comment*/space
	                ts.emitComments(currentText, currentLineMap, writer, jsDocComments, /*trailingSeparator*/ true, newLine, ts.writeCommentRange);
	            }
	        }
	        function emitTypeWithNewGetSymbolAccessibilityDiagnostic(type, getSymbolAccessibilityDiagnostic) {
	            writer.getSymbolAccessibilityDiagnostic = getSymbolAccessibilityDiagnostic;
	            emitType(type);
	        }
	        function emitType(type) {
	            switch (type.kind) {
	                case 117 /* AnyKeyword */:
	                case 130 /* StringKeyword */:
	                case 128 /* NumberKeyword */:
	                case 120 /* BooleanKeyword */:
	                case 131 /* SymbolKeyword */:
	                case 103 /* VoidKeyword */:
	                case 162 /* ThisType */:
	                case 163 /* StringLiteralType */:
	                    return writeTextOfNode(currentText, type);
	                case 191 /* ExpressionWithTypeArguments */:
	                    return emitExpressionWithTypeArguments(type);
	                case 152 /* TypeReference */:
	                    return emitTypeReference(type);
	                case 155 /* TypeQuery */:
	                    return emitTypeQuery(type);
	                case 157 /* ArrayType */:
	                    return emitArrayType(type);
	                case 158 /* TupleType */:
	                    return emitTupleType(type);
	                case 159 /* UnionType */:
	                    return emitUnionType(type);
	                case 160 /* IntersectionType */:
	                    return emitIntersectionType(type);
	                case 161 /* ParenthesizedType */:
	                    return emitParenType(type);
	                case 153 /* FunctionType */:
	                case 154 /* ConstructorType */:
	                    return emitSignatureDeclarationWithJsDocComments(type);
	                case 156 /* TypeLiteral */:
	                    return emitTypeLiteral(type);
	                case 69 /* Identifier */:
	                    return emitEntityName(type);
	                case 136 /* QualifiedName */:
	                    return emitEntityName(type);
	                case 151 /* TypePredicate */:
	                    return emitTypePredicate(type);
	            }
	            function writeEntityName(entityName) {
	                if (entityName.kind === 69 /* Identifier */) {
	                    writeTextOfNode(currentText, entityName);
	                }
	                else {
	                    var left = entityName.kind === 136 /* QualifiedName */ ? entityName.left : entityName.expression;
	                    var right = entityName.kind === 136 /* QualifiedName */ ? entityName.right : entityName.name;
	                    writeEntityName(left);
	                    write(".");
	                    writeTextOfNode(currentText, right);
	                }
	            }
	            function emitEntityName(entityName) {
	                var visibilityResult = resolver.isEntityNameVisible(entityName, 
	                // Aliases can be written asynchronously so use correct enclosing declaration
	                entityName.parent.kind === 224 /* ImportEqualsDeclaration */ ? entityName.parent : enclosingDeclaration);
	                handleSymbolAccessibilityError(visibilityResult);
	                writeEntityName(entityName);
	            }
	            function emitExpressionWithTypeArguments(node) {
	                if (ts.isSupportedExpressionWithTypeArguments(node)) {
	                    ts.Debug.assert(node.expression.kind === 69 /* Identifier */ || node.expression.kind === 169 /* PropertyAccessExpression */);
	                    emitEntityName(node.expression);
	                    if (node.typeArguments) {
	                        write("<");
	                        emitCommaList(node.typeArguments, emitType);
	                        write(">");
	                    }
	                }
	            }
	            function emitTypeReference(type) {
	                emitEntityName(type.typeName);
	                if (type.typeArguments) {
	                    write("<");
	                    emitCommaList(type.typeArguments, emitType);
	                    write(">");
	                }
	            }
	            function emitTypePredicate(type) {
	                writeTextOfNode(currentText, type.parameterName);
	                write(" is ");
	                emitType(type.type);
	            }
	            function emitTypeQuery(type) {
	                write("typeof ");
	                emitEntityName(type.exprName);
	            }
	            function emitArrayType(type) {
	                emitType(type.elementType);
	                write("[]");
	            }
	            function emitTupleType(type) {
	                write("[");
	                emitCommaList(type.elementTypes, emitType);
	                write("]");
	            }
	            function emitUnionType(type) {
	                emitSeparatedList(type.types, " | ", emitType);
	            }
	            function emitIntersectionType(type) {
	                emitSeparatedList(type.types, " & ", emitType);
	            }
	            function emitParenType(type) {
	                write("(");
	                emitType(type.type);
	                write(")");
	            }
	            function emitTypeLiteral(type) {
	                write("{");
	                if (type.members.length) {
	                    writeLine();
	                    increaseIndent();
	                    // write members
	                    emitLines(type.members);
	                    decreaseIndent();
	                }
	                write("}");
	            }
	        }
	        function emitSourceFile(node) {
	            currentText = node.text;
	            currentLineMap = ts.getLineStarts(node);
	            currentIdentifiers = node.identifiers;
	            isCurrentFileExternalModule = ts.isExternalModule(node);
	            enclosingDeclaration = node;
	            ts.emitDetachedComments(currentText, currentLineMap, writer, ts.writeCommentRange, node, newLine, true /* remove comments */);
	            emitLines(node.statements);
	        }
	        // Return a temp variable name to be used in `export default` statements.
	        // The temp name will be of the form _default_counter.
	        // Note that export default is only allowed at most once in a module, so we
	        // do not need to keep track of created temp names.
	        function getExportDefaultTempVariableName() {
	            var baseName = "_default";
	            if (!ts.hasProperty(currentIdentifiers, baseName)) {
	                return baseName;
	            }
	            var count = 0;
	            while (true) {
	                count++;
	                var name_21 = baseName + "_" + count;
	                if (!ts.hasProperty(currentIdentifiers, name_21)) {
	                    return name_21;
	                }
	            }
	        }
	        function emitExportAssignment(node) {
	            if (node.expression.kind === 69 /* Identifier */) {
	                write(node.isExportEquals ? "export = " : "export default ");
	                writeTextOfNode(currentText, node.expression);
	            }
	            else {
	                // Expression
	                var tempVarName = getExportDefaultTempVariableName();
	                write("declare var ");
	                write(tempVarName);
	                write(": ");
	                writer.getSymbolAccessibilityDiagnostic = getDefaultExportAccessibilityDiagnostic;
	                resolver.writeTypeOfExpression(node.expression, enclosingDeclaration, 2 /* UseTypeOfFunction */, writer);
	                write(";");
	                writeLine();
	                write(node.isExportEquals ? "export = " : "export default ");
	                write(tempVarName);
	            }
	            write(";");
	            writeLine();
	            // Make all the declarations visible for the export name
	            if (node.expression.kind === 69 /* Identifier */) {
	                var nodes = resolver.collectLinkedAliases(node.expression);
	                // write each of these declarations asynchronously
	                writeAsynchronousModuleElements(nodes);
	            }
	            function getDefaultExportAccessibilityDiagnostic(diagnostic) {
	                return {
	                    diagnosticMessage: ts.Diagnostics.Default_export_of_the_module_has_or_is_using_private_name_0,
	                    errorNode: node
	                };
	            }
	        }
	        function isModuleElementVisible(node) {
	            return resolver.isDeclarationVisible(node);
	        }
	        function emitModuleElement(node, isModuleElementVisible) {
	            if (isModuleElementVisible) {
	                writeModuleElement(node);
	            }
	            else if (node.kind === 224 /* ImportEqualsDeclaration */ ||
	                (node.parent.kind === 251 /* SourceFile */ && isCurrentFileExternalModule)) {
	                var isVisible = void 0;
	                if (asynchronousSubModuleDeclarationEmitInfo && node.parent.kind !== 251 /* SourceFile */) {
	                    // Import declaration of another module that is visited async so lets put it in right spot
	                    asynchronousSubModuleDeclarationEmitInfo.push({
	                        node: node,
	                        outputPos: writer.getTextPos(),
	                        indent: writer.getIndent(),
	                        isVisible: isVisible
	                    });
	                }
	                else {
	                    if (node.kind === 225 /* ImportDeclaration */) {
	                        var importDeclaration = node;
	                        if (importDeclaration.importClause) {
	                            isVisible = (importDeclaration.importClause.name && resolver.isDeclarationVisible(importDeclaration.importClause)) ||
	                                isVisibleNamedBinding(importDeclaration.importClause.namedBindings);
	                        }
	                    }
	                    moduleElementDeclarationEmitInfo.push({
	                        node: node,
	                        outputPos: writer.getTextPos(),
	                        indent: writer.getIndent(),
	                        isVisible: isVisible
	                    });
	                }
	            }
	        }
	        function writeModuleElement(node) {
	            switch (node.kind) {
	                case 216 /* FunctionDeclaration */:
	                    return writeFunctionDeclaration(node);
	                case 196 /* VariableStatement */:
	                    return writeVariableStatement(node);
	                case 218 /* InterfaceDeclaration */:
	                    return writeInterfaceDeclaration(node);
	                case 217 /* ClassDeclaration */:
	                    return writeClassDeclaration(node);
	                case 219 /* TypeAliasDeclaration */:
	                    return writeTypeAliasDeclaration(node);
	                case 220 /* EnumDeclaration */:
	                    return writeEnumDeclaration(node);
	                case 221 /* ModuleDeclaration */:
	                    return writeModuleDeclaration(node);
	                case 224 /* ImportEqualsDeclaration */:
	                    return writeImportEqualsDeclaration(node);
	                case 225 /* ImportDeclaration */:
	                    return writeImportDeclaration(node);
	                default:
	                    ts.Debug.fail("Unknown symbol kind");
	            }
	        }
	        function emitModuleElementDeclarationFlags(node) {
	            // If the node is parented in the current source file we need to emit export declare or just export
	            if (node.parent.kind === 251 /* SourceFile */) {
	                // If the node is exported
	                if (node.flags & 2 /* Export */) {
	                    write("export ");
	                }
	                if (node.flags & 512 /* Default */) {
	                    write("default ");
	                }
	                else if (node.kind !== 218 /* InterfaceDeclaration */ && !noDeclare) {
	                    write("declare ");
	                }
	            }
	        }
	        function emitClassMemberDeclarationFlags(node) {
	            if (node.flags & 16 /* Private */) {
	                write("private ");
	            }
	            else if (node.flags & 32 /* Protected */) {
	                write("protected ");
	            }
	            if (node.flags & 64 /* Static */) {
	                write("static ");
	            }
	            if (node.flags & 128 /* Abstract */) {
	                write("abstract ");
	            }
	        }
	        function writeImportEqualsDeclaration(node) {
	            // note usage of writer. methods instead of aliases created, just to make sure we are using
	            // correct writer especially to handle asynchronous alias writing
	            emitJsDocComments(node);
	            if (node.flags & 2 /* Export */) {
	                write("export ");
	            }
	            write("import ");
	            writeTextOfNode(currentText, node.name);
	            write(" = ");
	            if (ts.isInternalModuleImportEqualsDeclaration(node)) {
	                emitTypeWithNewGetSymbolAccessibilityDiagnostic(node.moduleReference, getImportEntityNameVisibilityError);
	                write(";");
	            }
	            else {
	                write("require(");
	                emitExternalModuleSpecifier(node);
	                write(");");
	            }
	            writer.writeLine();
	            function getImportEntityNameVisibilityError(symbolAccesibilityResult) {
	                return {
	                    diagnosticMessage: ts.Diagnostics.Import_declaration_0_is_using_private_name_1,
	                    errorNode: node,
	                    typeName: node.name
	                };
	            }
	        }
	        function isVisibleNamedBinding(namedBindings) {
	            if (namedBindings) {
	                if (namedBindings.kind === 227 /* NamespaceImport */) {
	                    return resolver.isDeclarationVisible(namedBindings);
	                }
	                else {
	                    return ts.forEach(namedBindings.elements, function (namedImport) { return resolver.isDeclarationVisible(namedImport); });
	                }
	            }
	        }
	        function writeImportDeclaration(node) {
	            emitJsDocComments(node);
	            if (node.flags & 2 /* Export */) {
	                write("export ");
	            }
	            write("import ");
	            if (node.importClause) {
	                var currentWriterPos = writer.getTextPos();
	                if (node.importClause.name && resolver.isDeclarationVisible(node.importClause)) {
	                    writeTextOfNode(currentText, node.importClause.name);
	                }
	                if (node.importClause.namedBindings && isVisibleNamedBinding(node.importClause.namedBindings)) {
	                    if (currentWriterPos !== writer.getTextPos()) {
	                        // If the default binding was emitted, write the separated
	                        write(", ");
	                    }
	                    if (node.importClause.namedBindings.kind === 227 /* NamespaceImport */) {
	                        write("* as ");
	                        writeTextOfNode(currentText, node.importClause.namedBindings.name);
	                    }
	                    else {
	                        write("{ ");
	                        emitCommaList(node.importClause.namedBindings.elements, emitImportOrExportSpecifier, resolver.isDeclarationVisible);
	                        write(" }");
	                    }
	                }
	                write(" from ");
	            }
	            emitExternalModuleSpecifier(node);
	            write(";");
	            writer.writeLine();
	        }
	        function emitExternalModuleSpecifier(parent) {
	            // emitExternalModuleSpecifier is usually called when we emit something in the.d.ts file that will make it an external module (i.e. import/export declarations).
	            // the only case when it is not true is when we call it to emit correct name for module augmentation - d.ts files with just module augmentations are not considered 
	            // external modules since they are indistingushable from script files with ambient modules. To fix this in such d.ts files we'll emit top level 'export {}'
	            // so compiler will treat them as external modules.
	            resultHasExternalModuleIndicator = resultHasExternalModuleIndicator || parent.kind !== 221 /* ModuleDeclaration */;
	            var moduleSpecifier;
	            if (parent.kind === 224 /* ImportEqualsDeclaration */) {
	                var node = parent;
	                moduleSpecifier = ts.getExternalModuleImportEqualsDeclarationExpression(node);
	            }
	            else if (parent.kind === 221 /* ModuleDeclaration */) {
	                moduleSpecifier = parent.name;
	            }
	            else {
	                var node = parent;
	                moduleSpecifier = node.moduleSpecifier;
	            }
	            if (moduleSpecifier.kind === 9 /* StringLiteral */ && isBundledEmit && (compilerOptions.out || compilerOptions.outFile)) {
	                var moduleName = ts.getExternalModuleNameFromDeclaration(host, resolver, parent);
	                if (moduleName) {
	                    write("\"");
	                    write(moduleName);
	                    write("\"");
	                    return;
	                }
	            }
	            writeTextOfNode(currentText, moduleSpecifier);
	        }
	        function emitImportOrExportSpecifier(node) {
	            if (node.propertyName) {
	                writeTextOfNode(currentText, node.propertyName);
	                write(" as ");
	            }
	            writeTextOfNode(currentText, node.name);
	        }
	        function emitExportSpecifier(node) {
	            emitImportOrExportSpecifier(node);
	            // Make all the declarations visible for the export name
	            var nodes = resolver.collectLinkedAliases(node.propertyName || node.name);
	            // write each of these declarations asynchronously
	            writeAsynchronousModuleElements(nodes);
	        }
	        function emitExportDeclaration(node) {
	            emitJsDocComments(node);
	            write("export ");
	            if (node.exportClause) {
	                write("{ ");
	                emitCommaList(node.exportClause.elements, emitExportSpecifier);
	                write(" }");
	            }
	            else {
	                write("*");
	            }
	            if (node.moduleSpecifier) {
	                write(" from ");
	                emitExternalModuleSpecifier(node);
	            }
	            write(";");
	            writer.writeLine();
	        }
	        function writeModuleDeclaration(node) {
	            emitJsDocComments(node);
	            emitModuleElementDeclarationFlags(node);
	            if (ts.isGlobalScopeAugmentation(node)) {
	                write("global ");
	            }
	            else {
	                if (node.flags & 65536 /* Namespace */) {
	                    write("namespace ");
	                }
	                else {
	                    write("module ");
	                }
	                if (ts.isExternalModuleAugmentation(node)) {
	                    emitExternalModuleSpecifier(node);
	                }
	                else {
	                    writeTextOfNode(currentText, node.name);
	                }
	            }
	            while (node.body.kind !== 222 /* ModuleBlock */) {
	                node = node.body;
	                write(".");
	                writeTextOfNode(currentText, node.name);
	            }
	            var prevEnclosingDeclaration = enclosingDeclaration;
	            enclosingDeclaration = node;
	            write(" {");
	            writeLine();
	            increaseIndent();
	            emitLines(node.body.statements);
	            decreaseIndent();
	            write("}");
	            writeLine();
	            enclosingDeclaration = prevEnclosingDeclaration;
	        }
	        function writeTypeAliasDeclaration(node) {
	            var prevEnclosingDeclaration = enclosingDeclaration;
	            enclosingDeclaration = node;
	            emitJsDocComments(node);
	            emitModuleElementDeclarationFlags(node);
	            write("type ");
	            writeTextOfNode(currentText, node.name);
	            emitTypeParameters(node.typeParameters);
	            write(" = ");
	            emitTypeWithNewGetSymbolAccessibilityDiagnostic(node.type, getTypeAliasDeclarationVisibilityError);
	            write(";");
	            writeLine();
	            enclosingDeclaration = prevEnclosingDeclaration;
	            function getTypeAliasDeclarationVisibilityError(symbolAccesibilityResult) {
	                return {
	                    diagnosticMessage: ts.Diagnostics.Exported_type_alias_0_has_or_is_using_private_name_1,
	                    errorNode: node.type,
	                    typeName: node.name
	                };
	            }
	        }
	        function writeEnumDeclaration(node) {
	            emitJsDocComments(node);
	            emitModuleElementDeclarationFlags(node);
	            if (ts.isConst(node)) {
	                write("const ");
	            }
	            write("enum ");
	            writeTextOfNode(currentText, node.name);
	            write(" {");
	            writeLine();
	            increaseIndent();
	            emitLines(node.members);
	            decreaseIndent();
	            write("}");
	            writeLine();
	        }
	        function emitEnumMemberDeclaration(node) {
	            emitJsDocComments(node);
	            writeTextOfNode(currentText, node.name);
	            var enumMemberValue = resolver.getConstantValue(node);
	            if (enumMemberValue !== undefined) {
	                write(" = ");
	                write(enumMemberValue.toString());
	            }
	            write(",");
	            writeLine();
	        }
	        function isPrivateMethodTypeParameter(node) {
	            return node.parent.kind === 144 /* MethodDeclaration */ && (node.parent.flags & 16 /* Private */);
	        }
	        function emitTypeParameters(typeParameters) {
	            function emitTypeParameter(node) {
	                increaseIndent();
	                emitJsDocComments(node);
	                decreaseIndent();
	                writeTextOfNode(currentText, node.name);
	                // If there is constraint present and this is not a type parameter of the private method emit the constraint
	                if (node.constraint && !isPrivateMethodTypeParameter(node)) {
	                    write(" extends ");
	                    if (node.parent.kind === 153 /* FunctionType */ ||
	                        node.parent.kind === 154 /* ConstructorType */ ||
	                        (node.parent.parent && node.parent.parent.kind === 156 /* TypeLiteral */)) {
	                        ts.Debug.assert(node.parent.kind === 144 /* MethodDeclaration */ ||
	                            node.parent.kind === 143 /* MethodSignature */ ||
	                            node.parent.kind === 153 /* FunctionType */ ||
	                            node.parent.kind === 154 /* ConstructorType */ ||
	                            node.parent.kind === 148 /* CallSignature */ ||
	                            node.parent.kind === 149 /* ConstructSignature */);
	                        emitType(node.constraint);
	                    }
	                    else {
	                        emitTypeWithNewGetSymbolAccessibilityDiagnostic(node.constraint, getTypeParameterConstraintVisibilityError);
	                    }
	                }
	                function getTypeParameterConstraintVisibilityError(symbolAccesibilityResult) {
	                    // Type parameter constraints are named by user so we should always be able to name it
	                    var diagnosticMessage;
	                    switch (node.parent.kind) {
	                        case 217 /* ClassDeclaration */:
	                            diagnosticMessage = ts.Diagnostics.Type_parameter_0_of_exported_class_has_or_is_using_private_name_1;
	                            break;
	                        case 218 /* InterfaceDeclaration */:
	                            diagnosticMessage = ts.Diagnostics.Type_parameter_0_of_exported_interface_has_or_is_using_private_name_1;
	                            break;
	                        case 149 /* ConstructSignature */:
	                            diagnosticMessage = ts.Diagnostics.Type_parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1;
	                            break;
	                        case 148 /* CallSignature */:
	                            diagnosticMessage = ts.Diagnostics.Type_parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1;
	                            break;
	                        case 144 /* MethodDeclaration */:
	                        case 143 /* MethodSignature */:
	                            if (node.parent.flags & 64 /* Static */) {
	                                diagnosticMessage = ts.Diagnostics.Type_parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1;
	                            }
	                            else if (node.parent.parent.kind === 217 /* ClassDeclaration */) {
	                                diagnosticMessage = ts.Diagnostics.Type_parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1;
	                            }
	                            else {
	                                diagnosticMessage = ts.Diagnostics.Type_parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1;
	                            }
	                            break;
	                        case 216 /* FunctionDeclaration */:
	                            diagnosticMessage = ts.Diagnostics.Type_parameter_0_of_exported_function_has_or_is_using_private_name_1;
	                            break;
	                        default:
	                            ts.Debug.fail("This is unknown parent for type parameter: " + node.parent.kind);
	                    }
	                    return {
	                        diagnosticMessage: diagnosticMessage,
	                        errorNode: node,
	                        typeName: node.name
	                    };
	                }
	            }
	            if (typeParameters) {
	                write("<");
	                emitCommaList(typeParameters, emitTypeParameter);
	                write(">");
	            }
	        }
	        function emitHeritageClause(typeReferences, isImplementsList) {
	            if (typeReferences) {
	                write(isImplementsList ? " implements " : " extends ");
	                emitCommaList(typeReferences, emitTypeOfTypeReference);
	            }
	            function emitTypeOfTypeReference(node) {
	                if (ts.isSupportedExpressionWithTypeArguments(node)) {
	                    emitTypeWithNewGetSymbolAccessibilityDiagnostic(node, getHeritageClauseVisibilityError);
	                }
	                else if (!isImplementsList && node.expression.kind === 93 /* NullKeyword */) {
	                    write("null");
	                }
	                function getHeritageClauseVisibilityError(symbolAccesibilityResult) {
	                    var diagnosticMessage;
	                    // Heritage clause is written by user so it can always be named
	                    if (node.parent.parent.kind === 217 /* ClassDeclaration */) {
	                        // Class or Interface implemented/extended is inaccessible
	                        diagnosticMessage = isImplementsList ?
	                            ts.Diagnostics.Implements_clause_of_exported_class_0_has_or_is_using_private_name_1 :
	                            ts.Diagnostics.Extends_clause_of_exported_class_0_has_or_is_using_private_name_1;
	                    }
	                    else {
	                        // interface is inaccessible
	                        diagnosticMessage = ts.Diagnostics.Extends_clause_of_exported_interface_0_has_or_is_using_private_name_1;
	                    }
	                    return {
	                        diagnosticMessage: diagnosticMessage,
	                        errorNode: node,
	                        typeName: node.parent.parent.name
	                    };
	                }
	            }
	        }
	        function writeClassDeclaration(node) {
	            function emitParameterProperties(constructorDeclaration) {
	                if (constructorDeclaration) {
	                    ts.forEach(constructorDeclaration.parameters, function (param) {
	                        if (param.flags & 56 /* AccessibilityModifier */) {
	                            emitPropertyDeclaration(param);
	                        }
	                    });
	                }
	            }
	            emitJsDocComments(node);
	            emitModuleElementDeclarationFlags(node);
	            if (node.flags & 128 /* Abstract */) {
	                write("abstract ");
	            }
	            write("class ");
	            writeTextOfNode(currentText, node.name);
	            var prevEnclosingDeclaration = enclosingDeclaration;
	            enclosingDeclaration = node;
	            emitTypeParameters(node.typeParameters);
	            var baseTypeNode = ts.getClassExtendsHeritageClauseElement(node);
	            if (baseTypeNode) {
	                emitHeritageClause([baseTypeNode], /*isImplementsList*/ false);
	            }
	            emitHeritageClause(ts.getClassImplementsHeritageClauseElements(node), /*isImplementsList*/ true);
	            write(" {");
	            writeLine();
	            increaseIndent();
	            emitParameterProperties(ts.getFirstConstructorWithBody(node));
	            emitLines(node.members);
	            decreaseIndent();
	            write("}");
	            writeLine();
	            enclosingDeclaration = prevEnclosingDeclaration;
	        }
	        function writeInterfaceDeclaration(node) {
	            emitJsDocComments(node);
	            emitModuleElementDeclarationFlags(node);
	            write("interface ");
	            writeTextOfNode(currentText, node.name);
	            var prevEnclosingDeclaration = enclosingDeclaration;
	            enclosingDeclaration = node;
	            emitTypeParameters(node.typeParameters);
	            emitHeritageClause(ts.getInterfaceBaseTypeNodes(node), /*isImplementsList*/ false);
	            write(" {");
	            writeLine();
	            increaseIndent();
	            emitLines(node.members);
	            decreaseIndent();
	            write("}");
	            writeLine();
	            enclosingDeclaration = prevEnclosingDeclaration;
	        }
	        function emitPropertyDeclaration(node) {
	            if (ts.hasDynamicName(node)) {
	                return;
	            }
	            emitJsDocComments(node);
	            emitClassMemberDeclarationFlags(node);
	            emitVariableDeclaration(node);
	            write(";");
	            writeLine();
	        }
	        function emitVariableDeclaration(node) {
	            // If we are emitting property it isn't moduleElement and hence we already know it needs to be emitted
	            // so there is no check needed to see if declaration is visible
	            if (node.kind !== 214 /* VariableDeclaration */ || resolver.isDeclarationVisible(node)) {
	                if (ts.isBindingPattern(node.name)) {
	                    emitBindingPattern(node.name);
	                }
	                else {
	                    // If this node is a computed name, it can only be a symbol, because we've already skipped
	                    // it if it's not a well known symbol. In that case, the text of the name will be exactly
	                    // what we want, namely the name expression enclosed in brackets.
	                    writeTextOfNode(currentText, node.name);
	                    // If optional property emit ?
	                    if ((node.kind === 142 /* PropertyDeclaration */ || node.kind === 141 /* PropertySignature */) && ts.hasQuestionToken(node)) {
	                        write("?");
	                    }
	                    if ((node.kind === 142 /* PropertyDeclaration */ || node.kind === 141 /* PropertySignature */) && node.parent.kind === 156 /* TypeLiteral */) {
	                        emitTypeOfVariableDeclarationFromTypeLiteral(node);
	                    }
	                    else if (!(node.flags & 16 /* Private */)) {
	                        writeTypeOfDeclaration(node, node.type, getVariableDeclarationTypeVisibilityError);
	                    }
	                }
	            }
	            function getVariableDeclarationTypeVisibilityDiagnosticMessage(symbolAccesibilityResult) {
	                if (node.kind === 214 /* VariableDeclaration */) {
	                    return symbolAccesibilityResult.errorModuleName ?
	                        symbolAccesibilityResult.accessibility === 2 /* CannotBeNamed */ ?
	                            ts.Diagnostics.Exported_variable_0_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named :
	                            ts.Diagnostics.Exported_variable_0_has_or_is_using_name_1_from_private_module_2 :
	                        ts.Diagnostics.Exported_variable_0_has_or_is_using_private_name_1;
	                }
	                else if (node.kind === 142 /* PropertyDeclaration */ || node.kind === 141 /* PropertySignature */) {
	                    // TODO(jfreeman): Deal with computed properties in error reporting.
	                    if (node.flags & 64 /* Static */) {
	                        return symbolAccesibilityResult.errorModuleName ?
	                            symbolAccesibilityResult.accessibility === 2 /* CannotBeNamed */ ?
	                                ts.Diagnostics.Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named :
	                                ts.Diagnostics.Public_static_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2 :
	                            ts.Diagnostics.Public_static_property_0_of_exported_class_has_or_is_using_private_name_1;
	                    }
	                    else if (node.parent.kind === 217 /* ClassDeclaration */) {
	                        return symbolAccesibilityResult.errorModuleName ?
	                            symbolAccesibilityResult.accessibility === 2 /* CannotBeNamed */ ?
	                                ts.Diagnostics.Public_property_0_of_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named :
	                                ts.Diagnostics.Public_property_0_of_exported_class_has_or_is_using_name_1_from_private_module_2 :
	                            ts.Diagnostics.Public_property_0_of_exported_class_has_or_is_using_private_name_1;
	                    }
	                    else {
	                        // Interfaces cannot have types that cannot be named
	                        return symbolAccesibilityResult.errorModuleName ?
	                            ts.Diagnostics.Property_0_of_exported_interface_has_or_is_using_name_1_from_private_module_2 :
	                            ts.Diagnostics.Property_0_of_exported_interface_has_or_is_using_private_name_1;
	                    }
	                }
	            }
	            function getVariableDeclarationTypeVisibilityError(symbolAccesibilityResult) {
	                var diagnosticMessage = getVariableDeclarationTypeVisibilityDiagnosticMessage(symbolAccesibilityResult);
	                return diagnosticMessage !== undefined ? {
	                    diagnosticMessage: diagnosticMessage,
	                    errorNode: node,
	                    typeName: node.name
	                } : undefined;
	            }
	            function emitBindingPattern(bindingPattern) {
	                // Only select non-omitted expression from the bindingPattern's elements.
	                // We have to do this to avoid emitting trailing commas.
	                // For example:
	                //      original: var [, c,,] = [ 2,3,4]
	                //      emitted: declare var c: number; // instead of declare var c:number, ;
	                var elements = [];
	                for (var _i = 0, _a = bindingPattern.elements; _i < _a.length; _i++) {
	                    var element = _a[_i];
	                    if (element.kind !== 190 /* OmittedExpression */) {
	                        elements.push(element);
	                    }
	                }
	                emitCommaList(elements, emitBindingElement);
	            }
	            function emitBindingElement(bindingElement) {
	                function getBindingElementTypeVisibilityError(symbolAccesibilityResult) {
	                    var diagnosticMessage = getVariableDeclarationTypeVisibilityDiagnosticMessage(symbolAccesibilityResult);
	                    return diagnosticMessage !== undefined ? {
	                        diagnosticMessage: diagnosticMessage,
	                        errorNode: bindingElement,
	                        typeName: bindingElement.name
	                    } : undefined;
	                }
	                if (bindingElement.name) {
	                    if (ts.isBindingPattern(bindingElement.name)) {
	                        emitBindingPattern(bindingElement.name);
	                    }
	                    else {
	                        writeTextOfNode(currentText, bindingElement.name);
	                        writeTypeOfDeclaration(bindingElement, /*type*/ undefined, getBindingElementTypeVisibilityError);
	                    }
	                }
	            }
	        }
	        function emitTypeOfVariableDeclarationFromTypeLiteral(node) {
	            // if this is property of type literal,
	            // or is parameter of method/call/construct/index signature of type literal
	            // emit only if type is specified
	            if (node.type) {
	                write(": ");
	                emitType(node.type);
	            }
	        }
	        function isVariableStatementVisible(node) {
	            return ts.forEach(node.declarationList.declarations, function (varDeclaration) { return resolver.isDeclarationVisible(varDeclaration); });
	        }
	        function writeVariableStatement(node) {
	            emitJsDocComments(node);
	            emitModuleElementDeclarationFlags(node);
	            if (ts.isLet(node.declarationList)) {
	                write("let ");
	            }
	            else if (ts.isConst(node.declarationList)) {
	                write("const ");
	            }
	            else {
	                write("var ");
	            }
	            emitCommaList(node.declarationList.declarations, emitVariableDeclaration, resolver.isDeclarationVisible);
	            write(";");
	            writeLine();
	        }
	        function emitAccessorDeclaration(node) {
	            if (ts.hasDynamicName(node)) {
	                return;
	            }
	            var accessors = ts.getAllAccessorDeclarations(node.parent.members, node);
	            var accessorWithTypeAnnotation;
	            if (node === accessors.firstAccessor) {
	                emitJsDocComments(accessors.getAccessor);
	                emitJsDocComments(accessors.setAccessor);
	                emitClassMemberDeclarationFlags(node);
	                writeTextOfNode(currentText, node.name);
	                if (!(node.flags & 16 /* Private */)) {
	                    accessorWithTypeAnnotation = node;
	                    var type = getTypeAnnotationFromAccessor(node);
	                    if (!type) {
	                        // couldn't get type for the first accessor, try the another one
	                        var anotherAccessor = node.kind === 146 /* GetAccessor */ ? accessors.setAccessor : accessors.getAccessor;
	                        type = getTypeAnnotationFromAccessor(anotherAccessor);
	                        if (type) {
	                            accessorWithTypeAnnotation = anotherAccessor;
	                        }
	                    }
	                    writeTypeOfDeclaration(node, type, getAccessorDeclarationTypeVisibilityError);
	                }
	                write(";");
	                writeLine();
	            }
	            function getTypeAnnotationFromAccessor(accessor) {
	                if (accessor) {
	                    return accessor.kind === 146 /* GetAccessor */
	                        ? accessor.type // Getter - return type
	                        : accessor.parameters.length > 0
	                            ? accessor.parameters[0].type // Setter parameter type
	                            : undefined;
	                }
	            }
	            function getAccessorDeclarationTypeVisibilityError(symbolAccesibilityResult) {
	                var diagnosticMessage;
	                if (accessorWithTypeAnnotation.kind === 147 /* SetAccessor */) {
	                    // Setters have to have type named and cannot infer it so, the type should always be named
	                    if (accessorWithTypeAnnotation.parent.flags & 64 /* Static */) {
	                        diagnosticMessage = symbolAccesibilityResult.errorModuleName ?
	                            ts.Diagnostics.Parameter_0_of_public_static_property_setter_from_exported_class_has_or_is_using_name_1_from_private_module_2 :
	                            ts.Diagnostics.Parameter_0_of_public_static_property_setter_from_exported_class_has_or_is_using_private_name_1;
	                    }
	                    else {
	                        diagnosticMessage = symbolAccesibilityResult.errorModuleName ?
	                            ts.Diagnostics.Parameter_0_of_public_property_setter_from_exported_class_has_or_is_using_name_1_from_private_module_2 :
	                            ts.Diagnostics.Parameter_0_of_public_property_setter_from_exported_class_has_or_is_using_private_name_1;
	                    }
	                    return {
	                        diagnosticMessage: diagnosticMessage,
	                        errorNode: accessorWithTypeAnnotation.parameters[0],
	                        // TODO(jfreeman): Investigate why we are passing node.name instead of node.parameters[0].name
	                        typeName: accessorWithTypeAnnotation.name
	                    };
	                }
	                else {
	                    if (accessorWithTypeAnnotation.flags & 64 /* Static */) {
	                        diagnosticMessage = symbolAccesibilityResult.errorModuleName ?
	                            symbolAccesibilityResult.accessibility === 2 /* CannotBeNamed */ ?
	                                ts.Diagnostics.Return_type_of_public_static_property_getter_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named :
	                                ts.Diagnostics.Return_type_of_public_static_property_getter_from_exported_class_has_or_is_using_name_0_from_private_module_1 :
	                            ts.Diagnostics.Return_type_of_public_static_property_getter_from_exported_class_has_or_is_using_private_name_0;
	                    }
	                    else {
	                        diagnosticMessage = symbolAccesibilityResult.errorModuleName ?
	                            symbolAccesibilityResult.accessibility === 2 /* CannotBeNamed */ ?
	                                ts.Diagnostics.Return_type_of_public_property_getter_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named :
	                                ts.Diagnostics.Return_type_of_public_property_getter_from_exported_class_has_or_is_using_name_0_from_private_module_1 :
	                            ts.Diagnostics.Return_type_of_public_property_getter_from_exported_class_has_or_is_using_private_name_0;
	                    }
	                    return {
	                        diagnosticMessage: diagnosticMessage,
	                        errorNode: accessorWithTypeAnnotation.name,
	                        typeName: undefined
	                    };
	                }
	            }
	        }
	        function writeFunctionDeclaration(node) {
	            if (ts.hasDynamicName(node)) {
	                return;
	            }
	            // If we are emitting Method/Constructor it isn't moduleElement and hence already determined to be emitting
	            // so no need to verify if the declaration is visible
	            if (!resolver.isImplementationOfOverload(node)) {
	                emitJsDocComments(node);
	                if (node.kind === 216 /* FunctionDeclaration */) {
	                    emitModuleElementDeclarationFlags(node);
	                }
	                else if (node.kind === 144 /* MethodDeclaration */) {
	                    emitClassMemberDeclarationFlags(node);
	                }
	                if (node.kind === 216 /* FunctionDeclaration */) {
	                    write("function ");
	                    writeTextOfNode(currentText, node.name);
	                }
	                else if (node.kind === 145 /* Constructor */) {
	                    write("constructor");
	                }
	                else {
	                    writeTextOfNode(currentText, node.name);
	                    if (ts.hasQuestionToken(node)) {
	                        write("?");
	                    }
	                }
	                emitSignatureDeclaration(node);
	            }
	        }
	        function emitSignatureDeclarationWithJsDocComments(node) {
	            emitJsDocComments(node);
	            emitSignatureDeclaration(node);
	        }
	        function emitSignatureDeclaration(node) {
	            var prevEnclosingDeclaration = enclosingDeclaration;
	            enclosingDeclaration = node;
	            // Construct signature or constructor type write new Signature
	            if (node.kind === 149 /* ConstructSignature */ || node.kind === 154 /* ConstructorType */) {
	                write("new ");
	            }
	            emitTypeParameters(node.typeParameters);
	            if (node.kind === 150 /* IndexSignature */) {
	                write("[");
	            }
	            else {
	                write("(");
	            }
	            // Parameters
	            emitCommaList(node.parameters, emitParameterDeclaration);
	            if (node.kind === 150 /* IndexSignature */) {
	                write("]");
	            }
	            else {
	                write(")");
	            }
	            // If this is not a constructor and is not private, emit the return type
	            var isFunctionTypeOrConstructorType = node.kind === 153 /* FunctionType */ || node.kind === 154 /* ConstructorType */;
	            if (isFunctionTypeOrConstructorType || node.parent.kind === 156 /* TypeLiteral */) {
	                // Emit type literal signature return type only if specified
	                if (node.type) {
	                    write(isFunctionTypeOrConstructorType ? " => " : ": ");
	                    emitType(node.type);
	                }
	            }
	            else if (node.kind !== 145 /* Constructor */ && !(node.flags & 16 /* Private */)) {
	                writeReturnTypeAtSignature(node, getReturnTypeVisibilityError);
	            }
	            enclosingDeclaration = prevEnclosingDeclaration;
	            if (!isFunctionTypeOrConstructorType) {
	                write(";");
	                writeLine();
	            }
	            function getReturnTypeVisibilityError(symbolAccesibilityResult) {
	                var diagnosticMessage;
	                switch (node.kind) {
	                    case 149 /* ConstructSignature */:
	                        // Interfaces cannot have return types that cannot be named
	                        diagnosticMessage = symbolAccesibilityResult.errorModuleName ?
	                            ts.Diagnostics.Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1 :
	                            ts.Diagnostics.Return_type_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_0;
	                        break;
	                    case 148 /* CallSignature */:
	                        // Interfaces cannot have return types that cannot be named
	                        diagnosticMessage = symbolAccesibilityResult.errorModuleName ?
	                            ts.Diagnostics.Return_type_of_call_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1 :
	                            ts.Diagnostics.Return_type_of_call_signature_from_exported_interface_has_or_is_using_private_name_0;
	                        break;
	                    case 150 /* IndexSignature */:
	                        // Interfaces cannot have return types that cannot be named
	                        diagnosticMessage = symbolAccesibilityResult.errorModuleName ?
	                            ts.Diagnostics.Return_type_of_index_signature_from_exported_interface_has_or_is_using_name_0_from_private_module_1 :
	                            ts.Diagnostics.Return_type_of_index_signature_from_exported_interface_has_or_is_using_private_name_0;
	                        break;
	                    case 144 /* MethodDeclaration */:
	                    case 143 /* MethodSignature */:
	                        if (node.flags & 64 /* Static */) {
	                            diagnosticMessage = symbolAccesibilityResult.errorModuleName ?
	                                symbolAccesibilityResult.accessibility === 2 /* CannotBeNamed */ ?
	                                    ts.Diagnostics.Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named :
	                                    ts.Diagnostics.Return_type_of_public_static_method_from_exported_class_has_or_is_using_name_0_from_private_module_1 :
	                                ts.Diagnostics.Return_type_of_public_static_method_from_exported_class_has_or_is_using_private_name_0;
	                        }
	                        else if (node.parent.kind === 217 /* ClassDeclaration */) {
	                            diagnosticMessage = symbolAccesibilityResult.errorModuleName ?
	                                symbolAccesibilityResult.accessibility === 2 /* CannotBeNamed */ ?
	                                    ts.Diagnostics.Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named :
	                                    ts.Diagnostics.Return_type_of_public_method_from_exported_class_has_or_is_using_name_0_from_private_module_1 :
	                                ts.Diagnostics.Return_type_of_public_method_from_exported_class_has_or_is_using_private_name_0;
	                        }
	                        else {
	                            // Interfaces cannot have return types that cannot be named
	                            diagnosticMessage = symbolAccesibilityResult.errorModuleName ?
	                                ts.Diagnostics.Return_type_of_method_from_exported_interface_has_or_is_using_name_0_from_private_module_1 :
	                                ts.Diagnostics.Return_type_of_method_from_exported_interface_has_or_is_using_private_name_0;
	                        }
	                        break;
	                    case 216 /* FunctionDeclaration */:
	                        diagnosticMessage = symbolAccesibilityResult.errorModuleName ?
	                            symbolAccesibilityResult.accessibility === 2 /* CannotBeNamed */ ?
	                                ts.Diagnostics.Return_type_of_exported_function_has_or_is_using_name_0_from_external_module_1_but_cannot_be_named :
	                                ts.Diagnostics.Return_type_of_exported_function_has_or_is_using_name_0_from_private_module_1 :
	                            ts.Diagnostics.Return_type_of_exported_function_has_or_is_using_private_name_0;
	                        break;
	                    default:
	                        ts.Debug.fail("This is unknown kind for signature: " + node.kind);
	                }
	                return {
	                    diagnosticMessage: diagnosticMessage,
	                    errorNode: node.name || node
	                };
	            }
	        }
	        function emitParameterDeclaration(node) {
	            increaseIndent();
	            emitJsDocComments(node);
	            if (node.dotDotDotToken) {
	                write("...");
	            }
	            if (ts.isBindingPattern(node.name)) {
	                // For bindingPattern, we can't simply writeTextOfNode from the source file
	                // because we want to omit the initializer and using writeTextOfNode will result in initializer get emitted.
	                // Therefore, we will have to recursively emit each element in the bindingPattern.
	                emitBindingPattern(node.name);
	            }
	            else {
	                writeTextOfNode(currentText, node.name);
	            }
	            if (resolver.isOptionalParameter(node)) {
	                write("?");
	            }
	            decreaseIndent();
	            if (node.parent.kind === 153 /* FunctionType */ ||
	                node.parent.kind === 154 /* ConstructorType */ ||
	                node.parent.parent.kind === 156 /* TypeLiteral */) {
	                emitTypeOfVariableDeclarationFromTypeLiteral(node);
	            }
	            else if (!(node.parent.flags & 16 /* Private */)) {
	                writeTypeOfDeclaration(node, node.type, getParameterDeclarationTypeVisibilityError);
	            }
	            function getParameterDeclarationTypeVisibilityError(symbolAccesibilityResult) {
	                var diagnosticMessage = getParameterDeclarationTypeVisibilityDiagnosticMessage(symbolAccesibilityResult);
	                return diagnosticMessage !== undefined ? {
	                    diagnosticMessage: diagnosticMessage,
	                    errorNode: node,
	                    typeName: node.name
	                } : undefined;
	            }
	            function getParameterDeclarationTypeVisibilityDiagnosticMessage(symbolAccesibilityResult) {
	                switch (node.parent.kind) {
	                    case 145 /* Constructor */:
	                        return symbolAccesibilityResult.errorModuleName ?
	                            symbolAccesibilityResult.accessibility === 2 /* CannotBeNamed */ ?
	                                ts.Diagnostics.Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named :
	                                ts.Diagnostics.Parameter_0_of_constructor_from_exported_class_has_or_is_using_name_1_from_private_module_2 :
	                            ts.Diagnostics.Parameter_0_of_constructor_from_exported_class_has_or_is_using_private_name_1;
	                    case 149 /* ConstructSignature */:
	                        // Interfaces cannot have parameter types that cannot be named
	                        return symbolAccesibilityResult.errorModuleName ?
	                            ts.Diagnostics.Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2 :
	                            ts.Diagnostics.Parameter_0_of_constructor_signature_from_exported_interface_has_or_is_using_private_name_1;
	                    case 148 /* CallSignature */:
	                        // Interfaces cannot have parameter types that cannot be named
	                        return symbolAccesibilityResult.errorModuleName ?
	                            ts.Diagnostics.Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_name_1_from_private_module_2 :
	                            ts.Diagnostics.Parameter_0_of_call_signature_from_exported_interface_has_or_is_using_private_name_1;
	                    case 144 /* MethodDeclaration */:
	                    case 143 /* MethodSignature */:
	                        if (node.parent.flags & 64 /* Static */) {
	                            return symbolAccesibilityResult.errorModuleName ?
	                                symbolAccesibilityResult.accessibility === 2 /* CannotBeNamed */ ?
	                                    ts.Diagnostics.Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named :
	                                    ts.Diagnostics.Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_name_1_from_private_module_2 :
	                                ts.Diagnostics.Parameter_0_of_public_static_method_from_exported_class_has_or_is_using_private_name_1;
	                        }
	                        else if (node.parent.parent.kind === 217 /* ClassDeclaration */) {
	                            return symbolAccesibilityResult.errorModuleName ?
	                                symbolAccesibilityResult.accessibility === 2 /* CannotBeNamed */ ?
	                                    ts.Diagnostics.Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named :
	                                    ts.Diagnostics.Parameter_0_of_public_method_from_exported_class_has_or_is_using_name_1_from_private_module_2 :
	                                ts.Diagnostics.Parameter_0_of_public_method_from_exported_class_has_or_is_using_private_name_1;
	                        }
	                        else {
	                            // Interfaces cannot have parameter types that cannot be named
	                            return symbolAccesibilityResult.errorModuleName ?
	                                ts.Diagnostics.Parameter_0_of_method_from_exported_interface_has_or_is_using_name_1_from_private_module_2 :
	                                ts.Diagnostics.Parameter_0_of_method_from_exported_interface_has_or_is_using_private_name_1;
	                        }
	                    case 216 /* FunctionDeclaration */:
	                        return symbolAccesibilityResult.errorModuleName ?
	                            symbolAccesibilityResult.accessibility === 2 /* CannotBeNamed */ ?
	                                ts.Diagnostics.Parameter_0_of_exported_function_has_or_is_using_name_1_from_external_module_2_but_cannot_be_named :
	                                ts.Diagnostics.Parameter_0_of_exported_function_has_or_is_using_name_1_from_private_module_2 :
	                            ts.Diagnostics.Parameter_0_of_exported_function_has_or_is_using_private_name_1;
	                    default:
	                        ts.Debug.fail("This is unknown parent for parameter: " + node.parent.kind);
	                }
	            }
	            function emitBindingPattern(bindingPattern) {
	                // We have to explicitly emit square bracket and bracket because these tokens are not store inside the node.
	                if (bindingPattern.kind === 164 /* ObjectBindingPattern */) {
	                    write("{");
	                    emitCommaList(bindingPattern.elements, emitBindingElement);
	                    write("}");
	                }
	                else if (bindingPattern.kind === 165 /* ArrayBindingPattern */) {
	                    write("[");
	                    var elements = bindingPattern.elements;
	                    emitCommaList(elements, emitBindingElement);
	                    if (elements && elements.hasTrailingComma) {
	                        write(", ");
	                    }
	                    write("]");
	                }
	            }
	            function emitBindingElement(bindingElement) {
	                if (bindingElement.kind === 190 /* OmittedExpression */) {
	                    // If bindingElement is an omittedExpression (i.e. containing elision),
	                    // we will emit blank space (although this may differ from users' original code,
	                    // it allows emitSeparatedList to write separator appropriately)
	                    // Example:
	                    //      original: function foo([, x, ,]) {}
	                    //      emit    : function foo([ , x,  , ]) {}
	                    write(" ");
	                }
	                else if (bindingElement.kind === 166 /* BindingElement */) {
	                    if (bindingElement.propertyName) {
	                        // bindingElement has propertyName property in the following case:
	                        //      { y: [a,b,c] ...} -> bindingPattern will have a property called propertyName for "y"
	                        // We have to explicitly emit the propertyName before descending into its binding elements.
	                        // Example:
	                        //      original: function foo({y: [a,b,c]}) {}
	                        //      emit    : declare function foo({y: [a, b, c]}: { y: [any, any, any] }) void;
	                        writeTextOfNode(currentText, bindingElement.propertyName);
	                        write(": ");
	                    }
	                    if (bindingElement.name) {
	                        if (ts.isBindingPattern(bindingElement.name)) {
	                            // If it is a nested binding pattern, we will recursively descend into each element and emit each one separately.
	                            // In the case of rest element, we will omit rest element.
	                            // Example:
	                            //      original: function foo([a, [[b]], c] = [1,[["string"]], 3]) {}
	                            //      emit    : declare function foo([a, [[b]], c]: [number, [[string]], number]): void;
	                            //      original with rest: function foo([a, ...c]) {}
	                            //      emit              : declare function foo([a, ...c]): void;
	                            emitBindingPattern(bindingElement.name);
	                        }
	                        else {
	                            ts.Debug.assert(bindingElement.name.kind === 69 /* Identifier */);
	                            // If the node is just an identifier, we will simply emit the text associated with the node's name
	                            // Example:
	                            //      original: function foo({y = 10, x}) {}
	                            //      emit    : declare function foo({y, x}: {number, any}): void;
	                            if (bindingElement.dotDotDotToken) {
	                                write("...");
	                            }
	                            writeTextOfNode(currentText, bindingElement.name);
	                        }
	                    }
	                }
	            }
	        }
	        function emitNode(node) {
	            switch (node.kind) {
	                case 216 /* FunctionDeclaration */:
	                case 221 /* ModuleDeclaration */:
	                case 224 /* ImportEqualsDeclaration */:
	                case 218 /* InterfaceDeclaration */:
	                case 217 /* ClassDeclaration */:
	                case 219 /* TypeAliasDeclaration */:
	                case 220 /* EnumDeclaration */:
	                    return emitModuleElement(node, isModuleElementVisible(node));
	                case 196 /* VariableStatement */:
	                    return emitModuleElement(node, isVariableStatementVisible(node));
	                case 225 /* ImportDeclaration */:
	                    // Import declaration without import clause is visible, otherwise it is not visible
	                    return emitModuleElement(node, /*isModuleElementVisible*/ !node.importClause);
	                case 231 /* ExportDeclaration */:
	                    return emitExportDeclaration(node);
	                case 145 /* Constructor */:
	                case 144 /* MethodDeclaration */:
	                case 143 /* MethodSignature */:
	                    return writeFunctionDeclaration(node);
	                case 149 /* ConstructSignature */:
	                case 148 /* CallSignature */:
	                case 150 /* IndexSignature */:
	                    return emitSignatureDeclarationWithJsDocComments(node);
	                case 146 /* GetAccessor */:
	                case 147 /* SetAccessor */:
	                    return emitAccessorDeclaration(node);
	                case 142 /* PropertyDeclaration */:
	                case 141 /* PropertySignature */:
	                    return emitPropertyDeclaration(node);
	                case 250 /* EnumMember */:
	                    return emitEnumMemberDeclaration(node);
	                case 230 /* ExportAssignment */:
	                    return emitExportAssignment(node);
	                case 251 /* SourceFile */:
	                    return emitSourceFile(node);
	            }
	        }
	        /**
	         * Adds the reference to referenced file, returns true if global file reference was emitted
	         * @param referencedFile
	         * @param addBundledFileReference Determines if global file reference corresponding to bundled file should be emitted or not
	         */
	        function writeReferencePath(referencedFile, addBundledFileReference) {
	            var declFileName;
	            var addedBundledEmitReference = false;
	            if (ts.isDeclarationFile(referencedFile)) {
	                // Declaration file, use declaration file name
	                declFileName = referencedFile.fileName;
	            }
	            else {
	                // Get the declaration file path
	                ts.forEachExpectedEmitFile(host, getDeclFileName, referencedFile);
	            }
	            if (declFileName) {
	                declFileName = ts.getRelativePathToDirectoryOrUrl(ts.getDirectoryPath(ts.normalizeSlashes(declarationFilePath)), declFileName, host.getCurrentDirectory(), host.getCanonicalFileName, 
	                /*isAbsolutePathAnUrl*/ false);
	                referencePathsOutput += "/// <reference path=\"" + declFileName + "\" />" + newLine;
	            }
	            return addedBundledEmitReference;
	            function getDeclFileName(emitFileNames, sourceFiles, isBundledEmit) {
	                // Dont add reference path to this file if it is a bundled emit and caller asked not emit bundled file path
	                if (isBundledEmit && !addBundledFileReference) {
	                    return;
	                }
	                ts.Debug.assert(!!emitFileNames.declarationFilePath || ts.isSourceFileJavaScript(referencedFile), "Declaration file is not present only for javascript files");
	                declFileName = emitFileNames.declarationFilePath || emitFileNames.jsFilePath;
	                addedBundledEmitReference = isBundledEmit;
	            }
	        }
	    }
	    /* @internal */
	    function writeDeclarationFile(declarationFilePath, sourceFiles, isBundledEmit, host, resolver, emitterDiagnostics) {
	        var emitDeclarationResult = emitDeclarations(host, resolver, emitterDiagnostics, declarationFilePath, sourceFiles, isBundledEmit);
	        var emitSkipped = emitDeclarationResult.reportedDeclarationError || host.isEmitBlocked(declarationFilePath) || host.getCompilerOptions().noEmit;
	        if (!emitSkipped) {
	            var declarationOutput = emitDeclarationResult.referencePathsOutput
	                + getDeclarationOutput(emitDeclarationResult.synchronousDeclarationOutput, emitDeclarationResult.moduleElementDeclarationEmitInfo);
	            ts.writeFile(host, emitterDiagnostics, declarationFilePath, declarationOutput, host.getCompilerOptions().emitBOM);
	        }
	        return emitSkipped;
	        function getDeclarationOutput(synchronousDeclarationOutput, moduleElementDeclarationEmitInfo) {
	            var appliedSyncOutputPos = 0;
	            var declarationOutput = "";
	            // apply asynchronous additions to the synchronous output
	            ts.forEach(moduleElementDeclarationEmitInfo, function (aliasEmitInfo) {
	                if (aliasEmitInfo.asynchronousOutput) {
	                    declarationOutput += synchronousDeclarationOutput.substring(appliedSyncOutputPos, aliasEmitInfo.outputPos);
	                    declarationOutput += getDeclarationOutput(aliasEmitInfo.asynchronousOutput, aliasEmitInfo.subModuleElementDeclarationEmitInfo);
	                    appliedSyncOutputPos = aliasEmitInfo.outputPos;
	                }
	            });
	            declarationOutput += synchronousDeclarationOutput.substring(appliedSyncOutputPos);
	            return declarationOutput;
	        }
	    }
	    ts.writeDeclarationFile = writeDeclarationFile;
	})(ts || (ts = {}));
	/// <reference path="checker.ts"/>
	/// <reference path="sourcemap.ts" />
	/// <reference path="declarationEmitter.ts"/>
	/* @internal */
	var ts;
	(function (ts) {
	    function getResolvedExternalModuleName(host, file) {
	        return file.moduleName || ts.getExternalModuleNameFromPath(host, file.fileName);
	    }
	    ts.getResolvedExternalModuleName = getResolvedExternalModuleName;
	    function getExternalModuleNameFromDeclaration(host, resolver, declaration) {
	        var file = resolver.getExternalModuleFileFromDeclaration(declaration);
	        if (!file || ts.isDeclarationFile(file)) {
	            return undefined;
	        }
	        return getResolvedExternalModuleName(host, file);
	    }
	    ts.getExternalModuleNameFromDeclaration = getExternalModuleNameFromDeclaration;
	    var Jump;
	    (function (Jump) {
	        Jump[Jump["Break"] = 2] = "Break";
	        Jump[Jump["Continue"] = 4] = "Continue";
	        Jump[Jump["Return"] = 8] = "Return";
	    })(Jump || (Jump = {}));
	    var entities = {
	        "quot": 0x0022,
	        "amp": 0x0026,
	        "apos": 0x0027,
	        "lt": 0x003C,
	        "gt": 0x003E,
	        "nbsp": 0x00A0,
	        "iexcl": 0x00A1,
	        "cent": 0x00A2,
	        "pound": 0x00A3,
	        "curren": 0x00A4,
	        "yen": 0x00A5,
	        "brvbar": 0x00A6,
	        "sect": 0x00A7,
	        "uml": 0x00A8,
	        "copy": 0x00A9,
	        "ordf": 0x00AA,
	        "laquo": 0x00AB,
	        "not": 0x00AC,
	        "shy": 0x00AD,
	        "reg": 0x00AE,
	        "macr": 0x00AF,
	        "deg": 0x00B0,
	        "plusmn": 0x00B1,
	        "sup2": 0x00B2,
	        "sup3": 0x00B3,
	        "acute": 0x00B4,
	        "micro": 0x00B5,
	        "para": 0x00B6,
	        "middot": 0x00B7,
	        "cedil": 0x00B8,
	        "sup1": 0x00B9,
	        "ordm": 0x00BA,
	        "raquo": 0x00BB,
	        "frac14": 0x00BC,
	        "frac12": 0x00BD,
	        "frac34": 0x00BE,
	        "iquest": 0x00BF,
	        "Agrave": 0x00C0,
	        "Aacute": 0x00C1,
	        "Acirc": 0x00C2,
	        "Atilde": 0x00C3,
	        "Auml": 0x00C4,
	        "Aring": 0x00C5,
	        "AElig": 0x00C6,
	        "Ccedil": 0x00C7,
	        "Egrave": 0x00C8,
	        "Eacute": 0x00C9,
	        "Ecirc": 0x00CA,
	        "Euml": 0x00CB,
	        "Igrave": 0x00CC,
	        "Iacute": 0x00CD,
	        "Icirc": 0x00CE,
	        "Iuml": 0x00CF,
	        "ETH": 0x00D0,
	        "Ntilde": 0x00D1,
	        "Ograve": 0x00D2,
	        "Oacute": 0x00D3,
	        "Ocirc": 0x00D4,
	        "Otilde": 0x00D5,
	        "Ouml": 0x00D6,
	        "times": 0x00D7,
	        "Oslash": 0x00D8,
	        "Ugrave": 0x00D9,
	        "Uacute": 0x00DA,
	        "Ucirc": 0x00DB,
	        "Uuml": 0x00DC,
	        "Yacute": 0x00DD,
	        "THORN": 0x00DE,
	        "szlig": 0x00DF,
	        "agrave": 0x00E0,
	        "aacute": 0x00E1,
	        "acirc": 0x00E2,
	        "atilde": 0x00E3,
	        "auml": 0x00E4,
	        "aring": 0x00E5,
	        "aelig": 0x00E6,
	        "ccedil": 0x00E7,
	        "egrave": 0x00E8,
	        "eacute": 0x00E9,
	        "ecirc": 0x00EA,
	        "euml": 0x00EB,
	        "igrave": 0x00EC,
	        "iacute": 0x00ED,
	        "icirc": 0x00EE,
	        "iuml": 0x00EF,
	        "eth": 0x00F0,
	        "ntilde": 0x00F1,
	        "ograve": 0x00F2,
	        "oacute": 0x00F3,
	        "ocirc": 0x00F4,
	        "otilde": 0x00F5,
	        "ouml": 0x00F6,
	        "divide": 0x00F7,
	        "oslash": 0x00F8,
	        "ugrave": 0x00F9,
	        "uacute": 0x00FA,
	        "ucirc": 0x00FB,
	        "uuml": 0x00FC,
	        "yacute": 0x00FD,
	        "thorn": 0x00FE,
	        "yuml": 0x00FF,
	        "OElig": 0x0152,
	        "oelig": 0x0153,
	        "Scaron": 0x0160,
	        "scaron": 0x0161,
	        "Yuml": 0x0178,
	        "fnof": 0x0192,
	        "circ": 0x02C6,
	        "tilde": 0x02DC,
	        "Alpha": 0x0391,
	        "Beta": 0x0392,
	        "Gamma": 0x0393,
	        "Delta": 0x0394,
	        "Epsilon": 0x0395,
	        "Zeta": 0x0396,
	        "Eta": 0x0397,
	        "Theta": 0x0398,
	        "Iota": 0x0399,
	        "Kappa": 0x039A,
	        "Lambda": 0x039B,
	        "Mu": 0x039C,
	        "Nu": 0x039D,
	        "Xi": 0x039E,
	        "Omicron": 0x039F,
	        "Pi": 0x03A0,
	        "Rho": 0x03A1,
	        "Sigma": 0x03A3,
	        "Tau": 0x03A4,
	        "Upsilon": 0x03A5,
	        "Phi": 0x03A6,
	        "Chi": 0x03A7,
	        "Psi": 0x03A8,
	        "Omega": 0x03A9,
	        "alpha": 0x03B1,
	        "beta": 0x03B2,
	        "gamma": 0x03B3,
	        "delta": 0x03B4,
	        "epsilon": 0x03B5,
	        "zeta": 0x03B6,
	        "eta": 0x03B7,
	        "theta": 0x03B8,
	        "iota": 0x03B9,
	        "kappa": 0x03BA,
	        "lambda": 0x03BB,
	        "mu": 0x03BC,
	        "nu": 0x03BD,
	        "xi": 0x03BE,
	        "omicron": 0x03BF,
	        "pi": 0x03C0,
	        "rho": 0x03C1,
	        "sigmaf": 0x03C2,
	        "sigma": 0x03C3,
	        "tau": 0x03C4,
	        "upsilon": 0x03C5,
	        "phi": 0x03C6,
	        "chi": 0x03C7,
	        "psi": 0x03C8,
	        "omega": 0x03C9,
	        "thetasym": 0x03D1,
	        "upsih": 0x03D2,
	        "piv": 0x03D6,
	        "ensp": 0x2002,
	        "emsp": 0x2003,
	        "thinsp": 0x2009,
	        "zwnj": 0x200C,
	        "zwj": 0x200D,
	        "lrm": 0x200E,
	        "rlm": 0x200F,
	        "ndash": 0x2013,
	        "mdash": 0x2014,
	        "lsquo": 0x2018,
	        "rsquo": 0x2019,
	        "sbquo": 0x201A,
	        "ldquo": 0x201C,
	        "rdquo": 0x201D,
	        "bdquo": 0x201E,
	        "dagger": 0x2020,
	        "Dagger": 0x2021,
	        "bull": 0x2022,
	        "hellip": 0x2026,
	        "permil": 0x2030,
	        "prime": 0x2032,
	        "Prime": 0x2033,
	        "lsaquo": 0x2039,
	        "rsaquo": 0x203A,
	        "oline": 0x203E,
	        "frasl": 0x2044,
	        "euro": 0x20AC,
	        "image": 0x2111,
	        "weierp": 0x2118,
	        "real": 0x211C,
	        "trade": 0x2122,
	        "alefsym": 0x2135,
	        "larr": 0x2190,
	        "uarr": 0x2191,
	        "rarr": 0x2192,
	        "darr": 0x2193,
	        "harr": 0x2194,
	        "crarr": 0x21B5,
	        "lArr": 0x21D0,
	        "uArr": 0x21D1,
	        "rArr": 0x21D2,
	        "dArr": 0x21D3,
	        "hArr": 0x21D4,
	        "forall": 0x2200,
	        "part": 0x2202,
	        "exist": 0x2203,
	        "empty": 0x2205,
	        "nabla": 0x2207,
	        "isin": 0x2208,
	        "notin": 0x2209,
	        "ni": 0x220B,
	        "prod": 0x220F,
	        "sum": 0x2211,
	        "minus": 0x2212,
	        "lowast": 0x2217,
	        "radic": 0x221A,
	        "prop": 0x221D,
	        "infin": 0x221E,
	        "ang": 0x2220,
	        "and": 0x2227,
	        "or": 0x2228,
	        "cap": 0x2229,
	        "cup": 0x222A,
	        "int": 0x222B,
	        "there4": 0x2234,
	        "sim": 0x223C,
	        "cong": 0x2245,
	        "asymp": 0x2248,
	        "ne": 0x2260,
	        "equiv": 0x2261,
	        "le": 0x2264,
	        "ge": 0x2265,
	        "sub": 0x2282,
	        "sup": 0x2283,
	        "nsub": 0x2284,
	        "sube": 0x2286,
	        "supe": 0x2287,
	        "oplus": 0x2295,
	        "otimes": 0x2297,
	        "perp": 0x22A5,
	        "sdot": 0x22C5,
	        "lceil": 0x2308,
	        "rceil": 0x2309,
	        "lfloor": 0x230A,
	        "rfloor": 0x230B,
	        "lang": 0x2329,
	        "rang": 0x232A,
	        "loz": 0x25CA,
	        "spades": 0x2660,
	        "clubs": 0x2663,
	        "hearts": 0x2665,
	        "diams": 0x2666
	    };
	    // Flags enum to track count of temp variables and a few dedicated names
	    var TempFlags;
	    (function (TempFlags) {
	        TempFlags[TempFlags["Auto"] = 0] = "Auto";
	        TempFlags[TempFlags["CountMask"] = 268435455] = "CountMask";
	        TempFlags[TempFlags["_i"] = 268435456] = "_i";
	    })(TempFlags || (TempFlags = {}));
	    var CopyDirection;
	    (function (CopyDirection) {
	        CopyDirection[CopyDirection["ToOriginal"] = 0] = "ToOriginal";
	        CopyDirection[CopyDirection["ToOutParameter"] = 1] = "ToOutParameter";
	    })(CopyDirection || (CopyDirection = {}));
	    // targetSourceFile is when users only want one file in entire project to be emitted. This is used in compileOnSave feature
	    function emitFiles(resolver, host, targetSourceFile) {
	        // emit output for the __extends helper function
	        var extendsHelper = "\nvar __extends = (this && this.__extends) || function (d, b) {\n    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];\n    function __() { this.constructor = d; }\n    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());\n};";
	        // emit output for the __decorate helper function
	        var decorateHelper = "\nvar __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {\n    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;\n    if (typeof Reflect === \"object\" && typeof Reflect.decorate === \"function\") r = Reflect.decorate(decorators, target, key, desc);\n    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;\n    return c > 3 && r && Object.defineProperty(target, key, r), r;\n};";
	        // emit output for the __metadata helper function
	        var metadataHelper = "\nvar __metadata = (this && this.__metadata) || function (k, v) {\n    if (typeof Reflect === \"object\" && typeof Reflect.metadata === \"function\") return Reflect.metadata(k, v);\n};";
	        // emit output for the __param helper function
	        var paramHelper = "\nvar __param = (this && this.__param) || function (paramIndex, decorator) {\n    return function (target, key) { decorator(target, key, paramIndex); }\n};";
	        var awaiterHelper = "\nvar __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {\n    return new (P || (P = Promise))(function (resolve, reject) {\n        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }\n        function rejected(value) { try { step(generator.throw(value)); } catch (e) { reject(e); } }\n        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }\n        step((generator = generator.apply(thisArg, _arguments)).next());\n    });\n};";
	        var compilerOptions = host.getCompilerOptions();
	        var languageVersion = ts.getEmitScriptTarget(compilerOptions);
	        var modulekind = ts.getEmitModuleKind(compilerOptions);
	        var sourceMapDataList = compilerOptions.sourceMap || compilerOptions.inlineSourceMap ? [] : undefined;
	        var emitterDiagnostics = ts.createDiagnosticCollection();
	        var emitSkipped = false;
	        var newLine = host.getNewLine();
	        var emitJavaScript = createFileEmitter();
	        ts.forEachExpectedEmitFile(host, emitFile, targetSourceFile);
	        return {
	            emitSkipped: emitSkipped,
	            diagnostics: emitterDiagnostics.getDiagnostics(),
	            sourceMaps: sourceMapDataList
	        };
	        function isUniqueLocalName(name, container) {
	            for (var node = container; ts.isNodeDescendentOf(node, container); node = node.nextContainer) {
	                if (node.locals && ts.hasProperty(node.locals, name)) {
	                    // We conservatively include alias symbols to cover cases where they're emitted as locals
	                    if (node.locals[name].flags & (107455 /* Value */ | 1048576 /* ExportValue */ | 8388608 /* Alias */)) {
	                        return false;
	                    }
	                }
	            }
	            return true;
	        }
	        function setLabeledJump(state, isBreak, labelText, labelMarker) {
	            if (isBreak) {
	                if (!state.labeledNonLocalBreaks) {
	                    state.labeledNonLocalBreaks = {};
	                }
	                state.labeledNonLocalBreaks[labelText] = labelMarker;
	            }
	            else {
	                if (!state.labeledNonLocalContinues) {
	                    state.labeledNonLocalContinues = {};
	                }
	                state.labeledNonLocalContinues[labelText] = labelMarker;
	            }
	        }
	        function hoistVariableDeclarationFromLoop(state, declaration) {
	            if (!state.hoistedLocalVariables) {
	                state.hoistedLocalVariables = [];
	            }
	            visit(declaration.name);
	            function visit(node) {
	                if (node.kind === 69 /* Identifier */) {
	                    state.hoistedLocalVariables.push(node);
	                }
	                else {
	                    for (var _a = 0, _b = node.elements; _a < _b.length; _a++) {
	                        var element = _b[_a];
	                        visit(element.name);
	                    }
	                }
	            }
	        }
	        function createFileEmitter() {
	            var writer = ts.createTextWriter(newLine);
	            var write = writer.write, writeTextOfNode = writer.writeTextOfNode, writeLine = writer.writeLine, increaseIndent = writer.increaseIndent, decreaseIndent = writer.decreaseIndent;
	            var sourceMap = compilerOptions.sourceMap || compilerOptions.inlineSourceMap ? ts.createSourceMapWriter(host, writer) : ts.getNullSourceMapWriter();
	            var setSourceFile = sourceMap.setSourceFile, emitStart = sourceMap.emitStart, emitEnd = sourceMap.emitEnd, emitPos = sourceMap.emitPos;
	            var currentSourceFile;
	            var currentText;
	            var currentLineMap;
	            var currentFileIdentifiers;
	            var renamedDependencies;
	            var isEs6Module;
	            var isCurrentFileExternalModule;
	            // name of an exporter function if file is a System external module
	            // System.register([...], function (<exporter>) {...})
	            // exporting in System modules looks like:
	            // export var x; ... x = 1
	            // =>
	            // var x;... exporter("x", x = 1)
	            var exportFunctionForFile;
	            var contextObjectForFile;
	            var generatedNameSet;
	            var nodeToGeneratedName;
	            var computedPropertyNamesToGeneratedNames;
	            var decoratedClassAliases;
	            var convertedLoopState;
	            var extendsEmitted;
	            var decorateEmitted;
	            var paramEmitted;
	            var awaiterEmitted;
	            var tempFlags = 0;
	            var tempVariables;
	            var tempParameters;
	            var externalImports;
	            var exportSpecifiers;
	            var exportEquals;
	            var hasExportStarsToExportValues;
	            var detachedCommentsInfo;
	            /** Sourcemap data that will get encoded */
	            var sourceMapData;
	            /** Is the file being emitted into its own file */
	            var isOwnFileEmit;
	            /** If removeComments is true, no leading-comments needed to be emitted **/
	            var emitLeadingCommentsOfPosition = compilerOptions.removeComments ? function (pos) { } : emitLeadingCommentsOfPositionWorker;
	            var setSourceMapWriterEmit = compilerOptions.sourceMap || compilerOptions.inlineSourceMap ? changeSourceMapEmit : function (writer) { };
	            var moduleEmitDelegates = (_a = {},
	                _a[5 /* ES6 */] = emitES6Module,
	                _a[2 /* AMD */] = emitAMDModule,
	                _a[4 /* System */] = emitSystemModule,
	                _a[3 /* UMD */] = emitUMDModule,
	                _a[1 /* CommonJS */] = emitCommonJSModule,
	                _a
	            );
	            var bundleEmitDelegates = (_b = {},
	                _b[5 /* ES6 */] = function () { },
	                _b[2 /* AMD */] = emitAMDModule,
	                _b[4 /* System */] = emitSystemModule,
	                _b[3 /* UMD */] = function () { },
	                _b[1 /* CommonJS */] = function () { },
	                _b
	            );
	            return doEmit;
	            function doEmit(jsFilePath, sourceMapFilePath, sourceFiles, isBundledEmit) {
	                sourceMap.initialize(jsFilePath, sourceMapFilePath, sourceFiles, isBundledEmit);
	                generatedNameSet = {};
	                nodeToGeneratedName = [];
	                decoratedClassAliases = [];
	                isOwnFileEmit = !isBundledEmit;
	                // Emit helpers from all the files
	                if (isBundledEmit && modulekind) {
	                    ts.forEach(sourceFiles, emitEmitHelpers);
	                }
	                // Do not call emit directly. It does not set the currentSourceFile.
	                ts.forEach(sourceFiles, emitSourceFile);
	                writeLine();
	                var sourceMappingURL = sourceMap.getSourceMappingURL();
	                if (sourceMappingURL) {
	                    write("//# sourceMappingURL=" + sourceMappingURL);
	                }
	                writeEmittedFiles(writer.getText(), jsFilePath, sourceMapFilePath, /*writeByteOrderMark*/ compilerOptions.emitBOM);
	                // reset the state
	                sourceMap.reset();
	                writer.reset();
	                currentSourceFile = undefined;
	                currentText = undefined;
	                currentLineMap = undefined;
	                exportFunctionForFile = undefined;
	                contextObjectForFile = undefined;
	                generatedNameSet = undefined;
	                nodeToGeneratedName = undefined;
	                decoratedClassAliases = undefined;
	                computedPropertyNamesToGeneratedNames = undefined;
	                convertedLoopState = undefined;
	                extendsEmitted = false;
	                decorateEmitted = false;
	                paramEmitted = false;
	                awaiterEmitted = false;
	                tempFlags = 0;
	                tempVariables = undefined;
	                tempParameters = undefined;
	                externalImports = undefined;
	                exportSpecifiers = undefined;
	                exportEquals = undefined;
	                hasExportStarsToExportValues = undefined;
	                detachedCommentsInfo = undefined;
	                sourceMapData = undefined;
	                isEs6Module = false;
	                renamedDependencies = undefined;
	                isCurrentFileExternalModule = false;
	            }
	            function emitSourceFile(sourceFile) {
	                currentSourceFile = sourceFile;
	                currentText = sourceFile.text;
	                currentLineMap = ts.getLineStarts(sourceFile);
	                exportFunctionForFile = undefined;
	                contextObjectForFile = undefined;
	                isEs6Module = sourceFile.symbol && sourceFile.symbol.exports && !!sourceFile.symbol.exports["___esModule"];
	                renamedDependencies = sourceFile.renamedDependencies;
	                currentFileIdentifiers = sourceFile.identifiers;
	                isCurrentFileExternalModule = ts.isExternalModule(sourceFile);
	                setSourceFile(sourceFile);
	                emitNodeWithCommentsAndWithoutSourcemap(sourceFile);
	            }
	            function isUniqueName(name) {
	                return !resolver.hasGlobalName(name) &&
	                    !ts.hasProperty(currentFileIdentifiers, name) &&
	                    !ts.hasProperty(generatedNameSet, name);
	            }
	            // Return the next available name in the pattern _a ... _z, _0, _1, ...
	            // TempFlags._i or TempFlags._n may be used to express a preference for that dedicated name.
	            // Note that names generated by makeTempVariableName and makeUniqueName will never conflict.
	            function makeTempVariableName(flags) {
	                if (flags && !(tempFlags & flags)) {
	                    var name_22 = flags === 268435456 /* _i */ ? "_i" : "_n";
	                    if (isUniqueName(name_22)) {
	                        tempFlags |= flags;
	                        return name_22;
	                    }
	                }
	                while (true) {
	                    var count = tempFlags & 268435455 /* CountMask */;
	                    tempFlags++;
	                    // Skip over 'i' and 'n'
	                    if (count !== 8 && count !== 13) {
	                        var name_23 = count < 26 ? "_" + String.fromCharCode(97 /* a */ + count) : "_" + (count - 26);
	                        if (isUniqueName(name_23)) {
	                            return name_23;
	                        }
	                    }
	                }
	            }
	            // Generate a name that is unique within the current file and doesn't conflict with any names
	            // in global scope. The name is formed by adding an '_n' suffix to the specified base name,
	            // where n is a positive integer. Note that names generated by makeTempVariableName and
	            // makeUniqueName are guaranteed to never conflict.
	            function makeUniqueName(baseName) {
	                // Find the first unique 'name_n', where n is a positive number
	                if (baseName.charCodeAt(baseName.length - 1) !== 95 /* _ */) {
	                    baseName += "_";
	                }
	                var i = 1;
	                while (true) {
	                    var generatedName = baseName + i;
	                    if (isUniqueName(generatedName)) {
	                        return generatedNameSet[generatedName] = generatedName;
	                    }
	                    i++;
	                }
	            }
	            function generateNameForModuleOrEnum(node) {
	                var name = node.name.text;
	                // Use module/enum name itself if it is unique, otherwise make a unique variation
	                return isUniqueLocalName(name, node) ? name : makeUniqueName(name);
	            }
	            function generateNameForImportOrExportDeclaration(node) {
	                var expr = ts.getExternalModuleName(node);
	                var baseName = expr.kind === 9 /* StringLiteral */ ?
	                    ts.escapeIdentifier(ts.makeIdentifierFromModuleName(expr.text)) : "module";
	                return makeUniqueName(baseName);
	            }
	            function generateNameForExportDefault() {
	                return makeUniqueName("default");
	            }
	            function generateNameForClassExpression() {
	                return makeUniqueName("class");
	            }
	            function generateNameForNode(node) {
	                switch (node.kind) {
	                    case 69 /* Identifier */:
	                        return makeUniqueName(node.text);
	                    case 221 /* ModuleDeclaration */:
	                    case 220 /* EnumDeclaration */:
	                        return generateNameForModuleOrEnum(node);
	                    case 225 /* ImportDeclaration */:
	                    case 231 /* ExportDeclaration */:
	                        return generateNameForImportOrExportDeclaration(node);
	                    case 216 /* FunctionDeclaration */:
	                    case 217 /* ClassDeclaration */:
	                    case 230 /* ExportAssignment */:
	                        return generateNameForExportDefault();
	                    case 189 /* ClassExpression */:
	                        return generateNameForClassExpression();
	                }
	            }
	            function getGeneratedNameForNode(node) {
	                var id = ts.getNodeId(node);
	                return nodeToGeneratedName[id] || (nodeToGeneratedName[id] = ts.unescapeIdentifier(generateNameForNode(node)));
	            }
	            /** Write emitted output to disk */
	            function writeEmittedFiles(emitOutput, jsFilePath, sourceMapFilePath, writeByteOrderMark) {
	                if (compilerOptions.sourceMap && !compilerOptions.inlineSourceMap) {
	                    ts.writeFile(host, emitterDiagnostics, sourceMapFilePath, sourceMap.getText(), /*writeByteOrderMark*/ false);
	                }
	                if (sourceMapDataList) {
	                    sourceMapDataList.push(sourceMap.getSourceMapData());
	                }
	                ts.writeFile(host, emitterDiagnostics, jsFilePath, emitOutput, writeByteOrderMark);
	            }
	            // Create a temporary variable with a unique unused name.
	            function createTempVariable(flags) {
	                var result = ts.createSynthesizedNode(69 /* Identifier */);
	                result.text = makeTempVariableName(flags);
	                return result;
	            }
	            function recordTempDeclaration(name) {
	                if (!tempVariables) {
	                    tempVariables = [];
	                }
	                tempVariables.push(name);
	            }
	            function createAndRecordTempVariable(flags) {
	                var temp = createTempVariable(flags);
	                recordTempDeclaration(temp);
	                return temp;
	            }
	            function emitTempDeclarations(newLine) {
	                if (tempVariables) {
	                    if (newLine) {
	                        writeLine();
	                    }
	                    else {
	                        write(" ");
	                    }
	                    write("var ");
	                    emitCommaList(tempVariables);
	                    write(";");
	                }
	            }
	            /** Emit the text for the given token that comes after startPos
	              * This by default writes the text provided with the given tokenKind
	              * but if optional emitFn callback is provided the text is emitted using the callback instead of default text
	              * @param tokenKind the kind of the token to search and emit
	              * @param startPos the position in the source to start searching for the token
	              * @param emitFn if given will be invoked to emit the text instead of actual token emit */
	            function emitToken(tokenKind, startPos, emitFn) {
	                var tokenStartPos = ts.skipTrivia(currentText, startPos);
	                emitPos(tokenStartPos);
	                var tokenString = ts.tokenToString(tokenKind);
	                if (emitFn) {
	                    emitFn();
	                }
	                else {
	                    write(tokenString);
	                }
	                var tokenEndPos = tokenStartPos + tokenString.length;
	                emitPos(tokenEndPos);
	                return tokenEndPos;
	            }
	            function emitOptional(prefix, node) {
	                if (node) {
	                    write(prefix);
	                    emit(node);
	                }
	            }
	            function emitParenthesizedIf(node, parenthesized) {
	                if (parenthesized) {
	                    write("(");
	                }
	                emit(node);
	                if (parenthesized) {
	                    write(")");
	                }
	            }
	            function emitLinePreservingList(parent, nodes, allowTrailingComma, spacesBetweenBraces) {
	                ts.Debug.assert(nodes.length > 0);
	                increaseIndent();
	                if (nodeStartPositionsAreOnSameLine(parent, nodes[0])) {
	                    if (spacesBetweenBraces) {
	                        write(" ");
	                    }
	                }
	                else {
	                    writeLine();
	                }
	                for (var i = 0, n = nodes.length; i < n; i++) {
	                    if (i) {
	                        if (nodeEndIsOnSameLineAsNodeStart(nodes[i - 1], nodes[i])) {
	                            write(", ");
	                        }
	                        else {
	                            write(",");
	                            writeLine();
	                        }
	                    }
	                    emit(nodes[i]);
	                }
	                if (nodes.hasTrailingComma && allowTrailingComma) {
	                    write(",");
	                }
	                decreaseIndent();
	                if (nodeEndPositionsAreOnSameLine(parent, ts.lastOrUndefined(nodes))) {
	                    if (spacesBetweenBraces) {
	                        write(" ");
	                    }
	                }
	                else {
	                    writeLine();
	                }
	            }
	            function emitList(nodes, start, count, multiLine, trailingComma, leadingComma, noTrailingNewLine, emitNode) {
	                if (!emitNode) {
	                    emitNode = emit;
	                }
	                for (var i = 0; i < count; i++) {
	                    if (multiLine) {
	                        if (i || leadingComma) {
	                            write(",");
	                        }
	                        writeLine();
	                    }
	                    else {
	                        if (i || leadingComma) {
	                            write(", ");
	                        }
	                    }
	                    var node = nodes[start + i];
	                    // This emitting is to make sure we emit following comment properly
	                    //   ...(x, /*comment1*/ y)...
	                    //         ^ => node.pos
	                    // "comment1" is not considered leading comment for "y" but rather
	                    // considered as trailing comment of the previous node.
	                    emitTrailingCommentsOfPosition(node.pos);
	                    emitNode(node);
	                    leadingComma = true;
	                }
	                if (trailingComma) {
	                    write(",");
	                }
	                if (multiLine && !noTrailingNewLine) {
	                    writeLine();
	                }
	                return count;
	            }
	            function emitCommaList(nodes) {
	                if (nodes) {
	                    emitList(nodes, 0, nodes.length, /*multiLine*/ false, /*trailingComma*/ false);
	                }
	            }
	            function emitLines(nodes) {
	                emitLinesStartingAt(nodes, /*startIndex*/ 0);
	            }
	            function emitLinesStartingAt(nodes, startIndex) {
	                for (var i = startIndex; i < nodes.length; i++) {
	                    writeLine();
	                    emit(nodes[i]);
	                }
	            }
	            function isBinaryOrOctalIntegerLiteral(node, text) {
	                if (node.kind === 8 /* NumericLiteral */ && text.length > 1) {
	                    switch (text.charCodeAt(1)) {
	                        case 98 /* b */:
	                        case 66 /* B */:
	                        case 111 /* o */:
	                        case 79 /* O */:
	                            return true;
	                    }
	                }
	                return false;
	            }
	            function emitLiteral(node) {
	                var text = getLiteralText(node);
	                if ((compilerOptions.sourceMap || compilerOptions.inlineSourceMap) && (node.kind === 9 /* StringLiteral */ || ts.isTemplateLiteralKind(node.kind))) {
	                    writer.writeLiteral(text);
	                }
	                else if (languageVersion < 2 /* ES6 */ && isBinaryOrOctalIntegerLiteral(node, text)) {
	                    write(node.text);
	                }
	                else {
	                    write(text);
	                }
	            }
	            function getLiteralText(node) {
	                // Any template literal or string literal with an extended escape
	                // (e.g. "\u{0067}") will need to be downleveled as a escaped string literal.
	                if (languageVersion < 2 /* ES6 */ && (ts.isTemplateLiteralKind(node.kind) || node.hasExtendedUnicodeEscape)) {
	                    return getQuotedEscapedLiteralText("\"", node.text, "\"");
	                }
	                // If we don't need to downlevel and we can reach the original source text using
	                // the node's parent reference, then simply get the text as it was originally written.
	                if (node.parent) {
	                    return ts.getTextOfNodeFromSourceText(currentText, node);
	                }
	                // If we can't reach the original source text, use the canonical form if it's a number,
	                // or an escaped quoted form of the original text if it's string-like.
	                switch (node.kind) {
	                    case 9 /* StringLiteral */:
	                        return getQuotedEscapedLiteralText("\"", node.text, "\"");
	                    case 11 /* NoSubstitutionTemplateLiteral */:
	                        return getQuotedEscapedLiteralText("`", node.text, "`");
	                    case 12 /* TemplateHead */:
	                        return getQuotedEscapedLiteralText("`", node.text, "${");
	                    case 13 /* TemplateMiddle */:
	                        return getQuotedEscapedLiteralText("}", node.text, "${");
	                    case 14 /* TemplateTail */:
	                        return getQuotedEscapedLiteralText("}", node.text, "`");
	                    case 8 /* NumericLiteral */:
	                        return node.text;
	                }
	                ts.Debug.fail("Literal kind '" + node.kind + "' not accounted for.");
	            }
	            function getQuotedEscapedLiteralText(leftQuote, text, rightQuote) {
	                return leftQuote + ts.escapeNonAsciiCharacters(ts.escapeString(text)) + rightQuote;
	            }
	            function emitDownlevelRawTemplateLiteral(node) {
	                // Find original source text, since we need to emit the raw strings of the tagged template.
	                // The raw strings contain the (escaped) strings of what the user wrote.
	                // Examples: `\n` is converted to "\\n", a template string with a newline to "\n".
	                var text = ts.getTextOfNodeFromSourceText(currentText, node);
	                // text contains the original source, it will also contain quotes ("`"), dolar signs and braces ("${" and "}"),
	                // thus we need to remove those characters.
	                // First template piece starts with "`", others with "}"
	                // Last template piece ends with "`", others with "${"
	                var isLast = node.kind === 11 /* NoSubstitutionTemplateLiteral */ || node.kind === 14 /* TemplateTail */;
	                text = text.substring(1, text.length - (isLast ? 1 : 2));
	                // Newline normalization:
	                // ES6 Spec 11.8.6.1 - Static Semantics of TV's and TRV's
	                // <CR><LF> and <CR> LineTerminatorSequences are normalized to <LF> for both TV and TRV.
	                text = text.replace(/\r\n?/g, "\n");
	                text = ts.escapeString(text);
	                write("\"" + text + "\"");
	            }
	            function emitDownlevelTaggedTemplateArray(node, literalEmitter) {
	                write("[");
	                if (node.template.kind === 11 /* NoSubstitutionTemplateLiteral */) {
	                    literalEmitter(node.template);
	                }
	                else {
	                    literalEmitter(node.template.head);
	                    ts.forEach(node.template.templateSpans, function (child) {
	                        write(", ");
	                        literalEmitter(child.literal);
	                    });
	                }
	                write("]");
	            }
	            function emitDownlevelTaggedTemplate(node) {
	                var tempVariable = createAndRecordTempVariable(0 /* Auto */);
	                write("(");
	                emit(tempVariable);
	                write(" = ");
	                emitDownlevelTaggedTemplateArray(node, emit);
	                write(", ");
	                emit(tempVariable);
	                write(".raw = ");
	                emitDownlevelTaggedTemplateArray(node, emitDownlevelRawTemplateLiteral);
	                write(", ");
	                emitParenthesizedIf(node.tag, needsParenthesisForPropertyAccessOrInvocation(node.tag));
	                write("(");
	                emit(tempVariable);
	                // Now we emit the expressions
	                if (node.template.kind === 186 /* TemplateExpression */) {
	                    ts.forEach(node.template.templateSpans, function (templateSpan) {
	                        write(", ");
	                        var needsParens = templateSpan.expression.kind === 184 /* BinaryExpression */
	                            && templateSpan.expression.operatorToken.kind === 24 /* CommaToken */;
	                        emitParenthesizedIf(templateSpan.expression, needsParens);
	                    });
	                }
	                write("))");
	            }
	            function emitTemplateExpression(node) {
	                // In ES6 mode and above, we can simply emit each portion of a template in order, but in
	                // ES3 & ES5 we must convert the template expression into a series of string concatenations.
	                if (languageVersion >= 2 /* ES6 */) {
	                    ts.forEachChild(node, emit);
	                    return;
	                }
	                var emitOuterParens = ts.isExpression(node.parent)
	                    && templateNeedsParens(node, node.parent);
	                if (emitOuterParens) {
	                    write("(");
	                }
	                var headEmitted = false;
	                if (shouldEmitTemplateHead()) {
	                    emitLiteral(node.head);
	                    headEmitted = true;
	                }
	                for (var i = 0, n = node.templateSpans.length; i < n; i++) {
	                    var templateSpan = node.templateSpans[i];
	                    // Check if the expression has operands and binds its operands less closely than binary '+'.
	                    // If it does, we need to wrap the expression in parentheses. Otherwise, something like
	                    //    `abc${ 1 << 2 }`
	                    // becomes
	                    //    "abc" + 1 << 2 + ""
	                    // which is really
	                    //    ("abc" + 1) << (2 + "")
	                    // rather than
	                    //    "abc" + (1 << 2) + ""
	                    var needsParens = templateSpan.expression.kind !== 175 /* ParenthesizedExpression */
	                        && comparePrecedenceToBinaryPlus(templateSpan.expression) !== 1 /* GreaterThan */;
	                    if (i > 0 || headEmitted) {
	                        // If this is the first span and the head was not emitted, then this templateSpan's
	                        // expression will be the first to be emitted. Don't emit the preceding ' + ' in that
	                        // case.
	                        write(" + ");
	                    }
	                    emitParenthesizedIf(templateSpan.expression, needsParens);
	                    // Only emit if the literal is non-empty.
	                    // The binary '+' operator is left-associative, so the first string concatenation
	                    // with the head will force the result up to this point to be a string.
	                    // Emitting a '+ ""' has no semantic effect for middles and tails.
	                    if (templateSpan.literal.text.length !== 0) {
	                        write(" + ");
	                        emitLiteral(templateSpan.literal);
	                    }
	                }
	                if (emitOuterParens) {
	                    write(")");
	                }
	                function shouldEmitTemplateHead() {
	                    // If this expression has an empty head literal and the first template span has a non-empty
	                    // literal, then emitting the empty head literal is not necessary.
	                    //     `${ foo } and ${ bar }`
	                    // can be emitted as
	                    //     foo + " and " + bar
	                    // This is because it is only required that one of the first two operands in the emit
	                    // output must be a string literal, so that the other operand and all following operands
	                    // are forced into strings.
	                    //
	                    // If the first template span has an empty literal, then the head must still be emitted.
	                    //     `${ foo }${ bar }`
	                    // must still be emitted as
	                    //     "" + foo + bar
	                    // There is always atleast one templateSpan in this code path, since
	                    // NoSubstitutionTemplateLiterals are directly emitted via emitLiteral()
	                    ts.Debug.assert(node.templateSpans.length !== 0);
	                    return node.head.text.length !== 0 || node.templateSpans[0].literal.text.length === 0;
	                }
	                function templateNeedsParens(template, parent) {
	                    switch (parent.kind) {
	                        case 171 /* CallExpression */:
	                        case 172 /* NewExpression */:
	                            return parent.expression === template;
	                        case 173 /* TaggedTemplateExpression */:
	                        case 175 /* ParenthesizedExpression */:
	                            return false;
	                        default:
	                            return comparePrecedenceToBinaryPlus(parent) !== -1 /* LessThan */;
	                    }
	                }
	                /**
	                 * Returns whether the expression has lesser, greater,
	                 * or equal precedence to the binary '+' operator
	                 */
	                function comparePrecedenceToBinaryPlus(expression) {
	                    // All binary expressions have lower precedence than '+' apart from '*', '/', and '%'
	                    // which have greater precedence and '-' which has equal precedence.
	                    // All unary operators have a higher precedence apart from yield.
	                    // Arrow functions and conditionals have a lower precedence,
	                    // although we convert the former into regular function expressions in ES5 mode,
	                    // and in ES6 mode this function won't get called anyway.
	                    //
	                    // TODO (drosen): Note that we need to account for the upcoming 'yield' and
	                    //                spread ('...') unary operators that are anticipated for ES6.
	                    switch (expression.kind) {
	                        case 184 /* BinaryExpression */:
	                            switch (expression.operatorToken.kind) {
	                                case 37 /* AsteriskToken */:
	                                case 39 /* SlashToken */:
	                                case 40 /* PercentToken */:
	                                    return 1 /* GreaterThan */;
	                                case 35 /* PlusToken */:
	                                case 36 /* MinusToken */:
	                                    return 0 /* EqualTo */;
	                                default:
	                                    return -1 /* LessThan */;
	                            }
	                        case 187 /* YieldExpression */:
	                        case 185 /* ConditionalExpression */:
	                            return -1 /* LessThan */;
	                        default:
	                            return 1 /* GreaterThan */;
	                    }
	                }
	            }
	            function emitTemplateSpan(span) {
	                emit(span.expression);
	                emit(span.literal);
	            }
	            function jsxEmitReact(node) {
	                /// Emit a tag name, which is either '"div"' for lower-cased names, or
	                /// 'Div' for upper-cased or dotted names
	                function emitTagName(name) {
	                    if (name.kind === 69 /* Identifier */ && ts.isIntrinsicJsxName(name.text)) {
	                        write("\"");
	                        emit(name);
	                        write("\"");
	                    }
	                    else {
	                        emit(name);
	                    }
	                }
	                /// Emit an attribute name, which is quoted if it needs to be quoted. Because
	                /// these emit into an object literal property name, we don't need to be worried
	                /// about keywords, just non-identifier characters
	                function emitAttributeName(name) {
	                    if (/^[A-Za-z_]\w*$/.test(name.text)) {
	                        emit(name);
	                    }
	                    else {
	                        write("\"");
	                        emit(name);
	                        write("\"");
	                    }
	                }
	                /// Emit an name/value pair for an attribute (e.g. "x: 3")
	                function emitJsxAttribute(node) {
	                    emitAttributeName(node.name);
	                    write(": ");
	                    if (node.initializer) {
	                        emit(node.initializer);
	                    }
	                    else {
	                        write("true");
	                    }
	                }
	                function emitJsxElement(openingNode, children) {
	                    var syntheticReactRef = ts.createSynthesizedNode(69 /* Identifier */);
	                    syntheticReactRef.text = compilerOptions.reactNamespace ? compilerOptions.reactNamespace : "React";
	                    syntheticReactRef.parent = openingNode;
	                    // Call React.createElement(tag, ...
	                    emitLeadingComments(openingNode);
	                    emitExpressionIdentifier(syntheticReactRef);
	                    write(".createElement(");
	                    emitTagName(openingNode.tagName);
	                    write(", ");
	                    // Attribute list
	                    if (openingNode.attributes.length === 0) {
	                        // When there are no attributes, React wants "null"
	                        write("null");
	                    }
	                    else {
	                        // Either emit one big object literal (no spread attribs), or
	                        // a call to React.__spread
	                        var attrs = openingNode.attributes;
	                        if (ts.forEach(attrs, function (attr) { return attr.kind === 242 /* JsxSpreadAttribute */; })) {
	                            emitExpressionIdentifier(syntheticReactRef);
	                            write(".__spread(");
	                            var haveOpenedObjectLiteral = false;
	                            for (var i = 0; i < attrs.length; i++) {
	                                if (attrs[i].kind === 242 /* JsxSpreadAttribute */) {
	                                    // If this is the first argument, we need to emit a {} as the first argument
	                                    if (i === 0) {
	                                        write("{}, ");
	                                    }
	                                    if (haveOpenedObjectLiteral) {
	                                        write("}");
	                                        haveOpenedObjectLiteral = false;
	                                    }
	                                    if (i > 0) {
	                                        write(", ");
	                                    }
	                                    emit(attrs[i].expression);
	                                }
	                                else {
	                                    ts.Debug.assert(attrs[i].kind === 241 /* JsxAttribute */);
	                                    if (haveOpenedObjectLiteral) {
	                                        write(", ");
	                                    }
	                                    else {
	                                        haveOpenedObjectLiteral = true;
	                                        if (i > 0) {
	                                            write(", ");
	                                        }
	                                        write("{");
	                                    }
	                                    emitJsxAttribute(attrs[i]);
	                                }
	                            }
	                            if (haveOpenedObjectLiteral)
	                                write("}");
	                            write(")"); // closing paren to React.__spread(
	                        }
	                        else {
	                            // One object literal with all the attributes in them
	                            write("{");
	                            for (var i = 0, n = attrs.length; i < n; i++) {
	                                if (i > 0) {
	                                    write(", ");
	                                }
	                                emitJsxAttribute(attrs[i]);
	                            }
	                            write("}");
	                        }
	                    }
	                    // Children
	                    if (children) {
	                        for (var i = 0; i < children.length; i++) {
	                            // Don't emit empty expressions
	                            if (children[i].kind === 243 /* JsxExpression */ && !(children[i].expression)) {
	                                continue;
	                            }
	                            // Don't emit empty strings
	                            if (children[i].kind === 239 /* JsxText */) {
	                                var text = getTextToEmit(children[i]);
	                                if (text !== undefined) {
	                                    write(", \"");
	                                    write(text);
	                                    write("\"");
	                                }
	                            }
	                            else {
	                                write(", ");
	                                emit(children[i]);
	                            }
	                        }
	                    }
	                    // Closing paren
	                    write(")"); // closes "React.createElement("
	                    emitTrailingComments(openingNode);
	                }
	                if (node.kind === 236 /* JsxElement */) {
	                    emitJsxElement(node.openingElement, node.children);
	                }
	                else {
	                    ts.Debug.assert(node.kind === 237 /* JsxSelfClosingElement */);
	                    emitJsxElement(node);
	                }
	            }
	            function jsxEmitPreserve(node) {
	                function emitJsxAttribute(node) {
	                    emit(node.name);
	                    if (node.initializer) {
	                        write("=");
	                        emit(node.initializer);
	                    }
	                }
	                function emitJsxSpreadAttribute(node) {
	                    write("{...");
	                    emit(node.expression);
	                    write("}");
	                }
	                function emitAttributes(attribs) {
	                    for (var i = 0, n = attribs.length; i < n; i++) {
	                        if (i > 0) {
	                            write(" ");
	                        }
	                        if (attribs[i].kind === 242 /* JsxSpreadAttribute */) {
	                            emitJsxSpreadAttribute(attribs[i]);
	                        }
	                        else {
	                            ts.Debug.assert(attribs[i].kind === 241 /* JsxAttribute */);
	                            emitJsxAttribute(attribs[i]);
	                        }
	                    }
	                }
	                function emitJsxOpeningOrSelfClosingElement(node) {
	                    write("<");
	                    emit(node.tagName);
	                    if (node.attributes.length > 0 || (node.kind === 237 /* JsxSelfClosingElement */)) {
	                        write(" ");
	                    }
	                    emitAttributes(node.attributes);
	                    if (node.kind === 237 /* JsxSelfClosingElement */) {
	                        write("/>");
	                    }
	                    else {
	                        write(">");
	                    }
	                }
	                function emitJsxClosingElement(node) {
	                    write("</");
	                    emit(node.tagName);
	                    write(">");
	                }
	                function emitJsxElement(node) {
	                    emitJsxOpeningOrSelfClosingElement(node.openingElement);
	                    for (var i = 0, n = node.children.length; i < n; i++) {
	                        emit(node.children[i]);
	                    }
	                    emitJsxClosingElement(node.closingElement);
	                }
	                if (node.kind === 236 /* JsxElement */) {
	                    emitJsxElement(node);
	                }
	                else {
	                    ts.Debug.assert(node.kind === 237 /* JsxSelfClosingElement */);
	                    emitJsxOpeningOrSelfClosingElement(node);
	                }
	            }
	            // This function specifically handles numeric/string literals for enum and accessor 'identifiers'.
	            // In a sense, it does not actually emit identifiers as much as it declares a name for a specific property.
	            // For example, this is utilized when feeding in a result to Object.defineProperty.
	            function emitExpressionForPropertyName(node) {
	                ts.Debug.assert(node.kind !== 166 /* BindingElement */);
	                if (node.kind === 9 /* StringLiteral */) {
	                    emitLiteral(node);
	                }
	                else if (node.kind === 137 /* ComputedPropertyName */) {
	                    // if this is a decorated computed property, we will need to capture the result
	                    // of the property expression so that we can apply decorators later. This is to ensure
	                    // we don't introduce unintended side effects:
	                    //
	                    //   class C {
	                    //     [_a = x]() { }
	                    //   }
	                    //
	                    // The emit for the decorated computed property decorator is:
	                    //
	                    //   __decorate([dec], C.prototype, _a, Object.getOwnPropertyDescriptor(C.prototype, _a));
	                    //
	                    if (ts.nodeIsDecorated(node.parent)) {
	                        if (!computedPropertyNamesToGeneratedNames) {
	                            computedPropertyNamesToGeneratedNames = [];
	                        }
	                        var generatedName = computedPropertyNamesToGeneratedNames[ts.getNodeId(node)];
	                        if (generatedName) {
	                            // we have already generated a variable for this node, write that value instead.
	                            write(generatedName);
	                            return;
	                        }
	                        generatedName = createAndRecordTempVariable(0 /* Auto */).text;
	                        computedPropertyNamesToGeneratedNames[ts.getNodeId(node)] = generatedName;
	                        write(generatedName);
	                        write(" = ");
	                    }
	                    emit(node.expression);
	                }
	                else {
	                    write("\"");
	                    if (node.kind === 8 /* NumericLiteral */) {
	                        write(node.text);
	                    }
	                    else {
	                        writeTextOfNode(currentText, node);
	                    }
	                    write("\"");
	                }
	            }
	            function isExpressionIdentifier(node) {
	                var parent = node.parent;
	                switch (parent.kind) {
	                    case 167 /* ArrayLiteralExpression */:
	                    case 192 /* AsExpression */:
	                    case 184 /* BinaryExpression */:
	                    case 171 /* CallExpression */:
	                    case 244 /* CaseClause */:
	                    case 137 /* ComputedPropertyName */:
	                    case 185 /* ConditionalExpression */:
	                    case 140 /* Decorator */:
	                    case 178 /* DeleteExpression */:
	                    case 200 /* DoStatement */:
	                    case 170 /* ElementAccessExpression */:
	                    case 230 /* ExportAssignment */:
	                    case 198 /* ExpressionStatement */:
	                    case 191 /* ExpressionWithTypeArguments */:
	                    case 202 /* ForStatement */:
	                    case 203 /* ForInStatement */:
	                    case 204 /* ForOfStatement */:
	                    case 199 /* IfStatement */:
	                    case 240 /* JsxClosingElement */:
	                    case 237 /* JsxSelfClosingElement */:
	                    case 238 /* JsxOpeningElement */:
	                    case 242 /* JsxSpreadAttribute */:
	                    case 243 /* JsxExpression */:
	                    case 172 /* NewExpression */:
	                    case 175 /* ParenthesizedExpression */:
	                    case 183 /* PostfixUnaryExpression */:
	                    case 182 /* PrefixUnaryExpression */:
	                    case 207 /* ReturnStatement */:
	                    case 249 /* ShorthandPropertyAssignment */:
	                    case 188 /* SpreadElementExpression */:
	                    case 209 /* SwitchStatement */:
	                    case 173 /* TaggedTemplateExpression */:
	                    case 193 /* TemplateSpan */:
	                    case 211 /* ThrowStatement */:
	                    case 174 /* TypeAssertionExpression */:
	                    case 179 /* TypeOfExpression */:
	                    case 180 /* VoidExpression */:
	                    case 201 /* WhileStatement */:
	                    case 208 /* WithStatement */:
	                    case 187 /* YieldExpression */:
	                        return true;
	                    case 166 /* BindingElement */:
	                    case 250 /* EnumMember */:
	                    case 139 /* Parameter */:
	                    case 248 /* PropertyAssignment */:
	                    case 142 /* PropertyDeclaration */:
	                    case 214 /* VariableDeclaration */:
	                        return parent.initializer === node;
	                    case 169 /* PropertyAccessExpression */:
	                        return parent.expression === node;
	                    case 177 /* ArrowFunction */:
	                    case 176 /* FunctionExpression */:
	                        return parent.body === node;
	                    case 224 /* ImportEqualsDeclaration */:
	                        return parent.moduleReference === node;
	                    case 136 /* QualifiedName */:
	                        return parent.left === node;
	                }
	                return false;
	            }
	            function emitExpressionIdentifier(node) {
	                var container = resolver.getReferencedExportContainer(node);
	                if (container) {
	                    if (container.kind === 251 /* SourceFile */) {
	                        // Identifier references module export
	                        if (modulekind !== 5 /* ES6 */ && modulekind !== 4 /* System */) {
	                            write("exports.");
	                        }
	                    }
	                    else {
	                        // Identifier references namespace export
	                        write(getGeneratedNameForNode(container));
	                        write(".");
	                    }
	                }
	                else {
	                    if (modulekind !== 5 /* ES6 */) {
	                        var declaration = resolver.getReferencedImportDeclaration(node);
	                        if (declaration) {
	                            if (declaration.kind === 226 /* ImportClause */) {
	                                // Identifier references default import
	                                write(getGeneratedNameForNode(declaration.parent));
	                                write(languageVersion === 0 /* ES3 */ ? "[\"default\"]" : ".default");
	                                return;
	                            }
	                            else if (declaration.kind === 229 /* ImportSpecifier */) {
	                                // Identifier references named import
	                                write(getGeneratedNameForNode(declaration.parent.parent.parent));
	                                var name_24 = declaration.propertyName || declaration.name;
	                                var identifier = ts.getTextOfNodeFromSourceText(currentText, name_24);
	                                if (languageVersion === 0 /* ES3 */ && identifier === "default") {
	                                    write("[\"default\"]");
	                                }
	                                else {
	                                    write(".");
	                                    write(identifier);
	                                }
	                                return;
	                            }
	                        }
	                    }
	                    if (languageVersion < 2 /* ES6 */) {
	                        var declaration = resolver.getReferencedDeclarationWithCollidingName(node);
	                        if (declaration) {
	                            write(getGeneratedNameForNode(declaration.name));
	                            return;
	                        }
	                    }
	                    else if (resolver.getNodeCheckFlags(node) & 1048576 /* BodyScopedClassBinding */) {
	                        // Due to the emit for class decorators, any reference to the class from inside of the class body
	                        // must instead be rewritten to point to a temporary variable to avoid issues with the double-bind
	                        // behavior of class names in ES6.
	                        var declaration = resolver.getReferencedValueDeclaration(node);
	                        if (declaration) {
	                            var classAlias = decoratedClassAliases[ts.getNodeId(declaration)];
	                            if (classAlias !== undefined) {
	                                write(classAlias);
	                                return;
	                            }
	                        }
	                    }
	                }
	                if (ts.nodeIsSynthesized(node)) {
	                    write(node.text);
	                }
	                else {
	                    writeTextOfNode(currentText, node);
	                }
	            }
	            function isNameOfNestedBlockScopedRedeclarationOrCapturedBinding(node) {
	                if (languageVersion < 2 /* ES6 */) {
	                    var parent_8 = node.parent;
	                    switch (parent_8.kind) {
	                        case 166 /* BindingElement */:
	                        case 217 /* ClassDeclaration */:
	                        case 220 /* EnumDeclaration */:
	                        case 214 /* VariableDeclaration */:
	                            return parent_8.name === node && resolver.isDeclarationWithCollidingName(parent_8);
	                    }
	                }
	                return false;
	            }
	            function emitIdentifier(node) {
	                if (convertedLoopState) {
	                    if (node.text == "arguments" && resolver.isArgumentsLocalBinding(node)) {
	                        // in converted loop body arguments cannot be used directly.
	                        var name_25 = convertedLoopState.argumentsName || (convertedLoopState.argumentsName = makeUniqueName("arguments"));
	                        write(name_25);
	                        return;
	                    }
	                }
	                if (!node.parent) {
	                    write(node.text);
	                }
	                else if (isExpressionIdentifier(node)) {
	                    emitExpressionIdentifier(node);
	                }
	                else if (isNameOfNestedBlockScopedRedeclarationOrCapturedBinding(node)) {
	                    write(getGeneratedNameForNode(node));
	                }
	                else if (ts.nodeIsSynthesized(node)) {
	                    write(node.text);
	                }
	                else {
	                    writeTextOfNode(currentText, node);
	                }
	            }
	            function emitThis(node) {
	                if (resolver.getNodeCheckFlags(node) & 2 /* LexicalThis */) {
	                    write("_this");
	                }
	                else if (convertedLoopState) {
	                    write(convertedLoopState.thisName || (convertedLoopState.thisName = makeUniqueName("this")));
	                }
	                else {
	                    write("this");
	                }
	            }
	            function emitSuper(node) {
	                if (languageVersion >= 2 /* ES6 */) {
	                    write("super");
	                }
	                else {
	                    var flags = resolver.getNodeCheckFlags(node);
	                    if (flags & 256 /* SuperInstance */) {
	                        write("_super.prototype");
	                    }
	                    else {
	                        write("_super");
	                    }
	                }
	            }
	            function emitObjectBindingPattern(node) {
	                write("{ ");
	                var elements = node.elements;
	                emitList(elements, 0, elements.length, /*multiLine*/ false, /*trailingComma*/ elements.hasTrailingComma);
	                write(" }");
	            }
	            function emitArrayBindingPattern(node) {
	                write("[");
	                var elements = node.elements;
	                emitList(elements, 0, elements.length, /*multiLine*/ false, /*trailingComma*/ elements.hasTrailingComma);
	                write("]");
	            }
	            function emitBindingElement(node) {
	                if (node.propertyName) {
	                    emit(node.propertyName);
	                    write(": ");
	                }
	                if (node.dotDotDotToken) {
	                    write("...");
	                }
	                if (ts.isBindingPattern(node.name)) {
	                    emit(node.name);
	                }
	                else {
	                    emitModuleMemberName(node);
	                }
	                emitOptional(" = ", node.initializer);
	            }
	            function emitSpreadElementExpression(node) {
	                write("...");
	                emit(node.expression);
	            }
	            function emitYieldExpression(node) {
	                write(ts.tokenToString(114 /* YieldKeyword */));
	                if (node.asteriskToken) {
	                    write("*");
	                }
	                if (node.expression) {
	                    write(" ");
	                    emit(node.expression);
	                }
	            }
	            function emitAwaitExpression(node) {
	                var needsParenthesis = needsParenthesisForAwaitExpressionAsYield(node);
	                if (needsParenthesis) {
	                    write("(");
	                }
	                write(ts.tokenToString(114 /* YieldKeyword */));
	                write(" ");
	                emit(node.expression);
	                if (needsParenthesis) {
	                    write(")");
	                }
	            }
	            function needsParenthesisForAwaitExpressionAsYield(node) {
	                if (node.parent.kind === 184 /* BinaryExpression */ && !ts.isAssignmentOperator(node.parent.operatorToken.kind)) {
	                    return true;
	                }
	                else if (node.parent.kind === 185 /* ConditionalExpression */ && node.parent.condition === node) {
	                    return true;
	                }
	                return false;
	            }
	            function needsParenthesisForPropertyAccessOrInvocation(node) {
	                switch (node.kind) {
	                    case 69 /* Identifier */:
	                    case 167 /* ArrayLiteralExpression */:
	                    case 169 /* PropertyAccessExpression */:
	                    case 170 /* ElementAccessExpression */:
	                    case 171 /* CallExpression */:
	                    case 175 /* ParenthesizedExpression */:
	                        // This list is not exhaustive and only includes those cases that are relevant
	                        // to the check in emitArrayLiteral. More cases can be added as needed.
	                        return false;
	                }
	                return true;
	            }
	            function emitListWithSpread(elements, needsUniqueCopy, multiLine, trailingComma, useConcat) {
	                var pos = 0;
	                var group = 0;
	                var length = elements.length;
	                while (pos < length) {
	                    // Emit using the pattern <group0>.concat(<group1>, <group2>, ...)
	                    if (group === 1 && useConcat) {
	                        write(".concat(");
	                    }
	                    else if (group > 0) {
	                        write(", ");
	                    }
	                    var e = elements[pos];
	                    if (e.kind === 188 /* SpreadElementExpression */) {
	                        e = e.expression;
	                        emitParenthesizedIf(e, /*parenthesized*/ group === 0 && needsParenthesisForPropertyAccessOrInvocation(e));
	                        pos++;
	                        if (pos === length && group === 0 && needsUniqueCopy && e.kind !== 167 /* ArrayLiteralExpression */) {
	                            write(".slice()");
	                        }
	                    }
	                    else {
	                        var i = pos;
	                        while (i < length && elements[i].kind !== 188 /* SpreadElementExpression */) {
	                            i++;
	                        }
	                        write("[");
	                        if (multiLine) {
	                            increaseIndent();
	                        }
	                        emitList(elements, pos, i - pos, multiLine, trailingComma && i === length);
	                        if (multiLine) {
	                            decreaseIndent();
	                        }
	                        write("]");
	                        pos = i;
	                    }
	                    group++;
	                }
	                if (group > 1) {
	                    if (useConcat) {
	                        write(")");
	                    }
	                }
	            }
	            function isSpreadElementExpression(node) {
	                return node.kind === 188 /* SpreadElementExpression */;
	            }
	            function emitArrayLiteral(node) {
	                var elements = node.elements;
	                if (elements.length === 0) {
	                    write("[]");
	                }
	                else if (languageVersion >= 2 /* ES6 */ || !ts.forEach(elements, isSpreadElementExpression)) {
	                    write("[");
	                    emitLinePreservingList(node, node.elements, elements.hasTrailingComma, /*spacesBetweenBraces*/ false);
	                    write("]");
	                }
	                else {
	                    emitListWithSpread(elements, /*needsUniqueCopy*/ true, /*multiLine*/ (node.flags & 1024 /* MultiLine */) !== 0, 
	                    /*trailingComma*/ elements.hasTrailingComma, /*useConcat*/ true);
	                }
	            }
	            function emitObjectLiteralBody(node, numElements) {
	                if (numElements === 0) {
	                    write("{}");
	                    return;
	                }
	                write("{");
	                if (numElements > 0) {
	                    var properties = node.properties;
	                    // If we are not doing a downlevel transformation for object literals,
	                    // then try to preserve the original shape of the object literal.
	                    // Otherwise just try to preserve the formatting.
	                    if (numElements === properties.length) {
	                        emitLinePreservingList(node, properties, /*allowTrailingComma*/ languageVersion >= 1 /* ES5 */, /*spacesBetweenBraces*/ true);
	                    }
	                    else {
	                        var multiLine = (node.flags & 1024 /* MultiLine */) !== 0;
	                        if (!multiLine) {
	                            write(" ");
	                        }
	                        else {
	                            increaseIndent();
	                        }
	                        emitList(properties, 0, numElements, /*multiLine*/ multiLine, /*trailingComma*/ false);
	                        if (!multiLine) {
	                            write(" ");
	                        }
	                        else {
	                            decreaseIndent();
	                        }
	                    }
	                }
	                write("}");
	            }
	            function emitDownlevelObjectLiteralWithComputedProperties(node, firstComputedPropertyIndex) {
	                var multiLine = (node.flags & 1024 /* MultiLine */) !== 0;
	                var properties = node.properties;
	                write("(");
	                if (multiLine) {
	                    increaseIndent();
	                }
	                // For computed properties, we need to create a unique handle to the object
	                // literal so we can modify it without risking internal assignments tainting the object.
	                var tempVar = createAndRecordTempVariable(0 /* Auto */);
	                // Write out the first non-computed properties
	                // (or all properties if none of them are computed),
	                // then emit the rest through indexing on the temp variable.
	                emit(tempVar);
	                write(" = ");
	                emitObjectLiteralBody(node, firstComputedPropertyIndex);
	                for (var i = firstComputedPropertyIndex, n = properties.length; i < n; i++) {
	                    writeComma();
	                    var property = properties[i];
	                    emitStart(property);
	                    if (property.kind === 146 /* GetAccessor */ || property.kind === 147 /* SetAccessor */) {
	                        // TODO (drosen): Reconcile with 'emitMemberFunctions'.
	                        var accessors = ts.getAllAccessorDeclarations(node.properties, property);
	                        if (property !== accessors.firstAccessor) {
	                            continue;
	                        }
	                        write("Object.defineProperty(");
	                        emit(tempVar);
	                        write(", ");
	                        emitStart(node.name);
	                        emitExpressionForPropertyName(property.name);
	                        emitEnd(property.name);
	                        write(", {");
	                        increaseIndent();
	                        if (accessors.getAccessor) {
	                            writeLine();
	                            emitLeadingComments(accessors.getAccessor);
	                            write("get: ");
	                            emitStart(accessors.getAccessor);
	                            write("function ");
	                            emitSignatureAndBody(accessors.getAccessor);
	                            emitEnd(accessors.getAccessor);
	                            emitTrailingComments(accessors.getAccessor);
	                            write(",");
	                        }
	                        if (accessors.setAccessor) {
	                            writeLine();
	                            emitLeadingComments(accessors.setAccessor);
	                            write("set: ");
	                            emitStart(accessors.setAccessor);
	                            write("function ");
	                            emitSignatureAndBody(accessors.setAccessor);
	                            emitEnd(accessors.setAccessor);
	                            emitTrailingComments(accessors.setAccessor);
	                            write(",");
	                        }
	                        writeLine();
	                        write("enumerable: true,");
	                        writeLine();
	                        write("configurable: true");
	                        decreaseIndent();
	                        writeLine();
	                        write("})");
	                        emitEnd(property);
	                    }
	                    else {
	                        emitLeadingComments(property);
	                        emitStart(property.name);
	                        emit(tempVar);
	                        emitMemberAccessForPropertyName(property.name);
	                        emitEnd(property.name);
	                        write(" = ");
	                        if (property.kind === 248 /* PropertyAssignment */) {
	                            emit(property.initializer);
	                        }
	                        else if (property.kind === 249 /* ShorthandPropertyAssignment */) {
	                            emitExpressionIdentifier(property.name);
	                        }
	                        else if (property.kind === 144 /* MethodDeclaration */) {
	                            emitFunctionDeclaration(property);
	                        }
	                        else {
	                            ts.Debug.fail("ObjectLiteralElement type not accounted for: " + property.kind);
	                        }
	                    }
	                    emitEnd(property);
	                }
	                writeComma();
	                emit(tempVar);
	                if (multiLine) {
	                    decreaseIndent();
	                    writeLine();
	                }
	                write(")");
	                function writeComma() {
	                    if (multiLine) {
	                        write(",");
	                        writeLine();
	                    }
	                    else {
	                        write(", ");
	                    }
	                }
	            }
	            function emitObjectLiteral(node) {
	                var properties = node.properties;
	                if (languageVersion < 2 /* ES6 */) {
	                    var numProperties = properties.length;
	                    // Find the first computed property.
	                    // Everything until that point can be emitted as part of the initial object literal.
	                    var numInitialNonComputedProperties = numProperties;
	                    for (var i = 0, n = properties.length; i < n; i++) {
	                        if (properties[i].name.kind === 137 /* ComputedPropertyName */) {
	                            numInitialNonComputedProperties = i;
	                            break;
	                        }
	                    }
	                    var hasComputedProperty = numInitialNonComputedProperties !== properties.length;
	                    if (hasComputedProperty) {
	                        emitDownlevelObjectLiteralWithComputedProperties(node, numInitialNonComputedProperties);
	                        return;
	                    }
	                }
	                // Ordinary case: either the object has no computed properties
	                // or we're compiling with an ES6+ target.
	                emitObjectLiteralBody(node, properties.length);
	            }
	            function createBinaryExpression(left, operator, right, startsOnNewLine) {
	                var result = ts.createSynthesizedNode(184 /* BinaryExpression */, startsOnNewLine);
	                result.operatorToken = ts.createSynthesizedNode(operator);
	                result.left = left;
	                result.right = right;
	                return result;
	            }
	            function createPropertyAccessExpression(expression, name) {
	                var result = ts.createSynthesizedNode(169 /* PropertyAccessExpression */);
	                result.expression = parenthesizeForAccess(expression);
	                result.dotToken = ts.createSynthesizedNode(21 /* DotToken */);
	                result.name = name;
	                return result;
	            }
	            function createElementAccessExpression(expression, argumentExpression) {
	                var result = ts.createSynthesizedNode(170 /* ElementAccessExpression */);
	                result.expression = parenthesizeForAccess(expression);
	                result.argumentExpression = argumentExpression;
	                return result;
	            }
	            function parenthesizeForAccess(expr) {
	                // When diagnosing whether the expression needs parentheses, the decision should be based
	                // on the innermost expression in a chain of nested type assertions.
	                while (expr.kind === 174 /* TypeAssertionExpression */ || expr.kind === 192 /* AsExpression */) {
	                    expr = expr.expression;
	                }
	                // isLeftHandSideExpression is almost the correct criterion for when it is not necessary
	                // to parenthesize the expression before a dot. The known exceptions are:
	                //
	                //    NewExpression:
	                //       new C.x        -> not the same as (new C).x
	                //    NumberLiteral
	                //       1.x            -> not the same as (1).x
	                //
	                if (ts.isLeftHandSideExpression(expr) &&
	                    expr.kind !== 172 /* NewExpression */ &&
	                    expr.kind !== 8 /* NumericLiteral */) {
	                    return expr;
	                }
	                var node = ts.createSynthesizedNode(175 /* ParenthesizedExpression */);
	                node.expression = expr;
	                return node;
	            }
	            function emitComputedPropertyName(node) {
	                write("[");
	                emitExpressionForPropertyName(node);
	                write("]");
	            }
	            function emitMethod(node) {
	                if (languageVersion >= 2 /* ES6 */ && node.asteriskToken) {
	                    write("*");
	                }
	                emit(node.name);
	                if (languageVersion < 2 /* ES6 */) {
	                    write(": function ");
	                }
	                emitSignatureAndBody(node);
	            }
	            function emitPropertyAssignment(node) {
	                emit(node.name);
	                write(": ");
	                // This is to ensure that we emit comment in the following case:
	                //      For example:
	                //          obj = {
	                //              id: /*comment1*/ ()=>void
	                //          }
	                // "comment1" is not considered to be leading comment for node.initializer
	                // but rather a trailing comment on the previous node.
	                emitTrailingCommentsOfPosition(node.initializer.pos);
	                emit(node.initializer);
	            }
	            // Return true if identifier resolves to an exported member of a namespace
	            function isNamespaceExportReference(node) {
	                var container = resolver.getReferencedExportContainer(node);
	                return container && container.kind !== 251 /* SourceFile */;
	            }
	            function emitShorthandPropertyAssignment(node) {
	                // The name property of a short-hand property assignment is considered an expression position, so here
	                // we manually emit the identifier to avoid rewriting.
	                writeTextOfNode(currentText, node.name);
	                // If emitting pre-ES6 code, or if the name requires rewriting when resolved as an expression identifier,
	                // we emit a normal property assignment. For example:
	                //   module m {
	                //       export let y;
	                //   }
	                //   module m {
	                //       let obj = { y };
	                //   }
	                // Here we need to emit obj = { y : m.y } regardless of the output target.
	                if (modulekind !== 5 /* ES6 */ || isNamespaceExportReference(node.name)) {
	                    // Emit identifier as an identifier
	                    write(": ");
	                    emit(node.name);
	                }
	                if (languageVersion >= 2 /* ES6 */ && node.objectAssignmentInitializer) {
	                    write(" = ");
	                    emit(node.objectAssignmentInitializer);
	                }
	            }
	            function tryEmitConstantValue(node) {
	                var constantValue = tryGetConstEnumValue(node);
	                if (constantValue !== undefined) {
	                    write(constantValue.toString());
	                    if (!compilerOptions.removeComments) {
	                        var propertyName = node.kind === 169 /* PropertyAccessExpression */ ? ts.declarationNameToString(node.name) : ts.getTextOfNode(node.argumentExpression);
	                        write(" /* " + propertyName + " */");
	                    }
	                    return true;
	                }
	                return false;
	            }
	            function tryGetConstEnumValue(node) {
	                if (compilerOptions.isolatedModules) {
	                    return undefined;
	                }
	                return node.kind === 169 /* PropertyAccessExpression */ || node.kind === 170 /* ElementAccessExpression */
	                    ? resolver.getConstantValue(node)
	                    : undefined;
	            }
	            // Returns 'true' if the code was actually indented, false otherwise.
	            // If the code is not indented, an optional valueToWriteWhenNotIndenting will be
	            // emitted instead.
	            function indentIfOnDifferentLines(parent, node1, node2, valueToWriteWhenNotIndenting) {
	                var realNodesAreOnDifferentLines = !ts.nodeIsSynthesized(parent) && !nodeEndIsOnSameLineAsNodeStart(node1, node2);
	                // Always use a newline for synthesized code if the synthesizer desires it.
	                var synthesizedNodeIsOnDifferentLine = synthesizedNodeStartsOnNewLine(node2);
	                if (realNodesAreOnDifferentLines || synthesizedNodeIsOnDifferentLine) {
	                    increaseIndent();
	                    writeLine();
	                    return true;
	                }
	                else {
	                    if (valueToWriteWhenNotIndenting) {
	                        write(valueToWriteWhenNotIndenting);
	                    }
	                    return false;
	                }
	            }
	            function emitPropertyAccess(node) {
	                if (tryEmitConstantValue(node)) {
	                    return;
	                }
	                if (languageVersion === 2 /* ES6 */ &&
	                    node.expression.kind === 95 /* SuperKeyword */ &&
	                    isInAsyncMethodWithSuperInES6(node)) {
	                    var name_26 = ts.createSynthesizedNode(9 /* StringLiteral */);
	                    name_26.text = node.name.text;
	                    emitSuperAccessInAsyncMethod(node.expression, name_26);
	                    return;
	                }
	                emit(node.expression);
	                var indentedBeforeDot = indentIfOnDifferentLines(node, node.expression, node.dotToken);
	                // 1 .toString is a valid property access, emit a space after the literal
	                // Also emit a space if expression is a integer const enum value - it will appear in generated code as numeric literal
	                var shouldEmitSpace = false;
	                if (!indentedBeforeDot) {
	                    if (node.expression.kind === 8 /* NumericLiteral */) {
	                        // check if numeric literal was originally written with a dot
	                        var text = ts.getTextOfNodeFromSourceText(currentText, node.expression);
	                        shouldEmitSpace = text.indexOf(ts.tokenToString(21 /* DotToken */)) < 0;
	                    }
	                    else {
	                        // check if constant enum value is integer
	                        var constantValue = tryGetConstEnumValue(node.expression);
	                        // isFinite handles cases when constantValue is undefined
	                        shouldEmitSpace = isFinite(constantValue) && Math.floor(constantValue) === constantValue;
	                    }
	                }
	                if (shouldEmitSpace) {
	                    write(" .");
	                }
	                else {
	                    write(".");
	                }
	                var indentedAfterDot = indentIfOnDifferentLines(node, node.dotToken, node.name);
	                emit(node.name);
	                decreaseIndentIf(indentedBeforeDot, indentedAfterDot);
	            }
	            function emitQualifiedName(node) {
	                emit(node.left);
	                write(".");
	                emit(node.right);
	            }
	            function emitQualifiedNameAsExpression(node, useFallback) {
	                if (node.left.kind === 69 /* Identifier */) {
	                    emitEntityNameAsExpression(node.left, useFallback);
	                }
	                else if (useFallback) {
	                    var temp = createAndRecordTempVariable(0 /* Auto */);
	                    write("(");
	                    emitNodeWithoutSourceMap(temp);
	                    write(" = ");
	                    emitEntityNameAsExpression(node.left, /*useFallback*/ true);
	                    write(") && ");
	                    emitNodeWithoutSourceMap(temp);
	                }
	                else {
	                    emitEntityNameAsExpression(node.left, /*useFallback*/ false);
	                }
	                write(".");
	                emit(node.right);
	            }
	            function emitEntityNameAsExpression(node, useFallback) {
	                switch (node.kind) {
	                    case 69 /* Identifier */:
	                        if (useFallback) {
	                            write("typeof ");
	                            emitExpressionIdentifier(node);
	                            write(" !== 'undefined' && ");
	                        }
	                        emitExpressionIdentifier(node);
	                        break;
	                    case 136 /* QualifiedName */:
	                        emitQualifiedNameAsExpression(node, useFallback);
	                        break;
	                    default:
	                        emitNodeWithoutSourceMap(node);
	                        break;
	                }
	            }
	            function emitIndexedAccess(node) {
	                if (tryEmitConstantValue(node)) {
	                    return;
	                }
	                if (languageVersion === 2 /* ES6 */ &&
	                    node.expression.kind === 95 /* SuperKeyword */ &&
	                    isInAsyncMethodWithSuperInES6(node)) {
	                    emitSuperAccessInAsyncMethod(node.expression, node.argumentExpression);
	                    return;
	                }
	                emit(node.expression);
	                write("[");
	                emit(node.argumentExpression);
	                write("]");
	            }
	            function hasSpreadElement(elements) {
	                return ts.forEach(elements, function (e) { return e.kind === 188 /* SpreadElementExpression */; });
	            }
	            function skipParentheses(node) {
	                while (node.kind === 175 /* ParenthesizedExpression */ || node.kind === 174 /* TypeAssertionExpression */ || node.kind === 192 /* AsExpression */) {
	                    node = node.expression;
	                }
	                return node;
	            }
	            function emitCallTarget(node) {
	                if (node.kind === 69 /* Identifier */ || node.kind === 97 /* ThisKeyword */ || node.kind === 95 /* SuperKeyword */) {
	                    emit(node);
	                    return node;
	                }
	                var temp = createAndRecordTempVariable(0 /* Auto */);
	                write("(");
	                emit(temp);
	                write(" = ");
	                emit(node);
	                write(")");
	                return temp;
	            }
	            function emitCallWithSpread(node) {
	                var target;
	                var expr = skipParentheses(node.expression);
	                if (expr.kind === 169 /* PropertyAccessExpression */) {
	                    // Target will be emitted as "this" argument
	                    target = emitCallTarget(expr.expression);
	                    write(".");
	                    emit(expr.name);
	                }
	                else if (expr.kind === 170 /* ElementAccessExpression */) {
	                    // Target will be emitted as "this" argument
	                    target = emitCallTarget(expr.expression);
	                    write("[");
	                    emit(expr.argumentExpression);
	                    write("]");
	                }
	                else if (expr.kind === 95 /* SuperKeyword */) {
	                    target = expr;
	                    write("_super");
	                }
	                else {
	                    emit(node.expression);
	                }
	                write(".apply(");
	                if (target) {
	                    if (target.kind === 95 /* SuperKeyword */) {
	                        // Calls of form super(...) and super.foo(...)
	                        emitThis(target);
	                    }
	                    else {
	                        // Calls of form obj.foo(...)
	                        emit(target);
	                    }
	                }
	                else {
	                    // Calls of form foo(...)
	                    write("void 0");
	                }
	                write(", ");
	                emitListWithSpread(node.arguments, /*needsUniqueCopy*/ false, /*multiLine*/ false, /*trailingComma*/ false, /*useConcat*/ true);
	                write(")");
	            }
	            function isInAsyncMethodWithSuperInES6(node) {
	                if (languageVersion === 2 /* ES6 */) {
	                    var container = ts.getSuperContainer(node, /*includeFunctions*/ false);
	                    if (container && resolver.getNodeCheckFlags(container) & (2048 /* AsyncMethodWithSuper */ | 4096 /* AsyncMethodWithSuperBinding */)) {
	                        return true;
	                    }
	                }
	                return false;
	            }
	            function emitSuperAccessInAsyncMethod(superNode, argumentExpression) {
	                var container = ts.getSuperContainer(superNode, /*includeFunctions*/ false);
	                var isSuperBinding = resolver.getNodeCheckFlags(container) & 4096 /* AsyncMethodWithSuperBinding */;
	                write("_super(");
	                emit(argumentExpression);
	                write(isSuperBinding ? ").value" : ")");
	            }
	            function emitCallExpression(node) {
	                if (languageVersion < 2 /* ES6 */ && hasSpreadElement(node.arguments)) {
	                    emitCallWithSpread(node);
	                    return;
	                }
	                var expression = node.expression;
	                var superCall = false;
	                var isAsyncMethodWithSuper = false;
	                if (expression.kind === 95 /* SuperKeyword */) {
	                    emitSuper(expression);
	                    superCall = true;
	                }
	                else {
	                    superCall = ts.isSuperPropertyOrElementAccess(expression);
	                    isAsyncMethodWithSuper = superCall && isInAsyncMethodWithSuperInES6(node);
	                    emit(expression);
	                }
	                if (superCall && (languageVersion < 2 /* ES6 */ || isAsyncMethodWithSuper)) {
	                    write(".call(");
	                    emitThis(expression);
	                    if (node.arguments.length) {
	                        write(", ");
	                        emitCommaList(node.arguments);
	                    }
	                    write(")");
	                }
	                else {
	                    write("(");
	                    emitCommaList(node.arguments);
	                    write(")");
	                }
	            }
	            function emitNewExpression(node) {
	                write("new ");
	                // Spread operator logic is supported in new expressions in ES5 using a combination
	                // of Function.prototype.bind() and Function.prototype.apply().
	                //
	                //     Example:
	                //
	                //         var args = [1, 2, 3, 4, 5];
	                //         new Array(...args);
	                //
	                //     is compiled into the following ES5:
	                //
	                //         var args = [1, 2, 3, 4, 5];
	                //         new (Array.bind.apply(Array, [void 0].concat(args)));
	                //
	                // The 'thisArg' to 'bind' is ignored when invoking the result of 'bind' with 'new',
	                // Thus, we set it to undefined ('void 0').
	                if (languageVersion === 1 /* ES5 */ &&
	                    node.arguments &&
	                    hasSpreadElement(node.arguments)) {
	                    write("(");
	                    var target = emitCallTarget(node.expression);
	                    write(".bind.apply(");
	                    emit(target);
	                    write(", [void 0].concat(");
	                    emitListWithSpread(node.arguments, /*needsUniqueCopy*/ false, /*multiLine*/ false, /*trailingComma*/ false, /*useConcat*/ false);
	                    write(")))");
	                    write("()");
	                }
	                else {
	                    emit(node.expression);
	                    if (node.arguments) {
	                        write("(");
	                        emitCommaList(node.arguments);
	                        write(")");
	                    }
	                }
	            }
	            function emitTaggedTemplateExpression(node) {
	                if (languageVersion >= 2 /* ES6 */) {
	                    emit(node.tag);
	                    write(" ");
	                    emit(node.template);
	                }
	                else {
	                    emitDownlevelTaggedTemplate(node);
	                }
	            }
	            function emitParenExpression(node) {
	                // If the node is synthesized, it means the emitter put the parentheses there,
	                // not the user. If we didn't want them, the emitter would not have put them
	                // there.
	                if (!ts.nodeIsSynthesized(node) && node.parent.kind !== 177 /* ArrowFunction */) {
	                    if (node.expression.kind === 174 /* TypeAssertionExpression */ || node.expression.kind === 192 /* AsExpression */) {
	                        var operand = node.expression.expression;
	                        // Make sure we consider all nested cast expressions, e.g.:
	                        // (<any><number><any>-A).x;
	                        while (operand.kind === 174 /* TypeAssertionExpression */ || operand.kind === 192 /* AsExpression */) {
	                            operand = operand.expression;
	                        }
	                        // We have an expression of the form: (<Type>SubExpr)
	                        // Emitting this as (SubExpr) is really not desirable. We would like to emit the subexpr as is.
	                        // Omitting the parentheses, however, could cause change in the semantics of the generated
	                        // code if the casted expression has a lower precedence than the rest of the expression, e.g.:
	                        //      (<any>new A).foo should be emitted as (new A).foo and not new A.foo
	                        //      (<any>typeof A).toString() should be emitted as (typeof A).toString() and not typeof A.toString()
	                        //      new (<any>A()) should be emitted as new (A()) and not new A()
	                        //      (<any>function foo() { })() should be emitted as an IIF (function foo(){})() and not declaration function foo(){} ()
	                        if (operand.kind !== 182 /* PrefixUnaryExpression */ &&
	                            operand.kind !== 180 /* VoidExpression */ &&
	                            operand.kind !== 179 /* TypeOfExpression */ &&
	                            operand.kind !== 178 /* DeleteExpression */ &&
	                            operand.kind !== 183 /* PostfixUnaryExpression */ &&
	                            operand.kind !== 172 /* NewExpression */ &&
	                            !(operand.kind === 171 /* CallExpression */ && node.parent.kind === 172 /* NewExpression */) &&
	                            !(operand.kind === 176 /* FunctionExpression */ && node.parent.kind === 171 /* CallExpression */) &&
	                            !(operand.kind === 8 /* NumericLiteral */ && node.parent.kind === 169 /* PropertyAccessExpression */)) {
	                            emit(operand);
	                            return;
	                        }
	                    }
	                }
	                write("(");
	                emit(node.expression);
	                write(")");
	            }
	            function emitDeleteExpression(node) {
	                write(ts.tokenToString(78 /* DeleteKeyword */));
	                write(" ");
	                emit(node.expression);
	            }
	            function emitVoidExpression(node) {
	                write(ts.tokenToString(103 /* VoidKeyword */));
	                write(" ");
	                emit(node.expression);
	            }
	            function emitTypeOfExpression(node) {
	                write(ts.tokenToString(101 /* TypeOfKeyword */));
	                write(" ");
	                emit(node.expression);
	            }
	            function isNameOfExportedSourceLevelDeclarationInSystemExternalModule(node) {
	                if (!isCurrentFileSystemExternalModule() || node.kind !== 69 /* Identifier */ || ts.nodeIsSynthesized(node)) {
	                    return false;
	                }
	                var isVariableDeclarationOrBindingElement = node.parent && (node.parent.kind === 214 /* VariableDeclaration */ || node.parent.kind === 166 /* BindingElement */);
	                var targetDeclaration = isVariableDeclarationOrBindingElement
	                    ? node.parent
	                    : resolver.getReferencedValueDeclaration(node);
	                return isSourceFileLevelDeclarationInSystemJsModule(targetDeclaration, /*isExported*/ true);
	            }
	            function emitPrefixUnaryExpression(node) {
	                var exportChanged = (node.operator === 41 /* PlusPlusToken */ || node.operator === 42 /* MinusMinusToken */) &&
	                    isNameOfExportedSourceLevelDeclarationInSystemExternalModule(node.operand);
	                if (exportChanged) {
	                    // emit
	                    // ++x
	                    // as
	                    // exports('x', ++x)
	                    write(exportFunctionForFile + "(\"");
	                    emitNodeWithoutSourceMap(node.operand);
	                    write("\", ");
	                }
	                write(ts.tokenToString(node.operator));
	                // In some cases, we need to emit a space between the operator and the operand. One obvious case
	                // is when the operator is an identifier, like delete or typeof. We also need to do this for plus
	                // and minus expressions in certain cases. Specifically, consider the following two cases (parens
	                // are just for clarity of exposition, and not part of the source code):
	                //
	                //  (+(+1))
	                //  (+(++1))
	                //
	                // We need to emit a space in both cases. In the first case, the absence of a space will make
	                // the resulting expression a prefix increment operation. And in the second, it will make the resulting
	                // expression a prefix increment whose operand is a plus expression - (++(+x))
	                // The same is true of minus of course.
	                if (node.operand.kind === 182 /* PrefixUnaryExpression */) {
	                    var operand = node.operand;
	                    if (node.operator === 35 /* PlusToken */ && (operand.operator === 35 /* PlusToken */ || operand.operator === 41 /* PlusPlusToken */)) {
	                        write(" ");
	                    }
	                    else if (node.operator === 36 /* MinusToken */ && (operand.operator === 36 /* MinusToken */ || operand.operator === 42 /* MinusMinusToken */)) {
	                        write(" ");
	                    }
	                }
	                emit(node.operand);
	                if (exportChanged) {
	                    write(")");
	                }
	            }
	            function emitPostfixUnaryExpression(node) {
	                var exportChanged = isNameOfExportedSourceLevelDeclarationInSystemExternalModule(node.operand);
	                if (exportChanged) {
	                    // export function returns the value that was passes as the second argument
	                    // however for postfix unary expressions result value should be the value before modification.
	                    // emit 'x++' as '(export('x', ++x) - 1)' and 'x--' as '(export('x', --x) + 1)'
	                    write("(" + exportFunctionForFile + "(\"");
	                    emitNodeWithoutSourceMap(node.operand);
	                    write("\", ");
	                    write(ts.tokenToString(node.operator));
	                    emit(node.operand);
	                    if (node.operator === 41 /* PlusPlusToken */) {
	                        write(") - 1)");
	                    }
	                    else {
	                        write(") + 1)");
	                    }
	                }
	                else {
	                    emit(node.operand);
	                    write(ts.tokenToString(node.operator));
	                }
	            }
	            function shouldHoistDeclarationInSystemJsModule(node) {
	                return isSourceFileLevelDeclarationInSystemJsModule(node, /*isExported*/ false);
	            }
	            /*
	             * Checks if given node is a source file level declaration (not nested in module/function).
	             * If 'isExported' is true - then declaration must also be exported.
	             * This function is used in two cases:
	             * - check if node is a exported source file level value to determine
	             *   if we should also export the value after its it changed
	             * - check if node is a source level declaration to emit it differently,
	             *   i.e non-exported variable statement 'var x = 1' is hoisted so
	             *   we we emit variable statement 'var' should be dropped.
	             */
	            function isSourceFileLevelDeclarationInSystemJsModule(node, isExported) {
	                if (!node || !isCurrentFileSystemExternalModule()) {
	                    return false;
	                }
	                var current = ts.getRootDeclaration(node).parent;
	                while (current) {
	                    if (current.kind === 251 /* SourceFile */) {
	                        return !isExported || ((ts.getCombinedNodeFlags(node) & 2 /* Export */) !== 0);
	                    }
	                    else if (ts.isDeclaration(current)) {
	                        return false;
	                    }
	                    else {
	                        current = current.parent;
	                    }
	                }
	            }
	            /**
	             * Emit ES7 exponentiation operator downlevel using Math.pow
	             * @param node a binary expression node containing exponentiationOperator (**, **=)
	             */
	            function emitExponentiationOperator(node) {
	                var leftHandSideExpression = node.left;
	                if (node.operatorToken.kind === 60 /* AsteriskAsteriskEqualsToken */) {
	                    var synthesizedLHS = void 0;
	                    var shouldEmitParentheses = false;
	                    if (ts.isElementAccessExpression(leftHandSideExpression)) {
	                        shouldEmitParentheses = true;
	                        write("(");
	                        synthesizedLHS = ts.createSynthesizedNode(170 /* ElementAccessExpression */, /*startsOnNewLine*/ false);
	                        var identifier = emitTempVariableAssignment(leftHandSideExpression.expression, /*canDefineTempVariablesInPlace*/ false, /*shouldEmitCommaBeforeAssignment*/ false);
	                        synthesizedLHS.expression = identifier;
	                        if (leftHandSideExpression.argumentExpression.kind !== 8 /* NumericLiteral */ &&
	                            leftHandSideExpression.argumentExpression.kind !== 9 /* StringLiteral */) {
	                            var tempArgumentExpression = createAndRecordTempVariable(268435456 /* _i */);
	                            synthesizedLHS.argumentExpression = tempArgumentExpression;
	                            emitAssignment(tempArgumentExpression, leftHandSideExpression.argumentExpression, /*shouldEmitCommaBeforeAssignment*/ true, leftHandSideExpression.expression);
	                        }
	                        else {
	                            synthesizedLHS.argumentExpression = leftHandSideExpression.argumentExpression;
	                        }
	                        write(", ");
	                    }
	                    else if (ts.isPropertyAccessExpression(leftHandSideExpression)) {
	                        shouldEmitParentheses = true;
	                        write("(");
	                        synthesizedLHS = ts.createSynthesizedNode(169 /* PropertyAccessExpression */, /*startsOnNewLine*/ false);
	                        var identifier = emitTempVariableAssignment(leftHandSideExpression.expression, /*canDefineTempVariablesInPlace*/ false, /*shouldEmitCommaBeforeAssignment*/ false);
	                        synthesizedLHS.expression = identifier;
	                        synthesizedLHS.dotToken = leftHandSideExpression.dotToken;
	                        synthesizedLHS.name = leftHandSideExpression.name;
	                        write(", ");
	                    }
	                    emit(synthesizedLHS || leftHandSideExpression);
	                    write(" = ");
	                    write("Math.pow(");
	                    emit(synthesizedLHS || leftHandSideExpression);
	                    write(", ");
	                    emit(node.right);
	                    write(")");
	                    if (shouldEmitParentheses) {
	                        write(")");
	                    }
	                }
	                else {
	                    write("Math.pow(");
	                    emit(leftHandSideExpression);
	                    write(", ");
	                    emit(node.right);
	                    write(")");
	                }
	            }
	            function emitBinaryExpression(node) {
	                if (languageVersion < 2 /* ES6 */ && node.operatorToken.kind === 56 /* EqualsToken */ &&
	                    (node.left.kind === 168 /* ObjectLiteralExpression */ || node.left.kind === 167 /* ArrayLiteralExpression */)) {
	                    emitDestructuring(node, node.parent.kind === 198 /* ExpressionStatement */);
	                }
	                else {
	                    var exportChanged = node.operatorToken.kind >= 56 /* FirstAssignment */ &&
	                        node.operatorToken.kind <= 68 /* LastAssignment */ &&
	                        isNameOfExportedSourceLevelDeclarationInSystemExternalModule(node.left);
	                    if (exportChanged) {
	                        // emit assignment 'x <op> y' as 'exports("x", x <op> y)'
	                        write(exportFunctionForFile + "(\"");
	                        emitNodeWithoutSourceMap(node.left);
	                        write("\", ");
	                    }
	                    if (node.operatorToken.kind === 38 /* AsteriskAsteriskToken */ || node.operatorToken.kind === 60 /* AsteriskAsteriskEqualsToken */) {
	                        // Downleveled emit exponentiation operator using Math.pow
	                        emitExponentiationOperator(node);
	                    }
	                    else {
	                        emit(node.left);
	                        // Add indentation before emit the operator if the operator is on different line
	                        // For example:
	                        //      3
	                        //      + 2;
	                        //   emitted as
	                        //      3
	                        //          + 2;
	                        var indentedBeforeOperator = indentIfOnDifferentLines(node, node.left, node.operatorToken, node.operatorToken.kind !== 24 /* CommaToken */ ? " " : undefined);
	                        write(ts.tokenToString(node.operatorToken.kind));
	                        var indentedAfterOperator = indentIfOnDifferentLines(node, node.operatorToken, node.right, " ");
	                        emit(node.right);
	                        decreaseIndentIf(indentedBeforeOperator, indentedAfterOperator);
	                    }
	                    if (exportChanged) {
	                        write(")");
	                    }
	                }
	            }
	            function synthesizedNodeStartsOnNewLine(node) {
	                return ts.nodeIsSynthesized(node) && node.startsOnNewLine;
	            }
	            function emitConditionalExpression(node) {
	                emit(node.condition);
	                var indentedBeforeQuestion = indentIfOnDifferentLines(node, node.condition, node.questionToken, " ");
	                write("?");
	                var indentedAfterQuestion = indentIfOnDifferentLines(node, node.questionToken, node.whenTrue, " ");
	                emit(node.whenTrue);
	                decreaseIndentIf(indentedBeforeQuestion, indentedAfterQuestion);
	                var indentedBeforeColon = indentIfOnDifferentLines(node, node.whenTrue, node.colonToken, " ");
	                write(":");
	                var indentedAfterColon = indentIfOnDifferentLines(node, node.colonToken, node.whenFalse, " ");
	                emit(node.whenFalse);
	                decreaseIndentIf(indentedBeforeColon, indentedAfterColon);
	            }
	            // Helper function to decrease the indent if we previously indented.  Allows multiple
	            // previous indent values to be considered at a time.  This also allows caller to just
	            // call this once, passing in all their appropriate indent values, instead of needing
	            // to call this helper function multiple times.
	            function decreaseIndentIf(value1, value2) {
	                if (value1) {
	                    decreaseIndent();
	                }
	                if (value2) {
	                    decreaseIndent();
	                }
	            }
	            function isSingleLineEmptyBlock(node) {
	                if (node && node.kind === 195 /* Block */) {
	                    var block = node;
	                    return block.statements.length === 0 && nodeEndIsOnSameLineAsNodeStart(block, block);
	                }
	            }
	            function emitBlock(node) {
	                if (isSingleLineEmptyBlock(node)) {
	                    emitToken(15 /* OpenBraceToken */, node.pos);
	                    write(" ");
	                    emitToken(16 /* CloseBraceToken */, node.statements.end);
	                    return;
	                }
	                emitToken(15 /* OpenBraceToken */, node.pos);
	                increaseIndent();
	                if (node.kind === 222 /* ModuleBlock */) {
	                    ts.Debug.assert(node.parent.kind === 221 /* ModuleDeclaration */);
	                    emitCaptureThisForNodeIfNecessary(node.parent);
	                }
	                emitLines(node.statements);
	                if (node.kind === 222 /* ModuleBlock */) {
	                    emitTempDeclarations(/*newLine*/ true);
	                }
	                decreaseIndent();
	                writeLine();
	                emitToken(16 /* CloseBraceToken */, node.statements.end);
	            }
	            function emitEmbeddedStatement(node) {
	                if (node.kind === 195 /* Block */) {
	                    write(" ");
	                    emit(node);
	                }
	                else {
	                    increaseIndent();
	                    writeLine();
	                    emit(node);
	                    decreaseIndent();
	                }
	            }
	            function emitExpressionStatement(node) {
	                emitParenthesizedIf(node.expression, /*parenthesized*/ node.expression.kind === 177 /* ArrowFunction */);
	                write(";");
	            }
	            function emitIfStatement(node) {
	                var endPos = emitToken(88 /* IfKeyword */, node.pos);
	                write(" ");
	                endPos = emitToken(17 /* OpenParenToken */, endPos);
	                emit(node.expression);
	                emitToken(18 /* CloseParenToken */, node.expression.end);
	                emitEmbeddedStatement(node.thenStatement);
	                if (node.elseStatement) {
	                    writeLine();
	                    emitToken(80 /* ElseKeyword */, node.thenStatement.end);
	                    if (node.elseStatement.kind === 199 /* IfStatement */) {
	                        write(" ");
	                        emit(node.elseStatement);
	                    }
	                    else {
	                        emitEmbeddedStatement(node.elseStatement);
	                    }
	                }
	            }
	            function emitDoStatement(node) {
	                emitLoop(node, emitDoStatementWorker);
	            }
	            function emitDoStatementWorker(node, loop) {
	                write("do");
	                if (loop) {
	                    emitConvertedLoopCall(loop, /*emitAsBlock*/ true);
	                }
	                else {
	                    emitNormalLoopBody(node, /*emitAsEmbeddedStatement*/ true);
	                }
	                if (node.statement.kind === 195 /* Block */) {
	                    write(" ");
	                }
	                else {
	                    writeLine();
	                }
	                write("while (");
	                emit(node.expression);
	                write(");");
	            }
	            function emitWhileStatement(node) {
	                emitLoop(node, emitWhileStatementWorker);
	            }
	            function emitWhileStatementWorker(node, loop) {
	                write("while (");
	                emit(node.expression);
	                write(")");
	                if (loop) {
	                    emitConvertedLoopCall(loop, /*emitAsBlock*/ true);
	                }
	                else {
	                    emitNormalLoopBody(node, /*emitAsEmbeddedStatement*/ true);
	                }
	            }
	            /**
	             * Returns true if start of variable declaration list was emitted.
	             * Returns false if nothing was written - this can happen for source file level variable declarations
	             *     in system modules where such variable declarations are hoisted.
	             */
	            function tryEmitStartOfVariableDeclarationList(decl) {
	                if (shouldHoistVariable(decl, /*checkIfSourceFileLevelDecl*/ true)) {
	                    // variables in variable declaration list were already hoisted
	                    return false;
	                }
	                if (convertedLoopState && (ts.getCombinedNodeFlags(decl) & 24576 /* BlockScoped */) === 0) {
	                    // we are inside a converted loop - this can only happen in downlevel scenarios
	                    // record names for all variable declarations
	                    for (var _a = 0, _b = decl.declarations; _a < _b.length; _a++) {
	                        var varDecl = _b[_a];
	                        hoistVariableDeclarationFromLoop(convertedLoopState, varDecl);
	                    }
	                    return false;
	                }
	                emitStart(decl);
	                if (decl && languageVersion >= 2 /* ES6 */) {
	                    if (ts.isLet(decl)) {
	                        write("let ");
	                    }
	                    else if (ts.isConst(decl)) {
	                        write("const ");
	                    }
	                    else {
	                        write("var ");
	                    }
	                }
	                else {
	                    write("var ");
	                }
	                // Note here we specifically dont emit end so that if we are going to emit binding pattern
	                // we can alter the source map correctly
	                return true;
	            }
	            function emitVariableDeclarationListSkippingUninitializedEntries(list) {
	                var started = false;
	                for (var _a = 0, _b = list.declarations; _a < _b.length; _a++) {
	                    var decl = _b[_a];
	                    if (!decl.initializer) {
	                        continue;
	                    }
	                    if (!started) {
	                        started = true;
	                    }
	                    else {
	                        write(", ");
	                    }
	                    emit(decl);
	                }
	                return started;
	            }
	            function shouldConvertLoopBody(node) {
	                return languageVersion < 2 /* ES6 */ &&
	                    (resolver.getNodeCheckFlags(node) & 65536 /* LoopWithCapturedBlockScopedBinding */) !== 0;
	            }
	            function emitLoop(node, loopEmitter) {
	                var shouldConvert = shouldConvertLoopBody(node);
	                if (!shouldConvert) {
	                    loopEmitter(node, /* convertedLoop*/ undefined);
	                }
	                else {
	                    var loop = convertLoopBody(node);
	                    if (node.parent.kind === 210 /* LabeledStatement */) {
	                        // if parent of the loop was labeled statement - attach the label to loop skipping converted loop body
	                        emitLabelAndColon(node.parent);
	                    }
	                    loopEmitter(node, loop);
	                }
	            }
	            function convertLoopBody(node) {
	                var functionName = makeUniqueName("_loop");
	                var loopInitializer;
	                switch (node.kind) {
	                    case 202 /* ForStatement */:
	                    case 203 /* ForInStatement */:
	                    case 204 /* ForOfStatement */:
	                        var initializer = node.initializer;
	                        if (initializer && initializer.kind === 215 /* VariableDeclarationList */) {
	                            loopInitializer = node.initializer;
	                        }
	                        break;
	                }
	                var loopParameters;
	                var loopOutParameters;
	                if (loopInitializer && (ts.getCombinedNodeFlags(loopInitializer) & 24576 /* BlockScoped */)) {
	                    // if loop initializer contains block scoped variables - they should be passed to converted loop body as parameters
	                    loopParameters = [];
	                    for (var _a = 0, _b = loopInitializer.declarations; _a < _b.length; _a++) {
	                        var varDeclaration = _b[_a];
	                        processVariableDeclaration(varDeclaration.name);
	                    }
	                }
	                var bodyIsBlock = node.statement.kind === 195 /* Block */;
	                var paramList = loopParameters ? loopParameters.join(", ") : "";
	                writeLine();
	                write("var " + functionName + " = function(" + paramList + ")");
	                var convertedOuterLoopState = convertedLoopState;
	                convertedLoopState = { loopOutParameters: loopOutParameters };
	                if (convertedOuterLoopState) {
	                    // convertedOuterLoopState !== undefined means that this converted loop is nested in another converted loop.
	                    // if outer converted loop has already accumulated some state - pass it through
	                    if (convertedOuterLoopState.argumentsName) {
	                        // outer loop has already used 'arguments' so we've already have some name to alias it
	                        // use the same name in all nested loops
	                        convertedLoopState.argumentsName = convertedOuterLoopState.argumentsName;
	                    }
	                    if (convertedOuterLoopState.thisName) {
	                        // outer loop has already used 'this' so we've already have some name to alias it
	                        // use the same name in all nested loops
	                        convertedLoopState.thisName = convertedOuterLoopState.thisName;
	                    }
	                    if (convertedOuterLoopState.hoistedLocalVariables) {
	                        // we've already collected some non-block scoped variable declarations in enclosing loop
	                        // use the same storage in nested loop
	                        convertedLoopState.hoistedLocalVariables = convertedOuterLoopState.hoistedLocalVariables;
	                    }
	                }
	                write(" {");
	                writeLine();
	                increaseIndent();
	                if (bodyIsBlock) {
	                    emitLines(node.statement.statements);
	                }
	                else {
	                    emit(node.statement);
	                }
	                writeLine();
	                // end of loop body -> copy out parameter
	                copyLoopOutParameters(convertedLoopState, 1 /* ToOutParameter */, /*emitAsStatements*/ true);
	                decreaseIndent();
	                writeLine();
	                write("};");
	                writeLine();
	                if (loopOutParameters) {
	                    // declare variables to hold out params for loop body
	                    write("var ");
	                    for (var i = 0; i < loopOutParameters.length; i++) {
	                        if (i !== 0) {
	                            write(", ");
	                        }
	                        write(loopOutParameters[i].outParamName);
	                    }
	                    write(";");
	                    writeLine();
	                }
	                if (convertedLoopState.argumentsName) {
	                    // if alias for arguments is set
	                    if (convertedOuterLoopState) {
	                        // pass it to outer converted loop
	                        convertedOuterLoopState.argumentsName = convertedLoopState.argumentsName;
	                    }
	                    else {
	                        // this is top level converted loop and we need to create an alias for 'arguments' object
	                        write("var " + convertedLoopState.argumentsName + " = arguments;");
	                        writeLine();
	                    }
	                }
	                if (convertedLoopState.thisName) {
	                    // if alias for this is set
	                    if (convertedOuterLoopState) {
	                        // pass it to outer converted loop
	                        convertedOuterLoopState.thisName = convertedLoopState.thisName;
	                    }
	                    else {
	                        // this is top level converted loop so we need to create an alias for 'this' here
	                        // NOTE:
	                        // if converted loops were all nested in arrow function then we'll always emit '_this' so convertedLoopState.thisName will not be set.
	                        // If it is set this means that all nested loops are not nested in arrow function and it is safe to capture 'this'.
	                        write("var " + convertedLoopState.thisName + " = this;");
	                        writeLine();
	                    }
	                }
	                if (convertedLoopState.hoistedLocalVariables) {
	                    // if hoistedLocalVariables !== undefined this means that we've possibly collected some variable declarations to be hoisted later
	                    if (convertedOuterLoopState) {
	                        // pass them to outer converted loop
	                        convertedOuterLoopState.hoistedLocalVariables = convertedLoopState.hoistedLocalVariables;
	                    }
	                    else {
	                        // deduplicate and hoist collected variable declarations
	                        write("var ");
	                        var seen = void 0;
	                        for (var _c = 0, _d = convertedLoopState.hoistedLocalVariables; _c < _d.length; _c++) {
	                            var id = _d[_c];
	                            // Don't initialize seen unless we have at least one element.
	                            // Emit a comma to separate for all but the first element.
	                            if (!seen) {
	                                seen = {};
	                            }
	                            else {
	                                write(", ");
	                            }
	                            if (!ts.hasProperty(seen, id.text)) {
	                                emit(id);
	                                seen[id.text] = id.text;
	                            }
	                        }
	                        write(";");
	                        writeLine();
	                    }
	                }
	                var currentLoopState = convertedLoopState;
	                convertedLoopState = convertedOuterLoopState;
	                return { functionName: functionName, paramList: paramList, state: currentLoopState };
	                function processVariableDeclaration(name) {
	                    if (name.kind === 69 /* Identifier */) {
	                        var nameText = isNameOfNestedBlockScopedRedeclarationOrCapturedBinding(name)
	                            ? getGeneratedNameForNode(name)
	                            : name.text;
	                        loopParameters.push(nameText);
	                        if (resolver.getNodeCheckFlags(name.parent) & 2097152 /* NeedsLoopOutParameter */) {
	                            var reassignedVariable = { originalName: name, outParamName: makeUniqueName("out_" + nameText) };
	                            (loopOutParameters || (loopOutParameters = [])).push(reassignedVariable);
	                        }
	                    }
	                    else {
	                        for (var _a = 0, _b = name.elements; _a < _b.length; _a++) {
	                            var element = _b[_a];
	                            processVariableDeclaration(element.name);
	                        }
	                    }
	                }
	            }
	            function emitNormalLoopBody(node, emitAsEmbeddedStatement) {
	                var saveAllowedNonLabeledJumps;
	                if (convertedLoopState) {
	                    // we get here if we are trying to emit normal loop loop inside converted loop
	                    // set allowedNonLabeledJumps to Break | Continue to mark that break\continue inside the loop should be emitted as is
	                    saveAllowedNonLabeledJumps = convertedLoopState.allowedNonLabeledJumps;
	                    convertedLoopState.allowedNonLabeledJumps = 2 /* Break */ | 4 /* Continue */;
	                }
	                if (emitAsEmbeddedStatement) {
	                    emitEmbeddedStatement(node.statement);
	                }
	                else if (node.statement.kind === 195 /* Block */) {
	                    emitLines(node.statement.statements);
	                }
	                else {
	                    writeLine();
	                    emit(node.statement);
	                }
	                if (convertedLoopState) {
	                    convertedLoopState.allowedNonLabeledJumps = saveAllowedNonLabeledJumps;
	                }
	            }
	            function copyLoopOutParameters(state, copyDirection, emitAsStatements) {
	                if (state.loopOutParameters) {
	                    for (var _a = 0, _b = state.loopOutParameters; _a < _b.length; _a++) {
	                        var outParam = _b[_a];
	                        if (copyDirection === 0 /* ToOriginal */) {
	                            emitIdentifier(outParam.originalName);
	                            write(" = " + outParam.outParamName);
	                        }
	                        else {
	                            write(outParam.outParamName + " = ");
	                            emitIdentifier(outParam.originalName);
	                        }
	                        if (emitAsStatements) {
	                            write(";");
	                            writeLine();
	                        }
	                        else {
	                            write(", ");
	                        }
	                    }
	                }
	            }
	            function emitConvertedLoopCall(loop, emitAsBlock) {
	                if (emitAsBlock) {
	                    write(" {");
	                    writeLine();
	                    increaseIndent();
	                }
	                // loop is considered simple if it does not have any return statements or break\continue that transfer control outside of the loop
	                // simple loops are emitted as just 'loop()';
	                var isSimpleLoop = !loop.state.nonLocalJumps &&
	                    !loop.state.labeledNonLocalBreaks &&
	                    !loop.state.labeledNonLocalContinues;
	                var loopResult = makeUniqueName("state");
	                if (!isSimpleLoop) {
	                    write("var " + loopResult + " = ");
	                }
	                write(loop.functionName + "(" + loop.paramList + ");");
	                writeLine();
	                copyLoopOutParameters(loop.state, 0 /* ToOriginal */, /*emitAsStatements*/ true);
	                if (!isSimpleLoop) {
	                    // for non simple loops we need to store result returned from converted loop function and use it to do dispatching
	                    // converted loop function can return:
	                    // - object - used when body of the converted loop contains return statement. Property "value" of this object stores retuned value
	                    // - string - used to dispatch jumps. "break" and "continue" are used to non-labeled jumps, other values are used to transfer control to
	                    //   different labels
	                    writeLine();
	                    if (loop.state.nonLocalJumps & 8 /* Return */) {
	                        write("if (typeof " + loopResult + " === \"object\") ");
	                        if (convertedLoopState) {
	                            // we are currently nested in another converted loop - return unwrapped result
	                            write("return " + loopResult + ";");
	                            // propagate 'hasReturn' flag to outer loop
	                            convertedLoopState.nonLocalJumps |= 8 /* Return */;
	                        }
	                        else {
	                            // top level converted loop - return unwrapped value
	                            write("return " + loopResult + ".value;");
	                        }
	                        writeLine();
	                    }
	                    if (loop.state.nonLocalJumps & 2 /* Break */) {
	                        write("if (" + loopResult + " === \"break\") break;");
	                        writeLine();
	                    }
	                    if (loop.state.nonLocalJumps & 4 /* Continue */) {
	                        write("if (" + loopResult + " === \"continue\") continue;");
	                        writeLine();
	                    }
	                    // in case of labeled breaks emit code that either breaks to some known label inside outer loop or delegates jump decision to outer loop
	                    emitDispatchTableForLabeledJumps(loopResult, loop.state, convertedLoopState);
	                }
	                if (emitAsBlock) {
	                    writeLine();
	                    decreaseIndent();
	                    write("}");
	                }
	                function emitDispatchTableForLabeledJumps(loopResultVariable, currentLoop, outerLoop) {
	                    if (!currentLoop.labeledNonLocalBreaks && !currentLoop.labeledNonLocalContinues) {
	                        return;
	                    }
	                    write("switch(" + loopResultVariable + ") {");
	                    increaseIndent();
	                    emitDispatchEntriesForLabeledJumps(currentLoop.labeledNonLocalBreaks, /*isBreak*/ true, loopResultVariable, outerLoop);
	                    emitDispatchEntriesForLabeledJumps(currentLoop.labeledNonLocalContinues, /*isBreak*/ false, loopResultVariable, outerLoop);
	                    decreaseIndent();
	                    writeLine();
	                    write("}");
	                }
	                function emitDispatchEntriesForLabeledJumps(table, isBreak, loopResultVariable, outerLoop) {
	                    if (!table) {
	                        return;
	                    }
	                    for (var labelText in table) {
	                        var labelMarker = table[labelText];
	                        writeLine();
	                        write("case \"" + labelMarker + "\": ");
	                        // if there are no outer converted loop or outer label in question is located inside outer converted loop
	                        // then emit labeled break\continue
	                        // otherwise propagate pair 'label -> marker' to outer converted loop and emit 'return labelMarker' so outer loop can later decide what to do
	                        if (!outerLoop || (outerLoop.labels && outerLoop.labels[labelText])) {
	                            if (isBreak) {
	                                write("break ");
	                            }
	                            else {
	                                write("continue ");
	                            }
	                            write(labelText + ";");
	                        }
	                        else {
	                            setLabeledJump(outerLoop, isBreak, labelText, labelMarker);
	                            write("return " + loopResultVariable + ";");
	                        }
	                    }
	                }
	            }
	            function emitForStatement(node) {
	                emitLoop(node, emitForStatementWorker);
	            }
	            function emitForStatementWorker(node, loop) {
	                var endPos = emitToken(86 /* ForKeyword */, node.pos);
	                write(" ");
	                endPos = emitToken(17 /* OpenParenToken */, endPos);
	                if (node.initializer && node.initializer.kind === 215 /* VariableDeclarationList */) {
	                    var variableDeclarationList = node.initializer;
	                    var startIsEmitted = tryEmitStartOfVariableDeclarationList(variableDeclarationList);
	                    if (startIsEmitted) {
	                        emitCommaList(variableDeclarationList.declarations);
	                    }
	                    else {
	                        emitVariableDeclarationListSkippingUninitializedEntries(variableDeclarationList);
	                    }
	                }
	                else if (node.initializer) {
	                    emit(node.initializer);
	                }
	                write(";");
	                emitOptional(" ", node.condition);
	                write(";");
	                emitOptional(" ", node.incrementor);
	                write(")");
	                if (loop) {
	                    emitConvertedLoopCall(loop, /*emitAsBlock*/ true);
	                }
	                else {
	                    emitNormalLoopBody(node, /*emitAsEmbeddedStatement*/ true);
	                }
	            }
	            function emitForInOrForOfStatement(node) {
	                if (languageVersion < 2 /* ES6 */ && node.kind === 204 /* ForOfStatement */) {
	                    emitLoop(node, emitDownLevelForOfStatementWorker);
	                }
	                else {
	                    emitLoop(node, emitForInOrForOfStatementWorker);
	                }
	            }
	            function emitForInOrForOfStatementWorker(node, loop) {
	                var endPos = emitToken(86 /* ForKeyword */, node.pos);
	                write(" ");
	                endPos = emitToken(17 /* OpenParenToken */, endPos);
	                if (node.initializer.kind === 215 /* VariableDeclarationList */) {
	                    var variableDeclarationList = node.initializer;
	                    if (variableDeclarationList.declarations.length >= 1) {
	                        tryEmitStartOfVariableDeclarationList(variableDeclarationList);
	                        emit(variableDeclarationList.declarations[0]);
	                    }
	                }
	                else {
	                    emit(node.initializer);
	                }
	                if (node.kind === 203 /* ForInStatement */) {
	                    write(" in ");
	                }
	                else {
	                    write(" of ");
	                }
	                emit(node.expression);
	                emitToken(18 /* CloseParenToken */, node.expression.end);
	                if (loop) {
	                    emitConvertedLoopCall(loop, /*emitAsBlock*/ true);
	                }
	                else {
	                    emitNormalLoopBody(node, /*emitAsEmbeddedStatement*/ true);
	                }
	            }
	            function emitDownLevelForOfStatementWorker(node, loop) {
	                // The following ES6 code:
	                //
	                //    for (let v of expr) { }
	                //
	                // should be emitted as
	                //
	                //    for (let _i = 0, _a = expr; _i < _a.length; _i++) {
	                //        let v = _a[_i];
	                //    }
	                //
	                // where _a and _i are temps emitted to capture the RHS and the counter,
	                // respectively.
	                // When the left hand side is an expression instead of a let declaration,
	                // the "let v" is not emitted.
	                // When the left hand side is a let/const, the v is renamed if there is
	                // another v in scope.
	                // Note that all assignments to the LHS are emitted in the body, including
	                // all destructuring.
	                // Note also that because an extra statement is needed to assign to the LHS,
	                // for-of bodies are always emitted as blocks.
	                var endPos = emitToken(86 /* ForKeyword */, node.pos);
	                write(" ");
	                endPos = emitToken(17 /* OpenParenToken */, endPos);
	                // Do not emit the LHS let declaration yet, because it might contain destructuring.
	                // Do not call recordTempDeclaration because we are declaring the temps
	                // right here. Recording means they will be declared later.
	                // In the case where the user wrote an identifier as the RHS, like this:
	                //
	                //     for (let v of arr) { }
	                //
	                // we can't reuse 'arr' because it might be modified within the body of the loop.
	                var counter = createTempVariable(268435456 /* _i */);
	                var rhsReference = ts.createSynthesizedNode(69 /* Identifier */);
	                rhsReference.text = node.expression.kind === 69 /* Identifier */ ?
	                    makeUniqueName(node.expression.text) :
	                    makeTempVariableName(0 /* Auto */);
	                // This is the let keyword for the counter and rhsReference. The let keyword for
	                // the LHS will be emitted inside the body.
	                emitStart(node.expression);
	                write("var ");
	                // _i = 0
	                emitNodeWithoutSourceMap(counter);
	                write(" = 0");
	                emitEnd(node.expression);
	                // , _a = expr
	                write(", ");
	                emitStart(node.expression);
	                emitNodeWithoutSourceMap(rhsReference);
	                write(" = ");
	                emitNodeWithoutSourceMap(node.expression);
	                emitEnd(node.expression);
	                write("; ");
	                // _i < _a.length;
	                emitStart(node.expression);
	                emitNodeWithoutSourceMap(counter);
	                write(" < ");
	                emitNodeWithCommentsAndWithoutSourcemap(rhsReference);
	                write(".length");
	                emitEnd(node.expression);
	                write("; ");
	                // _i++)
	                emitStart(node.expression);
	                emitNodeWithoutSourceMap(counter);
	                write("++");
	                emitEnd(node.expression);
	                emitToken(18 /* CloseParenToken */, node.expression.end);
	                // Body
	                write(" {");
	                writeLine();
	                increaseIndent();
	                // Initialize LHS
	                // let v = _a[_i];
	                var rhsIterationValue = createElementAccessExpression(rhsReference, counter);
	                emitStart(node.initializer);
	                if (node.initializer.kind === 215 /* VariableDeclarationList */) {
	                    write("var ");
	                    var variableDeclarationList = node.initializer;
	                    if (variableDeclarationList.declarations.length > 0) {
	                        var declaration = variableDeclarationList.declarations[0];
	                        if (ts.isBindingPattern(declaration.name)) {
	                            // This works whether the declaration is a var, let, or const.
	                            // It will use rhsIterationValue _a[_i] as the initializer.
	                            emitDestructuring(declaration, /*isAssignmentExpressionStatement*/ false, rhsIterationValue);
	                        }
	                        else {
	                            // The following call does not include the initializer, so we have
	                            // to emit it separately.
	                            emitNodeWithCommentsAndWithoutSourcemap(declaration);
	                            write(" = ");
	                            emitNodeWithoutSourceMap(rhsIterationValue);
	                        }
	                    }
	                    else {
	                        // It's an empty declaration list. This can only happen in an error case, if the user wrote
	                        //     for (let of []) {}
	                        emitNodeWithoutSourceMap(createTempVariable(0 /* Auto */));
	                        write(" = ");
	                        emitNodeWithoutSourceMap(rhsIterationValue);
	                    }
	                }
	                else {
	                    // Initializer is an expression. Emit the expression in the body, so that it's
	                    // evaluated on every iteration.
	                    var assignmentExpression = createBinaryExpression(node.initializer, 56 /* EqualsToken */, rhsIterationValue, /*startsOnNewLine*/ false);
	                    if (node.initializer.kind === 167 /* ArrayLiteralExpression */ || node.initializer.kind === 168 /* ObjectLiteralExpression */) {
	                        // This is a destructuring pattern, so call emitDestructuring instead of emit. Calling emit will not work, because it will cause
	                        // the BinaryExpression to be passed in instead of the expression statement, which will cause emitDestructuring to crash.
	                        emitDestructuring(assignmentExpression, /*isAssignmentExpressionStatement*/ true, /*value*/ undefined);
	                    }
	                    else {
	                        emitNodeWithCommentsAndWithoutSourcemap(assignmentExpression);
	                    }
	                }
	                emitEnd(node.initializer);
	                write(";");
	                if (loop) {
	                    writeLine();
	                    emitConvertedLoopCall(loop, /*emitAsBlock*/ false);
	                }
	                else {
	                    emitNormalLoopBody(node, /*emitAsEmbeddedStatement*/ false);
	                }
	                writeLine();
	                decreaseIndent();
	                write("}");
	            }
	            function emitBreakOrContinueStatement(node) {
	                if (convertedLoopState) {
	                    // check if we can emit break\continue as is
	                    // it is possible if either
	                    //   - break\continue is statement labeled and label is located inside the converted loop
	                    //   - break\continue is non-labeled and located in non-converted loop\switch statement
	                    var jump = node.kind === 206 /* BreakStatement */ ? 2 /* Break */ : 4 /* Continue */;
	                    var canUseBreakOrContinue = (node.label && convertedLoopState.labels && convertedLoopState.labels[node.label.text]) ||
	                        (!node.label && (convertedLoopState.allowedNonLabeledJumps & jump));
	                    if (!canUseBreakOrContinue) {
	                        write("return ");
	                        // explicit exit from loop -> copy out parameters
	                        copyLoopOutParameters(convertedLoopState, 1 /* ToOutParameter */, /*emitAsStatements*/ false);
	                        if (!node.label) {
	                            if (node.kind === 206 /* BreakStatement */) {
	                                convertedLoopState.nonLocalJumps |= 2 /* Break */;
	                                write("\"break\";");
	                            }
	                            else {
	                                convertedLoopState.nonLocalJumps |= 4 /* Continue */;
	                                write("\"continue\";");
	                            }
	                        }
	                        else {
	                            var labelMarker = void 0;
	                            if (node.kind === 206 /* BreakStatement */) {
	                                labelMarker = "break-" + node.label.text;
	                                setLabeledJump(convertedLoopState, /*isBreak*/ true, node.label.text, labelMarker);
	                            }
	                            else {
	                                labelMarker = "continue-" + node.label.text;
	                                setLabeledJump(convertedLoopState, /*isBreak*/ false, node.label.text, labelMarker);
	                            }
	                            write("\"" + labelMarker + "\";");
	                        }
	                        return;
	                    }
	                }
	                emitToken(node.kind === 206 /* BreakStatement */ ? 70 /* BreakKeyword */ : 75 /* ContinueKeyword */, node.pos);
	                emitOptional(" ", node.label);
	                write(";");
	            }
	            function emitReturnStatement(node) {
	                if (convertedLoopState) {
	                    convertedLoopState.nonLocalJumps |= 8 /* Return */;
	                    write("return { value: ");
	                    if (node.expression) {
	                        emit(node.expression);
	                    }
	                    else {
	                        write("void 0");
	                    }
	                    write(" };");
	                    return;
	                }
	                emitToken(94 /* ReturnKeyword */, node.pos);
	                emitOptional(" ", node.expression);
	                write(";");
	            }
	            function emitWithStatement(node) {
	                write("with (");
	                emit(node.expression);
	                write(")");
	                emitEmbeddedStatement(node.statement);
	            }
	            function emitSwitchStatement(node) {
	                var endPos = emitToken(96 /* SwitchKeyword */, node.pos);
	                write(" ");
	                emitToken(17 /* OpenParenToken */, endPos);
	                emit(node.expression);
	                endPos = emitToken(18 /* CloseParenToken */, node.expression.end);
	                write(" ");
	                var saveAllowedNonLabeledJumps;
	                if (convertedLoopState) {
	                    saveAllowedNonLabeledJumps = convertedLoopState.allowedNonLabeledJumps;
	                    // for switch statement allow only non-labeled break
	                    convertedLoopState.allowedNonLabeledJumps |= 2 /* Break */;
	                }
	                emitCaseBlock(node.caseBlock, endPos);
	                if (convertedLoopState) {
	                    convertedLoopState.allowedNonLabeledJumps = saveAllowedNonLabeledJumps;
	                }
	            }
	            function emitCaseBlock(node, startPos) {
	                emitToken(15 /* OpenBraceToken */, startPos);
	                increaseIndent();
	                emitLines(node.clauses);
	                decreaseIndent();
	                writeLine();
	                emitToken(16 /* CloseBraceToken */, node.clauses.end);
	            }
	            function nodeStartPositionsAreOnSameLine(node1, node2) {
	                return ts.getLineOfLocalPositionFromLineMap(currentLineMap, ts.skipTrivia(currentText, node1.pos)) ===
	                    ts.getLineOfLocalPositionFromLineMap(currentLineMap, ts.skipTrivia(currentText, node2.pos));
	            }
	            function nodeEndPositionsAreOnSameLine(node1, node2) {
	                return ts.getLineOfLocalPositionFromLineMap(currentLineMap, node1.end) ===
	                    ts.getLineOfLocalPositionFromLineMap(currentLineMap, node2.end);
	            }
	            function nodeEndIsOnSameLineAsNodeStart(node1, node2) {
	                return ts.getLineOfLocalPositionFromLineMap(currentLineMap, node1.end) ===
	                    ts.getLineOfLocalPositionFromLineMap(currentLineMap, ts.skipTrivia(currentText, node2.pos));
	            }
	            function emitCaseOrDefaultClause(node) {
	                if (node.kind === 244 /* CaseClause */) {
	                    write("case ");
	                    emit(node.expression);
	                    write(":");
	                }
	                else {
	                    write("default:");
	                }
	                if (node.statements.length === 1 && nodeStartPositionsAreOnSameLine(node, node.statements[0])) {
	                    write(" ");
	                    emit(node.statements[0]);
	                }
	                else {
	                    increaseIndent();
	                    emitLines(node.statements);
	                    decreaseIndent();
	                }
	            }
	            function emitThrowStatement(node) {
	                write("throw ");
	                emit(node.expression);
	                write(";");
	            }
	            function emitTryStatement(node) {
	                write("try ");
	                emit(node.tryBlock);
	                emit(node.catchClause);
	                if (node.finallyBlock) {
	                    writeLine();
	                    write("finally ");
	                    emit(node.finallyBlock);
	                }
	            }
	            function emitCatchClause(node) {
	                writeLine();
	                var endPos = emitToken(72 /* CatchKeyword */, node.pos);
	                write(" ");
	                emitToken(17 /* OpenParenToken */, endPos);
	                emit(node.variableDeclaration);
	                emitToken(18 /* CloseParenToken */, node.variableDeclaration ? node.variableDeclaration.end : endPos);
	                write(" ");
	                emitBlock(node.block);
	            }
	            function emitDebuggerStatement(node) {
	                emitToken(76 /* DebuggerKeyword */, node.pos);
	                write(";");
	            }
	            function emitLabelAndColon(node) {
	                emit(node.label);
	                write(": ");
	            }
	            function emitLabeledStatement(node) {
	                if (!ts.isIterationStatement(node.statement, /* lookInLabeledStatements */ false) || !shouldConvertLoopBody(node.statement)) {
	                    emitLabelAndColon(node);
	                }
	                if (convertedLoopState) {
	                    if (!convertedLoopState.labels) {
	                        convertedLoopState.labels = {};
	                    }
	                    convertedLoopState.labels[node.label.text] = node.label.text;
	                }
	                emit(node.statement);
	                if (convertedLoopState) {
	                    convertedLoopState.labels[node.label.text] = undefined;
	                }
	            }
	            function getContainingModule(node) {
	                do {
	                    node = node.parent;
	                } while (node && node.kind !== 221 /* ModuleDeclaration */);
	                return node;
	            }
	            function emitContainingModuleName(node) {
	                var container = getContainingModule(node);
	                write(container ? getGeneratedNameForNode(container) : "exports");
	            }
	            function emitModuleMemberName(node) {
	                emitStart(node.name);
	                if (ts.getCombinedNodeFlags(node) & 2 /* Export */) {
	                    var container = getContainingModule(node);
	                    if (container) {
	                        write(getGeneratedNameForNode(container));
	                        write(".");
	                    }
	                    else if (modulekind !== 5 /* ES6 */ && modulekind !== 4 /* System */) {
	                        write("exports.");
	                    }
	                }
	                emitNodeWithCommentsAndWithoutSourcemap(node.name);
	                emitEnd(node.name);
	            }
	            function createVoidZero() {
	                var zero = ts.createSynthesizedNode(8 /* NumericLiteral */);
	                zero.text = "0";
	                var result = ts.createSynthesizedNode(180 /* VoidExpression */);
	                result.expression = zero;
	                return result;
	            }
	            function emitEs6ExportDefaultCompat(node) {
	                if (node.parent.kind === 251 /* SourceFile */) {
	                    ts.Debug.assert(!!(node.flags & 512 /* Default */) || node.kind === 230 /* ExportAssignment */);
	                    // only allow export default at a source file level
	                    if (modulekind === 1 /* CommonJS */ || modulekind === 2 /* AMD */ || modulekind === 3 /* UMD */) {
	                        if (!isEs6Module) {
	                            if (languageVersion !== 0 /* ES3 */) {
	                                // default value of configurable, enumerable, writable are `false`.
	                                write("Object.defineProperty(exports, \"__esModule\", { value: true });");
	                                writeLine();
	                            }
	                            else {
	                                write("exports.__esModule = true;");
	                                writeLine();
	                            }
	                        }
	                    }
	                }
	            }
	            function emitExportMemberAssignment(node) {
	                if (node.flags & 2 /* Export */) {
	                    writeLine();
	                    emitStart(node);
	                    // emit call to exporter only for top level nodes
	                    if (modulekind === 4 /* System */ && node.parent === currentSourceFile) {
	                        // emit export default <smth> as
	                        // export("default", <smth>)
	                        write(exportFunctionForFile + "(\"");
	                        if (node.flags & 512 /* Default */) {
	                            write("default");
	                        }
	                        else {
	                            emitNodeWithCommentsAndWithoutSourcemap(node.name);
	                        }
	                        write("\", ");
	                        emitDeclarationName(node);
	                        write(")");
	                    }
	                    else {
	                        if (node.flags & 512 /* Default */) {
	                            emitEs6ExportDefaultCompat(node);
	                            if (languageVersion === 0 /* ES3 */) {
	                                write("exports[\"default\"]");
	                            }
	                            else {
	                                write("exports.default");
	                            }
	                        }
	                        else {
	                            emitModuleMemberName(node);
	                        }
	                        write(" = ");
	                        emitDeclarationName(node);
	                    }
	                    emitEnd(node);
	                    write(";");
	                }
	            }
	            function emitExportMemberAssignments(name) {
	                if (modulekind === 4 /* System */) {
	                    return;
	                }
	                if (!exportEquals && exportSpecifiers && ts.hasProperty(exportSpecifiers, name.text)) {
	                    for (var _a = 0, _b = exportSpecifiers[name.text]; _a < _b.length; _a++) {
	                        var specifier = _b[_a];
	                        writeLine();
	                        emitStart(specifier.name);
	                        emitContainingModuleName(specifier);
	                        write(".");
	                        emitNodeWithCommentsAndWithoutSourcemap(specifier.name);
	                        emitEnd(specifier.name);
	                        write(" = ");
	                        emitExpressionIdentifier(name);
	                        write(";");
	                    }
	                }
	            }
	            function emitExportSpecifierInSystemModule(specifier) {
	                ts.Debug.assert(modulekind === 4 /* System */);
	                if (!resolver.getReferencedValueDeclaration(specifier.propertyName || specifier.name) && !resolver.isValueAliasDeclaration(specifier)) {
	                    return;
	                }
	                writeLine();
	                emitStart(specifier.name);
	                write(exportFunctionForFile + "(\"");
	                emitNodeWithCommentsAndWithoutSourcemap(specifier.name);
	                write("\", ");
	                emitExpressionIdentifier(specifier.propertyName || specifier.name);
	                write(")");
	                emitEnd(specifier.name);
	                write(";");
	            }
	            /**
	             * Emit an assignment to a given identifier, 'name', with a given expression, 'value'.
	             * @param name an identifier as a left-hand-side operand of the assignment
	             * @param value an expression as a right-hand-side operand of the assignment
	             * @param shouldEmitCommaBeforeAssignment a boolean indicating whether to prefix an assignment with comma
	             */
	            function emitAssignment(name, value, shouldEmitCommaBeforeAssignment, nodeForSourceMap) {
	                if (shouldEmitCommaBeforeAssignment) {
	                    write(", ");
	                }
	                var exportChanged = isNameOfExportedSourceLevelDeclarationInSystemExternalModule(name);
	                if (exportChanged) {
	                    write(exportFunctionForFile + "(\"");
	                    emitNodeWithCommentsAndWithoutSourcemap(name);
	                    write("\", ");
	                }
	                var isVariableDeclarationOrBindingElement = name.parent && (name.parent.kind === 214 /* VariableDeclaration */ || name.parent.kind === 166 /* BindingElement */);
	                // If this is first var declaration, we need to start at var/let/const keyword instead
	                // otherwise use nodeForSourceMap as the start position
	                emitStart(isFirstVariableDeclaration(nodeForSourceMap) ? nodeForSourceMap.parent : nodeForSourceMap);
	                withTemporaryNoSourceMap(function () {
	                    if (isVariableDeclarationOrBindingElement) {
	                        emitModuleMemberName(name.parent);
	                    }
	                    else {
	                        emit(name);
	                    }
	                    write(" = ");
	                    emit(value);
	                });
	                emitEnd(nodeForSourceMap, /*stopOverridingSpan*/ true);
	                if (exportChanged) {
	                    write(")");
	                }
	            }
	            /**
	             * Create temporary variable, emit an assignment of the variable the given expression
	             * @param expression an expression to assign to the newly created temporary variable
	             * @param canDefineTempVariablesInPlace a boolean indicating whether you can define the temporary variable at an assignment location
	             * @param shouldEmitCommaBeforeAssignment a boolean indicating whether an assignment should prefix with comma
	             */
	            function emitTempVariableAssignment(expression, canDefineTempVariablesInPlace, shouldEmitCommaBeforeAssignment, sourceMapNode) {
	                var identifier = createTempVariable(0 /* Auto */);
	                if (!canDefineTempVariablesInPlace) {
	                    recordTempDeclaration(identifier);
	                }
	                emitAssignment(identifier, expression, shouldEmitCommaBeforeAssignment, sourceMapNode || expression.parent);
	                return identifier;
	            }
	            function isFirstVariableDeclaration(root) {
	                return root.kind === 214 /* VariableDeclaration */ &&
	                    root.parent.kind === 215 /* VariableDeclarationList */ &&
	                    root.parent.declarations[0] === root;
	            }
	            function emitDestructuring(root, isAssignmentExpressionStatement, value) {
	                var emitCount = 0;
	                // An exported declaration is actually emitted as an assignment (to a property on the module object), so
	                // temporary variables in an exported declaration need to have real declarations elsewhere
	                // Also temporary variables should be explicitly allocated for source level declarations when module target is system
	                // because actual variable declarations are hoisted
	                var canDefineTempVariablesInPlace = false;
	                if (root.kind === 214 /* VariableDeclaration */) {
	                    var isExported = ts.getCombinedNodeFlags(root) & 2 /* Export */;
	                    var isSourceLevelForSystemModuleKind = shouldHoistDeclarationInSystemJsModule(root);
	                    canDefineTempVariablesInPlace = !isExported && !isSourceLevelForSystemModuleKind;
	                }
	                else if (root.kind === 139 /* Parameter */) {
	                    canDefineTempVariablesInPlace = true;
	                }
	                if (root.kind === 184 /* BinaryExpression */) {
	                    emitAssignmentExpression(root);
	                }
	                else {
	                    ts.Debug.assert(!isAssignmentExpressionStatement);
	                    // If first variable declaration of variable statement correct the start location
	                    if (isFirstVariableDeclaration(root)) {
	                        // Use emit location of "var " as next emit start entry
	                        sourceMap.changeEmitSourcePos();
	                    }
	                    emitBindingElement(root, value);
	                }
	                /**
	                 * Ensures that there exists a declared identifier whose value holds the given expression.
	                 * This function is useful to ensure that the expression's value can be read from in subsequent expressions.
	                 * Unless 'reuseIdentifierExpressions' is false, 'expr' will be returned if it is just an identifier.
	                 *
	                 * @param expr the expression whose value needs to be bound.
	                 * @param reuseIdentifierExpressions true if identifier expressions can simply be returned;
	                 *                                   false if it is necessary to always emit an identifier.
	                 */
	                function ensureIdentifier(expr, reuseIdentifierExpressions, sourceMapNode) {
	                    if (expr.kind === 69 /* Identifier */ && reuseIdentifierExpressions) {
	                        return expr;
	                    }
	                    var identifier = emitTempVariableAssignment(expr, canDefineTempVariablesInPlace, emitCount > 0, sourceMapNode);
	                    emitCount++;
	                    return identifier;
	                }
	                function createDefaultValueCheck(value, defaultValue, sourceMapNode) {
	                    // The value expression will be evaluated twice, so for anything but a simple identifier
	                    // we need to generate a temporary variable
	                    // If the temporary variable needs to be emitted use the source Map node for assignment of that statement
	                    value = ensureIdentifier(value, /*reuseIdentifierExpressions*/ true, sourceMapNode);
	                    // Return the expression 'value === void 0 ? defaultValue : value'
	                    var equals = ts.createSynthesizedNode(184 /* BinaryExpression */);
	                    equals.left = value;
	                    equals.operatorToken = ts.createSynthesizedNode(32 /* EqualsEqualsEqualsToken */);
	                    equals.right = createVoidZero();
	                    return createConditionalExpression(equals, defaultValue, value);
	                }
	                function createConditionalExpression(condition, whenTrue, whenFalse) {
	                    var cond = ts.createSynthesizedNode(185 /* ConditionalExpression */);
	                    cond.condition = condition;
	                    cond.questionToken = ts.createSynthesizedNode(53 /* QuestionToken */);
	                    cond.whenTrue = whenTrue;
	                    cond.colonToken = ts.createSynthesizedNode(54 /* ColonToken */);
	                    cond.whenFalse = whenFalse;
	                    return cond;
	                }
	                function createNumericLiteral(value) {
	                    var node = ts.createSynthesizedNode(8 /* NumericLiteral */);
	                    node.text = "" + value;
	                    return node;
	                }
	                function createPropertyAccessForDestructuringProperty(object, propName) {
	                    var index;
	                    var nameIsComputed = propName.kind === 137 /* ComputedPropertyName */;
	                    if (nameIsComputed) {
	                        // TODO to handle when we look into sourcemaps for computed properties, for now use propName
	                        index = ensureIdentifier(propName.expression, /*reuseIdentifierExpressions*/ false, propName);
	                    }
	                    else {
	                        // We create a synthetic copy of the identifier in order to avoid the rewriting that might
	                        // otherwise occur when the identifier is emitted.
	                        index = ts.createSynthesizedNode(propName.kind);
	                        // We need to unescape identifier here because when parsing an identifier prefixing with "__"
	                        // the parser need to append "_" in order to escape colliding with magic identifiers such as "__proto__"
	                        // Therefore, in order to correctly emit identifiers that are written in original TypeScript file,
	                        // we will unescapeIdentifier to remove additional underscore (if no underscore is added, the function will return original input string)
	                        index.text = ts.unescapeIdentifier(propName.text);
	                    }
	                    return !nameIsComputed && index.kind === 69 /* Identifier */
	                        ? createPropertyAccessExpression(object, index)
	                        : createElementAccessExpression(object, index);
	                }
	                function createSliceCall(value, sliceIndex) {
	                    var call = ts.createSynthesizedNode(171 /* CallExpression */);
	                    var sliceIdentifier = ts.createSynthesizedNode(69 /* Identifier */);
	                    sliceIdentifier.text = "slice";
	                    call.expression = createPropertyAccessExpression(value, sliceIdentifier);
	                    call.arguments = ts.createSynthesizedNodeArray();
	                    call.arguments[0] = createNumericLiteral(sliceIndex);
	                    return call;
	                }
	                function emitObjectLiteralAssignment(target, value, sourceMapNode) {
	                    var properties = target.properties;
	                    if (properties.length !== 1) {
	                        // For anything but a single element destructuring we need to generate a temporary
	                        // to ensure value is evaluated exactly once.
	                        // When doing so we want to hightlight the passed in source map node since thats the one needing this temp assignment
	                        value = ensureIdentifier(value, /*reuseIdentifierExpressions*/ true, sourceMapNode);
	                    }
	                    for (var _a = 0, properties_5 = properties; _a < properties_5.length; _a++) {
	                        var p = properties_5[_a];
	                        if (p.kind === 248 /* PropertyAssignment */ || p.kind === 249 /* ShorthandPropertyAssignment */) {
	                            var propName = p.name;
	                            var target_1 = p.kind === 249 /* ShorthandPropertyAssignment */ ? p : p.initializer || propName;
	                            // Assignment for target = value.propName should highligh whole property, hence use p as source map node
	                            emitDestructuringAssignment(target_1, createPropertyAccessForDestructuringProperty(value, propName), p);
	                        }
	                    }
	                }
	                function emitArrayLiteralAssignment(target, value, sourceMapNode) {
	                    var elements = target.elements;
	                    if (elements.length !== 1) {
	                        // For anything but a single element destructuring we need to generate a temporary
	                        // to ensure value is evaluated exactly once.
	                        // When doing so we want to hightlight the passed in source map node since thats the one needing this temp assignment
	                        value = ensureIdentifier(value, /*reuseIdentifierExpressions*/ true, sourceMapNode);
	                    }
	                    for (var i = 0; i < elements.length; i++) {
	                        var e = elements[i];
	                        if (e.kind !== 190 /* OmittedExpression */) {
	                            // Assignment for target = value.propName should highligh whole property, hence use e as source map node
	                            if (e.kind !== 188 /* SpreadElementExpression */) {
	                                emitDestructuringAssignment(e, createElementAccessExpression(value, createNumericLiteral(i)), e);
	                            }
	                            else if (i === elements.length - 1) {
	                                emitDestructuringAssignment(e.expression, createSliceCall(value, i), e);
	                            }
	                        }
	                    }
	                }
	                function emitDestructuringAssignment(target, value, sourceMapNode) {
	                    // When emitting target = value use source map node to highlight, including any temporary assignments needed for this
	                    if (target.kind === 249 /* ShorthandPropertyAssignment */) {
	                        if (target.objectAssignmentInitializer) {
	                            value = createDefaultValueCheck(value, target.objectAssignmentInitializer, sourceMapNode);
	                        }
	                        target = target.name;
	                    }
	                    else if (target.kind === 184 /* BinaryExpression */ && target.operatorToken.kind === 56 /* EqualsToken */) {
	                        value = createDefaultValueCheck(value, target.right, sourceMapNode);
	                        target = target.left;
	                    }
	                    if (target.kind === 168 /* ObjectLiteralExpression */) {
	                        emitObjectLiteralAssignment(target, value, sourceMapNode);
	                    }
	                    else if (target.kind === 167 /* ArrayLiteralExpression */) {
	                        emitArrayLiteralAssignment(target, value, sourceMapNode);
	                    }
	                    else {
	                        emitAssignment(target, value, /*shouldEmitCommaBeforeAssignment*/ emitCount > 0, sourceMapNode);
	                        emitCount++;
	                    }
	                }
	                function emitAssignmentExpression(root) {
	                    var target = root.left;
	                    var value = root.right;
	                    if (ts.isEmptyObjectLiteralOrArrayLiteral(target)) {
	                        emit(value);
	                    }
	                    else if (isAssignmentExpressionStatement) {
	                        // Source map node for root.left = root.right is root
	                        // but if root is synthetic, which could be in below case, use the target which is { a }
	                        // for ({a} of {a: string}) {
	                        // }
	                        emitDestructuringAssignment(target, value, ts.nodeIsSynthesized(root) ? target : root);
	                    }
	                    else {
	                        if (root.parent.kind !== 175 /* ParenthesizedExpression */) {
	                            write("(");
	                        }
	                        // Temporary assignment needed to emit root should highlight whole binary expression
	                        value = ensureIdentifier(value, /*reuseIdentifierExpressions*/ true, root);
	                        // Source map node for root.left = root.right is root
	                        emitDestructuringAssignment(target, value, root);
	                        write(", ");
	                        emit(value);
	                        if (root.parent.kind !== 175 /* ParenthesizedExpression */) {
	                            write(")");
	                        }
	                    }
	                }
	                function emitBindingElement(target, value) {
	                    // Any temporary assignments needed to emit target = value should point to target
	                    if (target.initializer) {
	                        // Combine value and initializer
	                        value = value ? createDefaultValueCheck(value, target.initializer, target) : target.initializer;
	                    }
	                    else if (!value) {
	                        // Use 'void 0' in absence of value and initializer
	                        value = createVoidZero();
	                    }
	                    if (ts.isBindingPattern(target.name)) {
	                        var pattern = target.name;
	                        var elements = pattern.elements;
	                        var numElements = elements.length;
	                        if (numElements !== 1) {
	                            // For anything other than a single-element destructuring we need to generate a temporary
	                            // to ensure value is evaluated exactly once. Additionally, if we have zero elements
	                            // we need to emit *something* to ensure that in case a 'var' keyword was already emitted,
	                            // so in that case, we'll intentionally create that temporary.
	                            value = ensureIdentifier(value, /*reuseIdentifierExpressions*/ numElements !== 0, target);
	                        }
	                        for (var i = 0; i < numElements; i++) {
	                            var element = elements[i];
	                            if (pattern.kind === 164 /* ObjectBindingPattern */) {
	                                // Rewrite element to a declaration with an initializer that fetches property
	                                var propName = element.propertyName || element.name;
	                                emitBindingElement(element, createPropertyAccessForDestructuringProperty(value, propName));
	                            }
	                            else if (element.kind !== 190 /* OmittedExpression */) {
	                                if (!element.dotDotDotToken) {
	                                    // Rewrite element to a declaration that accesses array element at index i
	                                    emitBindingElement(element, createElementAccessExpression(value, createNumericLiteral(i)));
	                                }
	                                else if (i === numElements - 1) {
	                                    emitBindingElement(element, createSliceCall(value, i));
	                                }
	                            }
	                        }
	                    }
	                    else {
	                        emitAssignment(target.name, value, /*shouldEmitCommaBeforeAssignment*/ emitCount > 0, target);
	                        emitCount++;
	                    }
	                }
	            }
	            function emitVariableDeclaration(node) {
	                if (ts.isBindingPattern(node.name)) {
	                    if (languageVersion < 2 /* ES6 */) {
	                        emitDestructuring(node, /*isAssignmentExpressionStatement*/ false);
	                    }
	                    else {
	                        emit(node.name);
	                        emitOptional(" = ", node.initializer);
	                    }
	                }
	                else {
	                    var initializer = node.initializer;
	                    if (!initializer &&
	                        languageVersion < 2 /* ES6 */ &&
	                        // for names - binding patterns that lack initializer there is no point to emit explicit initializer
	                        // since downlevel codegen for destructuring will fail in the absence of initializer so all binding elements will say uninitialized
	                        node.name.kind === 69 /* Identifier */) {
	                        var container = ts.getEnclosingBlockScopeContainer(node);
	                        var flags = resolver.getNodeCheckFlags(node);
	                        // nested let bindings might need to be initialized explicitly to preserve ES6 semantic
	                        // { let x = 1; }
	                        // { let x; } // x here should be undefined. not 1
	                        // NOTES:
	                        // Top level bindings never collide with anything and thus don't require explicit initialization.
	                        // As for nested let bindings there are two cases:
	                        // - nested let bindings that were not renamed definitely should be initialized explicitly
	                        //   { let x = 1; }
	                        //   { let x; if (some-condition) { x = 1}; if (x) { /*1*/ } }
	                        //   Without explicit initialization code in /*1*/ can be executed even if some-condition is evaluated to false
	                        // - renaming introduces fresh name that should not collide with any existing names, however renamed bindings sometimes also should be
	                        //   explicitly initialized. One particular case: non-captured binding declared inside loop body (but not in loop initializer)
	                        //   let x;
	                        //   for (;;) {
	                        //       let x;
	                        //   }
	                        //   in downlevel codegen inner 'x' will be renamed so it won't collide with outer 'x' however it will should be reset on every iteration
	                        //   as if it was declared anew.
	                        //   * Why non-captured binding - because if loop contains block scoped binding captured in some function then loop body will be rewritten
	                        //   to have a fresh scope on every iteration so everything will just work.
	                        //   * Why loop initializer is excluded - since we've introduced a fresh name it already will be undefined.
	                        var isCapturedInFunction = flags & 131072 /* CapturedBlockScopedBinding */;
	                        var isDeclaredInLoop = flags & 262144 /* BlockScopedBindingInLoop */;
	                        var emittedAsTopLevel = ts.isBlockScopedContainerTopLevel(container) ||
	                            (isCapturedInFunction && isDeclaredInLoop && container.kind === 195 /* Block */ && ts.isIterationStatement(container.parent, /*lookInLabeledStatements*/ false));
	                        var emittedAsNestedLetDeclaration = ts.getCombinedNodeFlags(node) & 8192 /* Let */ &&
	                            !emittedAsTopLevel;
	                        var emitExplicitInitializer = emittedAsNestedLetDeclaration &&
	                            container.kind !== 203 /* ForInStatement */ &&
	                            container.kind !== 204 /* ForOfStatement */ &&
	                            (!resolver.isDeclarationWithCollidingName(node) ||
	                                (isDeclaredInLoop && !isCapturedInFunction && !ts.isIterationStatement(container, /*lookInLabeledStatements*/ false)));
	                        if (emitExplicitInitializer) {
	                            initializer = createVoidZero();
	                        }
	                    }
	                    var exportChanged = isNameOfExportedSourceLevelDeclarationInSystemExternalModule(node.name);
	                    if (exportChanged) {
	                        write(exportFunctionForFile + "(\"");
	                        emitNodeWithCommentsAndWithoutSourcemap(node.name);
	                        write("\", ");
	                    }
	                    emitModuleMemberName(node);
	                    emitOptional(" = ", initializer);
	                    if (exportChanged) {
	                        write(")");
	                    }
	                }
	            }
	            function emitExportVariableAssignments(node) {
	                if (node.kind === 190 /* OmittedExpression */) {
	                    return;
	                }
	                var name = node.name;
	                if (name.kind === 69 /* Identifier */) {
	                    emitExportMemberAssignments(name);
	                }
	                else if (ts.isBindingPattern(name)) {
	                    ts.forEach(name.elements, emitExportVariableAssignments);
	                }
	            }
	            function isES6ExportedDeclaration(node) {
	                return !!(node.flags & 2 /* Export */) &&
	                    modulekind === 5 /* ES6 */ &&
	                    node.parent.kind === 251 /* SourceFile */;
	            }
	            function emitVariableStatement(node) {
	                var startIsEmitted = false;
	                if (node.flags & 2 /* Export */) {
	                    if (isES6ExportedDeclaration(node)) {
	                        // Exported ES6 module member
	                        write("export ");
	                        startIsEmitted = tryEmitStartOfVariableDeclarationList(node.declarationList);
	                    }
	                }
	                else {
	                    startIsEmitted = tryEmitStartOfVariableDeclarationList(node.declarationList);
	                }
	                if (startIsEmitted) {
	                    emitCommaList(node.declarationList.declarations);
	                    write(";");
	                }
	                else {
	                    var atLeastOneItem = emitVariableDeclarationListSkippingUninitializedEntries(node.declarationList);
	                    if (atLeastOneItem) {
	                        write(";");
	                    }
	                }
	                if (modulekind !== 5 /* ES6 */ && node.parent === currentSourceFile) {
	                    ts.forEach(node.declarationList.declarations, emitExportVariableAssignments);
	                }
	            }
	            function shouldEmitLeadingAndTrailingCommentsForVariableStatement(node) {
	                // If we're not exporting the variables, there's nothing special here.
	                // Always emit comments for these nodes.
	                if (!(node.flags & 2 /* Export */)) {
	                    return true;
	                }
	                // If we are exporting, but it's a top-level ES6 module exports,
	                // we'll emit the declaration list verbatim, so emit comments too.
	                if (isES6ExportedDeclaration(node)) {
	                    return true;
	                }
	                // Otherwise, only emit if we have at least one initializer present.
	                for (var _a = 0, _b = node.declarationList.declarations; _a < _b.length; _a++) {
	                    var declaration = _b[_a];
	                    if (declaration.initializer) {
	                        return true;
	                    }
	                }
	                return false;
	            }
	            function emitParameter(node) {
	                if (languageVersion < 2 /* ES6 */) {
	                    if (ts.isBindingPattern(node.name)) {
	                        var name_27 = createTempVariable(0 /* Auto */);
	                        if (!tempParameters) {
	                            tempParameters = [];
	                        }
	                        tempParameters.push(name_27);
	                        emit(name_27);
	                    }
	                    else {
	                        emit(node.name);
	                    }
	                }
	                else {
	                    if (node.dotDotDotToken) {
	                        write("...");
	                    }
	                    emit(node.name);
	                    emitOptional(" = ", node.initializer);
	                }
	            }
	            function emitDefaultValueAssignments(node) {
	                if (languageVersion < 2 /* ES6 */) {
	                    var tempIndex_1 = 0;
	                    ts.forEach(node.parameters, function (parameter) {
	                        // A rest parameter cannot have a binding pattern or an initializer,
	                        // so let's just ignore it.
	                        if (parameter.dotDotDotToken) {
	                            return;
	                        }
	                        var paramName = parameter.name, initializer = parameter.initializer;
	                        if (ts.isBindingPattern(paramName)) {
	                            // In cases where a binding pattern is simply '[]' or '{}',
	                            // we usually don't want to emit a var declaration; however, in the presence
	                            // of an initializer, we must emit that expression to preserve side effects.
	                            var hasBindingElements = paramName.elements.length > 0;
	                            if (hasBindingElements || initializer) {
	                                writeLine();
	                                write("var ");
	                                if (hasBindingElements) {
	                                    emitDestructuring(parameter, /*isAssignmentExpressionStatement*/ false, tempParameters[tempIndex_1]);
	                                }
	                                else {
	                                    emit(tempParameters[tempIndex_1]);
	                                    write(" = ");
	                                    emit(initializer);
	                                }
	                                write(";");
	                                tempIndex_1++;
	                            }
	                        }
	                        else if (initializer) {
	                            writeLine();
	                            emitStart(parameter);
	                            write("if (");
	                            emitNodeWithoutSourceMap(paramName);
	                            write(" === void 0)");
	                            emitEnd(parameter);
	                            write(" { ");
	                            emitStart(parameter);
	                            emitNodeWithCommentsAndWithoutSourcemap(paramName);
	                            write(" = ");
	                            emitNodeWithCommentsAndWithoutSourcemap(initializer);
	                            emitEnd(parameter);
	                            write("; }");
	                        }
	                    });
	                }
	            }
	            function emitRestParameter(node) {
	                if (languageVersion < 2 /* ES6 */ && ts.hasRestParameter(node)) {
	                    var restIndex = node.parameters.length - 1;
	                    var restParam = node.parameters[restIndex];
	                    // A rest parameter cannot have a binding pattern, so let's just ignore it if it does.
	                    if (ts.isBindingPattern(restParam.name)) {
	                        return;
	                    }
	                    var tempName = createTempVariable(268435456 /* _i */).text;
	                    writeLine();
	                    emitLeadingComments(restParam);
	                    emitStart(restParam);
	                    write("var ");
	                    emitNodeWithCommentsAndWithoutSourcemap(restParam.name);
	                    write(" = [];");
	                    emitEnd(restParam);
	                    emitTrailingComments(restParam);
	                    writeLine();
	                    write("for (");
	                    emitStart(restParam);
	                    write("var " + tempName + " = " + restIndex + ";");
	                    emitEnd(restParam);
	                    write(" ");
	                    emitStart(restParam);
	                    write(tempName + " < arguments.length;");
	                    emitEnd(restParam);
	                    write(" ");
	                    emitStart(restParam);
	                    write(tempName + "++");
	                    emitEnd(restParam);
	                    write(") {");
	                    increaseIndent();
	                    writeLine();
	                    emitStart(restParam);
	                    emitNodeWithCommentsAndWithoutSourcemap(restParam.name);
	                    write("[" + tempName + " - " + restIndex + "] = arguments[" + tempName + "];");
	                    emitEnd(restParam);
	                    decreaseIndent();
	                    writeLine();
	                    write("}");
	                }
	            }
	            function emitAccessor(node) {
	                write(node.kind === 146 /* GetAccessor */ ? "get " : "set ");
	                emit(node.name);
	                emitSignatureAndBody(node);
	            }
	            function shouldEmitAsArrowFunction(node) {
	                return node.kind === 177 /* ArrowFunction */ && languageVersion >= 2 /* ES6 */;
	            }
	            function emitDeclarationName(node) {
	                if (node.name) {
	                    emitNodeWithCommentsAndWithoutSourcemap(node.name);
	                }
	                else {
	                    write(getGeneratedNameForNode(node));
	                }
	            }
	            function shouldEmitFunctionName(node) {
	                if (node.kind === 176 /* FunctionExpression */) {
	                    // Emit name if one is present
	                    return !!node.name;
	                }
	                if (node.kind === 216 /* FunctionDeclaration */) {
	                    // Emit name if one is present, or emit generated name in down-level case (for export default case)
	                    return !!node.name || modulekind !== 5 /* ES6 */;
	                }
	            }
	            function emitFunctionDeclaration(node) {
	                if (ts.nodeIsMissing(node.body)) {
	                    return emitCommentsOnNotEmittedNode(node);
	                }
	                // TODO (yuisu) : we should not have special cases to condition emitting comments
	                // but have one place to fix check for these conditions.
	                var kind = node.kind, parent = node.parent;
	                if (kind !== 144 /* MethodDeclaration */ &&
	                    kind !== 143 /* MethodSignature */ &&
	                    parent &&
	                    parent.kind !== 248 /* PropertyAssignment */ &&
	                    parent.kind !== 171 /* CallExpression */ &&
	                    parent.kind !== 167 /* ArrayLiteralExpression */) {
	                    // 1. Methods will emit comments at their assignment declaration sites.
	                    //
	                    // 2. If the function is a property of object literal, emitting leading-comments
	                    //    is done by emitNodeWithoutSourceMap which then call this function.
	                    //    In particular, we would like to avoid emit comments twice in following case:
	                    //
	                    //          var obj = {
	                    //              id:
	                    //                  /*comment*/ () => void
	                    //          }
	                    //
	                    // 3. If the function is an argument in call expression, emitting of comments will be
	                    //    taken care of in emit list of arguments inside of 'emitCallExpression'.
	                    //
	                    // 4. If the function is in an array literal, 'emitLinePreservingList' will take care
	                    //    of leading comments.
	                    emitLeadingComments(node);
	                }
	                emitStart(node);
	                // For targeting below es6, emit functions-like declaration including arrow function using function keyword.
	                // When targeting ES6, emit arrow function natively in ES6 by omitting function keyword and using fat arrow instead
	                if (!shouldEmitAsArrowFunction(node)) {
	                    if (isES6ExportedDeclaration(node)) {
	                        write("export ");
	                        if (node.flags & 512 /* Default */) {
	                            write("default ");
	                        }
	                    }
	                    write("function");
	                    if (languageVersion >= 2 /* ES6 */ && node.asteriskToken) {
	                        write("*");
	                    }
	                    write(" ");
	                }
	                if (shouldEmitFunctionName(node)) {
	                    emitDeclarationName(node);
	                }
	                emitSignatureAndBody(node);
	                if (modulekind !== 5 /* ES6 */ && kind === 216 /* FunctionDeclaration */ && parent === currentSourceFile && node.name) {
	                    emitExportMemberAssignments(node.name);
	                }
	                emitEnd(node);
	                if (kind !== 144 /* MethodDeclaration */ && kind !== 143 /* MethodSignature */) {
	                    emitTrailingComments(node);
	                }
	            }
	            function emitCaptureThisForNodeIfNecessary(node) {
	                if (resolver.getNodeCheckFlags(node) & 4 /* CaptureThis */) {
	                    writeLine();
	                    emitStart(node);
	                    write("var _this = this;");
	                    emitEnd(node);
	                }
	            }
	            function emitSignatureParameters(node) {
	                increaseIndent();
	                write("(");
	                if (node) {
	                    var parameters = node.parameters;
	                    var omitCount = languageVersion < 2 /* ES6 */ && ts.hasRestParameter(node) ? 1 : 0;
	                    emitList(parameters, 0, parameters.length - omitCount, /*multiLine*/ false, /*trailingComma*/ false);
	                }
	                write(")");
	                decreaseIndent();
	            }
	            function emitSignatureParametersForArrow(node) {
	                // Check whether the parameter list needs parentheses and preserve no-parenthesis
	                if (node.parameters.length === 1 && node.pos === node.parameters[0].pos) {
	                    emit(node.parameters[0]);
	                    return;
	                }
	                emitSignatureParameters(node);
	            }
	            function emitAsyncFunctionBodyForES6(node) {
	                var promiseConstructor = ts.getEntityNameFromTypeNode(node.type);
	                var isArrowFunction = node.kind === 177 /* ArrowFunction */;
	                var hasLexicalArguments = (resolver.getNodeCheckFlags(node) & 8192 /* CaptureArguments */) !== 0;
	                // An async function is emit as an outer function that calls an inner
	                // generator function. To preserve lexical bindings, we pass the current
	                // `this` and `arguments` objects to `__awaiter`. The generator function
	                // passed to `__awaiter` is executed inside of the callback to the
	                // promise constructor.
	                //
	                // The emit for an async arrow without a lexical `arguments` binding might be:
	                //
	                //  // input
	                //  let a = async (b) => { await b; }
	                //
	                //  // output
	                //  let a = (b) => __awaiter(this, void 0, void 0, function* () {
	                //      yield b;
	                //  });
	                //
	                // The emit for an async arrow with a lexical `arguments` binding might be:
	                //
	                //  // input
	                //  let a = async (b) => { await arguments[0]; }
	                //
	                //  // output
	                //  let a = (b) => __awaiter(this, arguments, void 0, function* (arguments) {
	                //      yield arguments[0];
	                //  });
	                //
	                // The emit for an async function expression without a lexical `arguments` binding
	                // might be:
	                //
	                //  // input
	                //  let a = async function (b) {
	                //      await b;
	                //  }
	                //
	                //  // output
	                //  let a = function (b) {
	                //      return __awaiter(this, void 0, void 0, function* () {
	                //          yield b;
	                //      });
	                //  }
	                //
	                // The emit for an async function expression with a lexical `arguments` binding
	                // might be:
	                //
	                //  // input
	                //  let a = async function (b) {
	                //      await arguments[0];
	                //  }
	                //
	                //  // output
	                //  let a = function (b) {
	                //      return __awaiter(this, arguments, void 0, function* (_arguments) {
	                //          yield _arguments[0];
	                //      });
	                //  }
	                //
	                // The emit for an async function expression with a lexical `arguments` binding
	                // and a return type annotation might be:
	                //
	                //  // input
	                //  let a = async function (b): MyPromise<any> {
	                //      await arguments[0];
	                //  }
	                //
	                //  // output
	                //  let a = function (b) {
	                //      return __awaiter(this, arguments, MyPromise, function* (_arguments) {
	                //          yield _arguments[0];
	                //      });
	                //  }
	                //
	                // If this is not an async arrow, emit the opening brace of the function body
	                // and the start of the return statement.
	                if (!isArrowFunction) {
	                    write(" {");
	                    increaseIndent();
	                    writeLine();
	                    if (resolver.getNodeCheckFlags(node) & 4096 /* AsyncMethodWithSuperBinding */) {
	                        writeLines("\nconst _super = (function (geti, seti) {\n    const cache = Object.create(null);\n    return name => cache[name] || (cache[name] = { get value() { return geti(name); }, set value(v) { seti(name, v); } });\n})(name => super[name], (name, value) => super[name] = value);");
	                        writeLine();
	                    }
	                    else if (resolver.getNodeCheckFlags(node) & 2048 /* AsyncMethodWithSuper */) {
	                        write("const _super = name => super[name];");
	                        writeLine();
	                    }
	                    write("return");
	                }
	                write(" __awaiter(this");
	                if (hasLexicalArguments) {
	                    write(", arguments, ");
	                }
	                else {
	                    write(", void 0, ");
	                }
	                if (!promiseConstructor || (compilerOptions.noCustomAsyncPromise && languageVersion >= 2 /* ES6 */)) {
	                    write("void 0");
	                }
	                else {
	                    emitEntityNameAsExpression(promiseConstructor, /*useFallback*/ false);
	                }
	                // Emit the call to __awaiter.
	                write(", function* ()");
	                // Emit the signature and body for the inner generator function.
	                emitFunctionBody(node);
	                write(")");
	                // If this is not an async arrow, emit the closing brace of the outer function body.
	                if (!isArrowFunction) {
	                    write(";");
	                    decreaseIndent();
	                    writeLine();
	                    write("}");
	                }
	            }
	            function emitFunctionBody(node) {
	                if (!node.body) {
	                    // There can be no body when there are parse errors.  Just emit an empty block
	                    // in that case.
	                    write(" { }");
	                }
	                else {
	                    if (node.body.kind === 195 /* Block */) {
	                        emitBlockFunctionBody(node, node.body);
	                    }
	                    else {
	                        emitExpressionFunctionBody(node, node.body);
	                    }
	                }
	            }
	            function emitSignatureAndBody(node) {
	                var saveConvertedLoopState = convertedLoopState;
	                var saveTempFlags = tempFlags;
	                var saveTempVariables = tempVariables;
	                var saveTempParameters = tempParameters;
	                convertedLoopState = undefined;
	                tempFlags = 0;
	                tempVariables = undefined;
	                tempParameters = undefined;
	                // When targeting ES6, emit arrow function natively in ES6
	                if (shouldEmitAsArrowFunction(node)) {
	                    emitSignatureParametersForArrow(node);
	                    write(" =>");
	                }
	                else {
	                    emitSignatureParameters(node);
	                }
	                var isAsync = ts.isAsyncFunctionLike(node);
	                if (isAsync) {
	                    emitAsyncFunctionBodyForES6(node);
	                }
	                else {
	                    emitFunctionBody(node);
	                }
	                if (!isES6ExportedDeclaration(node)) {
	                    emitExportMemberAssignment(node);
	                }
	                ts.Debug.assert(convertedLoopState === undefined);
	                convertedLoopState = saveConvertedLoopState;
	                tempFlags = saveTempFlags;
	                tempVariables = saveTempVariables;
	                tempParameters = saveTempParameters;
	            }
	            // Returns true if any preamble code was emitted.
	            function emitFunctionBodyPreamble(node) {
	                emitCaptureThisForNodeIfNecessary(node);
	                emitDefaultValueAssignments(node);
	                emitRestParameter(node);
	            }
	            function emitExpressionFunctionBody(node, body) {
	                if (languageVersion < 2 /* ES6 */ || node.flags & 256 /* Async */) {
	                    emitDownLevelExpressionFunctionBody(node, body);
	                    return;
	                }
	                // For es6 and higher we can emit the expression as is.  However, in the case
	                // where the expression might end up looking like a block when emitted, we'll
	                // also wrap it in parentheses first.  For example if you have: a => <foo>{}
	                // then we need to generate: a => ({})
	                write(" ");
	                // Unwrap all type assertions.
	                var current = body;
	                while (current.kind === 174 /* TypeAssertionExpression */) {
	                    current = current.expression;
	                }
	                emitParenthesizedIf(body, current.kind === 168 /* ObjectLiteralExpression */);
	            }
	            function emitDownLevelExpressionFunctionBody(node, body) {
	                write(" {");
	                increaseIndent();
	                var outPos = writer.getTextPos();
	                emitDetachedCommentsAndUpdateCommentsInfo(node.body);
	                emitFunctionBodyPreamble(node);
	                var preambleEmitted = writer.getTextPos() !== outPos;
	                decreaseIndent();
	                // If we didn't have to emit any preamble code, then attempt to keep the arrow
	                // function on one line.
	                if (!preambleEmitted && nodeStartPositionsAreOnSameLine(node, body)) {
	                    write(" ");
	                    emitStart(body);
	                    write("return ");
	                    emit(body);
	                    emitEnd(body);
	                    write(";");
	                    emitTempDeclarations(/*newLine*/ false);
	                    write(" ");
	                }
	                else {
	                    increaseIndent();
	                    writeLine();
	                    emitLeadingComments(node.body);
	                    emitStart(body);
	                    write("return ");
	                    emit(body);
	                    emitEnd(body);
	                    write(";");
	                    emitTrailingComments(node.body);
	                    emitTempDeclarations(/*newLine*/ true);
	                    decreaseIndent();
	                    writeLine();
	                }
	                emitStart(node.body);
	                write("}");
	                emitEnd(node.body);
	            }
	            function emitBlockFunctionBody(node, body) {
	                write(" {");
	                var initialTextPos = writer.getTextPos();
	                increaseIndent();
	                emitDetachedCommentsAndUpdateCommentsInfo(body.statements);
	                // Emit all the directive prologues (like "use strict").  These have to come before
	                // any other preamble code we write (like parameter initializers).
	                var startIndex = emitDirectivePrologues(body.statements, /*startWithNewLine*/ true);
	                emitFunctionBodyPreamble(node);
	                decreaseIndent();
	                var preambleEmitted = writer.getTextPos() !== initialTextPos;
	                if (!preambleEmitted && nodeEndIsOnSameLineAsNodeStart(body, body)) {
	                    for (var _a = 0, _b = body.statements; _a < _b.length; _a++) {
	                        var statement = _b[_a];
	                        write(" ");
	                        emit(statement);
	                    }
	                    emitTempDeclarations(/*newLine*/ false);
	                    write(" ");
	                    emitLeadingCommentsOfPosition(body.statements.end);
	                }
	                else {
	                    increaseIndent();
	                    emitLinesStartingAt(body.statements, startIndex);
	                    emitTempDeclarations(/*newLine*/ true);
	                    writeLine();
	                    emitLeadingCommentsOfPosition(body.statements.end);
	                    decreaseIndent();
	                }
	                emitToken(16 /* CloseBraceToken */, body.statements.end);
	            }
	            /**
	             * Return the statement at a given index if it is a super-call statement
	             * @param ctor a constructor declaration
	             * @param index an index to constructor's body to check
	             */
	            function getSuperCallAtGivenIndex(ctor, index) {
	                if (!ctor.body) {
	                    return undefined;
	                }
	                var statements = ctor.body.statements;
	                if (!statements || index >= statements.length) {
	                    return undefined;
	                }
	                var statement = statements[index];
	                if (statement.kind === 198 /* ExpressionStatement */) {
	                    return ts.isSuperCallExpression(statement.expression) ? statement : undefined;
	                }
	            }
	            function emitParameterPropertyAssignments(node) {
	                ts.forEach(node.parameters, function (param) {
	                    if (param.flags & 56 /* AccessibilityModifier */) {
	                        writeLine();
	                        emitStart(param);
	                        emitStart(param.name);
	                        write("this.");
	                        emitNodeWithoutSourceMap(param.name);
	                        emitEnd(param.name);
	                        write(" = ");
	                        emit(param.name);
	                        write(";");
	                        emitEnd(param);
	                    }
	                });
	            }
	            function emitMemberAccessForPropertyName(memberName) {
	                // This does not emit source map because it is emitted by caller as caller
	                // is aware how the property name changes to the property access
	                // eg. public x = 10; becomes this.x and static x = 10 becomes className.x
	                if (memberName.kind === 9 /* StringLiteral */ || memberName.kind === 8 /* NumericLiteral */) {
	                    write("[");
	                    emitNodeWithCommentsAndWithoutSourcemap(memberName);
	                    write("]");
	                }
	                else if (memberName.kind === 137 /* ComputedPropertyName */) {
	                    emitComputedPropertyName(memberName);
	                }
	                else {
	                    write(".");
	                    emitNodeWithCommentsAndWithoutSourcemap(memberName);
	                }
	            }
	            function getInitializedProperties(node, isStatic) {
	                var properties = [];
	                for (var _a = 0, _b = node.members; _a < _b.length; _a++) {
	                    var member = _b[_a];
	                    if (member.kind === 142 /* PropertyDeclaration */ && isStatic === ((member.flags & 64 /* Static */) !== 0) && member.initializer) {
	                        properties.push(member);
	                    }
	                }
	                return properties;
	            }
	            function emitPropertyDeclarations(node, properties) {
	                for (var _a = 0, properties_6 = properties; _a < properties_6.length; _a++) {
	                    var property = properties_6[_a];
	                    emitPropertyDeclaration(node, property);
	                }
	            }
	            function emitPropertyDeclaration(node, property, receiver, isExpression) {
	                writeLine();
	                emitLeadingComments(property);
	                emitStart(property);
	                emitStart(property.name);
	                if (receiver) {
	                    emit(receiver);
	                }
	                else {
	                    if (property.flags & 64 /* Static */) {
	                        emitDeclarationName(node);
	                    }
	                    else {
	                        write("this");
	                    }
	                }
	                emitMemberAccessForPropertyName(property.name);
	                emitEnd(property.name);
	                write(" = ");
	                emit(property.initializer);
	                if (!isExpression) {
	                    write(";");
	                }
	                emitEnd(property);
	                emitTrailingComments(property);
	            }
	            function emitMemberFunctionsForES5AndLower(node) {
	                ts.forEach(node.members, function (member) {
	                    if (member.kind === 194 /* SemicolonClassElement */) {
	                        writeLine();
	                        write(";");
	                    }
	                    else if (member.kind === 144 /* MethodDeclaration */ || node.kind === 143 /* MethodSignature */) {
	                        if (!member.body) {
	                            return emitCommentsOnNotEmittedNode(member);
	                        }
	                        writeLine();
	                        emitLeadingComments(member);
	                        emitStart(member);
	                        emitStart(member.name);
	                        emitClassMemberPrefix(node, member);
	                        emitMemberAccessForPropertyName(member.name);
	                        emitEnd(member.name);
	                        write(" = ");
	                        emitFunctionDeclaration(member);
	                        emitEnd(member);
	                        write(";");
	                        emitTrailingComments(member);
	                    }
	                    else if (member.kind === 146 /* GetAccessor */ || member.kind === 147 /* SetAccessor */) {
	                        var accessors = ts.getAllAccessorDeclarations(node.members, member);
	                        if (member === accessors.firstAccessor) {
	                            writeLine();
	                            emitStart(member);
	                            write("Object.defineProperty(");
	                            emitStart(member.name);
	                            emitClassMemberPrefix(node, member);
	                            write(", ");
	                            emitExpressionForPropertyName(member.name);
	                            emitEnd(member.name);
	                            write(", {");
	                            increaseIndent();
	                            if (accessors.getAccessor) {
	                                writeLine();
	                                emitLeadingComments(accessors.getAccessor);
	                                write("get: ");
	                                emitStart(accessors.getAccessor);
	                                write("function ");
	                                emitSignatureAndBody(accessors.getAccessor);
	                                emitEnd(accessors.getAccessor);
	                                emitTrailingComments(accessors.getAccessor);
	                                write(",");
	                            }
	                            if (accessors.setAccessor) {
	                                writeLine();
	                                emitLeadingComments(accessors.setAccessor);
	                                write("set: ");
	                                emitStart(accessors.setAccessor);
	                                write("function ");
	                                emitSignatureAndBody(accessors.setAccessor);
	                                emitEnd(accessors.setAccessor);
	                                emitTrailingComments(accessors.setAccessor);
	                                write(",");
	                            }
	                            writeLine();
	                            write("enumerable: true,");
	                            writeLine();
	                            write("configurable: true");
	                            decreaseIndent();
	                            writeLine();
	                            write("});");
	                            emitEnd(member);
	                        }
	                    }
	                });
	            }
	            function emitMemberFunctionsForES6AndHigher(node) {
	                for (var _a = 0, _b = node.members; _a < _b.length; _a++) {
	                    var member = _b[_a];
	                    if ((member.kind === 144 /* MethodDeclaration */ || node.kind === 143 /* MethodSignature */) && !member.body) {
	                        emitCommentsOnNotEmittedNode(member);
	                    }
	                    else if (member.kind === 144 /* MethodDeclaration */ ||
	                        member.kind === 146 /* GetAccessor */ ||
	                        member.kind === 147 /* SetAccessor */) {
	                        writeLine();
	                        emitLeadingComments(member);
	                        emitStart(member);
	                        if (member.flags & 64 /* Static */) {
	                            write("static ");
	                        }
	                        if (member.kind === 146 /* GetAccessor */) {
	                            write("get ");
	                        }
	                        else if (member.kind === 147 /* SetAccessor */) {
	                            write("set ");
	                        }
	                        if (member.asteriskToken) {
	                            write("*");
	                        }
	                        emit(member.name);
	                        emitSignatureAndBody(member);
	                        emitEnd(member);
	                        emitTrailingComments(member);
	                    }
	                    else if (member.kind === 194 /* SemicolonClassElement */) {
	                        writeLine();
	                        write(";");
	                    }
	                }
	            }
	            function emitConstructor(node, baseTypeElement) {
	                var saveConvertedLoopState = convertedLoopState;
	                var saveTempFlags = tempFlags;
	                var saveTempVariables = tempVariables;
	                var saveTempParameters = tempParameters;
	                convertedLoopState = undefined;
	                tempFlags = 0;
	                tempVariables = undefined;
	                tempParameters = undefined;
	                emitConstructorWorker(node, baseTypeElement);
	                ts.Debug.assert(convertedLoopState === undefined);
	                convertedLoopState = saveConvertedLoopState;
	                tempFlags = saveTempFlags;
	                tempVariables = saveTempVariables;
	                tempParameters = saveTempParameters;
	            }
	            function emitConstructorWorker(node, baseTypeElement) {
	                // Check if we have property assignment inside class declaration.
	                // If there is property assignment, we need to emit constructor whether users define it or not
	                // If there is no property assignment, we can omit constructor if users do not define it
	                var hasInstancePropertyWithInitializer = false;
	                // Emit the constructor overload pinned comments
	                ts.forEach(node.members, function (member) {
	                    if (member.kind === 145 /* Constructor */ && !member.body) {
	                        emitCommentsOnNotEmittedNode(member);
	                    }
	                    // Check if there is any non-static property assignment
	                    if (member.kind === 142 /* PropertyDeclaration */ && member.initializer && (member.flags & 64 /* Static */) === 0) {
	                        hasInstancePropertyWithInitializer = true;
	                    }
	                });
	                var ctor = ts.getFirstConstructorWithBody(node);
	                // For target ES6 and above, if there is no user-defined constructor and there is no property assignment
	                // do not emit constructor in class declaration.
	                if (languageVersion >= 2 /* ES6 */ && !ctor && !hasInstancePropertyWithInitializer) {
	                    return;
	                }
	                if (ctor) {
	                    emitLeadingComments(ctor);
	                }
	                emitStart(ctor || node);
	                if (languageVersion < 2 /* ES6 */) {
	                    write("function ");
	                    emitDeclarationName(node);
	                    emitSignatureParameters(ctor);
	                }
	                else {
	                    write("constructor");
	                    if (ctor) {
	                        emitSignatureParameters(ctor);
	                    }
	                    else {
	                        // Based on EcmaScript6 section 14.5.14: Runtime Semantics: ClassDefinitionEvaluation.
	                        // If constructor is empty, then,
	                        //      If ClassHeritageopt is present, then
	                        //          Let constructor be the result of parsing the String "constructor(... args){ super (...args);}" using the syntactic grammar with the goal symbol MethodDefinition.
	                        //      Else,
	                        //          Let constructor be the result of parsing the String "constructor( ){ }" using the syntactic grammar with the goal symbol MethodDefinition
	                        if (baseTypeElement) {
	                            write("(...args)");
	                        }
	                        else {
	                            write("()");
	                        }
	                    }
	                }
	                var startIndex = 0;
	                write(" {");
	                increaseIndent();
	                if (ctor) {
	                    // Emit all the directive prologues (like "use strict").  These have to come before
	                    // any other preamble code we write (like parameter initializers).
	                    startIndex = emitDirectivePrologues(ctor.body.statements, /*startWithNewLine*/ true);
	                    emitDetachedCommentsAndUpdateCommentsInfo(ctor.body.statements);
	                }
	                emitCaptureThisForNodeIfNecessary(node);
	                var superCall;
	                if (ctor) {
	                    emitDefaultValueAssignments(ctor);
	                    emitRestParameter(ctor);
	                    if (baseTypeElement) {
	                        superCall = getSuperCallAtGivenIndex(ctor, startIndex);
	                        if (superCall) {
	                            writeLine();
	                            emit(superCall);
	                        }
	                    }
	                    emitParameterPropertyAssignments(ctor);
	                }
	                else {
	                    if (baseTypeElement) {
	                        writeLine();
	                        emitStart(baseTypeElement);
	                        if (languageVersion < 2 /* ES6 */) {
	                            write("_super.apply(this, arguments);");
	                        }
	                        else {
	                            write("super(...args);");
	                        }
	                        emitEnd(baseTypeElement);
	                    }
	                }
	                emitPropertyDeclarations(node, getInitializedProperties(node, /*isStatic*/ false));
	                if (ctor) {
	                    var statements = ctor.body.statements;
	                    if (superCall) {
	                        statements = statements.slice(1);
	                    }
	                    emitLinesStartingAt(statements, startIndex);
	                }
	                emitTempDeclarations(/*newLine*/ true);
	                writeLine();
	                if (ctor) {
	                    emitLeadingCommentsOfPosition(ctor.body.statements.end);
	                }
	                decreaseIndent();
	                emitToken(16 /* CloseBraceToken */, ctor ? ctor.body.statements.end : node.members.end);
	                emitEnd(ctor || node);
	                if (ctor) {
	                    emitTrailingComments(ctor);
	                }
	            }
	            function emitClassExpression(node) {
	                return emitClassLikeDeclaration(node);
	            }
	            function emitClassDeclaration(node) {
	                return emitClassLikeDeclaration(node);
	            }
	            function emitClassLikeDeclaration(node) {
	                if (languageVersion < 2 /* ES6 */) {
	                    emitClassLikeDeclarationBelowES6(node);
	                }
	                else {
	                    emitClassLikeDeclarationForES6AndHigher(node);
	                }
	                if (modulekind !== 5 /* ES6 */ && node.parent === currentSourceFile && node.name) {
	                    emitExportMemberAssignments(node.name);
	                }
	            }
	            function emitClassLikeDeclarationForES6AndHigher(node) {
	                var decoratedClassAlias;
	                var thisNodeIsDecorated = ts.nodeIsDecorated(node);
	                if (node.kind === 217 /* ClassDeclaration */) {
	                    if (thisNodeIsDecorated) {
	                        // When we emit an ES6 class that has a class decorator, we must tailor the
	                        // emit to certain specific cases.
	                        //
	                        // In the simplest case, we emit the class declaration as a let declaration, and
	                        // evaluate decorators after the close of the class body:
	                        //
	                        //  TypeScript                      | Javascript
	                        //  --------------------------------|------------------------------------
	                        //  @dec                            | let C = class C {
	                        //  class C {                       | }
	                        //  }                               | C = __decorate([dec], C);
	                        //  --------------------------------|------------------------------------
	                        //  @dec                            | export let C = class C {
	                        //  export class C {                | }
	                        //  }                               | C = __decorate([dec], C);
	                        //  ---------------------------------------------------------------------
	                        //  [Example 1]
	                        //
	                        // If a class declaration contains a reference to itself *inside* of the class body,
	                        // this introduces two bindings to the class: One outside of the class body, and one
	                        // inside of the class body. If we apply decorators as in [Example 1] above, there
	                        // is the possibility that the decorator `dec` will return a new value for the
	                        // constructor, which would result in the binding inside of the class no longer
	                        // pointing to the same reference as the binding outside of the class.
	                        //
	                        // As a result, we must instead rewrite all references to the class *inside* of the
	                        // class body to instead point to a local temporary alias for the class:
	                        //
	                        //  TypeScript                      | Javascript
	                        //  --------------------------------|------------------------------------
	                        //  @dec                            | let C_1;
	                        //  class C {                       | let C = C_1 = class C {
	                        //    static x() { return C.y; }    |   static x() { return C_1.y; }
	                        //    static y = 1;                 | }
	                        //  }                               | C.y = 1;
	                        //                                  | C = C_1 = __decorate([dec], C);
	                        //  --------------------------------|------------------------------------
	                        //  @dec                            | let C_1;
	                        //  export class C {                | export let C = C_1 = class C {
	                        //    static x() { return C.y; }    |   static x() { return C_1.y; }
	                        //    static y = 1;                 | }
	                        //  }                               | C.y = 1;
	                        //                                  | C = C_1 = __decorate([dec], C);
	                        //  ---------------------------------------------------------------------
	                        //  [Example 2]
	                        //
	                        // If a class declaration is the default export of a module, we instead emit
	                        // the export after the decorated declaration:
	                        //
	                        //  TypeScript                      | Javascript
	                        //  --------------------------------|------------------------------------
	                        //  @dec                            | let default_1 = class {
	                        //  export default class {          | }
	                        //  }                               | default_1 = __decorate([dec], default_1);
	                        //                                  | export default default_1;
	                        //  --------------------------------|------------------------------------
	                        //  @dec                            | let C = class C {
	                        //  export default class {          | }
	                        //  }                               | C = __decorate([dec], C);
	                        //                                  | export default C;
	                        //  ---------------------------------------------------------------------
	                        //  [Example 3]
	                        //
	                        // If the class declaration is the default export and a reference to itself
	                        // inside of the class body, we must emit both an alias for the class *and*
	                        // move the export after the declaration:
	                        //
	                        //  TypeScript                      | Javascript
	                        //  --------------------------------|------------------------------------
	                        //  @dec                            | let C_1;
	                        //  export default class C {        | let C = C_1 = class C {
	                        //    static x() { return C.y; }    |   static x() { return C_1.y; }
	                        //    static y = 1;                 | }
	                        //  }                               | C.y = 1;
	                        //                                  | C = C_1 = __decorate([dec], C);
	                        //                                  | export default C;
	                        //  ---------------------------------------------------------------------
	                        //  [Example 4]
	                        //
	                        if (resolver.getNodeCheckFlags(node) & 524288 /* ClassWithBodyScopedClassBinding */) {
	                            decoratedClassAlias = ts.unescapeIdentifier(makeUniqueName(node.name ? node.name.text : "default"));
	                            decoratedClassAliases[ts.getNodeId(node)] = decoratedClassAlias;
	                            write("let " + decoratedClassAlias + ";");
	                            writeLine();
	                        }
	                        if (isES6ExportedDeclaration(node) && !(node.flags & 512 /* Default */)) {
	                            write("export ");
	                        }
	                        write("let ");
	                        emitDeclarationName(node);
	                        if (decoratedClassAlias !== undefined) {
	                            write(" = " + decoratedClassAlias);
	                        }
	                        write(" = ");
	                    }
	                    else if (isES6ExportedDeclaration(node)) {
	                        write("export ");
	                        if (node.flags & 512 /* Default */) {
	                            write("default ");
	                        }
	                    }
	                }
	                // If the class has static properties, and it's a class expression, then we'll need
	                // to specialize the emit a bit.  for a class expression of the form:
	                //
	                //      class C { static a = 1; static b = 2; ... }
	                //
	                // We'll emit:
	                //
	                //      (_temp = class C { ... }, _temp.a = 1, _temp.b = 2, _temp)
	                //
	                // This keeps the expression as an expression, while ensuring that the static parts
	                // of it have been initialized by the time it is used.
	                var staticProperties = getInitializedProperties(node, /*isStatic*/ true);
	                var isClassExpressionWithStaticProperties = staticProperties.length > 0 && node.kind === 189 /* ClassExpression */;
	                var tempVariable;
	                if (isClassExpressionWithStaticProperties) {
	                    tempVariable = createAndRecordTempVariable(0 /* Auto */);
	                    write("(");
	                    increaseIndent();
	                    emit(tempVariable);
	                    write(" = ");
	                }
	                write("class");
	                // emit name if
	                // - node has a name
	                // - this is default export with static initializers
	                if (node.name || (node.flags & 512 /* Default */ && (staticProperties.length > 0 || modulekind !== 5 /* ES6 */) && !thisNodeIsDecorated)) {
	                    write(" ");
	                    emitDeclarationName(node);
	                }
	                var baseTypeNode = ts.getClassExtendsHeritageClauseElement(node);
	                if (baseTypeNode) {
	                    write(" extends ");
	                    emit(baseTypeNode.expression);
	                }
	                write(" {");
	                increaseIndent();
	                writeLine();
	                emitConstructor(node, baseTypeNode);
	                emitMemberFunctionsForES6AndHigher(node);
	                decreaseIndent();
	                writeLine();
	                emitToken(16 /* CloseBraceToken */, node.members.end);
	                if (thisNodeIsDecorated) {
	                    decoratedClassAliases[ts.getNodeId(node)] = undefined;
	                    write(";");
	                }
	                // Emit static property assignment. Because classDeclaration is lexically evaluated,
	                // it is safe to emit static property assignment after classDeclaration
	                // From ES6 specification:
	                //      HasLexicalDeclaration (N) : Determines if the argument identifier has a binding in this environment record that was created using
	                //                                  a lexical declaration such as a LexicalDeclaration or a ClassDeclaration.
	                if (isClassExpressionWithStaticProperties) {
	                    for (var _a = 0, staticProperties_1 = staticProperties; _a < staticProperties_1.length; _a++) {
	                        var property = staticProperties_1[_a];
	                        write(",");
	                        writeLine();
	                        emitPropertyDeclaration(node, property, /*receiver*/ tempVariable, /*isExpression*/ true);
	                    }
	                    write(",");
	                    writeLine();
	                    emit(tempVariable);
	                    decreaseIndent();
	                    write(")");
	                }
	                else {
	                    writeLine();
	                    emitPropertyDeclarations(node, staticProperties);
	                    emitDecoratorsOfClass(node, decoratedClassAlias);
	                }
	                if (!(node.flags & 2 /* Export */)) {
	                    return;
	                }
	                if (modulekind !== 5 /* ES6 */) {
	                    emitExportMemberAssignment(node);
	                }
	                else {
	                    // If this is an exported class, but not on the top level (i.e. on an internal
	                    // module), export it
	                    if (node.flags & 512 /* Default */) {
	                        // if this is a top level default export of decorated class, write the export after the declaration.
	                        if (thisNodeIsDecorated) {
	                            writeLine();
	                            write("export default ");
	                            emitDeclarationName(node);
	                            write(";");
	                        }
	                    }
	                    else if (node.parent.kind !== 251 /* SourceFile */) {
	                        writeLine();
	                        emitStart(node);
	                        emitModuleMemberName(node);
	                        write(" = ");
	                        emitDeclarationName(node);
	                        emitEnd(node);
	                        write(";");
	                    }
	                }
	            }
	            function emitClassLikeDeclarationBelowES6(node) {
	                if (node.kind === 217 /* ClassDeclaration */) {
	                    // source file level classes in system modules are hoisted so 'var's for them are already defined
	                    if (!shouldHoistDeclarationInSystemJsModule(node)) {
	                        write("var ");
	                    }
	                    emitDeclarationName(node);
	                    write(" = ");
	                }
	                write("(function (");
	                var baseTypeNode = ts.getClassExtendsHeritageClauseElement(node);
	                if (baseTypeNode) {
	                    write("_super");
	                }
	                write(") {");
	                var saveTempFlags = tempFlags;
	                var saveTempVariables = tempVariables;
	                var saveTempParameters = tempParameters;
	                var saveComputedPropertyNamesToGeneratedNames = computedPropertyNamesToGeneratedNames;
	                var saveConvertedLoopState = convertedLoopState;
	                convertedLoopState = undefined;
	                tempFlags = 0;
	                tempVariables = undefined;
	                tempParameters = undefined;
	                computedPropertyNamesToGeneratedNames = undefined;
	                increaseIndent();
	                if (baseTypeNode) {
	                    writeLine();
	                    emitStart(baseTypeNode);
	                    write("__extends(");
	                    emitDeclarationName(node);
	                    write(", _super);");
	                    emitEnd(baseTypeNode);
	                }
	                writeLine();
	                emitConstructor(node, baseTypeNode);
	                emitMemberFunctionsForES5AndLower(node);
	                emitPropertyDeclarations(node, getInitializedProperties(node, /*isStatic*/ true));
	                writeLine();
	                emitDecoratorsOfClass(node, /*decoratedClassAlias*/ undefined);
	                writeLine();
	                emitToken(16 /* CloseBraceToken */, node.members.end, function () {
	                    write("return ");
	                    emitDeclarationName(node);
	                });
	                write(";");
	                emitTempDeclarations(/*newLine*/ true);
	                ts.Debug.assert(convertedLoopState === undefined);
	                convertedLoopState = saveConvertedLoopState;
	                tempFlags = saveTempFlags;
	                tempVariables = saveTempVariables;
	                tempParameters = saveTempParameters;
	                computedPropertyNamesToGeneratedNames = saveComputedPropertyNamesToGeneratedNames;
	                decreaseIndent();
	                writeLine();
	                emitToken(16 /* CloseBraceToken */, node.members.end);
	                emitStart(node);
	                write("(");
	                if (baseTypeNode) {
	                    emit(baseTypeNode.expression);
	                }
	                write("))");
	                if (node.kind === 217 /* ClassDeclaration */) {
	                    write(";");
	                }
	                emitEnd(node);
	                if (node.kind === 217 /* ClassDeclaration */) {
	                    emitExportMemberAssignment(node);
	                }
	            }
	            function emitClassMemberPrefix(node, member) {
	                emitDeclarationName(node);
	                if (!(member.flags & 64 /* Static */)) {
	                    write(".prototype");
	                }
	            }
	            function emitDecoratorsOfClass(node, decoratedClassAlias) {
	                emitDecoratorsOfMembers(node, /*staticFlag*/ 0);
	                emitDecoratorsOfMembers(node, 64 /* Static */);
	                emitDecoratorsOfConstructor(node, decoratedClassAlias);
	            }
	            function emitDecoratorsOfConstructor(node, decoratedClassAlias) {
	                var decorators = node.decorators;
	                var constructor = ts.getFirstConstructorWithBody(node);
	                var firstParameterDecorator = constructor && ts.forEach(constructor.parameters, function (parameter) { return parameter.decorators; });
	                // skip decoration of the constructor if neither it nor its parameters are decorated
	                if (!decorators && !firstParameterDecorator) {
	                    return;
	                }
	                // Emit the call to __decorate. Given the class:
	                //
	                //   @dec
	                //   class C {
	                //   }
	                //
	                // The emit for the class is:
	                //
	                //   C = __decorate([dec], C);
	                //
	                writeLine();
	                emitStart(node.decorators || firstParameterDecorator);
	                emitDeclarationName(node);
	                if (decoratedClassAlias !== undefined) {
	                    write(" = " + decoratedClassAlias);
	                }
	                write(" = __decorate([");
	                increaseIndent();
	                writeLine();
	                var decoratorCount = decorators ? decorators.length : 0;
	                var argumentsWritten = emitList(decorators, 0, decoratorCount, /*multiLine*/ true, /*trailingComma*/ false, /*leadingComma*/ false, /*noTrailingNewLine*/ true, function (decorator) { return emit(decorator.expression); });
	                if (firstParameterDecorator) {
	                    argumentsWritten += emitDecoratorsOfParameters(constructor, /*leadingComma*/ argumentsWritten > 0);
	                }
	                emitSerializedTypeMetadata(node, /*leadingComma*/ argumentsWritten >= 0);
	                decreaseIndent();
	                writeLine();
	                write("], ");
	                emitDeclarationName(node);
	                write(")");
	                emitEnd(node.decorators || firstParameterDecorator);
	                write(";");
	                writeLine();
	            }
	            function emitDecoratorsOfMembers(node, staticFlag) {
	                for (var _a = 0, _b = node.members; _a < _b.length; _a++) {
	                    var member = _b[_a];
	                    // only emit members in the correct group
	                    if ((member.flags & 64 /* Static */) !== staticFlag) {
	                        continue;
	                    }
	                    // skip members that cannot be decorated (such as the constructor)
	                    if (!ts.nodeCanBeDecorated(member)) {
	                        continue;
	                    }
	                    // skip an accessor declaration if it is not the first accessor
	                    var decorators = void 0;
	                    var functionLikeMember = void 0;
	                    if (ts.isAccessor(member)) {
	                        var accessors = ts.getAllAccessorDeclarations(node.members, member);
	                        if (member !== accessors.firstAccessor) {
	                            continue;
	                        }
	                        // get the decorators from the first accessor with decorators
	                        decorators = accessors.firstAccessor.decorators;
	                        if (!decorators && accessors.secondAccessor) {
	                            decorators = accessors.secondAccessor.decorators;
	                        }
	                        // we only decorate parameters of the set accessor
	                        functionLikeMember = accessors.setAccessor;
	                    }
	                    else {
	                        decorators = member.decorators;
	                        // we only decorate the parameters here if this is a method
	                        if (member.kind === 144 /* MethodDeclaration */) {
	                            functionLikeMember = member;
	                        }
	                    }
	                    var firstParameterDecorator = functionLikeMember && ts.forEach(functionLikeMember.parameters, function (parameter) { return parameter.decorators; });
	                    // skip a member if it or any of its parameters are not decorated
	                    if (!decorators && !firstParameterDecorator) {
	                        continue;
	                    }
	                    // Emit the call to __decorate. Given the following:
	                    //
	                    //   class C {
	                    //     @dec method(@dec2 x) {}
	                    //     @dec get accessor() {}
	                    //     @dec prop;
	                    //   }
	                    //
	                    // The emit for a method is:
	                    //
	                    //   __decorate([
	                    //       dec,
	                    //       __param(0, dec2),
	                    //       __metadata("design:type", Function),
	                    //       __metadata("design:paramtypes", [Object]),
	                    //       __metadata("design:returntype", void 0)
	                    //   ], C.prototype, "method", undefined);
	                    //
	                    // The emit for an accessor is:
	                    //
	                    //   __decorate([
	                    //       dec
	                    //   ], C.prototype, "accessor", undefined);
	                    //
	                    // The emit for a property is:
	                    //
	                    //   __decorate([
	                    //       dec
	                    //   ], C.prototype, "prop");
	                    //
	                    writeLine();
	                    emitStart(decorators || firstParameterDecorator);
	                    write("__decorate([");
	                    increaseIndent();
	                    writeLine();
	                    var decoratorCount = decorators ? decorators.length : 0;
	                    var argumentsWritten = emitList(decorators, 0, decoratorCount, /*multiLine*/ true, /*trailingComma*/ false, /*leadingComma*/ false, /*noTrailingNewLine*/ true, function (decorator) { return emit(decorator.expression); });
	                    if (firstParameterDecorator) {
	                        argumentsWritten += emitDecoratorsOfParameters(functionLikeMember, argumentsWritten > 0);
	                    }
	                    emitSerializedTypeMetadata(member, argumentsWritten > 0);
	                    decreaseIndent();
	                    writeLine();
	                    write("], ");
	                    emitClassMemberPrefix(node, member);
	                    write(", ");
	                    emitExpressionForPropertyName(member.name);
	                    if (languageVersion > 0 /* ES3 */) {
	                        if (member.kind !== 142 /* PropertyDeclaration */) {
	                            // We emit `null` here to indicate to `__decorate` that it can invoke `Object.getOwnPropertyDescriptor` directly.
	                            // We have this extra argument here so that we can inject an explicit property descriptor at a later date.
	                            write(", null");
	                        }
	                        else {
	                            // We emit `void 0` here to indicate to `__decorate` that it can invoke `Object.defineProperty` directly, but that it
	                            // should not invoke `Object.getOwnPropertyDescriptor`.
	                            write(", void 0");
	                        }
	                    }
	                    write(")");
	                    emitEnd(decorators || firstParameterDecorator);
	                    write(";");
	                    writeLine();
	                }
	            }
	            function emitDecoratorsOfParameters(node, leadingComma) {
	                var argumentsWritten = 0;
	                if (node) {
	                    var parameterIndex_1 = 0;
	                    for (var _a = 0, _b = node.parameters; _a < _b.length; _a++) {
	                        var parameter = _b[_a];
	                        if (ts.nodeIsDecorated(parameter)) {
	                            var decorators = parameter.decorators;
	                            argumentsWritten += emitList(decorators, 0, decorators.length, /*multiLine*/ true, /*trailingComma*/ false, /*leadingComma*/ leadingComma, /*noTrailingNewLine*/ true, function (decorator) {
	                                write("__param(" + parameterIndex_1 + ", ");
	                                emit(decorator.expression);
	                                write(")");
	                            });
	                            leadingComma = true;
	                        }
	                        parameterIndex_1++;
	                    }
	                }
	                return argumentsWritten;
	            }
	            function shouldEmitTypeMetadata(node) {
	                // This method determines whether to emit the "design:type" metadata based on the node's kind.
	                // The caller should have already tested whether the node has decorators and whether the emitDecoratorMetadata
	                // compiler option is set.
	                switch (node.kind) {
	                    case 144 /* MethodDeclaration */:
	                    case 146 /* GetAccessor */:
	                    case 147 /* SetAccessor */:
	                    case 142 /* PropertyDeclaration */:
	                        return true;
	                }
	                return false;
	            }
	            function shouldEmitReturnTypeMetadata(node) {
	                // This method determines whether to emit the "design:returntype" metadata based on the node's kind.
	                // The caller should have already tested whether the node has decorators and whether the emitDecoratorMetadata
	                // compiler option is set.
	                switch (node.kind) {
	                    case 144 /* MethodDeclaration */:
	                        return true;
	                }
	                return false;
	            }
	            function shouldEmitParamTypesMetadata(node) {
	                // This method determines whether to emit the "design:paramtypes" metadata based on the node's kind.
	                // The caller should have already tested whether the node has decorators and whether the emitDecoratorMetadata
	                // compiler option is set.
	                switch (node.kind) {
	                    case 217 /* ClassDeclaration */:
	                    case 144 /* MethodDeclaration */:
	                    case 147 /* SetAccessor */:
	                        return true;
	                }
	                return false;
	            }
	            /** Serializes the type of a declaration to an appropriate JS constructor value. Used by the __metadata decorator for a class member. */
	            function emitSerializedTypeOfNode(node) {
	                // serialization of the type of a declaration uses the following rules:
	                //
	                // * The serialized type of a ClassDeclaration is "Function"
	                // * The serialized type of a ParameterDeclaration is the serialized type of its type annotation.
	                // * The serialized type of a PropertyDeclaration is the serialized type of its type annotation.
	                // * The serialized type of an AccessorDeclaration is the serialized type of the return type annotation of its getter or parameter type annotation of its setter.
	                // * The serialized type of any other FunctionLikeDeclaration is "Function".
	                // * The serialized type of any other node is "void 0".
	                //
	                // For rules on serializing type annotations, see `serializeTypeNode`.
	                switch (node.kind) {
	                    case 217 /* ClassDeclaration */:
	                        write("Function");
	                        return;
	                    case 142 /* PropertyDeclaration */:
	                        emitSerializedTypeNode(node.type);
	                        return;
	                    case 139 /* Parameter */:
	                        emitSerializedTypeNode(node.type);
	                        return;
	                    case 146 /* GetAccessor */:
	                        emitSerializedTypeNode(node.type);
	                        return;
	                    case 147 /* SetAccessor */:
	                        emitSerializedTypeNode(ts.getSetAccessorTypeAnnotationNode(node));
	                        return;
	                }
	                if (ts.isFunctionLike(node)) {
	                    write("Function");
	                    return;
	                }
	                write("void 0");
	            }
	            function emitSerializedTypeNode(node) {
	                if (node) {
	                    switch (node.kind) {
	                        case 103 /* VoidKeyword */:
	                            write("void 0");
	                            return;
	                        case 161 /* ParenthesizedType */:
	                            emitSerializedTypeNode(node.type);
	                            return;
	                        case 153 /* FunctionType */:
	                        case 154 /* ConstructorType */:
	                            write("Function");
	                            return;
	                        case 157 /* ArrayType */:
	                        case 158 /* TupleType */:
	                            write("Array");
	                            return;
	                        case 151 /* TypePredicate */:
	                        case 120 /* BooleanKeyword */:
	                            write("Boolean");
	                            return;
	                        case 130 /* StringKeyword */:
	                        case 163 /* StringLiteralType */:
	                            write("String");
	                            return;
	                        case 128 /* NumberKeyword */:
	                            write("Number");
	                            return;
	                        case 131 /* SymbolKeyword */:
	                            write("Symbol");
	                            return;
	                        case 152 /* TypeReference */:
	                            emitSerializedTypeReferenceNode(node);
	                            return;
	                        case 155 /* TypeQuery */:
	                        case 156 /* TypeLiteral */:
	                        case 159 /* UnionType */:
	                        case 160 /* IntersectionType */:
	                        case 117 /* AnyKeyword */:
	                        case 162 /* ThisType */:
	                            break;
	                        default:
	                            ts.Debug.fail("Cannot serialize unexpected type node.");
	                            break;
	                    }
	                }
	                write("Object");
	            }
	            /** Serializes a TypeReferenceNode to an appropriate JS constructor value. Used by the __metadata decorator. */
	            function emitSerializedTypeReferenceNode(node) {
	                var location = node.parent;
	                while (ts.isDeclaration(location) || ts.isTypeNode(location)) {
	                    location = location.parent;
	                }
	                // Clone the type name and parent it to a location outside of the current declaration.
	                var typeName = ts.cloneEntityName(node.typeName, location);
	                var result = resolver.getTypeReferenceSerializationKind(typeName);
	                switch (result) {
	                    case ts.TypeReferenceSerializationKind.Unknown:
	                        var temp = createAndRecordTempVariable(0 /* Auto */);
	                        write("(typeof (");
	                        emitNodeWithoutSourceMap(temp);
	                        write(" = ");
	                        emitEntityNameAsExpression(typeName, /*useFallback*/ true);
	                        write(") === 'function' && ");
	                        emitNodeWithoutSourceMap(temp);
	                        write(") || Object");
	                        break;
	                    case ts.TypeReferenceSerializationKind.TypeWithConstructSignatureAndValue:
	                        emitEntityNameAsExpression(typeName, /*useFallback*/ false);
	                        break;
	                    case ts.TypeReferenceSerializationKind.VoidType:
	                        write("void 0");
	                        break;
	                    case ts.TypeReferenceSerializationKind.BooleanType:
	                        write("Boolean");
	                        break;
	                    case ts.TypeReferenceSerializationKind.NumberLikeType:
	                        write("Number");
	                        break;
	                    case ts.TypeReferenceSerializationKind.StringLikeType:
	                        write("String");
	                        break;
	                    case ts.TypeReferenceSerializationKind.ArrayLikeType:
	                        write("Array");
	                        break;
	                    case ts.TypeReferenceSerializationKind.ESSymbolType:
	                        if (languageVersion < 2 /* ES6 */) {
	                            write("typeof Symbol === 'function' ? Symbol : Object");
	                        }
	                        else {
	                            write("Symbol");
	                        }
	                        break;
	                    case ts.TypeReferenceSerializationKind.TypeWithCallSignature:
	                        write("Function");
	                        break;
	                    case ts.TypeReferenceSerializationKind.ObjectType:
	                        write("Object");
	                        break;
	                }
	            }
	            /** Serializes the parameter types of a function or the constructor of a class. Used by the __metadata decorator for a method or set accessor. */
	            function emitSerializedParameterTypesOfNode(node) {
	                // serialization of parameter types uses the following rules:
	                //
	                // * If the declaration is a class, the parameters of the first constructor with a body are used.
	                // * If the declaration is function-like and has a body, the parameters of the function are used.
	                //
	                // For the rules on serializing the type of each parameter declaration, see `serializeTypeOfDeclaration`.
	                if (node) {
	                    var valueDeclaration = void 0;
	                    if (node.kind === 217 /* ClassDeclaration */) {
	                        valueDeclaration = ts.getFirstConstructorWithBody(node);
	                    }
	                    else if (ts.isFunctionLike(node) && ts.nodeIsPresent(node.body)) {
	                        valueDeclaration = node;
	                    }
	                    if (valueDeclaration) {
	                        var parameters = valueDeclaration.parameters;
	                        var parameterCount = parameters.length;
	                        if (parameterCount > 0) {
	                            for (var i = 0; i < parameterCount; i++) {
	                                if (i > 0) {
	                                    write(", ");
	                                }
	                                if (parameters[i].dotDotDotToken) {
	                                    var parameterType = parameters[i].type;
	                                    if (parameterType.kind === 157 /* ArrayType */) {
	                                        parameterType = parameterType.elementType;
	                                    }
	                                    else if (parameterType.kind === 152 /* TypeReference */ && parameterType.typeArguments && parameterType.typeArguments.length === 1) {
	                                        parameterType = parameterType.typeArguments[0];
	                                    }
	                                    else {
	                                        parameterType = undefined;
	                                    }
	                                    emitSerializedTypeNode(parameterType);
	                                }
	                                else {
	                                    emitSerializedTypeOfNode(parameters[i]);
	                                }
	                            }
	                        }
	                    }
	                }
	            }
	            /** Serializes the return type of function. Used by the __metadata decorator for a method. */
	            function emitSerializedReturnTypeOfNode(node) {
	                if (node && ts.isFunctionLike(node) && node.type) {
	                    emitSerializedTypeNode(node.type);
	                    return;
	                }
	                write("void 0");
	            }
	            function emitSerializedTypeMetadata(node, writeComma) {
	                // This method emits the serialized type metadata for a decorator target.
	                // The caller should have already tested whether the node has decorators.
	                var argumentsWritten = 0;
	                if (compilerOptions.emitDecoratorMetadata) {
	                    if (shouldEmitTypeMetadata(node)) {
	                        if (writeComma) {
	                            write(", ");
	                        }
	                        writeLine();
	                        write("__metadata('design:type', ");
	                        emitSerializedTypeOfNode(node);
	                        write(")");
	                        argumentsWritten++;
	                    }
	                    if (shouldEmitParamTypesMetadata(node)) {
	                        if (writeComma || argumentsWritten) {
	                            write(", ");
	                        }
	                        writeLine();
	                        write("__metadata('design:paramtypes', [");
	                        emitSerializedParameterTypesOfNode(node);
	                        write("])");
	                        argumentsWritten++;
	                    }
	                    if (shouldEmitReturnTypeMetadata(node)) {
	                        if (writeComma || argumentsWritten) {
	                            write(", ");
	                        }
	                        writeLine();
	                        write("__metadata('design:returntype', ");
	                        emitSerializedReturnTypeOfNode(node);
	                        write(")");
	                        argumentsWritten++;
	                    }
	                }
	                return argumentsWritten;
	            }
	            function emitInterfaceDeclaration(node) {
	                emitCommentsOnNotEmittedNode(node);
	            }
	            function shouldEmitEnumDeclaration(node) {
	                var isConstEnum = ts.isConst(node);
	                return !isConstEnum || compilerOptions.preserveConstEnums || compilerOptions.isolatedModules;
	            }
	            function emitEnumDeclaration(node) {
	                // const enums are completely erased during compilation.
	                if (!shouldEmitEnumDeclaration(node)) {
	                    return;
	                }
	                if (!shouldHoistDeclarationInSystemJsModule(node)) {
	                    // do not emit var if variable was already hoisted
	                    var isES6ExportedEnum = isES6ExportedDeclaration(node);
	                    if (!(node.flags & 2 /* Export */) || (isES6ExportedEnum && isFirstDeclarationOfKind(node, node.symbol && node.symbol.declarations, 220 /* EnumDeclaration */))) {
	                        emitStart(node);
	                        if (isES6ExportedEnum) {
	                            write("export ");
	                        }
	                        write("var ");
	                        emit(node.name);
	                        emitEnd(node);
	                        write(";");
	                    }
	                }
	                writeLine();
	                emitStart(node);
	                write("(function (");
	                emitStart(node.name);
	                write(getGeneratedNameForNode(node));
	                emitEnd(node.name);
	                write(") {");
	                increaseIndent();
	                emitLines(node.members);
	                decreaseIndent();
	                writeLine();
	                emitToken(16 /* CloseBraceToken */, node.members.end);
	                write(")(");
	                emitModuleMemberName(node);
	                write(" || (");
	                emitModuleMemberName(node);
	                write(" = {}));");
	                emitEnd(node);
	                if (!isES6ExportedDeclaration(node) && node.flags & 2 /* Export */ && !shouldHoistDeclarationInSystemJsModule(node)) {
	                    // do not emit var if variable was already hoisted
	                    writeLine();
	                    emitStart(node);
	                    write("var ");
	                    emit(node.name);
	                    write(" = ");
	                    emitModuleMemberName(node);
	                    emitEnd(node);
	                    write(";");
	                }
	                if (modulekind !== 5 /* ES6 */ && node.parent === currentSourceFile) {
	                    if (modulekind === 4 /* System */ && (node.flags & 2 /* Export */)) {
	                        // write the call to exporter for enum
	                        writeLine();
	                        write(exportFunctionForFile + "(\"");
	                        emitDeclarationName(node);
	                        write("\", ");
	                        emitDeclarationName(node);
	                        write(");");
	                    }
	                    emitExportMemberAssignments(node.name);
	                }
	            }
	            function emitEnumMember(node) {
	                var enumParent = node.parent;
	                emitStart(node);
	                write(getGeneratedNameForNode(enumParent));
	                write("[");
	                write(getGeneratedNameForNode(enumParent));
	                write("[");
	                emitExpressionForPropertyName(node.name);
	                write("] = ");
	                writeEnumMemberDeclarationValue(node);
	                write("] = ");
	                emitExpressionForPropertyName(node.name);
	                emitEnd(node);
	                write(";");
	            }
	            function writeEnumMemberDeclarationValue(member) {
	                var value = resolver.getConstantValue(member);
	                if (value !== undefined) {
	                    write(value.toString());
	                    return;
	                }
	                else if (member.initializer) {
	                    emit(member.initializer);
	                }
	                else {
	                    write("undefined");
	                }
	            }
	            function getInnerMostModuleDeclarationFromDottedModule(moduleDeclaration) {
	                if (moduleDeclaration.body.kind === 221 /* ModuleDeclaration */) {
	                    var recursiveInnerModule = getInnerMostModuleDeclarationFromDottedModule(moduleDeclaration.body);
	                    return recursiveInnerModule || moduleDeclaration.body;
	                }
	            }
	            function shouldEmitModuleDeclaration(node) {
	                return ts.isInstantiatedModule(node, compilerOptions.preserveConstEnums || compilerOptions.isolatedModules);
	            }
	            function isModuleMergedWithES6Class(node) {
	                return languageVersion === 2 /* ES6 */ && !!(resolver.getNodeCheckFlags(node) & 32768 /* LexicalModuleMergesWithClass */);
	            }
	            function isFirstDeclarationOfKind(node, declarations, kind) {
	                return !ts.forEach(declarations, function (declaration) { return declaration.kind === kind && declaration.pos < node.pos; });
	            }
	            function emitModuleDeclaration(node) {
	                // Emit only if this module is non-ambient.
	                var shouldEmit = shouldEmitModuleDeclaration(node);
	                if (!shouldEmit) {
	                    return emitCommentsOnNotEmittedNode(node);
	                }
	                var hoistedInDeclarationScope = shouldHoistDeclarationInSystemJsModule(node);
	                var emitVarForModule = !hoistedInDeclarationScope && !isModuleMergedWithES6Class(node);
	                if (emitVarForModule) {
	                    var isES6ExportedNamespace = isES6ExportedDeclaration(node);
	                    if (!isES6ExportedNamespace || isFirstDeclarationOfKind(node, node.symbol && node.symbol.declarations, 221 /* ModuleDeclaration */)) {
	                        emitStart(node);
	                        if (isES6ExportedNamespace) {
	                            write("export ");
	                        }
	                        write("var ");
	                        emit(node.name);
	                        write(";");
	                        emitEnd(node);
	                        writeLine();
	                    }
	                }
	                emitStart(node);
	                write("(function (");
	                emitStart(node.name);
	                write(getGeneratedNameForNode(node));
	                emitEnd(node.name);
	                write(") ");
	                if (node.body.kind === 222 /* ModuleBlock */) {
	                    var saveConvertedLoopState = convertedLoopState;
	                    var saveTempFlags = tempFlags;
	                    var saveTempVariables = tempVariables;
	                    convertedLoopState = undefined;
	                    tempFlags = 0;
	                    tempVariables = undefined;
	                    emit(node.body);
	                    ts.Debug.assert(convertedLoopState === undefined);
	                    convertedLoopState = saveConvertedLoopState;
	                    tempFlags = saveTempFlags;
	                    tempVariables = saveTempVariables;
	                }
	                else {
	                    write("{");
	                    increaseIndent();
	                    emitCaptureThisForNodeIfNecessary(node);
	                    writeLine();
	                    emit(node.body);
	                    decreaseIndent();
	                    writeLine();
	                    var moduleBlock = getInnerMostModuleDeclarationFromDottedModule(node).body;
	                    emitToken(16 /* CloseBraceToken */, moduleBlock.statements.end);
	                }
	                write(")(");
	                // write moduleDecl = containingModule.m only if it is not exported es6 module member
	                if ((node.flags & 2 /* Export */) && !isES6ExportedDeclaration(node)) {
	                    emit(node.name);
	                    write(" = ");
	                }
	                emitModuleMemberName(node);
	                write(" || (");
	                emitModuleMemberName(node);
	                write(" = {}));");
	                emitEnd(node);
	                if (!isES6ExportedDeclaration(node) && node.name.kind === 69 /* Identifier */ && node.parent === currentSourceFile) {
	                    if (modulekind === 4 /* System */ && (node.flags & 2 /* Export */)) {
	                        writeLine();
	                        write(exportFunctionForFile + "(\"");
	                        emitDeclarationName(node);
	                        write("\", ");
	                        emitDeclarationName(node);
	                        write(");");
	                    }
	                    emitExportMemberAssignments(node.name);
	                }
	            }
	            /*
	             * Some bundlers (SystemJS builder) sometimes want to rename dependencies.
	             * Here we check if alternative name was provided for a given moduleName and return it if possible.
	             */
	            function tryRenameExternalModule(moduleName) {
	                if (renamedDependencies && ts.hasProperty(renamedDependencies, moduleName.text)) {
	                    return "\"" + renamedDependencies[moduleName.text] + "\"";
	                }
	                return undefined;
	            }
	            function emitRequire(moduleName) {
	                if (moduleName.kind === 9 /* StringLiteral */) {
	                    write("require(");
	                    var text = tryRenameExternalModule(moduleName);
	                    if (text) {
	                        write(text);
	                    }
	                    else {
	                        emitStart(moduleName);
	                        emitLiteral(moduleName);
	                        emitEnd(moduleName);
	                    }
	                    emitToken(18 /* CloseParenToken */, moduleName.end);
	                }
	                else {
	                    write("require()");
	                }
	            }
	            function getNamespaceDeclarationNode(node) {
	                if (node.kind === 224 /* ImportEqualsDeclaration */) {
	                    return node;
	                }
	                var importClause = node.importClause;
	                if (importClause && importClause.namedBindings && importClause.namedBindings.kind === 227 /* NamespaceImport */) {
	                    return importClause.namedBindings;
	                }
	            }
	            function isDefaultImport(node) {
	                return node.kind === 225 /* ImportDeclaration */ && node.importClause && !!node.importClause.name;
	            }
	            function emitExportImportAssignments(node) {
	                if (ts.isAliasSymbolDeclaration(node) && resolver.isValueAliasDeclaration(node)) {
	                    emitExportMemberAssignments(node.name);
	                }
	                ts.forEachChild(node, emitExportImportAssignments);
	            }
	            function emitImportDeclaration(node) {
	                if (modulekind !== 5 /* ES6 */) {
	                    return emitExternalImportDeclaration(node);
	                }
	                // ES6 import
	                if (node.importClause) {
	                    var shouldEmitDefaultBindings = resolver.isReferencedAliasDeclaration(node.importClause);
	                    var shouldEmitNamedBindings = node.importClause.namedBindings && resolver.isReferencedAliasDeclaration(node.importClause.namedBindings, /* checkChildren */ true);
	                    if (shouldEmitDefaultBindings || shouldEmitNamedBindings) {
	                        write("import ");
	                        emitStart(node.importClause);
	                        if (shouldEmitDefaultBindings) {
	                            emit(node.importClause.name);
	                            if (shouldEmitNamedBindings) {
	                                write(", ");
	                            }
	                        }
	                        if (shouldEmitNamedBindings) {
	                            emitLeadingComments(node.importClause.namedBindings);
	                            emitStart(node.importClause.namedBindings);
	                            if (node.importClause.namedBindings.kind === 227 /* NamespaceImport */) {
	                                write("* as ");
	                                emit(node.importClause.namedBindings.name);
	                            }
	                            else {
	                                write("{ ");
	                                emitExportOrImportSpecifierList(node.importClause.namedBindings.elements, resolver.isReferencedAliasDeclaration);
	                                write(" }");
	                            }
	                            emitEnd(node.importClause.namedBindings);
	                            emitTrailingComments(node.importClause.namedBindings);
	                        }
	                        emitEnd(node.importClause);
	                        write(" from ");
	                        emit(node.moduleSpecifier);
	                        write(";");
	                    }
	                }
	                else {
	                    write("import ");
	                    emit(node.moduleSpecifier);
	                    write(";");
	                }
	            }
	            function emitExternalImportDeclaration(node) {
	                if (ts.contains(externalImports, node)) {
	                    var isExportedImport = node.kind === 224 /* ImportEqualsDeclaration */ && (node.flags & 2 /* Export */) !== 0;
	                    var namespaceDeclaration = getNamespaceDeclarationNode(node);
	                    var varOrConst = (languageVersion <= 1 /* ES5 */) ? "var " : "const ";
	                    if (modulekind !== 2 /* AMD */) {
	                        emitLeadingComments(node);
	                        emitStart(node);
	                        if (namespaceDeclaration && !isDefaultImport(node)) {
	                            // import x = require("foo")
	                            // import * as x from "foo"
	                            if (!isExportedImport) {
	                                write(varOrConst);
	                            }
	                            ;
	                            emitModuleMemberName(namespaceDeclaration);
	                            write(" = ");
	                        }
	                        else {
	                            // import "foo"
	                            // import x from "foo"
	                            // import { x, y } from "foo"
	                            // import d, * as x from "foo"
	                            // import d, { x, y } from "foo"
	                            var isNakedImport = 225 /* ImportDeclaration */ && !node.importClause;
	                            if (!isNakedImport) {
	                                write(varOrConst);
	                                write(getGeneratedNameForNode(node));
	                                write(" = ");
	                            }
	                        }
	                        emitRequire(ts.getExternalModuleName(node));
	                        if (namespaceDeclaration && isDefaultImport(node)) {
	                            // import d, * as x from "foo"
	                            write(", ");
	                            emitModuleMemberName(namespaceDeclaration);
	                            write(" = ");
	                            write(getGeneratedNameForNode(node));
	                        }
	                        write(";");
	                        emitEnd(node);
	                        emitExportImportAssignments(node);
	                        emitTrailingComments(node);
	                    }
	                    else {
	                        if (isExportedImport) {
	                            emitModuleMemberName(namespaceDeclaration);
	                            write(" = ");
	                            emit(namespaceDeclaration.name);
	                            write(";");
	                        }
	                        else if (namespaceDeclaration && isDefaultImport(node)) {
	                            // import d, * as x from "foo"
	                            write(varOrConst);
	                            emitModuleMemberName(namespaceDeclaration);
	                            write(" = ");
	                            write(getGeneratedNameForNode(node));
	                            write(";");
	                        }
	                        emitExportImportAssignments(node);
	                    }
	                }
	            }
	            function emitImportEqualsDeclaration(node) {
	                if (ts.isExternalModuleImportEqualsDeclaration(node)) {
	                    emitExternalImportDeclaration(node);
	                    return;
	                }
	                // preserve old compiler's behavior: emit 'var' for import declaration (even if we do not consider them referenced) when
	                // - current file is not external module
	                // - import declaration is top level and target is value imported by entity name
	                if (resolver.isReferencedAliasDeclaration(node) ||
	                    (!isCurrentFileExternalModule && resolver.isTopLevelValueImportEqualsWithEntityName(node))) {
	                    emitLeadingComments(node);
	                    emitStart(node);
	                    // variable declaration for import-equals declaration can be hoisted in system modules
	                    // in this case 'var' should be omitted and emit should contain only initialization
	                    var variableDeclarationIsHoisted = shouldHoistVariable(node, /*checkIfSourceFileLevelDecl*/ true);
	                    // is it top level export import v = a.b.c in system module?
	                    // if yes - it needs to be rewritten as exporter('v', v = a.b.c)
	                    var isExported = isSourceFileLevelDeclarationInSystemJsModule(node, /*isExported*/ true);
	                    if (!variableDeclarationIsHoisted) {
	                        ts.Debug.assert(!isExported);
	                        if (isES6ExportedDeclaration(node)) {
	                            write("export ");
	                            write("var ");
	                        }
	                        else if (!(node.flags & 2 /* Export */)) {
	                            write("var ");
	                        }
	                    }
	                    if (isExported) {
	                        write(exportFunctionForFile + "(\"");
	                        emitNodeWithoutSourceMap(node.name);
	                        write("\", ");
	                    }
	                    emitModuleMemberName(node);
	                    write(" = ");
	                    emit(node.moduleReference);
	                    if (isExported) {
	                        write(")");
	                    }
	                    write(";");
	                    emitEnd(node);
	                    emitExportImportAssignments(node);
	                    emitTrailingComments(node);
	                }
	            }
	            function emitExportDeclaration(node) {
	                ts.Debug.assert(modulekind !== 4 /* System */);
	                if (modulekind !== 5 /* ES6 */) {
	                    if (node.moduleSpecifier && (!node.exportClause || resolver.isValueAliasDeclaration(node))) {
	                        emitStart(node);
	                        var generatedName = getGeneratedNameForNode(node);
	                        if (node.exportClause) {
	                            // export { x, y, ... } from "foo"
	                            if (modulekind !== 2 /* AMD */) {
	                                write("var ");
	                                write(generatedName);
	                                write(" = ");
	                                emitRequire(ts.getExternalModuleName(node));
	                                write(";");
	                            }
	                            for (var _a = 0, _b = node.exportClause.elements; _a < _b.length; _a++) {
	                                var specifier = _b[_a];
	                                if (resolver.isValueAliasDeclaration(specifier)) {
	                                    writeLine();
	                                    emitStart(specifier);
	                                    emitContainingModuleName(specifier);
	                                    write(".");
	                                    emitNodeWithCommentsAndWithoutSourcemap(specifier.name);
	                                    write(" = ");
	                                    write(generatedName);
	                                    write(".");
	                                    emitNodeWithCommentsAndWithoutSourcemap(specifier.propertyName || specifier.name);
	                                    write(";");
	                                    emitEnd(specifier);
	                                }
	                            }
	                        }
	                        else {
	                            // export * from "foo"
	                            if (hasExportStarsToExportValues && resolver.moduleExportsSomeValue(node.moduleSpecifier)) {
	                                writeLine();
	                                write("__export(");
	                                if (modulekind !== 2 /* AMD */) {
	                                    emitRequire(ts.getExternalModuleName(node));
	                                }
	                                else {
	                                    write(generatedName);
	                                }
	                                write(");");
	                            }
	                        }
	                        emitEnd(node);
	                    }
	                }
	                else {
	                    if (!node.exportClause || resolver.isValueAliasDeclaration(node)) {
	                        write("export ");
	                        if (node.exportClause) {
	                            // export { x, y, ... }
	                            write("{ ");
	                            emitExportOrImportSpecifierList(node.exportClause.elements, resolver.isValueAliasDeclaration);
	                            write(" }");
	                        }
	                        else {
	                            write("*");
	                        }
	                        if (node.moduleSpecifier) {
	                            write(" from ");
	                            emit(node.moduleSpecifier);
	                        }
	                        write(";");
	                    }
	                }
	            }
	            function emitExportOrImportSpecifierList(specifiers, shouldEmit) {
	                ts.Debug.assert(modulekind === 5 /* ES6 */);
	                var needsComma = false;
	                for (var _a = 0, specifiers_1 = specifiers; _a < specifiers_1.length; _a++) {
	                    var specifier = specifiers_1[_a];
	                    if (shouldEmit(specifier)) {
	                        if (needsComma) {
	                            write(", ");
	                        }
	                        if (specifier.propertyName) {
	                            emit(specifier.propertyName);
	                            write(" as ");
	                        }
	                        emit(specifier.name);
	                        needsComma = true;
	                    }
	                }
	            }
	            function emitExportAssignment(node) {
	                if (!node.isExportEquals && resolver.isValueAliasDeclaration(node)) {
	                    if (modulekind === 5 /* ES6 */) {
	                        writeLine();
	                        emitStart(node);
	                        write("export default ");
	                        var expression = node.expression;
	                        emit(expression);
	                        if (expression.kind !== 216 /* FunctionDeclaration */ &&
	                            expression.kind !== 217 /* ClassDeclaration */) {
	                            write(";");
	                        }
	                        emitEnd(node);
	                    }
	                    else {
	                        writeLine();
	                        emitStart(node);
	                        if (modulekind === 4 /* System */) {
	                            write(exportFunctionForFile + "(\"default\",");
	                            emit(node.expression);
	                            write(")");
	                        }
	                        else {
	                            emitEs6ExportDefaultCompat(node);
	                            emitContainingModuleName(node);
	                            if (languageVersion === 0 /* ES3 */) {
	                                write("[\"default\"] = ");
	                            }
	                            else {
	                                write(".default = ");
	                            }
	                            emit(node.expression);
	                        }
	                        write(";");
	                        emitEnd(node);
	                    }
	                }
	            }
	            function collectExternalModuleInfo(sourceFile) {
	                externalImports = [];
	                exportSpecifiers = {};
	                exportEquals = undefined;
	                hasExportStarsToExportValues = false;
	                for (var _a = 0, _b = sourceFile.statements; _a < _b.length; _a++) {
	                    var node = _b[_a];
	                    switch (node.kind) {
	                        case 225 /* ImportDeclaration */:
	                            if (!node.importClause ||
	                                resolver.isReferencedAliasDeclaration(node.importClause, /*checkChildren*/ true)) {
	                                // import "mod"
	                                // import x from "mod" where x is referenced
	                                // import * as x from "mod" where x is referenced
	                                // import { x, y } from "mod" where at least one import is referenced
	                                externalImports.push(node);
	                            }
	                            break;
	                        case 224 /* ImportEqualsDeclaration */:
	                            if (node.moduleReference.kind === 235 /* ExternalModuleReference */ && resolver.isReferencedAliasDeclaration(node)) {
	                                // import x = require("mod") where x is referenced
	                                externalImports.push(node);
	                            }
	                            break;
	                        case 231 /* ExportDeclaration */:
	                            if (node.moduleSpecifier) {
	                                if (!node.exportClause) {
	                                    // export * from "mod"
	                                    if (resolver.moduleExportsSomeValue(node.moduleSpecifier)) {
	                                        externalImports.push(node);
	                                        hasExportStarsToExportValues = true;
	                                    }
	                                }
	                                else if (resolver.isValueAliasDeclaration(node)) {
	                                    // export { x, y } from "mod" where at least one export is a value symbol
	                                    externalImports.push(node);
	                                }
	                            }
	                            else {
	                                // export { x, y }
	                                for (var _c = 0, _d = node.exportClause.elements; _c < _d.length; _c++) {
	                                    var specifier = _d[_c];
	                                    var name_28 = (specifier.propertyName || specifier.name).text;
	                                    (exportSpecifiers[name_28] || (exportSpecifiers[name_28] = [])).push(specifier);
	                                }
	                            }
	                            break;
	                        case 230 /* ExportAssignment */:
	                            if (node.isExportEquals && !exportEquals) {
	                                // export = x
	                                exportEquals = node;
	                            }
	                            break;
	                    }
	                }
	            }
	            function emitExportStarHelper() {
	                if (hasExportStarsToExportValues) {
	                    writeLine();
	                    write("function __export(m) {");
	                    increaseIndent();
	                    writeLine();
	                    write("for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];");
	                    decreaseIndent();
	                    writeLine();
	                    write("}");
	                }
	            }
	            function getLocalNameForExternalImport(node) {
	                var namespaceDeclaration = getNamespaceDeclarationNode(node);
	                if (namespaceDeclaration && !isDefaultImport(node)) {
	                    return ts.getTextOfNodeFromSourceText(currentText, namespaceDeclaration.name);
	                }
	                if (node.kind === 225 /* ImportDeclaration */ && node.importClause) {
	                    return getGeneratedNameForNode(node);
	                }
	                if (node.kind === 231 /* ExportDeclaration */ && node.moduleSpecifier) {
	                    return getGeneratedNameForNode(node);
	                }
	            }
	            function getExternalModuleNameText(importNode, emitRelativePathAsModuleName) {
	                if (emitRelativePathAsModuleName) {
	                    var name_29 = getExternalModuleNameFromDeclaration(host, resolver, importNode);
	                    if (name_29) {
	                        return "\"" + name_29 + "\"";
	                    }
	                }
	                var moduleName = ts.getExternalModuleName(importNode);
	                if (moduleName.kind === 9 /* StringLiteral */) {
	                    return tryRenameExternalModule(moduleName) || getLiteralText(moduleName);
	                }
	                return undefined;
	            }
	            function emitVariableDeclarationsForImports() {
	                if (externalImports.length === 0) {
	                    return;
	                }
	                writeLine();
	                var started = false;
	                for (var _a = 0, externalImports_1 = externalImports; _a < externalImports_1.length; _a++) {
	                    var importNode = externalImports_1[_a];
	                    // do not create variable declaration for exports and imports that lack import clause
	                    var skipNode = importNode.kind === 231 /* ExportDeclaration */ ||
	                        (importNode.kind === 225 /* ImportDeclaration */ && !importNode.importClause);
	                    if (skipNode) {
	                        continue;
	                    }
	                    if (!started) {
	                        write("var ");
	                        started = true;
	                    }
	                    else {
	                        write(", ");
	                    }
	                    write(getLocalNameForExternalImport(importNode));
	                }
	                if (started) {
	                    write(";");
	                }
	            }
	            function emitLocalStorageForExportedNamesIfNecessary(exportedDeclarations) {
	                // when resolving exports local exported entries/indirect exported entries in the module
	                // should always win over entries with similar names that were added via star exports
	                // to support this we store names of local/indirect exported entries in a set.
	                // this set is used to filter names brought by star expors.
	                if (!hasExportStarsToExportValues) {
	                    // local names set is needed only in presence of star exports
	                    return undefined;
	                }
	                // local names set should only be added if we have anything exported
	                if (!exportedDeclarations && ts.isEmpty(exportSpecifiers)) {
	                    // no exported declarations (export var ...) or export specifiers (export {x})
	                    // check if we have any non star export declarations.
	                    var hasExportDeclarationWithExportClause = false;
	                    for (var _a = 0, externalImports_2 = externalImports; _a < externalImports_2.length; _a++) {
	                        var externalImport = externalImports_2[_a];
	                        if (externalImport.kind === 231 /* ExportDeclaration */ && externalImport.exportClause) {
	                            hasExportDeclarationWithExportClause = true;
	                            break;
	                        }
	                    }
	                    if (!hasExportDeclarationWithExportClause) {
	                        // we still need to emit exportStar helper
	                        return emitExportStarFunction(/*localNames*/ undefined);
	                    }
	                }
	                var exportedNamesStorageRef = makeUniqueName("exportedNames");
	                writeLine();
	                write("var " + exportedNamesStorageRef + " = {");
	                increaseIndent();
	                var started = false;
	                if (exportedDeclarations) {
	                    for (var i = 0; i < exportedDeclarations.length; i++) {
	                        // write name of exported declaration, i.e 'export var x...'
	                        writeExportedName(exportedDeclarations[i]);
	                    }
	                }
	                if (exportSpecifiers) {
	                    for (var n in exportSpecifiers) {
	                        for (var _b = 0, _c = exportSpecifiers[n]; _b < _c.length; _b++) {
	                            var specifier = _c[_b];
	                            // write name of export specified, i.e. 'export {x}'
	                            writeExportedName(specifier.name);
	                        }
	                    }
	                }
	                for (var _d = 0, externalImports_3 = externalImports; _d < externalImports_3.length; _d++) {
	                    var externalImport = externalImports_3[_d];
	                    if (externalImport.kind !== 231 /* ExportDeclaration */) {
	                        continue;
	                    }
	                    var exportDecl = externalImport;
	                    if (!exportDecl.exportClause) {
	                        // export * from ...
	                        continue;
	                    }
	                    for (var _e = 0, _f = exportDecl.exportClause.elements; _e < _f.length; _e++) {
	                        var element = _f[_e];
	                        // write name of indirectly exported entry, i.e. 'export {x} from ...'
	                        writeExportedName(element.name || element.propertyName);
	                    }
	                }
	                decreaseIndent();
	                writeLine();
	                write("};");
	                return emitExportStarFunction(exportedNamesStorageRef);
	                function emitExportStarFunction(localNames) {
	                    var exportStarFunction = makeUniqueName("exportStar");
	                    writeLine();
	                    // define an export star helper function
	                    write("function " + exportStarFunction + "(m) {");
	                    increaseIndent();
	                    writeLine();
	                    write("var exports = {};");
	                    writeLine();
	                    write("for(var n in m) {");
	                    increaseIndent();
	                    writeLine();
	                    write("if (n !== \"default\"");
	                    if (localNames) {
	                        write("&& !" + localNames + ".hasOwnProperty(n)");
	                    }
	                    write(") exports[n] = m[n];");
	                    decreaseIndent();
	                    writeLine();
	                    write("}");
	                    writeLine();
	                    write(exportFunctionForFile + "(exports);");
	                    decreaseIndent();
	                    writeLine();
	                    write("}");
	                    return exportStarFunction;
	                }
	                function writeExportedName(node) {
	                    // do not record default exports
	                    // they are local to module and never overwritten (explicitly skipped) by star export
	                    if (node.kind !== 69 /* Identifier */ && node.flags & 512 /* Default */) {
	                        return;
	                    }
	                    if (started) {
	                        write(",");
	                    }
	                    else {
	                        started = true;
	                    }
	                    writeLine();
	                    write("'");
	                    if (node.kind === 69 /* Identifier */) {
	                        emitNodeWithCommentsAndWithoutSourcemap(node);
	                    }
	                    else {
	                        emitDeclarationName(node);
	                    }
	                    write("': true");
	                }
	            }
	            function processTopLevelVariableAndFunctionDeclarations(node) {
	                // per ES6 spec:
	                // 15.2.1.16.4 ModuleDeclarationInstantiation() Concrete Method
	                // - var declarations are initialized to undefined - 14.a.ii
	                // - function/generator declarations are instantiated - 16.a.iv
	                // this means that after module is instantiated but before its evaluation
	                // exported functions are already accessible at import sites
	                // in theory we should hoist only exported functions and its dependencies
	                // in practice to simplify things we'll hoist all source level functions and variable declaration
	                // including variables declarations for module and class declarations
	                var hoistedVars;
	                var hoistedFunctionDeclarations;
	                var exportedDeclarations;
	                visit(node);
	                if (hoistedVars) {
	                    writeLine();
	                    write("var ");
	                    var seen = {};
	                    for (var i = 0; i < hoistedVars.length; i++) {
	                        var local = hoistedVars[i];
	                        var name_30 = local.kind === 69 /* Identifier */
	                            ? local
	                            : local.name;
	                        if (name_30) {
	                            // do not emit duplicate entries (in case of declaration merging) in the list of hoisted variables
	                            var text = ts.unescapeIdentifier(name_30.text);
	                            if (ts.hasProperty(seen, text)) {
	                                continue;
	                            }
	                            else {
	                                seen[text] = text;
	                            }
	                        }
	                        if (i !== 0) {
	                            write(", ");
	                        }
	                        if (local.kind === 217 /* ClassDeclaration */ || local.kind === 221 /* ModuleDeclaration */ || local.kind === 220 /* EnumDeclaration */) {
	                            emitDeclarationName(local);
	                        }
	                        else {
	                            emit(local);
	                        }
	                        var flags = ts.getCombinedNodeFlags(local.kind === 69 /* Identifier */ ? local.parent : local);
	                        if (flags & 2 /* Export */) {
	                            if (!exportedDeclarations) {
	                                exportedDeclarations = [];
	                            }
	                            exportedDeclarations.push(local);
	                        }
	                    }
	                    write(";");
	                }
	                if (hoistedFunctionDeclarations) {
	                    for (var _a = 0, hoistedFunctionDeclarations_1 = hoistedFunctionDeclarations; _a < hoistedFunctionDeclarations_1.length; _a++) {
	                        var f = hoistedFunctionDeclarations_1[_a];
	                        writeLine();
	                        emit(f);
	                        if (f.flags & 2 /* Export */) {
	                            if (!exportedDeclarations) {
	                                exportedDeclarations = [];
	                            }
	                            exportedDeclarations.push(f);
	                        }
	                    }
	                }
	                return exportedDeclarations;
	                function visit(node) {
	                    if (node.flags & 4 /* Ambient */) {
	                        return;
	                    }
	                    if (node.kind === 216 /* FunctionDeclaration */) {
	                        if (!hoistedFunctionDeclarations) {
	                            hoistedFunctionDeclarations = [];
	                        }
	                        hoistedFunctionDeclarations.push(node);
	                        return;
	                    }
	                    if (node.kind === 217 /* ClassDeclaration */) {
	                        if (!hoistedVars) {
	                            hoistedVars = [];
	                        }
	                        hoistedVars.push(node);
	                        return;
	                    }
	                    if (node.kind === 220 /* EnumDeclaration */) {
	                        if (shouldEmitEnumDeclaration(node)) {
	                            if (!hoistedVars) {
	                                hoistedVars = [];
	                            }
	                            hoistedVars.push(node);
	                        }
	                        return;
	                    }
	                    if (node.kind === 221 /* ModuleDeclaration */) {
	                        if (shouldEmitModuleDeclaration(node)) {
	                            if (!hoistedVars) {
	                                hoistedVars = [];
	                            }
	                            hoistedVars.push(node);
	                        }
	                        return;
	                    }
	                    if (node.kind === 214 /* VariableDeclaration */ || node.kind === 166 /* BindingElement */) {
	                        if (shouldHoistVariable(node, /*checkIfSourceFileLevelDecl*/ false)) {
	                            var name_31 = node.name;
	                            if (name_31.kind === 69 /* Identifier */) {
	                                if (!hoistedVars) {
	                                    hoistedVars = [];
	                                }
	                                hoistedVars.push(name_31);
	                            }
	                            else {
	                                ts.forEachChild(name_31, visit);
	                            }
	                        }
	                        return;
	                    }
	                    if (ts.isInternalModuleImportEqualsDeclaration(node) && resolver.isValueAliasDeclaration(node)) {
	                        if (!hoistedVars) {
	                            hoistedVars = [];
	                        }
	                        hoistedVars.push(node.name);
	                        return;
	                    }
	                    if (ts.isBindingPattern(node)) {
	                        ts.forEach(node.elements, visit);
	                        return;
	                    }
	                    if (!ts.isDeclaration(node)) {
	                        ts.forEachChild(node, visit);
	                    }
	                }
	            }
	            function shouldHoistVariable(node, checkIfSourceFileLevelDecl) {
	                if (checkIfSourceFileLevelDecl && !shouldHoistDeclarationInSystemJsModule(node)) {
	                    return false;
	                }
	                // hoist variable if
	                // - it is not block scoped
	                // - it is top level block scoped
	                // if block scoped variables are nested in some another block then
	                // no other functions can use them except ones that are defined at least in the same block
	                return (ts.getCombinedNodeFlags(node) & 24576 /* BlockScoped */) === 0 ||
	                    ts.getEnclosingBlockScopeContainer(node).kind === 251 /* SourceFile */;
	            }
	            function isCurrentFileSystemExternalModule() {
	                return modulekind === 4 /* System */ && isCurrentFileExternalModule;
	            }
	            function emitSystemModuleBody(node, dependencyGroups, startIndex) {
	                // shape of the body in system modules:
	                // function (exports) {
	                //     <list of local aliases for imports>
	                //     <hoisted function declarations>
	                //     <hoisted variable declarations>
	                //     return {
	                //         setters: [
	                //             <list of setter function for imports>
	                //         ],
	                //         execute: function() {
	                //             <module statements>
	                //         }
	                //     }
	                //     <temp declarations>
	                // }
	                // I.e:
	                // import {x} from 'file1'
	                // var y = 1;
	                // export function foo() { return y + x(); }
	                // console.log(y);
	                // will be transformed to
	                // function(exports) {
	                //     var file1; // local alias
	                //     var y;
	                //     function foo() { return y + file1.x(); }
	                //     exports("foo", foo);
	                //     return {
	                //         setters: [
	                //             function(v) { file1 = v }
	                //         ],
	                //         execute(): function() {
	                //             y = 1;
	                //             console.log(y);
	                //         }
	                //     };
	                // }
	                emitVariableDeclarationsForImports();
	                writeLine();
	                var exportedDeclarations = processTopLevelVariableAndFunctionDeclarations(node);
	                var exportStarFunction = emitLocalStorageForExportedNamesIfNecessary(exportedDeclarations);
	                writeLine();
	                write("return {");
	                increaseIndent();
	                writeLine();
	                emitSetters(exportStarFunction, dependencyGroups);
	                writeLine();
	                emitExecute(node, startIndex);
	                decreaseIndent();
	                writeLine();
	                write("}"); // return
	                emitTempDeclarations(/*newLine*/ true);
	            }
	            function emitSetters(exportStarFunction, dependencyGroups) {
	                write("setters:[");
	                for (var i = 0; i < dependencyGroups.length; i++) {
	                    if (i !== 0) {
	                        write(",");
	                    }
	                    writeLine();
	                    increaseIndent();
	                    var group = dependencyGroups[i];
	                    // derive a unique name for parameter from the first named entry in the group
	                    var parameterName = makeUniqueName(ts.forEach(group, getLocalNameForExternalImport) || "");
	                    write("function (" + parameterName + ") {");
	                    increaseIndent();
	                    for (var _a = 0, group_1 = group; _a < group_1.length; _a++) {
	                        var entry = group_1[_a];
	                        var importVariableName = getLocalNameForExternalImport(entry) || "";
	                        switch (entry.kind) {
	                            case 225 /* ImportDeclaration */:
	                                if (!entry.importClause) {
	                                    // 'import "..."' case
	                                    // module is imported only for side-effects, no emit required
	                                    break;
	                                }
	                            // fall-through
	                            case 224 /* ImportEqualsDeclaration */:
	                                ts.Debug.assert(importVariableName !== "");
	                                writeLine();
	                                // save import into the local
	                                write(importVariableName + " = " + parameterName + ";");
	                                writeLine();
	                                break;
	                            case 231 /* ExportDeclaration */:
	                                ts.Debug.assert(importVariableName !== "");
	                                if (entry.exportClause) {
	                                    // export {a, b as c} from 'foo'
	                                    // emit as:
	                                    // exports_({
	                                    //    "a": _["a"],
	                                    //    "c": _["b"]
	                                    // });
	                                    writeLine();
	                                    write(exportFunctionForFile + "({");
	                                    writeLine();
	                                    increaseIndent();
	                                    for (var i_1 = 0, len = entry.exportClause.elements.length; i_1 < len; i_1++) {
	                                        if (i_1 !== 0) {
	                                            write(",");
	                                            writeLine();
	                                        }
	                                        var e = entry.exportClause.elements[i_1];
	                                        write("\"");
	                                        emitNodeWithCommentsAndWithoutSourcemap(e.name);
	                                        write("\": " + parameterName + "[\"");
	                                        emitNodeWithCommentsAndWithoutSourcemap(e.propertyName || e.name);
	                                        write("\"]");
	                                    }
	                                    decreaseIndent();
	                                    writeLine();
	                                    write("});");
	                                }
	                                else {
	                                    // collectExternalModuleInfo prefilters star exports to keep only ones that export values
	                                    // this means that check 'resolver.moduleExportsSomeValue' is redundant and can be omitted here
	                                    writeLine();
	                                    // export * from 'foo'
	                                    // emit as:
	                                    // exportStar(_foo);
	                                    write(exportStarFunction + "(" + parameterName + ");");
	                                }
	                                writeLine();
	                                break;
	                        }
	                    }
	                    decreaseIndent();
	                    write("}");
	                    decreaseIndent();
	                }
	                write("],");
	            }
	            function emitExecute(node, startIndex) {
	                write("execute: function() {");
	                increaseIndent();
	                writeLine();
	                for (var i = startIndex; i < node.statements.length; i++) {
	                    var statement = node.statements[i];
	                    switch (statement.kind) {
	                        // - function declarations are not emitted because they were already hoisted
	                        // - import declarations are not emitted since they are already handled in setters
	                        // - export declarations with module specifiers are not emitted since they were already written in setters
	                        // - export declarations without module specifiers are emitted preserving the order
	                        case 216 /* FunctionDeclaration */:
	                        case 225 /* ImportDeclaration */:
	                            continue;
	                        case 231 /* ExportDeclaration */:
	                            if (!statement.moduleSpecifier) {
	                                for (var _a = 0, _b = statement.exportClause.elements; _a < _b.length; _a++) {
	                                    var element = _b[_a];
	                                    // write call to exporter function for every export specifier in exports list
	                                    emitExportSpecifierInSystemModule(element);
	                                }
	                            }
	                            continue;
	                        case 224 /* ImportEqualsDeclaration */:
	                            if (!ts.isInternalModuleImportEqualsDeclaration(statement)) {
	                                // - import equals declarations that import external modules are not emitted
	                                continue;
	                            }
	                        // fall-though for import declarations that import internal modules
	                        default:
	                            writeLine();
	                            emit(statement);
	                    }
	                }
	                decreaseIndent();
	                writeLine();
	                write("}"); // execute
	            }
	            function writeModuleName(node, emitRelativePathAsModuleName) {
	                var moduleName = node.moduleName;
	                if (moduleName || (emitRelativePathAsModuleName && (moduleName = getResolvedExternalModuleName(host, node)))) {
	                    write("\"" + moduleName + "\", ");
	                }
	            }
	            function emitSystemModule(node, emitRelativePathAsModuleName) {
	                collectExternalModuleInfo(node);
	                // System modules has the following shape
	                // System.register(['dep-1', ... 'dep-n'], function(exports) {/* module body function */})
	                // 'exports' here is a function 'exports<T>(name: string, value: T): T' that is used to publish exported values.
	                // 'exports' returns its 'value' argument so in most cases expressions
	                // that mutate exported values can be rewritten as:
	                // expr -> exports('name', expr).
	                // The only exception in this rule is postfix unary operators,
	                // see comment to 'emitPostfixUnaryExpression' for more details
	                ts.Debug.assert(!exportFunctionForFile);
	                // make sure that  name of 'exports' function does not conflict with existing identifiers
	                exportFunctionForFile = makeUniqueName("exports");
	                contextObjectForFile = makeUniqueName("context");
	                writeLine();
	                write("System.register(");
	                writeModuleName(node, emitRelativePathAsModuleName);
	                write("[");
	                var groupIndices = {};
	                var dependencyGroups = [];
	                for (var i = 0; i < externalImports.length; i++) {
	                    var text = getExternalModuleNameText(externalImports[i], emitRelativePathAsModuleName);
	                    if (text === undefined) {
	                        continue;
	                    }
	                    // text should be quoted string
	                    // for deduplication purposes in key remove leading and trailing quotes so 'a' and "a" will be considered the same
	                    var key = text.substr(1, text.length - 2);
	                    if (ts.hasProperty(groupIndices, key)) {
	                        // deduplicate/group entries in dependency list by the dependency name
	                        var groupIndex = groupIndices[key];
	                        dependencyGroups[groupIndex].push(externalImports[i]);
	                        continue;
	                    }
	                    else {
	                        groupIndices[key] = dependencyGroups.length;
	                        dependencyGroups.push([externalImports[i]]);
	                    }
	                    if (i !== 0) {
	                        write(", ");
	                    }
	                    write(text);
	                }
	                write("], function(" + exportFunctionForFile + ", " + contextObjectForFile + ") {");
	                writeLine();
	                increaseIndent();
	                var startIndex = emitDirectivePrologues(node.statements, /*startWithNewLine*/ true, /*ensureUseStrict*/ !compilerOptions.noImplicitUseStrict);
	                writeLine();
	                write("var __moduleName = " + contextObjectForFile + " && " + contextObjectForFile + ".id;");
	                writeLine();
	                emitEmitHelpers(node);
	                emitCaptureThisForNodeIfNecessary(node);
	                emitSystemModuleBody(node, dependencyGroups, startIndex);
	                decreaseIndent();
	                writeLine();
	                write("});");
	            }
	            function getAMDDependencyNames(node, includeNonAmdDependencies, emitRelativePathAsModuleName) {
	                // names of modules with corresponding parameter in the factory function
	                var aliasedModuleNames = [];
	                // names of modules with no corresponding parameters in factory function
	                var unaliasedModuleNames = [];
	                var importAliasNames = []; // names of the parameters in the factory function; these
	                // parameters need to match the indexes of the corresponding
	                // module names in aliasedModuleNames.
	                // Fill in amd-dependency tags
	                for (var _a = 0, _b = node.amdDependencies; _a < _b.length; _a++) {
	                    var amdDependency = _b[_a];
	                    if (amdDependency.name) {
	                        aliasedModuleNames.push("\"" + amdDependency.path + "\"");
	                        importAliasNames.push(amdDependency.name);
	                    }
	                    else {
	                        unaliasedModuleNames.push("\"" + amdDependency.path + "\"");
	                    }
	                }
	                for (var _c = 0, externalImports_4 = externalImports; _c < externalImports_4.length; _c++) {
	                    var importNode = externalImports_4[_c];
	                    // Find the name of the external module
	                    var externalModuleName = getExternalModuleNameText(importNode, emitRelativePathAsModuleName);
	                    // Find the name of the module alias, if there is one
	                    var importAliasName = getLocalNameForExternalImport(importNode);
	                    if (includeNonAmdDependencies && importAliasName) {
	                        aliasedModuleNames.push(externalModuleName);
	                        importAliasNames.push(importAliasName);
	                    }
	                    else {
	                        unaliasedModuleNames.push(externalModuleName);
	                    }
	                }
	                return { aliasedModuleNames: aliasedModuleNames, unaliasedModuleNames: unaliasedModuleNames, importAliasNames: importAliasNames };
	            }
	            function emitAMDDependencies(node, includeNonAmdDependencies, emitRelativePathAsModuleName) {
	                // An AMD define function has the following shape:
	                //     define(id?, dependencies?, factory);
	                //
	                // This has the shape of
	                //     define(name, ["module1", "module2"], function (module1Alias) {
	                // The location of the alias in the parameter list in the factory function needs to
	                // match the position of the module name in the dependency list.
	                //
	                // To ensure this is true in cases of modules with no aliases, e.g.:
	                // `import "module"` or `<amd-dependency path= "a.css" />`
	                // we need to add modules without alias names to the end of the dependencies list
	                var dependencyNames = getAMDDependencyNames(node, includeNonAmdDependencies, emitRelativePathAsModuleName);
	                emitAMDDependencyList(dependencyNames);
	                write(", ");
	                emitAMDFactoryHeader(dependencyNames);
	            }
	            function emitAMDDependencyList(_a) {
	                var aliasedModuleNames = _a.aliasedModuleNames, unaliasedModuleNames = _a.unaliasedModuleNames;
	                write("[\"require\", \"exports\"");
	                if (aliasedModuleNames.length) {
	                    write(", ");
	                    write(aliasedModuleNames.join(", "));
	                }
	                if (unaliasedModuleNames.length) {
	                    write(", ");
	                    write(unaliasedModuleNames.join(", "));
	                }
	                write("]");
	            }
	            function emitAMDFactoryHeader(_a) {
	                var importAliasNames = _a.importAliasNames;
	                write("function (require, exports");
	                if (importAliasNames.length) {
	                    write(", ");
	                    write(importAliasNames.join(", "));
	                }
	                write(") {");
	            }
	            function emitAMDModule(node, emitRelativePathAsModuleName) {
	                emitEmitHelpers(node);
	                collectExternalModuleInfo(node);
	                writeLine();
	                write("define(");
	                writeModuleName(node, emitRelativePathAsModuleName);
	                emitAMDDependencies(node, /*includeNonAmdDependencies*/ true, emitRelativePathAsModuleName);
	                increaseIndent();
	                var startIndex = emitDirectivePrologues(node.statements, /*startWithNewLine*/ true, /*ensureUseStrict*/ !compilerOptions.noImplicitUseStrict);
	                emitExportStarHelper();
	                emitCaptureThisForNodeIfNecessary(node);
	                emitLinesStartingAt(node.statements, startIndex);
	                emitTempDeclarations(/*newLine*/ true);
	                emitExportEquals(/*emitAsReturn*/ true);
	                decreaseIndent();
	                writeLine();
	                write("});");
	            }
	            function emitCommonJSModule(node) {
	                var startIndex = emitDirectivePrologues(node.statements, /*startWithNewLine*/ false, /*ensureUseStrict*/ !compilerOptions.noImplicitUseStrict);
	                emitEmitHelpers(node);
	                collectExternalModuleInfo(node);
	                emitExportStarHelper();
	                emitCaptureThisForNodeIfNecessary(node);
	                emitLinesStartingAt(node.statements, startIndex);
	                emitTempDeclarations(/*newLine*/ true);
	                emitExportEquals(/*emitAsReturn*/ false);
	            }
	            function emitUMDModule(node) {
	                emitEmitHelpers(node);
	                collectExternalModuleInfo(node);
	                var dependencyNames = getAMDDependencyNames(node, /*includeNonAmdDependencies*/ false);
	                // Module is detected first to support Browserify users that load into a browser with an AMD loader
	                writeLines("(function (factory) {\n    if (typeof module === 'object' && typeof module.exports === 'object') {\n        var v = factory(require, exports); if (v !== undefined) module.exports = v;\n    }\n    else if (typeof define === 'function' && define.amd) {\n        define(");
	                emitAMDDependencyList(dependencyNames);
	                write(", factory);");
	                writeLines("    }\n})(");
	                emitAMDFactoryHeader(dependencyNames);
	                increaseIndent();
	                var startIndex = emitDirectivePrologues(node.statements, /*startWithNewLine*/ true, /*ensureUseStrict*/ !compilerOptions.noImplicitUseStrict);
	                emitExportStarHelper();
	                emitCaptureThisForNodeIfNecessary(node);
	                emitLinesStartingAt(node.statements, startIndex);
	                emitTempDeclarations(/*newLine*/ true);
	                emitExportEquals(/*emitAsReturn*/ true);
	                decreaseIndent();
	                writeLine();
	                write("});");
	            }
	            function emitES6Module(node) {
	                externalImports = undefined;
	                exportSpecifiers = undefined;
	                exportEquals = undefined;
	                hasExportStarsToExportValues = false;
	                var startIndex = emitDirectivePrologues(node.statements, /*startWithNewLine*/ false);
	                emitEmitHelpers(node);
	                emitCaptureThisForNodeIfNecessary(node);
	                emitLinesStartingAt(node.statements, startIndex);
	                emitTempDeclarations(/*newLine*/ true);
	                // Emit exportDefault if it exists will happen as part
	                // or normal statement emit.
	            }
	            function emitExportEquals(emitAsReturn) {
	                if (exportEquals && resolver.isValueAliasDeclaration(exportEquals)) {
	                    writeLine();
	                    emitStart(exportEquals);
	                    write(emitAsReturn ? "return " : "module.exports = ");
	                    emit(exportEquals.expression);
	                    write(";");
	                    emitEnd(exportEquals);
	                }
	            }
	            function emitJsxElement(node) {
	                switch (compilerOptions.jsx) {
	                    case 2 /* React */:
	                        jsxEmitReact(node);
	                        break;
	                    case 1 /* Preserve */:
	                    // Fall back to preserve if None was specified (we'll error earlier)
	                    default:
	                        jsxEmitPreserve(node);
	                        break;
	                }
	            }
	            function trimReactWhitespaceAndApplyEntities(node) {
	                var result = undefined;
	                var text = ts.getTextOfNode(node, /*includeTrivia*/ true);
	                var firstNonWhitespace = 0;
	                var lastNonWhitespace = -1;
	                // JSX trims whitespace at the end and beginning of lines, except that the
	                // start/end of a tag is considered a start/end of a line only if that line is
	                // on the same line as the closing tag. See examples in tests/cases/conformance/jsx/tsxReactEmitWhitespace.tsx
	                for (var i = 0; i < text.length; i++) {
	                    var c = text.charCodeAt(i);
	                    if (ts.isLineBreak(c)) {
	                        if (firstNonWhitespace !== -1 && (lastNonWhitespace - firstNonWhitespace + 1 > 0)) {
	                            var part = text.substr(firstNonWhitespace, lastNonWhitespace - firstNonWhitespace + 1);
	                            result = (result ? result + "\" + ' ' + \"" : "") + ts.escapeString(part);
	                        }
	                        firstNonWhitespace = -1;
	                    }
	                    else if (!ts.isWhiteSpace(c)) {
	                        lastNonWhitespace = i;
	                        if (firstNonWhitespace === -1) {
	                            firstNonWhitespace = i;
	                        }
	                    }
	                }
	                if (firstNonWhitespace !== -1) {
	                    var part = text.substr(firstNonWhitespace);
	                    result = (result ? result + "\" + ' ' + \"" : "") + ts.escapeString(part);
	                }
	                if (result) {
	                    // Replace entities like &nbsp;
	                    result = result.replace(/&(\w+);/g, function (s, m) {
	                        if (entities[m] !== undefined) {
	                            var ch = String.fromCharCode(entities[m]);
	                            // &quot; needs to be escaped
	                            return ch === "\"" ? "\\\"" : ch;
	                        }
	                        else {
	                            return s;
	                        }
	                    });
	                }
	                return result;
	            }
	            function getTextToEmit(node) {
	                switch (compilerOptions.jsx) {
	                    case 2 /* React */:
	                        var text = trimReactWhitespaceAndApplyEntities(node);
	                        if (text === undefined || text.length === 0) {
	                            return undefined;
	                        }
	                        else {
	                            return text;
	                        }
	                    case 1 /* Preserve */:
	                    default:
	                        return ts.getTextOfNode(node, /*includeTrivia*/ true);
	                }
	            }
	            function emitJsxText(node) {
	                switch (compilerOptions.jsx) {
	                    case 2 /* React */:
	                        write("\"");
	                        write(trimReactWhitespaceAndApplyEntities(node));
	                        write("\"");
	                        break;
	                    case 1 /* Preserve */:
	                    default:
	                        writer.writeLiteral(ts.getTextOfNode(node, /*includeTrivia*/ true));
	                        break;
	                }
	            }
	            function emitJsxExpression(node) {
	                if (node.expression) {
	                    switch (compilerOptions.jsx) {
	                        case 1 /* Preserve */:
	                        default:
	                            write("{");
	                            emit(node.expression);
	                            write("}");
	                            break;
	                        case 2 /* React */:
	                            emit(node.expression);
	                            break;
	                    }
	                }
	            }
	            function isUseStrictPrologue(node) {
	                return !!node.expression.text.match(/use strict/);
	            }
	            function ensureUseStrictPrologue(startWithNewLine, writeUseStrict) {
	                if (writeUseStrict) {
	                    if (startWithNewLine) {
	                        writeLine();
	                    }
	                    write("\"use strict\";");
	                }
	            }
	            function emitDirectivePrologues(statements, startWithNewLine, ensureUseStrict) {
	                var foundUseStrict = false;
	                for (var i = 0; i < statements.length; i++) {
	                    if (ts.isPrologueDirective(statements[i])) {
	                        if (isUseStrictPrologue(statements[i])) {
	                            foundUseStrict = true;
	                        }
	                        if (startWithNewLine || i > 0) {
	                            writeLine();
	                        }
	                        emit(statements[i]);
	                    }
	                    else {
	                        ensureUseStrictPrologue(startWithNewLine || i > 0, !foundUseStrict && ensureUseStrict);
	                        // return index of the first non prologue directive
	                        return i;
	                    }
	                }
	                ensureUseStrictPrologue(startWithNewLine, !foundUseStrict && ensureUseStrict);
	                return statements.length;
	            }
	            function writeLines(text) {
	                var lines = text.split(/\r\n|\r|\n/g);
	                for (var i = 0; i < lines.length; i++) {
	                    var line = lines[i];
	                    if (line.length) {
	                        writeLine();
	                        write(line);
	                    }
	                }
	            }
	            function emitEmitHelpers(node) {
	                // Only emit helpers if the user did not say otherwise.
	                if (!compilerOptions.noEmitHelpers) {
	                    // Only Emit __extends function when target ES5.
	                    // For target ES6 and above, we can emit classDeclaration as is.
	                    if ((languageVersion < 2 /* ES6 */) && (!extendsEmitted && node.flags & 4194304 /* HasClassExtends */)) {
	                        writeLines(extendsHelper);
	                        extendsEmitted = true;
	                    }
	                    if (!decorateEmitted && node.flags & 8388608 /* HasDecorators */) {
	                        writeLines(decorateHelper);
	                        if (compilerOptions.emitDecoratorMetadata) {
	                            writeLines(metadataHelper);
	                        }
	                        decorateEmitted = true;
	                    }
	                    if (!paramEmitted && node.flags & 16777216 /* HasParamDecorators */) {
	                        writeLines(paramHelper);
	                        paramEmitted = true;
	                    }
	                    if (!awaiterEmitted && node.flags & 33554432 /* HasAsyncFunctions */) {
	                        writeLines(awaiterHelper);
	                        awaiterEmitted = true;
	                    }
	                }
	            }
	            function emitSourceFileNode(node) {
	                // Start new file on new line
	                writeLine();
	                emitShebang();
	                emitDetachedCommentsAndUpdateCommentsInfo(node);
	                if (ts.isExternalModule(node) || compilerOptions.isolatedModules) {
	                    if (isOwnFileEmit || (!ts.isExternalModule(node) && compilerOptions.isolatedModules)) {
	                        var emitModule = moduleEmitDelegates[modulekind] || moduleEmitDelegates[1 /* CommonJS */];
	                        emitModule(node);
	                    }
	                    else {
	                        bundleEmitDelegates[modulekind](node, /*emitRelativePathAsModuleName*/ true);
	                    }
	                }
	                else {
	                    // emit prologue directives prior to __extends
	                    var startIndex = emitDirectivePrologues(node.statements, /*startWithNewLine*/ false);
	                    externalImports = undefined;
	                    exportSpecifiers = undefined;
	                    exportEquals = undefined;
	                    hasExportStarsToExportValues = false;
	                    emitEmitHelpers(node);
	                    emitCaptureThisForNodeIfNecessary(node);
	                    emitLinesStartingAt(node.statements, startIndex);
	                    emitTempDeclarations(/*newLine*/ true);
	                }
	                emitLeadingComments(node.endOfFileToken);
	            }
	            function emit(node) {
	                emitNodeConsideringCommentsOption(node, emitNodeWithSourceMap);
	            }
	            function emitNodeWithCommentsAndWithoutSourcemap(node) {
	                emitNodeConsideringCommentsOption(node, emitNodeWithoutSourceMap);
	            }
	            function emitNodeConsideringCommentsOption(node, emitNodeConsideringSourcemap) {
	                if (node) {
	                    if (node.flags & 4 /* Ambient */) {
	                        return emitCommentsOnNotEmittedNode(node);
	                    }
	                    if (isSpecializedCommentHandling(node)) {
	                        // This is the node that will handle its own comments and sourcemap
	                        return emitNodeWithoutSourceMap(node);
	                    }
	                    var emitComments_1 = shouldEmitLeadingAndTrailingComments(node);
	                    if (emitComments_1) {
	                        emitLeadingComments(node);
	                    }
	                    emitNodeConsideringSourcemap(node);
	                    if (emitComments_1) {
	                        emitTrailingComments(node);
	                    }
	                }
	            }
	            function emitNodeWithSourceMap(node) {
	                if (node) {
	                    emitStart(node);
	                    emitNodeWithoutSourceMap(node);
	                    emitEnd(node);
	                }
	            }
	            function emitNodeWithoutSourceMap(node) {
	                if (node) {
	                    emitJavaScriptWorker(node);
	                }
	            }
	            function changeSourceMapEmit(writer) {
	                sourceMap = writer;
	                emitStart = writer.emitStart;
	                emitEnd = writer.emitEnd;
	                emitPos = writer.emitPos;
	                setSourceFile = writer.setSourceFile;
	            }
	            function withTemporaryNoSourceMap(callback) {
	                var prevSourceMap = sourceMap;
	                setSourceMapWriterEmit(ts.getNullSourceMapWriter());
	                callback();
	                setSourceMapWriterEmit(prevSourceMap);
	            }
	            function isSpecializedCommentHandling(node) {
	                switch (node.kind) {
	                    // All of these entities are emitted in a specialized fashion.  As such, we allow
	                    // the specialized methods for each to handle the comments on the nodes.
	                    case 218 /* InterfaceDeclaration */:
	                    case 216 /* FunctionDeclaration */:
	                    case 225 /* ImportDeclaration */:
	                    case 224 /* ImportEqualsDeclaration */:
	                    case 219 /* TypeAliasDeclaration */:
	                    case 230 /* ExportAssignment */:
	                        return true;
	                }
	            }
	            function shouldEmitLeadingAndTrailingComments(node) {
	                switch (node.kind) {
	                    case 196 /* VariableStatement */:
	                        return shouldEmitLeadingAndTrailingCommentsForVariableStatement(node);
	                    case 221 /* ModuleDeclaration */:
	                        // Only emit the leading/trailing comments for a module if we're actually
	                        // emitting the module as well.
	                        return shouldEmitModuleDeclaration(node);
	                    case 220 /* EnumDeclaration */:
	                        // Only emit the leading/trailing comments for an enum if we're actually
	                        // emitting the module as well.
	                        return shouldEmitEnumDeclaration(node);
	                }
	                // If the node is emitted in specialized fashion, dont emit comments as this node will handle
	                // emitting comments when emitting itself
	                ts.Debug.assert(!isSpecializedCommentHandling(node));
	                // If this is the expression body of an arrow function that we're down-leveling,
	                // then we don't want to emit comments when we emit the body.  It will have already
	                // been taken care of when we emitted the 'return' statement for the function
	                // expression body.
	                if (node.kind !== 195 /* Block */ &&
	                    node.parent &&
	                    node.parent.kind === 177 /* ArrowFunction */ &&
	                    node.parent.body === node &&
	                    compilerOptions.target <= 1 /* ES5 */) {
	                    return false;
	                }
	                // Emit comments for everything else.
	                return true;
	            }
	            function emitJavaScriptWorker(node) {
	                // Check if the node can be emitted regardless of the ScriptTarget
	                switch (node.kind) {
	                    case 69 /* Identifier */:
	                        return emitIdentifier(node);
	                    case 139 /* Parameter */:
	                        return emitParameter(node);
	                    case 144 /* MethodDeclaration */:
	                    case 143 /* MethodSignature */:
	                        return emitMethod(node);
	                    case 146 /* GetAccessor */:
	                    case 147 /* SetAccessor */:
	                        return emitAccessor(node);
	                    case 97 /* ThisKeyword */:
	                        return emitThis(node);
	                    case 95 /* SuperKeyword */:
	                        return emitSuper(node);
	                    case 93 /* NullKeyword */:
	                        return write("null");
	                    case 99 /* TrueKeyword */:
	                        return write("true");
	                    case 84 /* FalseKeyword */:
	                        return write("false");
	                    case 8 /* NumericLiteral */:
	                    case 9 /* StringLiteral */:
	                    case 10 /* RegularExpressionLiteral */:
	                    case 11 /* NoSubstitutionTemplateLiteral */:
	                    case 12 /* TemplateHead */:
	                    case 13 /* TemplateMiddle */:
	                    case 14 /* TemplateTail */:
	                        return emitLiteral(node);
	                    case 186 /* TemplateExpression */:
	                        return emitTemplateExpression(node);
	                    case 193 /* TemplateSpan */:
	                        return emitTemplateSpan(node);
	                    case 236 /* JsxElement */:
	                    case 237 /* JsxSelfClosingElement */:
	                        return emitJsxElement(node);
	                    case 239 /* JsxText */:
	                        return emitJsxText(node);
	                    case 243 /* JsxExpression */:
	                        return emitJsxExpression(node);
	                    case 136 /* QualifiedName */:
	                        return emitQualifiedName(node);
	                    case 164 /* ObjectBindingPattern */:
	                        return emitObjectBindingPattern(node);
	                    case 165 /* ArrayBindingPattern */:
	                        return emitArrayBindingPattern(node);
	                    case 166 /* BindingElement */:
	                        return emitBindingElement(node);
	                    case 167 /* ArrayLiteralExpression */:
	                        return emitArrayLiteral(node);
	                    case 168 /* ObjectLiteralExpression */:
	                        return emitObjectLiteral(node);
	                    case 248 /* PropertyAssignment */:
	                        return emitPropertyAssignment(node);
	                    case 249 /* ShorthandPropertyAssignment */:
	                        return emitShorthandPropertyAssignment(node);
	                    case 137 /* ComputedPropertyName */:
	                        return emitComputedPropertyName(node);
	                    case 169 /* PropertyAccessExpression */:
	                        return emitPropertyAccess(node);
	                    case 170 /* ElementAccessExpression */:
	                        return emitIndexedAccess(node);
	                    case 171 /* CallExpression */:
	                        return emitCallExpression(node);
	                    case 172 /* NewExpression */:
	                        return emitNewExpression(node);
	                    case 173 /* TaggedTemplateExpression */:
	                        return emitTaggedTemplateExpression(node);
	                    case 174 /* TypeAssertionExpression */:
	                        return emit(node.expression);
	                    case 192 /* AsExpression */:
	                        return emit(node.expression);
	                    case 175 /* ParenthesizedExpression */:
	                        return emitParenExpression(node);
	                    case 216 /* FunctionDeclaration */:
	                    case 176 /* FunctionExpression */:
	                    case 177 /* ArrowFunction */:
	                        return emitFunctionDeclaration(node);
	                    case 178 /* DeleteExpression */:
	                        return emitDeleteExpression(node);
	                    case 179 /* TypeOfExpression */:
	                        return emitTypeOfExpression(node);
	                    case 180 /* VoidExpression */:
	                        return emitVoidExpression(node);
	                    case 181 /* AwaitExpression */:
	                        return emitAwaitExpression(node);
	                    case 182 /* PrefixUnaryExpression */:
	                        return emitPrefixUnaryExpression(node);
	                    case 183 /* PostfixUnaryExpression */:
	                        return emitPostfixUnaryExpression(node);
	                    case 184 /* BinaryExpression */:
	                        return emitBinaryExpression(node);
	                    case 185 /* ConditionalExpression */:
	                        return emitConditionalExpression(node);
	                    case 188 /* SpreadElementExpression */:
	                        return emitSpreadElementExpression(node);
	                    case 187 /* YieldExpression */:
	                        return emitYieldExpression(node);
	                    case 190 /* OmittedExpression */:
	                        return;
	                    case 195 /* Block */:
	                    case 222 /* ModuleBlock */:
	                        return emitBlock(node);
	                    case 196 /* VariableStatement */:
	                        return emitVariableStatement(node);
	                    case 197 /* EmptyStatement */:
	                        return write(";");
	                    case 198 /* ExpressionStatement */:
	                        return emitExpressionStatement(node);
	                    case 199 /* IfStatement */:
	                        return emitIfStatement(node);
	                    case 200 /* DoStatement */:
	                        return emitDoStatement(node);
	                    case 201 /* WhileStatement */:
	                        return emitWhileStatement(node);
	                    case 202 /* ForStatement */:
	                        return emitForStatement(node);
	                    case 204 /* ForOfStatement */:
	                    case 203 /* ForInStatement */:
	                        return emitForInOrForOfStatement(node);
	                    case 205 /* ContinueStatement */:
	                    case 206 /* BreakStatement */:
	                        return emitBreakOrContinueStatement(node);
	                    case 207 /* ReturnStatement */:
	                        return emitReturnStatement(node);
	                    case 208 /* WithStatement */:
	                        return emitWithStatement(node);
	                    case 209 /* SwitchStatement */:
	                        return emitSwitchStatement(node);
	                    case 244 /* CaseClause */:
	                    case 245 /* DefaultClause */:
	                        return emitCaseOrDefaultClause(node);
	                    case 210 /* LabeledStatement */:
	                        return emitLabeledStatement(node);
	                    case 211 /* ThrowStatement */:
	                        return emitThrowStatement(node);
	                    case 212 /* TryStatement */:
	                        return emitTryStatement(node);
	                    case 247 /* CatchClause */:
	                        return emitCatchClause(node);
	                    case 213 /* DebuggerStatement */:
	                        return emitDebuggerStatement(node);
	                    case 214 /* VariableDeclaration */:
	                        return emitVariableDeclaration(node);
	                    case 189 /* ClassExpression */:
	                        return emitClassExpression(node);
	                    case 217 /* ClassDeclaration */:
	                        return emitClassDeclaration(node);
	                    case 218 /* InterfaceDeclaration */:
	                        return emitInterfaceDeclaration(node);
	                    case 220 /* EnumDeclaration */:
	                        return emitEnumDeclaration(node);
	                    case 250 /* EnumMember */:
	                        return emitEnumMember(node);
	                    case 221 /* ModuleDeclaration */:
	                        return emitModuleDeclaration(node);
	                    case 225 /* ImportDeclaration */:
	                        return emitImportDeclaration(node);
	                    case 224 /* ImportEqualsDeclaration */:
	                        return emitImportEqualsDeclaration(node);
	                    case 231 /* ExportDeclaration */:
	                        return emitExportDeclaration(node);
	                    case 230 /* ExportAssignment */:
	                        return emitExportAssignment(node);
	                    case 251 /* SourceFile */:
	                        return emitSourceFileNode(node);
	                }
	            }
	            function hasDetachedComments(pos) {
	                return detachedCommentsInfo !== undefined && ts.lastOrUndefined(detachedCommentsInfo).nodePos === pos;
	            }
	            function getLeadingCommentsWithoutDetachedComments() {
	                // get the leading comments from detachedPos
	                var leadingComments = ts.getLeadingCommentRanges(currentText, ts.lastOrUndefined(detachedCommentsInfo).detachedCommentEndPos);
	                if (detachedCommentsInfo.length - 1) {
	                    detachedCommentsInfo.pop();
	                }
	                else {
	                    detachedCommentsInfo = undefined;
	                }
	                return leadingComments;
	            }
	            /**
	             * Determine if the given comment is a triple-slash
	             *
	             * @return true if the comment is a triple-slash comment else false
	             **/
	            function isTripleSlashComment(comment) {
	                // Verify this is /// comment, but do the regexp match only when we first can find /// in the comment text
	                // so that we don't end up computing comment string and doing match for all // comments
	                if (currentText.charCodeAt(comment.pos + 1) === 47 /* slash */ &&
	                    comment.pos + 2 < comment.end &&
	                    currentText.charCodeAt(comment.pos + 2) === 47 /* slash */) {
	                    var textSubStr = currentText.substring(comment.pos, comment.end);
	                    return textSubStr.match(ts.fullTripleSlashReferencePathRegEx) ||
	                        textSubStr.match(ts.fullTripleSlashAMDReferencePathRegEx) ?
	                        true : false;
	                }
	                return false;
	            }
	            function getLeadingCommentsToEmit(node) {
	                // Emit the leading comments only if the parent's pos doesn't match because parent should take care of emitting these comments
	                if (node.parent) {
	                    if (node.parent.kind === 251 /* SourceFile */ || node.pos !== node.parent.pos) {
	                        if (hasDetachedComments(node.pos)) {
	                            // get comments without detached comments
	                            return getLeadingCommentsWithoutDetachedComments();
	                        }
	                        else {
	                            // get the leading comments from the node
	                            return ts.getLeadingCommentRangesOfNodeFromText(node, currentText);
	                        }
	                    }
	                }
	            }
	            function getTrailingCommentsToEmit(node) {
	                // Emit the trailing comments only if the parent's pos doesn't match because parent should take care of emitting these comments
	                if (node.parent) {
	                    if (node.parent.kind === 251 /* SourceFile */ || node.end !== node.parent.end) {
	                        return ts.getTrailingCommentRanges(currentText, node.end);
	                    }
	                }
	            }
	            /**
	             * Emit comments associated with node that will not be emitted into JS file
	             */
	            function emitCommentsOnNotEmittedNode(node) {
	                emitLeadingCommentsWorker(node, /*isEmittedNode*/ false);
	            }
	            function emitLeadingComments(node) {
	                return emitLeadingCommentsWorker(node, /*isEmittedNode*/ true);
	            }
	            function emitLeadingCommentsWorker(node, isEmittedNode) {
	                if (compilerOptions.removeComments) {
	                    return;
	                }
	                var leadingComments;
	                if (isEmittedNode) {
	                    leadingComments = getLeadingCommentsToEmit(node);
	                }
	                else {
	                    // If the node will not be emitted in JS, remove all the comments(normal, pinned and ///) associated with the node,
	                    // unless it is a triple slash comment at the top of the file.
	                    // For Example:
	                    //      /// <reference-path ...>
	                    //      declare var x;
	                    //      /// <reference-path ...>
	                    //      interface F {}
	                    //  The first /// will NOT be removed while the second one will be removed eventhough both node will not be emitted
	                    if (node.pos === 0) {
	                        leadingComments = ts.filter(getLeadingCommentsToEmit(node), isTripleSlashComment);
	                    }
	                }
	                ts.emitNewLineBeforeLeadingComments(currentLineMap, writer, node, leadingComments);
	                // Leading comments are emitted at /*leading comment1 */space/*leading comment*/space
	                ts.emitComments(currentText, currentLineMap, writer, leadingComments, /*trailingSeparator*/ true, newLine, writeComment);
	            }
	            function emitTrailingComments(node) {
	                if (compilerOptions.removeComments) {
	                    return;
	                }
	                // Emit the trailing comments only if the parent's end doesn't match
	                var trailingComments = getTrailingCommentsToEmit(node);
	                // trailing comments are emitted at space/*trailing comment1 */space/*trailing comment*/
	                ts.emitComments(currentText, currentLineMap, writer, trailingComments, /*trailingSeparator*/ false, newLine, writeComment);
	            }
	            /**
	             * Emit trailing comments at the position. The term trailing comment is used here to describe following comment:
	             *      x, /comment1/ y
	             *        ^ => pos; the function will emit "comment1" in the emitJS
	             */
	            function emitTrailingCommentsOfPosition(pos) {
	                if (compilerOptions.removeComments) {
	                    return;
	                }
	                var trailingComments = ts.getTrailingCommentRanges(currentText, pos);
	                // trailing comments are emitted at space/*trailing comment1 */space/*trailing comment*/
	                ts.emitComments(currentText, currentLineMap, writer, trailingComments, /*trailingSeparator*/ true, newLine, writeComment);
	            }
	            function emitLeadingCommentsOfPositionWorker(pos) {
	                if (compilerOptions.removeComments) {
	                    return;
	                }
	                var leadingComments;
	                if (hasDetachedComments(pos)) {
	                    // get comments without detached comments
	                    leadingComments = getLeadingCommentsWithoutDetachedComments();
	                }
	                else {
	                    // get the leading comments from the node
	                    leadingComments = ts.getLeadingCommentRanges(currentText, pos);
	                }
	                ts.emitNewLineBeforeLeadingComments(currentLineMap, writer, { pos: pos, end: pos }, leadingComments);
	                // Leading comments are emitted at /*leading comment1 */space/*leading comment*/space
	                ts.emitComments(currentText, currentLineMap, writer, leadingComments, /*trailingSeparator*/ true, newLine, writeComment);
	            }
	            function emitDetachedCommentsAndUpdateCommentsInfo(node) {
	                var currentDetachedCommentInfo = ts.emitDetachedComments(currentText, currentLineMap, writer, writeComment, node, newLine, compilerOptions.removeComments);
	                if (currentDetachedCommentInfo) {
	                    if (detachedCommentsInfo) {
	                        detachedCommentsInfo.push(currentDetachedCommentInfo);
	                    }
	                    else {
	                        detachedCommentsInfo = [currentDetachedCommentInfo];
	                    }
	                }
	            }
	            function writeComment(text, lineMap, writer, comment, newLine) {
	                emitPos(comment.pos);
	                ts.writeCommentRange(text, lineMap, writer, comment, newLine);
	                emitPos(comment.end);
	            }
	            function emitShebang() {
	                var shebang = ts.getShebang(currentText);
	                if (shebang) {
	                    write(shebang);
	                    writeLine();
	                }
	            }
	            var _a, _b;
	        }
	        function emitFile(_a, sourceFiles, isBundledEmit) {
	            var jsFilePath = _a.jsFilePath, sourceMapFilePath = _a.sourceMapFilePath, declarationFilePath = _a.declarationFilePath;
	            // Make sure not to write js File and source map file if any of them cannot be written
	            if (!host.isEmitBlocked(jsFilePath) && !compilerOptions.noEmit) {
	                emitJavaScript(jsFilePath, sourceMapFilePath, sourceFiles, isBundledEmit);
	            }
	            else {
	                emitSkipped = true;
	            }
	            if (declarationFilePath) {
	                emitSkipped = ts.writeDeclarationFile(declarationFilePath, sourceFiles, isBundledEmit, host, resolver, emitterDiagnostics) || emitSkipped;
	            }
	        }
	    }
	    ts.emitFiles = emitFiles;
	})(ts || (ts = {}));
	/// <reference path="sys.ts" />
	/// <reference path="emitter.ts" />
	/// <reference path="core.ts" />
	var ts;
	(function (ts) {
	    /* @internal */ ts.programTime = 0;
	    /* @internal */ ts.emitTime = 0;
	    /* @internal */ ts.ioReadTime = 0;
	    /* @internal */ ts.ioWriteTime = 0;
	    /** The version of the TypeScript compiler release */
	    var emptyArray = [];
	    ts.version = "1.8.7";
	    function findConfigFile(searchPath, fileExists) {
	        var fileName = "tsconfig.json";
	        while (true) {
	            if (fileExists(fileName)) {
	                return fileName;
	            }
	            var parentPath = ts.getDirectoryPath(searchPath);
	            if (parentPath === searchPath) {
	                break;
	            }
	            searchPath = parentPath;
	            fileName = "../" + fileName;
	        }
	        return undefined;
	    }
	    ts.findConfigFile = findConfigFile;
	    function resolveTripleslashReference(moduleName, containingFile) {
	        var basePath = ts.getDirectoryPath(containingFile);
	        var referencedFileName = ts.isRootedDiskPath(moduleName) ? moduleName : ts.combinePaths(basePath, moduleName);
	        return ts.normalizePath(referencedFileName);
	    }
	    ts.resolveTripleslashReference = resolveTripleslashReference;
	    function resolveModuleName(moduleName, containingFile, compilerOptions, host) {
	        var moduleResolution = compilerOptions.moduleResolution !== undefined
	            ? compilerOptions.moduleResolution
	            : ts.getEmitModuleKind(compilerOptions) === 1 /* CommonJS */ ? 2 /* NodeJs */ : 1 /* Classic */;
	        switch (moduleResolution) {
	            case 2 /* NodeJs */: return nodeModuleNameResolver(moduleName, containingFile, compilerOptions, host);
	            case 1 /* Classic */: return classicNameResolver(moduleName, containingFile, compilerOptions, host);
	        }
	    }
	    ts.resolveModuleName = resolveModuleName;
	    function nodeModuleNameResolver(moduleName, containingFile, compilerOptions, host) {
	        var containingDirectory = ts.getDirectoryPath(containingFile);
	        var supportedExtensions = ts.getSupportedExtensions(compilerOptions);
	        if (ts.getRootLength(moduleName) !== 0 || nameStartsWithDotSlashOrDotDotSlash(moduleName)) {
	            var failedLookupLocations = [];
	            var candidate = ts.normalizePath(ts.combinePaths(containingDirectory, moduleName));
	            var resolvedFileName = loadNodeModuleFromFile(supportedExtensions, candidate, failedLookupLocations, /*onlyRecordFailures*/ false, host);
	            if (resolvedFileName) {
	                return { resolvedModule: { resolvedFileName: resolvedFileName }, failedLookupLocations: failedLookupLocations };
	            }
	            resolvedFileName = loadNodeModuleFromDirectory(supportedExtensions, candidate, failedLookupLocations, /*onlyRecordFailures*/ false, host);
	            return resolvedFileName
	                ? { resolvedModule: { resolvedFileName: resolvedFileName }, failedLookupLocations: failedLookupLocations }
	                : { resolvedModule: undefined, failedLookupLocations: failedLookupLocations };
	        }
	        else {
	            return loadModuleFromNodeModules(moduleName, containingDirectory, host);
	        }
	    }
	    ts.nodeModuleNameResolver = nodeModuleNameResolver;
	    /* @internal */
	    function directoryProbablyExists(directoryName, host) {
	        // if host does not support 'directoryExists' assume that directory will exist
	        return !host.directoryExists || host.directoryExists(directoryName);
	    }
	    ts.directoryProbablyExists = directoryProbablyExists;
	    /**
	     * @param {boolean} onlyRecordFailures - if true then function won't try to actually load files but instead record all attempts as failures. This flag is necessary
	     * in cases when we know upfront that all load attempts will fail (because containing folder does not exists) however we still need to record all failed lookup locations.
	     */
	    function loadNodeModuleFromFile(extensions, candidate, failedLookupLocation, onlyRecordFailures, host) {
	        return ts.forEach(extensions, tryLoad);
	        function tryLoad(ext) {
	            var fileName = ts.fileExtensionIs(candidate, ext) ? candidate : candidate + ext;
	            if (!onlyRecordFailures && host.fileExists(fileName)) {
	                return fileName;
	            }
	            else {
	                failedLookupLocation.push(fileName);
	                return undefined;
	            }
	        }
	    }
	    function loadNodeModuleFromDirectory(extensions, candidate, failedLookupLocation, onlyRecordFailures, host) {
	        var packageJsonPath = ts.combinePaths(candidate, "package.json");
	        var directoryExists = !onlyRecordFailures && directoryProbablyExists(candidate, host);
	        if (directoryExists && host.fileExists(packageJsonPath)) {
	            var jsonContent = void 0;
	            try {
	                var jsonText = host.readFile(packageJsonPath);
	                jsonContent = jsonText ? JSON.parse(jsonText) : { typings: undefined };
	            }
	            catch (e) {
	                // gracefully handle if readFile fails or returns not JSON
	                jsonContent = { typings: undefined };
	            }
	            if (typeof jsonContent.typings === "string") {
	                var path = ts.normalizePath(ts.combinePaths(candidate, jsonContent.typings));
	                var result = loadNodeModuleFromFile(extensions, path, failedLookupLocation, !directoryProbablyExists(ts.getDirectoryPath(path), host), host);
	                if (result) {
	                    return result;
	                }
	            }
	        }
	        else {
	            // record package json as one of failed lookup locations - in the future if this file will appear it will invalidate resolution results
	            failedLookupLocation.push(packageJsonPath);
	        }
	        return loadNodeModuleFromFile(extensions, ts.combinePaths(candidate, "index"), failedLookupLocation, !directoryExists, host);
	    }
	    function loadModuleFromNodeModules(moduleName, directory, host) {
	        var failedLookupLocations = [];
	        directory = ts.normalizeSlashes(directory);
	        while (true) {
	            var baseName = ts.getBaseFileName(directory);
	            if (baseName !== "node_modules") {
	                var nodeModulesFolder = ts.combinePaths(directory, "node_modules");
	                var nodeModulesFolderExists = directoryProbablyExists(nodeModulesFolder, host);
	                var candidate = ts.normalizePath(ts.combinePaths(nodeModulesFolder, moduleName));
	                // Load only typescript files irrespective of allowJs option if loading from node modules
	                var result = loadNodeModuleFromFile(ts.supportedTypeScriptExtensions, candidate, failedLookupLocations, !nodeModulesFolderExists, host);
	                if (result) {
	                    return { resolvedModule: { resolvedFileName: result, isExternalLibraryImport: true }, failedLookupLocations: failedLookupLocations };
	                }
	                result = loadNodeModuleFromDirectory(ts.supportedTypeScriptExtensions, candidate, failedLookupLocations, !nodeModulesFolderExists, host);
	                if (result) {
	                    return { resolvedModule: { resolvedFileName: result, isExternalLibraryImport: true }, failedLookupLocations: failedLookupLocations };
	                }
	            }
	            var parentPath = ts.getDirectoryPath(directory);
	            if (parentPath === directory) {
	                break;
	            }
	            directory = parentPath;
	        }
	        return { resolvedModule: undefined, failedLookupLocations: failedLookupLocations };
	    }
	    function nameStartsWithDotSlashOrDotDotSlash(name) {
	        var i = name.lastIndexOf("./", 1);
	        return i === 0 || (i === 1 && name.charCodeAt(0) === 46 /* dot */);
	    }
	    function classicNameResolver(moduleName, containingFile, compilerOptions, host) {
	        // module names that contain '!' are used to reference resources and are not resolved to actual files on disk
	        if (moduleName.indexOf("!") != -1) {
	            return { resolvedModule: undefined, failedLookupLocations: [] };
	        }
	        var searchPath = ts.getDirectoryPath(containingFile);
	        var searchName;
	        var failedLookupLocations = [];
	        var referencedSourceFile;
	        var supportedExtensions = ts.getSupportedExtensions(compilerOptions);
	        while (true) {
	            searchName = ts.normalizePath(ts.combinePaths(searchPath, moduleName));
	            referencedSourceFile = ts.forEach(supportedExtensions, function (extension) {
	                if (extension === ".tsx" && !compilerOptions.jsx) {
	                    // resolve .tsx files only if jsx support is enabled
	                    // 'logical not' handles both undefined and None cases
	                    return undefined;
	                }
	                var candidate = searchName + extension;
	                if (host.fileExists(candidate)) {
	                    return candidate;
	                }
	                else {
	                    failedLookupLocations.push(candidate);
	                }
	            });
	            if (referencedSourceFile) {
	                break;
	            }
	            var parentPath = ts.getDirectoryPath(searchPath);
	            if (parentPath === searchPath) {
	                break;
	            }
	            searchPath = parentPath;
	        }
	        return referencedSourceFile
	            ? { resolvedModule: { resolvedFileName: referencedSourceFile }, failedLookupLocations: failedLookupLocations }
	            : { resolvedModule: undefined, failedLookupLocations: failedLookupLocations };
	    }
	    ts.classicNameResolver = classicNameResolver;
	    /* @internal */
	    ts.defaultInitCompilerOptions = {
	        module: 1 /* CommonJS */,
	        target: 1 /* ES5 */,
	        noImplicitAny: false,
	        sourceMap: false
	    };
	    function createCompilerHost(options, setParentNodes) {
	        var existingDirectories = {};
	        function getCanonicalFileName(fileName) {
	            // if underlying system can distinguish between two files whose names differs only in cases then file name already in canonical form.
	            // otherwise use toLowerCase as a canonical form.
	            return ts.sys.useCaseSensitiveFileNames ? fileName : fileName.toLowerCase();
	        }
	        // returned by CScript sys environment
	        var unsupportedFileEncodingErrorCode = -2147024809;
	        function getSourceFile(fileName, languageVersion, onError) {
	            var text;
	            try {
	                var start = new Date().getTime();
	                text = ts.sys.readFile(fileName, options.charset);
	                ts.ioReadTime += new Date().getTime() - start;
	            }
	            catch (e) {
	                if (onError) {
	                    onError(e.number === unsupportedFileEncodingErrorCode
	                        ? ts.createCompilerDiagnostic(ts.Diagnostics.Unsupported_file_encoding).messageText
	                        : e.message);
	                }
	                text = "";
	            }
	            return text !== undefined ? ts.createSourceFile(fileName, text, languageVersion, setParentNodes) : undefined;
	        }
	        function directoryExists(directoryPath) {
	            if (ts.hasProperty(existingDirectories, directoryPath)) {
	                return true;
	            }
	            if (ts.sys.directoryExists(directoryPath)) {
	                existingDirectories[directoryPath] = true;
	                return true;
	            }
	            return false;
	        }
	        function ensureDirectoriesExist(directoryPath) {
	            if (directoryPath.length > ts.getRootLength(directoryPath) && !directoryExists(directoryPath)) {
	                var parentDirectory = ts.getDirectoryPath(directoryPath);
	                ensureDirectoriesExist(parentDirectory);
	                ts.sys.createDirectory(directoryPath);
	            }
	        }
	        function writeFile(fileName, data, writeByteOrderMark, onError) {
	            try {
	                var start = new Date().getTime();
	                ensureDirectoriesExist(ts.getDirectoryPath(ts.normalizePath(fileName)));
	                ts.sys.writeFile(fileName, data, writeByteOrderMark);
	                ts.ioWriteTime += new Date().getTime() - start;
	            }
	            catch (e) {
	                if (onError) {
	                    onError(e.message);
	                }
	            }
	        }
	        var newLine = ts.getNewLineCharacter(options);
	        return {
	            getSourceFile: getSourceFile,
	            getDefaultLibFileName: function (options) { return ts.combinePaths(ts.getDirectoryPath(ts.normalizePath(ts.sys.getExecutingFilePath())), ts.getDefaultLibFileName(options)); },
	            writeFile: writeFile,
	            getCurrentDirectory: ts.memoize(function () { return ts.sys.getCurrentDirectory(); }),
	            useCaseSensitiveFileNames: function () { return ts.sys.useCaseSensitiveFileNames; },
	            getCanonicalFileName: getCanonicalFileName,
	            getNewLine: function () { return newLine; },
	            fileExists: function (fileName) { return ts.sys.fileExists(fileName); },
	            readFile: function (fileName) { return ts.sys.readFile(fileName); },
	            directoryExists: function (directoryName) { return ts.sys.directoryExists(directoryName); }
	        };
	    }
	    ts.createCompilerHost = createCompilerHost;
	    function getPreEmitDiagnostics(program, sourceFile, cancellationToken) {
	        var diagnostics = program.getOptionsDiagnostics(cancellationToken).concat(program.getSyntacticDiagnostics(sourceFile, cancellationToken), program.getGlobalDiagnostics(cancellationToken), program.getSemanticDiagnostics(sourceFile, cancellationToken));
	        if (program.getCompilerOptions().declaration) {
	            diagnostics = diagnostics.concat(program.getDeclarationDiagnostics(sourceFile, cancellationToken));
	        }
	        return ts.sortAndDeduplicateDiagnostics(diagnostics);
	    }
	    ts.getPreEmitDiagnostics = getPreEmitDiagnostics;
	    function flattenDiagnosticMessageText(messageText, newLine) {
	        if (typeof messageText === "string") {
	            return messageText;
	        }
	        else {
	            var diagnosticChain = messageText;
	            var result = "";
	            var indent = 0;
	            while (diagnosticChain) {
	                if (indent) {
	                    result += newLine;
	                    for (var i = 0; i < indent; i++) {
	                        result += "  ";
	                    }
	                }
	                result += diagnosticChain.messageText;
	                indent++;
	                diagnosticChain = diagnosticChain.next;
	            }
	            return result;
	        }
	    }
	    ts.flattenDiagnosticMessageText = flattenDiagnosticMessageText;
	    function createProgram(rootNames, options, host, oldProgram) {
	        var program;
	        var files = [];
	        var fileProcessingDiagnostics = ts.createDiagnosticCollection();
	        var programDiagnostics = ts.createDiagnosticCollection();
	        var commonSourceDirectory;
	        var diagnosticsProducingTypeChecker;
	        var noDiagnosticsTypeChecker;
	        var classifiableNames;
	        var skipDefaultLib = options.noLib;
	        var supportedExtensions = ts.getSupportedExtensions(options);
	        var start = new Date().getTime();
	        host = host || createCompilerHost(options);
	        // Map storing if there is emit blocking diagnostics for given input
	        var hasEmitBlockingDiagnostics = ts.createFileMap(getCanonicalFileName);
	        var currentDirectory = host.getCurrentDirectory();
	        var resolveModuleNamesWorker = host.resolveModuleNames
	            ? (function (moduleNames, containingFile) { return host.resolveModuleNames(moduleNames, containingFile); })
	            : (function (moduleNames, containingFile) {
	                var resolvedModuleNames = [];
	                // resolveModuleName does not store any results between calls.
	                // lookup is a local cache to avoid resolving the same module name several times
	                var lookup = {};
	                for (var _i = 0, moduleNames_1 = moduleNames; _i < moduleNames_1.length; _i++) {
	                    var moduleName = moduleNames_1[_i];
	                    var resolvedName = void 0;
	                    if (ts.hasProperty(lookup, moduleName)) {
	                        resolvedName = lookup[moduleName];
	                    }
	                    else {
	                        resolvedName = resolveModuleName(moduleName, containingFile, options, host).resolvedModule;
	                        lookup[moduleName] = resolvedName;
	                    }
	                    resolvedModuleNames.push(resolvedName);
	                }
	                return resolvedModuleNames;
	            });
	        var filesByName = ts.createFileMap();
	        // stores 'filename -> file association' ignoring case
	        // used to track cases when two file names differ only in casing
	        var filesByNameIgnoreCase = host.useCaseSensitiveFileNames() ? ts.createFileMap(function (fileName) { return fileName.toLowerCase(); }) : undefined;
	        if (oldProgram) {
	            // check properties that can affect structure of the program or module resolution strategy
	            // if any of these properties has changed - structure cannot be reused
	            var oldOptions = oldProgram.getCompilerOptions();
	            if ((oldOptions.module !== options.module) ||
	                (oldOptions.noResolve !== options.noResolve) ||
	                (oldOptions.target !== options.target) ||
	                (oldOptions.noLib !== options.noLib) ||
	                (oldOptions.jsx !== options.jsx) ||
	                (oldOptions.allowJs !== options.allowJs)) {
	                oldProgram = undefined;
	            }
	        }
	        if (!tryReuseStructureFromOldProgram()) {
	            ts.forEach(rootNames, function (name) { return processRootFile(name, /*isDefaultLib*/ false); });
	            // Do not process the default library if:
	            //  - The '--noLib' flag is used.
	            //  - A 'no-default-lib' reference comment is encountered in
	            //      processing the root files.
	            if (!skipDefaultLib) {
	                processRootFile(host.getDefaultLibFileName(options), /*isDefaultLib*/ true);
	            }
	        }
	        // unconditionally set oldProgram to undefined to prevent it from being captured in closure
	        oldProgram = undefined;
	        program = {
	            getRootFileNames: function () { return rootNames; },
	            getSourceFile: getSourceFile,
	            getSourceFiles: function () { return files; },
	            getCompilerOptions: function () { return options; },
	            getSyntacticDiagnostics: getSyntacticDiagnostics,
	            getOptionsDiagnostics: getOptionsDiagnostics,
	            getGlobalDiagnostics: getGlobalDiagnostics,
	            getSemanticDiagnostics: getSemanticDiagnostics,
	            getDeclarationDiagnostics: getDeclarationDiagnostics,
	            getTypeChecker: getTypeChecker,
	            getClassifiableNames: getClassifiableNames,
	            getDiagnosticsProducingTypeChecker: getDiagnosticsProducingTypeChecker,
	            getCommonSourceDirectory: getCommonSourceDirectory,
	            emit: emit,
	            getCurrentDirectory: function () { return currentDirectory; },
	            getNodeCount: function () { return getDiagnosticsProducingTypeChecker().getNodeCount(); },
	            getIdentifierCount: function () { return getDiagnosticsProducingTypeChecker().getIdentifierCount(); },
	            getSymbolCount: function () { return getDiagnosticsProducingTypeChecker().getSymbolCount(); },
	            getTypeCount: function () { return getDiagnosticsProducingTypeChecker().getTypeCount(); },
	            getFileProcessingDiagnostics: function () { return fileProcessingDiagnostics; }
	        };
	        verifyCompilerOptions();
	        ts.programTime += new Date().getTime() - start;
	        return program;
	        function getCommonSourceDirectory() {
	            if (typeof commonSourceDirectory === "undefined") {
	                if (options.rootDir && checkSourceFilesBelongToPath(files, options.rootDir)) {
	                    // If a rootDir is specified and is valid use it as the commonSourceDirectory
	                    commonSourceDirectory = ts.getNormalizedAbsolutePath(options.rootDir, currentDirectory);
	                }
	                else {
	                    commonSourceDirectory = computeCommonSourceDirectory(files);
	                }
	                if (commonSourceDirectory && commonSourceDirectory[commonSourceDirectory.length - 1] !== ts.directorySeparator) {
	                    // Make sure directory path ends with directory separator so this string can directly
	                    // used to replace with "" to get the relative path of the source file and the relative path doesn't
	                    // start with / making it rooted path
	                    commonSourceDirectory += ts.directorySeparator;
	                }
	            }
	            return commonSourceDirectory;
	        }
	        function getClassifiableNames() {
	            if (!classifiableNames) {
	                // Initialize a checker so that all our files are bound.
	                getTypeChecker();
	                classifiableNames = {};
	                for (var _i = 0, files_3 = files; _i < files_3.length; _i++) {
	                    var sourceFile = files_3[_i];
	                    ts.copyMap(sourceFile.classifiableNames, classifiableNames);
	                }
	            }
	            return classifiableNames;
	        }
	        function tryReuseStructureFromOldProgram() {
	            if (!oldProgram) {
	                return false;
	            }
	            ts.Debug.assert(!oldProgram.structureIsReused);
	            // there is an old program, check if we can reuse its structure
	            var oldRootNames = oldProgram.getRootFileNames();
	            if (!ts.arrayIsEqualTo(oldRootNames, rootNames)) {
	                return false;
	            }
	            // check if program source files has changed in the way that can affect structure of the program
	            var newSourceFiles = [];
	            var filePaths = [];
	            var modifiedSourceFiles = [];
	            for (var _i = 0, _a = oldProgram.getSourceFiles(); _i < _a.length; _i++) {
	                var oldSourceFile = _a[_i];
	                var newSourceFile = host.getSourceFile(oldSourceFile.fileName, options.target);
	                if (!newSourceFile) {
	                    return false;
	                }
	                newSourceFile.path = oldSourceFile.path;
	                filePaths.push(newSourceFile.path);
	                if (oldSourceFile !== newSourceFile) {
	                    if (oldSourceFile.hasNoDefaultLib !== newSourceFile.hasNoDefaultLib) {
	                        // value of no-default-lib has changed
	                        // this will affect if default library is injected into the list of files
	                        return false;
	                    }
	                    // check tripleslash references
	                    if (!ts.arrayIsEqualTo(oldSourceFile.referencedFiles, newSourceFile.referencedFiles, fileReferenceIsEqualTo)) {
	                        // tripleslash references has changed
	                        return false;
	                    }
	                    // check imports and module augmentations
	                    collectExternalModuleReferences(newSourceFile);
	                    if (!ts.arrayIsEqualTo(oldSourceFile.imports, newSourceFile.imports, moduleNameIsEqualTo)) {
	                        // imports has changed
	                        return false;
	                    }
	                    if (!ts.arrayIsEqualTo(oldSourceFile.moduleAugmentations, newSourceFile.moduleAugmentations, moduleNameIsEqualTo)) {
	                        // moduleAugmentations has changed
	                        return false;
	                    }
	                    if (resolveModuleNamesWorker) {
	                        var moduleNames = ts.map(ts.concatenate(newSourceFile.imports, newSourceFile.moduleAugmentations), getTextOfLiteral);
	                        var resolutions = resolveModuleNamesWorker(moduleNames, ts.getNormalizedAbsolutePath(newSourceFile.fileName, currentDirectory));
	                        // ensure that module resolution results are still correct
	                        for (var i = 0; i < moduleNames.length; i++) {
	                            var newResolution = resolutions[i];
	                            var oldResolution = ts.getResolvedModule(oldSourceFile, moduleNames[i]);
	                            var resolutionChanged = oldResolution
	                                ? !newResolution ||
	                                    oldResolution.resolvedFileName !== newResolution.resolvedFileName ||
	                                    !!oldResolution.isExternalLibraryImport !== !!newResolution.isExternalLibraryImport
	                                : newResolution;
	                            if (resolutionChanged) {
	                                return false;
	                            }
	                        }
	                    }
	                    // pass the cache of module resolutions from the old source file
	                    newSourceFile.resolvedModules = oldSourceFile.resolvedModules;
	                    modifiedSourceFiles.push(newSourceFile);
	                }
	                else {
	                    // file has no changes - use it as is
	                    newSourceFile = oldSourceFile;
	                }
	                // if file has passed all checks it should be safe to reuse it
	                newSourceFiles.push(newSourceFile);
	            }
	            // update fileName -> file mapping
	            for (var i = 0, len = newSourceFiles.length; i < len; i++) {
	                filesByName.set(filePaths[i], newSourceFiles[i]);
	            }
	            files = newSourceFiles;
	            fileProcessingDiagnostics = oldProgram.getFileProcessingDiagnostics();
	            for (var _b = 0, modifiedSourceFiles_1 = modifiedSourceFiles; _b < modifiedSourceFiles_1.length; _b++) {
	                var modifiedFile = modifiedSourceFiles_1[_b];
	                fileProcessingDiagnostics.reattachFileDiagnostics(modifiedFile);
	            }
	            oldProgram.structureIsReused = true;
	            return true;
	        }
	        function getEmitHost(writeFileCallback) {
	            return {
	                getCanonicalFileName: getCanonicalFileName,
	                getCommonSourceDirectory: program.getCommonSourceDirectory,
	                getCompilerOptions: program.getCompilerOptions,
	                getCurrentDirectory: function () { return currentDirectory; },
	                getNewLine: function () { return host.getNewLine(); },
	                getSourceFile: program.getSourceFile,
	                getSourceFiles: program.getSourceFiles,
	                writeFile: writeFileCallback || (function (fileName, data, writeByteOrderMark, onError) { return host.writeFile(fileName, data, writeByteOrderMark, onError); }),
	                isEmitBlocked: isEmitBlocked
	            };
	        }
	        function getDiagnosticsProducingTypeChecker() {
	            return diagnosticsProducingTypeChecker || (diagnosticsProducingTypeChecker = ts.createTypeChecker(program, /*produceDiagnostics:*/ true));
	        }
	        function getTypeChecker() {
	            return noDiagnosticsTypeChecker || (noDiagnosticsTypeChecker = ts.createTypeChecker(program, /*produceDiagnostics:*/ false));
	        }
	        function emit(sourceFile, writeFileCallback, cancellationToken) {
	            var _this = this;
	            return runWithCancellationToken(function () { return emitWorker(_this, sourceFile, writeFileCallback, cancellationToken); });
	        }
	        function isEmitBlocked(emitFileName) {
	            return hasEmitBlockingDiagnostics.contains(ts.toPath(emitFileName, currentDirectory, getCanonicalFileName));
	        }
	        function emitWorker(program, sourceFile, writeFileCallback, cancellationToken) {
	            // If the noEmitOnError flag is set, then check if we have any errors so far.  If so,
	            // immediately bail out.  Note that we pass 'undefined' for 'sourceFile' so that we
	            // get any preEmit diagnostics, not just the ones
	            if (options.noEmitOnError) {
	                var diagnostics = program.getOptionsDiagnostics(cancellationToken).concat(program.getSyntacticDiagnostics(sourceFile, cancellationToken), program.getGlobalDiagnostics(cancellationToken), program.getSemanticDiagnostics(sourceFile, cancellationToken));
	                var declarationDiagnostics = [];
	                if (diagnostics.length === 0 && program.getCompilerOptions().declaration) {
	                    declarationDiagnostics = program.getDeclarationDiagnostics(/*sourceFile*/ undefined, cancellationToken);
	                }
	                if (diagnostics.length > 0 || declarationDiagnostics.length > 0) {
	                    return { diagnostics: declarationDiagnostics, sourceMaps: undefined, emitSkipped: true };
	                }
	            }
	            // Create the emit resolver outside of the "emitTime" tracking code below.  That way
	            // any cost associated with it (like type checking) are appropriate associated with
	            // the type-checking counter.
	            //
	            // If the -out option is specified, we should not pass the source file to getEmitResolver.
	            // This is because in the -out scenario all files need to be emitted, and therefore all
	            // files need to be type checked. And the way to specify that all files need to be type
	            // checked is to not pass the file to getEmitResolver.
	            var emitResolver = getDiagnosticsProducingTypeChecker().getEmitResolver((options.outFile || options.out) ? undefined : sourceFile);
	            var start = new Date().getTime();
	            var emitResult = ts.emitFiles(emitResolver, getEmitHost(writeFileCallback), sourceFile);
	            ts.emitTime += new Date().getTime() - start;
	            return emitResult;
	        }
	        function getSourceFile(fileName) {
	            return filesByName.get(ts.toPath(fileName, currentDirectory, getCanonicalFileName));
	        }
	        function getDiagnosticsHelper(sourceFile, getDiagnostics, cancellationToken) {
	            if (sourceFile) {
	                return getDiagnostics(sourceFile, cancellationToken);
	            }
	            var allDiagnostics = [];
	            ts.forEach(program.getSourceFiles(), function (sourceFile) {
	                if (cancellationToken) {
	                    cancellationToken.throwIfCancellationRequested();
	                }
	                ts.addRange(allDiagnostics, getDiagnostics(sourceFile, cancellationToken));
	            });
	            return ts.sortAndDeduplicateDiagnostics(allDiagnostics);
	        }
	        function getSyntacticDiagnostics(sourceFile, cancellationToken) {
	            return getDiagnosticsHelper(sourceFile, getSyntacticDiagnosticsForFile, cancellationToken);
	        }
	        function getSemanticDiagnostics(sourceFile, cancellationToken) {
	            return getDiagnosticsHelper(sourceFile, getSemanticDiagnosticsForFile, cancellationToken);
	        }
	        function getDeclarationDiagnostics(sourceFile, cancellationToken) {
	            var options = program.getCompilerOptions();
	            // collect diagnostics from the program only once if either no source file was specified or out/outFile is set (bundled emit)
	            if (!sourceFile || options.out || options.outFile) {
	                return getDeclarationDiagnosticsWorker(sourceFile, cancellationToken);
	            }
	            else {
	                return getDiagnosticsHelper(sourceFile, getDeclarationDiagnosticsForFile, cancellationToken);
	            }
	        }
	        function getSyntacticDiagnosticsForFile(sourceFile, cancellationToken) {
	            return sourceFile.parseDiagnostics;
	        }
	        function runWithCancellationToken(func) {
	            try {
	                return func();
	            }
	            catch (e) {
	                if (e instanceof ts.OperationCanceledException) {
	                    // We were canceled while performing the operation.  Because our type checker
	                    // might be a bad state, we need to throw it away.
	                    //
	                    // Note: we are overly agressive here.  We do not actually *have* to throw away
	                    // the "noDiagnosticsTypeChecker".  However, for simplicity, i'd like to keep
	                    // the lifetimes of these two TypeCheckers the same.  Also, we generally only
	                    // cancel when the user has made a change anyways.  And, in that case, we (the
	                    // program instance) will get thrown away anyways.  So trying to keep one of
	                    // these type checkers alive doesn't serve much purpose.
	                    noDiagnosticsTypeChecker = undefined;
	                    diagnosticsProducingTypeChecker = undefined;
	                }
	                throw e;
	            }
	        }
	        function getSemanticDiagnosticsForFile(sourceFile, cancellationToken) {
	            return runWithCancellationToken(function () {
	                var typeChecker = getDiagnosticsProducingTypeChecker();
	                ts.Debug.assert(!!sourceFile.bindDiagnostics);
	                var bindDiagnostics = sourceFile.bindDiagnostics;
	                // For JavaScript files, we don't want to report the normal typescript semantic errors.
	                // Instead, we just report errors for using TypeScript-only constructs from within a
	                // JavaScript file.
	                var checkDiagnostics = ts.isSourceFileJavaScript(sourceFile) ?
	                    getJavaScriptSemanticDiagnosticsForFile(sourceFile, cancellationToken) :
	                    typeChecker.getDiagnostics(sourceFile, cancellationToken);
	                var fileProcessingDiagnosticsInFile = fileProcessingDiagnostics.getDiagnostics(sourceFile.fileName);
	                var programDiagnosticsInFile = programDiagnostics.getDiagnostics(sourceFile.fileName);
	                return bindDiagnostics.concat(checkDiagnostics).concat(fileProcessingDiagnosticsInFile).concat(programDiagnosticsInFile);
	            });
	        }
	        function getJavaScriptSemanticDiagnosticsForFile(sourceFile, cancellationToken) {
	            return runWithCancellationToken(function () {
	                var diagnostics = [];
	                walk(sourceFile);
	                return diagnostics;
	                function walk(node) {
	                    if (!node) {
	                        return false;
	                    }
	                    switch (node.kind) {
	                        case 224 /* ImportEqualsDeclaration */:
	                            diagnostics.push(ts.createDiagnosticForNode(node, ts.Diagnostics.import_can_only_be_used_in_a_ts_file));
	                            return true;
	                        case 230 /* ExportAssignment */:
	                            if (node.isExportEquals) {
	                                diagnostics.push(ts.createDiagnosticForNode(node, ts.Diagnostics.export_can_only_be_used_in_a_ts_file));
	                                return true;
	                            }
	                            break;
	                        case 217 /* ClassDeclaration */:
	                            var classDeclaration = node;
	                            if (checkModifiers(classDeclaration.modifiers) ||
	                                checkTypeParameters(classDeclaration.typeParameters)) {
	                                return true;
	                            }
	                            break;
	                        case 246 /* HeritageClause */:
	                            var heritageClause = node;
	                            if (heritageClause.token === 106 /* ImplementsKeyword */) {
	                                diagnostics.push(ts.createDiagnosticForNode(node, ts.Diagnostics.implements_clauses_can_only_be_used_in_a_ts_file));
	                                return true;
	                            }
	                            break;
	                        case 218 /* InterfaceDeclaration */:
	                            diagnostics.push(ts.createDiagnosticForNode(node, ts.Diagnostics.interface_declarations_can_only_be_used_in_a_ts_file));
	                            return true;
	                        case 221 /* ModuleDeclaration */:
	                            diagnostics.push(ts.createDiagnosticForNode(node, ts.Diagnostics.module_declarations_can_only_be_used_in_a_ts_file));
	                            return true;
	                        case 219 /* TypeAliasDeclaration */:
	                            diagnostics.push(ts.createDiagnosticForNode(node, ts.Diagnostics.type_aliases_can_only_be_used_in_a_ts_file));
	                            return true;
	                        case 144 /* MethodDeclaration */:
	                        case 143 /* MethodSignature */:
	                        case 145 /* Constructor */:
	                        case 146 /* GetAccessor */:
	                        case 147 /* SetAccessor */:
	                        case 176 /* FunctionExpression */:
	                        case 216 /* FunctionDeclaration */:
	                        case 177 /* ArrowFunction */:
	                        case 216 /* FunctionDeclaration */:
	                            var functionDeclaration = node;
	                            if (checkModifiers(functionDeclaration.modifiers) ||
	                                checkTypeParameters(functionDeclaration.typeParameters) ||
	                                checkTypeAnnotation(functionDeclaration.type)) {
	                                return true;
	                            }
	                            break;
	                        case 196 /* VariableStatement */:
	                            var variableStatement = node;
	                            if (checkModifiers(variableStatement.modifiers)) {
	                                return true;
	                            }
	                            break;
	                        case 214 /* VariableDeclaration */:
	                            var variableDeclaration = node;
	                            if (checkTypeAnnotation(variableDeclaration.type)) {
	                                return true;
	                            }
	                            break;
	                        case 171 /* CallExpression */:
	                        case 172 /* NewExpression */:
	                            var expression = node;
	                            if (expression.typeArguments && expression.typeArguments.length > 0) {
	                                var start_2 = expression.typeArguments.pos;
	                                diagnostics.push(ts.createFileDiagnostic(sourceFile, start_2, expression.typeArguments.end - start_2, ts.Diagnostics.type_arguments_can_only_be_used_in_a_ts_file));
	                                return true;
	                            }
	                            break;
	                        case 139 /* Parameter */:
	                            var parameter = node;
	                            if (parameter.modifiers) {
	                                var start_3 = parameter.modifiers.pos;
	                                diagnostics.push(ts.createFileDiagnostic(sourceFile, start_3, parameter.modifiers.end - start_3, ts.Diagnostics.parameter_modifiers_can_only_be_used_in_a_ts_file));
	                                return true;
	                            }
	                            if (parameter.questionToken) {
	                                diagnostics.push(ts.createDiagnosticForNode(parameter.questionToken, ts.Diagnostics._0_can_only_be_used_in_a_ts_file, "?"));
	                                return true;
	                            }
	                            if (parameter.type) {
	                                diagnostics.push(ts.createDiagnosticForNode(parameter.type, ts.Diagnostics.types_can_only_be_used_in_a_ts_file));
	                                return true;
	                            }
	                            break;
	                        case 142 /* PropertyDeclaration */:
	                            diagnostics.push(ts.createDiagnosticForNode(node, ts.Diagnostics.property_declarations_can_only_be_used_in_a_ts_file));
	                            return true;
	                        case 220 /* EnumDeclaration */:
	                            diagnostics.push(ts.createDiagnosticForNode(node, ts.Diagnostics.enum_declarations_can_only_be_used_in_a_ts_file));
	                            return true;
	                        case 174 /* TypeAssertionExpression */:
	                            var typeAssertionExpression = node;
	                            diagnostics.push(ts.createDiagnosticForNode(typeAssertionExpression.type, ts.Diagnostics.type_assertion_expressions_can_only_be_used_in_a_ts_file));
	                            return true;
	                        case 140 /* Decorator */:
	                            if (!options.experimentalDecorators) {
	                                diagnostics.push(ts.createDiagnosticForNode(node, ts.Diagnostics.Experimental_support_for_decorators_is_a_feature_that_is_subject_to_change_in_a_future_release_Set_the_experimentalDecorators_option_to_remove_this_warning));
	                            }
	                            return true;
	                    }
	                    return ts.forEachChild(node, walk);
	                }
	                function checkTypeParameters(typeParameters) {
	                    if (typeParameters) {
	                        var start_4 = typeParameters.pos;
	                        diagnostics.push(ts.createFileDiagnostic(sourceFile, start_4, typeParameters.end - start_4, ts.Diagnostics.type_parameter_declarations_can_only_be_used_in_a_ts_file));
	                        return true;
	                    }
	                    return false;
	                }
	                function checkTypeAnnotation(type) {
	                    if (type) {
	                        diagnostics.push(ts.createDiagnosticForNode(type, ts.Diagnostics.types_can_only_be_used_in_a_ts_file));
	                        return true;
	                    }
	                    return false;
	                }
	                function checkModifiers(modifiers) {
	                    if (modifiers) {
	                        for (var _i = 0, modifiers_1 = modifiers; _i < modifiers_1.length; _i++) {
	                            var modifier = modifiers_1[_i];
	                            switch (modifier.kind) {
	                                case 112 /* PublicKeyword */:
	                                case 110 /* PrivateKeyword */:
	                                case 111 /* ProtectedKeyword */:
	                                case 122 /* DeclareKeyword */:
	                                    diagnostics.push(ts.createDiagnosticForNode(modifier, ts.Diagnostics._0_can_only_be_used_in_a_ts_file, ts.tokenToString(modifier.kind)));
	                                    return true;
	                                // These are all legal modifiers.
	                                case 113 /* StaticKeyword */:
	                                case 82 /* ExportKeyword */:
	                                case 74 /* ConstKeyword */:
	                                case 77 /* DefaultKeyword */:
	                                case 115 /* AbstractKeyword */:
	                            }
	                        }
	                    }
	                    return false;
	                }
	            });
	        }
	        function getDeclarationDiagnosticsWorker(sourceFile, cancellationToken) {
	            return runWithCancellationToken(function () {
	                var resolver = getDiagnosticsProducingTypeChecker().getEmitResolver(sourceFile, cancellationToken);
	                // Don't actually write any files since we're just getting diagnostics.
	                var writeFile = function () { };
	                return ts.getDeclarationDiagnostics(getEmitHost(writeFile), resolver, sourceFile);
	            });
	        }
	        function getDeclarationDiagnosticsForFile(sourceFile, cancellationToken) {
	            return ts.isDeclarationFile(sourceFile) ? [] : getDeclarationDiagnosticsWorker(sourceFile, cancellationToken);
	        }
	        function getOptionsDiagnostics() {
	            var allDiagnostics = [];
	            ts.addRange(allDiagnostics, fileProcessingDiagnostics.getGlobalDiagnostics());
	            ts.addRange(allDiagnostics, programDiagnostics.getGlobalDiagnostics());
	            return ts.sortAndDeduplicateDiagnostics(allDiagnostics);
	        }
	        function getGlobalDiagnostics() {
	            var allDiagnostics = [];
	            ts.addRange(allDiagnostics, getDiagnosticsProducingTypeChecker().getGlobalDiagnostics());
	            return ts.sortAndDeduplicateDiagnostics(allDiagnostics);
	        }
	        function hasExtension(fileName) {
	            return ts.getBaseFileName(fileName).indexOf(".") >= 0;
	        }
	        function processRootFile(fileName, isDefaultLib) {
	            processSourceFile(ts.normalizePath(fileName), isDefaultLib);
	        }
	        function fileReferenceIsEqualTo(a, b) {
	            return a.fileName === b.fileName;
	        }
	        function moduleNameIsEqualTo(a, b) {
	            return a.text === b.text;
	        }
	        function getTextOfLiteral(literal) {
	            return literal.text;
	        }
	        function collectExternalModuleReferences(file) {
	            if (file.imports) {
	                return;
	            }
	            var isJavaScriptFile = ts.isSourceFileJavaScript(file);
	            var isExternalModuleFile = ts.isExternalModule(file);
	            var imports;
	            var moduleAugmentations;
	            for (var _i = 0, _a = file.statements; _i < _a.length; _i++) {
	                var node = _a[_i];
	                collectModuleReferences(node, /*inAmbientModule*/ false);
	                if (isJavaScriptFile) {
	                    collectRequireCalls(node);
	                }
	            }
	            file.imports = imports || emptyArray;
	            file.moduleAugmentations = moduleAugmentations || emptyArray;
	            return;
	            function collectModuleReferences(node, inAmbientModule) {
	                switch (node.kind) {
	                    case 225 /* ImportDeclaration */:
	                    case 224 /* ImportEqualsDeclaration */:
	                    case 231 /* ExportDeclaration */:
	                        var moduleNameExpr = ts.getExternalModuleName(node);
	                        if (!moduleNameExpr || moduleNameExpr.kind !== 9 /* StringLiteral */) {
	                            break;
	                        }
	                        if (!moduleNameExpr.text) {
	                            break;
	                        }
	                        // TypeScript 1.0 spec (April 2014): 12.1.6
	                        // An ExternalImportDeclaration in an AmbientExternalModuleDeclaration may reference other external modules
	                        // only through top - level external module names. Relative external module names are not permitted.
	                        if (!inAmbientModule || !ts.isExternalModuleNameRelative(moduleNameExpr.text)) {
	                            (imports || (imports = [])).push(moduleNameExpr);
	                        }
	                        break;
	                    case 221 /* ModuleDeclaration */:
	                        if (ts.isAmbientModule(node) && (inAmbientModule || node.flags & 4 /* Ambient */ || ts.isDeclarationFile(file))) {
	                            var moduleName = node.name;
	                            // Ambient module declarations can be interpreted as augmentations for some existing external modules.
	                            // This will happen in two cases:
	                            // - if current file is external module then module augmentation is a ambient module declaration defined in the top level scope
	                            // - if current file is not external module then module augmentation is an ambient module declaration with non-relative module name
	                            //   immediately nested in top level ambient module declaration .
	                            if (isExternalModuleFile || (inAmbientModule && !ts.isExternalModuleNameRelative(moduleName.text))) {
	                                (moduleAugmentations || (moduleAugmentations = [])).push(moduleName);
	                            }
	                            else if (!inAmbientModule) {
	                                // An AmbientExternalModuleDeclaration declares an external module.
	                                // This type of declaration is permitted only in the global module.
	                                // The StringLiteral must specify a top - level external module name.
	                                // Relative external module names are not permitted
	                                // NOTE: body of ambient module is always a module block
	                                for (var _i = 0, _a = node.body.statements; _i < _a.length; _i++) {
	                                    var statement = _a[_i];
	                                    collectModuleReferences(statement, /*inAmbientModule*/ true);
	                                }
	                            }
	                        }
	                }
	            }
	            function collectRequireCalls(node) {
	                if (ts.isRequireCall(node, /*checkArgumentIsStringLiteral*/ true)) {
	                    (imports || (imports = [])).push(node.arguments[0]);
	                }
	                else {
	                    ts.forEachChild(node, collectRequireCalls);
	                }
	            }
	        }
	        function processSourceFile(fileName, isDefaultLib, refFile, refPos, refEnd) {
	            var diagnosticArgument;
	            var diagnostic;
	            if (hasExtension(fileName)) {
	                if (!options.allowNonTsExtensions && !ts.forEach(supportedExtensions, function (extension) { return ts.fileExtensionIs(host.getCanonicalFileName(fileName), extension); })) {
	                    diagnostic = ts.Diagnostics.File_0_has_unsupported_extension_The_only_supported_extensions_are_1;
	                    diagnosticArgument = [fileName, "'" + supportedExtensions.join("', '") + "'"];
	                }
	                else if (!findSourceFile(fileName, ts.toPath(fileName, currentDirectory, getCanonicalFileName), isDefaultLib, refFile, refPos, refEnd)) {
	                    diagnostic = ts.Diagnostics.File_0_not_found;
	                    diagnosticArgument = [fileName];
	                }
	                else if (refFile && host.getCanonicalFileName(fileName) === host.getCanonicalFileName(refFile.fileName)) {
	                    diagnostic = ts.Diagnostics.A_file_cannot_have_a_reference_to_itself;
	                    diagnosticArgument = [fileName];
	                }
	            }
	            else {
	                var nonTsFile = options.allowNonTsExtensions && findSourceFile(fileName, ts.toPath(fileName, currentDirectory, getCanonicalFileName), isDefaultLib, refFile, refPos, refEnd);
	                if (!nonTsFile) {
	                    if (options.allowNonTsExtensions) {
	                        diagnostic = ts.Diagnostics.File_0_not_found;
	                        diagnosticArgument = [fileName];
	                    }
	                    else if (!ts.forEach(supportedExtensions, function (extension) { return findSourceFile(fileName + extension, ts.toPath(fileName + extension, currentDirectory, getCanonicalFileName), isDefaultLib, refFile, refPos, refEnd); })) {
	                        diagnostic = ts.Diagnostics.File_0_not_found;
	                        fileName += ".ts";
	                        diagnosticArgument = [fileName];
	                    }
	                }
	            }
	            if (diagnostic) {
	                if (refFile !== undefined && refEnd !== undefined && refPos !== undefined) {
	                    fileProcessingDiagnostics.add(ts.createFileDiagnostic.apply(void 0, [refFile, refPos, refEnd - refPos, diagnostic].concat(diagnosticArgument)));
	                }
	                else {
	                    fileProcessingDiagnostics.add(ts.createCompilerDiagnostic.apply(void 0, [diagnostic].concat(diagnosticArgument)));
	                }
	            }
	        }
	        function reportFileNamesDifferOnlyInCasingError(fileName, existingFileName, refFile, refPos, refEnd) {
	            if (refFile !== undefined && refPos !== undefined && refEnd !== undefined) {
	                fileProcessingDiagnostics.add(ts.createFileDiagnostic(refFile, refPos, refEnd - refPos, ts.Diagnostics.File_name_0_differs_from_already_included_file_name_1_only_in_casing, fileName, existingFileName));
	            }
	            else {
	                fileProcessingDiagnostics.add(ts.createCompilerDiagnostic(ts.Diagnostics.File_name_0_differs_from_already_included_file_name_1_only_in_casing, fileName, existingFileName));
	            }
	        }
	        // Get source file from normalized fileName
	        function findSourceFile(fileName, path, isDefaultLib, refFile, refPos, refEnd) {
	            if (filesByName.contains(path)) {
	                var file_1 = filesByName.get(path);
	                // try to check if we've already seen this file but with a different casing in path
	                // NOTE: this only makes sense for case-insensitive file systems
	                if (file_1 && options.forceConsistentCasingInFileNames && ts.getNormalizedAbsolutePath(file_1.fileName, currentDirectory) !== ts.getNormalizedAbsolutePath(fileName, currentDirectory)) {
	                    reportFileNamesDifferOnlyInCasingError(fileName, file_1.fileName, refFile, refPos, refEnd);
	                }
	                return file_1;
	            }
	            // We haven't looked for this file, do so now and cache result
	            var file = host.getSourceFile(fileName, options.target, function (hostErrorMessage) {
	                if (refFile !== undefined && refPos !== undefined && refEnd !== undefined) {
	                    fileProcessingDiagnostics.add(ts.createFileDiagnostic(refFile, refPos, refEnd - refPos, ts.Diagnostics.Cannot_read_file_0_Colon_1, fileName, hostErrorMessage));
	                }
	                else {
	                    fileProcessingDiagnostics.add(ts.createCompilerDiagnostic(ts.Diagnostics.Cannot_read_file_0_Colon_1, fileName, hostErrorMessage));
	                }
	            });
	            filesByName.set(path, file);
	            if (file) {
	                file.path = path;
	                if (host.useCaseSensitiveFileNames()) {
	                    // for case-sensitive file systems check if we've already seen some file with similar filename ignoring case
	                    var existingFile = filesByNameIgnoreCase.get(path);
	                    if (existingFile) {
	                        reportFileNamesDifferOnlyInCasingError(fileName, existingFile.fileName, refFile, refPos, refEnd);
	                    }
	                    else {
	                        filesByNameIgnoreCase.set(path, file);
	                    }
	                }
	                skipDefaultLib = skipDefaultLib || file.hasNoDefaultLib;
	                var basePath = ts.getDirectoryPath(fileName);
	                if (!options.noResolve) {
	                    processReferencedFiles(file, basePath);
	                }
	                // always process imported modules to record module name resolutions
	                processImportedModules(file, basePath);
	                if (isDefaultLib) {
	                    files.unshift(file);
	                }
	                else {
	                    files.push(file);
	                }
	            }
	            return file;
	        }
	        function processReferencedFiles(file, basePath) {
	            ts.forEach(file.referencedFiles, function (ref) {
	                var referencedFileName = resolveTripleslashReference(ref.fileName, file.fileName);
	                processSourceFile(referencedFileName, /*isDefaultLib*/ false, file, ref.pos, ref.end);
	            });
	        }
	        function getCanonicalFileName(fileName) {
	            return host.getCanonicalFileName(fileName);
	        }
	        function processImportedModules(file, basePath) {
	            collectExternalModuleReferences(file);
	            if (file.imports.length || file.moduleAugmentations.length) {
	                file.resolvedModules = {};
	                var moduleNames = ts.map(ts.concatenate(file.imports, file.moduleAugmentations), getTextOfLiteral);
	                var resolutions = resolveModuleNamesWorker(moduleNames, ts.getNormalizedAbsolutePath(file.fileName, currentDirectory));
	                for (var i = 0; i < moduleNames.length; i++) {
	                    var resolution = resolutions[i];
	                    ts.setResolvedModule(file, moduleNames[i], resolution);
	                    // add file to program only if:
	                    // - resolution was successfull
	                    // - noResolve is falsy
	                    // - module name come from the list fo imports
	                    var shouldAddFile = resolution &&
	                        !options.noResolve &&
	                        i < file.imports.length;
	                    if (shouldAddFile) {
	                        var importedFile = findSourceFile(resolution.resolvedFileName, ts.toPath(resolution.resolvedFileName, currentDirectory, getCanonicalFileName), /*isDefaultLib*/ false, file, ts.skipTrivia(file.text, file.imports[i].pos), file.imports[i].end);
	                        if (importedFile && resolution.isExternalLibraryImport) {
	                            // Since currently irrespective of allowJs, we only look for supportedTypeScript extension external module files,
	                            // this check is ok. Otherwise this would be never true for javascript file
	                            if (!ts.isExternalModule(importedFile) && importedFile.statements.length) {
	                                var start_5 = ts.getTokenPosOfNode(file.imports[i], file);
	                                fileProcessingDiagnostics.add(ts.createFileDiagnostic(file, start_5, file.imports[i].end - start_5, ts.Diagnostics.Exported_external_package_typings_file_0_is_not_a_module_Please_contact_the_package_author_to_update_the_package_definition, importedFile.fileName));
	                            }
	                            else if (importedFile.referencedFiles.length) {
	                                var firstRef = importedFile.referencedFiles[0];
	                                fileProcessingDiagnostics.add(ts.createFileDiagnostic(importedFile, firstRef.pos, firstRef.end - firstRef.pos, ts.Diagnostics.Exported_external_package_typings_file_cannot_contain_tripleslash_references_Please_contact_the_package_author_to_update_the_package_definition));
	                            }
	                        }
	                    }
	                }
	            }
	            else {
	                // no imports - drop cached module resolutions
	                file.resolvedModules = undefined;
	            }
	            return;
	        }
	        function computeCommonSourceDirectory(sourceFiles) {
	            var commonPathComponents;
	            var failed = ts.forEach(files, function (sourceFile) {
	                // Each file contributes into common source file path
	                if (ts.isDeclarationFile(sourceFile)) {
	                    return;
	                }
	                var sourcePathComponents = ts.getNormalizedPathComponents(sourceFile.fileName, currentDirectory);
	                sourcePathComponents.pop(); // The base file name is not part of the common directory path
	                if (!commonPathComponents) {
	                    // first file
	                    commonPathComponents = sourcePathComponents;
	                    return;
	                }
	                for (var i = 0, n = Math.min(commonPathComponents.length, sourcePathComponents.length); i < n; i++) {
	                    if (getCanonicalFileName(commonPathComponents[i]) !== getCanonicalFileName(sourcePathComponents[i])) {
	                        if (i === 0) {
	                            // Failed to find any common path component
	                            return true;
	                        }
	                        // New common path found that is 0 -> i-1
	                        commonPathComponents.length = i;
	                        break;
	                    }
	                }
	                // If the sourcePathComponents was shorter than the commonPathComponents, truncate to the sourcePathComponents
	                if (sourcePathComponents.length < commonPathComponents.length) {
	                    commonPathComponents.length = sourcePathComponents.length;
	                }
	            });
	            // A common path can not be found when paths span multiple drives on windows, for example
	            if (failed) {
	                return "";
	            }
	            if (!commonPathComponents) {
	                return currentDirectory;
	            }
	            return ts.getNormalizedPathFromPathComponents(commonPathComponents);
	        }
	        function checkSourceFilesBelongToPath(sourceFiles, rootDirectory) {
	            var allFilesBelongToPath = true;
	            if (sourceFiles) {
	                var absoluteRootDirectoryPath = host.getCanonicalFileName(ts.getNormalizedAbsolutePath(rootDirectory, currentDirectory));
	                for (var _i = 0, sourceFiles_2 = sourceFiles; _i < sourceFiles_2.length; _i++) {
	                    var sourceFile = sourceFiles_2[_i];
	                    if (!ts.isDeclarationFile(sourceFile)) {
	                        var absoluteSourceFilePath = host.getCanonicalFileName(ts.getNormalizedAbsolutePath(sourceFile.fileName, currentDirectory));
	                        if (absoluteSourceFilePath.indexOf(absoluteRootDirectoryPath) !== 0) {
	                            programDiagnostics.add(ts.createCompilerDiagnostic(ts.Diagnostics.File_0_is_not_under_rootDir_1_rootDir_is_expected_to_contain_all_source_files, sourceFile.fileName, options.rootDir));
	                            allFilesBelongToPath = false;
	                        }
	                    }
	                }
	            }
	            return allFilesBelongToPath;
	        }
	        function verifyCompilerOptions() {
	            if (options.isolatedModules) {
	                if (options.declaration) {
	                    programDiagnostics.add(ts.createCompilerDiagnostic(ts.Diagnostics.Option_0_cannot_be_specified_with_option_1, "declaration", "isolatedModules"));
	                }
	                if (options.noEmitOnError) {
	                    programDiagnostics.add(ts.createCompilerDiagnostic(ts.Diagnostics.Option_0_cannot_be_specified_with_option_1, "noEmitOnError", "isolatedModules"));
	                }
	                if (options.out) {
	                    programDiagnostics.add(ts.createCompilerDiagnostic(ts.Diagnostics.Option_0_cannot_be_specified_with_option_1, "out", "isolatedModules"));
	                }
	                if (options.outFile) {
	                    programDiagnostics.add(ts.createCompilerDiagnostic(ts.Diagnostics.Option_0_cannot_be_specified_with_option_1, "outFile", "isolatedModules"));
	                }
	            }
	            if (options.inlineSourceMap) {
	                if (options.sourceMap) {
	                    programDiagnostics.add(ts.createCompilerDiagnostic(ts.Diagnostics.Option_0_cannot_be_specified_with_option_1, "sourceMap", "inlineSourceMap"));
	                }
	                if (options.mapRoot) {
	                    programDiagnostics.add(ts.createCompilerDiagnostic(ts.Diagnostics.Option_0_cannot_be_specified_with_option_1, "mapRoot", "inlineSourceMap"));
	                }
	            }
	            if (options.inlineSources) {
	                if (!options.sourceMap && !options.inlineSourceMap) {
	                    programDiagnostics.add(ts.createCompilerDiagnostic(ts.Diagnostics.Option_inlineSources_can_only_be_used_when_either_option_inlineSourceMap_or_option_sourceMap_is_provided));
	                }
	                if (options.sourceRoot) {
	                    programDiagnostics.add(ts.createCompilerDiagnostic(ts.Diagnostics.Option_0_cannot_be_specified_with_option_1, "sourceRoot", "inlineSources"));
	                }
	            }
	            if (options.out && options.outFile) {
	                programDiagnostics.add(ts.createCompilerDiagnostic(ts.Diagnostics.Option_0_cannot_be_specified_with_option_1, "out", "outFile"));
	            }
	            if (!options.sourceMap && (options.mapRoot || options.sourceRoot)) {
	                // Error to specify --mapRoot or --sourceRoot without mapSourceFiles
	                if (options.mapRoot) {
	                    programDiagnostics.add(ts.createCompilerDiagnostic(ts.Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1, "mapRoot", "sourceMap"));
	                }
	                if (options.sourceRoot && !options.inlineSourceMap) {
	                    programDiagnostics.add(ts.createCompilerDiagnostic(ts.Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1, "sourceRoot", "sourceMap"));
	                }
	            }
	            var languageVersion = options.target || 0 /* ES3 */;
	            var outFile = options.outFile || options.out;
	            var firstExternalModuleSourceFile = ts.forEach(files, function (f) { return ts.isExternalModule(f) ? f : undefined; });
	            if (options.isolatedModules) {
	                if (options.module === 0 /* None */ && languageVersion < 2 /* ES6 */) {
	                    programDiagnostics.add(ts.createCompilerDiagnostic(ts.Diagnostics.Option_isolatedModules_can_only_be_used_when_either_option_module_is_provided_or_option_target_is_ES2015_or_higher));
	                }
	                var firstNonExternalModuleSourceFile = ts.forEach(files, function (f) { return !ts.isExternalModule(f) && !ts.isDeclarationFile(f) ? f : undefined; });
	                if (firstNonExternalModuleSourceFile) {
	                    var span = ts.getErrorSpanForNode(firstNonExternalModuleSourceFile, firstNonExternalModuleSourceFile);
	                    programDiagnostics.add(ts.createFileDiagnostic(firstNonExternalModuleSourceFile, span.start, span.length, ts.Diagnostics.Cannot_compile_namespaces_when_the_isolatedModules_flag_is_provided));
	                }
	            }
	            else if (firstExternalModuleSourceFile && languageVersion < 2 /* ES6 */ && options.module === 0 /* None */) {
	                // We cannot use createDiagnosticFromNode because nodes do not have parents yet
	                var span = ts.getErrorSpanForNode(firstExternalModuleSourceFile, firstExternalModuleSourceFile.externalModuleIndicator);
	                programDiagnostics.add(ts.createFileDiagnostic(firstExternalModuleSourceFile, span.start, span.length, ts.Diagnostics.Cannot_compile_modules_unless_the_module_flag_is_provided_with_a_valid_module_type_Consider_setting_the_module_compiler_option_in_a_tsconfig_json_file));
	            }
	            // Cannot specify module gen target of es6 when below es6
	            if (options.module === 5 /* ES6 */ && languageVersion < 2 /* ES6 */) {
	                programDiagnostics.add(ts.createCompilerDiagnostic(ts.Diagnostics.Cannot_compile_modules_into_es2015_when_targeting_ES5_or_lower));
	            }
	            // Cannot specify module gen that isn't amd or system with --out
	            if (outFile && options.module && !(options.module === 2 /* AMD */ || options.module === 4 /* System */)) {
	                programDiagnostics.add(ts.createCompilerDiagnostic(ts.Diagnostics.Only_amd_and_system_modules_are_supported_alongside_0, options.out ? "out" : "outFile"));
	            }
	            // there has to be common source directory if user specified --outdir || --sourceRoot
	            // if user specified --mapRoot, there needs to be common source directory if there would be multiple files being emitted
	            if (options.outDir ||
	                options.sourceRoot ||
	                options.mapRoot) {
	                // Precalculate and cache the common source directory
	                var dir = getCommonSourceDirectory();
	                // If we failed to find a good common directory, but outDir is specified and at least one of our files is on a windows drive/URL/other resource, add a failure
	                if (options.outDir && dir === "" && ts.forEach(files, function (file) { return ts.getRootLength(file.fileName) > 1; })) {
	                    programDiagnostics.add(ts.createCompilerDiagnostic(ts.Diagnostics.Cannot_find_the_common_subdirectory_path_for_the_input_files));
	                }
	            }
	            if (options.noEmit) {
	                if (options.out) {
	                    programDiagnostics.add(ts.createCompilerDiagnostic(ts.Diagnostics.Option_0_cannot_be_specified_with_option_1, "noEmit", "out"));
	                }
	                if (options.outFile) {
	                    programDiagnostics.add(ts.createCompilerDiagnostic(ts.Diagnostics.Option_0_cannot_be_specified_with_option_1, "noEmit", "outFile"));
	                }
	                if (options.outDir) {
	                    programDiagnostics.add(ts.createCompilerDiagnostic(ts.Diagnostics.Option_0_cannot_be_specified_with_option_1, "noEmit", "outDir"));
	                }
	                if (options.declaration) {
	                    programDiagnostics.add(ts.createCompilerDiagnostic(ts.Diagnostics.Option_0_cannot_be_specified_with_option_1, "noEmit", "declaration"));
	                }
	            }
	            else if (options.allowJs && options.declaration) {
	                programDiagnostics.add(ts.createCompilerDiagnostic(ts.Diagnostics.Option_0_cannot_be_specified_with_option_1, "allowJs", "declaration"));
	            }
	            if (options.emitDecoratorMetadata &&
	                !options.experimentalDecorators) {
	                programDiagnostics.add(ts.createCompilerDiagnostic(ts.Diagnostics.Option_0_cannot_be_specified_without_specifying_option_1, "emitDecoratorMetadata", "experimentalDecorators"));
	            }
	            if (options.reactNamespace && !ts.isIdentifier(options.reactNamespace, languageVersion)) {
	                programDiagnostics.add(ts.createCompilerDiagnostic(ts.Diagnostics.Invalide_value_for_reactNamespace_0_is_not_a_valid_identifier, options.reactNamespace));
	            }
	            // If the emit is enabled make sure that every output file is unique and not overwriting any of the input files
	            if (!options.noEmit && !options.suppressOutputPathCheck) {
	                var emitHost = getEmitHost();
	                var emitFilesSeen_1 = ts.createFileMap(!host.useCaseSensitiveFileNames() ? function (key) { return key.toLocaleLowerCase(); } : undefined);
	                ts.forEachExpectedEmitFile(emitHost, function (emitFileNames, sourceFiles, isBundledEmit) {
	                    verifyEmitFilePath(emitFileNames.jsFilePath, emitFilesSeen_1);
	                    verifyEmitFilePath(emitFileNames.declarationFilePath, emitFilesSeen_1);
	                });
	            }
	            // Verify that all the emit files are unique and don't overwrite input files
	            function verifyEmitFilePath(emitFileName, emitFilesSeen) {
	                if (emitFileName) {
	                    var emitFilePath = ts.toPath(emitFileName, currentDirectory, getCanonicalFileName);
	                    // Report error if the output overwrites input file
	                    if (filesByName.contains(emitFilePath)) {
	                        createEmitBlockingDiagnostics(emitFileName, emitFilePath, ts.Diagnostics.Cannot_write_file_0_because_it_would_overwrite_input_file);
	                    }
	                    // Report error if multiple files write into same file
	                    if (emitFilesSeen.contains(emitFilePath)) {
	                        // Already seen the same emit file - report error
	                        createEmitBlockingDiagnostics(emitFileName, emitFilePath, ts.Diagnostics.Cannot_write_file_0_because_it_would_be_overwritten_by_multiple_input_files);
	                    }
	                    else {
	                        emitFilesSeen.set(emitFilePath, true);
	                    }
	                }
	            }
	        }
	        function createEmitBlockingDiagnostics(emitFileName, emitFilePath, message) {
	            hasEmitBlockingDiagnostics.set(ts.toPath(emitFileName, currentDirectory, getCanonicalFileName), true);
	            programDiagnostics.add(ts.createCompilerDiagnostic(message, emitFileName));
	        }
	    }
	    ts.createProgram = createProgram;
	})(ts || (ts = {}));
	/// <reference path="sys.ts"/>
	/// <reference path="types.ts"/>
	/// <reference path="core.ts"/>
	/// <reference path="diagnosticInformationMap.generated.ts"/>
	/// <reference path="scanner.ts"/>
	var ts;
	(function (ts) {
	    /* @internal */
	    ts.optionDeclarations = [
	        {
	            name: "charset",
	            type: "string"
	        },
	        {
	            name: "declaration",
	            shortName: "d",
	            type: "boolean",
	            description: ts.Diagnostics.Generates_corresponding_d_ts_file
	        },
	        {
	            name: "diagnostics",
	            type: "boolean"
	        },
	        {
	            name: "emitBOM",
	            type: "boolean"
	        },
	        {
	            name: "help",
	            shortName: "h",
	            type: "boolean",
	            description: ts.Diagnostics.Print_this_message
	        },
	        {
	            name: "init",
	            type: "boolean",
	            description: ts.Diagnostics.Initializes_a_TypeScript_project_and_creates_a_tsconfig_json_file
	        },
	        {
	            name: "inlineSourceMap",
	            type: "boolean"
	        },
	        {
	            name: "inlineSources",
	            type: "boolean"
	        },
	        {
	            name: "jsx",
	            type: {
	                "preserve": 1 /* Preserve */,
	                "react": 2 /* React */
	            },
	            paramType: ts.Diagnostics.KIND,
	            description: ts.Diagnostics.Specify_JSX_code_generation_Colon_preserve_or_react,
	            error: ts.Diagnostics.Argument_for_jsx_must_be_preserve_or_react
	        },
	        {
	            name: "reactNamespace",
	            type: "string",
	            description: ts.Diagnostics.Specifies_the_object_invoked_for_createElement_and_spread_when_targeting_react_JSX_emit
	        },
	        {
	            name: "listFiles",
	            type: "boolean"
	        },
	        {
	            name: "locale",
	            type: "string"
	        },
	        {
	            name: "mapRoot",
	            type: "string",
	            isFilePath: true,
	            description: ts.Diagnostics.Specifies_the_location_where_debugger_should_locate_map_files_instead_of_generated_locations,
	            paramType: ts.Diagnostics.LOCATION
	        },
	        {
	            name: "module",
	            shortName: "m",
	            type: {
	                "none": 0 /* None */,
	                "commonjs": 1 /* CommonJS */,
	                "amd": 2 /* AMD */,
	                "system": 4 /* System */,
	                "umd": 3 /* UMD */,
	                "es6": 5 /* ES6 */,
	                "es2015": 5 /* ES2015 */
	            },
	            description: ts.Diagnostics.Specify_module_code_generation_Colon_commonjs_amd_system_umd_or_es2015,
	            paramType: ts.Diagnostics.KIND,
	            error: ts.Diagnostics.Argument_for_module_option_must_be_commonjs_amd_system_umd_es2015_or_none
	        },
	        {
	            name: "newLine",
	            type: {
	                "crlf": 0 /* CarriageReturnLineFeed */,
	                "lf": 1 /* LineFeed */
	            },
	            description: ts.Diagnostics.Specifies_the_end_of_line_sequence_to_be_used_when_emitting_files_Colon_CRLF_dos_or_LF_unix,
	            paramType: ts.Diagnostics.NEWLINE,
	            error: ts.Diagnostics.Argument_for_newLine_option_must_be_CRLF_or_LF
	        },
	        {
	            name: "noEmit",
	            type: "boolean",
	            description: ts.Diagnostics.Do_not_emit_outputs
	        },
	        {
	            name: "noEmitHelpers",
	            type: "boolean"
	        },
	        {
	            name: "noEmitOnError",
	            type: "boolean",
	            description: ts.Diagnostics.Do_not_emit_outputs_if_any_errors_were_reported
	        },
	        {
	            name: "noImplicitAny",
	            type: "boolean",
	            description: ts.Diagnostics.Raise_error_on_expressions_and_declarations_with_an_implied_any_type
	        },
	        {
	            name: "noLib",
	            type: "boolean"
	        },
	        {
	            name: "noResolve",
	            type: "boolean"
	        },
	        {
	            name: "skipDefaultLibCheck",
	            type: "boolean"
	        },
	        {
	            name: "out",
	            type: "string",
	            isFilePath: false,
	            // for correct behaviour, please use outFile
	            paramType: ts.Diagnostics.FILE
	        },
	        {
	            name: "outFile",
	            type: "string",
	            isFilePath: true,
	            description: ts.Diagnostics.Concatenate_and_emit_output_to_single_file,
	            paramType: ts.Diagnostics.FILE
	        },
	        {
	            name: "outDir",
	            type: "string",
	            isFilePath: true,
	            description: ts.Diagnostics.Redirect_output_structure_to_the_directory,
	            paramType: ts.Diagnostics.DIRECTORY
	        },
	        {
	            name: "preserveConstEnums",
	            type: "boolean",
	            description: ts.Diagnostics.Do_not_erase_const_enum_declarations_in_generated_code
	        },
	        {
	            name: "pretty",
	            paramType: ts.Diagnostics.KIND,
	            description: ts.Diagnostics.Stylize_errors_and_messages_using_color_and_context_experimental,
	            type: "boolean"
	        },
	        {
	            name: "project",
	            shortName: "p",
	            type: "string",
	            isFilePath: true,
	            description: ts.Diagnostics.Compile_the_project_in_the_given_directory,
	            paramType: ts.Diagnostics.DIRECTORY
	        },
	        {
	            name: "removeComments",
	            type: "boolean",
	            description: ts.Diagnostics.Do_not_emit_comments_to_output
	        },
	        {
	            name: "rootDir",
	            type: "string",
	            isFilePath: true,
	            description: ts.Diagnostics.Specifies_the_root_directory_of_input_files_Use_to_control_the_output_directory_structure_with_outDir,
	            paramType: ts.Diagnostics.LOCATION
	        },
	        {
	            name: "isolatedModules",
	            type: "boolean"
	        },
	        {
	            name: "sourceMap",
	            type: "boolean",
	            description: ts.Diagnostics.Generates_corresponding_map_file
	        },
	        {
	            name: "sourceRoot",
	            type: "string",
	            isFilePath: true,
	            description: ts.Diagnostics.Specifies_the_location_where_debugger_should_locate_TypeScript_files_instead_of_source_locations,
	            paramType: ts.Diagnostics.LOCATION
	        },
	        {
	            name: "suppressExcessPropertyErrors",
	            type: "boolean",
	            description: ts.Diagnostics.Suppress_excess_property_checks_for_object_literals,
	            experimental: true
	        },
	        {
	            name: "suppressImplicitAnyIndexErrors",
	            type: "boolean",
	            description: ts.Diagnostics.Suppress_noImplicitAny_errors_for_indexing_objects_lacking_index_signatures
	        },
	        {
	            name: "stripInternal",
	            type: "boolean",
	            description: ts.Diagnostics.Do_not_emit_declarations_for_code_that_has_an_internal_annotation,
	            experimental: true
	        },
	        {
	            name: "target",
	            shortName: "t",
	            type: {
	                "es3": 0 /* ES3 */,
	                "es5": 1 /* ES5 */,
	                "es6": 2 /* ES6 */,
	                "es2015": 2 /* ES2015 */
	            },
	            description: ts.Diagnostics.Specify_ECMAScript_target_version_Colon_ES3_default_ES5_or_ES2015_experimental,
	            paramType: ts.Diagnostics.VERSION,
	            error: ts.Diagnostics.Argument_for_target_option_must_be_ES3_ES5_or_ES2015
	        },
	        {
	            name: "version",
	            shortName: "v",
	            type: "boolean",
	            description: ts.Diagnostics.Print_the_compiler_s_version
	        },
	        {
	            name: "watch",
	            shortName: "w",
	            type: "boolean",
	            description: ts.Diagnostics.Watch_input_files
	        },
	        {
	            name: "experimentalDecorators",
	            type: "boolean",
	            description: ts.Diagnostics.Enables_experimental_support_for_ES7_decorators
	        },
	        {
	            name: "emitDecoratorMetadata",
	            type: "boolean",
	            experimental: true,
	            description: ts.Diagnostics.Enables_experimental_support_for_emitting_type_metadata_for_decorators
	        },
	        {
	            name: "moduleResolution",
	            type: {
	                "node": 2 /* NodeJs */,
	                "classic": 1 /* Classic */
	            },
	            description: ts.Diagnostics.Specifies_module_resolution_strategy_Colon_node_Node_js_or_classic_TypeScript_pre_1_6,
	            error: ts.Diagnostics.Argument_for_moduleResolution_option_must_be_node_or_classic
	        },
	        {
	            name: "allowUnusedLabels",
	            type: "boolean",
	            description: ts.Diagnostics.Do_not_report_errors_on_unused_labels
	        },
	        {
	            name: "noImplicitReturns",
	            type: "boolean",
	            description: ts.Diagnostics.Report_error_when_not_all_code_paths_in_function_return_a_value
	        },
	        {
	            name: "noFallthroughCasesInSwitch",
	            type: "boolean",
	            description: ts.Diagnostics.Report_errors_for_fallthrough_cases_in_switch_statement
	        },
	        {
	            name: "allowUnreachableCode",
	            type: "boolean",
	            description: ts.Diagnostics.Do_not_report_errors_on_unreachable_code
	        },
	        {
	            name: "forceConsistentCasingInFileNames",
	            type: "boolean",
	            description: ts.Diagnostics.Disallow_inconsistently_cased_references_to_the_same_file
	        },
	        {
	            name: "allowSyntheticDefaultImports",
	            type: "boolean",
	            description: ts.Diagnostics.Allow_default_imports_from_modules_with_no_default_export_This_does_not_affect_code_emit_just_typechecking
	        },
	        {
	            name: "allowJs",
	            type: "boolean",
	            description: ts.Diagnostics.Allow_javascript_files_to_be_compiled
	        },
	        {
	            name: "noImplicitUseStrict",
	            type: "boolean",
	            description: ts.Diagnostics.Do_not_emit_use_strict_directives_in_module_output
	        },
	        {
	            name: "noCustomAsyncPromise",
	            type: "boolean",
	            experimental: true
	        }
	    ];
	    var optionNameMapCache;
	    /* @internal */
	    function getOptionNameMap() {
	        if (optionNameMapCache) {
	            return optionNameMapCache;
	        }
	        var optionNameMap = {};
	        var shortOptionNames = {};
	        ts.forEach(ts.optionDeclarations, function (option) {
	            optionNameMap[option.name.toLowerCase()] = option;
	            if (option.shortName) {
	                shortOptionNames[option.shortName] = option.name;
	            }
	        });
	        optionNameMapCache = { optionNameMap: optionNameMap, shortOptionNames: shortOptionNames };
	        return optionNameMapCache;
	    }
	    ts.getOptionNameMap = getOptionNameMap;
	    function parseCommandLine(commandLine, readFile) {
	        var options = {};
	        var fileNames = [];
	        var errors = [];
	        var _a = getOptionNameMap(), optionNameMap = _a.optionNameMap, shortOptionNames = _a.shortOptionNames;
	        parseStrings(commandLine);
	        return {
	            options: options,
	            fileNames: fileNames,
	            errors: errors
	        };
	        function parseStrings(args) {
	            var i = 0;
	            while (i < args.length) {
	                var s = args[i];
	                i++;
	                if (s.charCodeAt(0) === 64 /* at */) {
	                    parseResponseFile(s.slice(1));
	                }
	                else if (s.charCodeAt(0) === 45 /* minus */) {
	                    s = s.slice(s.charCodeAt(1) === 45 /* minus */ ? 2 : 1).toLowerCase();
	                    // Try to translate short option names to their full equivalents.
	                    if (ts.hasProperty(shortOptionNames, s)) {
	                        s = shortOptionNames[s];
	                    }
	                    if (ts.hasProperty(optionNameMap, s)) {
	                        var opt = optionNameMap[s];
	                        // Check to see if no argument was provided (e.g. "--locale" is the last command-line argument).
	                        if (!args[i] && opt.type !== "boolean") {
	                            errors.push(ts.createCompilerDiagnostic(ts.Diagnostics.Compiler_option_0_expects_an_argument, opt.name));
	                        }
	                        switch (opt.type) {
	                            case "number":
	                                options[opt.name] = parseInt(args[i]);
	                                i++;
	                                break;
	                            case "boolean":
	                                options[opt.name] = true;
	                                break;
	                            case "string":
	                                options[opt.name] = args[i] || "";
	                                i++;
	                                break;
	                            // If not a primitive, the possible types are specified in what is effectively a map of options.
	                            default:
	                                var map_1 = opt.type;
	                                var key = (args[i] || "").toLowerCase();
	                                i++;
	                                if (ts.hasProperty(map_1, key)) {
	                                    options[opt.name] = map_1[key];
	                                }
	                                else {
	                                    errors.push(ts.createCompilerDiagnostic(opt.error));
	                                }
	                        }
	                    }
	                    else {
	                        errors.push(ts.createCompilerDiagnostic(ts.Diagnostics.Unknown_compiler_option_0, s));
	                    }
	                }
	                else {
	                    fileNames.push(s);
	                }
	            }
	        }
	        function parseResponseFile(fileName) {
	            var text = readFile ? readFile(fileName) : ts.sys.readFile(fileName);
	            if (!text) {
	                errors.push(ts.createCompilerDiagnostic(ts.Diagnostics.File_0_not_found, fileName));
	                return;
	            }
	            var args = [];
	            var pos = 0;
	            while (true) {
	                while (pos < text.length && text.charCodeAt(pos) <= 32 /* space */)
	                    pos++;
	                if (pos >= text.length)
	                    break;
	                var start = pos;
	                if (text.charCodeAt(start) === 34 /* doubleQuote */) {
	                    pos++;
	                    while (pos < text.length && text.charCodeAt(pos) !== 34 /* doubleQuote */)
	                        pos++;
	                    if (pos < text.length) {
	                        args.push(text.substring(start + 1, pos));
	                        pos++;
	                    }
	                    else {
	                        errors.push(ts.createCompilerDiagnostic(ts.Diagnostics.Unterminated_quoted_string_in_response_file_0, fileName));
	                    }
	                }
	                else {
	                    while (text.charCodeAt(pos) > 32 /* space */)
	                        pos++;
	                    args.push(text.substring(start, pos));
	                }
	            }
	            parseStrings(args);
	        }
	    }
	    ts.parseCommandLine = parseCommandLine;
	    /**
	      * Read tsconfig.json file
	      * @param fileName The path to the config file
	      */
	    function readConfigFile(fileName, readFile) {
	        var text = "";
	        try {
	            text = readFile(fileName);
	        }
	        catch (e) {
	            return { error: ts.createCompilerDiagnostic(ts.Diagnostics.Cannot_read_file_0_Colon_1, fileName, e.message) };
	        }
	        return parseConfigFileTextToJson(fileName, text);
	    }
	    ts.readConfigFile = readConfigFile;
	    /**
	      * Parse the text of the tsconfig.json file
	      * @param fileName The path to the config file
	      * @param jsonText The text of the config file
	      */
	    function parseConfigFileTextToJson(fileName, jsonText) {
	        try {
	            var jsonTextWithoutComments = removeComments(jsonText);
	            return { config: /\S/.test(jsonTextWithoutComments) ? JSON.parse(jsonTextWithoutComments) : {} };
	        }
	        catch (e) {
	            return { error: ts.createCompilerDiagnostic(ts.Diagnostics.Failed_to_parse_file_0_Colon_1, fileName, e.message) };
	        }
	    }
	    ts.parseConfigFileTextToJson = parseConfigFileTextToJson;
	    /**
	     * Remove the comments from a json like text.
	     * Comments can be single line comments (starting with # or //) or multiline comments using / * * /
	     *
	     * This method replace comment content by whitespace rather than completely remove them to keep positions in json parsing error reporting accurate.
	     */
	    function removeComments(jsonText) {
	        var output = "";
	        var scanner = ts.createScanner(1 /* ES5 */, /* skipTrivia */ false, 0 /* Standard */, jsonText);
	        var token;
	        while ((token = scanner.scan()) !== 1 /* EndOfFileToken */) {
	            switch (token) {
	                case 2 /* SingleLineCommentTrivia */:
	                case 3 /* MultiLineCommentTrivia */:
	                    // replace comments with whitespace to preserve original character positions
	                    output += scanner.getTokenText().replace(/\S/g, " ");
	                    break;
	                default:
	                    output += scanner.getTokenText();
	                    break;
	            }
	        }
	        return output;
	    }
	    /**
	      * Parse the contents of a config file (tsconfig.json).
	      * @param json The contents of the config file to parse
	      * @param host Instance of ParseConfigHost used to enumerate files in folder.
	      * @param basePath A root directory to resolve relative path entries in the config
	      *    file to. e.g. outDir
	      */
	    function parseJsonConfigFileContent(json, host, basePath, existingOptions, configFileName) {
	        if (existingOptions === void 0) { existingOptions = {}; }
	        var _a = convertCompilerOptionsFromJson(json["compilerOptions"], basePath, configFileName), optionsFromJsonConfigFile = _a.options, errors = _a.errors;
	        var options = ts.extend(existingOptions, optionsFromJsonConfigFile);
	        return {
	            options: options,
	            fileNames: getFileNames(),
	            errors: errors
	        };
	        function getFileNames() {
	            var fileNames = [];
	            if (ts.hasProperty(json, "files")) {
	                if (json["files"] instanceof Array) {
	                    fileNames = ts.map(json["files"], function (s) { return ts.combinePaths(basePath, s); });
	                }
	                else {
	                    errors.push(ts.createCompilerDiagnostic(ts.Diagnostics.Compiler_option_0_requires_a_value_of_type_1, "files", "Array"));
	                }
	            }
	            else {
	                var filesSeen = {};
	                var exclude = [];
	                if (json["exclude"] instanceof Array) {
	                    exclude = json["exclude"];
	                }
	                else {
	                    // by default exclude node_modules, and any specificied output directory
	                    exclude = ["node_modules"];
	                    var outDir = json["compilerOptions"] && json["compilerOptions"]["outDir"];
	                    if (outDir) {
	                        exclude.push(outDir);
	                    }
	                }
	                exclude = ts.map(exclude, ts.normalizeSlashes);
	                var supportedExtensions = ts.getSupportedExtensions(options);
	                ts.Debug.assert(ts.indexOf(supportedExtensions, ".ts") < ts.indexOf(supportedExtensions, ".d.ts"), "Changed priority of extensions to pick");
	                // Get files of supported extensions in their order of resolution
	                for (var _i = 0, supportedExtensions_1 = supportedExtensions; _i < supportedExtensions_1.length; _i++) {
	                    var extension = supportedExtensions_1[_i];
	                    var filesInDirWithExtension = host.readDirectory(basePath, extension, exclude);
	                    for (var _a = 0, filesInDirWithExtension_1 = filesInDirWithExtension; _a < filesInDirWithExtension_1.length; _a++) {
	                        var fileName = filesInDirWithExtension_1[_a];
	                        // .ts extension would read the .d.ts extension files too but since .d.ts is lower priority extension,
	                        // lets pick them when its turn comes up
	                        if (extension === ".ts" && ts.fileExtensionIs(fileName, ".d.ts")) {
	                            continue;
	                        }
	                        // Skip over any minified JavaScript files (ending in ".min.js")
	                        if (/\.min\.js$/.test(fileName)) {
	                            continue;
	                        }
	                        // If this is one of the output extension (which would be .d.ts and .js if we are allowing compilation of js files)
	                        // do not include this file if we included .ts or .tsx file with same base name as it could be output of the earlier compilation
	                        if (extension === ".d.ts" || (options.allowJs && ts.contains(ts.supportedJavascriptExtensions, extension))) {
	                            var baseName = fileName.substr(0, fileName.length - extension.length);
	                            if (ts.hasProperty(filesSeen, baseName + ".ts") || ts.hasProperty(filesSeen, baseName + ".tsx")) {
	                                continue;
	                            }
	                        }
	                        filesSeen[fileName] = true;
	                        fileNames.push(fileName);
	                    }
	                }
	            }
	            return fileNames;
	        }
	    }
	    ts.parseJsonConfigFileContent = parseJsonConfigFileContent;
	    function convertCompilerOptionsFromJson(jsonOptions, basePath, configFileName) {
	        var options = {};
	        var errors = [];
	        if (configFileName && ts.getBaseFileName(configFileName) === "jsconfig.json") {
	            options.allowJs = true;
	        }
	        if (!jsonOptions) {
	            return { options: options, errors: errors };
	        }
	        var optionNameMap = ts.arrayToMap(ts.optionDeclarations, function (opt) { return opt.name; });
	        for (var id in jsonOptions) {
	            if (ts.hasProperty(optionNameMap, id)) {
	                var opt = optionNameMap[id];
	                var optType = opt.type;
	                var value = jsonOptions[id];
	                var expectedType = typeof optType === "string" ? optType : "string";
	                if (typeof value === expectedType) {
	                    if (typeof optType !== "string") {
	                        var key = value.toLowerCase();
	                        if (ts.hasProperty(optType, key)) {
	                            value = optType[key];
	                        }
	                        else {
	                            errors.push(ts.createCompilerDiagnostic(opt.error));
	                            value = 0;
	                        }
	                    }
	                    if (opt.isFilePath) {
	                        value = ts.normalizePath(ts.combinePaths(basePath, value));
	                        if (value === "") {
	                            value = ".";
	                        }
	                    }
	                    options[opt.name] = value;
	                }
	                else {
	                    errors.push(ts.createCompilerDiagnostic(ts.Diagnostics.Compiler_option_0_requires_a_value_of_type_1, id, expectedType));
	                }
	            }
	            else {
	                errors.push(ts.createCompilerDiagnostic(ts.Diagnostics.Unknown_compiler_option_0, id));
	            }
	        }
	        return { options: options, errors: errors };
	    }
	    ts.convertCompilerOptionsFromJson = convertCompilerOptionsFromJson;
	})(ts || (ts = {}));
	/* @internal */
	var ts;
	(function (ts) {
	    var OutliningElementsCollector;
	    (function (OutliningElementsCollector) {
	        function collectElements(sourceFile) {
	            var elements = [];
	            var collapseText = "...";
	            function addOutliningSpan(hintSpanNode, startElement, endElement, autoCollapse) {
	                if (hintSpanNode && startElement && endElement) {
	                    var span = {
	                        textSpan: ts.createTextSpanFromBounds(startElement.pos, endElement.end),
	                        hintSpan: ts.createTextSpanFromBounds(hintSpanNode.getStart(), hintSpanNode.end),
	                        bannerText: collapseText,
	                        autoCollapse: autoCollapse
	                    };
	                    elements.push(span);
	                }
	            }
	            function addOutliningSpanComments(commentSpan, autoCollapse) {
	                if (commentSpan) {
	                    var span = {
	                        textSpan: ts.createTextSpanFromBounds(commentSpan.pos, commentSpan.end),
	                        hintSpan: ts.createTextSpanFromBounds(commentSpan.pos, commentSpan.end),
	                        bannerText: collapseText,
	                        autoCollapse: autoCollapse
	                    };
	                    elements.push(span);
	                }
	            }
	            function addOutliningForLeadingCommentsForNode(n) {
	                var comments = ts.getLeadingCommentRangesOfNode(n, sourceFile);
	                if (comments) {
	                    var firstSingleLineCommentStart = -1;
	                    var lastSingleLineCommentEnd = -1;
	                    var isFirstSingleLineComment = true;
	                    var singleLineCommentCount = 0;
	                    for (var _i = 0, comments_2 = comments; _i < comments_2.length; _i++) {
	                        var currentComment = comments_2[_i];
	                        // For single line comments, combine consecutive ones (2 or more) into
	                        // a single span from the start of the first till the end of the last
	                        if (currentComment.kind === 2 /* SingleLineCommentTrivia */) {
	                            if (isFirstSingleLineComment) {
	                                firstSingleLineCommentStart = currentComment.pos;
	                            }
	                            isFirstSingleLineComment = false;
	                            lastSingleLineCommentEnd = currentComment.end;
	                            singleLineCommentCount++;
	                        }
	                        else if (currentComment.kind === 3 /* MultiLineCommentTrivia */) {
	                            combineAndAddMultipleSingleLineComments(singleLineCommentCount, firstSingleLineCommentStart, lastSingleLineCommentEnd);
	                            addOutliningSpanComments(currentComment, /*autoCollapse*/ false);
	                            singleLineCommentCount = 0;
	                            lastSingleLineCommentEnd = -1;
	                            isFirstSingleLineComment = true;
	                        }
	                    }
	                    combineAndAddMultipleSingleLineComments(singleLineCommentCount, firstSingleLineCommentStart, lastSingleLineCommentEnd);
	                }
	            }
	            function combineAndAddMultipleSingleLineComments(count, start, end) {
	                // Only outline spans of two or more consecutive single line comments
	                if (count > 1) {
	                    var multipleSingleLineComments = {
	                        pos: start,
	                        end: end,
	                        kind: 2 /* SingleLineCommentTrivia */
	                    };
	                    addOutliningSpanComments(multipleSingleLineComments, /*autoCollapse*/ false);
	                }
	            }
	            function autoCollapse(node) {
	                return ts.isFunctionBlock(node) && node.parent.kind !== 177 /* ArrowFunction */;
	            }
	            var depth = 0;
	            var maxDepth = 20;
	            function walk(n) {
	                if (depth > maxDepth) {
	                    return;
	                }
	                if (ts.isDeclaration(n)) {
	                    addOutliningForLeadingCommentsForNode(n);
	                }
	                switch (n.kind) {
	                    case 195 /* Block */:
	                        if (!ts.isFunctionBlock(n)) {
	                            var parent_9 = n.parent;
	                            var openBrace = ts.findChildOfKind(n, 15 /* OpenBraceToken */, sourceFile);
	                            var closeBrace = ts.findChildOfKind(n, 16 /* CloseBraceToken */, sourceFile);
	                            // Check if the block is standalone, or 'attached' to some parent statement.
	                            // If the latter, we want to collaps the block, but consider its hint span
	                            // to be the entire span of the parent.
	                            if (parent_9.kind === 200 /* DoStatement */ ||
	                                parent_9.kind === 203 /* ForInStatement */ ||
	                                parent_9.kind === 204 /* ForOfStatement */ ||
	                                parent_9.kind === 202 /* ForStatement */ ||
	                                parent_9.kind === 199 /* IfStatement */ ||
	                                parent_9.kind === 201 /* WhileStatement */ ||
	                                parent_9.kind === 208 /* WithStatement */ ||
	                                parent_9.kind === 247 /* CatchClause */) {
	                                addOutliningSpan(parent_9, openBrace, closeBrace, autoCollapse(n));
	                                break;
	                            }
	                            if (parent_9.kind === 212 /* TryStatement */) {
	                                // Could be the try-block, or the finally-block.
	                                var tryStatement = parent_9;
	                                if (tryStatement.tryBlock === n) {
	                                    addOutliningSpan(parent_9, openBrace, closeBrace, autoCollapse(n));
	                                    break;
	                                }
	                                else if (tryStatement.finallyBlock === n) {
	                                    var finallyKeyword = ts.findChildOfKind(tryStatement, 85 /* FinallyKeyword */, sourceFile);
	                                    if (finallyKeyword) {
	                                        addOutliningSpan(finallyKeyword, openBrace, closeBrace, autoCollapse(n));
	                                        break;
	                                    }
	                                }
	                            }
	                            // Block was a standalone block.  In this case we want to only collapse
	                            // the span of the block, independent of any parent span.
	                            var span = ts.createTextSpanFromBounds(n.getStart(), n.end);
	                            elements.push({
	                                textSpan: span,
	                                hintSpan: span,
	                                bannerText: collapseText,
	                                autoCollapse: autoCollapse(n)
	                            });
	                            break;
	                        }
	                    // Fallthrough.
	                    case 222 /* ModuleBlock */: {
	                        var openBrace = ts.findChildOfKind(n, 15 /* OpenBraceToken */, sourceFile);
	                        var closeBrace = ts.findChildOfKind(n, 16 /* CloseBraceToken */, sourceFile);
	                        addOutliningSpan(n.parent, openBrace, closeBrace, autoCollapse(n));
	                        break;
	                    }
	                    case 217 /* ClassDeclaration */:
	                    case 218 /* InterfaceDeclaration */:
	                    case 220 /* EnumDeclaration */:
	                    case 168 /* ObjectLiteralExpression */:
	                    case 223 /* CaseBlock */: {
	                        var openBrace = ts.findChildOfKind(n, 15 /* OpenBraceToken */, sourceFile);
	                        var closeBrace = ts.findChildOfKind(n, 16 /* CloseBraceToken */, sourceFile);
	                        addOutliningSpan(n, openBrace, closeBrace, autoCollapse(n));
	                        break;
	                    }
	                    case 167 /* ArrayLiteralExpression */:
	                        var openBracket = ts.findChildOfKind(n, 19 /* OpenBracketToken */, sourceFile);
	                        var closeBracket = ts.findChildOfKind(n, 20 /* CloseBracketToken */, sourceFile);
	                        addOutliningSpan(n, openBracket, closeBracket, autoCollapse(n));
	                        break;
	                }
	                depth++;
	                ts.forEachChild(n, walk);
	                depth--;
	            }
	            walk(sourceFile);
	            return elements;
	        }
	        OutliningElementsCollector.collectElements = collectElements;
	    })(OutliningElementsCollector = ts.OutliningElementsCollector || (ts.OutliningElementsCollector = {}));
	})(ts || (ts = {}));
	/* @internal */
	var ts;
	(function (ts) {
	    var NavigateTo;
	    (function (NavigateTo) {
	        function getNavigateToItems(program, cancellationToken, searchValue, maxResultCount) {
	            var patternMatcher = ts.createPatternMatcher(searchValue);
	            var rawItems = [];
	            // This means "compare in a case insensitive manner."
	            var baseSensitivity = { sensitivity: "base" };
	            // Search the declarations in all files and output matched NavigateToItem into array of NavigateToItem[] 
	            ts.forEach(program.getSourceFiles(), function (sourceFile) {
	                cancellationToken.throwIfCancellationRequested();
	                var nameToDeclarations = sourceFile.getNamedDeclarations();
	                for (var name_32 in nameToDeclarations) {
	                    var declarations = ts.getProperty(nameToDeclarations, name_32);
	                    if (declarations) {
	                        // First do a quick check to see if the name of the declaration matches the 
	                        // last portion of the (possibly) dotted name they're searching for.
	                        var matches = patternMatcher.getMatchesForLastSegmentOfPattern(name_32);
	                        if (!matches) {
	                            continue;
	                        }
	                        for (var _i = 0, declarations_6 = declarations; _i < declarations_6.length; _i++) {
	                            var declaration = declarations_6[_i];
	                            // It was a match!  If the pattern has dots in it, then also see if the 
	                            // declaration container matches as well.
	                            if (patternMatcher.patternContainsDots) {
	                                var containers = getContainers(declaration);
	                                if (!containers) {
	                                    return undefined;
	                                }
	                                matches = patternMatcher.getMatches(containers, name_32);
	                                if (!matches) {
	                                    continue;
	                                }
	                            }
	                            var fileName = sourceFile.fileName;
	                            var matchKind = bestMatchKind(matches);
	                            rawItems.push({ name: name_32, fileName: fileName, matchKind: matchKind, isCaseSensitive: allMatchesAreCaseSensitive(matches), declaration: declaration });
	                        }
	                    }
	                }
	            });
	            rawItems.sort(compareNavigateToItems);
	            if (maxResultCount !== undefined) {
	                rawItems = rawItems.slice(0, maxResultCount);
	            }
	            var items = ts.map(rawItems, createNavigateToItem);
	            return items;
	            function allMatchesAreCaseSensitive(matches) {
	                ts.Debug.assert(matches.length > 0);
	                // This is a case sensitive match, only if all the submatches were case sensitive.
	                for (var _i = 0, matches_1 = matches; _i < matches_1.length; _i++) {
	                    var match = matches_1[_i];
	                    if (!match.isCaseSensitive) {
	                        return false;
	                    }
	                }
	                return true;
	            }
	            function getTextOfIdentifierOrLiteral(node) {
	                if (node) {
	                    if (node.kind === 69 /* Identifier */ ||
	                        node.kind === 9 /* StringLiteral */ ||
	                        node.kind === 8 /* NumericLiteral */) {
	                        return node.text;
	                    }
	                }
	                return undefined;
	            }
	            function tryAddSingleDeclarationName(declaration, containers) {
	                if (declaration && declaration.name) {
	                    var text = getTextOfIdentifierOrLiteral(declaration.name);
	                    if (text !== undefined) {
	                        containers.unshift(text);
	                    }
	                    else if (declaration.name.kind === 137 /* ComputedPropertyName */) {
	                        return tryAddComputedPropertyName(declaration.name.expression, containers, /*includeLastPortion*/ true);
	                    }
	                    else {
	                        // Don't know how to add this.
	                        return false;
	                    }
	                }
	                return true;
	            }
	            // Only added the names of computed properties if they're simple dotted expressions, like:
	            //
	            //      [X.Y.Z]() { }
	            function tryAddComputedPropertyName(expression, containers, includeLastPortion) {
	                var text = getTextOfIdentifierOrLiteral(expression);
	                if (text !== undefined) {
	                    if (includeLastPortion) {
	                        containers.unshift(text);
	                    }
	                    return true;
	                }
	                if (expression.kind === 169 /* PropertyAccessExpression */) {
	                    var propertyAccess = expression;
	                    if (includeLastPortion) {
	                        containers.unshift(propertyAccess.name.text);
	                    }
	                    return tryAddComputedPropertyName(propertyAccess.expression, containers, /*includeLastPortion*/ true);
	                }
	                return false;
	            }
	            function getContainers(declaration) {
	                var containers = [];
	                // First, if we started with a computed property name, then add all but the last
	                // portion into the container array.
	                if (declaration.name.kind === 137 /* ComputedPropertyName */) {
	                    if (!tryAddComputedPropertyName(declaration.name.expression, containers, /*includeLastPortion*/ false)) {
	                        return undefined;
	                    }
	                }
	                // Now, walk up our containers, adding all their names to the container array.
	                declaration = ts.getContainerNode(declaration);
	                while (declaration) {
	                    if (!tryAddSingleDeclarationName(declaration, containers)) {
	                        return undefined;
	                    }
	                    declaration = ts.getContainerNode(declaration);
	                }
	                return containers;
	            }
	            function bestMatchKind(matches) {
	                ts.Debug.assert(matches.length > 0);
	                var bestMatchKind = ts.PatternMatchKind.camelCase;
	                for (var _i = 0, matches_2 = matches; _i < matches_2.length; _i++) {
	                    var match = matches_2[_i];
	                    var kind = match.kind;
	                    if (kind < bestMatchKind) {
	                        bestMatchKind = kind;
	                    }
	                }
	                return bestMatchKind;
	            }
	            function compareNavigateToItems(i1, i2) {
	                // TODO(cyrusn): get the gamut of comparisons that VS already uses here.
	                // Right now we just sort by kind first, and then by name of the item.
	                // We first sort case insensitively.  So "Aaa" will come before "bar".
	                // Then we sort case sensitively, so "aaa" will come before "Aaa".
	                return i1.matchKind - i2.matchKind ||
	                    i1.name.localeCompare(i2.name, undefined, baseSensitivity) ||
	                    i1.name.localeCompare(i2.name);
	            }
	            function createNavigateToItem(rawItem) {
	                var declaration = rawItem.declaration;
	                var container = ts.getContainerNode(declaration);
	                return {
	                    name: rawItem.name,
	                    kind: ts.getNodeKind(declaration),
	                    kindModifiers: ts.getNodeModifiers(declaration),
	                    matchKind: ts.PatternMatchKind[rawItem.matchKind],
	                    isCaseSensitive: rawItem.isCaseSensitive,
	                    fileName: rawItem.fileName,
	                    textSpan: ts.createTextSpanFromBounds(declaration.getStart(), declaration.getEnd()),
	                    // TODO(jfreeman): What should be the containerName when the container has a computed name?
	                    containerName: container && container.name ? container.name.text : "",
	                    containerKind: container && container.name ? ts.getNodeKind(container) : ""
	                };
	            }
	        }
	        NavigateTo.getNavigateToItems = getNavigateToItems;
	    })(NavigateTo = ts.NavigateTo || (ts.NavigateTo = {}));
	})(ts || (ts = {}));
	/// <reference path='services.ts' />
	/* @internal */
	var ts;
	(function (ts) {
	    var NavigationBar;
	    (function (NavigationBar) {
	        function getNavigationBarItems(sourceFile, compilerOptions) {
	            // If the source file has any child items, then it included in the tree
	            // and takes lexical ownership of all other top-level items.
	            var hasGlobalNode = false;
	            return getItemsWorker(getTopLevelNodes(sourceFile), createTopLevelItem);
	            function getIndent(node) {
	                // If we have a global node in the tree,
	                // then it adds an extra layer of depth to all subnodes.
	                var indent = hasGlobalNode ? 1 : 0;
	                var current = node.parent;
	                while (current) {
	                    switch (current.kind) {
	                        case 221 /* ModuleDeclaration */:
	                            // If we have a module declared as A.B.C, it is more "intuitive"
	                            // to say it only has a single layer of depth
	                            do {
	                                current = current.parent;
	                            } while (current.kind === 221 /* ModuleDeclaration */);
	                        // fall through
	                        case 217 /* ClassDeclaration */:
	                        case 220 /* EnumDeclaration */:
	                        case 218 /* InterfaceDeclaration */:
	                        case 216 /* FunctionDeclaration */:
	                            indent++;
	                    }
	                    current = current.parent;
	                }
	                return indent;
	            }
	            function getChildNodes(nodes) {
	                var childNodes = [];
	                function visit(node) {
	                    switch (node.kind) {
	                        case 196 /* VariableStatement */:
	                            ts.forEach(node.declarationList.declarations, visit);
	                            break;
	                        case 164 /* ObjectBindingPattern */:
	                        case 165 /* ArrayBindingPattern */:
	                            ts.forEach(node.elements, visit);
	                            break;
	                        case 231 /* ExportDeclaration */:
	                            // Handle named exports case e.g.:
	                            //    export {a, b as B} from "mod";
	                            if (node.exportClause) {
	                                ts.forEach(node.exportClause.elements, visit);
	                            }
	                            break;
	                        case 225 /* ImportDeclaration */:
	                            var importClause = node.importClause;
	                            if (importClause) {
	                                // Handle default import case e.g.:
	                                //    import d from "mod";
	                                if (importClause.name) {
	                                    childNodes.push(importClause);
	                                }
	                                // Handle named bindings in imports e.g.:
	                                //    import * as NS from "mod";
	                                //    import {a, b as B} from "mod";
	                                if (importClause.namedBindings) {
	                                    if (importClause.namedBindings.kind === 227 /* NamespaceImport */) {
	                                        childNodes.push(importClause.namedBindings);
	                                    }
	                                    else {
	                                        ts.forEach(importClause.namedBindings.elements, visit);
	                                    }
	                                }
	                            }
	                            break;
	                        case 166 /* BindingElement */:
	                        case 214 /* VariableDeclaration */:
	                            if (ts.isBindingPattern(node.name)) {
	                                visit(node.name);
	                                break;
	                            }
	                        // Fall through
	                        case 217 /* ClassDeclaration */:
	                        case 220 /* EnumDeclaration */:
	                        case 218 /* InterfaceDeclaration */:
	                        case 221 /* ModuleDeclaration */:
	                        case 216 /* FunctionDeclaration */:
	                        case 224 /* ImportEqualsDeclaration */:
	                        case 229 /* ImportSpecifier */:
	                        case 233 /* ExportSpecifier */:
	                            childNodes.push(node);
	                            break;
	                    }
	                }
	                //for (let i = 0, n = nodes.length; i < n; i++) {
	                //    let node = nodes[i];
	                //    if (node.kind === SyntaxKind.ClassDeclaration ||
	                //        node.kind === SyntaxKind.EnumDeclaration ||
	                //        node.kind === SyntaxKind.InterfaceDeclaration ||
	                //        node.kind === SyntaxKind.ModuleDeclaration ||
	                //        node.kind === SyntaxKind.FunctionDeclaration) {
	                //        childNodes.push(node);
	                //    }
	                //    else if (node.kind === SyntaxKind.VariableStatement) {
	                //        childNodes.push.apply(childNodes, (<VariableStatement>node).declarations);
	                //    }
	                //}
	                ts.forEach(nodes, visit);
	                return sortNodes(childNodes);
	            }
	            function getTopLevelNodes(node) {
	                var topLevelNodes = [];
	                topLevelNodes.push(node);
	                addTopLevelNodes(node.statements, topLevelNodes);
	                return topLevelNodes;
	            }
	            function sortNodes(nodes) {
	                return nodes.slice(0).sort(function (n1, n2) {
	                    if (n1.name && n2.name) {
	                        return ts.getPropertyNameForPropertyNameNode(n1.name).localeCompare(ts.getPropertyNameForPropertyNameNode(n2.name));
	                    }
	                    else if (n1.name) {
	                        return 1;
	                    }
	                    else if (n2.name) {
	                        return -1;
	                    }
	                    else {
	                        return n1.kind - n2.kind;
	                    }
	                });
	            }
	            function addTopLevelNodes(nodes, topLevelNodes) {
	                nodes = sortNodes(nodes);
	                for (var _i = 0, nodes_4 = nodes; _i < nodes_4.length; _i++) {
	                    var node = nodes_4[_i];
	                    switch (node.kind) {
	                        case 217 /* ClassDeclaration */:
	                        case 220 /* EnumDeclaration */:
	                        case 218 /* InterfaceDeclaration */:
	                            topLevelNodes.push(node);
	                            break;
	                        case 221 /* ModuleDeclaration */:
	                            var moduleDeclaration = node;
	                            topLevelNodes.push(node);
	                            addTopLevelNodes(getInnermostModule(moduleDeclaration).body.statements, topLevelNodes);
	                            break;
	                        case 216 /* FunctionDeclaration */:
	                            var functionDeclaration = node;
	                            if (isTopLevelFunctionDeclaration(functionDeclaration)) {
	                                topLevelNodes.push(node);
	                                addTopLevelNodes(functionDeclaration.body.statements, topLevelNodes);
	                            }
	                            break;
	                    }
	                }
	            }
	            function isTopLevelFunctionDeclaration(functionDeclaration) {
	                if (functionDeclaration.kind === 216 /* FunctionDeclaration */) {
	                    // A function declaration is 'top level' if it contains any function declarations 
	                    // within it. 
	                    if (functionDeclaration.body && functionDeclaration.body.kind === 195 /* Block */) {
	                        // Proper function declarations can only have identifier names
	                        if (ts.forEach(functionDeclaration.body.statements, function (s) { return s.kind === 216 /* FunctionDeclaration */ && !isEmpty(s.name.text); })) {
	                            return true;
	                        }
	                        // Or if it is not parented by another function.  i.e all functions
	                        // at module scope are 'top level'.
	                        if (!ts.isFunctionBlock(functionDeclaration.parent)) {
	                            return true;
	                        }
	                    }
	                }
	                return false;
	            }
	            function getItemsWorker(nodes, createItem) {
	                var items = [];
	                var keyToItem = {};
	                for (var _i = 0, nodes_5 = nodes; _i < nodes_5.length; _i++) {
	                    var child = nodes_5[_i];
	                    var item = createItem(child);
	                    if (item !== undefined) {
	                        if (item.text.length > 0) {
	                            var key = item.text + "-" + item.kind + "-" + item.indent;
	                            var itemWithSameName = keyToItem[key];
	                            if (itemWithSameName) {
	                                // We had an item with the same name.  Merge these items together.
	                                merge(itemWithSameName, item);
	                            }
	                            else {
	                                keyToItem[key] = item;
	                                items.push(item);
	                            }
	                        }
	                    }
	                }
	                return items;
	            }
	            function merge(target, source) {
	                // First, add any spans in the source to the target.
	                ts.addRange(target.spans, source.spans);
	                if (source.childItems) {
	                    if (!target.childItems) {
	                        target.childItems = [];
	                    }
	                    // Next, recursively merge or add any children in the source as appropriate.
	                    outer: for (var _i = 0, _a = source.childItems; _i < _a.length; _i++) {
	                        var sourceChild = _a[_i];
	                        for (var _b = 0, _c = target.childItems; _b < _c.length; _b++) {
	                            var targetChild = _c[_b];
	                            if (targetChild.text === sourceChild.text && targetChild.kind === sourceChild.kind) {
	                                // Found a match.  merge them.
	                                merge(targetChild, sourceChild);
	                                continue outer;
	                            }
	                        }
	                        // Didn't find a match, just add this child to the list.
	                        target.childItems.push(sourceChild);
	                    }
	                }
	            }
	            function createChildItem(node) {
	                switch (node.kind) {
	                    case 139 /* Parameter */:
	                        if (ts.isBindingPattern(node.name)) {
	                            break;
	                        }
	                        if ((node.flags & 1022 /* Modifier */) === 0) {
	                            return undefined;
	                        }
	                        return createItem(node, getTextOfNode(node.name), ts.ScriptElementKind.memberVariableElement);
	                    case 144 /* MethodDeclaration */:
	                    case 143 /* MethodSignature */:
	                        return createItem(node, getTextOfNode(node.name), ts.ScriptElementKind.memberFunctionElement);
	                    case 146 /* GetAccessor */:
	                        return createItem(node, getTextOfNode(node.name), ts.ScriptElementKind.memberGetAccessorElement);
	                    case 147 /* SetAccessor */:
	                        return createItem(node, getTextOfNode(node.name), ts.ScriptElementKind.memberSetAccessorElement);
	                    case 150 /* IndexSignature */:
	                        return createItem(node, "[]", ts.ScriptElementKind.indexSignatureElement);
	                    case 250 /* EnumMember */:
	                        return createItem(node, getTextOfNode(node.name), ts.ScriptElementKind.memberVariableElement);
	                    case 148 /* CallSignature */:
	                        return createItem(node, "()", ts.ScriptElementKind.callSignatureElement);
	                    case 149 /* ConstructSignature */:
	                        return createItem(node, "new()", ts.ScriptElementKind.constructSignatureElement);
	                    case 142 /* PropertyDeclaration */:
	                    case 141 /* PropertySignature */:
	                        return createItem(node, getTextOfNode(node.name), ts.ScriptElementKind.memberVariableElement);
	                    case 216 /* FunctionDeclaration */:
	                        return createItem(node, getTextOfNode(node.name), ts.ScriptElementKind.functionElement);
	                    case 214 /* VariableDeclaration */:
	                    case 166 /* BindingElement */:
	                        var variableDeclarationNode = void 0;
	                        var name_33;
	                        if (node.kind === 166 /* BindingElement */) {
	                            name_33 = node.name;
	                            variableDeclarationNode = node;
	                            // binding elements are added only for variable declarations
	                            // bubble up to the containing variable declaration
	                            while (variableDeclarationNode && variableDeclarationNode.kind !== 214 /* VariableDeclaration */) {
	                                variableDeclarationNode = variableDeclarationNode.parent;
	                            }
	                            ts.Debug.assert(variableDeclarationNode !== undefined);
	                        }
	                        else {
	                            ts.Debug.assert(!ts.isBindingPattern(node.name));
	                            variableDeclarationNode = node;
	                            name_33 = node.name;
	                        }
	                        if (ts.isConst(variableDeclarationNode)) {
	                            return createItem(node, getTextOfNode(name_33), ts.ScriptElementKind.constElement);
	                        }
	                        else if (ts.isLet(variableDeclarationNode)) {
	                            return createItem(node, getTextOfNode(name_33), ts.ScriptElementKind.letElement);
	                        }
	                        else {
	                            return createItem(node, getTextOfNode(name_33), ts.ScriptElementKind.variableElement);
	                        }
	                    case 145 /* Constructor */:
	                        return createItem(node, "constructor", ts.ScriptElementKind.constructorImplementationElement);
	                    case 233 /* ExportSpecifier */:
	                    case 229 /* ImportSpecifier */:
	                    case 224 /* ImportEqualsDeclaration */:
	                    case 226 /* ImportClause */:
	                    case 227 /* NamespaceImport */:
	                        return createItem(node, getTextOfNode(node.name), ts.ScriptElementKind.alias);
	                }
	                return undefined;
	                function createItem(node, name, scriptElementKind) {
	                    return getNavigationBarItem(name, scriptElementKind, ts.getNodeModifiers(node), [getNodeSpan(node)]);
	                }
	            }
	            function isEmpty(text) {
	                return !text || text.trim() === "";
	            }
	            function getNavigationBarItem(text, kind, kindModifiers, spans, childItems, indent) {
	                if (childItems === void 0) { childItems = []; }
	                if (indent === void 0) { indent = 0; }
	                if (isEmpty(text)) {
	                    return undefined;
	                }
	                return {
	                    text: text,
	                    kind: kind,
	                    kindModifiers: kindModifiers,
	                    spans: spans,
	                    childItems: childItems,
	                    indent: indent,
	                    bolded: false,
	                    grayed: false
	                };
	            }
	            function createTopLevelItem(node) {
	                switch (node.kind) {
	                    case 251 /* SourceFile */:
	                        return createSourceFileItem(node);
	                    case 217 /* ClassDeclaration */:
	                        return createClassItem(node);
	                    case 220 /* EnumDeclaration */:
	                        return createEnumItem(node);
	                    case 218 /* InterfaceDeclaration */:
	                        return createIterfaceItem(node);
	                    case 221 /* ModuleDeclaration */:
	                        return createModuleItem(node);
	                    case 216 /* FunctionDeclaration */:
	                        return createFunctionItem(node);
	                }
	                return undefined;
	                function getModuleName(moduleDeclaration) {
	                    // We want to maintain quotation marks.
	                    if (ts.isAmbientModule(moduleDeclaration)) {
	                        return getTextOfNode(moduleDeclaration.name);
	                    }
	                    // Otherwise, we need to aggregate each identifier to build up the qualified name.
	                    var result = [];
	                    result.push(moduleDeclaration.name.text);
	                    while (moduleDeclaration.body && moduleDeclaration.body.kind === 221 /* ModuleDeclaration */) {
	                        moduleDeclaration = moduleDeclaration.body;
	                        result.push(moduleDeclaration.name.text);
	                    }
	                    return result.join(".");
	                }
	                function createModuleItem(node) {
	                    var moduleName = getModuleName(node);
	                    var childItems = getItemsWorker(getChildNodes(getInnermostModule(node).body.statements), createChildItem);
	                    return getNavigationBarItem(moduleName, ts.ScriptElementKind.moduleElement, ts.getNodeModifiers(node), [getNodeSpan(node)], childItems, getIndent(node));
	                }
	                function createFunctionItem(node) {
	                    if (node.body && node.body.kind === 195 /* Block */) {
	                        var childItems = getItemsWorker(sortNodes(node.body.statements), createChildItem);
	                        return getNavigationBarItem(!node.name ? "default" : node.name.text, ts.ScriptElementKind.functionElement, ts.getNodeModifiers(node), [getNodeSpan(node)], childItems, getIndent(node));
	                    }
	                    return undefined;
	                }
	                function createSourceFileItem(node) {
	                    var childItems = getItemsWorker(getChildNodes(node.statements), createChildItem);
	                    if (childItems === undefined || childItems.length === 0) {
	                        return undefined;
	                    }
	                    hasGlobalNode = true;
	                    var rootName = ts.isExternalModule(node)
	                        ? "\"" + ts.escapeString(ts.getBaseFileName(ts.removeFileExtension(ts.normalizePath(node.fileName)))) + "\""
	                        : "<global>";
	                    return getNavigationBarItem(rootName, ts.ScriptElementKind.moduleElement, ts.ScriptElementKindModifier.none, [getNodeSpan(node)], childItems);
	                }
	                function createClassItem(node) {
	                    var childItems;
	                    if (node.members) {
	                        var constructor = ts.forEach(node.members, function (member) {
	                            return member.kind === 145 /* Constructor */ && member;
	                        });
	                        // Add the constructor parameters in as children of the class (for property parameters).
	                        // Note that *all non-binding pattern named* parameters will be added to the nodes array, but parameters that
	                        // are not properties will be filtered out later by createChildItem.
	                        var nodes = removeDynamicallyNamedProperties(node);
	                        if (constructor) {
	                            ts.addRange(nodes, ts.filter(constructor.parameters, function (p) { return !ts.isBindingPattern(p.name); }));
	                        }
	                        childItems = getItemsWorker(sortNodes(nodes), createChildItem);
	                    }
	                    var nodeName = !node.name ? "default" : node.name.text;
	                    return getNavigationBarItem(nodeName, ts.ScriptElementKind.classElement, ts.getNodeModifiers(node), [getNodeSpan(node)], childItems, getIndent(node));
	                }
	                function createEnumItem(node) {
	                    var childItems = getItemsWorker(sortNodes(removeComputedProperties(node)), createChildItem);
	                    return getNavigationBarItem(node.name.text, ts.ScriptElementKind.enumElement, ts.getNodeModifiers(node), [getNodeSpan(node)], childItems, getIndent(node));
	                }
	                function createIterfaceItem(node) {
	                    var childItems = getItemsWorker(sortNodes(removeDynamicallyNamedProperties(node)), createChildItem);
	                    return getNavigationBarItem(node.name.text, ts.ScriptElementKind.interfaceElement, ts.getNodeModifiers(node), [getNodeSpan(node)], childItems, getIndent(node));
	                }
	            }
	            function removeComputedProperties(node) {
	                return ts.filter(node.members, function (member) { return member.name === undefined || member.name.kind !== 137 /* ComputedPropertyName */; });
	            }
	            /**
	             * Like removeComputedProperties, but retains the properties with well known symbol names
	             */
	            function removeDynamicallyNamedProperties(node) {
	                return ts.filter(node.members, function (member) { return !ts.hasDynamicName(member); });
	            }
	            function getInnermostModule(node) {
	                while (node.body.kind === 221 /* ModuleDeclaration */) {
	                    node = node.body;
	                }
	                return node;
	            }
	            function getNodeSpan(node) {
	                return node.kind === 251 /* SourceFile */
	                    ? ts.createTextSpanFromBounds(node.getFullStart(), node.getEnd())
	                    : ts.createTextSpanFromBounds(node.getStart(), node.getEnd());
	            }
	            function getTextOfNode(node) {
	                return ts.getTextOfNodeFromSourceText(sourceFile.text, node);
	            }
	        }
	        NavigationBar.getNavigationBarItems = getNavigationBarItems;
	    })(NavigationBar = ts.NavigationBar || (ts.NavigationBar = {}));
	})(ts || (ts = {}));
	/* @internal */
	var ts;
	(function (ts) {
	    // Note(cyrusn): this enum is ordered from strongest match type to weakest match type.
	    (function (PatternMatchKind) {
	        PatternMatchKind[PatternMatchKind["exact"] = 0] = "exact";
	        PatternMatchKind[PatternMatchKind["prefix"] = 1] = "prefix";
	        PatternMatchKind[PatternMatchKind["substring"] = 2] = "substring";
	        PatternMatchKind[PatternMatchKind["camelCase"] = 3] = "camelCase";
	    })(ts.PatternMatchKind || (ts.PatternMatchKind = {}));
	    var PatternMatchKind = ts.PatternMatchKind;
	    function createPatternMatch(kind, punctuationStripped, isCaseSensitive, camelCaseWeight) {
	        return {
	            kind: kind,
	            punctuationStripped: punctuationStripped,
	            isCaseSensitive: isCaseSensitive,
	            camelCaseWeight: camelCaseWeight
	        };
	    }
	    function createPatternMatcher(pattern) {
	        // We'll often see the same candidate string many times when searching (For example, when
	        // we see the name of a module that is used everywhere, or the name of an overload).  As
	        // such, we cache the information we compute about the candidate for the life of this
	        // pattern matcher so we don't have to compute it multiple times.
	        var stringToWordSpans = {};
	        pattern = pattern.trim();
	        var dotSeparatedSegments = pattern.split(".").map(function (p) { return createSegment(p.trim()); });
	        var invalidPattern = dotSeparatedSegments.length === 0 || ts.forEach(dotSeparatedSegments, segmentIsInvalid);
	        return {
	            getMatches: getMatches,
	            getMatchesForLastSegmentOfPattern: getMatchesForLastSegmentOfPattern,
	            patternContainsDots: dotSeparatedSegments.length > 1
	        };
	        // Quick checks so we can bail out when asked to match a candidate.
	        function skipMatch(candidate) {
	            return invalidPattern || !candidate;
	        }
	        function getMatchesForLastSegmentOfPattern(candidate) {
	            if (skipMatch(candidate)) {
	                return undefined;
	            }
	            return matchSegment(candidate, ts.lastOrUndefined(dotSeparatedSegments));
	        }
	        function getMatches(candidateContainers, candidate) {
	            if (skipMatch(candidate)) {
	                return undefined;
	            }
	            // First, check that the last part of the dot separated pattern matches the name of the
	            // candidate.  If not, then there's no point in proceeding and doing the more
	            // expensive work.
	            var candidateMatch = matchSegment(candidate, ts.lastOrUndefined(dotSeparatedSegments));
	            if (!candidateMatch) {
	                return undefined;
	            }
	            candidateContainers = candidateContainers || [];
	            // -1 because the last part was checked against the name, and only the rest
	            // of the parts are checked against the container.
	            if (dotSeparatedSegments.length - 1 > candidateContainers.length) {
	                // There weren't enough container parts to match against the pattern parts.
	                // So this definitely doesn't match.
	                return undefined;
	            }
	            // So far so good.  Now break up the container for the candidate and check if all
	            // the dotted parts match up correctly.
	            var totalMatch = candidateMatch;
	            for (var i = dotSeparatedSegments.length - 2, j = candidateContainers.length - 1; i >= 0; i -= 1, j -= 1) {
	                var segment = dotSeparatedSegments[i];
	                var containerName = candidateContainers[j];
	                var containerMatch = matchSegment(containerName, segment);
	                if (!containerMatch) {
	                    // This container didn't match the pattern piece.  So there's no match at all.
	                    return undefined;
	                }
	                ts.addRange(totalMatch, containerMatch);
	            }
	            // Success, this symbol's full name matched against the dotted name the user was asking
	            // about.
	            return totalMatch;
	        }
	        function getWordSpans(word) {
	            if (!ts.hasProperty(stringToWordSpans, word)) {
	                stringToWordSpans[word] = breakIntoWordSpans(word);
	            }
	            return stringToWordSpans[word];
	        }
	        function matchTextChunk(candidate, chunk, punctuationStripped) {
	            var index = indexOfIgnoringCase(candidate, chunk.textLowerCase);
	            if (index === 0) {
	                if (chunk.text.length === candidate.length) {
	                    // a) Check if the part matches the candidate entirely, in an case insensitive or
	                    //    sensitive manner.  If it does, return that there was an exact match.
	                    return createPatternMatch(PatternMatchKind.exact, punctuationStripped, /*isCaseSensitive:*/ candidate === chunk.text);
	                }
	                else {
	                    // b) Check if the part is a prefix of the candidate, in a case insensitive or sensitive
	                    //    manner.  If it does, return that there was a prefix match.
	                    return createPatternMatch(PatternMatchKind.prefix, punctuationStripped, /*isCaseSensitive:*/ startsWith(candidate, chunk.text));
	                }
	            }
	            var isLowercase = chunk.isLowerCase;
	            if (isLowercase) {
	                if (index > 0) {
	                    // c) If the part is entirely lowercase, then check if it is contained anywhere in the
	                    //    candidate in a case insensitive manner.  If so, return that there was a substring
	                    //    match.
	                    //
	                    //    Note: We only have a substring match if the lowercase part is prefix match of some
	                    //    word part. That way we don't match something like 'Class' when the user types 'a'.
	                    //    But we would match 'FooAttribute' (since 'Attribute' starts with 'a').
	                    var wordSpans = getWordSpans(candidate);
	                    for (var _i = 0, wordSpans_1 = wordSpans; _i < wordSpans_1.length; _i++) {
	                        var span = wordSpans_1[_i];
	                        if (partStartsWith(candidate, span, chunk.text, /*ignoreCase:*/ true)) {
	                            return createPatternMatch(PatternMatchKind.substring, punctuationStripped, 
	                            /*isCaseSensitive:*/ partStartsWith(candidate, span, chunk.text, /*ignoreCase:*/ false));
	                        }
	                    }
	                }
	            }
	            else {
	                // d) If the part was not entirely lowercase, then check if it is contained in the
	                //    candidate in a case *sensitive* manner. If so, return that there was a substring
	                //    match.
	                if (candidate.indexOf(chunk.text) > 0) {
	                    return createPatternMatch(PatternMatchKind.substring, punctuationStripped, /*isCaseSensitive:*/ true);
	                }
	            }
	            if (!isLowercase) {
	                // e) If the part was not entirely lowercase, then attempt a camel cased match as well.
	                if (chunk.characterSpans.length > 0) {
	                    var candidateParts = getWordSpans(candidate);
	                    var camelCaseWeight = tryCamelCaseMatch(candidate, candidateParts, chunk, /*ignoreCase:*/ false);
	                    if (camelCaseWeight !== undefined) {
	                        return createPatternMatch(PatternMatchKind.camelCase, punctuationStripped, /*isCaseSensitive:*/ true, /*camelCaseWeight:*/ camelCaseWeight);
	                    }
	                    camelCaseWeight = tryCamelCaseMatch(candidate, candidateParts, chunk, /*ignoreCase:*/ true);
	                    if (camelCaseWeight !== undefined) {
	                        return createPatternMatch(PatternMatchKind.camelCase, punctuationStripped, /*isCaseSensitive:*/ false, /*camelCaseWeight:*/ camelCaseWeight);
	                    }
	                }
	            }
	            if (isLowercase) {
	                // f) Is the pattern a substring of the candidate starting on one of the candidate's word boundaries?
	                // We could check every character boundary start of the candidate for the pattern. However, that's
	                // an m * n operation in the wost case. Instead, find the first instance of the pattern
	                // substring, and see if it starts on a capital letter. It seems unlikely that the user will try to
	                // filter the list based on a substring that starts on a capital letter and also with a lowercase one.
	                // (Pattern: fogbar, Candidate: quuxfogbarFogBar).
	                if (chunk.text.length < candidate.length) {
	                    if (index > 0 && isUpperCaseLetter(candidate.charCodeAt(index))) {
	                        return createPatternMatch(PatternMatchKind.substring, punctuationStripped, /*isCaseSensitive:*/ false);
	                    }
	                }
	            }
	            return undefined;
	        }
	        function containsSpaceOrAsterisk(text) {
	            for (var i = 0; i < text.length; i++) {
	                var ch = text.charCodeAt(i);
	                if (ch === 32 /* space */ || ch === 42 /* asterisk */) {
	                    return true;
	                }
	            }
	            return false;
	        }
	        function matchSegment(candidate, segment) {
	            // First check if the segment matches as is.  This is also useful if the segment contains
	            // characters we would normally strip when splitting into parts that we also may want to
	            // match in the candidate.  For example if the segment is "@int" and the candidate is
	            // "@int", then that will show up as an exact match here.
	            //
	            // Note: if the segment contains a space or an asterisk then we must assume that it's a
	            // multi-word segment.
	            if (!containsSpaceOrAsterisk(segment.totalTextChunk.text)) {
	                var match = matchTextChunk(candidate, segment.totalTextChunk, /*punctuationStripped:*/ false);
	                if (match) {
	                    return [match];
	                }
	            }
	            // The logic for pattern matching is now as follows:
	            //
	            // 1) Break the segment passed in into words.  Breaking is rather simple and a
	            //    good way to think about it that if gives you all the individual alphanumeric words
	            //    of the pattern.
	            //
	            // 2) For each word try to match the word against the candidate value.
	            //
	            // 3) Matching is as follows:
	            //
	            //   a) Check if the word matches the candidate entirely, in an case insensitive or
	            //    sensitive manner.  If it does, return that there was an exact match.
	            //
	            //   b) Check if the word is a prefix of the candidate, in a case insensitive or
	            //      sensitive manner.  If it does, return that there was a prefix match.
	            //
	            //   c) If the word is entirely lowercase, then check if it is contained anywhere in the
	            //      candidate in a case insensitive manner.  If so, return that there was a substring
	            //      match.
	            //
	            //      Note: We only have a substring match if the lowercase part is prefix match of
	            //      some word part. That way we don't match something like 'Class' when the user
	            //      types 'a'. But we would match 'FooAttribute' (since 'Attribute' starts with
	            //      'a').
	            //
	            //   d) If the word was not entirely lowercase, then check if it is contained in the
	            //      candidate in a case *sensitive* manner. If so, return that there was a substring
	            //      match.
	            //
	            //   e) If the word was not entirely lowercase, then attempt a camel cased match as
	            //      well.
	            //
	            //   f) The word is all lower case. Is it a case insensitive substring of the candidate starting
	            //      on a part boundary of the candidate?
	            //
	            // Only if all words have some sort of match is the pattern considered matched.
	            var subWordTextChunks = segment.subWordTextChunks;
	            var matches = undefined;
	            for (var _i = 0, subWordTextChunks_1 = subWordTextChunks; _i < subWordTextChunks_1.length; _i++) {
	                var subWordTextChunk = subWordTextChunks_1[_i];
	                // Try to match the candidate with this word
	                var result = matchTextChunk(candidate, subWordTextChunk, /*punctuationStripped:*/ true);
	                if (!result) {
	                    return undefined;
	                }
	                matches = matches || [];
	                matches.push(result);
	            }
	            return matches;
	        }
	        function partStartsWith(candidate, candidateSpan, pattern, ignoreCase, patternSpan) {
	            var patternPartStart = patternSpan ? patternSpan.start : 0;
	            var patternPartLength = patternSpan ? patternSpan.length : pattern.length;
	            if (patternPartLength > candidateSpan.length) {
	                // Pattern part is longer than the candidate part. There can never be a match.
	                return false;
	            }
	            if (ignoreCase) {
	                for (var i = 0; i < patternPartLength; i++) {
	                    var ch1 = pattern.charCodeAt(patternPartStart + i);
	                    var ch2 = candidate.charCodeAt(candidateSpan.start + i);
	                    if (toLowerCase(ch1) !== toLowerCase(ch2)) {
	                        return false;
	                    }
	                }
	            }
	            else {
	                for (var i = 0; i < patternPartLength; i++) {
	                    var ch1 = pattern.charCodeAt(patternPartStart + i);
	                    var ch2 = candidate.charCodeAt(candidateSpan.start + i);
	                    if (ch1 !== ch2) {
	                        return false;
	                    }
	                }
	            }
	            return true;
	        }
	        function tryCamelCaseMatch(candidate, candidateParts, chunk, ignoreCase) {
	            var chunkCharacterSpans = chunk.characterSpans;
	            // Note: we may have more pattern parts than candidate parts.  This is because multiple
	            // pattern parts may match a candidate part.  For example "SiUI" against "SimpleUI".
	            // We'll have 3 pattern parts Si/U/I against two candidate parts Simple/UI.  However, U
	            // and I will both match in UI.
	            var currentCandidate = 0;
	            var currentChunkSpan = 0;
	            var firstMatch = undefined;
	            var contiguous = undefined;
	            while (true) {
	                // Let's consider our termination cases
	                if (currentChunkSpan === chunkCharacterSpans.length) {
	                    // We did match! We shall assign a weight to this
	                    var weight = 0;
	                    // Was this contiguous?
	                    if (contiguous) {
	                        weight += 1;
	                    }
	                    // Did we start at the beginning of the candidate?
	                    if (firstMatch === 0) {
	                        weight += 2;
	                    }
	                    return weight;
	                }
	                else if (currentCandidate === candidateParts.length) {
	                    // No match, since we still have more of the pattern to hit
	                    return undefined;
	                }
	                var candidatePart = candidateParts[currentCandidate];
	                var gotOneMatchThisCandidate = false;
	                // Consider the case of matching SiUI against SimpleUIElement. The candidate parts
	                // will be Simple/UI/Element, and the pattern parts will be Si/U/I.  We'll match 'Si'
	                // against 'Simple' first.  Then we'll match 'U' against 'UI'. However, we want to
	                // still keep matching pattern parts against that candidate part.
	                for (; currentChunkSpan < chunkCharacterSpans.length; currentChunkSpan++) {
	                    var chunkCharacterSpan = chunkCharacterSpans[currentChunkSpan];
	                    if (gotOneMatchThisCandidate) {
	                        // We've already gotten one pattern part match in this candidate.  We will
	                        // only continue trying to consumer pattern parts if the last part and this
	                        // part are both upper case.
	                        if (!isUpperCaseLetter(chunk.text.charCodeAt(chunkCharacterSpans[currentChunkSpan - 1].start)) ||
	                            !isUpperCaseLetter(chunk.text.charCodeAt(chunkCharacterSpans[currentChunkSpan].start))) {
	                            break;
	                        }
	                    }
	                    if (!partStartsWith(candidate, candidatePart, chunk.text, ignoreCase, chunkCharacterSpan)) {
	                        break;
	                    }
	                    gotOneMatchThisCandidate = true;
	                    firstMatch = firstMatch === undefined ? currentCandidate : firstMatch;
	                    // If we were contiguous, then keep that value.  If we weren't, then keep that
	                    // value.  If we don't know, then set the value to 'true' as an initial match is
	                    // obviously contiguous.
	                    contiguous = contiguous === undefined ? true : contiguous;
	                    candidatePart = ts.createTextSpan(candidatePart.start + chunkCharacterSpan.length, candidatePart.length - chunkCharacterSpan.length);
	                }
	                // Check if we matched anything at all.  If we didn't, then we need to unset the
	                // contiguous bit if we currently had it set.
	                // If we haven't set the bit yet, then that means we haven't matched anything so
	                // far, and we don't want to change that.
	                if (!gotOneMatchThisCandidate && contiguous !== undefined) {
	                    contiguous = false;
	                }
	                // Move onto the next candidate.
	                currentCandidate++;
	            }
	        }
	    }
	    ts.createPatternMatcher = createPatternMatcher;
	    function createSegment(text) {
	        return {
	            totalTextChunk: createTextChunk(text),
	            subWordTextChunks: breakPatternIntoTextChunks(text)
	        };
	    }
	    // A segment is considered invalid if we couldn't find any words in it.
	    function segmentIsInvalid(segment) {
	        return segment.subWordTextChunks.length === 0;
	    }
	    function isUpperCaseLetter(ch) {
	        // Fast check for the ascii range.
	        if (ch >= 65 /* A */ && ch <= 90 /* Z */) {
	            return true;
	        }
	        if (ch < 127 /* maxAsciiCharacter */ || !ts.isUnicodeIdentifierStart(ch, 2 /* Latest */)) {
	            return false;
	        }
	        // TODO: find a way to determine this for any unicode characters in a
	        // non-allocating manner.
	        var str = String.fromCharCode(ch);
	        return str === str.toUpperCase();
	    }
	    function isLowerCaseLetter(ch) {
	        // Fast check for the ascii range.
	        if (ch >= 97 /* a */ && ch <= 122 /* z */) {
	            return true;
	        }
	        if (ch < 127 /* maxAsciiCharacter */ || !ts.isUnicodeIdentifierStart(ch, 2 /* Latest */)) {
	            return false;
	        }
	        // TODO: find a way to determine this for any unicode characters in a
	        // non-allocating manner.
	        var str = String.fromCharCode(ch);
	        return str === str.toLowerCase();
	    }
	    function startsWith(string, search) {
	        for (var i = 0, n = search.length; i < n; i++) {
	            if (string.charCodeAt(i) !== search.charCodeAt(i)) {
	                return false;
	            }
	        }
	        return true;
	    }
	    // Assumes 'value' is already lowercase.
	    function indexOfIgnoringCase(string, value) {
	        for (var i = 0, n = string.length - value.length; i <= n; i++) {
	            if (startsWithIgnoringCase(string, value, i)) {
	                return i;
	            }
	        }
	        return -1;
	    }
	    // Assumes 'value' is already lowercase.
	    function startsWithIgnoringCase(string, value, start) {
	        for (var i = 0, n = value.length; i < n; i++) {
	            var ch1 = toLowerCase(string.charCodeAt(i + start));
	            var ch2 = value.charCodeAt(i);
	            if (ch1 !== ch2) {
	                return false;
	            }
	        }
	        return true;
	    }
	    function toLowerCase(ch) {
	        // Fast convert for the ascii range.
	        if (ch >= 65 /* A */ && ch <= 90 /* Z */) {
	            return 97 /* a */ + (ch - 65 /* A */);
	        }
	        if (ch < 127 /* maxAsciiCharacter */) {
	            return ch;
	        }
	        // TODO: find a way to compute this for any unicode characters in a
	        // non-allocating manner.
	        return String.fromCharCode(ch).toLowerCase().charCodeAt(0);
	    }
	    function isDigit(ch) {
	        // TODO(cyrusn): Find a way to support this for unicode digits.
	        return ch >= 48 /* _0 */ && ch <= 57 /* _9 */;
	    }
	    function isWordChar(ch) {
	        return isUpperCaseLetter(ch) || isLowerCaseLetter(ch) || isDigit(ch) || ch === 95 /* _ */ || ch === 36 /* $ */;
	    }
	    function breakPatternIntoTextChunks(pattern) {
	        var result = [];
	        var wordStart = 0;
	        var wordLength = 0;
	        for (var i = 0; i < pattern.length; i++) {
	            var ch = pattern.charCodeAt(i);
	            if (isWordChar(ch)) {
	                if (wordLength === 0) {
	                    wordStart = i;
	                }
	                wordLength++;
	            }
	            else {
	                if (wordLength > 0) {
	                    result.push(createTextChunk(pattern.substr(wordStart, wordLength)));
	                    wordLength = 0;
	                }
	            }
	        }
	        if (wordLength > 0) {
	            result.push(createTextChunk(pattern.substr(wordStart, wordLength)));
	        }
	        return result;
	    }
	    function createTextChunk(text) {
	        var textLowerCase = text.toLowerCase();
	        return {
	            text: text,
	            textLowerCase: textLowerCase,
	            isLowerCase: text === textLowerCase,
	            characterSpans: breakIntoCharacterSpans(text)
	        };
	    }
	    /* @internal */ function breakIntoCharacterSpans(identifier) {
	        return breakIntoSpans(identifier, /*word:*/ false);
	    }
	    ts.breakIntoCharacterSpans = breakIntoCharacterSpans;
	    /* @internal */ function breakIntoWordSpans(identifier) {
	        return breakIntoSpans(identifier, /*word:*/ true);
	    }
	    ts.breakIntoWordSpans = breakIntoWordSpans;
	    function breakIntoSpans(identifier, word) {
	        var result = [];
	        var wordStart = 0;
	        for (var i = 1, n = identifier.length; i < n; i++) {
	            var lastIsDigit = isDigit(identifier.charCodeAt(i - 1));
	            var currentIsDigit = isDigit(identifier.charCodeAt(i));
	            var hasTransitionFromLowerToUpper = transitionFromLowerToUpper(identifier, word, i);
	            var hasTransitionFromUpperToLower = transitionFromUpperToLower(identifier, word, i, wordStart);
	            if (charIsPunctuation(identifier.charCodeAt(i - 1)) ||
	                charIsPunctuation(identifier.charCodeAt(i)) ||
	                lastIsDigit !== currentIsDigit ||
	                hasTransitionFromLowerToUpper ||
	                hasTransitionFromUpperToLower) {
	                if (!isAllPunctuation(identifier, wordStart, i)) {
	                    result.push(ts.createTextSpan(wordStart, i - wordStart));
	                }
	                wordStart = i;
	            }
	        }
	        if (!isAllPunctuation(identifier, wordStart, identifier.length)) {
	            result.push(ts.createTextSpan(wordStart, identifier.length - wordStart));
	        }
	        return result;
	    }
	    function charIsPunctuation(ch) {
	        switch (ch) {
	            case 33 /* exclamation */:
	            case 34 /* doubleQuote */:
	            case 35 /* hash */:
	            case 37 /* percent */:
	            case 38 /* ampersand */:
	            case 39 /* singleQuote */:
	            case 40 /* openParen */:
	            case 41 /* closeParen */:
	            case 42 /* asterisk */:
	            case 44 /* comma */:
	            case 45 /* minus */:
	            case 46 /* dot */:
	            case 47 /* slash */:
	            case 58 /* colon */:
	            case 59 /* semicolon */:
	            case 63 /* question */:
	            case 64 /* at */:
	            case 91 /* openBracket */:
	            case 92 /* backslash */:
	            case 93 /* closeBracket */:
	            case 95 /* _ */:
	            case 123 /* openBrace */:
	            case 125 /* closeBrace */:
	                return true;
	        }
	        return false;
	    }
	    function isAllPunctuation(identifier, start, end) {
	        for (var i = start; i < end; i++) {
	            var ch = identifier.charCodeAt(i);
	            // We don't consider _ or $ as punctuation as there may be things with that name.
	            if (!charIsPunctuation(ch) || ch === 95 /* _ */ || ch === 36 /* $ */) {
	                return false;
	            }
	        }
	        return true;
	    }
	    function transitionFromUpperToLower(identifier, word, index, wordStart) {
	        if (word) {
	            // Cases this supports:
	            // 1) IDisposable -> I, Disposable
	            // 2) UIElement -> UI, Element
	            // 3) HTMLDocument -> HTML, Document
	            //
	            // etc.
	            if (index !== wordStart &&
	                index + 1 < identifier.length) {
	                var currentIsUpper = isUpperCaseLetter(identifier.charCodeAt(index));
	                var nextIsLower = isLowerCaseLetter(identifier.charCodeAt(index + 1));
	                if (currentIsUpper && nextIsLower) {
	                    // We have a transition from an upper to a lower letter here.  But we only
	                    // want to break if all the letters that preceded are uppercase.  i.e. if we
	                    // have "Foo" we don't want to break that into "F, oo".  But if we have
	                    // "IFoo" or "UIFoo", then we want to break that into "I, Foo" and "UI,
	                    // Foo".  i.e. the last uppercase letter belongs to the lowercase letters
	                    // that follows.  Note: this will make the following not split properly:
	                    // "HELLOthere".  However, these sorts of names do not show up in .Net
	                    // programs.
	                    for (var i = wordStart; i < index; i++) {
	                        if (!isUpperCaseLetter(identifier.charCodeAt(i))) {
	                            return false;
	                        }
	                    }
	                    return true;
	                }
	            }
	        }
	        return false;
	    }
	    function transitionFromLowerToUpper(identifier, word, index) {
	        var lastIsUpper = isUpperCaseLetter(identifier.charCodeAt(index - 1));
	        var currentIsUpper = isUpperCaseLetter(identifier.charCodeAt(index));
	        // See if the casing indicates we're starting a new word. Note: if we're breaking on
	        // words, then just seeing an upper case character isn't enough.  Instead, it has to
	        // be uppercase and the previous character can't be uppercase.
	        //
	        // For example, breaking "AddMetadata" on words would make: Add Metadata
	        //
	        // on characters would be: A dd M etadata
	        //
	        // Break "AM" on words would be: AM
	        //
	        // on characters would be: A M
	        //
	        // We break the search string on characters.  But we break the symbol name on words.
	        var transition = word
	            ? (currentIsUpper && !lastIsUpper)
	            : currentIsUpper;
	        return transition;
	    }
	})(ts || (ts = {}));
	///<reference path='services.ts' />
	/* @internal */
	var ts;
	(function (ts) {
	    var SignatureHelp;
	    (function (SignatureHelp) {
	        // A partially written generic type expression is not guaranteed to have the correct syntax tree. the expression could be parsed as less than/greater than expression or a comma expression
	        // or some other combination depending on what the user has typed so far. For the purposes of signature help we need to consider any location after "<" as a possible generic type reference. 
	        // To do this, the method will back parse the expression starting at the position required. it will try to parse the current expression as a generic type expression, if it did succeed it 
	        // will return the generic identifier that started the expression (e.g. "foo" in "foo<any, |"). It is then up to the caller to ensure that this is a valid generic expression through 
	        // looking up the type. The method will also keep track of the parameter index inside the expression.
	        //public static isInPartiallyWrittenTypeArgumentList(syntaxTree: TypeScript.SyntaxTree, position: number): any {
	        //    let token = Syntax.findTokenOnLeft(syntaxTree.sourceUnit(), position, /*includeSkippedTokens*/ true);
	        //    if (token && TypeScript.Syntax.hasAncestorOfKind(token, TypeScript.SyntaxKind.TypeParameterList)) {
	        //        // We are in the wrong generic list. bail out
	        //        return null;
	        //    }
	        //    let stack = 0;
	        //    let argumentIndex = 0;
	        //    whileLoop:
	        //    while (token) {
	        //        switch (token.kind()) {
	        //            case TypeScript.SyntaxKind.LessThanToken:
	        //                if (stack === 0) {
	        //                    // Found the beginning of the generic argument expression
	        //                    let lessThanToken = token;
	        //                    token = previousToken(token, /*includeSkippedTokens*/ true);
	        //                    if (!token || token.kind() !== TypeScript.SyntaxKind.IdentifierName) {
	        //                        break whileLoop;
	        //                    }
	        //                    // Found the name, return the data
	        //                    return {
	        //                        genericIdentifer: token,
	        //                        lessThanToken: lessThanToken,
	        //                        argumentIndex: argumentIndex
	        //                    };
	        //                }
	        //                else if (stack < 0) {
	        //                    // Seen one too many less than tokens, bail out
	        //                    break whileLoop;
	        //                }
	        //                else {
	        //                    stack--;
	        //                }
	        //                break;
	        //            case TypeScript.SyntaxKind.GreaterThanGreaterThanGreaterThanToken:
	        //                stack++;
	        //            // Intentaion fall through
	        //            case TypeScript.SyntaxKind.GreaterThanToken:
	        //                stack++;
	        //                break;
	        //            case TypeScript.SyntaxKind.CommaToken:
	        //                if (stack == 0) {
	        //                    argumentIndex++;
	        //                }
	        //                break;
	        //            case TypeScript.SyntaxKind.CloseBraceToken:
	        //                // This can be object type, skip untill we find the matching open brace token
	        //                let unmatchedOpenBraceTokens = 0;
	        //                // Skip untill the matching open brace token
	        //                token = SignatureInfoHelpers.moveBackUpTillMatchingTokenKind(token, TypeScript.SyntaxKind.CloseBraceToken, TypeScript.SyntaxKind.OpenBraceToken);
	        //                if (!token) {
	        //                    // No matching token was found. bail out
	        //                    break whileLoop;
	        //                }
	        //                break;
	        //            case TypeScript.SyntaxKind.EqualsGreaterThanToken:
	        //                // This can be a function type or a constructor type. In either case, we want to skip the function defintion
	        //                token = previousToken(token, /*includeSkippedTokens*/ true);
	        //                if (token && token.kind() === TypeScript.SyntaxKind.CloseParenToken) {
	        //                    // Skip untill the matching open paren token
	        //                    token = SignatureInfoHelpers.moveBackUpTillMatchingTokenKind(token, TypeScript.SyntaxKind.CloseParenToken, TypeScript.SyntaxKind.OpenParenToken);
	        //                    if (token && token.kind() === TypeScript.SyntaxKind.GreaterThanToken) {
	        //                        // Another generic type argument list, skip it\
	        //                        token = SignatureInfoHelpers.moveBackUpTillMatchingTokenKind(token, TypeScript.SyntaxKind.GreaterThanToken, TypeScript.SyntaxKind.LessThanToken);
	        //                    }
	        //                    if (token && token.kind() === TypeScript.SyntaxKind.NewKeyword) {
	        //                        // In case this was a constructor type, skip the new keyword
	        //                        token = previousToken(token, /*includeSkippedTokens*/ true);
	        //                    }
	        //                    if (!token) {
	        //                        // No matching token was found. bail out
	        //                        break whileLoop;
	        //                    }
	        //                }
	        //                else {
	        //                    // This is not a funtion type. exit the main loop
	        //                    break whileLoop;
	        //                }
	        //                break;
	        //            case TypeScript.SyntaxKind.IdentifierName:
	        //            case TypeScript.SyntaxKind.AnyKeyword:
	        //            case TypeScript.SyntaxKind.NumberKeyword:
	        //            case TypeScript.SyntaxKind.StringKeyword:
	        //            case TypeScript.SyntaxKind.VoidKeyword:
	        //            case TypeScript.SyntaxKind.BooleanKeyword:
	        //            case TypeScript.SyntaxKind.DotToken:
	        //            case TypeScript.SyntaxKind.OpenBracketToken:
	        //            case TypeScript.SyntaxKind.CloseBracketToken:
	        //                // Valid tokens in a type name. Skip.
	        //                break;
	        //            default:
	        //                break whileLoop;
	        //        }
	        //        token = previousToken(token, /*includeSkippedTokens*/ true);
	        //    }
	        //    return null;
	        //}
	        //private static moveBackUpTillMatchingTokenKind(token: TypeScript.ISyntaxToken, tokenKind: TypeScript.SyntaxKind, matchingTokenKind: TypeScript.SyntaxKind): TypeScript.ISyntaxToken {
	        //    if (!token || token.kind() !== tokenKind) {
	        //        throw TypeScript.Errors.invalidOperation();
	        //    }
	        //    // Skip the current token
	        //    token = previousToken(token, /*includeSkippedTokens*/ true);
	        //    let stack = 0;
	        //    while (token) {
	        //        if (token.kind() === matchingTokenKind) {
	        //            if (stack === 0) {
	        //                // Found the matching token, return
	        //                return token;
	        //            }
	        //            else if (stack < 0) {
	        //                // tokens overlapped.. bail out.
	        //                break;
	        //            }
	        //            else {
	        //                stack--;
	        //            }
	        //        }
	        //        else if (token.kind() === tokenKind) {
	        //            stack++;
	        //        }
	        //        // Move back
	        //        token = previousToken(token, /*includeSkippedTokens*/ true);
	        //    }
	        //    // Did not find matching token
	        //    return null;
	        //}
	        var emptyArray = [];
	        var ArgumentListKind;
	        (function (ArgumentListKind) {
	            ArgumentListKind[ArgumentListKind["TypeArguments"] = 0] = "TypeArguments";
	            ArgumentListKind[ArgumentListKind["CallArguments"] = 1] = "CallArguments";
	            ArgumentListKind[ArgumentListKind["TaggedTemplateArguments"] = 2] = "TaggedTemplateArguments";
	        })(ArgumentListKind || (ArgumentListKind = {}));
	        function getSignatureHelpItems(program, sourceFile, position, cancellationToken) {
	            var typeChecker = program.getTypeChecker();
	            // Decide whether to show signature help
	            var startingToken = ts.findTokenOnLeftOfPosition(sourceFile, position);
	            if (!startingToken) {
	                // We are at the beginning of the file
	                return undefined;
	            }
	            var argumentInfo = getContainingArgumentInfo(startingToken);
	            cancellationToken.throwIfCancellationRequested();
	            // Semantic filtering of signature help
	            if (!argumentInfo) {
	                return undefined;
	            }
	            var call = argumentInfo.invocation;
	            var candidates = [];
	            var resolvedSignature = typeChecker.getResolvedSignature(call, candidates);
	            cancellationToken.throwIfCancellationRequested();
	            if (!candidates.length) {
	                // We didn't have any sig help items produced by the TS compiler.  If this is a JS 
	                // file, then see if we can figure out anything better.
	                if (ts.isSourceFileJavaScript(sourceFile)) {
	                    return createJavaScriptSignatureHelpItems(argumentInfo);
	                }
	                return undefined;
	            }
	            return createSignatureHelpItems(candidates, resolvedSignature, argumentInfo);
	            function createJavaScriptSignatureHelpItems(argumentInfo) {
	                if (argumentInfo.invocation.kind !== 171 /* CallExpression */) {
	                    return undefined;
	                }
	                // See if we can find some symbol with the call expression name that has call signatures.
	                var callExpression = argumentInfo.invocation;
	                var expression = callExpression.expression;
	                var name = expression.kind === 69 /* Identifier */
	                    ? expression
	                    : expression.kind === 169 /* PropertyAccessExpression */
	                        ? expression.name
	                        : undefined;
	                if (!name || !name.text) {
	                    return undefined;
	                }
	                var typeChecker = program.getTypeChecker();
	                for (var _i = 0, _a = program.getSourceFiles(); _i < _a.length; _i++) {
	                    var sourceFile_1 = _a[_i];
	                    var nameToDeclarations = sourceFile_1.getNamedDeclarations();
	                    var declarations = ts.getProperty(nameToDeclarations, name.text);
	                    if (declarations) {
	                        for (var _b = 0, declarations_7 = declarations; _b < declarations_7.length; _b++) {
	                            var declaration = declarations_7[_b];
	                            var symbol = declaration.symbol;
	                            if (symbol) {
	                                var type = typeChecker.getTypeOfSymbolAtLocation(symbol, declaration);
	                                if (type) {
	                                    var callSignatures = type.getCallSignatures();
	                                    if (callSignatures && callSignatures.length) {
	                                        return createSignatureHelpItems(callSignatures, callSignatures[0], argumentInfo);
	                                    }
	                                }
	                            }
	                        }
	                    }
	                }
	            }
	            /**
	             * Returns relevant information for the argument list and the current argument if we are
	             * in the argument of an invocation; returns undefined otherwise.
	             */
	            function getImmediatelyContainingArgumentInfo(node) {
	                if (node.parent.kind === 171 /* CallExpression */ || node.parent.kind === 172 /* NewExpression */) {
	                    var callExpression = node.parent;
	                    // There are 3 cases to handle:
	                    //   1. The token introduces a list, and should begin a sig help session
	                    //   2. The token is either not associated with a list, or ends a list, so the session should end
	                    //   3. The token is buried inside a list, and should give sig help
	                    //
	                    // The following are examples of each:
	                    //
	                    //    Case 1:
	                    //          foo<#T, U>(#a, b)    -> The token introduces a list, and should begin a sig help session
	                    //    Case 2:
	                    //          fo#o<T, U>#(a, b)#   -> The token is either not associated with a list, or ends a list, so the session should end
	                    //    Case 3:
	                    //          foo<T#, U#>(a#, #b#) -> The token is buried inside a list, and should give sig help
	                    // Find out if 'node' is an argument, a type argument, or neither
	                    if (node.kind === 25 /* LessThanToken */ ||
	                        node.kind === 17 /* OpenParenToken */) {
	                        // Find the list that starts right *after* the < or ( token.
	                        // If the user has just opened a list, consider this item 0.
	                        var list = getChildListThatStartsWithOpenerToken(callExpression, node, sourceFile);
	                        var isTypeArgList = callExpression.typeArguments && callExpression.typeArguments.pos === list.pos;
	                        ts.Debug.assert(list !== undefined);
	                        return {
	                            kind: isTypeArgList ? 0 /* TypeArguments */ : 1 /* CallArguments */,
	                            invocation: callExpression,
	                            argumentsSpan: getApplicableSpanForArguments(list),
	                            argumentIndex: 0,
	                            argumentCount: getArgumentCount(list)
	                        };
	                    }
	                    // findListItemInfo can return undefined if we are not in parent's argument list
	                    // or type argument list. This includes cases where the cursor is:
	                    //   - To the right of the closing paren, non-substitution template, or template tail.
	                    //   - Between the type arguments and the arguments (greater than token)
	                    //   - On the target of the call (parent.func)
	                    //   - On the 'new' keyword in a 'new' expression
	                    var listItemInfo = ts.findListItemInfo(node);
	                    if (listItemInfo) {
	                        var list = listItemInfo.list;
	                        var isTypeArgList = callExpression.typeArguments && callExpression.typeArguments.pos === list.pos;
	                        var argumentIndex = getArgumentIndex(list, node);
	                        var argumentCount = getArgumentCount(list);
	                        ts.Debug.assert(argumentIndex === 0 || argumentIndex < argumentCount, "argumentCount < argumentIndex, " + argumentCount + " < " + argumentIndex);
	                        return {
	                            kind: isTypeArgList ? 0 /* TypeArguments */ : 1 /* CallArguments */,
	                            invocation: callExpression,
	                            argumentsSpan: getApplicableSpanForArguments(list),
	                            argumentIndex: argumentIndex,
	                            argumentCount: argumentCount
	                        };
	                    }
	                }
	                else if (node.kind === 11 /* NoSubstitutionTemplateLiteral */ && node.parent.kind === 173 /* TaggedTemplateExpression */) {
	                    // Check if we're actually inside the template;
	                    // otherwise we'll fall out and return undefined.
	                    if (ts.isInsideTemplateLiteral(node, position)) {
	                        return getArgumentListInfoForTemplate(node.parent, /*argumentIndex*/ 0);
	                    }
	                }
	                else if (node.kind === 12 /* TemplateHead */ && node.parent.parent.kind === 173 /* TaggedTemplateExpression */) {
	                    var templateExpression = node.parent;
	                    var tagExpression = templateExpression.parent;
	                    ts.Debug.assert(templateExpression.kind === 186 /* TemplateExpression */);
	                    var argumentIndex = ts.isInsideTemplateLiteral(node, position) ? 0 : 1;
	                    return getArgumentListInfoForTemplate(tagExpression, argumentIndex);
	                }
	                else if (node.parent.kind === 193 /* TemplateSpan */ && node.parent.parent.parent.kind === 173 /* TaggedTemplateExpression */) {
	                    var templateSpan = node.parent;
	                    var templateExpression = templateSpan.parent;
	                    var tagExpression = templateExpression.parent;
	                    ts.Debug.assert(templateExpression.kind === 186 /* TemplateExpression */);
	                    // If we're just after a template tail, don't show signature help.
	                    if (node.kind === 14 /* TemplateTail */ && !ts.isInsideTemplateLiteral(node, position)) {
	                        return undefined;
	                    }
	                    var spanIndex = templateExpression.templateSpans.indexOf(templateSpan);
	                    var argumentIndex = getArgumentIndexForTemplatePiece(spanIndex, node);
	                    return getArgumentListInfoForTemplate(tagExpression, argumentIndex);
	                }
	                return undefined;
	            }
	            function getArgumentIndex(argumentsList, node) {
	                // The list we got back can include commas.  In the presence of errors it may 
	                // also just have nodes without commas.  For example "Foo(a b c)" will have 3 
	                // args without commas.   We want to find what index we're at.  So we count
	                // forward until we hit ourselves, only incrementing the index if it isn't a
	                // comma.
	                //
	                // Note: the subtlety around trailing commas (in getArgumentCount) does not apply
	                // here.  That's because we're only walking forward until we hit the node we're
	                // on.  In that case, even if we're after the trailing comma, we'll still see
	                // that trailing comma in the list, and we'll have generated the appropriate
	                // arg index.
	                var argumentIndex = 0;
	                var listChildren = argumentsList.getChildren();
	                for (var _i = 0, listChildren_1 = listChildren; _i < listChildren_1.length; _i++) {
	                    var child = listChildren_1[_i];
	                    if (child === node) {
	                        break;
	                    }
	                    if (child.kind !== 24 /* CommaToken */) {
	                        argumentIndex++;
	                    }
	                }
	                return argumentIndex;
	            }
	            function getArgumentCount(argumentsList) {
	                // The argument count for a list is normally the number of non-comma children it has.
	                // For example, if you have "Foo(a,b)" then there will be three children of the arg
	                // list 'a' '<comma>' 'b'.  So, in this case the arg count will be 2.  However, there
	                // is a small subtlety.  If you have  "Foo(a,)", then the child list will just have
	                // 'a' '<comma>'.  So, in the case where the last child is a comma, we increase the
	                // arg count by one to compensate.
	                //
	                // Note: this subtlety only applies to the last comma.  If you had "Foo(a,,"  then 
	                // we'll have:  'a' '<comma>' '<missing>' 
	                // That will give us 2 non-commas.  We then add one for the last comma, givin us an
	                // arg count of 3.
	                var listChildren = argumentsList.getChildren();
	                var argumentCount = ts.countWhere(listChildren, function (arg) { return arg.kind !== 24 /* CommaToken */; });
	                if (listChildren.length > 0 && ts.lastOrUndefined(listChildren).kind === 24 /* CommaToken */) {
	                    argumentCount++;
	                }
	                return argumentCount;
	            }
	            // spanIndex is either the index for a given template span.
	            // This does not give appropriate results for a NoSubstitutionTemplateLiteral
	            function getArgumentIndexForTemplatePiece(spanIndex, node) {
	                // Because the TemplateStringsArray is the first argument, we have to offset each substitution expression by 1.
	                // There are three cases we can encounter:
	                //      1. We are precisely in the template literal (argIndex = 0).
	                //      2. We are in or to the right of the substitution expression (argIndex = spanIndex + 1).
	                //      3. We are directly to the right of the template literal, but because we look for the token on the left,
	                //          not enough to put us in the substitution expression; we should consider ourselves part of
	                //          the *next* span's expression by offsetting the index (argIndex = (spanIndex + 1) + 1).
	                //
	                // Example: f  `# abcd $#{#  1 + 1#  }# efghi ${ #"#hello"#  }  #  `
	                //              ^       ^ ^       ^   ^          ^ ^      ^     ^
	                // Case:        1       1 3       2   1          3 2      2     1
	                ts.Debug.assert(position >= node.getStart(), "Assumed 'position' could not occur before node.");
	                if (ts.isTemplateLiteralKind(node.kind)) {
	                    if (ts.isInsideTemplateLiteral(node, position)) {
	                        return 0;
	                    }
	                    return spanIndex + 2;
	                }
	                return spanIndex + 1;
	            }
	            function getArgumentListInfoForTemplate(tagExpression, argumentIndex) {
	                // argumentCount is either 1 or (numSpans + 1) to account for the template strings array argument.
	                var argumentCount = tagExpression.template.kind === 11 /* NoSubstitutionTemplateLiteral */
	                    ? 1
	                    : tagExpression.template.templateSpans.length + 1;
	                ts.Debug.assert(argumentIndex === 0 || argumentIndex < argumentCount, "argumentCount < argumentIndex, " + argumentCount + " < " + argumentIndex);
	                return {
	                    kind: 2 /* TaggedTemplateArguments */,
	                    invocation: tagExpression,
	                    argumentsSpan: getApplicableSpanForTaggedTemplate(tagExpression),
	                    argumentIndex: argumentIndex,
	                    argumentCount: argumentCount
	                };
	            }
	            function getApplicableSpanForArguments(argumentsList) {
	                // We use full start and skip trivia on the end because we want to include trivia on
	                // both sides. For example,
	                //
	                //    foo(   /*comment */     a, b, c      /*comment*/     )
	                //        |                                               |
	                //
	                // The applicable span is from the first bar to the second bar (inclusive,
	                // but not including parentheses)
	                var applicableSpanStart = argumentsList.getFullStart();
	                var applicableSpanEnd = ts.skipTrivia(sourceFile.text, argumentsList.getEnd(), /*stopAfterLineBreak*/ false);
	                return ts.createTextSpan(applicableSpanStart, applicableSpanEnd - applicableSpanStart);
	            }
	            function getApplicableSpanForTaggedTemplate(taggedTemplate) {
	                var template = taggedTemplate.template;
	                var applicableSpanStart = template.getStart();
	                var applicableSpanEnd = template.getEnd();
	                // We need to adjust the end position for the case where the template does not have a tail.
	                // Otherwise, we will not show signature help past the expression.
	                // For example,
	                //
	                //      `  ${ 1 + 1        foo(10)
	                //       |        |
	                //
	                // This is because a Missing node has no width. However, what we actually want is to include trivia
	                // leading up to the next token in case the user is about to type in a TemplateMiddle or TemplateTail.
	                if (template.kind === 186 /* TemplateExpression */) {
	                    var lastSpan = ts.lastOrUndefined(template.templateSpans);
	                    if (lastSpan.literal.getFullWidth() === 0) {
	                        applicableSpanEnd = ts.skipTrivia(sourceFile.text, applicableSpanEnd, /*stopAfterLineBreak*/ false);
	                    }
	                }
	                return ts.createTextSpan(applicableSpanStart, applicableSpanEnd - applicableSpanStart);
	            }
	            function getContainingArgumentInfo(node) {
	                for (var n = node; n.kind !== 251 /* SourceFile */; n = n.parent) {
	                    if (ts.isFunctionBlock(n)) {
	                        return undefined;
	                    }
	                    // If the node is not a subspan of its parent, this is a big problem.
	                    // There have been crashes that might be caused by this violation.
	                    if (n.pos < n.parent.pos || n.end > n.parent.end) {
	                        ts.Debug.fail("Node of kind " + n.kind + " is not a subspan of its parent of kind " + n.parent.kind);
	                    }
	                    var argumentInfo_1 = getImmediatelyContainingArgumentInfo(n);
	                    if (argumentInfo_1) {
	                        return argumentInfo_1;
	                    }
	                }
	                return undefined;
	            }
	            function getChildListThatStartsWithOpenerToken(parent, openerToken, sourceFile) {
	                var children = parent.getChildren(sourceFile);
	                var indexOfOpenerToken = children.indexOf(openerToken);
	                ts.Debug.assert(indexOfOpenerToken >= 0 && children.length > indexOfOpenerToken + 1);
	                return children[indexOfOpenerToken + 1];
	            }
	            /**
	             * The selectedItemIndex could be negative for several reasons.
	             *     1. There are too many arguments for all of the overloads
	             *     2. None of the overloads were type compatible
	             * The solution here is to try to pick the best overload by picking
	             * either the first one that has an appropriate number of parameters,
	             * or the one with the most parameters.
	             */
	            function selectBestInvalidOverloadIndex(candidates, argumentCount) {
	                var maxParamsSignatureIndex = -1;
	                var maxParams = -1;
	                for (var i = 0; i < candidates.length; i++) {
	                    var candidate = candidates[i];
	                    if (candidate.hasRestParameter || candidate.parameters.length >= argumentCount) {
	                        return i;
	                    }
	                    if (candidate.parameters.length > maxParams) {
	                        maxParams = candidate.parameters.length;
	                        maxParamsSignatureIndex = i;
	                    }
	                }
	                return maxParamsSignatureIndex;
	            }
	            function createSignatureHelpItems(candidates, bestSignature, argumentListInfo) {
	                var applicableSpan = argumentListInfo.argumentsSpan;
	                var isTypeParameterList = argumentListInfo.kind === 0 /* TypeArguments */;
	                var invocation = argumentListInfo.invocation;
	                var callTarget = ts.getInvokedExpression(invocation);
	                var callTargetSymbol = typeChecker.getSymbolAtLocation(callTarget);
	                var callTargetDisplayParts = callTargetSymbol && ts.symbolToDisplayParts(typeChecker, callTargetSymbol, /*enclosingDeclaration*/ undefined, /*meaning*/ undefined);
	                var items = ts.map(candidates, function (candidateSignature) {
	                    var signatureHelpParameters;
	                    var prefixDisplayParts = [];
	                    var suffixDisplayParts = [];
	                    if (callTargetDisplayParts) {
	                        ts.addRange(prefixDisplayParts, callTargetDisplayParts);
	                    }
	                    if (isTypeParameterList) {
	                        prefixDisplayParts.push(ts.punctuationPart(25 /* LessThanToken */));
	                        var typeParameters = candidateSignature.typeParameters;
	                        signatureHelpParameters = typeParameters && typeParameters.length > 0 ? ts.map(typeParameters, createSignatureHelpParameterForTypeParameter) : emptyArray;
	                        suffixDisplayParts.push(ts.punctuationPart(27 /* GreaterThanToken */));
	                        var parameterParts = ts.mapToDisplayParts(function (writer) {
	                            return typeChecker.getSymbolDisplayBuilder().buildDisplayForParametersAndDelimiters(candidateSignature.parameters, writer, invocation);
	                        });
	                        ts.addRange(suffixDisplayParts, parameterParts);
	                    }
	                    else {
	                        var typeParameterParts = ts.mapToDisplayParts(function (writer) {
	                            return typeChecker.getSymbolDisplayBuilder().buildDisplayForTypeParametersAndDelimiters(candidateSignature.typeParameters, writer, invocation);
	                        });
	                        ts.addRange(prefixDisplayParts, typeParameterParts);
	                        prefixDisplayParts.push(ts.punctuationPart(17 /* OpenParenToken */));
	                        var parameters = candidateSignature.parameters;
	                        signatureHelpParameters = parameters.length > 0 ? ts.map(parameters, createSignatureHelpParameterForParameter) : emptyArray;
	                        suffixDisplayParts.push(ts.punctuationPart(18 /* CloseParenToken */));
	                    }
	                    var returnTypeParts = ts.mapToDisplayParts(function (writer) {
	                        return typeChecker.getSymbolDisplayBuilder().buildReturnTypeDisplay(candidateSignature, writer, invocation);
	                    });
	                    ts.addRange(suffixDisplayParts, returnTypeParts);
	                    return {
	                        isVariadic: candidateSignature.hasRestParameter,
	                        prefixDisplayParts: prefixDisplayParts,
	                        suffixDisplayParts: suffixDisplayParts,
	                        separatorDisplayParts: [ts.punctuationPart(24 /* CommaToken */), ts.spacePart()],
	                        parameters: signatureHelpParameters,
	                        documentation: candidateSignature.getDocumentationComment()
	                    };
	                });
	                var argumentIndex = argumentListInfo.argumentIndex;
	                // argumentCount is the *apparent* number of arguments.
	                var argumentCount = argumentListInfo.argumentCount;
	                var selectedItemIndex = candidates.indexOf(bestSignature);
	                if (selectedItemIndex < 0) {
	                    selectedItemIndex = selectBestInvalidOverloadIndex(candidates, argumentCount);
	                }
	                ts.Debug.assert(argumentIndex === 0 || argumentIndex < argumentCount, "argumentCount < argumentIndex, " + argumentCount + " < " + argumentIndex);
	                return {
	                    items: items,
	                    applicableSpan: applicableSpan,
	                    selectedItemIndex: selectedItemIndex,
	                    argumentIndex: argumentIndex,
	                    argumentCount: argumentCount
	                };
	                function createSignatureHelpParameterForParameter(parameter) {
	                    var displayParts = ts.mapToDisplayParts(function (writer) {
	                        return typeChecker.getSymbolDisplayBuilder().buildParameterDisplay(parameter, writer, invocation);
	                    });
	                    return {
	                        name: parameter.name,
	                        documentation: parameter.getDocumentationComment(),
	                        displayParts: displayParts,
	                        isOptional: typeChecker.isOptionalParameter(parameter.valueDeclaration)
	                    };
	                }
	                function createSignatureHelpParameterForTypeParameter(typeParameter) {
	                    var displayParts = ts.mapToDisplayParts(function (writer) {
	                        return typeChecker.getSymbolDisplayBuilder().buildTypeParameterDisplay(typeParameter, writer, invocation);
	                    });
	                    return {
	                        name: typeParameter.symbol.name,
	                        documentation: emptyArray,
	                        displayParts: displayParts,
	                        isOptional: false
	                    };
	                }
	            }
	        }
	        SignatureHelp.getSignatureHelpItems = getSignatureHelpItems;
	    })(SignatureHelp = ts.SignatureHelp || (ts.SignatureHelp = {}));
	})(ts || (ts = {}));
	// These utilities are common to multiple language service features.
	/* @internal */
	var ts;
	(function (ts) {
	    function getEndLinePosition(line, sourceFile) {
	        ts.Debug.assert(line >= 0);
	        var lineStarts = sourceFile.getLineStarts();
	        var lineIndex = line;
	        if (lineIndex + 1 === lineStarts.length) {
	            // last line - return EOF
	            return sourceFile.text.length - 1;
	        }
	        else {
	            // current line start
	            var start = lineStarts[lineIndex];
	            // take the start position of the next line -1 = it should be some line break
	            var pos = lineStarts[lineIndex + 1] - 1;
	            ts.Debug.assert(ts.isLineBreak(sourceFile.text.charCodeAt(pos)));
	            // walk backwards skipping line breaks, stop the the beginning of current line.
	            // i.e:
	            // <some text>
	            // $ <- end of line for this position should match the start position
	            while (start <= pos && ts.isLineBreak(sourceFile.text.charCodeAt(pos))) {
	                pos--;
	            }
	            return pos;
	        }
	    }
	    ts.getEndLinePosition = getEndLinePosition;
	    function getLineStartPositionForPosition(position, sourceFile) {
	        var lineStarts = sourceFile.getLineStarts();
	        var line = sourceFile.getLineAndCharacterOfPosition(position).line;
	        return lineStarts[line];
	    }
	    ts.getLineStartPositionForPosition = getLineStartPositionForPosition;
	    function rangeContainsRange(r1, r2) {
	        return startEndContainsRange(r1.pos, r1.end, r2);
	    }
	    ts.rangeContainsRange = rangeContainsRange;
	    function startEndContainsRange(start, end, range) {
	        return start <= range.pos && end >= range.end;
	    }
	    ts.startEndContainsRange = startEndContainsRange;
	    function rangeContainsStartEnd(range, start, end) {
	        return range.pos <= start && range.end >= end;
	    }
	    ts.rangeContainsStartEnd = rangeContainsStartEnd;
	    function rangeOverlapsWithStartEnd(r1, start, end) {
	        return startEndOverlapsWithStartEnd(r1.pos, r1.end, start, end);
	    }
	    ts.rangeOverlapsWithStartEnd = rangeOverlapsWithStartEnd;
	    function startEndOverlapsWithStartEnd(start1, end1, start2, end2) {
	        var start = Math.max(start1, start2);
	        var end = Math.min(end1, end2);
	        return start < end;
	    }
	    ts.startEndOverlapsWithStartEnd = startEndOverlapsWithStartEnd;
	    function positionBelongsToNode(candidate, position, sourceFile) {
	        return candidate.end > position || !isCompletedNode(candidate, sourceFile);
	    }
	    ts.positionBelongsToNode = positionBelongsToNode;
	    function isCompletedNode(n, sourceFile) {
	        if (ts.nodeIsMissing(n)) {
	            return false;
	        }
	        switch (n.kind) {
	            case 217 /* ClassDeclaration */:
	            case 218 /* InterfaceDeclaration */:
	            case 220 /* EnumDeclaration */:
	            case 168 /* ObjectLiteralExpression */:
	            case 164 /* ObjectBindingPattern */:
	            case 156 /* TypeLiteral */:
	            case 195 /* Block */:
	            case 222 /* ModuleBlock */:
	            case 223 /* CaseBlock */:
	                return nodeEndsWith(n, 16 /* CloseBraceToken */, sourceFile);
	            case 247 /* CatchClause */:
	                return isCompletedNode(n.block, sourceFile);
	            case 172 /* NewExpression */:
	                if (!n.arguments) {
	                    return true;
	                }
	            // fall through
	            case 171 /* CallExpression */:
	            case 175 /* ParenthesizedExpression */:
	            case 161 /* ParenthesizedType */:
	                return nodeEndsWith(n, 18 /* CloseParenToken */, sourceFile);
	            case 153 /* FunctionType */:
	            case 154 /* ConstructorType */:
	                return isCompletedNode(n.type, sourceFile);
	            case 145 /* Constructor */:
	            case 146 /* GetAccessor */:
	            case 147 /* SetAccessor */:
	            case 216 /* FunctionDeclaration */:
	            case 176 /* FunctionExpression */:
	            case 144 /* MethodDeclaration */:
	            case 143 /* MethodSignature */:
	            case 149 /* ConstructSignature */:
	            case 148 /* CallSignature */:
	            case 177 /* ArrowFunction */:
	                if (n.body) {
	                    return isCompletedNode(n.body, sourceFile);
	                }
	                if (n.type) {
	                    return isCompletedNode(n.type, sourceFile);
	                }
	                // Even though type parameters can be unclosed, we can get away with
	                // having at least a closing paren.
	                return hasChildOfKind(n, 18 /* CloseParenToken */, sourceFile);
	            case 221 /* ModuleDeclaration */:
	                return n.body && isCompletedNode(n.body, sourceFile);
	            case 199 /* IfStatement */:
	                if (n.elseStatement) {
	                    return isCompletedNode(n.elseStatement, sourceFile);
	                }
	                return isCompletedNode(n.thenStatement, sourceFile);
	            case 198 /* ExpressionStatement */:
	                return isCompletedNode(n.expression, sourceFile) ||
	                    hasChildOfKind(n, 23 /* SemicolonToken */);
	            case 167 /* ArrayLiteralExpression */:
	            case 165 /* ArrayBindingPattern */:
	            case 170 /* ElementAccessExpression */:
	            case 137 /* ComputedPropertyName */:
	            case 158 /* TupleType */:
	                return nodeEndsWith(n, 20 /* CloseBracketToken */, sourceFile);
	            case 150 /* IndexSignature */:
	                if (n.type) {
	                    return isCompletedNode(n.type, sourceFile);
	                }
	                return hasChildOfKind(n, 20 /* CloseBracketToken */, sourceFile);
	            case 244 /* CaseClause */:
	            case 245 /* DefaultClause */:
	                // there is no such thing as terminator token for CaseClause/DefaultClause so for simplicitly always consider them non-completed
	                return false;
	            case 202 /* ForStatement */:
	            case 203 /* ForInStatement */:
	            case 204 /* ForOfStatement */:
	            case 201 /* WhileStatement */:
	                return isCompletedNode(n.statement, sourceFile);
	            case 200 /* DoStatement */:
	                // rough approximation: if DoStatement has While keyword - then if node is completed is checking the presence of ')';
	                var hasWhileKeyword = findChildOfKind(n, 104 /* WhileKeyword */, sourceFile);
	                if (hasWhileKeyword) {
	                    return nodeEndsWith(n, 18 /* CloseParenToken */, sourceFile);
	                }
	                return isCompletedNode(n.statement, sourceFile);
	            case 155 /* TypeQuery */:
	                return isCompletedNode(n.exprName, sourceFile);
	            case 179 /* TypeOfExpression */:
	            case 178 /* DeleteExpression */:
	            case 180 /* VoidExpression */:
	            case 187 /* YieldExpression */:
	            case 188 /* SpreadElementExpression */:
	                var unaryWordExpression = n;
	                return isCompletedNode(unaryWordExpression.expression, sourceFile);
	            case 173 /* TaggedTemplateExpression */:
	                return isCompletedNode(n.template, sourceFile);
	            case 186 /* TemplateExpression */:
	                var lastSpan = ts.lastOrUndefined(n.templateSpans);
	                return isCompletedNode(lastSpan, sourceFile);
	            case 193 /* TemplateSpan */:
	                return ts.nodeIsPresent(n.literal);
	            case 182 /* PrefixUnaryExpression */:
	                return isCompletedNode(n.operand, sourceFile);
	            case 184 /* BinaryExpression */:
	                return isCompletedNode(n.right, sourceFile);
	            case 185 /* ConditionalExpression */:
	                return isCompletedNode(n.whenFalse, sourceFile);
	            default:
	                return true;
	        }
	    }
	    ts.isCompletedNode = isCompletedNode;
	    /*
	     * Checks if node ends with 'expectedLastToken'.
	     * If child at position 'length - 1' is 'SemicolonToken' it is skipped and 'expectedLastToken' is compared with child at position 'length - 2'.
	     */
	    function nodeEndsWith(n, expectedLastToken, sourceFile) {
	        var children = n.getChildren(sourceFile);
	        if (children.length) {
	            var last = ts.lastOrUndefined(children);
	            if (last.kind === expectedLastToken) {
	                return true;
	            }
	            else if (last.kind === 23 /* SemicolonToken */ && children.length !== 1) {
	                return children[children.length - 2].kind === expectedLastToken;
	            }
	        }
	        return false;
	    }
	    function findListItemInfo(node) {
	        var list = findContainingList(node);
	        // It is possible at this point for syntaxList to be undefined, either if
	        // node.parent had no list child, or if none of its list children contained
	        // the span of node. If this happens, return undefined. The caller should
	        // handle this case.
	        if (!list) {
	            return undefined;
	        }
	        var children = list.getChildren();
	        var listItemIndex = ts.indexOf(children, node);
	        return {
	            listItemIndex: listItemIndex,
	            list: list
	        };
	    }
	    ts.findListItemInfo = findListItemInfo;
	    function hasChildOfKind(n, kind, sourceFile) {
	        return !!findChildOfKind(n, kind, sourceFile);
	    }
	    ts.hasChildOfKind = hasChildOfKind;
	    function findChildOfKind(n, kind, sourceFile) {
	        return ts.forEach(n.getChildren(sourceFile), function (c) { return c.kind === kind && c; });
	    }
	    ts.findChildOfKind = findChildOfKind;
	    function findContainingList(node) {
	        // The node might be a list element (nonsynthetic) or a comma (synthetic). Either way, it will
	        // be parented by the container of the SyntaxList, not the SyntaxList itself.
	        // In order to find the list item index, we first need to locate SyntaxList itself and then search
	        // for the position of the relevant node (or comma).
	        var syntaxList = ts.forEach(node.parent.getChildren(), function (c) {
	            // find syntax list that covers the span of the node
	            if (c.kind === 274 /* SyntaxList */ && c.pos <= node.pos && c.end >= node.end) {
	                return c;
	            }
	        });
	        // Either we didn't find an appropriate list, or the list must contain us.
	        ts.Debug.assert(!syntaxList || ts.contains(syntaxList.getChildren(), node));
	        return syntaxList;
	    }
	    ts.findContainingList = findContainingList;
	    /* Gets the token whose text has range [start, end) and
	     * position >= start and (position < end or (position === end && token is keyword or identifier))
	     */
	    function getTouchingWord(sourceFile, position) {
	        return getTouchingToken(sourceFile, position, function (n) { return isWord(n.kind); });
	    }
	    ts.getTouchingWord = getTouchingWord;
	    /* Gets the token whose text has range [start, end) and position >= start
	     * and (position < end or (position === end && token is keyword or identifier or numeric\string litera))
	     */
	    function getTouchingPropertyName(sourceFile, position) {
	        return getTouchingToken(sourceFile, position, function (n) { return isPropertyName(n.kind); });
	    }
	    ts.getTouchingPropertyName = getTouchingPropertyName;
	    /** Returns the token if position is in [start, end) or if position === end and includeItemAtEndPosition(token) === true */
	    function getTouchingToken(sourceFile, position, includeItemAtEndPosition) {
	        return getTokenAtPositionWorker(sourceFile, position, /*allowPositionInLeadingTrivia*/ false, includeItemAtEndPosition);
	    }
	    ts.getTouchingToken = getTouchingToken;
	    /** Returns a token if position is in [start-of-leading-trivia, end) */
	    function getTokenAtPosition(sourceFile, position) {
	        return getTokenAtPositionWorker(sourceFile, position, /*allowPositionInLeadingTrivia*/ true, /*includeItemAtEndPosition*/ undefined);
	    }
	    ts.getTokenAtPosition = getTokenAtPosition;
	    /** Get the token whose text contains the position */
	    function getTokenAtPositionWorker(sourceFile, position, allowPositionInLeadingTrivia, includeItemAtEndPosition) {
	        var current = sourceFile;
	        outer: while (true) {
	            if (isToken(current)) {
	                // exit early
	                return current;
	            }
	            // find the child that contains 'position'
	            for (var i = 0, n = current.getChildCount(sourceFile); i < n; i++) {
	                var child = current.getChildAt(i);
	                var start = allowPositionInLeadingTrivia ? child.getFullStart() : child.getStart(sourceFile);
	                if (start <= position) {
	                    var end = child.getEnd();
	                    if (position < end || (position === end && child.kind === 1 /* EndOfFileToken */)) {
	                        current = child;
	                        continue outer;
	                    }
	                    else if (includeItemAtEndPosition && end === position) {
	                        var previousToken = findPrecedingToken(position, sourceFile, child);
	                        if (previousToken && includeItemAtEndPosition(previousToken)) {
	                            return previousToken;
	                        }
	                    }
	                }
	            }
	            return current;
	        }
	    }
	    /**
	      * The token on the left of the position is the token that strictly includes the position
	      * or sits to the left of the cursor if it is on a boundary. For example
	      *
	      *   fo|o               -> will return foo
	      *   foo <comment> |bar -> will return foo
	      *
	      */
	    function findTokenOnLeftOfPosition(file, position) {
	        // Ideally, getTokenAtPosition should return a token. However, it is currently
	        // broken, so we do a check to make sure the result was indeed a token.
	        var tokenAtPosition = getTokenAtPosition(file, position);
	        if (isToken(tokenAtPosition) && position > tokenAtPosition.getStart(file) && position < tokenAtPosition.getEnd()) {
	            return tokenAtPosition;
	        }
	        return findPrecedingToken(position, file);
	    }
	    ts.findTokenOnLeftOfPosition = findTokenOnLeftOfPosition;
	    function findNextToken(previousToken, parent) {
	        return find(parent);
	        function find(n) {
	            if (isToken(n) && n.pos === previousToken.end) {
	                // this is token that starts at the end of previous token - return it
	                return n;
	            }
	            var children = n.getChildren();
	            for (var _i = 0, children_1 = children; _i < children_1.length; _i++) {
	                var child = children_1[_i];
	                var shouldDiveInChildNode = 
	                // previous token is enclosed somewhere in the child
	                (child.pos <= previousToken.pos && child.end > previousToken.end) ||
	                    // previous token ends exactly at the beginning of child
	                    (child.pos === previousToken.end);
	                if (shouldDiveInChildNode && nodeHasTokens(child)) {
	                    return find(child);
	                }
	            }
	            return undefined;
	        }
	    }
	    ts.findNextToken = findNextToken;
	    function findPrecedingToken(position, sourceFile, startNode) {
	        return find(startNode || sourceFile);
	        function findRightmostToken(n) {
	            if (isToken(n) || n.kind === 239 /* JsxText */) {
	                return n;
	            }
	            var children = n.getChildren();
	            var candidate = findRightmostChildNodeWithTokens(children, /*exclusiveStartPosition*/ children.length);
	            return candidate && findRightmostToken(candidate);
	        }
	        function find(n) {
	            if (isToken(n) || n.kind === 239 /* JsxText */) {
	                return n;
	            }
	            var children = n.getChildren();
	            for (var i = 0, len = children.length; i < len; i++) {
	                var child = children[i];
	                // condition 'position < child.end' checks if child node end after the position
	                // in the example below this condition will be false for 'aaaa' and 'bbbb' and true for 'ccc'
	                // aaaa___bbbb___$__ccc
	                // after we found child node with end after the position we check if start of the node is after the position.
	                // if yes - then position is in the trivia and we need to look into the previous child to find the token in question.
	                // if no - position is in the node itself so we should recurse in it.
	                // NOTE: JsxText is a weird kind of node that can contain only whitespaces (since they are not counted as trivia).
	                // if this is the case - then we should assume that token in question is located in previous child.
	                if (position < child.end && (nodeHasTokens(child) || child.kind === 239 /* JsxText */)) {
	                    var start = child.getStart(sourceFile);
	                    var lookInPreviousChild = (start >= position) ||
	                        (child.kind === 239 /* JsxText */ && start === child.end); // whitespace only JsxText
	                    if (lookInPreviousChild) {
	                        // actual start of the node is past the position - previous token should be at the end of previous child
	                        var candidate = findRightmostChildNodeWithTokens(children, /*exclusiveStartPosition*/ i);
	                        return candidate && findRightmostToken(candidate);
	                    }
	                    else {
	                        // candidate should be in this node
	                        return find(child);
	                    }
	                }
	            }
	            ts.Debug.assert(startNode !== undefined || n.kind === 251 /* SourceFile */);
	            // Here we know that none of child token nodes embrace the position,
	            // the only known case is when position is at the end of the file.
	            // Try to find the rightmost token in the file without filtering.
	            // Namely we are skipping the check: 'position < node.end'
	            if (children.length) {
	                var candidate = findRightmostChildNodeWithTokens(children, /*exclusiveStartPosition*/ children.length);
	                return candidate && findRightmostToken(candidate);
	            }
	        }
	        /// finds last node that is considered as candidate for search (isCandidate(node) === true) starting from 'exclusiveStartPosition'
	        function findRightmostChildNodeWithTokens(children, exclusiveStartPosition) {
	            for (var i = exclusiveStartPosition - 1; i >= 0; --i) {
	                if (nodeHasTokens(children[i])) {
	                    return children[i];
	                }
	            }
	        }
	    }
	    ts.findPrecedingToken = findPrecedingToken;
	    function isInString(sourceFile, position) {
	        var token = getTokenAtPosition(sourceFile, position);
	        return token && (token.kind === 9 /* StringLiteral */ || token.kind === 163 /* StringLiteralType */) && position > token.getStart();
	    }
	    ts.isInString = isInString;
	    function isInComment(sourceFile, position) {
	        return isInCommentHelper(sourceFile, position, /*predicate*/ undefined);
	    }
	    ts.isInComment = isInComment;
	    /**
	     * Returns true if the cursor at position in sourceFile is within a comment that additionally
	     * satisfies predicate, and false otherwise.
	     */
	    function isInCommentHelper(sourceFile, position, predicate) {
	        var token = getTokenAtPosition(sourceFile, position);
	        if (token && position <= token.getStart()) {
	            var commentRanges = ts.getLeadingCommentRanges(sourceFile.text, token.pos);
	            // The end marker of a single-line comment does not include the newline character.
	            // In the following case, we are inside a comment (^ denotes the cursor position):
	            //
	            //    // asdf   ^\n
	            //
	            // But for multi-line comments, we don't want to be inside the comment in the following case:
	            //
	            //    /* asdf */^
	            //
	            // Internally, we represent the end of the comment at the newline and closing '/', respectively.
	            return predicate ?
	                ts.forEach(commentRanges, function (c) { return c.pos < position &&
	                    (c.kind == 2 /* SingleLineCommentTrivia */ ? position <= c.end : position < c.end) &&
	                    predicate(c); }) :
	                ts.forEach(commentRanges, function (c) { return c.pos < position &&
	                    (c.kind == 2 /* SingleLineCommentTrivia */ ? position <= c.end : position < c.end); });
	        }
	        return false;
	    }
	    ts.isInCommentHelper = isInCommentHelper;
	    function hasDocComment(sourceFile, position) {
	        var token = getTokenAtPosition(sourceFile, position);
	        // First, we have to see if this position actually landed in a comment.
	        var commentRanges = ts.getLeadingCommentRanges(sourceFile.text, token.pos);
	        return ts.forEach(commentRanges, jsDocPrefix);
	        function jsDocPrefix(c) {
	            var text = sourceFile.text;
	            return text.length >= c.pos + 3 && text[c.pos] === '/' && text[c.pos + 1] === '*' && text[c.pos + 2] === '*';
	        }
	    }
	    ts.hasDocComment = hasDocComment;
	    /**
	     * Get the corresponding JSDocTag node if the position is in a jsDoc comment
	     */
	    function getJsDocTagAtPosition(sourceFile, position) {
	        var node = ts.getTokenAtPosition(sourceFile, position);
	        if (isToken(node)) {
	            switch (node.kind) {
	                case 102 /* VarKeyword */:
	                case 108 /* LetKeyword */:
	                case 74 /* ConstKeyword */:
	                    // if the current token is var, let or const, skip the VariableDeclarationList
	                    node = node.parent === undefined ? undefined : node.parent.parent;
	                    break;
	                default:
	                    node = node.parent;
	                    break;
	            }
	        }
	        if (node) {
	            var jsDocComment = node.jsDocComment;
	            if (jsDocComment) {
	                for (var _i = 0, _a = jsDocComment.tags; _i < _a.length; _i++) {
	                    var tag = _a[_i];
	                    if (tag.pos <= position && position <= tag.end) {
	                        return tag;
	                    }
	                }
	            }
	        }
	        return undefined;
	    }
	    ts.getJsDocTagAtPosition = getJsDocTagAtPosition;
	    function nodeHasTokens(n) {
	        // If we have a token or node that has a non-zero width, it must have tokens.
	        // Note, that getWidth() does not take trivia into account.
	        return n.getWidth() !== 0;
	    }
	    function getNodeModifiers(node) {
	        var flags = ts.getCombinedNodeFlags(node);
	        var result = [];
	        if (flags & 16 /* Private */)
	            result.push(ts.ScriptElementKindModifier.privateMemberModifier);
	        if (flags & 32 /* Protected */)
	            result.push(ts.ScriptElementKindModifier.protectedMemberModifier);
	        if (flags & 8 /* Public */)
	            result.push(ts.ScriptElementKindModifier.publicMemberModifier);
	        if (flags & 64 /* Static */)
	            result.push(ts.ScriptElementKindModifier.staticModifier);
	        if (flags & 128 /* Abstract */)
	            result.push(ts.ScriptElementKindModifier.abstractModifier);
	        if (flags & 2 /* Export */)
	            result.push(ts.ScriptElementKindModifier.exportedModifier);
	        if (ts.isInAmbientContext(node))
	            result.push(ts.ScriptElementKindModifier.ambientModifier);
	        return result.length > 0 ? result.join(',') : ts.ScriptElementKindModifier.none;
	    }
	    ts.getNodeModifiers = getNodeModifiers;
	    function getTypeArgumentOrTypeParameterList(node) {
	        if (node.kind === 152 /* TypeReference */ || node.kind === 171 /* CallExpression */) {
	            return node.typeArguments;
	        }
	        if (ts.isFunctionLike(node) || node.kind === 217 /* ClassDeclaration */ || node.kind === 218 /* InterfaceDeclaration */) {
	            return node.typeParameters;
	        }
	        return undefined;
	    }
	    ts.getTypeArgumentOrTypeParameterList = getTypeArgumentOrTypeParameterList;
	    function isToken(n) {
	        return n.kind >= 0 /* FirstToken */ && n.kind <= 135 /* LastToken */;
	    }
	    ts.isToken = isToken;
	    function isWord(kind) {
	        return kind === 69 /* Identifier */ || ts.isKeyword(kind);
	    }
	    ts.isWord = isWord;
	    function isPropertyName(kind) {
	        return kind === 9 /* StringLiteral */ || kind === 8 /* NumericLiteral */ || isWord(kind);
	    }
	    function isComment(kind) {
	        return kind === 2 /* SingleLineCommentTrivia */ || kind === 3 /* MultiLineCommentTrivia */;
	    }
	    ts.isComment = isComment;
	    function isStringOrRegularExpressionOrTemplateLiteral(kind) {
	        if (kind === 9 /* StringLiteral */
	            || kind === 163 /* StringLiteralType */
	            || kind === 10 /* RegularExpressionLiteral */
	            || ts.isTemplateLiteralKind(kind)) {
	            return true;
	        }
	        return false;
	    }
	    ts.isStringOrRegularExpressionOrTemplateLiteral = isStringOrRegularExpressionOrTemplateLiteral;
	    function isPunctuation(kind) {
	        return 15 /* FirstPunctuation */ <= kind && kind <= 68 /* LastPunctuation */;
	    }
	    ts.isPunctuation = isPunctuation;
	    function isInsideTemplateLiteral(node, position) {
	        return ts.isTemplateLiteralKind(node.kind)
	            && (node.getStart() < position && position < node.getEnd()) || (!!node.isUnterminated && position === node.getEnd());
	    }
	    ts.isInsideTemplateLiteral = isInsideTemplateLiteral;
	    function isAccessibilityModifier(kind) {
	        switch (kind) {
	            case 112 /* PublicKeyword */:
	            case 110 /* PrivateKeyword */:
	            case 111 /* ProtectedKeyword */:
	                return true;
	        }
	        return false;
	    }
	    ts.isAccessibilityModifier = isAccessibilityModifier;
	    function compareDataObjects(dst, src) {
	        for (var e in dst) {
	            if (typeof dst[e] === "object") {
	                if (!compareDataObjects(dst[e], src[e])) {
	                    return false;
	                }
	            }
	            else if (typeof dst[e] !== "function") {
	                if (dst[e] !== src[e]) {
	                    return false;
	                }
	            }
	        }
	        return true;
	    }
	    ts.compareDataObjects = compareDataObjects;
	    function isArrayLiteralOrObjectLiteralDestructuringPattern(node) {
	        if (node.kind === 167 /* ArrayLiteralExpression */ ||
	            node.kind === 168 /* ObjectLiteralExpression */) {
	            // [a,b,c] from:
	            // [a, b, c] = someExpression;
	            if (node.parent.kind === 184 /* BinaryExpression */ &&
	                node.parent.left === node &&
	                node.parent.operatorToken.kind === 56 /* EqualsToken */) {
	                return true;
	            }
	            // [a, b, c] from:
	            // for([a, b, c] of expression)
	            if (node.parent.kind === 204 /* ForOfStatement */ &&
	                node.parent.initializer === node) {
	                return true;
	            }
	            // [a, b, c] of
	            // [x, [a, b, c] ] = someExpression
	            // or 
	            // {x, a: {a, b, c} } = someExpression
	            if (isArrayLiteralOrObjectLiteralDestructuringPattern(node.parent.kind === 248 /* PropertyAssignment */ ? node.parent.parent : node.parent)) {
	                return true;
	            }
	        }
	        return false;
	    }
	    ts.isArrayLiteralOrObjectLiteralDestructuringPattern = isArrayLiteralOrObjectLiteralDestructuringPattern;
	})(ts || (ts = {}));
	// Display-part writer helpers
	/* @internal */
	var ts;
	(function (ts) {
	    function isFirstDeclarationOfSymbolParameter(symbol) {
	        return symbol.declarations && symbol.declarations.length > 0 && symbol.declarations[0].kind === 139 /* Parameter */;
	    }
	    ts.isFirstDeclarationOfSymbolParameter = isFirstDeclarationOfSymbolParameter;
	    var displayPartWriter = getDisplayPartWriter();
	    function getDisplayPartWriter() {
	        var displayParts;
	        var lineStart;
	        var indent;
	        resetWriter();
	        return {
	            displayParts: function () { return displayParts; },
	            writeKeyword: function (text) { return writeKind(text, ts.SymbolDisplayPartKind.keyword); },
	            writeOperator: function (text) { return writeKind(text, ts.SymbolDisplayPartKind.operator); },
	            writePunctuation: function (text) { return writeKind(text, ts.SymbolDisplayPartKind.punctuation); },
	            writeSpace: function (text) { return writeKind(text, ts.SymbolDisplayPartKind.space); },
	            writeStringLiteral: function (text) { return writeKind(text, ts.SymbolDisplayPartKind.stringLiteral); },
	            writeParameter: function (text) { return writeKind(text, ts.SymbolDisplayPartKind.parameterName); },
	            writeSymbol: writeSymbol,
	            writeLine: writeLine,
	            increaseIndent: function () { indent++; },
	            decreaseIndent: function () { indent--; },
	            clear: resetWriter,
	            trackSymbol: function () { },
	            reportInaccessibleThisError: function () { }
	        };
	        function writeIndent() {
	            if (lineStart) {
	                var indentString = ts.getIndentString(indent);
	                if (indentString) {
	                    displayParts.push(displayPart(indentString, ts.SymbolDisplayPartKind.space));
	                }
	                lineStart = false;
	            }
	        }
	        function writeKind(text, kind) {
	            writeIndent();
	            displayParts.push(displayPart(text, kind));
	        }
	        function writeSymbol(text, symbol) {
	            writeIndent();
	            displayParts.push(symbolPart(text, symbol));
	        }
	        function writeLine() {
	            displayParts.push(lineBreakPart());
	            lineStart = true;
	        }
	        function resetWriter() {
	            displayParts = [];
	            lineStart = true;
	            indent = 0;
	        }
	    }
	    function symbolPart(text, symbol) {
	        return displayPart(text, displayPartKind(symbol), symbol);
	        function displayPartKind(symbol) {
	            var flags = symbol.flags;
	            if (flags & 3 /* Variable */) {
	                return isFirstDeclarationOfSymbolParameter(symbol) ? ts.SymbolDisplayPartKind.parameterName : ts.SymbolDisplayPartKind.localName;
	            }
	            else if (flags & 4 /* Property */) {
	                return ts.SymbolDisplayPartKind.propertyName;
	            }
	            else if (flags & 32768 /* GetAccessor */) {
	                return ts.SymbolDisplayPartKind.propertyName;
	            }
	            else if (flags & 65536 /* SetAccessor */) {
	                return ts.SymbolDisplayPartKind.propertyName;
	            }
	            else if (flags & 8 /* EnumMember */) {
	                return ts.SymbolDisplayPartKind.enumMemberName;
	            }
	            else if (flags & 16 /* Function */) {
	                return ts.SymbolDisplayPartKind.functionName;
	            }
	            else if (flags & 32 /* Class */) {
	                return ts.SymbolDisplayPartKind.className;
	            }
	            else if (flags & 64 /* Interface */) {
	                return ts.SymbolDisplayPartKind.interfaceName;
	            }
	            else if (flags & 384 /* Enum */) {
	                return ts.SymbolDisplayPartKind.enumName;
	            }
	            else if (flags & 1536 /* Module */) {
	                return ts.SymbolDisplayPartKind.moduleName;
	            }
	            else if (flags & 8192 /* Method */) {
	                return ts.SymbolDisplayPartKind.methodName;
	            }
	            else if (flags & 262144 /* TypeParameter */) {
	                return ts.SymbolDisplayPartKind.typeParameterName;
	            }
	            else if (flags & 524288 /* TypeAlias */) {
	                return ts.SymbolDisplayPartKind.aliasName;
	            }
	            else if (flags & 8388608 /* Alias */) {
	                return ts.SymbolDisplayPartKind.aliasName;
	            }
	            return ts.SymbolDisplayPartKind.text;
	        }
	    }
	    ts.symbolPart = symbolPart;
	    function displayPart(text, kind, symbol) {
	        return {
	            text: text,
	            kind: ts.SymbolDisplayPartKind[kind]
	        };
	    }
	    ts.displayPart = displayPart;
	    function spacePart() {
	        return displayPart(" ", ts.SymbolDisplayPartKind.space);
	    }
	    ts.spacePart = spacePart;
	    function keywordPart(kind) {
	        return displayPart(ts.tokenToString(kind), ts.SymbolDisplayPartKind.keyword);
	    }
	    ts.keywordPart = keywordPart;
	    function punctuationPart(kind) {
	        return displayPart(ts.tokenToString(kind), ts.SymbolDisplayPartKind.punctuation);
	    }
	    ts.punctuationPart = punctuationPart;
	    function operatorPart(kind) {
	        return displayPart(ts.tokenToString(kind), ts.SymbolDisplayPartKind.operator);
	    }
	    ts.operatorPart = operatorPart;
	    function textOrKeywordPart(text) {
	        var kind = ts.stringToToken(text);
	        return kind === undefined
	            ? textPart(text)
	            : keywordPart(kind);
	    }
	    ts.textOrKeywordPart = textOrKeywordPart;
	    function textPart(text) {
	        return displayPart(text, ts.SymbolDisplayPartKind.text);
	    }
	    ts.textPart = textPart;
	    var carriageReturnLineFeed = "\r\n";
	    /**
	     * The default is CRLF.
	     */
	    function getNewLineOrDefaultFromHost(host) {
	        return host.getNewLine ? host.getNewLine() : carriageReturnLineFeed;
	    }
	    ts.getNewLineOrDefaultFromHost = getNewLineOrDefaultFromHost;
	    function lineBreakPart() {
	        return displayPart("\n", ts.SymbolDisplayPartKind.lineBreak);
	    }
	    ts.lineBreakPart = lineBreakPart;
	    function mapToDisplayParts(writeDisplayParts) {
	        writeDisplayParts(displayPartWriter);
	        var result = displayPartWriter.displayParts();
	        displayPartWriter.clear();
	        return result;
	    }
	    ts.mapToDisplayParts = mapToDisplayParts;
	    function typeToDisplayParts(typechecker, type, enclosingDeclaration, flags) {
	        return mapToDisplayParts(function (writer) {
	            typechecker.getSymbolDisplayBuilder().buildTypeDisplay(type, writer, enclosingDeclaration, flags);
	        });
	    }
	    ts.typeToDisplayParts = typeToDisplayParts;
	    function symbolToDisplayParts(typeChecker, symbol, enclosingDeclaration, meaning, flags) {
	        return mapToDisplayParts(function (writer) {
	            typeChecker.getSymbolDisplayBuilder().buildSymbolDisplay(symbol, writer, enclosingDeclaration, meaning, flags);
	        });
	    }
	    ts.symbolToDisplayParts = symbolToDisplayParts;
	    function signatureToDisplayParts(typechecker, signature, enclosingDeclaration, flags) {
	        return mapToDisplayParts(function (writer) {
	            typechecker.getSymbolDisplayBuilder().buildSignatureDisplay(signature, writer, enclosingDeclaration, flags);
	        });
	    }
	    ts.signatureToDisplayParts = signatureToDisplayParts;
	    function getDeclaredName(typeChecker, symbol, location) {
	        // If this is an export or import specifier it could have been renamed using the 'as' syntax.
	        // If so we want to search for whatever is under the cursor.
	        if (isImportOrExportSpecifierName(location)) {
	            return location.getText();
	        }
	        // Try to get the local symbol if we're dealing with an 'export default'
	        // since that symbol has the "true" name.
	        var localExportDefaultSymbol = ts.getLocalSymbolForExportDefault(symbol);
	        var name = typeChecker.symbolToString(localExportDefaultSymbol || symbol);
	        return name;
	    }
	    ts.getDeclaredName = getDeclaredName;
	    function isImportOrExportSpecifierName(location) {
	        return location.parent &&
	            (location.parent.kind === 229 /* ImportSpecifier */ || location.parent.kind === 233 /* ExportSpecifier */) &&
	            location.parent.propertyName === location;
	    }
	    ts.isImportOrExportSpecifierName = isImportOrExportSpecifierName;
	    /**
	     * Strip off existed single quotes or double quotes from a given string
	     *
	     * @return non-quoted string
	     */
	    function stripQuotes(name) {
	        var length = name.length;
	        if (length >= 2 &&
	            name.charCodeAt(0) === name.charCodeAt(length - 1) &&
	            (name.charCodeAt(0) === 34 /* doubleQuote */ || name.charCodeAt(0) === 39 /* singleQuote */)) {
	            return name.substring(1, length - 1);
	        }
	        ;
	        return name;
	    }
	    ts.stripQuotes = stripQuotes;
	})(ts || (ts = {}));
	/// <reference path="formatting.ts"/>
	/// <reference path="..\..\compiler\scanner.ts"/>
	/* @internal */
	var ts;
	(function (ts) {
	    var formatting;
	    (function (formatting) {
	        var standardScanner = ts.createScanner(2 /* Latest */, /*skipTrivia*/ false, 0 /* Standard */);
	        var jsxScanner = ts.createScanner(2 /* Latest */, /*skipTrivia*/ false, 1 /* JSX */);
	        /**
	         * Scanner that is currently used for formatting
	         */
	        var scanner;
	        var ScanAction;
	        (function (ScanAction) {
	            ScanAction[ScanAction["Scan"] = 0] = "Scan";
	            ScanAction[ScanAction["RescanGreaterThanToken"] = 1] = "RescanGreaterThanToken";
	            ScanAction[ScanAction["RescanSlashToken"] = 2] = "RescanSlashToken";
	            ScanAction[ScanAction["RescanTemplateToken"] = 3] = "RescanTemplateToken";
	            ScanAction[ScanAction["RescanJsxIdentifier"] = 4] = "RescanJsxIdentifier";
	        })(ScanAction || (ScanAction = {}));
	        function getFormattingScanner(sourceFile, startPos, endPos) {
	            ts.Debug.assert(scanner === undefined);
	            scanner = sourceFile.languageVariant === 1 /* JSX */ ? jsxScanner : standardScanner;
	            scanner.setText(sourceFile.text);
	            scanner.setTextPos(startPos);
	            var wasNewLine = true;
	            var leadingTrivia;
	            var trailingTrivia;
	            var savedPos;
	            var lastScanAction;
	            var lastTokenInfo;
	            return {
	                advance: advance,
	                readTokenInfo: readTokenInfo,
	                isOnToken: isOnToken,
	                getCurrentLeadingTrivia: function () { return leadingTrivia; },
	                lastTrailingTriviaWasNewLine: function () { return wasNewLine; },
	                close: function () {
	                    ts.Debug.assert(scanner !== undefined);
	                    lastTokenInfo = undefined;
	                    scanner.setText(undefined);
	                    scanner = undefined;
	                }
	            };
	            function advance() {
	                ts.Debug.assert(scanner !== undefined);
	                lastTokenInfo = undefined;
	                var isStarted = scanner.getStartPos() !== startPos;
	                if (isStarted) {
	                    if (trailingTrivia) {
	                        ts.Debug.assert(trailingTrivia.length !== 0);
	                        wasNewLine = ts.lastOrUndefined(trailingTrivia).kind === 4 /* NewLineTrivia */;
	                    }
	                    else {
	                        wasNewLine = false;
	                    }
	                }
	                leadingTrivia = undefined;
	                trailingTrivia = undefined;
	                if (!isStarted) {
	                    scanner.scan();
	                }
	                var t;
	                var pos = scanner.getStartPos();
	                // Read leading trivia and token
	                while (pos < endPos) {
	                    var t_1 = scanner.getToken();
	                    if (!ts.isTrivia(t_1)) {
	                        break;
	                    }
	                    // consume leading trivia
	                    scanner.scan();
	                    var item = {
	                        pos: pos,
	                        end: scanner.getStartPos(),
	                        kind: t_1
	                    };
	                    pos = scanner.getStartPos();
	                    if (!leadingTrivia) {
	                        leadingTrivia = [];
	                    }
	                    leadingTrivia.push(item);
	                }
	                savedPos = scanner.getStartPos();
	            }
	            function shouldRescanGreaterThanToken(node) {
	                if (node) {
	                    switch (node.kind) {
	                        case 29 /* GreaterThanEqualsToken */:
	                        case 64 /* GreaterThanGreaterThanEqualsToken */:
	                        case 65 /* GreaterThanGreaterThanGreaterThanEqualsToken */:
	                        case 45 /* GreaterThanGreaterThanGreaterThanToken */:
	                        case 44 /* GreaterThanGreaterThanToken */:
	                            return true;
	                    }
	                }
	                return false;
	            }
	            function shouldRescanJsxIdentifier(node) {
	                if (node.parent) {
	                    switch (node.parent.kind) {
	                        case 241 /* JsxAttribute */:
	                        case 238 /* JsxOpeningElement */:
	                        case 240 /* JsxClosingElement */:
	                        case 237 /* JsxSelfClosingElement */:
	                            return node.kind === 69 /* Identifier */;
	                    }
	                }
	                return false;
	            }
	            function shouldRescanSlashToken(container) {
	                return container.kind === 10 /* RegularExpressionLiteral */;
	            }
	            function shouldRescanTemplateToken(container) {
	                return container.kind === 13 /* TemplateMiddle */ ||
	                    container.kind === 14 /* TemplateTail */;
	            }
	            function startsWithSlashToken(t) {
	                return t === 39 /* SlashToken */ || t === 61 /* SlashEqualsToken */;
	            }
	            function readTokenInfo(n) {
	                ts.Debug.assert(scanner !== undefined);
	                if (!isOnToken()) {
	                    // scanner is not on the token (either advance was not called yet or scanner is already past the end position)
	                    return {
	                        leadingTrivia: leadingTrivia,
	                        trailingTrivia: undefined,
	                        token: undefined
	                    };
	                }
	                // normally scanner returns the smallest available token
	                // check the kind of context node to determine if scanner should have more greedy behavior and consume more text.
	                var expectedScanAction = shouldRescanGreaterThanToken(n)
	                    ? 1 /* RescanGreaterThanToken */
	                    : shouldRescanSlashToken(n)
	                        ? 2 /* RescanSlashToken */
	                        : shouldRescanTemplateToken(n)
	                            ? 3 /* RescanTemplateToken */
	                            : shouldRescanJsxIdentifier(n)
	                                ? 4 /* RescanJsxIdentifier */
	                                : 0 /* Scan */;
	                if (lastTokenInfo && expectedScanAction === lastScanAction) {
	                    // readTokenInfo was called before with the same expected scan action.
	                    // No need to re-scan text, return existing 'lastTokenInfo'
	                    // it is ok to call fixTokenKind here since it does not affect
	                    // what portion of text is consumed. In opposize rescanning can change it,
	                    // i.e. for '>=' when originally scanner eats just one character
	                    // and rescanning forces it to consume more.
	                    return fixTokenKind(lastTokenInfo, n);
	                }
	                if (scanner.getStartPos() !== savedPos) {
	                    ts.Debug.assert(lastTokenInfo !== undefined);
	                    // readTokenInfo was called before but scan action differs - rescan text
	                    scanner.setTextPos(savedPos);
	                    scanner.scan();
	                }
	                var currentToken = scanner.getToken();
	                if (expectedScanAction === 1 /* RescanGreaterThanToken */ && currentToken === 27 /* GreaterThanToken */) {
	                    currentToken = scanner.reScanGreaterToken();
	                    ts.Debug.assert(n.kind === currentToken);
	                    lastScanAction = 1 /* RescanGreaterThanToken */;
	                }
	                else if (expectedScanAction === 2 /* RescanSlashToken */ && startsWithSlashToken(currentToken)) {
	                    currentToken = scanner.reScanSlashToken();
	                    ts.Debug.assert(n.kind === currentToken);
	                    lastScanAction = 2 /* RescanSlashToken */;
	                }
	                else if (expectedScanAction === 3 /* RescanTemplateToken */ && currentToken === 16 /* CloseBraceToken */) {
	                    currentToken = scanner.reScanTemplateToken();
	                    lastScanAction = 3 /* RescanTemplateToken */;
	                }
	                else if (expectedScanAction === 4 /* RescanJsxIdentifier */ && currentToken === 69 /* Identifier */) {
	                    currentToken = scanner.scanJsxIdentifier();
	                    lastScanAction = 4 /* RescanJsxIdentifier */;
	                }
	                else {
	                    lastScanAction = 0 /* Scan */;
	                }
	                var token = {
	                    pos: scanner.getStartPos(),
	                    end: scanner.getTextPos(),
	                    kind: currentToken
	                };
	                // consume trailing trivia
	                if (trailingTrivia) {
	                    trailingTrivia = undefined;
	                }
	                while (scanner.getStartPos() < endPos) {
	                    currentToken = scanner.scan();
	                    if (!ts.isTrivia(currentToken)) {
	                        break;
	                    }
	                    var trivia = {
	                        pos: scanner.getStartPos(),
	                        end: scanner.getTextPos(),
	                        kind: currentToken
	                    };
	                    if (!trailingTrivia) {
	                        trailingTrivia = [];
	                    }
	                    trailingTrivia.push(trivia);
	                    if (currentToken === 4 /* NewLineTrivia */) {
	                        // move past new line
	                        scanner.scan();
	                        break;
	                    }
	                }
	                lastTokenInfo = {
	                    leadingTrivia: leadingTrivia,
	                    trailingTrivia: trailingTrivia,
	                    token: token
	                };
	                return fixTokenKind(lastTokenInfo, n);
	            }
	            function isOnToken() {
	                ts.Debug.assert(scanner !== undefined);
	                var current = (lastTokenInfo && lastTokenInfo.token.kind) || scanner.getToken();
	                var startPos = (lastTokenInfo && lastTokenInfo.token.pos) || scanner.getStartPos();
	                return startPos < endPos && current !== 1 /* EndOfFileToken */ && !ts.isTrivia(current);
	            }
	            // when containing node in the tree is token 
	            // but its kind differs from the kind that was returned by the scanner,
	            // then kind needs to be fixed. This might happen in cases 
	            // when parser interprets token differently, i.e keyword treated as identifier
	            function fixTokenKind(tokenInfo, container) {
	                if (ts.isToken(container) && tokenInfo.token.kind !== container.kind) {
	                    tokenInfo.token.kind = container.kind;
	                }
	                return tokenInfo;
	            }
	        }
	        formatting.getFormattingScanner = getFormattingScanner;
	    })(formatting = ts.formatting || (ts.formatting = {}));
	})(ts || (ts = {}));
	/// <reference path="references.ts"/>
	/* @internal */
	var ts;
	(function (ts) {
	    var formatting;
	    (function (formatting) {
	        var FormattingContext = (function () {
	            function FormattingContext(sourceFile, formattingRequestKind) {
	                this.sourceFile = sourceFile;
	                this.formattingRequestKind = formattingRequestKind;
	            }
	            FormattingContext.prototype.updateContext = function (currentRange, currentTokenParent, nextRange, nextTokenParent, commonParent) {
	                ts.Debug.assert(currentRange !== undefined, "currentTokenSpan is null");
	                ts.Debug.assert(currentTokenParent !== undefined, "currentTokenParent is null");
	                ts.Debug.assert(nextRange !== undefined, "nextTokenSpan is null");
	                ts.Debug.assert(nextTokenParent !== undefined, "nextTokenParent is null");
	                ts.Debug.assert(commonParent !== undefined, "commonParent is null");
	                this.currentTokenSpan = currentRange;
	                this.currentTokenParent = currentTokenParent;
	                this.nextTokenSpan = nextRange;
	                this.nextTokenParent = nextTokenParent;
	                this.contextNode = commonParent;
	                // drop cached results
	                this.contextNodeAllOnSameLine = undefined;
	                this.nextNodeAllOnSameLine = undefined;
	                this.tokensAreOnSameLine = undefined;
	                this.contextNodeBlockIsOnOneLine = undefined;
	                this.nextNodeBlockIsOnOneLine = undefined;
	            };
	            FormattingContext.prototype.ContextNodeAllOnSameLine = function () {
	                if (this.contextNodeAllOnSameLine === undefined) {
	                    this.contextNodeAllOnSameLine = this.NodeIsOnOneLine(this.contextNode);
	                }
	                return this.contextNodeAllOnSameLine;
	            };
	            FormattingContext.prototype.NextNodeAllOnSameLine = function () {
	                if (this.nextNodeAllOnSameLine === undefined) {
	                    this.nextNodeAllOnSameLine = this.NodeIsOnOneLine(this.nextTokenParent);
	                }
	                return this.nextNodeAllOnSameLine;
	            };
	            FormattingContext.prototype.TokensAreOnSameLine = function () {
	                if (this.tokensAreOnSameLine === undefined) {
	                    var startLine = this.sourceFile.getLineAndCharacterOfPosition(this.currentTokenSpan.pos).line;
	                    var endLine = this.sourceFile.getLineAndCharacterOfPosition(this.nextTokenSpan.pos).line;
	                    this.tokensAreOnSameLine = (startLine === endLine);
	                }
	                return this.tokensAreOnSameLine;
	            };
	            FormattingContext.prototype.ContextNodeBlockIsOnOneLine = function () {
	                if (this.contextNodeBlockIsOnOneLine === undefined) {
	                    this.contextNodeBlockIsOnOneLine = this.BlockIsOnOneLine(this.contextNode);
	                }
	                return this.contextNodeBlockIsOnOneLine;
	            };
	            FormattingContext.prototype.NextNodeBlockIsOnOneLine = function () {
	                if (this.nextNodeBlockIsOnOneLine === undefined) {
	                    this.nextNodeBlockIsOnOneLine = this.BlockIsOnOneLine(this.nextTokenParent);
	                }
	                return this.nextNodeBlockIsOnOneLine;
	            };
	            FormattingContext.prototype.NodeIsOnOneLine = function (node) {
	                var startLine = this.sourceFile.getLineAndCharacterOfPosition(node.getStart(this.sourceFile)).line;
	                var endLine = this.sourceFile.getLineAndCharacterOfPosition(node.getEnd()).line;
	                return startLine === endLine;
	            };
	            FormattingContext.prototype.BlockIsOnOneLine = function (node) {
	                var openBrace = ts.findChildOfKind(node, 15 /* OpenBraceToken */, this.sourceFile);
	                var closeBrace = ts.findChildOfKind(node, 16 /* CloseBraceToken */, this.sourceFile);
	                if (openBrace && closeBrace) {
	                    var startLine = this.sourceFile.getLineAndCharacterOfPosition(openBrace.getEnd()).line;
	                    var endLine = this.sourceFile.getLineAndCharacterOfPosition(closeBrace.getStart(this.sourceFile)).line;
	                    return startLine === endLine;
	                }
	                return false;
	            };
	            return FormattingContext;
	        }());
	        formatting.FormattingContext = FormattingContext;
	    })(formatting = ts.formatting || (ts.formatting = {}));
	})(ts || (ts = {}));
	/// <reference path="references.ts"/>
	/* @internal */
	var ts;
	(function (ts) {
	    var formatting;
	    (function (formatting) {
	        (function (FormattingRequestKind) {
	            FormattingRequestKind[FormattingRequestKind["FormatDocument"] = 0] = "FormatDocument";
	            FormattingRequestKind[FormattingRequestKind["FormatSelection"] = 1] = "FormatSelection";
	            FormattingRequestKind[FormattingRequestKind["FormatOnEnter"] = 2] = "FormatOnEnter";
	            FormattingRequestKind[FormattingRequestKind["FormatOnSemicolon"] = 3] = "FormatOnSemicolon";
	            FormattingRequestKind[FormattingRequestKind["FormatOnClosingCurlyBrace"] = 4] = "FormatOnClosingCurlyBrace";
	        })(formatting.FormattingRequestKind || (formatting.FormattingRequestKind = {}));
	        var FormattingRequestKind = formatting.FormattingRequestKind;
	    })(formatting = ts.formatting || (ts.formatting = {}));
	})(ts || (ts = {}));
	///<reference path='references.ts' />
	/* @internal */
	var ts;
	(function (ts) {
	    var formatting;
	    (function (formatting) {
	        var Rule = (function () {
	            function Rule(Descriptor, Operation, Flag) {
	                if (Flag === void 0) { Flag = 0 /* None */; }
	                this.Descriptor = Descriptor;
	                this.Operation = Operation;
	                this.Flag = Flag;
	            }
	            Rule.prototype.toString = function () {
	                return "[desc=" + this.Descriptor + "," +
	                    "operation=" + this.Operation + "," +
	                    "flag=" + this.Flag + "]";
	            };
	            return Rule;
	        }());
	        formatting.Rule = Rule;
	    })(formatting = ts.formatting || (ts.formatting = {}));
	})(ts || (ts = {}));
	///<reference path='references.ts' />
	/* @internal */
	var ts;
	(function (ts) {
	    var formatting;
	    (function (formatting) {
	        (function (RuleAction) {
	            RuleAction[RuleAction["Ignore"] = 1] = "Ignore";
	            RuleAction[RuleAction["Space"] = 2] = "Space";
	            RuleAction[RuleAction["NewLine"] = 4] = "NewLine";
	            RuleAction[RuleAction["Delete"] = 8] = "Delete";
	        })(formatting.RuleAction || (formatting.RuleAction = {}));
	        var RuleAction = formatting.RuleAction;
	    })(formatting = ts.formatting || (ts.formatting = {}));
	})(ts || (ts = {}));
	///<reference path='references.ts' />
	/* @internal */
	var ts;
	(function (ts) {
	    var formatting;
	    (function (formatting) {
	        var RuleDescriptor = (function () {
	            function RuleDescriptor(LeftTokenRange, RightTokenRange) {
	                this.LeftTokenRange = LeftTokenRange;
	                this.RightTokenRange = RightTokenRange;
	            }
	            RuleDescriptor.prototype.toString = function () {
	                return "[leftRange=" + this.LeftTokenRange + "," +
	                    "rightRange=" + this.RightTokenRange + "]";
	            };
	            RuleDescriptor.create1 = function (left, right) {
	                return RuleDescriptor.create4(formatting.Shared.TokenRange.FromToken(left), formatting.Shared.TokenRange.FromToken(right));
	            };
	            RuleDescriptor.create2 = function (left, right) {
	                return RuleDescriptor.create4(left, formatting.Shared.TokenRange.FromToken(right));
	            };
	            RuleDescriptor.create3 = function (left, right) {
	                return RuleDescriptor.create4(formatting.Shared.TokenRange.FromToken(left), right);
	            };
	            RuleDescriptor.create4 = function (left, right) {
	                return new RuleDescriptor(left, right);
	            };
	            return RuleDescriptor;
	        }());
	        formatting.RuleDescriptor = RuleDescriptor;
	    })(formatting = ts.formatting || (ts.formatting = {}));
	})(ts || (ts = {}));
	///<reference path='references.ts' />
	/* @internal */
	var ts;
	(function (ts) {
	    var formatting;
	    (function (formatting) {
	        (function (RuleFlags) {
	            RuleFlags[RuleFlags["None"] = 0] = "None";
	            RuleFlags[RuleFlags["CanDeleteNewLines"] = 1] = "CanDeleteNewLines";
	        })(formatting.RuleFlags || (formatting.RuleFlags = {}));
	        var RuleFlags = formatting.RuleFlags;
	    })(formatting = ts.formatting || (ts.formatting = {}));
	})(ts || (ts = {}));
	///<reference path='references.ts' />
	/* @internal */
	var ts;
	(function (ts) {
	    var formatting;
	    (function (formatting) {
	        var RuleOperation = (function () {
	            function RuleOperation() {
	                this.Context = null;
	                this.Action = null;
	            }
	            RuleOperation.prototype.toString = function () {
	                return "[context=" + this.Context + "," +
	                    "action=" + this.Action + "]";
	            };
	            RuleOperation.create1 = function (action) {
	                return RuleOperation.create2(formatting.RuleOperationContext.Any, action);
	            };
	            RuleOperation.create2 = function (context, action) {
	                var result = new RuleOperation();
	                result.Context = context;
	                result.Action = action;
	                return result;
	            };
	            return RuleOperation;
	        }());
	        formatting.RuleOperation = RuleOperation;
	    })(formatting = ts.formatting || (ts.formatting = {}));
	})(ts || (ts = {}));
	///<reference path='references.ts' />
	/* @internal */
	var ts;
	(function (ts) {
	    var formatting;
	    (function (formatting) {
	        var RuleOperationContext = (function () {
	            function RuleOperationContext() {
	                var funcs = [];
	                for (var _i = 0; _i < arguments.length; _i++) {
	                    funcs[_i - 0] = arguments[_i];
	                }
	                this.customContextChecks = funcs;
	            }
	            RuleOperationContext.prototype.IsAny = function () {
	                return this === RuleOperationContext.Any;
	            };
	            RuleOperationContext.prototype.InContext = function (context) {
	                if (this.IsAny()) {
	                    return true;
	                }
	                for (var _i = 0, _a = this.customContextChecks; _i < _a.length; _i++) {
	                    var check = _a[_i];
	                    if (!check(context)) {
	                        return false;
	                    }
	                }
	                return true;
	            };
	            RuleOperationContext.Any = new RuleOperationContext();
	            return RuleOperationContext;
	        }());
	        formatting.RuleOperationContext = RuleOperationContext;
	    })(formatting = ts.formatting || (ts.formatting = {}));
	})(ts || (ts = {}));
	///<reference path='references.ts' />
	/* @internal */
	var ts;
	(function (ts) {
	    var formatting;
	    (function (formatting) {
	        var Rules = (function () {
	            function Rules() {
	                ///
	                /// Common Rules
	                ///
	                // Leave comments alone
	                this.IgnoreBeforeComment = new formatting.Rule(formatting.RuleDescriptor.create4(formatting.Shared.TokenRange.Any, formatting.Shared.TokenRange.Comments), formatting.RuleOperation.create1(1 /* Ignore */));
	                this.IgnoreAfterLineComment = new formatting.Rule(formatting.RuleDescriptor.create3(2 /* SingleLineCommentTrivia */, formatting.Shared.TokenRange.Any), formatting.RuleOperation.create1(1 /* Ignore */));
	                // Space after keyword but not before ; or : or ?
	                this.NoSpaceBeforeSemicolon = new formatting.Rule(formatting.RuleDescriptor.create2(formatting.Shared.TokenRange.Any, 23 /* SemicolonToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 8 /* Delete */));
	                this.NoSpaceBeforeColon = new formatting.Rule(formatting.RuleDescriptor.create2(formatting.Shared.TokenRange.Any, 54 /* ColonToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsNotBinaryOpContext), 8 /* Delete */));
	                this.NoSpaceBeforeQuestionMark = new formatting.Rule(formatting.RuleDescriptor.create2(formatting.Shared.TokenRange.Any, 53 /* QuestionToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsNotBinaryOpContext), 8 /* Delete */));
	                this.SpaceAfterColon = new formatting.Rule(formatting.RuleDescriptor.create3(54 /* ColonToken */, formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsNotBinaryOpContext), 2 /* Space */));
	                this.SpaceAfterQuestionMarkInConditionalOperator = new formatting.Rule(formatting.RuleDescriptor.create3(53 /* QuestionToken */, formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsConditionalOperatorContext), 2 /* Space */));
	                this.NoSpaceAfterQuestionMark = new formatting.Rule(formatting.RuleDescriptor.create3(53 /* QuestionToken */, formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 8 /* Delete */));
	                this.SpaceAfterSemicolon = new formatting.Rule(formatting.RuleDescriptor.create3(23 /* SemicolonToken */, formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 2 /* Space */));
	                // Space after }.
	                this.SpaceAfterCloseBrace = new formatting.Rule(formatting.RuleDescriptor.create3(16 /* CloseBraceToken */, formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsAfterCodeBlockContext), 2 /* Space */));
	                // Special case for (}, else) and (}, while) since else & while tokens are not part of the tree which makes SpaceAfterCloseBrace rule not applied
	                this.SpaceBetweenCloseBraceAndElse = new formatting.Rule(formatting.RuleDescriptor.create1(16 /* CloseBraceToken */, 80 /* ElseKeyword */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 2 /* Space */));
	                this.SpaceBetweenCloseBraceAndWhile = new formatting.Rule(formatting.RuleDescriptor.create1(16 /* CloseBraceToken */, 104 /* WhileKeyword */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 2 /* Space */));
	                this.NoSpaceAfterCloseBrace = new formatting.Rule(formatting.RuleDescriptor.create3(16 /* CloseBraceToken */, formatting.Shared.TokenRange.FromTokens([18 /* CloseParenToken */, 20 /* CloseBracketToken */, 24 /* CommaToken */, 23 /* SemicolonToken */])), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 8 /* Delete */));
	                // No space for dot
	                this.NoSpaceBeforeDot = new formatting.Rule(formatting.RuleDescriptor.create2(formatting.Shared.TokenRange.Any, 21 /* DotToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 8 /* Delete */));
	                this.NoSpaceAfterDot = new formatting.Rule(formatting.RuleDescriptor.create3(21 /* DotToken */, formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 8 /* Delete */));
	                // No space before and after indexer
	                this.NoSpaceBeforeOpenBracket = new formatting.Rule(formatting.RuleDescriptor.create2(formatting.Shared.TokenRange.Any, 19 /* OpenBracketToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 8 /* Delete */));
	                this.NoSpaceAfterCloseBracket = new formatting.Rule(formatting.RuleDescriptor.create3(20 /* CloseBracketToken */, formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsNotBeforeBlockInFunctionDeclarationContext), 8 /* Delete */));
	                // Place a space before open brace in a function declaration
	                this.FunctionOpenBraceLeftTokenRange = formatting.Shared.TokenRange.AnyIncludingMultilineComments;
	                this.SpaceBeforeOpenBraceInFunction = new formatting.Rule(formatting.RuleDescriptor.create2(this.FunctionOpenBraceLeftTokenRange, 15 /* OpenBraceToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsFunctionDeclContext, Rules.IsBeforeBlockContext, Rules.IsNotFormatOnEnter, Rules.IsSameLineTokenOrBeforeMultilineBlockContext), 2 /* Space */), 1 /* CanDeleteNewLines */);
	                // Place a space before open brace in a TypeScript declaration that has braces as children (class, module, enum, etc)
	                this.TypeScriptOpenBraceLeftTokenRange = formatting.Shared.TokenRange.FromTokens([69 /* Identifier */, 3 /* MultiLineCommentTrivia */, 73 /* ClassKeyword */]);
	                this.SpaceBeforeOpenBraceInTypeScriptDeclWithBlock = new formatting.Rule(formatting.RuleDescriptor.create2(this.TypeScriptOpenBraceLeftTokenRange, 15 /* OpenBraceToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsTypeScriptDeclWithBlockContext, Rules.IsNotFormatOnEnter, Rules.IsSameLineTokenOrBeforeMultilineBlockContext), 2 /* Space */), 1 /* CanDeleteNewLines */);
	                // Place a space before open brace in a control flow construct
	                this.ControlOpenBraceLeftTokenRange = formatting.Shared.TokenRange.FromTokens([18 /* CloseParenToken */, 3 /* MultiLineCommentTrivia */, 79 /* DoKeyword */, 100 /* TryKeyword */, 85 /* FinallyKeyword */, 80 /* ElseKeyword */]);
	                this.SpaceBeforeOpenBraceInControl = new formatting.Rule(formatting.RuleDescriptor.create2(this.ControlOpenBraceLeftTokenRange, 15 /* OpenBraceToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsControlDeclContext, Rules.IsNotFormatOnEnter, Rules.IsSameLineTokenOrBeforeMultilineBlockContext), 2 /* Space */), 1 /* CanDeleteNewLines */);
	                // Insert a space after { and before } in single-line contexts, but remove space from empty object literals {}.
	                this.SpaceAfterOpenBrace = new formatting.Rule(formatting.RuleDescriptor.create3(15 /* OpenBraceToken */, formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSingleLineBlockContext), 2 /* Space */));
	                this.SpaceBeforeCloseBrace = new formatting.Rule(formatting.RuleDescriptor.create2(formatting.Shared.TokenRange.Any, 16 /* CloseBraceToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSingleLineBlockContext), 2 /* Space */));
	                this.NoSpaceBetweenEmptyBraceBrackets = new formatting.Rule(formatting.RuleDescriptor.create1(15 /* OpenBraceToken */, 16 /* CloseBraceToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsObjectContext), 8 /* Delete */));
	                // Insert new line after { and before } in multi-line contexts.
	                this.NewLineAfterOpenBraceInBlockContext = new formatting.Rule(formatting.RuleDescriptor.create3(15 /* OpenBraceToken */, formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsMultilineBlockContext), 4 /* NewLine */));
	                // For functions and control block place } on a new line    [multi-line rule]
	                this.NewLineBeforeCloseBraceInBlockContext = new formatting.Rule(formatting.RuleDescriptor.create2(formatting.Shared.TokenRange.AnyIncludingMultilineComments, 16 /* CloseBraceToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsMultilineBlockContext), 4 /* NewLine */));
	                // Special handling of unary operators.
	                // Prefix operators generally shouldn't have a space between
	                // them and their target unary expression.
	                this.NoSpaceAfterUnaryPrefixOperator = new formatting.Rule(formatting.RuleDescriptor.create4(formatting.Shared.TokenRange.UnaryPrefixOperators, formatting.Shared.TokenRange.UnaryPrefixExpressions), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsNotBinaryOpContext), 8 /* Delete */));
	                this.NoSpaceAfterUnaryPreincrementOperator = new formatting.Rule(formatting.RuleDescriptor.create3(41 /* PlusPlusToken */, formatting.Shared.TokenRange.UnaryPreincrementExpressions), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 8 /* Delete */));
	                this.NoSpaceAfterUnaryPredecrementOperator = new formatting.Rule(formatting.RuleDescriptor.create3(42 /* MinusMinusToken */, formatting.Shared.TokenRange.UnaryPredecrementExpressions), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 8 /* Delete */));
	                this.NoSpaceBeforeUnaryPostincrementOperator = new formatting.Rule(formatting.RuleDescriptor.create2(formatting.Shared.TokenRange.UnaryPostincrementExpressions, 41 /* PlusPlusToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 8 /* Delete */));
	                this.NoSpaceBeforeUnaryPostdecrementOperator = new formatting.Rule(formatting.RuleDescriptor.create2(formatting.Shared.TokenRange.UnaryPostdecrementExpressions, 42 /* MinusMinusToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 8 /* Delete */));
	                // More unary operator special-casing.
	                // DevDiv 181814:  Be careful when removing leading whitespace
	                // around unary operators.  Examples:
	                //      1 - -2  --X-->  1--2
	                //      a + ++b --X-->  a+++b
	                this.SpaceAfterPostincrementWhenFollowedByAdd = new formatting.Rule(formatting.RuleDescriptor.create1(41 /* PlusPlusToken */, 35 /* PlusToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsBinaryOpContext), 2 /* Space */));
	                this.SpaceAfterAddWhenFollowedByUnaryPlus = new formatting.Rule(formatting.RuleDescriptor.create1(35 /* PlusToken */, 35 /* PlusToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsBinaryOpContext), 2 /* Space */));
	                this.SpaceAfterAddWhenFollowedByPreincrement = new formatting.Rule(formatting.RuleDescriptor.create1(35 /* PlusToken */, 41 /* PlusPlusToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsBinaryOpContext), 2 /* Space */));
	                this.SpaceAfterPostdecrementWhenFollowedBySubtract = new formatting.Rule(formatting.RuleDescriptor.create1(42 /* MinusMinusToken */, 36 /* MinusToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsBinaryOpContext), 2 /* Space */));
	                this.SpaceAfterSubtractWhenFollowedByUnaryMinus = new formatting.Rule(formatting.RuleDescriptor.create1(36 /* MinusToken */, 36 /* MinusToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsBinaryOpContext), 2 /* Space */));
	                this.SpaceAfterSubtractWhenFollowedByPredecrement = new formatting.Rule(formatting.RuleDescriptor.create1(36 /* MinusToken */, 42 /* MinusMinusToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsBinaryOpContext), 2 /* Space */));
	                this.NoSpaceBeforeComma = new formatting.Rule(formatting.RuleDescriptor.create2(formatting.Shared.TokenRange.Any, 24 /* CommaToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 8 /* Delete */));
	                this.SpaceAfterCertainKeywords = new formatting.Rule(formatting.RuleDescriptor.create4(formatting.Shared.TokenRange.FromTokens([102 /* VarKeyword */, 98 /* ThrowKeyword */, 92 /* NewKeyword */, 78 /* DeleteKeyword */, 94 /* ReturnKeyword */, 101 /* TypeOfKeyword */, 119 /* AwaitKeyword */]), formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 2 /* Space */));
	                this.SpaceAfterLetConstInVariableDeclaration = new formatting.Rule(formatting.RuleDescriptor.create4(formatting.Shared.TokenRange.FromTokens([108 /* LetKeyword */, 74 /* ConstKeyword */]), formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsStartOfVariableDeclarationList), 2 /* Space */));
	                this.NoSpaceBeforeOpenParenInFuncCall = new formatting.Rule(formatting.RuleDescriptor.create2(formatting.Shared.TokenRange.Any, 17 /* OpenParenToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsFunctionCallOrNewContext, Rules.IsPreviousTokenNotComma), 8 /* Delete */));
	                this.SpaceAfterFunctionInFuncDecl = new formatting.Rule(formatting.RuleDescriptor.create3(87 /* FunctionKeyword */, formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsFunctionDeclContext), 2 /* Space */));
	                this.NoSpaceBeforeOpenParenInFuncDecl = new formatting.Rule(formatting.RuleDescriptor.create2(formatting.Shared.TokenRange.Any, 17 /* OpenParenToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsFunctionDeclContext), 8 /* Delete */));
	                this.SpaceAfterVoidOperator = new formatting.Rule(formatting.RuleDescriptor.create3(103 /* VoidKeyword */, formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsVoidOpContext), 2 /* Space */));
	                this.NoSpaceBetweenReturnAndSemicolon = new formatting.Rule(formatting.RuleDescriptor.create1(94 /* ReturnKeyword */, 23 /* SemicolonToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 8 /* Delete */));
	                // Add a space between statements. All keywords except (do,else,case) has open/close parens after them.
	                // So, we have a rule to add a space for [),Any], [do,Any], [else,Any], and [case,Any]
	                this.SpaceBetweenStatements = new formatting.Rule(formatting.RuleDescriptor.create4(formatting.Shared.TokenRange.FromTokens([18 /* CloseParenToken */, 79 /* DoKeyword */, 80 /* ElseKeyword */, 71 /* CaseKeyword */]), formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsNotForContext), 2 /* Space */));
	                // This low-pri rule takes care of "try {" and "finally {" in case the rule SpaceBeforeOpenBraceInControl didn't execute on FormatOnEnter.
	                this.SpaceAfterTryFinally = new formatting.Rule(formatting.RuleDescriptor.create2(formatting.Shared.TokenRange.FromTokens([100 /* TryKeyword */, 85 /* FinallyKeyword */]), 15 /* OpenBraceToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 2 /* Space */));
	                //      get x() {}
	                //      set x(val) {}
	                this.SpaceAfterGetSetInMember = new formatting.Rule(formatting.RuleDescriptor.create2(formatting.Shared.TokenRange.FromTokens([123 /* GetKeyword */, 129 /* SetKeyword */]), 69 /* Identifier */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsFunctionDeclContext), 2 /* Space */));
	                // Special case for binary operators (that are keywords). For these we have to add a space and shouldn't follow any user options.
	                this.SpaceBeforeBinaryKeywordOperator = new formatting.Rule(formatting.RuleDescriptor.create4(formatting.Shared.TokenRange.Any, formatting.Shared.TokenRange.BinaryKeywordOperators), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsBinaryOpContext), 2 /* Space */));
	                this.SpaceAfterBinaryKeywordOperator = new formatting.Rule(formatting.RuleDescriptor.create4(formatting.Shared.TokenRange.BinaryKeywordOperators, formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsBinaryOpContext), 2 /* Space */));
	                // TypeScript-specific higher priority rules
	                // Treat constructor as an identifier in a function declaration, and remove spaces between constructor and following left parentheses
	                this.NoSpaceAfterConstructor = new formatting.Rule(formatting.RuleDescriptor.create1(121 /* ConstructorKeyword */, 17 /* OpenParenToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 8 /* Delete */));
	                // Use of module as a function call. e.g.: import m2 = module("m2");
	                this.NoSpaceAfterModuleImport = new formatting.Rule(formatting.RuleDescriptor.create2(formatting.Shared.TokenRange.FromTokens([125 /* ModuleKeyword */, 127 /* RequireKeyword */]), 17 /* OpenParenToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 8 /* Delete */));
	                // Add a space around certain TypeScript keywords
	                this.SpaceAfterCertainTypeScriptKeywords = new formatting.Rule(formatting.RuleDescriptor.create4(formatting.Shared.TokenRange.FromTokens([115 /* AbstractKeyword */, 73 /* ClassKeyword */, 122 /* DeclareKeyword */, 77 /* DefaultKeyword */, 81 /* EnumKeyword */, 82 /* ExportKeyword */, 83 /* ExtendsKeyword */, 123 /* GetKeyword */, 106 /* ImplementsKeyword */, 89 /* ImportKeyword */, 107 /* InterfaceKeyword */, 125 /* ModuleKeyword */, 126 /* NamespaceKeyword */, 110 /* PrivateKeyword */, 112 /* PublicKeyword */, 111 /* ProtectedKeyword */, 129 /* SetKeyword */, 113 /* StaticKeyword */, 132 /* TypeKeyword */]), formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 2 /* Space */));
	                this.SpaceBeforeCertainTypeScriptKeywords = new formatting.Rule(formatting.RuleDescriptor.create4(formatting.Shared.TokenRange.Any, formatting.Shared.TokenRange.FromTokens([83 /* ExtendsKeyword */, 106 /* ImplementsKeyword */])), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 2 /* Space */));
	                // Treat string literals in module names as identifiers, and add a space between the literal and the opening Brace braces, e.g.: module "m2" {
	                this.SpaceAfterModuleName = new formatting.Rule(formatting.RuleDescriptor.create1(9 /* StringLiteral */, 15 /* OpenBraceToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsModuleDeclContext), 2 /* Space */));
	                // Lambda expressions
	                this.SpaceBeforeArrow = new formatting.Rule(formatting.RuleDescriptor.create2(formatting.Shared.TokenRange.Any, 34 /* EqualsGreaterThanToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 2 /* Space */));
	                this.SpaceAfterArrow = new formatting.Rule(formatting.RuleDescriptor.create3(34 /* EqualsGreaterThanToken */, formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 2 /* Space */));
	                // Optional parameters and let args
	                this.NoSpaceAfterEllipsis = new formatting.Rule(formatting.RuleDescriptor.create1(22 /* DotDotDotToken */, 69 /* Identifier */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 8 /* Delete */));
	                this.NoSpaceAfterOptionalParameters = new formatting.Rule(formatting.RuleDescriptor.create3(53 /* QuestionToken */, formatting.Shared.TokenRange.FromTokens([18 /* CloseParenToken */, 24 /* CommaToken */])), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsNotBinaryOpContext), 8 /* Delete */));
	                // generics and type assertions
	                this.NoSpaceBeforeOpenAngularBracket = new formatting.Rule(formatting.RuleDescriptor.create2(formatting.Shared.TokenRange.TypeNames, 25 /* LessThanToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsTypeArgumentOrParameterOrAssertionContext), 8 /* Delete */));
	                this.NoSpaceBetweenCloseParenAndAngularBracket = new formatting.Rule(formatting.RuleDescriptor.create1(18 /* CloseParenToken */, 25 /* LessThanToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsTypeArgumentOrParameterOrAssertionContext), 8 /* Delete */));
	                this.NoSpaceAfterOpenAngularBracket = new formatting.Rule(formatting.RuleDescriptor.create3(25 /* LessThanToken */, formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsTypeArgumentOrParameterOrAssertionContext), 8 /* Delete */));
	                this.NoSpaceBeforeCloseAngularBracket = new formatting.Rule(formatting.RuleDescriptor.create2(formatting.Shared.TokenRange.Any, 27 /* GreaterThanToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsTypeArgumentOrParameterOrAssertionContext), 8 /* Delete */));
	                this.NoSpaceAfterCloseAngularBracket = new formatting.Rule(formatting.RuleDescriptor.create3(27 /* GreaterThanToken */, formatting.Shared.TokenRange.FromTokens([17 /* OpenParenToken */, 19 /* OpenBracketToken */, 27 /* GreaterThanToken */, 24 /* CommaToken */])), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsTypeArgumentOrParameterOrAssertionContext), 8 /* Delete */));
	                this.NoSpaceAfterTypeAssertion = new formatting.Rule(formatting.RuleDescriptor.create3(27 /* GreaterThanToken */, formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsTypeAssertionContext), 8 /* Delete */));
	                // Remove spaces in empty interface literals. e.g.: x: {}
	                this.NoSpaceBetweenEmptyInterfaceBraceBrackets = new formatting.Rule(formatting.RuleDescriptor.create1(15 /* OpenBraceToken */, 16 /* CloseBraceToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsObjectTypeContext), 8 /* Delete */));
	                // decorators
	                this.SpaceBeforeAt = new formatting.Rule(formatting.RuleDescriptor.create2(formatting.Shared.TokenRange.Any, 55 /* AtToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 2 /* Space */));
	                this.NoSpaceAfterAt = new formatting.Rule(formatting.RuleDescriptor.create3(55 /* AtToken */, formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 8 /* Delete */));
	                this.SpaceAfterDecorator = new formatting.Rule(formatting.RuleDescriptor.create4(formatting.Shared.TokenRange.Any, formatting.Shared.TokenRange.FromTokens([115 /* AbstractKeyword */, 69 /* Identifier */, 82 /* ExportKeyword */, 77 /* DefaultKeyword */, 73 /* ClassKeyword */, 113 /* StaticKeyword */, 112 /* PublicKeyword */, 110 /* PrivateKeyword */, 111 /* ProtectedKeyword */, 123 /* GetKeyword */, 129 /* SetKeyword */, 19 /* OpenBracketToken */, 37 /* AsteriskToken */])), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsEndOfDecoratorContextOnSameLine), 2 /* Space */));
	                this.NoSpaceBetweenFunctionKeywordAndStar = new formatting.Rule(formatting.RuleDescriptor.create1(87 /* FunctionKeyword */, 37 /* AsteriskToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsFunctionDeclarationOrFunctionExpressionContext), 8 /* Delete */));
	                this.SpaceAfterStarInGeneratorDeclaration = new formatting.Rule(formatting.RuleDescriptor.create3(37 /* AsteriskToken */, formatting.Shared.TokenRange.FromTokens([69 /* Identifier */, 17 /* OpenParenToken */])), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsFunctionDeclarationOrFunctionExpressionContext), 2 /* Space */));
	                this.NoSpaceBetweenYieldKeywordAndStar = new formatting.Rule(formatting.RuleDescriptor.create1(114 /* YieldKeyword */, 37 /* AsteriskToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsYieldOrYieldStarWithOperand), 8 /* Delete */));
	                this.SpaceBetweenYieldOrYieldStarAndOperand = new formatting.Rule(formatting.RuleDescriptor.create4(formatting.Shared.TokenRange.FromTokens([114 /* YieldKeyword */, 37 /* AsteriskToken */]), formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsYieldOrYieldStarWithOperand), 2 /* Space */));
	                // Async-await
	                this.SpaceBetweenAsyncAndOpenParen = new formatting.Rule(formatting.RuleDescriptor.create1(118 /* AsyncKeyword */, 17 /* OpenParenToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsArrowFunctionContext, Rules.IsSameLineTokenContext), 2 /* Space */));
	                this.SpaceBetweenAsyncAndFunctionKeyword = new formatting.Rule(formatting.RuleDescriptor.create1(118 /* AsyncKeyword */, 87 /* FunctionKeyword */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 2 /* Space */));
	                // template string
	                this.NoSpaceBetweenTagAndTemplateString = new formatting.Rule(formatting.RuleDescriptor.create3(69 /* Identifier */, formatting.Shared.TokenRange.FromTokens([11 /* NoSubstitutionTemplateLiteral */, 12 /* TemplateHead */])), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 8 /* Delete */));
	                // These rules are higher in priority than user-configurable rules.
	                this.HighPriorityCommonRules = [
	                    this.IgnoreBeforeComment, this.IgnoreAfterLineComment,
	                    this.NoSpaceBeforeColon, this.SpaceAfterColon, this.NoSpaceBeforeQuestionMark, this.SpaceAfterQuestionMarkInConditionalOperator,
	                    this.NoSpaceAfterQuestionMark,
	                    this.NoSpaceBeforeDot, this.NoSpaceAfterDot,
	                    this.NoSpaceAfterUnaryPrefixOperator,
	                    this.NoSpaceAfterUnaryPreincrementOperator, this.NoSpaceAfterUnaryPredecrementOperator,
	                    this.NoSpaceBeforeUnaryPostincrementOperator, this.NoSpaceBeforeUnaryPostdecrementOperator,
	                    this.SpaceAfterPostincrementWhenFollowedByAdd,
	                    this.SpaceAfterAddWhenFollowedByUnaryPlus, this.SpaceAfterAddWhenFollowedByPreincrement,
	                    this.SpaceAfterPostdecrementWhenFollowedBySubtract,
	                    this.SpaceAfterSubtractWhenFollowedByUnaryMinus, this.SpaceAfterSubtractWhenFollowedByPredecrement,
	                    this.NoSpaceAfterCloseBrace,
	                    this.SpaceAfterOpenBrace, this.SpaceBeforeCloseBrace, this.NewLineBeforeCloseBraceInBlockContext,
	                    this.SpaceAfterCloseBrace, this.SpaceBetweenCloseBraceAndElse, this.SpaceBetweenCloseBraceAndWhile, this.NoSpaceBetweenEmptyBraceBrackets,
	                    this.NoSpaceBetweenFunctionKeywordAndStar, this.SpaceAfterStarInGeneratorDeclaration,
	                    this.SpaceAfterFunctionInFuncDecl, this.NewLineAfterOpenBraceInBlockContext, this.SpaceAfterGetSetInMember,
	                    this.NoSpaceBetweenYieldKeywordAndStar, this.SpaceBetweenYieldOrYieldStarAndOperand,
	                    this.NoSpaceBetweenReturnAndSemicolon,
	                    this.SpaceAfterCertainKeywords,
	                    this.SpaceAfterLetConstInVariableDeclaration,
	                    this.NoSpaceBeforeOpenParenInFuncCall,
	                    this.SpaceBeforeBinaryKeywordOperator, this.SpaceAfterBinaryKeywordOperator,
	                    this.SpaceAfterVoidOperator,
	                    this.SpaceBetweenAsyncAndOpenParen, this.SpaceBetweenAsyncAndFunctionKeyword,
	                    this.NoSpaceBetweenTagAndTemplateString,
	                    // TypeScript-specific rules
	                    this.NoSpaceAfterConstructor, this.NoSpaceAfterModuleImport,
	                    this.SpaceAfterCertainTypeScriptKeywords, this.SpaceBeforeCertainTypeScriptKeywords,
	                    this.SpaceAfterModuleName,
	                    this.SpaceBeforeArrow, this.SpaceAfterArrow,
	                    this.NoSpaceAfterEllipsis,
	                    this.NoSpaceAfterOptionalParameters,
	                    this.NoSpaceBetweenEmptyInterfaceBraceBrackets,
	                    this.NoSpaceBeforeOpenAngularBracket,
	                    this.NoSpaceBetweenCloseParenAndAngularBracket,
	                    this.NoSpaceAfterOpenAngularBracket,
	                    this.NoSpaceBeforeCloseAngularBracket,
	                    this.NoSpaceAfterCloseAngularBracket,
	                    this.NoSpaceAfterTypeAssertion,
	                    this.SpaceBeforeAt,
	                    this.NoSpaceAfterAt,
	                    this.SpaceAfterDecorator,
	                ];
	                // These rules are lower in priority than user-configurable rules.
	                this.LowPriorityCommonRules = [
	                    this.NoSpaceBeforeSemicolon,
	                    this.SpaceBeforeOpenBraceInControl, this.SpaceBeforeOpenBraceInFunction, this.SpaceBeforeOpenBraceInTypeScriptDeclWithBlock,
	                    this.NoSpaceBeforeComma,
	                    this.NoSpaceBeforeOpenBracket,
	                    this.NoSpaceAfterCloseBracket,
	                    this.SpaceAfterSemicolon,
	                    this.NoSpaceBeforeOpenParenInFuncDecl,
	                    this.SpaceBetweenStatements, this.SpaceAfterTryFinally
	                ];
	                ///
	                /// Rules controlled by user options
	                ///
	                // Insert space after comma delimiter
	                this.SpaceAfterComma = new formatting.Rule(formatting.RuleDescriptor.create3(24 /* CommaToken */, formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsNextTokenNotCloseBracket), 2 /* Space */));
	                this.NoSpaceAfterComma = new formatting.Rule(formatting.RuleDescriptor.create3(24 /* CommaToken */, formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 8 /* Delete */));
	                // Insert space before and after binary operators
	                this.SpaceBeforeBinaryOperator = new formatting.Rule(formatting.RuleDescriptor.create4(formatting.Shared.TokenRange.Any, formatting.Shared.TokenRange.BinaryOperators), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsBinaryOpContext), 2 /* Space */));
	                this.SpaceAfterBinaryOperator = new formatting.Rule(formatting.RuleDescriptor.create4(formatting.Shared.TokenRange.BinaryOperators, formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsBinaryOpContext), 2 /* Space */));
	                this.NoSpaceBeforeBinaryOperator = new formatting.Rule(formatting.RuleDescriptor.create4(formatting.Shared.TokenRange.Any, formatting.Shared.TokenRange.BinaryOperators), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsBinaryOpContext), 8 /* Delete */));
	                this.NoSpaceAfterBinaryOperator = new formatting.Rule(formatting.RuleDescriptor.create4(formatting.Shared.TokenRange.BinaryOperators, formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsBinaryOpContext), 8 /* Delete */));
	                // Insert space after keywords in control flow statements
	                this.SpaceAfterKeywordInControl = new formatting.Rule(formatting.RuleDescriptor.create2(formatting.Shared.TokenRange.Keywords, 17 /* OpenParenToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsControlDeclContext), 2 /* Space */));
	                this.NoSpaceAfterKeywordInControl = new formatting.Rule(formatting.RuleDescriptor.create2(formatting.Shared.TokenRange.Keywords, 17 /* OpenParenToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsControlDeclContext), 8 /* Delete */));
	                // Open Brace braces after function
	                //TypeScript: Function can have return types, which can be made of tons of different token kinds
	                this.NewLineBeforeOpenBraceInFunction = new formatting.Rule(formatting.RuleDescriptor.create2(this.FunctionOpenBraceLeftTokenRange, 15 /* OpenBraceToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsFunctionDeclContext, Rules.IsBeforeMultilineBlockContext), 4 /* NewLine */), 1 /* CanDeleteNewLines */);
	                // Open Brace braces after TypeScript module/class/interface
	                this.NewLineBeforeOpenBraceInTypeScriptDeclWithBlock = new formatting.Rule(formatting.RuleDescriptor.create2(this.TypeScriptOpenBraceLeftTokenRange, 15 /* OpenBraceToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsTypeScriptDeclWithBlockContext, Rules.IsBeforeMultilineBlockContext), 4 /* NewLine */), 1 /* CanDeleteNewLines */);
	                // Open Brace braces after control block
	                this.NewLineBeforeOpenBraceInControl = new formatting.Rule(formatting.RuleDescriptor.create2(this.ControlOpenBraceLeftTokenRange, 15 /* OpenBraceToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsControlDeclContext, Rules.IsBeforeMultilineBlockContext), 4 /* NewLine */), 1 /* CanDeleteNewLines */);
	                // Insert space after semicolon in for statement
	                this.SpaceAfterSemicolonInFor = new formatting.Rule(formatting.RuleDescriptor.create3(23 /* SemicolonToken */, formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsForContext), 2 /* Space */));
	                this.NoSpaceAfterSemicolonInFor = new formatting.Rule(formatting.RuleDescriptor.create3(23 /* SemicolonToken */, formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext, Rules.IsForContext), 8 /* Delete */));
	                // Insert space after opening and before closing nonempty parenthesis
	                this.SpaceAfterOpenParen = new formatting.Rule(formatting.RuleDescriptor.create3(17 /* OpenParenToken */, formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 2 /* Space */));
	                this.SpaceBeforeCloseParen = new formatting.Rule(formatting.RuleDescriptor.create2(formatting.Shared.TokenRange.Any, 18 /* CloseParenToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 2 /* Space */));
	                this.NoSpaceBetweenParens = new formatting.Rule(formatting.RuleDescriptor.create1(17 /* OpenParenToken */, 18 /* CloseParenToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 8 /* Delete */));
	                this.NoSpaceAfterOpenParen = new formatting.Rule(formatting.RuleDescriptor.create3(17 /* OpenParenToken */, formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 8 /* Delete */));
	                this.NoSpaceBeforeCloseParen = new formatting.Rule(formatting.RuleDescriptor.create2(formatting.Shared.TokenRange.Any, 18 /* CloseParenToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 8 /* Delete */));
	                // Insert space after opening and before closing nonempty brackets
	                this.SpaceAfterOpenBracket = new formatting.Rule(formatting.RuleDescriptor.create3(19 /* OpenBracketToken */, formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 2 /* Space */));
	                this.SpaceBeforeCloseBracket = new formatting.Rule(formatting.RuleDescriptor.create2(formatting.Shared.TokenRange.Any, 20 /* CloseBracketToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 2 /* Space */));
	                this.NoSpaceBetweenBrackets = new formatting.Rule(formatting.RuleDescriptor.create1(19 /* OpenBracketToken */, 20 /* CloseBracketToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 8 /* Delete */));
	                this.NoSpaceAfterOpenBracket = new formatting.Rule(formatting.RuleDescriptor.create3(19 /* OpenBracketToken */, formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 8 /* Delete */));
	                this.NoSpaceBeforeCloseBracket = new formatting.Rule(formatting.RuleDescriptor.create2(formatting.Shared.TokenRange.Any, 20 /* CloseBracketToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 8 /* Delete */));
	                // Insert space after opening and before closing template string braces
	                this.NoSpaceAfterTemplateHeadAndMiddle = new formatting.Rule(formatting.RuleDescriptor.create4(formatting.Shared.TokenRange.FromTokens([12 /* TemplateHead */, 13 /* TemplateMiddle */]), formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 8 /* Delete */));
	                this.SpaceAfterTemplateHeadAndMiddle = new formatting.Rule(formatting.RuleDescriptor.create4(formatting.Shared.TokenRange.FromTokens([12 /* TemplateHead */, 13 /* TemplateMiddle */]), formatting.Shared.TokenRange.Any), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 2 /* Space */));
	                this.NoSpaceBeforeTemplateMiddleAndTail = new formatting.Rule(formatting.RuleDescriptor.create4(formatting.Shared.TokenRange.Any, formatting.Shared.TokenRange.FromTokens([13 /* TemplateMiddle */, 14 /* TemplateTail */])), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 8 /* Delete */));
	                this.SpaceBeforeTemplateMiddleAndTail = new formatting.Rule(formatting.RuleDescriptor.create4(formatting.Shared.TokenRange.Any, formatting.Shared.TokenRange.FromTokens([13 /* TemplateMiddle */, 14 /* TemplateTail */])), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsSameLineTokenContext), 2 /* Space */));
	                // Insert space after function keyword for anonymous functions
	                this.SpaceAfterAnonymousFunctionKeyword = new formatting.Rule(formatting.RuleDescriptor.create1(87 /* FunctionKeyword */, 17 /* OpenParenToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsFunctionDeclContext), 2 /* Space */));
	                this.NoSpaceAfterAnonymousFunctionKeyword = new formatting.Rule(formatting.RuleDescriptor.create1(87 /* FunctionKeyword */, 17 /* OpenParenToken */), formatting.RuleOperation.create2(new formatting.RuleOperationContext(Rules.IsFunctionDeclContext), 8 /* Delete */));
	            }
	            Rules.prototype.getRuleName = function (rule) {
	                var o = this;
	                for (var name_34 in o) {
	                    if (o[name_34] === rule) {
	                        return name_34;
	                    }
	                }
	                throw new Error("Unknown rule");
	            };
	            ///
	            /// Contexts
	            ///
	            Rules.IsForContext = function (context) {
	                return context.contextNode.kind === 202 /* ForStatement */;
	            };
	            Rules.IsNotForContext = function (context) {
	                return !Rules.IsForContext(context);
	            };
	            Rules.IsBinaryOpContext = function (context) {
	                switch (context.contextNode.kind) {
	                    case 184 /* BinaryExpression */:
	                    case 185 /* ConditionalExpression */:
	                    case 192 /* AsExpression */:
	                    case 151 /* TypePredicate */:
	                    case 159 /* UnionType */:
	                    case 160 /* IntersectionType */:
	                        return true;
	                    // equals in binding elements: function foo([[x, y] = [1, 2]])
	                    case 166 /* BindingElement */:
	                    // equals in type X = ...
	                    case 219 /* TypeAliasDeclaration */:
	                    // equal in import a = module('a');
	                    case 224 /* ImportEqualsDeclaration */:
	                    // equal in let a = 0;
	                    case 214 /* VariableDeclaration */:
	                    // equal in p = 0;
	                    case 139 /* Parameter */:
	                    case 250 /* EnumMember */:
	                    case 142 /* PropertyDeclaration */:
	                    case 141 /* PropertySignature */:
	                        return context.currentTokenSpan.kind === 56 /* EqualsToken */ || context.nextTokenSpan.kind === 56 /* EqualsToken */;
	                    // "in" keyword in for (let x in []) { }
	                    case 203 /* ForInStatement */:
	                        return context.currentTokenSpan.kind === 90 /* InKeyword */ || context.nextTokenSpan.kind === 90 /* InKeyword */;
	                    // Technically, "of" is not a binary operator, but format it the same way as "in"
	                    case 204 /* ForOfStatement */:
	                        return context.currentTokenSpan.kind === 135 /* OfKeyword */ || context.nextTokenSpan.kind === 135 /* OfKeyword */;
	                }
	                return false;
	            };
	            Rules.IsNotBinaryOpContext = function (context) {
	                return !Rules.IsBinaryOpContext(context);
	            };
	            Rules.IsConditionalOperatorContext = function (context) {
	                return context.contextNode.kind === 185 /* ConditionalExpression */;
	            };
	            Rules.IsSameLineTokenOrBeforeMultilineBlockContext = function (context) {
	                //// This check is mainly used inside SpaceBeforeOpenBraceInControl and SpaceBeforeOpenBraceInFunction.
	                ////
	                //// Ex: 
	                //// if (1)     { ....
	                ////      * ) and { are on the same line so apply the rule. Here we don't care whether it's same or multi block context
	                ////
	                //// Ex: 
	                //// if (1)
	                //// { ... }
	                ////      * ) and { are on differnet lines. We only need to format if the block is multiline context. So in this case we don't format.
	                ////
	                //// Ex:
	                //// if (1) 
	                //// { ...
	                //// }
	                ////      * ) and { are on differnet lines. We only need to format if the block is multiline context. So in this case we format.
	                return context.TokensAreOnSameLine() || Rules.IsBeforeMultilineBlockContext(context);
	            };
	            // This check is done before an open brace in a control construct, a function, or a typescript block declaration
	            Rules.IsBeforeMultilineBlockContext = function (context) {
	                return Rules.IsBeforeBlockContext(context) && !(context.NextNodeAllOnSameLine() || context.NextNodeBlockIsOnOneLine());
	            };
	            Rules.IsMultilineBlockContext = function (context) {
	                return Rules.IsBlockContext(context) && !(context.ContextNodeAllOnSameLine() || context.ContextNodeBlockIsOnOneLine());
	            };
	            Rules.IsSingleLineBlockContext = function (context) {
	                return Rules.IsBlockContext(context) && (context.ContextNodeAllOnSameLine() || context.ContextNodeBlockIsOnOneLine());
	            };
	            Rules.IsBlockContext = function (context) {
	                return Rules.NodeIsBlockContext(context.contextNode);
	            };
	            Rules.IsBeforeBlockContext = function (context) {
	                return Rules.NodeIsBlockContext(context.nextTokenParent);
	            };
	            // IMPORTANT!!! This method must return true ONLY for nodes with open and close braces as immediate children
	            Rules.NodeIsBlockContext = function (node) {
	                if (Rules.NodeIsTypeScriptDeclWithBlockContext(node)) {
	                    // This means we are in a context that looks like a block to the user, but in the grammar is actually not a node (it's a class, module, enum, object type literal, etc).
	                    return true;
	                }
	                switch (node.kind) {
	                    case 195 /* Block */:
	                    case 223 /* CaseBlock */:
	                    case 168 /* ObjectLiteralExpression */:
	                    case 222 /* ModuleBlock */:
	                        return true;
	                }
	                return false;
	            };
	            Rules.IsFunctionDeclContext = function (context) {
	                switch (context.contextNode.kind) {
	                    case 216 /* FunctionDeclaration */:
	                    case 144 /* MethodDeclaration */:
	                    case 143 /* MethodSignature */:
	                    //case SyntaxKind.MemberFunctionDeclaration:
	                    case 146 /* GetAccessor */:
	                    case 147 /* SetAccessor */:
	                    ///case SyntaxKind.MethodSignature:
	                    case 148 /* CallSignature */:
	                    case 176 /* FunctionExpression */:
	                    case 145 /* Constructor */:
	                    case 177 /* ArrowFunction */:
	                    //case SyntaxKind.ConstructorDeclaration:
	                    //case SyntaxKind.SimpleArrowFunctionExpression:
	                    //case SyntaxKind.ParenthesizedArrowFunctionExpression:
	                    case 218 /* InterfaceDeclaration */:
	                        return true;
	                }
	                return false;
	            };
	            Rules.IsFunctionDeclarationOrFunctionExpressionContext = function (context) {
	                return context.contextNode.kind === 216 /* FunctionDeclaration */ || context.contextNode.kind === 176 /* FunctionExpression */;
	            };
	            Rules.IsTypeScriptDeclWithBlockContext = function (context) {
	                return Rules.NodeIsTypeScriptDeclWithBlockContext(context.contextNode);
	            };
	            Rules.NodeIsTypeScriptDeclWithBlockContext = function (node) {
	                switch (node.kind) {
	                    case 217 /* ClassDeclaration */:
	                    case 189 /* ClassExpression */:
	                    case 218 /* InterfaceDeclaration */:
	                    case 220 /* EnumDeclaration */:
	                    case 156 /* TypeLiteral */:
	                    case 221 /* ModuleDeclaration */:
	                        return true;
	                }
	                return false;
	            };
	            Rules.IsAfterCodeBlockContext = function (context) {
	                switch (context.currentTokenParent.kind) {
	                    case 217 /* ClassDeclaration */:
	                    case 221 /* ModuleDeclaration */:
	                    case 220 /* EnumDeclaration */:
	                    case 195 /* Block */:
	                    case 247 /* CatchClause */:
	                    case 222 /* ModuleBlock */:
	                    case 209 /* SwitchStatement */:
	                        return true;
	                }
	                return false;
	            };
	            Rules.IsControlDeclContext = function (context) {
	                switch (context.contextNode.kind) {
	                    case 199 /* IfStatement */:
	                    case 209 /* SwitchStatement */:
	                    case 202 /* ForStatement */:
	                    case 203 /* ForInStatement */:
	                    case 204 /* ForOfStatement */:
	                    case 201 /* WhileStatement */:
	                    case 212 /* TryStatement */:
	                    case 200 /* DoStatement */:
	                    case 208 /* WithStatement */:
	                    // TODO
	                    // case SyntaxKind.ElseClause:
	                    case 247 /* CatchClause */:
	                        return true;
	                    default:
	                        return false;
	                }
	            };
	            Rules.IsObjectContext = function (context) {
	                return context.contextNode.kind === 168 /* ObjectLiteralExpression */;
	            };
	            Rules.IsFunctionCallContext = function (context) {
	                return context.contextNode.kind === 171 /* CallExpression */;
	            };
	            Rules.IsNewContext = function (context) {
	                return context.contextNode.kind === 172 /* NewExpression */;
	            };
	            Rules.IsFunctionCallOrNewContext = function (context) {
	                return Rules.IsFunctionCallContext(context) || Rules.IsNewContext(context);
	            };
	            Rules.IsPreviousTokenNotComma = function (context) {
	                return context.currentTokenSpan.kind !== 24 /* CommaToken */;
	            };
	            Rules.IsNextTokenNotCloseBracket = function (context) {
	                return context.nextTokenSpan.kind !== 20 /* CloseBracketToken */;
	            };
	            Rules.IsArrowFunctionContext = function (context) {
	                return context.contextNode.kind === 177 /* ArrowFunction */;
	            };
	            Rules.IsSameLineTokenContext = function (context) {
	                return context.TokensAreOnSameLine();
	            };
	            Rules.IsNotBeforeBlockInFunctionDeclarationContext = function (context) {
	                return !Rules.IsFunctionDeclContext(context) && !Rules.IsBeforeBlockContext(context);
	            };
	            Rules.IsEndOfDecoratorContextOnSameLine = function (context) {
	                return context.TokensAreOnSameLine() &&
	                    context.contextNode.decorators &&
	                    Rules.NodeIsInDecoratorContext(context.currentTokenParent) &&
	                    !Rules.NodeIsInDecoratorContext(context.nextTokenParent);
	            };
	            Rules.NodeIsInDecoratorContext = function (node) {
	                while (ts.isExpression(node)) {
	                    node = node.parent;
	                }
	                return node.kind === 140 /* Decorator */;
	            };
	            Rules.IsStartOfVariableDeclarationList = function (context) {
	                return context.currentTokenParent.kind === 215 /* VariableDeclarationList */ &&
	                    context.currentTokenParent.getStart(context.sourceFile) === context.currentTokenSpan.pos;
	            };
	            Rules.IsNotFormatOnEnter = function (context) {
	                return context.formattingRequestKind !== 2 /* FormatOnEnter */;
	            };
	            Rules.IsModuleDeclContext = function (context) {
	                return context.contextNode.kind === 221 /* ModuleDeclaration */;
	            };
	            Rules.IsObjectTypeContext = function (context) {
	                return context.contextNode.kind === 156 /* TypeLiteral */; // && context.contextNode.parent.kind !== SyntaxKind.InterfaceDeclaration;
	            };
	            Rules.IsTypeArgumentOrParameterOrAssertion = function (token, parent) {
	                if (token.kind !== 25 /* LessThanToken */ && token.kind !== 27 /* GreaterThanToken */) {
	                    return false;
	                }
	                switch (parent.kind) {
	                    case 152 /* TypeReference */:
	                    case 174 /* TypeAssertionExpression */:
	                    case 217 /* ClassDeclaration */:
	                    case 189 /* ClassExpression */:
	                    case 218 /* InterfaceDeclaration */:
	                    case 216 /* FunctionDeclaration */:
	                    case 176 /* FunctionExpression */:
	                    case 177 /* ArrowFunction */:
	                    case 144 /* MethodDeclaration */:
	                    case 143 /* MethodSignature */:
	                    case 148 /* CallSignature */:
	                    case 149 /* ConstructSignature */:
	                    case 171 /* CallExpression */:
	                    case 172 /* NewExpression */:
	                    case 191 /* ExpressionWithTypeArguments */:
	                        return true;
	                    default:
	                        return false;
	                }
	            };
	            Rules.IsTypeArgumentOrParameterOrAssertionContext = function (context) {
	                return Rules.IsTypeArgumentOrParameterOrAssertion(context.currentTokenSpan, context.currentTokenParent) ||
	                    Rules.IsTypeArgumentOrParameterOrAssertion(context.nextTokenSpan, context.nextTokenParent);
	            };
	            Rules.IsTypeAssertionContext = function (context) {
	                return context.contextNode.kind === 174 /* TypeAssertionExpression */;
	            };
	            Rules.IsVoidOpContext = function (context) {
	                return context.currentTokenSpan.kind === 103 /* VoidKeyword */ && context.currentTokenParent.kind === 180 /* VoidExpression */;
	            };
	            Rules.IsYieldOrYieldStarWithOperand = function (context) {
	                return context.contextNode.kind === 187 /* YieldExpression */ && context.contextNode.expression !== undefined;
	            };
	            return Rules;
	        }());
	        formatting.Rules = Rules;
	    })(formatting = ts.formatting || (ts.formatting = {}));
	})(ts || (ts = {}));
	///<reference path='references.ts' />
	/* @internal */
	var ts;
	(function (ts) {
	    var formatting;
	    (function (formatting) {
	        var RulesMap = (function () {
	            function RulesMap() {
	                this.map = [];
	                this.mapRowLength = 0;
	            }
	            RulesMap.create = function (rules) {
	                var result = new RulesMap();
	                result.Initialize(rules);
	                return result;
	            };
	            RulesMap.prototype.Initialize = function (rules) {
	                this.mapRowLength = 135 /* LastToken */ + 1;
	                this.map = new Array(this.mapRowLength * this.mapRowLength); //new Array<RulesBucket>(this.mapRowLength * this.mapRowLength);
	                // This array is used only during construction of the rulesbucket in the map
	                var rulesBucketConstructionStateList = new Array(this.map.length); //new Array<RulesBucketConstructionState>(this.map.length);
	                this.FillRules(rules, rulesBucketConstructionStateList);
	                return this.map;
	            };
	            RulesMap.prototype.FillRules = function (rules, rulesBucketConstructionStateList) {
	                var _this = this;
	                rules.forEach(function (rule) {
	                    _this.FillRule(rule, rulesBucketConstructionStateList);
	                });
	            };
	            RulesMap.prototype.GetRuleBucketIndex = function (row, column) {
	                var rulesBucketIndex = (row * this.mapRowLength) + column;
	                //Debug.Assert(rulesBucketIndex < this.map.Length, "Trying to access an index outside the array.");
	                return rulesBucketIndex;
	            };
	            RulesMap.prototype.FillRule = function (rule, rulesBucketConstructionStateList) {
	                var _this = this;
	                var specificRule = rule.Descriptor.LeftTokenRange !== formatting.Shared.TokenRange.Any &&
	                    rule.Descriptor.RightTokenRange !== formatting.Shared.TokenRange.Any;
	                rule.Descriptor.LeftTokenRange.GetTokens().forEach(function (left) {
	                    rule.Descriptor.RightTokenRange.GetTokens().forEach(function (right) {
	                        var rulesBucketIndex = _this.GetRuleBucketIndex(left, right);
	                        var rulesBucket = _this.map[rulesBucketIndex];
	                        if (rulesBucket === undefined) {
	                            rulesBucket = _this.map[rulesBucketIndex] = new RulesBucket();
	                        }
	                        rulesBucket.AddRule(rule, specificRule, rulesBucketConstructionStateList, rulesBucketIndex);
	                    });
	                });
	            };
	            RulesMap.prototype.GetRule = function (context) {
	                var bucketIndex = this.GetRuleBucketIndex(context.currentTokenSpan.kind, context.nextTokenSpan.kind);
	                var bucket = this.map[bucketIndex];
	                if (bucket != null) {
	                    for (var _i = 0, _a = bucket.Rules(); _i < _a.length; _i++) {
	                        var rule = _a[_i];
	                        if (rule.Operation.Context.InContext(context)) {
	                            return rule;
	                        }
	                    }
	                }
	                return null;
	            };
	            return RulesMap;
	        }());
	        formatting.RulesMap = RulesMap;
	        var MaskBitSize = 5;
	        var Mask = 0x1f;
	        (function (RulesPosition) {
	            RulesPosition[RulesPosition["IgnoreRulesSpecific"] = 0] = "IgnoreRulesSpecific";
	            RulesPosition[RulesPosition["IgnoreRulesAny"] = MaskBitSize * 1] = "IgnoreRulesAny";
	            RulesPosition[RulesPosition["ContextRulesSpecific"] = MaskBitSize * 2] = "ContextRulesSpecific";
	            RulesPosition[RulesPosition["ContextRulesAny"] = MaskBitSize * 3] = "ContextRulesAny";
	            RulesPosition[RulesPosition["NoContextRulesSpecific"] = MaskBitSize * 4] = "NoContextRulesSpecific";
	            RulesPosition[RulesPosition["NoContextRulesAny"] = MaskBitSize * 5] = "NoContextRulesAny";
	        })(formatting.RulesPosition || (formatting.RulesPosition = {}));
	        var RulesPosition = formatting.RulesPosition;
	        var RulesBucketConstructionState = (function () {
	            function RulesBucketConstructionState() {
	                //// The Rules list contains all the inserted rules into a rulebucket in the following order:
	                ////    1- Ignore rules with specific token combination
	                ////    2- Ignore rules with any token combination
	                ////    3- Context rules with specific token combination
	                ////    4- Context rules with any token combination
	                ////    5- Non-context rules with specific token combination
	                ////    6- Non-context rules with any token combination
	                //// 
	                //// The member rulesInsertionIndexBitmap is used to describe the number of rules
	                //// in each sub-bucket (above) hence can be used to know the index of where to insert 
	                //// the next rule. It's a bitmap which contains 6 different sections each is given 5 bits.
	                ////
	                //// Example:
	                //// In order to insert a rule to the end of sub-bucket (3), we get the index by adding
	                //// the values in the bitmap segments 3rd, 2nd, and 1st.
	                this.rulesInsertionIndexBitmap = 0;
	            }
	            RulesBucketConstructionState.prototype.GetInsertionIndex = function (maskPosition) {
	                var index = 0;
	                var pos = 0;
	                var indexBitmap = this.rulesInsertionIndexBitmap;
	                while (pos <= maskPosition) {
	                    index += (indexBitmap & Mask);
	                    indexBitmap >>= MaskBitSize;
	                    pos += MaskBitSize;
	                }
	                return index;
	            };
	            RulesBucketConstructionState.prototype.IncreaseInsertionIndex = function (maskPosition) {
	                var value = (this.rulesInsertionIndexBitmap >> maskPosition) & Mask;
	                value++;
	                ts.Debug.assert((value & Mask) === value, "Adding more rules into the sub-bucket than allowed. Maximum allowed is 32 rules.");
	                var temp = this.rulesInsertionIndexBitmap & ~(Mask << maskPosition);
	                temp |= value << maskPosition;
	                this.rulesInsertionIndexBitmap = temp;
	            };
	            return RulesBucketConstructionState;
	        }());
	        formatting.RulesBucketConstructionState = RulesBucketConstructionState;
	        var RulesBucket = (function () {
	            function RulesBucket() {
	                this.rules = [];
	            }
	            RulesBucket.prototype.Rules = function () {
	                return this.rules;
	            };
	            RulesBucket.prototype.AddRule = function (rule, specificTokens, constructionState, rulesBucketIndex) {
	                var position;
	                if (rule.Operation.Action === 1 /* Ignore */) {
	                    position = specificTokens ?
	                        RulesPosition.IgnoreRulesSpecific :
	                        RulesPosition.IgnoreRulesAny;
	                }
	                else if (!rule.Operation.Context.IsAny()) {
	                    position = specificTokens ?
	                        RulesPosition.ContextRulesSpecific :
	                        RulesPosition.ContextRulesAny;
	                }
	                else {
	                    position = specificTokens ?
	                        RulesPosition.NoContextRulesSpecific :
	                        RulesPosition.NoContextRulesAny;
	                }
	                var state = constructionState[rulesBucketIndex];
	                if (state === undefined) {
	                    state = constructionState[rulesBucketIndex] = new RulesBucketConstructionState();
	                }
	                var index = state.GetInsertionIndex(position);
	                this.rules.splice(index, 0, rule);
	                state.IncreaseInsertionIndex(position);
	            };
	            return RulesBucket;
	        }());
	        formatting.RulesBucket = RulesBucket;
	    })(formatting = ts.formatting || (ts.formatting = {}));
	})(ts || (ts = {}));
	///<reference path='references.ts' />
	/* @internal */
	var ts;
	(function (ts) {
	    var formatting;
	    (function (formatting) {
	        var Shared;
	        (function (Shared) {
	            var TokenRangeAccess = (function () {
	                function TokenRangeAccess(from, to, except) {
	                    this.tokens = [];
	                    for (var token = from; token <= to; token++) {
	                        if (ts.indexOf(except, token) < 0) {
	                            this.tokens.push(token);
	                        }
	                    }
	                }
	                TokenRangeAccess.prototype.GetTokens = function () {
	                    return this.tokens;
	                };
	                TokenRangeAccess.prototype.Contains = function (token) {
	                    return this.tokens.indexOf(token) >= 0;
	                };
	                return TokenRangeAccess;
	            }());
	            Shared.TokenRangeAccess = TokenRangeAccess;
	            var TokenValuesAccess = (function () {
	                function TokenValuesAccess(tks) {
	                    this.tokens = tks && tks.length ? tks : [];
	                }
	                TokenValuesAccess.prototype.GetTokens = function () {
	                    return this.tokens;
	                };
	                TokenValuesAccess.prototype.Contains = function (token) {
	                    return this.tokens.indexOf(token) >= 0;
	                };
	                return TokenValuesAccess;
	            }());
	            Shared.TokenValuesAccess = TokenValuesAccess;
	            var TokenSingleValueAccess = (function () {
	                function TokenSingleValueAccess(token) {
	                    this.token = token;
	                }
	                TokenSingleValueAccess.prototype.GetTokens = function () {
	                    return [this.token];
	                };
	                TokenSingleValueAccess.prototype.Contains = function (tokenValue) {
	                    return tokenValue === this.token;
	                };
	                return TokenSingleValueAccess;
	            }());
	            Shared.TokenSingleValueAccess = TokenSingleValueAccess;
	            var TokenAllAccess = (function () {
	                function TokenAllAccess() {
	                }
	                TokenAllAccess.prototype.GetTokens = function () {
	                    var result = [];
	                    for (var token = 0 /* FirstToken */; token <= 135 /* LastToken */; token++) {
	                        result.push(token);
	                    }
	                    return result;
	                };
	                TokenAllAccess.prototype.Contains = function (tokenValue) {
	                    return true;
	                };
	                TokenAllAccess.prototype.toString = function () {
	                    return "[allTokens]";
	                };
	                return TokenAllAccess;
	            }());
	            Shared.TokenAllAccess = TokenAllAccess;
	            var TokenRange = (function () {
	                function TokenRange(tokenAccess) {
	                    this.tokenAccess = tokenAccess;
	                }
	                TokenRange.FromToken = function (token) {
	                    return new TokenRange(new TokenSingleValueAccess(token));
	                };
	                TokenRange.FromTokens = function (tokens) {
	                    return new TokenRange(new TokenValuesAccess(tokens));
	                };
	                TokenRange.FromRange = function (f, to, except) {
	                    if (except === void 0) { except = []; }
	                    return new TokenRange(new TokenRangeAccess(f, to, except));
	                };
	                TokenRange.AllTokens = function () {
	                    return new TokenRange(new TokenAllAccess());
	                };
	                TokenRange.prototype.GetTokens = function () {
	                    return this.tokenAccess.GetTokens();
	                };
	                TokenRange.prototype.Contains = function (token) {
	                    return this.tokenAccess.Contains(token);
	                };
	                TokenRange.prototype.toString = function () {
	                    return this.tokenAccess.toString();
	                };
	                TokenRange.Any = TokenRange.AllTokens();
	                TokenRange.AnyIncludingMultilineComments = TokenRange.FromTokens(TokenRange.Any.GetTokens().concat([3 /* MultiLineCommentTrivia */]));
	                TokenRange.Keywords = TokenRange.FromRange(70 /* FirstKeyword */, 135 /* LastKeyword */);
	                TokenRange.BinaryOperators = TokenRange.FromRange(25 /* FirstBinaryOperator */, 68 /* LastBinaryOperator */);
	                TokenRange.BinaryKeywordOperators = TokenRange.FromTokens([90 /* InKeyword */, 91 /* InstanceOfKeyword */, 135 /* OfKeyword */, 116 /* AsKeyword */, 124 /* IsKeyword */]);
	                TokenRange.UnaryPrefixOperators = TokenRange.FromTokens([41 /* PlusPlusToken */, 42 /* MinusMinusToken */, 50 /* TildeToken */, 49 /* ExclamationToken */]);
	                TokenRange.UnaryPrefixExpressions = TokenRange.FromTokens([8 /* NumericLiteral */, 69 /* Identifier */, 17 /* OpenParenToken */, 19 /* OpenBracketToken */, 15 /* OpenBraceToken */, 97 /* ThisKeyword */, 92 /* NewKeyword */]);
	                TokenRange.UnaryPreincrementExpressions = TokenRange.FromTokens([69 /* Identifier */, 17 /* OpenParenToken */, 97 /* ThisKeyword */, 92 /* NewKeyword */]);
	                TokenRange.UnaryPostincrementExpressions = TokenRange.FromTokens([69 /* Identifier */, 18 /* CloseParenToken */, 20 /* CloseBracketToken */, 92 /* NewKeyword */]);
	                TokenRange.UnaryPredecrementExpressions = TokenRange.FromTokens([69 /* Identifier */, 17 /* OpenParenToken */, 97 /* ThisKeyword */, 92 /* NewKeyword */]);
	                TokenRange.UnaryPostdecrementExpressions = TokenRange.FromTokens([69 /* Identifier */, 18 /* CloseParenToken */, 20 /* CloseBracketToken */, 92 /* NewKeyword */]);
	                TokenRange.Comments = TokenRange.FromTokens([2 /* SingleLineCommentTrivia */, 3 /* MultiLineCommentTrivia */]);
	                TokenRange.TypeNames = TokenRange.FromTokens([69 /* Identifier */, 128 /* NumberKeyword */, 130 /* StringKeyword */, 120 /* BooleanKeyword */, 131 /* SymbolKeyword */, 103 /* VoidKeyword */, 117 /* AnyKeyword */]);
	                return TokenRange;
	            }());
	            Shared.TokenRange = TokenRange;
	        })(Shared = formatting.Shared || (formatting.Shared = {}));
	    })(formatting = ts.formatting || (ts.formatting = {}));
	})(ts || (ts = {}));
	///<reference path='..\services.ts' />
	///<reference path='formattingContext.ts' />
	///<reference path='formattingRequestKind.ts' />
	///<reference path='rule.ts' />
	///<reference path='ruleAction.ts' />
	///<reference path='ruleDescriptor.ts' />
	///<reference path='ruleFlag.ts' />
	///<reference path='ruleOperation.ts' />
	///<reference path='ruleOperationContext.ts' />
	///<reference path='rules.ts' />
	///<reference path='rulesMap.ts' />
	///<reference path='tokenRange.ts' /> 
	/// <reference path="references.ts"/>
	/* @internal */
	var ts;
	(function (ts) {
	    var formatting;
	    (function (formatting) {
	        var RulesProvider = (function () {
	            function RulesProvider() {
	                this.globalRules = new formatting.Rules();
	            }
	            RulesProvider.prototype.getRuleName = function (rule) {
	                return this.globalRules.getRuleName(rule);
	            };
	            RulesProvider.prototype.getRuleByName = function (name) {
	                return this.globalRules[name];
	            };
	            RulesProvider.prototype.getRulesMap = function () {
	                return this.rulesMap;
	            };
	            RulesProvider.prototype.ensureUpToDate = function (options) {
	                // TODO: Should this be '==='?
	                if (this.options == null || !ts.compareDataObjects(this.options, options)) {
	                    var activeRules = this.createActiveRules(options);
	                    var rulesMap = formatting.RulesMap.create(activeRules);
	                    this.activeRules = activeRules;
	                    this.rulesMap = rulesMap;
	                    this.options = ts.clone(options);
	                }
	            };
	            RulesProvider.prototype.createActiveRules = function (options) {
	                var rules = this.globalRules.HighPriorityCommonRules.slice(0);
	                if (options.InsertSpaceAfterCommaDelimiter) {
	                    rules.push(this.globalRules.SpaceAfterComma);
	                }
	                else {
	                    rules.push(this.globalRules.NoSpaceAfterComma);
	                }
	                if (options.InsertSpaceAfterFunctionKeywordForAnonymousFunctions) {
	                    rules.push(this.globalRules.SpaceAfterAnonymousFunctionKeyword);
	                }
	                else {
	                    rules.push(this.globalRules.NoSpaceAfterAnonymousFunctionKeyword);
	                }
	                if (options.InsertSpaceAfterKeywordsInControlFlowStatements) {
	                    rules.push(this.globalRules.SpaceAfterKeywordInControl);
	                }
	                else {
	                    rules.push(this.globalRules.NoSpaceAfterKeywordInControl);
	                }
	                if (options.InsertSpaceAfterOpeningAndBeforeClosingNonemptyParenthesis) {
	                    rules.push(this.globalRules.SpaceAfterOpenParen);
	                    rules.push(this.globalRules.SpaceBeforeCloseParen);
	                    rules.push(this.globalRules.NoSpaceBetweenParens);
	                }
	                else {
	                    rules.push(this.globalRules.NoSpaceAfterOpenParen);
	                    rules.push(this.globalRules.NoSpaceBeforeCloseParen);
	                    rules.push(this.globalRules.NoSpaceBetweenParens);
	                }
	                if (options.InsertSpaceAfterOpeningAndBeforeClosingNonemptyBrackets) {
	                    rules.push(this.globalRules.SpaceAfterOpenBracket);
	                    rules.push(this.globalRules.SpaceBeforeCloseBracket);
	                    rules.push(this.globalRules.NoSpaceBetweenBrackets);
	                }
	                else {
	                    rules.push(this.globalRules.NoSpaceAfterOpenBracket);
	                    rules.push(this.globalRules.NoSpaceBeforeCloseBracket);
	                    rules.push(this.globalRules.NoSpaceBetweenBrackets);
	                }
	                if (options.InsertSpaceAfterOpeningAndBeforeClosingTemplateStringBraces) {
	                    rules.push(this.globalRules.SpaceAfterTemplateHeadAndMiddle);
	                    rules.push(this.globalRules.SpaceBeforeTemplateMiddleAndTail);
	                }
	                else {
	                    rules.push(this.globalRules.NoSpaceAfterTemplateHeadAndMiddle);
	                    rules.push(this.globalRules.NoSpaceBeforeTemplateMiddleAndTail);
	                }
	                if (options.InsertSpaceAfterSemicolonInForStatements) {
	                    rules.push(this.globalRules.SpaceAfterSemicolonInFor);
	                }
	                else {
	                    rules.push(this.globalRules.NoSpaceAfterSemicolonInFor);
	                }
	                if (options.InsertSpaceBeforeAndAfterBinaryOperators) {
	                    rules.push(this.globalRules.SpaceBeforeBinaryOperator);
	                    rules.push(this.globalRules.SpaceAfterBinaryOperator);
	                }
	                else {
	                    rules.push(this.globalRules.NoSpaceBeforeBinaryOperator);
	                    rules.push(this.globalRules.NoSpaceAfterBinaryOperator);
	                }
	                if (options.PlaceOpenBraceOnNewLineForControlBlocks) {
	                    rules.push(this.globalRules.NewLineBeforeOpenBraceInControl);
	                }
	                if (options.PlaceOpenBraceOnNewLineForFunctions) {
	                    rules.push(this.globalRules.NewLineBeforeOpenBraceInFunction);
	                    rules.push(this.globalRules.NewLineBeforeOpenBraceInTypeScriptDeclWithBlock);
	                }
	                rules = rules.concat(this.globalRules.LowPriorityCommonRules);
	                return rules;
	            };
	            return RulesProvider;
	        }());
	        formatting.RulesProvider = RulesProvider;
	    })(formatting = ts.formatting || (ts.formatting = {}));
	})(ts || (ts = {}));
	///<reference path='..\services.ts' />
	///<reference path='formattingScanner.ts' />
	///<reference path='rulesProvider.ts' />
	///<reference path='references.ts' />
	/* @internal */
	var ts;
	(function (ts) {
	    var formatting;
	    (function (formatting) {
	        var Constants;
	        (function (Constants) {
	            Constants[Constants["Unknown"] = -1] = "Unknown";
	        })(Constants || (Constants = {}));
	        function formatOnEnter(position, sourceFile, rulesProvider, options) {
	            var line = sourceFile.getLineAndCharacterOfPosition(position).line;
	            if (line === 0) {
	                return [];
	            }
	            // get the span for the previous\current line
	            var span = {
	                // get start position for the previous line
	                pos: ts.getStartPositionOfLine(line - 1, sourceFile),
	                // get end position for the current line (end value is exclusive so add 1 to the result)
	                end: ts.getEndLinePosition(line, sourceFile) + 1
	            };
	            return formatSpan(span, sourceFile, options, rulesProvider, 2 /* FormatOnEnter */);
	        }
	        formatting.formatOnEnter = formatOnEnter;
	        function formatOnSemicolon(position, sourceFile, rulesProvider, options) {
	            return formatOutermostParent(position, 23 /* SemicolonToken */, sourceFile, options, rulesProvider, 3 /* FormatOnSemicolon */);
	        }
	        formatting.formatOnSemicolon = formatOnSemicolon;
	        function formatOnClosingCurly(position, sourceFile, rulesProvider, options) {
	            return formatOutermostParent(position, 16 /* CloseBraceToken */, sourceFile, options, rulesProvider, 4 /* FormatOnClosingCurlyBrace */);
	        }
	        formatting.formatOnClosingCurly = formatOnClosingCurly;
	        function formatDocument(sourceFile, rulesProvider, options) {
	            var span = {
	                pos: 0,
	                end: sourceFile.text.length
	            };
	            return formatSpan(span, sourceFile, options, rulesProvider, 0 /* FormatDocument */);
	        }
	        formatting.formatDocument = formatDocument;
	        function formatSelection(start, end, sourceFile, rulesProvider, options) {
	            // format from the beginning of the line
	            var span = {
	                pos: ts.getLineStartPositionForPosition(start, sourceFile),
	                end: end
	            };
	            return formatSpan(span, sourceFile, options, rulesProvider, 1 /* FormatSelection */);
	        }
	        formatting.formatSelection = formatSelection;
	        function formatOutermostParent(position, expectedLastToken, sourceFile, options, rulesProvider, requestKind) {
	            var parent = findOutermostParent(position, expectedLastToken, sourceFile);
	            if (!parent) {
	                return [];
	            }
	            var span = {
	                pos: ts.getLineStartPositionForPosition(parent.getStart(sourceFile), sourceFile),
	                end: parent.end
	            };
	            return formatSpan(span, sourceFile, options, rulesProvider, requestKind);
	        }
	        function findOutermostParent(position, expectedTokenKind, sourceFile) {
	            var precedingToken = ts.findPrecedingToken(position, sourceFile);
	            // when it is claimed that trigger character was typed at given position 
	            // we verify that there is a token with a matching kind whose end is equal to position (because the character was just typed).
	            // If this condition is not hold - then trigger character was typed in some other context, 
	            // i.e.in comment and thus should not trigger autoformatting
	            if (!precedingToken ||
	                precedingToken.kind !== expectedTokenKind ||
	                position !== precedingToken.getEnd()) {
	                return undefined;
	            }
	            // walk up and search for the parent node that ends at the same position with precedingToken.
	            // for cases like this
	            // 
	            // let x = 1;
	            // while (true) {
	            // } 
	            // after typing close curly in while statement we want to reformat just the while statement.
	            // However if we just walk upwards searching for the parent that has the same end value - 
	            // we'll end up with the whole source file. isListElement allows to stop on the list element level
	            var current = precedingToken;
	            while (current &&
	                current.parent &&
	                current.parent.end === precedingToken.end &&
	                !isListElement(current.parent, current)) {
	                current = current.parent;
	            }
	            return current;
	        }
	        // Returns true if node is a element in some list in parent
	        // i.e. parent is class declaration with the list of members and node is one of members.
	        function isListElement(parent, node) {
	            switch (parent.kind) {
	                case 217 /* ClassDeclaration */:
	                case 218 /* InterfaceDeclaration */:
	                    return ts.rangeContainsRange(parent.members, node);
	                case 221 /* ModuleDeclaration */:
	                    var body = parent.body;
	                    return body && body.kind === 195 /* Block */ && ts.rangeContainsRange(body.statements, node);
	                case 251 /* SourceFile */:
	                case 195 /* Block */:
	                case 222 /* ModuleBlock */:
	                    return ts.rangeContainsRange(parent.statements, node);
	                case 247 /* CatchClause */:
	                    return ts.rangeContainsRange(parent.block.statements, node);
	            }
	            return false;
	        }
	        /** find node that fully contains given text range */
	        function findEnclosingNode(range, sourceFile) {
	            return find(sourceFile);
	            function find(n) {
	                var candidate = ts.forEachChild(n, function (c) { return ts.startEndContainsRange(c.getStart(sourceFile), c.end, range) && c; });
	                if (candidate) {
	                    var result = find(candidate);
	                    if (result) {
	                        return result;
	                    }
	                }
	                return n;
	            }
	        }
	        /** formatting is not applied to ranges that contain parse errors.
	          * This function will return a predicate that for a given text range will tell
	          * if there are any parse errors that overlap with the range.
	          */
	        function prepareRangeContainsErrorFunction(errors, originalRange) {
	            if (!errors.length) {
	                return rangeHasNoErrors;
	            }
	            // pick only errors that fall in range
	            var sorted = errors
	                .filter(function (d) { return ts.rangeOverlapsWithStartEnd(originalRange, d.start, d.start + d.length); })
	                .sort(function (e1, e2) { return e1.start - e2.start; });
	            if (!sorted.length) {
	                return rangeHasNoErrors;
	            }
	            var index = 0;
	            return function (r) {
	                // in current implementation sequence of arguments [r1, r2...] is monotonically increasing.
	                // 'index' tracks the index of the most recent error that was checked.
	                while (true) {
	                    if (index >= sorted.length) {
	                        // all errors in the range were already checked -> no error in specified range 
	                        return false;
	                    }
	                    var error = sorted[index];
	                    if (r.end <= error.start) {
	                        // specified range ends before the error refered by 'index' - no error in range
	                        return false;
	                    }
	                    if (ts.startEndOverlapsWithStartEnd(r.pos, r.end, error.start, error.start + error.length)) {
	                        // specified range overlaps with error range
	                        return true;
	                    }
	                    index++;
	                }
	            };
	            function rangeHasNoErrors(r) {
	                return false;
	            }
	        }
	        /**
	          * Start of the original range might fall inside the comment - scanner will not yield appropriate results
	          * This function will look for token that is located before the start of target range
	          * and return its end as start position for the scanner.
	          */
	        function getScanStartPosition(enclosingNode, originalRange, sourceFile) {
	            var start = enclosingNode.getStart(sourceFile);
	            if (start === originalRange.pos && enclosingNode.end === originalRange.end) {
	                return start;
	            }
	            var precedingToken = ts.findPrecedingToken(originalRange.pos, sourceFile);
	            if (!precedingToken) {
	                // no preceding token found - start from the beginning of enclosing node
	                return enclosingNode.pos;
	            }
	            // preceding token ends after the start of original range (i.e when originaRange.pos falls in the middle of literal)
	            // start from the beginning of enclosingNode to handle the entire 'originalRange'
	            if (precedingToken.end >= originalRange.pos) {
	                return enclosingNode.pos;
	            }
	            return precedingToken.end;
	        }
	        /*
	         * For cases like
	         * if (a ||
	         *     b ||$
	         *     c) {...}
	         * If we hit Enter at $ we want line '    b ||' to be indented.
	         * Formatting will be applied to the last two lines.
	         * Node that fully encloses these lines is binary expression 'a ||...'.
	         * Initial indentation for this node will be 0.
	         * Binary expressions don't introduce new indentation scopes, however it is possible
	         * that some parent node on the same line does - like if statement in this case.
	         * Note that we are considering parents only from the same line with initial node -
	         * if parent is on the different line - its delta was already contributed
	         * to the initial indentation.
	         */
	        function getOwnOrInheritedDelta(n, options, sourceFile) {
	            var previousLine = -1 /* Unknown */;
	            var child;
	            while (n) {
	                var line = sourceFile.getLineAndCharacterOfPosition(n.getStart(sourceFile)).line;
	                if (previousLine !== -1 /* Unknown */ && line !== previousLine) {
	                    break;
	                }
	                if (formatting.SmartIndenter.shouldIndentChildNode(n, child)) {
	                    return options.IndentSize;
	                }
	                previousLine = line;
	                child = n;
	                n = n.parent;
	            }
	            return 0;
	        }
	        function formatSpan(originalRange, sourceFile, options, rulesProvider, requestKind) {
	            var rangeContainsError = prepareRangeContainsErrorFunction(sourceFile.parseDiagnostics, originalRange);
	            // formatting context is used by rules provider
	            var formattingContext = new formatting.FormattingContext(sourceFile, requestKind);
	            // find the smallest node that fully wraps the range and compute the initial indentation for the node
	            var enclosingNode = findEnclosingNode(originalRange, sourceFile);
	            var formattingScanner = formatting.getFormattingScanner(sourceFile, getScanStartPosition(enclosingNode, originalRange, sourceFile), originalRange.end);
	            var initialIndentation = formatting.SmartIndenter.getIndentationForNode(enclosingNode, originalRange, sourceFile, options);
	            var previousRangeHasError;
	            var previousRange;
	            var previousParent;
	            var previousRangeStartLine;
	            var lastIndentedLine;
	            var indentationOnLastIndentedLine;
	            var edits = [];
	            formattingScanner.advance();
	            if (formattingScanner.isOnToken()) {
	                var startLine = sourceFile.getLineAndCharacterOfPosition(enclosingNode.getStart(sourceFile)).line;
	                var undecoratedStartLine = startLine;
	                if (enclosingNode.decorators) {
	                    undecoratedStartLine = sourceFile.getLineAndCharacterOfPosition(ts.getNonDecoratorTokenPosOfNode(enclosingNode, sourceFile)).line;
	                }
	                var delta = getOwnOrInheritedDelta(enclosingNode, options, sourceFile);
	                processNode(enclosingNode, enclosingNode, startLine, undecoratedStartLine, initialIndentation, delta);
	            }
	            if (!formattingScanner.isOnToken()) {
	                var leadingTrivia = formattingScanner.getCurrentLeadingTrivia();
	                if (leadingTrivia) {
	                    processTrivia(leadingTrivia, enclosingNode, enclosingNode, undefined);
	                    trimTrailingWhitespacesForRemainingRange();
	                }
	            }
	            formattingScanner.close();
	            return edits;
	            // local functions
	            /** Tries to compute the indentation for a list element.
	              * If list element is not in range then
	              * function will pick its actual indentation
	              * so it can be pushed downstream as inherited indentation.
	              * If list element is in the range - its indentation will be equal
	              * to inherited indentation from its predecessors.
	              */
	            function tryComputeIndentationForListItem(startPos, endPos, parentStartLine, range, inheritedIndentation) {
	                if (ts.rangeOverlapsWithStartEnd(range, startPos, endPos) ||
	                    ts.rangeContainsStartEnd(range, startPos, endPos) /* Not to miss zero-range nodes e.g. JsxText */) {
	                    if (inheritedIndentation !== -1 /* Unknown */) {
	                        return inheritedIndentation;
	                    }
	                }
	                else {
	                    var startLine = sourceFile.getLineAndCharacterOfPosition(startPos).line;
	                    var startLinePosition = ts.getLineStartPositionForPosition(startPos, sourceFile);
	                    var column = formatting.SmartIndenter.findFirstNonWhitespaceColumn(startLinePosition, startPos, sourceFile, options);
	                    if (startLine !== parentStartLine || startPos === column) {
	                        return column;
	                    }
	                }
	                return -1 /* Unknown */;
	            }
	            function computeIndentation(node, startLine, inheritedIndentation, parent, parentDynamicIndentation, effectiveParentStartLine) {
	                var indentation = inheritedIndentation;
	                var delta = formatting.SmartIndenter.shouldIndentChildNode(node) ? options.IndentSize : 0;
	                if (effectiveParentStartLine === startLine) {
	                    // if node is located on the same line with the parent
	                    // - inherit indentation from the parent
	                    // - push children if either parent of node itself has non-zero delta
	                    indentation = startLine === lastIndentedLine
	                        ? indentationOnLastIndentedLine
	                        : parentDynamicIndentation.getIndentation();
	                    delta = Math.min(options.IndentSize, parentDynamicIndentation.getDelta(node) + delta);
	                }
	                else if (indentation === -1 /* Unknown */) {
	                    if (formatting.SmartIndenter.childStartsOnTheSameLineWithElseInIfStatement(parent, node, startLine, sourceFile)) {
	                        indentation = parentDynamicIndentation.getIndentation();
	                    }
	                    else {
	                        indentation = parentDynamicIndentation.getIndentation() + parentDynamicIndentation.getDelta(node);
	                    }
	                }
	                return {
	                    indentation: indentation,
	                    delta: delta
	                };
	            }
	            function getFirstNonDecoratorTokenOfNode(node) {
	                if (node.modifiers && node.modifiers.length) {
	                    return node.modifiers[0].kind;
	                }
	                switch (node.kind) {
	                    case 217 /* ClassDeclaration */: return 73 /* ClassKeyword */;
	                    case 218 /* InterfaceDeclaration */: return 107 /* InterfaceKeyword */;
	                    case 216 /* FunctionDeclaration */: return 87 /* FunctionKeyword */;
	                    case 220 /* EnumDeclaration */: return 220 /* EnumDeclaration */;
	                    case 146 /* GetAccessor */: return 123 /* GetKeyword */;
	                    case 147 /* SetAccessor */: return 129 /* SetKeyword */;
	                    case 144 /* MethodDeclaration */:
	                        if (node.asteriskToken) {
	                            return 37 /* AsteriskToken */;
	                        }
	                    // fall-through
	                    case 142 /* PropertyDeclaration */:
	                    case 139 /* Parameter */:
	                        return node.name.kind;
	                }
	            }
	            function getDynamicIndentation(node, nodeStartLine, indentation, delta) {
	                return {
	                    getIndentationForComment: function (kind, tokenIndentation, container) {
	                        switch (kind) {
	                            // preceding comment to the token that closes the indentation scope inherits the indentation from the scope
	                            // ..  {
	                            //     // comment
	                            // }
	                            case 16 /* CloseBraceToken */:
	                            case 20 /* CloseBracketToken */:
	                            case 18 /* CloseParenToken */:
	                                return indentation + getEffectiveDelta(delta, container);
	                        }
	                        return tokenIndentation !== -1 /* Unknown */ ? tokenIndentation : indentation;
	                    },
	                    getIndentationForToken: function (line, kind, container) {
	                        if (nodeStartLine !== line && node.decorators) {
	                            if (kind === getFirstNonDecoratorTokenOfNode(node)) {
	                                // if this token is the first token following the list of decorators, we do not need to indent
	                                return indentation;
	                            }
	                        }
	                        switch (kind) {
	                            // open and close brace, 'else' and 'while' (in do statement) tokens has indentation of the parent
	                            case 15 /* OpenBraceToken */:
	                            case 16 /* CloseBraceToken */:
	                            case 19 /* OpenBracketToken */:
	                            case 20 /* CloseBracketToken */:
	                            case 17 /* OpenParenToken */:
	                            case 18 /* CloseParenToken */:
	                            case 80 /* ElseKeyword */:
	                            case 104 /* WhileKeyword */:
	                            case 55 /* AtToken */:
	                                return indentation;
	                            default:
	                                // if token line equals to the line of containing node (this is a first token in the node) - use node indentation
	                                return nodeStartLine !== line ? indentation + getEffectiveDelta(delta, container) : indentation;
	                        }
	                    },
	                    getIndentation: function () { return indentation; },
	                    getDelta: function (child) { return getEffectiveDelta(delta, child); },
	                    recomputeIndentation: function (lineAdded) {
	                        if (node.parent && formatting.SmartIndenter.shouldIndentChildNode(node.parent, node)) {
	                            if (lineAdded) {
	                                indentation += options.IndentSize;
	                            }
	                            else {
	                                indentation -= options.IndentSize;
	                            }
	                            if (formatting.SmartIndenter.shouldIndentChildNode(node)) {
	                                delta = options.IndentSize;
	                            }
	                            else {
	                                delta = 0;
	                            }
	                        }
	                    }
	                };
	                function getEffectiveDelta(delta, child) {
	                    // Delta value should be zero when the node explicitly prevents indentation of the child node
	                    return formatting.SmartIndenter.nodeWillIndentChild(node, child, true) ? delta : 0;
	                }
	            }
	            function processNode(node, contextNode, nodeStartLine, undecoratedNodeStartLine, indentation, delta) {
	                if (!ts.rangeOverlapsWithStartEnd(originalRange, node.getStart(sourceFile), node.getEnd())) {
	                    return;
	                }
	                var nodeDynamicIndentation = getDynamicIndentation(node, nodeStartLine, indentation, delta);
	                // a useful observations when tracking context node
	                //        /
	                //      [a]
	                //   /   |   \ 
	                //  [b] [c] [d]
	                // node 'a' is a context node for nodes 'b', 'c', 'd' 
	                // except for the leftmost leaf token in [b] - in this case context node ('e') is located somewhere above 'a'
	                // this rule can be applied recursively to child nodes of 'a'.
	                // 
	                // context node is set to parent node value after processing every child node
	                // context node is set to parent of the token after processing every token
	                var childContextNode = contextNode;
	                // if there are any tokens that logically belong to node and interleave child nodes
	                // such tokens will be consumed in processChildNode for for the child that follows them
	                ts.forEachChild(node, function (child) {
	                    processChildNode(child, /*inheritedIndentation*/ -1 /* Unknown */, node, nodeDynamicIndentation, nodeStartLine, undecoratedNodeStartLine, /*isListElement*/ false);
	                }, function (nodes) {
	                    processChildNodes(nodes, node, nodeStartLine, nodeDynamicIndentation);
	                });
	                // proceed any tokens in the node that are located after child nodes
	                while (formattingScanner.isOnToken()) {
	                    var tokenInfo = formattingScanner.readTokenInfo(node);
	                    if (tokenInfo.token.end > node.end) {
	                        break;
	                    }
	                    consumeTokenAndAdvanceScanner(tokenInfo, node, nodeDynamicIndentation);
	                }
	                function processChildNode(child, inheritedIndentation, parent, parentDynamicIndentation, parentStartLine, undecoratedParentStartLine, isListItem) {
	                    var childStartPos = child.getStart(sourceFile);
	                    var childStartLine = sourceFile.getLineAndCharacterOfPosition(childStartPos).line;
	                    var undecoratedChildStartLine = childStartLine;
	                    if (child.decorators) {
	                        undecoratedChildStartLine = sourceFile.getLineAndCharacterOfPosition(ts.getNonDecoratorTokenPosOfNode(child, sourceFile)).line;
	                    }
	                    // if child is a list item - try to get its indentation
	                    var childIndentationAmount = -1 /* Unknown */;
	                    if (isListItem) {
	                        childIndentationAmount = tryComputeIndentationForListItem(childStartPos, child.end, parentStartLine, originalRange, inheritedIndentation);
	                        if (childIndentationAmount !== -1 /* Unknown */) {
	                            inheritedIndentation = childIndentationAmount;
	                        }
	                    }
	                    // child node is outside the target range - do not dive inside
	                    if (!ts.rangeOverlapsWithStartEnd(originalRange, child.pos, child.end)) {
	                        return inheritedIndentation;
	                    }
	                    if (child.getFullWidth() === 0) {
	                        return inheritedIndentation;
	                    }
	                    while (formattingScanner.isOnToken()) {
	                        // proceed any parent tokens that are located prior to child.getStart()
	                        var tokenInfo = formattingScanner.readTokenInfo(node);
	                        if (tokenInfo.token.end > childStartPos) {
	                            // stop when formatting scanner advances past the beginning of the child
	                            break;
	                        }
	                        consumeTokenAndAdvanceScanner(tokenInfo, node, parentDynamicIndentation);
	                    }
	                    if (!formattingScanner.isOnToken()) {
	                        return inheritedIndentation;
	                    }
	                    if (ts.isToken(child)) {
	                        // if child node is a token, it does not impact indentation, proceed it using parent indentation scope rules
	                        var tokenInfo = formattingScanner.readTokenInfo(child);
	                        ts.Debug.assert(tokenInfo.token.end === child.end);
	                        consumeTokenAndAdvanceScanner(tokenInfo, node, parentDynamicIndentation, child);
	                        return inheritedIndentation;
	                    }
	                    var effectiveParentStartLine = child.kind === 140 /* Decorator */ ? childStartLine : undecoratedParentStartLine;
	                    var childIndentation = computeIndentation(child, childStartLine, childIndentationAmount, node, parentDynamicIndentation, effectiveParentStartLine);
	                    processNode(child, childContextNode, childStartLine, undecoratedChildStartLine, childIndentation.indentation, childIndentation.delta);
	                    childContextNode = node;
	                    return inheritedIndentation;
	                }
	                function processChildNodes(nodes, parent, parentStartLine, parentDynamicIndentation) {
	                    var listStartToken = getOpenTokenForList(parent, nodes);
	                    var listEndToken = getCloseTokenForOpenToken(listStartToken);
	                    var listDynamicIndentation = parentDynamicIndentation;
	                    var startLine = parentStartLine;
	                    if (listStartToken !== 0 /* Unknown */) {
	                        // introduce a new indentation scope for lists (including list start and end tokens)
	                        while (formattingScanner.isOnToken()) {
	                            var tokenInfo = formattingScanner.readTokenInfo(parent);
	                            if (tokenInfo.token.end > nodes.pos) {
	                                // stop when formatting scanner moves past the beginning of node list
	                                break;
	                            }
	                            else if (tokenInfo.token.kind === listStartToken) {
	                                // consume list start token
	                                startLine = sourceFile.getLineAndCharacterOfPosition(tokenInfo.token.pos).line;
	                                var indentation_1 = computeIndentation(tokenInfo.token, startLine, -1 /* Unknown */, parent, parentDynamicIndentation, parentStartLine);
	                                listDynamicIndentation = getDynamicIndentation(parent, parentStartLine, indentation_1.indentation, indentation_1.delta);
	                                consumeTokenAndAdvanceScanner(tokenInfo, parent, listDynamicIndentation);
	                            }
	                            else {
	                                // consume any tokens that precede the list as child elements of 'node' using its indentation scope
	                                consumeTokenAndAdvanceScanner(tokenInfo, parent, parentDynamicIndentation);
	                            }
	                        }
	                    }
	                    var inheritedIndentation = -1 /* Unknown */;
	                    for (var _i = 0, nodes_6 = nodes; _i < nodes_6.length; _i++) {
	                        var child = nodes_6[_i];
	                        inheritedIndentation = processChildNode(child, inheritedIndentation, node, listDynamicIndentation, startLine, startLine, /*isListElement*/ true);
	                    }
	                    if (listEndToken !== 0 /* Unknown */) {
	                        if (formattingScanner.isOnToken()) {
	                            var tokenInfo = formattingScanner.readTokenInfo(parent);
	                            // consume the list end token only if it is still belong to the parent
	                            // there might be the case when current token matches end token but does not considered as one
	                            // function (x: function) <-- 
	                            // without this check close paren will be interpreted as list end token for function expression which is wrong
	                            if (tokenInfo.token.kind === listEndToken && ts.rangeContainsRange(parent, tokenInfo.token)) {
	                                // consume list end token
	                                consumeTokenAndAdvanceScanner(tokenInfo, parent, listDynamicIndentation);
	                            }
	                        }
	                    }
	                }
	                function consumeTokenAndAdvanceScanner(currentTokenInfo, parent, dynamicIndentation, container) {
	                    ts.Debug.assert(ts.rangeContainsRange(parent, currentTokenInfo.token));
	                    var lastTriviaWasNewLine = formattingScanner.lastTrailingTriviaWasNewLine();
	                    var indentToken = false;
	                    if (currentTokenInfo.leadingTrivia) {
	                        processTrivia(currentTokenInfo.leadingTrivia, parent, childContextNode, dynamicIndentation);
	                    }
	                    var lineAdded;
	                    var isTokenInRange = ts.rangeContainsRange(originalRange, currentTokenInfo.token);
	                    var tokenStart = sourceFile.getLineAndCharacterOfPosition(currentTokenInfo.token.pos);
	                    if (isTokenInRange) {
	                        var rangeHasError = rangeContainsError(currentTokenInfo.token);
	                        // save previousRange since processRange will overwrite this value with current one
	                        var savePreviousRange = previousRange;
	                        lineAdded = processRange(currentTokenInfo.token, tokenStart, parent, childContextNode, dynamicIndentation);
	                        if (rangeHasError) {
	                            // do not indent comments\token if token range overlaps with some error
	                            indentToken = false;
	                        }
	                        else {
	                            if (lineAdded !== undefined) {
	                                indentToken = lineAdded;
	                            }
	                            else {
	                                // indent token only if end line of previous range does not match start line of the token
	                                var prevEndLine = savePreviousRange && sourceFile.getLineAndCharacterOfPosition(savePreviousRange.end).line;
	                                indentToken = lastTriviaWasNewLine && tokenStart.line !== prevEndLine;
	                            }
	                        }
	                    }
	                    if (currentTokenInfo.trailingTrivia) {
	                        processTrivia(currentTokenInfo.trailingTrivia, parent, childContextNode, dynamicIndentation);
	                    }
	                    if (indentToken) {
	                        var tokenIndentation = (isTokenInRange && !rangeContainsError(currentTokenInfo.token)) ?
	                            dynamicIndentation.getIndentationForToken(tokenStart.line, currentTokenInfo.token.kind, container) :
	                            -1 /* Unknown */;
	                        if (currentTokenInfo.leadingTrivia) {
	                            var commentIndentation = dynamicIndentation.getIndentationForComment(currentTokenInfo.token.kind, tokenIndentation, container);
	                            var indentNextTokenOrTrivia = true;
	                            for (var _i = 0, _a = currentTokenInfo.leadingTrivia; _i < _a.length; _i++) {
	                                var triviaItem = _a[_i];
	                                if (!ts.rangeContainsRange(originalRange, triviaItem)) {
	                                    continue;
	                                }
	                                switch (triviaItem.kind) {
	                                    case 3 /* MultiLineCommentTrivia */:
	                                        indentMultilineComment(triviaItem, commentIndentation, /*firstLineIsIndented*/ !indentNextTokenOrTrivia);
	                                        indentNextTokenOrTrivia = false;
	                                        break;
	                                    case 2 /* SingleLineCommentTrivia */:
	                                        if (indentNextTokenOrTrivia) {
	                                            insertIndentation(triviaItem.pos, commentIndentation, /*lineAdded*/ false);
	                                            indentNextTokenOrTrivia = false;
	                                        }
	                                        break;
	                                    case 4 /* NewLineTrivia */:
	                                        indentNextTokenOrTrivia = true;
	                                        break;
	                                }
	                            }
	                        }
	                        // indent token only if is it is in target range and does not overlap with any error ranges
	                        if (tokenIndentation !== -1 /* Unknown */) {
	                            insertIndentation(currentTokenInfo.token.pos, tokenIndentation, lineAdded);
	                            lastIndentedLine = tokenStart.line;
	                            indentationOnLastIndentedLine = tokenIndentation;
	                        }
	                    }
	                    formattingScanner.advance();
	                    childContextNode = parent;
	                }
	            }
	            function processTrivia(trivia, parent, contextNode, dynamicIndentation) {
	                for (var _i = 0, trivia_1 = trivia; _i < trivia_1.length; _i++) {
	                    var triviaItem = trivia_1[_i];
	                    if (ts.isComment(triviaItem.kind) && ts.rangeContainsRange(originalRange, triviaItem)) {
	                        var triviaItemStart = sourceFile.getLineAndCharacterOfPosition(triviaItem.pos);
	                        processRange(triviaItem, triviaItemStart, parent, contextNode, dynamicIndentation);
	                    }
	                }
	            }
	            function processRange(range, rangeStart, parent, contextNode, dynamicIndentation) {
	                var rangeHasError = rangeContainsError(range);
	                var lineAdded;
	                if (!rangeHasError && !previousRangeHasError) {
	                    if (!previousRange) {
	                        // trim whitespaces starting from the beginning of the span up to the current line
	                        var originalStart = sourceFile.getLineAndCharacterOfPosition(originalRange.pos);
	                        trimTrailingWhitespacesForLines(originalStart.line, rangeStart.line);
	                    }
	                    else {
	                        lineAdded =
	                            processPair(range, rangeStart.line, parent, previousRange, previousRangeStartLine, previousParent, contextNode, dynamicIndentation);
	                    }
	                }
	                previousRange = range;
	                previousParent = parent;
	                previousRangeStartLine = rangeStart.line;
	                previousRangeHasError = rangeHasError;
	                return lineAdded;
	            }
	            function processPair(currentItem, currentStartLine, currentParent, previousItem, previousStartLine, previousParent, contextNode, dynamicIndentation) {
	                formattingContext.updateContext(previousItem, previousParent, currentItem, currentParent, contextNode);
	                var rule = rulesProvider.getRulesMap().GetRule(formattingContext);
	                var trimTrailingWhitespaces;
	                var lineAdded;
	                if (rule) {
	                    applyRuleEdits(rule, previousItem, previousStartLine, currentItem, currentStartLine);
	                    if (rule.Operation.Action & (2 /* Space */ | 8 /* Delete */) && currentStartLine !== previousStartLine) {
	                        lineAdded = false;
	                        // Handle the case where the next line is moved to be the end of this line. 
	                        // In this case we don't indent the next line in the next pass.
	                        if (currentParent.getStart(sourceFile) === currentItem.pos) {
	                            dynamicIndentation.recomputeIndentation(/*lineAdded*/ false);
	                        }
	                    }
	                    else if (rule.Operation.Action & 4 /* NewLine */ && currentStartLine === previousStartLine) {
	                        lineAdded = true;
	                        // Handle the case where token2 is moved to the new line. 
	                        // In this case we indent token2 in the next pass but we set
	                        // sameLineIndent flag to notify the indenter that the indentation is within the line.
	                        if (currentParent.getStart(sourceFile) === currentItem.pos) {
	                            dynamicIndentation.recomputeIndentation(/*lineAdded*/ true);
	                        }
	                    }
	                    // We need to trim trailing whitespace between the tokens if they were on different lines, and no rule was applied to put them on the same line
	                    trimTrailingWhitespaces = !(rule.Operation.Action & 8 /* Delete */) && rule.Flag !== 1 /* CanDeleteNewLines */;
	                }
	                else {
	                    trimTrailingWhitespaces = true;
	                }
	                if (currentStartLine !== previousStartLine && trimTrailingWhitespaces) {
	                    // We need to trim trailing whitespace between the tokens if they were on different lines, and no rule was applied to put them on the same line
	                    trimTrailingWhitespacesForLines(previousStartLine, currentStartLine, previousItem);
	                }
	                return lineAdded;
	            }
	            function insertIndentation(pos, indentation, lineAdded) {
	                var indentationString = getIndentationString(indentation, options);
	                if (lineAdded) {
	                    // new line is added before the token by the formatting rules
	                    // insert indentation string at the very beginning of the token
	                    recordReplace(pos, 0, indentationString);
	                }
	                else {
	                    var tokenStart = sourceFile.getLineAndCharacterOfPosition(pos);
	                    if (indentation !== tokenStart.character) {
	                        var startLinePosition = ts.getStartPositionOfLine(tokenStart.line, sourceFile);
	                        recordReplace(startLinePosition, tokenStart.character, indentationString);
	                    }
	                }
	            }
	            function indentMultilineComment(commentRange, indentation, firstLineIsIndented) {
	                // split comment in lines
	                var startLine = sourceFile.getLineAndCharacterOfPosition(commentRange.pos).line;
	                var endLine = sourceFile.getLineAndCharacterOfPosition(commentRange.end).line;
	                var parts;
	                if (startLine === endLine) {
	                    if (!firstLineIsIndented) {
	                        // treat as single line comment
	                        insertIndentation(commentRange.pos, indentation, /*lineAdded*/ false);
	                    }
	                    return;
	                }
	                else {
	                    parts = [];
	                    var startPos = commentRange.pos;
	                    for (var line = startLine; line < endLine; ++line) {
	                        var endOfLine = ts.getEndLinePosition(line, sourceFile);
	                        parts.push({ pos: startPos, end: endOfLine });
	                        startPos = ts.getStartPositionOfLine(line + 1, sourceFile);
	                    }
	                    parts.push({ pos: startPos, end: commentRange.end });
	                }
	                var startLinePos = ts.getStartPositionOfLine(startLine, sourceFile);
	                var nonWhitespaceColumnInFirstPart = formatting.SmartIndenter.findFirstNonWhitespaceCharacterAndColumn(startLinePos, parts[0].pos, sourceFile, options);
	                if (indentation === nonWhitespaceColumnInFirstPart.column) {
	                    return;
	                }
	                var startIndex = 0;
	                if (firstLineIsIndented) {
	                    startIndex = 1;
	                    startLine++;
	                }
	                // shift all parts on the delta size
	                var delta = indentation - nonWhitespaceColumnInFirstPart.column;
	                for (var i = startIndex, len = parts.length; i < len; ++i, ++startLine) {
	                    var startLinePos_1 = ts.getStartPositionOfLine(startLine, sourceFile);
	                    var nonWhitespaceCharacterAndColumn = i === 0
	                        ? nonWhitespaceColumnInFirstPart
	                        : formatting.SmartIndenter.findFirstNonWhitespaceCharacterAndColumn(parts[i].pos, parts[i].end, sourceFile, options);
	                    var newIndentation = nonWhitespaceCharacterAndColumn.column + delta;
	                    if (newIndentation > 0) {
	                        var indentationString = getIndentationString(newIndentation, options);
	                        recordReplace(startLinePos_1, nonWhitespaceCharacterAndColumn.character, indentationString);
	                    }
	                    else {
	                        recordDelete(startLinePos_1, nonWhitespaceCharacterAndColumn.character);
	                    }
	                }
	            }
	            function trimTrailingWhitespacesForLines(line1, line2, range) {
	                for (var line = line1; line < line2; ++line) {
	                    var lineStartPosition = ts.getStartPositionOfLine(line, sourceFile);
	                    var lineEndPosition = ts.getEndLinePosition(line, sourceFile);
	                    // do not trim whitespaces in comments or template expression
	                    if (range && (ts.isComment(range.kind) || ts.isStringOrRegularExpressionOrTemplateLiteral(range.kind)) && range.pos <= lineEndPosition && range.end > lineEndPosition) {
	                        continue;
	                    }
	                    var whitespaceStart = getTrailingWhitespaceStartPosition(lineStartPosition, lineEndPosition);
	                    if (whitespaceStart !== -1) {
	                        ts.Debug.assert(whitespaceStart === lineStartPosition || !ts.isWhiteSpace(sourceFile.text.charCodeAt(whitespaceStart - 1)));
	                        recordDelete(whitespaceStart, lineEndPosition + 1 - whitespaceStart);
	                    }
	                }
	            }
	            /**
	             * @param start The position of the first character in range
	             * @param end The position of the last character in range
	             */
	            function getTrailingWhitespaceStartPosition(start, end) {
	                var pos = end;
	                while (pos >= start && ts.isWhiteSpace(sourceFile.text.charCodeAt(pos))) {
	                    pos--;
	                }
	                if (pos !== end) {
	                    return pos + 1;
	                }
	                return -1;
	            }
	            /**
	             * Trimming will be done for lines after the previous range
	             */
	            function trimTrailingWhitespacesForRemainingRange() {
	                var startPosition = previousRange ? previousRange.end : originalRange.pos;
	                var startLine = sourceFile.getLineAndCharacterOfPosition(startPosition).line;
	                var endLine = sourceFile.getLineAndCharacterOfPosition(originalRange.end).line;
	                trimTrailingWhitespacesForLines(startLine, endLine + 1, previousRange);
	            }
	            function newTextChange(start, len, newText) {
	                return { span: ts.createTextSpan(start, len), newText: newText };
	            }
	            function recordDelete(start, len) {
	                if (len) {
	                    edits.push(newTextChange(start, len, ""));
	                }
	            }
	            function recordReplace(start, len, newText) {
	                if (len || newText) {
	                    edits.push(newTextChange(start, len, newText));
	                }
	            }
	            function applyRuleEdits(rule, previousRange, previousStartLine, currentRange, currentStartLine) {
	                var between;
	                switch (rule.Operation.Action) {
	                    case 1 /* Ignore */:
	                        // no action required
	                        return;
	                    case 8 /* Delete */:
	                        if (previousRange.end !== currentRange.pos) {
	                            // delete characters starting from t1.end up to t2.pos exclusive
	                            recordDelete(previousRange.end, currentRange.pos - previousRange.end);
	                        }
	                        break;
	                    case 4 /* NewLine */:
	                        // exit early if we on different lines and rule cannot change number of newlines
	                        // if line1 and line2 are on subsequent lines then no edits are required - ok to exit
	                        // if line1 and line2 are separated with more than one newline - ok to exit since we cannot delete extra new lines
	                        if (rule.Flag !== 1 /* CanDeleteNewLines */ && previousStartLine !== currentStartLine) {
	                            return;
	                        }
	                        // edit should not be applied only if we have one line feed between elements
	                        var lineDelta = currentStartLine - previousStartLine;
	                        if (lineDelta !== 1) {
	                            recordReplace(previousRange.end, currentRange.pos - previousRange.end, options.NewLineCharacter);
	                        }
	                        break;
	                    case 2 /* Space */:
	                        // exit early if we on different lines and rule cannot change number of newlines
	                        if (rule.Flag !== 1 /* CanDeleteNewLines */ && previousStartLine !== currentStartLine) {
	                            return;
	                        }
	                        var posDelta = currentRange.pos - previousRange.end;
	                        if (posDelta !== 1 || sourceFile.text.charCodeAt(previousRange.end) !== 32 /* space */) {
	                            recordReplace(previousRange.end, currentRange.pos - previousRange.end, " ");
	                        }
	                        break;
	                }
	            }
	        }
	        function isSomeBlock(kind) {
	            switch (kind) {
	                case 195 /* Block */:
	                case 222 /* ModuleBlock */:
	                    return true;
	            }
	            return false;
	        }
	        function getOpenTokenForList(node, list) {
	            switch (node.kind) {
	                case 145 /* Constructor */:
	                case 216 /* FunctionDeclaration */:
	                case 176 /* FunctionExpression */:
	                case 144 /* MethodDeclaration */:
	                case 143 /* MethodSignature */:
	                case 177 /* ArrowFunction */:
	                    if (node.typeParameters === list) {
	                        return 25 /* LessThanToken */;
	                    }
	                    else if (node.parameters === list) {
	                        return 17 /* OpenParenToken */;
	                    }
	                    break;
	                case 171 /* CallExpression */:
	                case 172 /* NewExpression */:
	                    if (node.typeArguments === list) {
	                        return 25 /* LessThanToken */;
	                    }
	                    else if (node.arguments === list) {
	                        return 17 /* OpenParenToken */;
	                    }
	                    break;
	                case 152 /* TypeReference */:
	                    if (node.typeArguments === list) {
	                        return 25 /* LessThanToken */;
	                    }
	            }
	            return 0 /* Unknown */;
	        }
	        function getCloseTokenForOpenToken(kind) {
	            switch (kind) {
	                case 17 /* OpenParenToken */:
	                    return 18 /* CloseParenToken */;
	                case 25 /* LessThanToken */:
	                    return 27 /* GreaterThanToken */;
	            }
	            return 0 /* Unknown */;
	        }
	        var internedSizes;
	        var internedTabsIndentation;
	        var internedSpacesIndentation;
	        function getIndentationString(indentation, options) {
	            // reset interned strings if FormatCodeOptions were changed
	            var resetInternedStrings = !internedSizes || (internedSizes.tabSize !== options.TabSize || internedSizes.indentSize !== options.IndentSize);
	            if (resetInternedStrings) {
	                internedSizes = { tabSize: options.TabSize, indentSize: options.IndentSize };
	                internedTabsIndentation = internedSpacesIndentation = undefined;
	            }
	            if (!options.ConvertTabsToSpaces) {
	                var tabs = Math.floor(indentation / options.TabSize);
	                var spaces = indentation - tabs * options.TabSize;
	                var tabString = void 0;
	                if (!internedTabsIndentation) {
	                    internedTabsIndentation = [];
	                }
	                if (internedTabsIndentation[tabs] === undefined) {
	                    internedTabsIndentation[tabs] = tabString = repeat('\t', tabs);
	                }
	                else {
	                    tabString = internedTabsIndentation[tabs];
	                }
	                return spaces ? tabString + repeat(" ", spaces) : tabString;
	            }
	            else {
	                var spacesString = void 0;
	                var quotient = Math.floor(indentation / options.IndentSize);
	                var remainder = indentation % options.IndentSize;
	                if (!internedSpacesIndentation) {
	                    internedSpacesIndentation = [];
	                }
	                if (internedSpacesIndentation[quotient] === undefined) {
	                    spacesString = repeat(" ", options.IndentSize * quotient);
	                    internedSpacesIndentation[quotient] = spacesString;
	                }
	                else {
	                    spacesString = internedSpacesIndentation[quotient];
	                }
	                return remainder ? spacesString + repeat(" ", remainder) : spacesString;
	            }
	            function repeat(value, count) {
	                var s = "";
	                for (var i = 0; i < count; ++i) {
	                    s += value;
	                }
	                return s;
	            }
	        }
	        formatting.getIndentationString = getIndentationString;
	    })(formatting = ts.formatting || (ts.formatting = {}));
	})(ts || (ts = {}));
	///<reference path='..\services.ts' />
	/* @internal */
	var ts;
	(function (ts) {
	    var formatting;
	    (function (formatting) {
	        var SmartIndenter;
	        (function (SmartIndenter) {
	            var Value;
	            (function (Value) {
	                Value[Value["Unknown"] = -1] = "Unknown";
	            })(Value || (Value = {}));
	            function getIndentation(position, sourceFile, options) {
	                if (position > sourceFile.text.length) {
	                    return 0; // past EOF
	                }
	                // no indentation when the indent style is set to none,
	                // so we can return fast
	                if (options.IndentStyle === ts.IndentStyle.None) {
	                    return 0;
	                }
	                var precedingToken = ts.findPrecedingToken(position, sourceFile);
	                if (!precedingToken) {
	                    return 0;
	                }
	                // no indentation in string \regex\template literals
	                var precedingTokenIsLiteral = ts.isStringOrRegularExpressionOrTemplateLiteral(precedingToken.kind);
	                if (precedingTokenIsLiteral && precedingToken.getStart(sourceFile) <= position && precedingToken.end > position) {
	                    return 0;
	                }
	                var lineAtPosition = sourceFile.getLineAndCharacterOfPosition(position).line;
	                // indentation is first non-whitespace character in a previous line
	                // for block indentation, we should look for a line which contains something that's not
	                // whitespace.
	                if (options.IndentStyle === ts.IndentStyle.Block) {
	                    // move backwards until we find a line with a non-whitespace character,
	                    // then find the first non-whitespace character for that line.
	                    var current_1 = position;
	                    while (current_1 > 0) {
	                        var char = sourceFile.text.charCodeAt(current_1);
	                        if (!ts.isWhiteSpace(char) && !ts.isLineBreak(char)) {
	                            break;
	                        }
	                        current_1--;
	                    }
	                    var lineStart = ts.getLineStartPositionForPosition(current_1, sourceFile);
	                    return SmartIndenter.findFirstNonWhitespaceColumn(lineStart, current_1, sourceFile, options);
	                }
	                if (precedingToken.kind === 24 /* CommaToken */ && precedingToken.parent.kind !== 184 /* BinaryExpression */) {
	                    // previous token is comma that separates items in list - find the previous item and try to derive indentation from it
	                    var actualIndentation = getActualIndentationForListItemBeforeComma(precedingToken, sourceFile, options);
	                    if (actualIndentation !== -1 /* Unknown */) {
	                        return actualIndentation;
	                    }
	                }
	                // try to find node that can contribute to indentation and includes 'position' starting from 'precedingToken'
	                // if such node is found - compute initial indentation for 'position' inside this node
	                var previous;
	                var current = precedingToken;
	                var currentStart;
	                var indentationDelta;
	                while (current) {
	                    if (ts.positionBelongsToNode(current, position, sourceFile) && shouldIndentChildNode(current, previous)) {
	                        currentStart = getStartLineAndCharacterForNode(current, sourceFile);
	                        if (nextTokenIsCurlyBraceOnSameLineAsCursor(precedingToken, current, lineAtPosition, sourceFile)) {
	                            indentationDelta = 0;
	                        }
	                        else {
	                            indentationDelta = lineAtPosition !== currentStart.line ? options.IndentSize : 0;
	                        }
	                        break;
	                    }
	                    // check if current node is a list item - if yes, take indentation from it
	                    var actualIndentation = getActualIndentationForListItem(current, sourceFile, options);
	                    if (actualIndentation !== -1 /* Unknown */) {
	                        return actualIndentation;
	                    }
	                    actualIndentation = getLineIndentationWhenExpressionIsInMultiLine(current, sourceFile, options);
	                    if (actualIndentation !== -1 /* Unknown */) {
	                        return actualIndentation + options.IndentSize;
	                    }
	                    previous = current;
	                    current = current.parent;
	                }
	                if (!current) {
	                    // no parent was found - return 0 to be indented on the level of SourceFile
	                    return 0;
	                }
	                return getIndentationForNodeWorker(current, currentStart, /*ignoreActualIndentationRange*/ undefined, indentationDelta, sourceFile, options);
	            }
	            SmartIndenter.getIndentation = getIndentation;
	            function getIndentationForNode(n, ignoreActualIndentationRange, sourceFile, options) {
	                var start = sourceFile.getLineAndCharacterOfPosition(n.getStart(sourceFile));
	                return getIndentationForNodeWorker(n, start, ignoreActualIndentationRange, /*indentationDelta*/ 0, sourceFile, options);
	            }
	            SmartIndenter.getIndentationForNode = getIndentationForNode;
	            function getIndentationForNodeWorker(current, currentStart, ignoreActualIndentationRange, indentationDelta, sourceFile, options) {
	                var parent = current.parent;
	                var parentStart;
	                // walk upwards and collect indentations for pairs of parent-child nodes
	                // indentation is not added if parent and child nodes start on the same line or if parent is IfStatement and child starts on the same line with 'else clause'
	                while (parent) {
	                    var useActualIndentation = true;
	                    if (ignoreActualIndentationRange) {
	                        var start = current.getStart(sourceFile);
	                        useActualIndentation = start < ignoreActualIndentationRange.pos || start > ignoreActualIndentationRange.end;
	                    }
	                    if (useActualIndentation) {
	                        // check if current node is a list item - if yes, take indentation from it
	                        var actualIndentation = getActualIndentationForListItem(current, sourceFile, options);
	                        if (actualIndentation !== -1 /* Unknown */) {
	                            return actualIndentation + indentationDelta;
	                        }
	                    }
	                    parentStart = getParentStart(parent, current, sourceFile);
	                    var parentAndChildShareLine = parentStart.line === currentStart.line ||
	                        childStartsOnTheSameLineWithElseInIfStatement(parent, current, currentStart.line, sourceFile);
	                    if (useActualIndentation) {
	                        // try to fetch actual indentation for current node from source text
	                        var actualIndentation = getActualIndentationForNode(current, parent, currentStart, parentAndChildShareLine, sourceFile, options);
	                        if (actualIndentation !== -1 /* Unknown */) {
	                            return actualIndentation + indentationDelta;
	                        }
	                        actualIndentation = getLineIndentationWhenExpressionIsInMultiLine(current, sourceFile, options);
	                        if (actualIndentation !== -1 /* Unknown */) {
	                            return actualIndentation + indentationDelta;
	                        }
	                    }
	                    // increase indentation if parent node wants its content to be indented and parent and child nodes don't start on the same line
	                    if (shouldIndentChildNode(parent, current) && !parentAndChildShareLine) {
	                        indentationDelta += options.IndentSize;
	                    }
	                    current = parent;
	                    currentStart = parentStart;
	                    parent = current.parent;
	                }
	                return indentationDelta;
	            }
	            function getParentStart(parent, child, sourceFile) {
	                var containingList = getContainingList(child, sourceFile);
	                if (containingList) {
	                    return sourceFile.getLineAndCharacterOfPosition(containingList.pos);
	                }
	                return sourceFile.getLineAndCharacterOfPosition(parent.getStart(sourceFile));
	            }
	            /*
	             * Function returns Value.Unknown if indentation cannot be determined
	             */
	            function getActualIndentationForListItemBeforeComma(commaToken, sourceFile, options) {
	                // previous token is comma that separates items in list - find the previous item and try to derive indentation from it
	                var commaItemInfo = ts.findListItemInfo(commaToken);
	                if (commaItemInfo && commaItemInfo.listItemIndex > 0) {
	                    return deriveActualIndentationFromList(commaItemInfo.list.getChildren(), commaItemInfo.listItemIndex - 1, sourceFile, options);
	                }
	                else {
	                    // handle broken code gracefully
	                    return -1 /* Unknown */;
	                }
	            }
	            /*
	             * Function returns Value.Unknown if actual indentation for node should not be used (i.e because node is nested expression)
	             */
	            function getActualIndentationForNode(current, parent, currentLineAndChar, parentAndChildShareLine, sourceFile, options) {
	                // actual indentation is used for statements\declarations if one of cases below is true:
	                // - parent is SourceFile - by default immediate children of SourceFile are not indented except when user indents them manually
	                // - parent and child are not on the same line
	                var useActualIndentation = (ts.isDeclaration(current) || ts.isStatement(current)) &&
	                    (parent.kind === 251 /* SourceFile */ || !parentAndChildShareLine);
	                if (!useActualIndentation) {
	                    return -1 /* Unknown */;
	                }
	                return findColumnForFirstNonWhitespaceCharacterInLine(currentLineAndChar, sourceFile, options);
	            }
	            function nextTokenIsCurlyBraceOnSameLineAsCursor(precedingToken, current, lineAtPosition, sourceFile) {
	                var nextToken = ts.findNextToken(precedingToken, current);
	                if (!nextToken) {
	                    return false;
	                }
	                if (nextToken.kind === 15 /* OpenBraceToken */) {
	                    // open braces are always indented at the parent level
	                    return true;
	                }
	                else if (nextToken.kind === 16 /* CloseBraceToken */) {
	                    // close braces are indented at the parent level if they are located on the same line with cursor
	                    // this means that if new line will be added at $ position, this case will be indented
	                    // class A {
	                    //    $
	                    // }
	                    /// and this one - not
	                    // class A {
	                    // $}
	                    var nextTokenStartLine = getStartLineAndCharacterForNode(nextToken, sourceFile).line;
	                    return lineAtPosition === nextTokenStartLine;
	                }
	                return false;
	            }
	            function getStartLineAndCharacterForNode(n, sourceFile) {
	                return sourceFile.getLineAndCharacterOfPosition(n.getStart(sourceFile));
	            }
	            function childStartsOnTheSameLineWithElseInIfStatement(parent, child, childStartLine, sourceFile) {
	                if (parent.kind === 199 /* IfStatement */ && parent.elseStatement === child) {
	                    var elseKeyword = ts.findChildOfKind(parent, 80 /* ElseKeyword */, sourceFile);
	                    ts.Debug.assert(elseKeyword !== undefined);
	                    var elseKeywordStartLine = getStartLineAndCharacterForNode(elseKeyword, sourceFile).line;
	                    return elseKeywordStartLine === childStartLine;
	                }
	                return false;
	            }
	            SmartIndenter.childStartsOnTheSameLineWithElseInIfStatement = childStartsOnTheSameLineWithElseInIfStatement;
	            function getContainingList(node, sourceFile) {
	                if (node.parent) {
	                    switch (node.parent.kind) {
	                        case 152 /* TypeReference */:
	                            if (node.parent.typeArguments &&
	                                ts.rangeContainsStartEnd(node.parent.typeArguments, node.getStart(sourceFile), node.getEnd())) {
	                                return node.parent.typeArguments;
	                            }
	                            break;
	                        case 168 /* ObjectLiteralExpression */:
	                            return node.parent.properties;
	                        case 167 /* ArrayLiteralExpression */:
	                            return node.parent.elements;
	                        case 216 /* FunctionDeclaration */:
	                        case 176 /* FunctionExpression */:
	                        case 177 /* ArrowFunction */:
	                        case 144 /* MethodDeclaration */:
	                        case 143 /* MethodSignature */:
	                        case 148 /* CallSignature */:
	                        case 149 /* ConstructSignature */: {
	                            var start = node.getStart(sourceFile);
	                            if (node.parent.typeParameters &&
	                                ts.rangeContainsStartEnd(node.parent.typeParameters, start, node.getEnd())) {
	                                return node.parent.typeParameters;
	                            }
	                            if (ts.rangeContainsStartEnd(node.parent.parameters, start, node.getEnd())) {
	                                return node.parent.parameters;
	                            }
	                            break;
	                        }
	                        case 172 /* NewExpression */:
	                        case 171 /* CallExpression */: {
	                            var start = node.getStart(sourceFile);
	                            if (node.parent.typeArguments &&
	                                ts.rangeContainsStartEnd(node.parent.typeArguments, start, node.getEnd())) {
	                                return node.parent.typeArguments;
	                            }
	                            if (node.parent.arguments &&
	                                ts.rangeContainsStartEnd(node.parent.arguments, start, node.getEnd())) {
	                                return node.parent.arguments;
	                            }
	                            break;
	                        }
	                    }
	                }
	                return undefined;
	            }
	            function getActualIndentationForListItem(node, sourceFile, options) {
	                var containingList = getContainingList(node, sourceFile);
	                return containingList ? getActualIndentationFromList(containingList) : -1 /* Unknown */;
	                function getActualIndentationFromList(list) {
	                    var index = ts.indexOf(list, node);
	                    return index !== -1 ? deriveActualIndentationFromList(list, index, sourceFile, options) : -1 /* Unknown */;
	                }
	            }
	            function getLineIndentationWhenExpressionIsInMultiLine(node, sourceFile, options) {
	                // actual indentation should not be used when:
	                // - node is close parenthesis - this is the end of the expression
	                if (node.kind === 18 /* CloseParenToken */) {
	                    return -1 /* Unknown */;
	                }
	                if (node.parent && (node.parent.kind === 171 /* CallExpression */ ||
	                    node.parent.kind === 172 /* NewExpression */) &&
	                    node.parent.expression !== node) {
	                    var fullCallOrNewExpression = node.parent.expression;
	                    var startingExpression = getStartingExpression(fullCallOrNewExpression);
	                    if (fullCallOrNewExpression === startingExpression) {
	                        return -1 /* Unknown */;
	                    }
	                    var fullCallOrNewExpressionEnd = sourceFile.getLineAndCharacterOfPosition(fullCallOrNewExpression.end);
	                    var startingExpressionEnd = sourceFile.getLineAndCharacterOfPosition(startingExpression.end);
	                    if (fullCallOrNewExpressionEnd.line === startingExpressionEnd.line) {
	                        return -1 /* Unknown */;
	                    }
	                    return findColumnForFirstNonWhitespaceCharacterInLine(fullCallOrNewExpressionEnd, sourceFile, options);
	                }
	                return -1 /* Unknown */;
	                function getStartingExpression(node) {
	                    while (true) {
	                        switch (node.kind) {
	                            case 171 /* CallExpression */:
	                            case 172 /* NewExpression */:
	                            case 169 /* PropertyAccessExpression */:
	                            case 170 /* ElementAccessExpression */:
	                                node = node.expression;
	                                break;
	                            default:
	                                return node;
	                        }
	                    }
	                }
	            }
	            function deriveActualIndentationFromList(list, index, sourceFile, options) {
	                ts.Debug.assert(index >= 0 && index < list.length);
	                var node = list[index];
	                // walk toward the start of the list starting from current node and check if the line is the same for all items.
	                // if end line for item [i - 1] differs from the start line for item [i] - find column of the first non-whitespace character on the line of item [i]
	                var lineAndCharacter = getStartLineAndCharacterForNode(node, sourceFile);
	                for (var i = index - 1; i >= 0; --i) {
	                    if (list[i].kind === 24 /* CommaToken */) {
	                        continue;
	                    }
	                    // skip list items that ends on the same line with the current list element
	                    var prevEndLine = sourceFile.getLineAndCharacterOfPosition(list[i].end).line;
	                    if (prevEndLine !== lineAndCharacter.line) {
	                        return findColumnForFirstNonWhitespaceCharacterInLine(lineAndCharacter, sourceFile, options);
	                    }
	                    lineAndCharacter = getStartLineAndCharacterForNode(list[i], sourceFile);
	                }
	                return -1 /* Unknown */;
	            }
	            function findColumnForFirstNonWhitespaceCharacterInLine(lineAndCharacter, sourceFile, options) {
	                var lineStart = sourceFile.getPositionOfLineAndCharacter(lineAndCharacter.line, 0);
	                return findFirstNonWhitespaceColumn(lineStart, lineStart + lineAndCharacter.character, sourceFile, options);
	            }
	            /*
	                Character is the actual index of the character since the beginning of the line.
	                Column - position of the character after expanding tabs to spaces
	                "0\t2$"
	                value of 'character' for '$' is 3
	                value of 'column' for '$' is 6 (assuming that tab size is 4)
	            */
	            function findFirstNonWhitespaceCharacterAndColumn(startPos, endPos, sourceFile, options) {
	                var character = 0;
	                var column = 0;
	                for (var pos = startPos; pos < endPos; ++pos) {
	                    var ch = sourceFile.text.charCodeAt(pos);
	                    if (!ts.isWhiteSpace(ch)) {
	                        break;
	                    }
	                    if (ch === 9 /* tab */) {
	                        column += options.TabSize + (column % options.TabSize);
	                    }
	                    else {
	                        column++;
	                    }
	                    character++;
	                }
	                return { column: column, character: character };
	            }
	            SmartIndenter.findFirstNonWhitespaceCharacterAndColumn = findFirstNonWhitespaceCharacterAndColumn;
	            function findFirstNonWhitespaceColumn(startPos, endPos, sourceFile, options) {
	                return findFirstNonWhitespaceCharacterAndColumn(startPos, endPos, sourceFile, options).column;
	            }
	            SmartIndenter.findFirstNonWhitespaceColumn = findFirstNonWhitespaceColumn;
	            function nodeContentIsAlwaysIndented(kind) {
	                switch (kind) {
	                    case 198 /* ExpressionStatement */:
	                    case 217 /* ClassDeclaration */:
	                    case 189 /* ClassExpression */:
	                    case 218 /* InterfaceDeclaration */:
	                    case 220 /* EnumDeclaration */:
	                    case 219 /* TypeAliasDeclaration */:
	                    case 167 /* ArrayLiteralExpression */:
	                    case 195 /* Block */:
	                    case 222 /* ModuleBlock */:
	                    case 168 /* ObjectLiteralExpression */:
	                    case 156 /* TypeLiteral */:
	                    case 158 /* TupleType */:
	                    case 223 /* CaseBlock */:
	                    case 245 /* DefaultClause */:
	                    case 244 /* CaseClause */:
	                    case 175 /* ParenthesizedExpression */:
	                    case 169 /* PropertyAccessExpression */:
	                    case 171 /* CallExpression */:
	                    case 172 /* NewExpression */:
	                    case 196 /* VariableStatement */:
	                    case 214 /* VariableDeclaration */:
	                    case 230 /* ExportAssignment */:
	                    case 207 /* ReturnStatement */:
	                    case 185 /* ConditionalExpression */:
	                    case 165 /* ArrayBindingPattern */:
	                    case 164 /* ObjectBindingPattern */:
	                    case 238 /* JsxOpeningElement */:
	                    case 237 /* JsxSelfClosingElement */:
	                    case 243 /* JsxExpression */:
	                    case 143 /* MethodSignature */:
	                    case 148 /* CallSignature */:
	                    case 149 /* ConstructSignature */:
	                    case 139 /* Parameter */:
	                    case 153 /* FunctionType */:
	                    case 154 /* ConstructorType */:
	                    case 161 /* ParenthesizedType */:
	                    case 173 /* TaggedTemplateExpression */:
	                    case 181 /* AwaitExpression */:
	                    case 228 /* NamedImports */:
	                        return true;
	                }
	                return false;
	            }
	            /* @internal */
	            function nodeWillIndentChild(parent, child, indentByDefault) {
	                var childKind = child ? child.kind : 0 /* Unknown */;
	                switch (parent.kind) {
	                    case 200 /* DoStatement */:
	                    case 201 /* WhileStatement */:
	                    case 203 /* ForInStatement */:
	                    case 204 /* ForOfStatement */:
	                    case 202 /* ForStatement */:
	                    case 199 /* IfStatement */:
	                    case 216 /* FunctionDeclaration */:
	                    case 176 /* FunctionExpression */:
	                    case 144 /* MethodDeclaration */:
	                    case 177 /* ArrowFunction */:
	                    case 145 /* Constructor */:
	                    case 146 /* GetAccessor */:
	                    case 147 /* SetAccessor */:
	                        return childKind !== 195 /* Block */;
	                    case 236 /* JsxElement */:
	                        return childKind !== 240 /* JsxClosingElement */;
	                }
	                // No explicit rule for given nodes so the result will follow the default value argument
	                return indentByDefault;
	            }
	            SmartIndenter.nodeWillIndentChild = nodeWillIndentChild;
	            /*
	            Function returns true when the parent node should indent the given child by an explicit rule
	            */
	            function shouldIndentChildNode(parent, child) {
	                return nodeContentIsAlwaysIndented(parent.kind) || nodeWillIndentChild(parent, child, false);
	            }
	            SmartIndenter.shouldIndentChildNode = shouldIndentChildNode;
	        })(SmartIndenter = formatting.SmartIndenter || (formatting.SmartIndenter = {}));
	    })(formatting = ts.formatting || (ts.formatting = {}));
	})(ts || (ts = {}));
	/// <reference path="..\compiler\program.ts"/>
	/// <reference path='breakpoints.ts' />
	/// <reference path='outliningElementsCollector.ts' />
	/// <reference path='navigateTo.ts' />
	/// <reference path='navigationBar.ts' />
	/// <reference path='patternMatcher.ts' />
	/// <reference path='signatureHelp.ts' />
	/// <reference path='utilities.ts' />
	/// <reference path='formatting\formatting.ts' />
	/// <reference path='formatting\smartIndenter.ts' />
	var ts;
	(function (ts) {
	    /** The version of the language service API */
	    ts.servicesVersion = "0.4";
	    var ScriptSnapshot;
	    (function (ScriptSnapshot) {
	        var StringScriptSnapshot = (function () {
	            function StringScriptSnapshot(text) {
	                this.text = text;
	            }
	            StringScriptSnapshot.prototype.getText = function (start, end) {
	                return this.text.substring(start, end);
	            };
	            StringScriptSnapshot.prototype.getLength = function () {
	                return this.text.length;
	            };
	            StringScriptSnapshot.prototype.getChangeRange = function (oldSnapshot) {
	                // Text-based snapshots do not support incremental parsing. Return undefined
	                // to signal that to the caller.
	                return undefined;
	            };
	            return StringScriptSnapshot;
	        }());
	        function fromString(text) {
	            return new StringScriptSnapshot(text);
	        }
	        ScriptSnapshot.fromString = fromString;
	    })(ScriptSnapshot = ts.ScriptSnapshot || (ts.ScriptSnapshot = {}));
	    var scanner = ts.createScanner(2 /* Latest */, /*skipTrivia*/ true);
	    var emptyArray = [];
	    var jsDocTagNames = [
	        "augments",
	        "author",
	        "argument",
	        "borrows",
	        "class",
	        "constant",
	        "constructor",
	        "constructs",
	        "default",
	        "deprecated",
	        "description",
	        "event",
	        "example",
	        "extends",
	        "field",
	        "fileOverview",
	        "function",
	        "ignore",
	        "inner",
	        "lends",
	        "link",
	        "memberOf",
	        "name",
	        "namespace",
	        "param",
	        "private",
	        "property",
	        "public",
	        "requires",
	        "returns",
	        "see",
	        "since",
	        "static",
	        "throws",
	        "type",
	        "version"
	    ];
	    var jsDocCompletionEntries;
	    function createNode(kind, pos, end, flags, parent) {
	        var node = new NodeObject(kind, pos, end);
	        node.flags = flags;
	        node.parent = parent;
	        return node;
	    }
	    var NodeObject = (function () {
	        function NodeObject(kind, pos, end) {
	            this.kind = kind;
	            this.pos = pos;
	            this.end = end;
	            this.flags = 0 /* None */;
	            this.parent = undefined;
	        }
	        NodeObject.prototype.getSourceFile = function () {
	            return ts.getSourceFileOfNode(this);
	        };
	        NodeObject.prototype.getStart = function (sourceFile) {
	            return ts.getTokenPosOfNode(this, sourceFile);
	        };
	        NodeObject.prototype.getFullStart = function () {
	            return this.pos;
	        };
	        NodeObject.prototype.getEnd = function () {
	            return this.end;
	        };
	        NodeObject.prototype.getWidth = function (sourceFile) {
	            return this.getEnd() - this.getStart(sourceFile);
	        };
	        NodeObject.prototype.getFullWidth = function () {
	            return this.end - this.pos;
	        };
	        NodeObject.prototype.getLeadingTriviaWidth = function (sourceFile) {
	            return this.getStart(sourceFile) - this.pos;
	        };
	        NodeObject.prototype.getFullText = function (sourceFile) {
	            return (sourceFile || this.getSourceFile()).text.substring(this.pos, this.end);
	        };
	        NodeObject.prototype.getText = function (sourceFile) {
	            return (sourceFile || this.getSourceFile()).text.substring(this.getStart(), this.getEnd());
	        };
	        NodeObject.prototype.addSyntheticNodes = function (nodes, pos, end) {
	            scanner.setTextPos(pos);
	            while (pos < end) {
	                var token = scanner.scan();
	                var textPos = scanner.getTextPos();
	                nodes.push(createNode(token, pos, textPos, 2048 /* Synthetic */, this));
	                pos = textPos;
	            }
	            return pos;
	        };
	        NodeObject.prototype.createSyntaxList = function (nodes) {
	            var list = createNode(274 /* SyntaxList */, nodes.pos, nodes.end, 2048 /* Synthetic */, this);
	            list._children = [];
	            var pos = nodes.pos;
	            for (var _i = 0, nodes_7 = nodes; _i < nodes_7.length; _i++) {
	                var node = nodes_7[_i];
	                if (pos < node.pos) {
	                    pos = this.addSyntheticNodes(list._children, pos, node.pos);
	                }
	                list._children.push(node);
	                pos = node.end;
	            }
	            if (pos < nodes.end) {
	                this.addSyntheticNodes(list._children, pos, nodes.end);
	            }
	            return list;
	        };
	        NodeObject.prototype.createChildren = function (sourceFile) {
	            var _this = this;
	            var children;
	            if (this.kind >= 136 /* FirstNode */) {
	                scanner.setText((sourceFile || this.getSourceFile()).text);
	                children = [];
	                var pos_3 = this.pos;
	                var processNode = function (node) {
	                    if (pos_3 < node.pos) {
	                        pos_3 = _this.addSyntheticNodes(children, pos_3, node.pos);
	                    }
	                    children.push(node);
	                    pos_3 = node.end;
	                };
	                var processNodes = function (nodes) {
	                    if (pos_3 < nodes.pos) {
	                        pos_3 = _this.addSyntheticNodes(children, pos_3, nodes.pos);
	                    }
	                    children.push(_this.createSyntaxList(nodes));
	                    pos_3 = nodes.end;
	                };
	                ts.forEachChild(this, processNode, processNodes);
	                if (pos_3 < this.end) {
	                    this.addSyntheticNodes(children, pos_3, this.end);
	                }
	                scanner.setText(undefined);
	            }
	            this._children = children || emptyArray;
	        };
	        NodeObject.prototype.getChildCount = function (sourceFile) {
	            if (!this._children)
	                this.createChildren(sourceFile);
	            return this._children.length;
	        };
	        NodeObject.prototype.getChildAt = function (index, sourceFile) {
	            if (!this._children)
	                this.createChildren(sourceFile);
	            return this._children[index];
	        };
	        NodeObject.prototype.getChildren = function (sourceFile) {
	            if (!this._children)
	                this.createChildren(sourceFile);
	            return this._children;
	        };
	        NodeObject.prototype.getFirstToken = function (sourceFile) {
	            var children = this.getChildren(sourceFile);
	            if (!children.length) {
	                return undefined;
	            }
	            var child = children[0];
	            return child.kind < 136 /* FirstNode */ ? child : child.getFirstToken(sourceFile);
	        };
	        NodeObject.prototype.getLastToken = function (sourceFile) {
	            var children = this.getChildren(sourceFile);
	            var child = ts.lastOrUndefined(children);
	            if (!child) {
	                return undefined;
	            }
	            return child.kind < 136 /* FirstNode */ ? child : child.getLastToken(sourceFile);
	        };
	        return NodeObject;
	    }());
	    var SymbolObject = (function () {
	        function SymbolObject(flags, name) {
	            this.flags = flags;
	            this.name = name;
	        }
	        SymbolObject.prototype.getFlags = function () {
	            return this.flags;
	        };
	        SymbolObject.prototype.getName = function () {
	            return this.name;
	        };
	        SymbolObject.prototype.getDeclarations = function () {
	            return this.declarations;
	        };
	        SymbolObject.prototype.getDocumentationComment = function () {
	            if (this.documentationComment === undefined) {
	                this.documentationComment = getJsDocCommentsFromDeclarations(this.declarations, this.name, !(this.flags & 4 /* Property */));
	            }
	            return this.documentationComment;
	        };
	        return SymbolObject;
	    }());
	    function getJsDocCommentsFromDeclarations(declarations, name, canUseParsedParamTagComments) {
	        var documentationComment = [];
	        var docComments = getJsDocCommentsSeparatedByNewLines();
	        ts.forEach(docComments, function (docComment) {
	            if (documentationComment.length) {
	                documentationComment.push(ts.lineBreakPart());
	            }
	            documentationComment.push(docComment);
	        });
	        return documentationComment;
	        function getJsDocCommentsSeparatedByNewLines() {
	            var paramTag = "@param";
	            var jsDocCommentParts = [];
	            ts.forEach(declarations, function (declaration, indexOfDeclaration) {
	                // Make sure we are collecting doc comment from declaration once,
	                // In case of union property there might be same declaration multiple times
	                // which only varies in type parameter
	                // Eg. const a: Array<string> | Array<number>; a.length
	                // The property length will have two declarations of property length coming
	                // from Array<T> - Array<string> and Array<number>
	                if (ts.indexOf(declarations, declaration) === indexOfDeclaration) {
	                    var sourceFileOfDeclaration_1 = ts.getSourceFileOfNode(declaration);
	                    // If it is parameter - try and get the jsDoc comment with @param tag from function declaration's jsDoc comments
	                    if (canUseParsedParamTagComments && declaration.kind === 139 /* Parameter */) {
	                        ts.forEach(getJsDocCommentTextRange(declaration.parent, sourceFileOfDeclaration_1), function (jsDocCommentTextRange) {
	                            var cleanedParamJsDocComment = getCleanedParamJsDocComment(jsDocCommentTextRange.pos, jsDocCommentTextRange.end, sourceFileOfDeclaration_1);
	                            if (cleanedParamJsDocComment) {
	                                ts.addRange(jsDocCommentParts, cleanedParamJsDocComment);
	                            }
	                        });
	                    }
	                    // If this is left side of dotted module declaration, there is no doc comments associated with this node
	                    if (declaration.kind === 221 /* ModuleDeclaration */ && declaration.body.kind === 221 /* ModuleDeclaration */) {
	                        return;
	                    }
	                    // If this is dotted module name, get the doc comments from the parent
	                    while (declaration.kind === 221 /* ModuleDeclaration */ && declaration.parent.kind === 221 /* ModuleDeclaration */) {
	                        declaration = declaration.parent;
	                    }
	                    // Get the cleaned js doc comment text from the declaration
	                    ts.forEach(getJsDocCommentTextRange(declaration.kind === 214 /* VariableDeclaration */ ? declaration.parent.parent : declaration, sourceFileOfDeclaration_1), function (jsDocCommentTextRange) {
	                        var cleanedJsDocComment = getCleanedJsDocComment(jsDocCommentTextRange.pos, jsDocCommentTextRange.end, sourceFileOfDeclaration_1);
	                        if (cleanedJsDocComment) {
	                            ts.addRange(jsDocCommentParts, cleanedJsDocComment);
	                        }
	                    });
	                }
	            });
	            return jsDocCommentParts;
	            function getJsDocCommentTextRange(node, sourceFile) {
	                return ts.map(ts.getJsDocComments(node, sourceFile), function (jsDocComment) {
	                    return {
	                        pos: jsDocComment.pos + "/*".length,
	                        end: jsDocComment.end - "*/".length // Trim off comment end indicator
	                    };
	                });
	            }
	            function consumeWhiteSpacesOnTheLine(pos, end, sourceFile, maxSpacesToRemove) {
	                if (maxSpacesToRemove !== undefined) {
	                    end = Math.min(end, pos + maxSpacesToRemove);
	                }
	                for (; pos < end; pos++) {
	                    var ch = sourceFile.text.charCodeAt(pos);
	                    if (!ts.isWhiteSpace(ch) || ts.isLineBreak(ch)) {
	                        // Either found lineBreak or non whiteSpace
	                        return pos;
	                    }
	                }
	                return end;
	            }
	            function consumeLineBreaks(pos, end, sourceFile) {
	                while (pos < end && ts.isLineBreak(sourceFile.text.charCodeAt(pos))) {
	                    pos++;
	                }
	                return pos;
	            }
	            function isName(pos, end, sourceFile, name) {
	                return pos + name.length < end &&
	                    sourceFile.text.substr(pos, name.length) === name &&
	                    (ts.isWhiteSpace(sourceFile.text.charCodeAt(pos + name.length)) ||
	                        ts.isLineBreak(sourceFile.text.charCodeAt(pos + name.length)));
	            }
	            function isParamTag(pos, end, sourceFile) {
	                // If it is @param tag
	                return isName(pos, end, sourceFile, paramTag);
	            }
	            function pushDocCommentLineText(docComments, text, blankLineCount) {
	                // Add the empty lines in between texts
	                while (blankLineCount) {
	                    blankLineCount--;
	                    docComments.push(ts.textPart(""));
	                }
	                docComments.push(ts.textPart(text));
	            }
	            function getCleanedJsDocComment(pos, end, sourceFile) {
	                var spacesToRemoveAfterAsterisk;
	                var docComments = [];
	                var blankLineCount = 0;
	                var isInParamTag = false;
	                while (pos < end) {
	                    var docCommentTextOfLine = "";
	                    // First consume leading white space
	                    pos = consumeWhiteSpacesOnTheLine(pos, end, sourceFile);
	                    // If the comment starts with '*' consume the spaces on this line
	                    if (pos < end && sourceFile.text.charCodeAt(pos) === 42 /* asterisk */) {
	                        var lineStartPos = pos + 1;
	                        pos = consumeWhiteSpacesOnTheLine(pos + 1, end, sourceFile, spacesToRemoveAfterAsterisk);
	                        // Set the spaces to remove after asterisk as margin if not already set
	                        if (spacesToRemoveAfterAsterisk === undefined && pos < end && !ts.isLineBreak(sourceFile.text.charCodeAt(pos))) {
	                            spacesToRemoveAfterAsterisk = pos - lineStartPos;
	                        }
	                    }
	                    else if (spacesToRemoveAfterAsterisk === undefined) {
	                        spacesToRemoveAfterAsterisk = 0;
	                    }
	                    // Analyse text on this line
	                    while (pos < end && !ts.isLineBreak(sourceFile.text.charCodeAt(pos))) {
	                        var ch = sourceFile.text.charAt(pos);
	                        if (ch === "@") {
	                            // If it is @param tag
	                            if (isParamTag(pos, end, sourceFile)) {
	                                isInParamTag = true;
	                                pos += paramTag.length;
	                                continue;
	                            }
	                            else {
	                                isInParamTag = false;
	                            }
	                        }
	                        // Add the ch to doc text if we arent in param tag
	                        if (!isInParamTag) {
	                            docCommentTextOfLine += ch;
	                        }
	                        // Scan next character
	                        pos++;
	                    }
	                    // Continue with next line
	                    pos = consumeLineBreaks(pos, end, sourceFile);
	                    if (docCommentTextOfLine) {
	                        pushDocCommentLineText(docComments, docCommentTextOfLine, blankLineCount);
	                        blankLineCount = 0;
	                    }
	                    else if (!isInParamTag && docComments.length) {
	                        // This is blank line when there is text already parsed
	                        blankLineCount++;
	                    }
	                }
	                return docComments;
	            }
	            function getCleanedParamJsDocComment(pos, end, sourceFile) {
	                var paramHelpStringMargin;
	                var paramDocComments = [];
	                while (pos < end) {
	                    if (isParamTag(pos, end, sourceFile)) {
	                        var blankLineCount = 0;
	                        var recordedParamTag = false;
	                        // Consume leading spaces
	                        pos = consumeWhiteSpaces(pos + paramTag.length);
	                        if (pos >= end) {
	                            break;
	                        }
	                        // Ignore type expression
	                        if (sourceFile.text.charCodeAt(pos) === 123 /* openBrace */) {
	                            pos++;
	                            for (var curlies = 1; pos < end; pos++) {
	                                var charCode = sourceFile.text.charCodeAt(pos);
	                                // { character means we need to find another } to match the found one
	                                if (charCode === 123 /* openBrace */) {
	                                    curlies++;
	                                    continue;
	                                }
	                                // } char
	                                if (charCode === 125 /* closeBrace */) {
	                                    curlies--;
	                                    if (curlies === 0) {
	                                        // We do not have any more } to match the type expression is ignored completely
	                                        pos++;
	                                        break;
	                                    }
	                                    else {
	                                        // there are more { to be matched with }
	                                        continue;
	                                    }
	                                }
	                                // Found start of another tag
	                                if (charCode === 64 /* at */) {
	                                    break;
	                                }
	                            }
	                            // Consume white spaces
	                            pos = consumeWhiteSpaces(pos);
	                            if (pos >= end) {
	                                break;
	                            }
	                        }
	                        // Parameter name
	                        if (isName(pos, end, sourceFile, name)) {
	                            // Found the parameter we are looking for consume white spaces
	                            pos = consumeWhiteSpaces(pos + name.length);
	                            if (pos >= end) {
	                                break;
	                            }
	                            var paramHelpString = "";
	                            var firstLineParamHelpStringPos = pos;
	                            while (pos < end) {
	                                var ch = sourceFile.text.charCodeAt(pos);
	                                // at line break, set this comment line text and go to next line
	                                if (ts.isLineBreak(ch)) {
	                                    if (paramHelpString) {
	                                        pushDocCommentLineText(paramDocComments, paramHelpString, blankLineCount);
	                                        paramHelpString = "";
	                                        blankLineCount = 0;
	                                        recordedParamTag = true;
	                                    }
	                                    else if (recordedParamTag) {
	                                        blankLineCount++;
	                                    }
	                                    // Get the pos after cleaning start of the line
	                                    setPosForParamHelpStringOnNextLine(firstLineParamHelpStringPos);
	                                    continue;
	                                }
	                                // Done scanning param help string - next tag found
	                                if (ch === 64 /* at */) {
	                                    break;
	                                }
	                                paramHelpString += sourceFile.text.charAt(pos);
	                                // Go to next character
	                                pos++;
	                            }
	                            // If there is param help text, add it top the doc comments
	                            if (paramHelpString) {
	                                pushDocCommentLineText(paramDocComments, paramHelpString, blankLineCount);
	                            }
	                            paramHelpStringMargin = undefined;
	                        }
	                        // If this is the start of another tag, continue with the loop in seach of param tag with symbol name
	                        if (sourceFile.text.charCodeAt(pos) === 64 /* at */) {
	                            continue;
	                        }
	                    }
	                    // Next character
	                    pos++;
	                }
	                return paramDocComments;
	                function consumeWhiteSpaces(pos) {
	                    while (pos < end && ts.isWhiteSpace(sourceFile.text.charCodeAt(pos))) {
	                        pos++;
	                    }
	                    return pos;
	                }
	                function setPosForParamHelpStringOnNextLine(firstLineParamHelpStringPos) {
	                    // Get the pos after consuming line breaks
	                    pos = consumeLineBreaks(pos, end, sourceFile);
	                    if (pos >= end) {
	                        return;
	                    }
	                    if (paramHelpStringMargin === undefined) {
	                        paramHelpStringMargin = sourceFile.getLineAndCharacterOfPosition(firstLineParamHelpStringPos).character;
	                    }
	                    // Now consume white spaces max
	                    var startOfLinePos = pos;
	                    pos = consumeWhiteSpacesOnTheLine(pos, end, sourceFile, paramHelpStringMargin);
	                    if (pos >= end) {
	                        return;
	                    }
	                    var consumedSpaces = pos - startOfLinePos;
	                    if (consumedSpaces < paramHelpStringMargin) {
	                        var ch = sourceFile.text.charCodeAt(pos);
	                        if (ch === 42 /* asterisk */) {
	                            // Consume more spaces after asterisk
	                            pos = consumeWhiteSpacesOnTheLine(pos + 1, end, sourceFile, paramHelpStringMargin - consumedSpaces - 1);
	                        }
	                    }
	                }
	            }
	        }
	    }
	    var TypeObject = (function () {
	        function TypeObject(checker, flags) {
	            this.checker = checker;
	            this.flags = flags;
	        }
	        TypeObject.prototype.getFlags = function () {
	            return this.flags;
	        };
	        TypeObject.prototype.getSymbol = function () {
	            return this.symbol;
	        };
	        TypeObject.prototype.getProperties = function () {
	            return this.checker.getPropertiesOfType(this);
	        };
	        TypeObject.prototype.getProperty = function (propertyName) {
	            return this.checker.getPropertyOfType(this, propertyName);
	        };
	        TypeObject.prototype.getApparentProperties = function () {
	            return this.checker.getAugmentedPropertiesOfType(this);
	        };
	        TypeObject.prototype.getCallSignatures = function () {
	            return this.checker.getSignaturesOfType(this, 0 /* Call */);
	        };
	        TypeObject.prototype.getConstructSignatures = function () {
	            return this.checker.getSignaturesOfType(this, 1 /* Construct */);
	        };
	        TypeObject.prototype.getStringIndexType = function () {
	            return this.checker.getIndexTypeOfType(this, 0 /* String */);
	        };
	        TypeObject.prototype.getNumberIndexType = function () {
	            return this.checker.getIndexTypeOfType(this, 1 /* Number */);
	        };
	        TypeObject.prototype.getBaseTypes = function () {
	            return this.flags & (1024 /* Class */ | 2048 /* Interface */)
	                ? this.checker.getBaseTypes(this)
	                : undefined;
	        };
	        return TypeObject;
	    }());
	    var SignatureObject = (function () {
	        function SignatureObject(checker) {
	            this.checker = checker;
	        }
	        SignatureObject.prototype.getDeclaration = function () {
	            return this.declaration;
	        };
	        SignatureObject.prototype.getTypeParameters = function () {
	            return this.typeParameters;
	        };
	        SignatureObject.prototype.getParameters = function () {
	            return this.parameters;
	        };
	        SignatureObject.prototype.getReturnType = function () {
	            return this.checker.getReturnTypeOfSignature(this);
	        };
	        SignatureObject.prototype.getDocumentationComment = function () {
	            if (this.documentationComment === undefined) {
	                this.documentationComment = this.declaration ? getJsDocCommentsFromDeclarations([this.declaration], 
	                /*name*/ undefined, 
	                /*canUseParsedParamTagComments*/ false) : [];
	            }
	            return this.documentationComment;
	        };
	        return SignatureObject;
	    }());
	    var SourceFileObject = (function (_super) {
	        __extends(SourceFileObject, _super);
	        function SourceFileObject(kind, pos, end) {
	            _super.call(this, kind, pos, end);
	        }
	        SourceFileObject.prototype.update = function (newText, textChangeRange) {
	            return ts.updateSourceFile(this, newText, textChangeRange);
	        };
	        SourceFileObject.prototype.getLineAndCharacterOfPosition = function (position) {
	            return ts.getLineAndCharacterOfPosition(this, position);
	        };
	        SourceFileObject.prototype.getLineStarts = function () {
	            return ts.getLineStarts(this);
	        };
	        SourceFileObject.prototype.getPositionOfLineAndCharacter = function (line, character) {
	            return ts.getPositionOfLineAndCharacter(this, line, character);
	        };
	        SourceFileObject.prototype.getNamedDeclarations = function () {
	            if (!this.namedDeclarations) {
	                this.namedDeclarations = this.computeNamedDeclarations();
	            }
	            return this.namedDeclarations;
	        };
	        SourceFileObject.prototype.computeNamedDeclarations = function () {
	            var result = {};
	            ts.forEachChild(this, visit);
	            return result;
	            function addDeclaration(declaration) {
	                var name = getDeclarationName(declaration);
	                if (name) {
	                    var declarations = getDeclarations(name);
	                    declarations.push(declaration);
	                }
	            }
	            function getDeclarations(name) {
	                return ts.getProperty(result, name) || (result[name] = []);
	            }
	            function getDeclarationName(declaration) {
	                if (declaration.name) {
	                    var result_3 = getTextOfIdentifierOrLiteral(declaration.name);
	                    if (result_3 !== undefined) {
	                        return result_3;
	                    }
	                    if (declaration.name.kind === 137 /* ComputedPropertyName */) {
	                        var expr = declaration.name.expression;
	                        if (expr.kind === 169 /* PropertyAccessExpression */) {
	                            return expr.name.text;
	                        }
	                        return getTextOfIdentifierOrLiteral(expr);
	                    }
	                }
	                return undefined;
	            }
	            function getTextOfIdentifierOrLiteral(node) {
	                if (node) {
	                    if (node.kind === 69 /* Identifier */ ||
	                        node.kind === 9 /* StringLiteral */ ||
	                        node.kind === 8 /* NumericLiteral */) {
	                        return node.text;
	                    }
	                }
	                return undefined;
	            }
	            function visit(node) {
	                switch (node.kind) {
	                    case 216 /* FunctionDeclaration */:
	                    case 144 /* MethodDeclaration */:
	                    case 143 /* MethodSignature */:
	                        var functionDeclaration = node;
	                        var declarationName = getDeclarationName(functionDeclaration);
	                        if (declarationName) {
	                            var declarations = getDeclarations(declarationName);
	                            var lastDeclaration = ts.lastOrUndefined(declarations);
	                            // Check whether this declaration belongs to an "overload group".
	                            if (lastDeclaration && functionDeclaration.parent === lastDeclaration.parent && functionDeclaration.symbol === lastDeclaration.symbol) {
	                                // Overwrite the last declaration if it was an overload
	                                // and this one is an implementation.
	                                if (functionDeclaration.body && !lastDeclaration.body) {
	                                    declarations[declarations.length - 1] = functionDeclaration;
	                                }
	                            }
	                            else {
	                                declarations.push(functionDeclaration);
	                            }
	                            ts.forEachChild(node, visit);
	                        }
	                        break;
	                    case 217 /* ClassDeclaration */:
	                    case 218 /* InterfaceDeclaration */:
	                    case 219 /* TypeAliasDeclaration */:
	                    case 220 /* EnumDeclaration */:
	                    case 221 /* ModuleDeclaration */:
	                    case 224 /* ImportEqualsDeclaration */:
	                    case 233 /* ExportSpecifier */:
	                    case 229 /* ImportSpecifier */:
	                    case 224 /* ImportEqualsDeclaration */:
	                    case 226 /* ImportClause */:
	                    case 227 /* NamespaceImport */:
	                    case 146 /* GetAccessor */:
	                    case 147 /* SetAccessor */:
	                    case 156 /* TypeLiteral */:
	                        addDeclaration(node);
	                    // fall through
	                    case 145 /* Constructor */:
	                    case 196 /* VariableStatement */:
	                    case 215 /* VariableDeclarationList */:
	                    case 164 /* ObjectBindingPattern */:
	                    case 165 /* ArrayBindingPattern */:
	                    case 222 /* ModuleBlock */:
	                        ts.forEachChild(node, visit);
	                        break;
	                    case 195 /* Block */:
	                        if (ts.isFunctionBlock(node)) {
	                            ts.forEachChild(node, visit);
	                        }
	                        break;
	                    case 139 /* Parameter */:
	                        // Only consider properties defined as constructor parameters
	                        if (!(node.flags & 56 /* AccessibilityModifier */)) {
	                            break;
	                        }
	                    // fall through
	                    case 214 /* VariableDeclaration */:
	                    case 166 /* BindingElement */:
	                        if (ts.isBindingPattern(node.name)) {
	                            ts.forEachChild(node.name, visit);
	                            break;
	                        }
	                    case 250 /* EnumMember */:
	                    case 142 /* PropertyDeclaration */:
	                    case 141 /* PropertySignature */:
	                        addDeclaration(node);
	                        break;
	                    case 231 /* ExportDeclaration */:
	                        // Handle named exports case e.g.:
	                        //    export {a, b as B} from "mod";
	                        if (node.exportClause) {
	                            ts.forEach(node.exportClause.elements, visit);
	                        }
	                        break;
	                    case 225 /* ImportDeclaration */:
	                        var importClause = node.importClause;
	                        if (importClause) {
	                            // Handle default import case e.g.:
	                            //    import d from "mod";
	                            if (importClause.name) {
	                                addDeclaration(importClause);
	                            }
	                            // Handle named bindings in imports e.g.:
	                            //    import * as NS from "mod";
	                            //    import {a, b as B} from "mod";
	                            if (importClause.namedBindings) {
	                                if (importClause.namedBindings.kind === 227 /* NamespaceImport */) {
	                                    addDeclaration(importClause.namedBindings);
	                                }
	                                else {
	                                    ts.forEach(importClause.namedBindings.elements, visit);
	                                }
	                            }
	                        }
	                        break;
	                }
	            }
	        };
	        return SourceFileObject;
	    }(NodeObject));
	    var TextChange = (function () {
	        function TextChange() {
	        }
	        return TextChange;
	    }());
	    ts.TextChange = TextChange;
	    var HighlightSpanKind;
	    (function (HighlightSpanKind) {
	        HighlightSpanKind.none = "none";
	        HighlightSpanKind.definition = "definition";
	        HighlightSpanKind.reference = "reference";
	        HighlightSpanKind.writtenReference = "writtenReference";
	    })(HighlightSpanKind = ts.HighlightSpanKind || (ts.HighlightSpanKind = {}));
	    (function (IndentStyle) {
	        IndentStyle[IndentStyle["None"] = 0] = "None";
	        IndentStyle[IndentStyle["Block"] = 1] = "Block";
	        IndentStyle[IndentStyle["Smart"] = 2] = "Smart";
	    })(ts.IndentStyle || (ts.IndentStyle = {}));
	    var IndentStyle = ts.IndentStyle;
	    (function (SymbolDisplayPartKind) {
	        SymbolDisplayPartKind[SymbolDisplayPartKind["aliasName"] = 0] = "aliasName";
	        SymbolDisplayPartKind[SymbolDisplayPartKind["className"] = 1] = "className";
	        SymbolDisplayPartKind[SymbolDisplayPartKind["enumName"] = 2] = "enumName";
	        SymbolDisplayPartKind[SymbolDisplayPartKind["fieldName"] = 3] = "fieldName";
	        SymbolDisplayPartKind[SymbolDisplayPartKind["interfaceName"] = 4] = "interfaceName";
	        SymbolDisplayPartKind[SymbolDisplayPartKind["keyword"] = 5] = "keyword";
	        SymbolDisplayPartKind[SymbolDisplayPartKind["lineBreak"] = 6] = "lineBreak";
	        SymbolDisplayPartKind[SymbolDisplayPartKind["numericLiteral"] = 7] = "numericLiteral";
	        SymbolDisplayPartKind[SymbolDisplayPartKind["stringLiteral"] = 8] = "stringLiteral";
	        SymbolDisplayPartKind[SymbolDisplayPartKind["localName"] = 9] = "localName";
	        SymbolDisplayPartKind[SymbolDisplayPartKind["methodName"] = 10] = "methodName";
	        SymbolDisplayPartKind[SymbolDisplayPartKind["moduleName"] = 11] = "moduleName";
	        SymbolDisplayPartKind[SymbolDisplayPartKind["operator"] = 12] = "operator";
	        SymbolDisplayPartKind[SymbolDisplayPartKind["parameterName"] = 13] = "parameterName";
	        SymbolDisplayPartKind[SymbolDisplayPartKind["propertyName"] = 14] = "propertyName";
	        SymbolDisplayPartKind[SymbolDisplayPartKind["punctuation"] = 15] = "punctuation";
	        SymbolDisplayPartKind[SymbolDisplayPartKind["space"] = 16] = "space";
	        SymbolDisplayPartKind[SymbolDisplayPartKind["text"] = 17] = "text";
	        SymbolDisplayPartKind[SymbolDisplayPartKind["typeParameterName"] = 18] = "typeParameterName";
	        SymbolDisplayPartKind[SymbolDisplayPartKind["enumMemberName"] = 19] = "enumMemberName";
	        SymbolDisplayPartKind[SymbolDisplayPartKind["functionName"] = 20] = "functionName";
	        SymbolDisplayPartKind[SymbolDisplayPartKind["regularExpressionLiteral"] = 21] = "regularExpressionLiteral";
	    })(ts.SymbolDisplayPartKind || (ts.SymbolDisplayPartKind = {}));
	    var SymbolDisplayPartKind = ts.SymbolDisplayPartKind;
	    (function (OutputFileType) {
	        OutputFileType[OutputFileType["JavaScript"] = 0] = "JavaScript";
	        OutputFileType[OutputFileType["SourceMap"] = 1] = "SourceMap";
	        OutputFileType[OutputFileType["Declaration"] = 2] = "Declaration";
	    })(ts.OutputFileType || (ts.OutputFileType = {}));
	    var OutputFileType = ts.OutputFileType;
	    (function (EndOfLineState) {
	        EndOfLineState[EndOfLineState["None"] = 0] = "None";
	        EndOfLineState[EndOfLineState["InMultiLineCommentTrivia"] = 1] = "InMultiLineCommentTrivia";
	        EndOfLineState[EndOfLineState["InSingleQuoteStringLiteral"] = 2] = "InSingleQuoteStringLiteral";
	        EndOfLineState[EndOfLineState["InDoubleQuoteStringLiteral"] = 3] = "InDoubleQuoteStringLiteral";
	        EndOfLineState[EndOfLineState["InTemplateHeadOrNoSubstitutionTemplate"] = 4] = "InTemplateHeadOrNoSubstitutionTemplate";
	        EndOfLineState[EndOfLineState["InTemplateMiddleOrTail"] = 5] = "InTemplateMiddleOrTail";
	        EndOfLineState[EndOfLineState["InTemplateSubstitutionPosition"] = 6] = "InTemplateSubstitutionPosition";
	    })(ts.EndOfLineState || (ts.EndOfLineState = {}));
	    var EndOfLineState = ts.EndOfLineState;
	    (function (TokenClass) {
	        TokenClass[TokenClass["Punctuation"] = 0] = "Punctuation";
	        TokenClass[TokenClass["Keyword"] = 1] = "Keyword";
	        TokenClass[TokenClass["Operator"] = 2] = "Operator";
	        TokenClass[TokenClass["Comment"] = 3] = "Comment";
	        TokenClass[TokenClass["Whitespace"] = 4] = "Whitespace";
	        TokenClass[TokenClass["Identifier"] = 5] = "Identifier";
	        TokenClass[TokenClass["NumberLiteral"] = 6] = "NumberLiteral";
	        TokenClass[TokenClass["StringLiteral"] = 7] = "StringLiteral";
	        TokenClass[TokenClass["RegExpLiteral"] = 8] = "RegExpLiteral";
	    })(ts.TokenClass || (ts.TokenClass = {}));
	    var TokenClass = ts.TokenClass;
	    // TODO: move these to enums
	    var ScriptElementKind;
	    (function (ScriptElementKind) {
	        ScriptElementKind.unknown = "";
	        ScriptElementKind.warning = "warning";
	        // predefined type (void) or keyword (class)
	        ScriptElementKind.keyword = "keyword";
	        // top level script node
	        ScriptElementKind.scriptElement = "script";
	        // module foo {}
	        ScriptElementKind.moduleElement = "module";
	        // class X {}
	        ScriptElementKind.classElement = "class";
	        // var x = class X {}
	        ScriptElementKind.localClassElement = "local class";
	        // interface Y {}
	        ScriptElementKind.interfaceElement = "interface";
	        // type T = ...
	        ScriptElementKind.typeElement = "type";
	        // enum E
	        ScriptElementKind.enumElement = "enum";
	        // Inside module and script only
	        // const v = ..
	        ScriptElementKind.variableElement = "var";
	        // Inside function
	        ScriptElementKind.localVariableElement = "local var";
	        // Inside module and script only
	        // function f() { }
	        ScriptElementKind.functionElement = "function";
	        // Inside function
	        ScriptElementKind.localFunctionElement = "local function";
	        // class X { [public|private]* foo() {} }
	        ScriptElementKind.memberFunctionElement = "method";
	        // class X { [public|private]* [get|set] foo:number; }
	        ScriptElementKind.memberGetAccessorElement = "getter";
	        ScriptElementKind.memberSetAccessorElement = "setter";
	        // class X { [public|private]* foo:number; }
	        // interface Y { foo:number; }
	        ScriptElementKind.memberVariableElement = "property";
	        // class X { constructor() { } }
	        ScriptElementKind.constructorImplementationElement = "constructor";
	        // interface Y { ():number; }
	        ScriptElementKind.callSignatureElement = "call";
	        // interface Y { []:number; }
	        ScriptElementKind.indexSignatureElement = "index";
	        // interface Y { new():Y; }
	        ScriptElementKind.constructSignatureElement = "construct";
	        // function foo(*Y*: string)
	        ScriptElementKind.parameterElement = "parameter";
	        ScriptElementKind.typeParameterElement = "type parameter";
	        ScriptElementKind.primitiveType = "primitive type";
	        ScriptElementKind.label = "label";
	        ScriptElementKind.alias = "alias";
	        ScriptElementKind.constElement = "const";
	        ScriptElementKind.letElement = "let";
	    })(ScriptElementKind = ts.ScriptElementKind || (ts.ScriptElementKind = {}));
	    var ScriptElementKindModifier;
	    (function (ScriptElementKindModifier) {
	        ScriptElementKindModifier.none = "";
	        ScriptElementKindModifier.publicMemberModifier = "public";
	        ScriptElementKindModifier.privateMemberModifier = "private";
	        ScriptElementKindModifier.protectedMemberModifier = "protected";
	        ScriptElementKindModifier.exportedModifier = "export";
	        ScriptElementKindModifier.ambientModifier = "declare";
	        ScriptElementKindModifier.staticModifier = "static";
	        ScriptElementKindModifier.abstractModifier = "abstract";
	    })(ScriptElementKindModifier = ts.ScriptElementKindModifier || (ts.ScriptElementKindModifier = {}));
	    var ClassificationTypeNames = (function () {
	        function ClassificationTypeNames() {
	        }
	        ClassificationTypeNames.comment = "comment";
	        ClassificationTypeNames.identifier = "identifier";
	        ClassificationTypeNames.keyword = "keyword";
	        ClassificationTypeNames.numericLiteral = "number";
	        ClassificationTypeNames.operator = "operator";
	        ClassificationTypeNames.stringLiteral = "string";
	        ClassificationTypeNames.whiteSpace = "whitespace";
	        ClassificationTypeNames.text = "text";
	        ClassificationTypeNames.punctuation = "punctuation";
	        ClassificationTypeNames.className = "class name";
	        ClassificationTypeNames.enumName = "enum name";
	        ClassificationTypeNames.interfaceName = "interface name";
	        ClassificationTypeNames.moduleName = "module name";
	        ClassificationTypeNames.typeParameterName = "type parameter name";
	        ClassificationTypeNames.typeAliasName = "type alias name";
	        ClassificationTypeNames.parameterName = "parameter name";
	        ClassificationTypeNames.docCommentTagName = "doc comment tag name";
	        ClassificationTypeNames.jsxOpenTagName = "jsx open tag name";
	        ClassificationTypeNames.jsxCloseTagName = "jsx close tag name";
	        ClassificationTypeNames.jsxSelfClosingTagName = "jsx self closing tag name";
	        ClassificationTypeNames.jsxAttribute = "jsx attribute";
	        ClassificationTypeNames.jsxText = "jsx text";
	        ClassificationTypeNames.jsxAttributeStringLiteralValue = "jsx attribute string literal value";
	        return ClassificationTypeNames;
	    }());
	    ts.ClassificationTypeNames = ClassificationTypeNames;
	    (function (ClassificationType) {
	        ClassificationType[ClassificationType["comment"] = 1] = "comment";
	        ClassificationType[ClassificationType["identifier"] = 2] = "identifier";
	        ClassificationType[ClassificationType["keyword"] = 3] = "keyword";
	        ClassificationType[ClassificationType["numericLiteral"] = 4] = "numericLiteral";
	        ClassificationType[ClassificationType["operator"] = 5] = "operator";
	        ClassificationType[ClassificationType["stringLiteral"] = 6] = "stringLiteral";
	        ClassificationType[ClassificationType["regularExpressionLiteral"] = 7] = "regularExpressionLiteral";
	        ClassificationType[ClassificationType["whiteSpace"] = 8] = "whiteSpace";
	        ClassificationType[ClassificationType["text"] = 9] = "text";
	        ClassificationType[ClassificationType["punctuation"] = 10] = "punctuation";
	        ClassificationType[ClassificationType["className"] = 11] = "className";
	        ClassificationType[ClassificationType["enumName"] = 12] = "enumName";
	        ClassificationType[ClassificationType["interfaceName"] = 13] = "interfaceName";
	        ClassificationType[ClassificationType["moduleName"] = 14] = "moduleName";
	        ClassificationType[ClassificationType["typeParameterName"] = 15] = "typeParameterName";
	        ClassificationType[ClassificationType["typeAliasName"] = 16] = "typeAliasName";
	        ClassificationType[ClassificationType["parameterName"] = 17] = "parameterName";
	        ClassificationType[ClassificationType["docCommentTagName"] = 18] = "docCommentTagName";
	        ClassificationType[ClassificationType["jsxOpenTagName"] = 19] = "jsxOpenTagName";
	        ClassificationType[ClassificationType["jsxCloseTagName"] = 20] = "jsxCloseTagName";
	        ClassificationType[ClassificationType["jsxSelfClosingTagName"] = 21] = "jsxSelfClosingTagName";
	        ClassificationType[ClassificationType["jsxAttribute"] = 22] = "jsxAttribute";
	        ClassificationType[ClassificationType["jsxText"] = 23] = "jsxText";
	        ClassificationType[ClassificationType["jsxAttributeStringLiteralValue"] = 24] = "jsxAttributeStringLiteralValue";
	    })(ts.ClassificationType || (ts.ClassificationType = {}));
	    var ClassificationType = ts.ClassificationType;
	    function displayPartsToString(displayParts) {
	        if (displayParts) {
	            return ts.map(displayParts, function (displayPart) { return displayPart.text; }).join("");
	        }
	        return "";
	    }
	    ts.displayPartsToString = displayPartsToString;
	    function isLocalVariableOrFunction(symbol) {
	        if (symbol.parent) {
	            return false; // This is exported symbol
	        }
	        return ts.forEach(symbol.declarations, function (declaration) {
	            // Function expressions are local
	            if (declaration.kind === 176 /* FunctionExpression */) {
	                return true;
	            }
	            if (declaration.kind !== 214 /* VariableDeclaration */ && declaration.kind !== 216 /* FunctionDeclaration */) {
	                return false;
	            }
	            // If the parent is not sourceFile or module block it is local variable
	            for (var parent_10 = declaration.parent; !ts.isFunctionBlock(parent_10); parent_10 = parent_10.parent) {
	                // Reached source file or module block
	                if (parent_10.kind === 251 /* SourceFile */ || parent_10.kind === 222 /* ModuleBlock */) {
	                    return false;
	                }
	            }
	            // parent is in function block
	            return true;
	        });
	    }
	    function getDefaultCompilerOptions() {
	        // Always default to "ScriptTarget.ES5" for the language service
	        return {
	            target: 1 /* ES5 */,
	            jsx: 1 /* Preserve */
	        };
	    }
	    ts.getDefaultCompilerOptions = getDefaultCompilerOptions;
	    // Cache host information about scrip Should be refreshed
	    // at each language service public entry point, since we don't know when
	    // set of scripts handled by the host changes.
	    var HostCache = (function () {
	        function HostCache(host, getCanonicalFileName) {
	            this.host = host;
	            this.getCanonicalFileName = getCanonicalFileName;
	            // script id => script index
	            this.currentDirectory = host.getCurrentDirectory();
	            this.fileNameToEntry = ts.createFileMap();
	            // Initialize the list with the root file names
	            var rootFileNames = host.getScriptFileNames();
	            for (var _i = 0, rootFileNames_1 = rootFileNames; _i < rootFileNames_1.length; _i++) {
	                var fileName = rootFileNames_1[_i];
	                this.createEntry(fileName, ts.toPath(fileName, this.currentDirectory, getCanonicalFileName));
	            }
	            // store the compilation settings
	            this._compilationSettings = host.getCompilationSettings() || getDefaultCompilerOptions();
	        }
	        HostCache.prototype.compilationSettings = function () {
	            return this._compilationSettings;
	        };
	        HostCache.prototype.createEntry = function (fileName, path) {
	            var entry;
	            var scriptSnapshot = this.host.getScriptSnapshot(fileName);
	            if (scriptSnapshot) {
	                entry = {
	                    hostFileName: fileName,
	                    version: this.host.getScriptVersion(fileName),
	                    scriptSnapshot: scriptSnapshot
	                };
	            }
	            this.fileNameToEntry.set(path, entry);
	            return entry;
	        };
	        HostCache.prototype.getEntry = function (path) {
	            return this.fileNameToEntry.get(path);
	        };
	        HostCache.prototype.contains = function (path) {
	            return this.fileNameToEntry.contains(path);
	        };
	        HostCache.prototype.getOrCreateEntry = function (fileName) {
	            var path = ts.toPath(fileName, this.currentDirectory, this.getCanonicalFileName);
	            if (this.contains(path)) {
	                return this.getEntry(path);
	            }
	            return this.createEntry(fileName, path);
	        };
	        HostCache.prototype.getRootFileNames = function () {
	            var fileNames = [];
	            this.fileNameToEntry.forEachValue(function (path, value) {
	                if (value) {
	                    fileNames.push(value.hostFileName);
	                }
	            });
	            return fileNames;
	        };
	        HostCache.prototype.getVersion = function (path) {
	            var file = this.getEntry(path);
	            return file && file.version;
	        };
	        HostCache.prototype.getScriptSnapshot = function (path) {
	            var file = this.getEntry(path);
	            return file && file.scriptSnapshot;
	        };
	        return HostCache;
	    }());
	    var SyntaxTreeCache = (function () {
	        function SyntaxTreeCache(host) {
	            this.host = host;
	        }
	        SyntaxTreeCache.prototype.getCurrentSourceFile = function (fileName) {
	            var scriptSnapshot = this.host.getScriptSnapshot(fileName);
	            if (!scriptSnapshot) {
	                // The host does not know about this file.
	                throw new Error("Could not find file: '" + fileName + "'.");
	            }
	            var version = this.host.getScriptVersion(fileName);
	            var sourceFile;
	            if (this.currentFileName !== fileName) {
	                // This is a new file, just parse it
	                sourceFile = createLanguageServiceSourceFile(fileName, scriptSnapshot, 2 /* Latest */, version, /*setNodeParents*/ true);
	            }
	            else if (this.currentFileVersion !== version) {
	                // This is the same file, just a newer version. Incrementally parse the file.
	                var editRange = scriptSnapshot.getChangeRange(this.currentFileScriptSnapshot);
	                sourceFile = updateLanguageServiceSourceFile(this.currentSourceFile, scriptSnapshot, version, editRange);
	            }
	            if (sourceFile) {
	                // All done, ensure state is up to date
	                this.currentFileVersion = version;
	                this.currentFileName = fileName;
	                this.currentFileScriptSnapshot = scriptSnapshot;
	                this.currentSourceFile = sourceFile;
	            }
	            return this.currentSourceFile;
	        };
	        return SyntaxTreeCache;
	    }());
	    function setSourceFileFields(sourceFile, scriptSnapshot, version) {
	        sourceFile.version = version;
	        sourceFile.scriptSnapshot = scriptSnapshot;
	    }
	    /*
	     * This function will compile source text from 'input' argument using specified compiler options.
	     * If not options are provided - it will use a set of default compiler options.
	     * Extra compiler options that will unconditionally be used by this function are:
	     * - isolatedModules = true
	     * - allowNonTsExtensions = true
	     * - noLib = true
	     * - noResolve = true
	     */
	    function transpileModule(input, transpileOptions) {
	        var options = transpileOptions.compilerOptions ? ts.clone(transpileOptions.compilerOptions) : getDefaultCompilerOptions();
	        options.isolatedModules = true;
	        // transpileModule does not write anything to disk so there is no need to verify that there are no conflicts between input and output paths. 
	        options.suppressOutputPathCheck = true;
	        // Filename can be non-ts file.
	        options.allowNonTsExtensions = true;
	        // We are not returning a sourceFile for lib file when asked by the program,
	        // so pass --noLib to avoid reporting a file not found error.
	        options.noLib = true;
	        // We are not doing a full typecheck, we are not resolving the whole context,
	        // so pass --noResolve to avoid reporting missing file errors.
	        options.noResolve = true;
	        // if jsx is specified then treat file as .tsx
	        var inputFileName = transpileOptions.fileName || (options.jsx ? "module.tsx" : "module.ts");
	        var sourceFile = ts.createSourceFile(inputFileName, input, options.target);
	        if (transpileOptions.moduleName) {
	            sourceFile.moduleName = transpileOptions.moduleName;
	        }
	        sourceFile.renamedDependencies = transpileOptions.renamedDependencies;
	        var newLine = ts.getNewLineCharacter(options);
	        // Output
	        var outputText;
	        var sourceMapText;
	        // Create a compilerHost object to allow the compiler to read and write files
	        var compilerHost = {
	            getSourceFile: function (fileName, target) { return fileName === ts.normalizeSlashes(inputFileName) ? sourceFile : undefined; },
	            writeFile: function (name, text, writeByteOrderMark) {
	                if (ts.fileExtensionIs(name, ".map")) {
	                    ts.Debug.assert(sourceMapText === undefined, "Unexpected multiple source map outputs for the file '" + name + "'");
	                    sourceMapText = text;
	                }
	                else {
	                    ts.Debug.assert(outputText === undefined, "Unexpected multiple outputs for the file: '" + name + "'");
	                    outputText = text;
	                }
	            },
	            getDefaultLibFileName: function () { return "lib.d.ts"; },
	            useCaseSensitiveFileNames: function () { return false; },
	            getCanonicalFileName: function (fileName) { return fileName; },
	            getCurrentDirectory: function () { return ""; },
	            getNewLine: function () { return newLine; },
	            fileExists: function (fileName) { return fileName === inputFileName; },
	            readFile: function (fileName) { return ""; },
	            directoryExists: function (directoryExists) { return true; }
	        };
	        var program = ts.createProgram([inputFileName], options, compilerHost);
	        var diagnostics;
	        if (transpileOptions.reportDiagnostics) {
	            diagnostics = [];
	            ts.addRange(/*to*/ diagnostics, /*from*/ program.getSyntacticDiagnostics(sourceFile));
	            ts.addRange(/*to*/ diagnostics, /*from*/ program.getOptionsDiagnostics());
	        }
	        // Emit
	        program.emit();
	        ts.Debug.assert(outputText !== undefined, "Output generation failed");
	        return { outputText: outputText, diagnostics: diagnostics, sourceMapText: sourceMapText };
	    }
	    ts.transpileModule = transpileModule;
	    /*
	     * This is a shortcut function for transpileModule - it accepts transpileOptions as parameters and returns only outputText part of the result.
	     */
	    function transpile(input, compilerOptions, fileName, diagnostics, moduleName) {
	        var output = transpileModule(input, { compilerOptions: compilerOptions, fileName: fileName, reportDiagnostics: !!diagnostics, moduleName: moduleName });
	        // addRange correctly handles cases when wither 'from' or 'to' argument is missing
	        ts.addRange(diagnostics, output.diagnostics);
	        return output.outputText;
	    }
	    ts.transpile = transpile;
	    function createLanguageServiceSourceFile(fileName, scriptSnapshot, scriptTarget, version, setNodeParents) {
	        var text = scriptSnapshot.getText(0, scriptSnapshot.getLength());
	        var sourceFile = ts.createSourceFile(fileName, text, scriptTarget, setNodeParents);
	        setSourceFileFields(sourceFile, scriptSnapshot, version);
	        return sourceFile;
	    }
	    ts.createLanguageServiceSourceFile = createLanguageServiceSourceFile;
	    ts.disableIncrementalParsing = false;
	    function updateLanguageServiceSourceFile(sourceFile, scriptSnapshot, version, textChangeRange, aggressiveChecks) {
	        // If we were given a text change range, and our version or open-ness changed, then
	        // incrementally parse this file.
	        if (textChangeRange) {
	            if (version !== sourceFile.version) {
	                // Once incremental parsing is ready, then just call into this function.
	                if (!ts.disableIncrementalParsing) {
	                    var newText = void 0;
	                    // grab the fragment from the beginning of the original text to the beginning of the span
	                    var prefix = textChangeRange.span.start !== 0
	                        ? sourceFile.text.substr(0, textChangeRange.span.start)
	                        : "";
	                    // grab the fragment from the end of the span till the end of the original text
	                    var suffix = ts.textSpanEnd(textChangeRange.span) !== sourceFile.text.length
	                        ? sourceFile.text.substr(ts.textSpanEnd(textChangeRange.span))
	                        : "";
	                    if (textChangeRange.newLength === 0) {
	                        // edit was a deletion - just combine prefix and suffix
	                        newText = prefix && suffix ? prefix + suffix : prefix || suffix;
	                    }
	                    else {
	                        // it was actual edit, fetch the fragment of new text that correspond to new span
	                        var changedText = scriptSnapshot.getText(textChangeRange.span.start, textChangeRange.span.start + textChangeRange.newLength);
	                        // combine prefix, changed text and suffix
	                        newText = prefix && suffix
	                            ? prefix + changedText + suffix
	                            : prefix
	                                ? (prefix + changedText)
	                                : (changedText + suffix);
	                    }
	                    var newSourceFile = ts.updateSourceFile(sourceFile, newText, textChangeRange, aggressiveChecks);
	                    setSourceFileFields(newSourceFile, scriptSnapshot, version);
	                    // after incremental parsing nameTable might not be up-to-date
	                    // drop it so it can be lazily recreated later
	                    newSourceFile.nameTable = undefined;
	                    // dispose all resources held by old script snapshot
	                    if (sourceFile !== newSourceFile && sourceFile.scriptSnapshot) {
	                        if (sourceFile.scriptSnapshot.dispose) {
	                            sourceFile.scriptSnapshot.dispose();
	                        }
	                        sourceFile.scriptSnapshot = undefined;
	                    }
	                    return newSourceFile;
	                }
	            }
	        }
	        // Otherwise, just create a new source file.
	        return createLanguageServiceSourceFile(sourceFile.fileName, scriptSnapshot, sourceFile.languageVersion, version, /*setNodeParents*/ true);
	    }
	    ts.updateLanguageServiceSourceFile = updateLanguageServiceSourceFile;
	    function createDocumentRegistry(useCaseSensitiveFileNames, currentDirectory) {
	        if (currentDirectory === void 0) { currentDirectory = ""; }
	        // Maps from compiler setting target (ES3, ES5, etc.) to all the cached documents we have
	        // for those settings.
	        var buckets = {};
	        var getCanonicalFileName = ts.createGetCanonicalFileName(!!useCaseSensitiveFileNames);
	        function getKeyFromCompilationSettings(settings) {
	            return "_" + settings.target + "|" + settings.module + "|" + settings.noResolve + "|" + settings.jsx + +"|" + settings.allowJs;
	        }
	        function getBucketForCompilationSettings(settings, createIfMissing) {
	            var key = getKeyFromCompilationSettings(settings);
	            var bucket = ts.lookUp(buckets, key);
	            if (!bucket && createIfMissing) {
	                buckets[key] = bucket = ts.createFileMap();
	            }
	            return bucket;
	        }
	        function reportStats() {
	            var bucketInfoArray = Object.keys(buckets).filter(function (name) { return name && name.charAt(0) === "_"; }).map(function (name) {
	                var entries = ts.lookUp(buckets, name);
	                var sourceFiles = [];
	                entries.forEachValue(function (key, entry) {
	                    sourceFiles.push({
	                        name: key,
	                        refCount: entry.languageServiceRefCount,
	                        references: entry.owners.slice(0)
	                    });
	                });
	                sourceFiles.sort(function (x, y) { return y.refCount - x.refCount; });
	                return {
	                    bucket: name,
	                    sourceFiles: sourceFiles
	                };
	            });
	            return JSON.stringify(bucketInfoArray, undefined, 2);
	        }
	        function acquireDocument(fileName, compilationSettings, scriptSnapshot, version) {
	            return acquireOrUpdateDocument(fileName, compilationSettings, scriptSnapshot, version, /*acquiring*/ true);
	        }
	        function updateDocument(fileName, compilationSettings, scriptSnapshot, version) {
	            return acquireOrUpdateDocument(fileName, compilationSettings, scriptSnapshot, version, /*acquiring*/ false);
	        }
	        function acquireOrUpdateDocument(fileName, compilationSettings, scriptSnapshot, version, acquiring) {
	            var bucket = getBucketForCompilationSettings(compilationSettings, /*createIfMissing*/ true);
	            var path = ts.toPath(fileName, currentDirectory, getCanonicalFileName);
	            var entry = bucket.get(path);
	            if (!entry) {
	                ts.Debug.assert(acquiring, "How could we be trying to update a document that the registry doesn't have?");
	                // Have never seen this file with these settings.  Create a new source file for it.
	                var sourceFile = createLanguageServiceSourceFile(fileName, scriptSnapshot, compilationSettings.target, version, /*setNodeParents*/ false);
	                entry = {
	                    sourceFile: sourceFile,
	                    languageServiceRefCount: 0,
	                    owners: []
	                };
	                bucket.set(path, entry);
	            }
	            else {
	                // We have an entry for this file.  However, it may be for a different version of
	                // the script snapshot.  If so, update it appropriately.  Otherwise, we can just
	                // return it as is.
	                if (entry.sourceFile.version !== version) {
	                    entry.sourceFile = updateLanguageServiceSourceFile(entry.sourceFile, scriptSnapshot, version, scriptSnapshot.getChangeRange(entry.sourceFile.scriptSnapshot));
	                }
	            }
	            // If we're acquiring, then this is the first time this LS is asking for this document.
	            // Increase our ref count so we know there's another LS using the document.  If we're
	            // not acquiring, then that means the LS is 'updating' the file instead, and that means
	            // it has already acquired the document previously.  As such, we do not need to increase
	            // the ref count.
	            if (acquiring) {
	                entry.languageServiceRefCount++;
	            }
	            return entry.sourceFile;
	        }
	        function releaseDocument(fileName, compilationSettings) {
	            var bucket = getBucketForCompilationSettings(compilationSettings, /*createIfMissing*/ false);
	            ts.Debug.assert(bucket !== undefined);
	            var path = ts.toPath(fileName, currentDirectory, getCanonicalFileName);
	            var entry = bucket.get(path);
	            entry.languageServiceRefCount--;
	            ts.Debug.assert(entry.languageServiceRefCount >= 0);
	            if (entry.languageServiceRefCount === 0) {
	                bucket.remove(path);
	            }
	        }
	        return {
	            acquireDocument: acquireDocument,
	            updateDocument: updateDocument,
	            releaseDocument: releaseDocument,
	            reportStats: reportStats
	        };
	    }
	    ts.createDocumentRegistry = createDocumentRegistry;
	    function preProcessFile(sourceText, readImportFiles, detectJavaScriptImports) {
	        if (readImportFiles === void 0) { readImportFiles = true; }
	        if (detectJavaScriptImports === void 0) { detectJavaScriptImports = false; }
	        var referencedFiles = [];
	        var importedFiles = [];
	        var ambientExternalModules;
	        var isNoDefaultLib = false;
	        function processTripleSlashDirectives() {
	            var commentRanges = ts.getLeadingCommentRanges(sourceText, 0);
	            ts.forEach(commentRanges, function (commentRange) {
	                var comment = sourceText.substring(commentRange.pos, commentRange.end);
	                var referencePathMatchResult = ts.getFileReferenceFromReferencePath(comment, commentRange);
	                if (referencePathMatchResult) {
	                    isNoDefaultLib = referencePathMatchResult.isNoDefaultLib;
	                    var fileReference = referencePathMatchResult.fileReference;
	                    if (fileReference) {
	                        referencedFiles.push(fileReference);
	                    }
	                }
	            });
	        }
	        function recordAmbientExternalModule() {
	            if (!ambientExternalModules) {
	                ambientExternalModules = [];
	            }
	            ambientExternalModules.push(scanner.getTokenValue());
	        }
	        function recordModuleName() {
	            var importPath = scanner.getTokenValue();
	            var pos = scanner.getTokenPos();
	            importedFiles.push({
	                fileName: importPath,
	                pos: pos,
	                end: pos + importPath.length
	            });
	        }
	        /**
	         * Returns true if at least one token was consumed from the stream
	         */
	        function tryConsumeDeclare() {
	            var token = scanner.getToken();
	            if (token === 122 /* DeclareKeyword */) {
	                // declare module "mod"
	                token = scanner.scan();
	                if (token === 125 /* ModuleKeyword */) {
	                    token = scanner.scan();
	                    if (token === 9 /* StringLiteral */) {
	                        recordAmbientExternalModule();
	                    }
	                }
	                return true;
	            }
	            return false;
	        }
	        /**
	         * Returns true if at least one token was consumed from the stream
	         */
	        function tryConsumeImport() {
	            var token = scanner.getToken();
	            if (token === 89 /* ImportKeyword */) {
	                token = scanner.scan();
	                if (token === 9 /* StringLiteral */) {
	                    // import "mod";
	                    recordModuleName();
	                    return true;
	                }
	                else {
	                    if (token === 69 /* Identifier */ || ts.isKeyword(token)) {
	                        token = scanner.scan();
	                        if (token === 133 /* FromKeyword */) {
	                            token = scanner.scan();
	                            if (token === 9 /* StringLiteral */) {
	                                // import d from "mod";
	                                recordModuleName();
	                                return true;
	                            }
	                        }
	                        else if (token === 56 /* EqualsToken */) {
	                            if (tryConsumeRequireCall(/*skipCurrentToken*/ true)) {
	                                return true;
	                            }
	                        }
	                        else if (token === 24 /* CommaToken */) {
	                            // consume comma and keep going
	                            token = scanner.scan();
	                        }
	                        else {
	                            // unknown syntax
	                            return true;
	                        }
	                    }
	                    if (token === 15 /* OpenBraceToken */) {
	                        token = scanner.scan();
	                        // consume "{ a as B, c, d as D}" clauses
	                        // make sure that it stops on EOF
	                        while (token !== 16 /* CloseBraceToken */ && token !== 1 /* EndOfFileToken */) {
	                            token = scanner.scan();
	                        }
	                        if (token === 16 /* CloseBraceToken */) {
	                            token = scanner.scan();
	                            if (token === 133 /* FromKeyword */) {
	                                token = scanner.scan();
	                                if (token === 9 /* StringLiteral */) {
	                                    // import {a as A} from "mod";
	                                    // import d, {a, b as B} from "mod"
	                                    recordModuleName();
	                                }
	                            }
	                        }
	                    }
	                    else if (token === 37 /* AsteriskToken */) {
	                        token = scanner.scan();
	                        if (token === 116 /* AsKeyword */) {
	                            token = scanner.scan();
	                            if (token === 69 /* Identifier */ || ts.isKeyword(token)) {
	                                token = scanner.scan();
	                                if (token === 133 /* FromKeyword */) {
	                                    token = scanner.scan();
	                                    if (token === 9 /* StringLiteral */) {
	                                        // import * as NS from "mod"
	                                        // import d, * as NS from "mod"
	                                        recordModuleName();
	                                    }
	                                }
	                            }
	                        }
	                    }
	                }
	                return true;
	            }
	            return false;
	        }
	        function tryConsumeExport() {
	            var token = scanner.getToken();
	            if (token === 82 /* ExportKeyword */) {
	                token = scanner.scan();
	                if (token === 15 /* OpenBraceToken */) {
	                    token = scanner.scan();
	                    // consume "{ a as B, c, d as D}" clauses
	                    // make sure it stops on EOF
	                    while (token !== 16 /* CloseBraceToken */ && token !== 1 /* EndOfFileToken */) {
	                        token = scanner.scan();
	                    }
	                    if (token === 16 /* CloseBraceToken */) {
	                        token = scanner.scan();
	                        if (token === 133 /* FromKeyword */) {
	                            token = scanner.scan();
	                            if (token === 9 /* StringLiteral */) {
	                                // export {a as A} from "mod";
	                                // export {a, b as B} from "mod"
	                                recordModuleName();
	                            }
	                        }
	                    }
	                }
	                else if (token === 37 /* AsteriskToken */) {
	                    token = scanner.scan();
	                    if (token === 133 /* FromKeyword */) {
	                        token = scanner.scan();
	                        if (token === 9 /* StringLiteral */) {
	                            // export * from "mod"
	                            recordModuleName();
	                        }
	                    }
	                }
	                else if (token === 89 /* ImportKeyword */) {
	                    token = scanner.scan();
	                    if (token === 69 /* Identifier */ || ts.isKeyword(token)) {
	                        token = scanner.scan();
	                        if (token === 56 /* EqualsToken */) {
	                            if (tryConsumeRequireCall(/*skipCurrentToken*/ true)) {
	                                return true;
	                            }
	                        }
	                    }
	                }
	                return true;
	            }
	            return false;
	        }
	        function tryConsumeRequireCall(skipCurrentToken) {
	            var token = skipCurrentToken ? scanner.scan() : scanner.getToken();
	            if (token === 127 /* RequireKeyword */) {
	                token = scanner.scan();
	                if (token === 17 /* OpenParenToken */) {
	                    token = scanner.scan();
	                    if (token === 9 /* StringLiteral */) {
	                        //  require("mod");
	                        recordModuleName();
	                    }
	                }
	                return true;
	            }
	            return false;
	        }
	        function tryConsumeDefine() {
	            var token = scanner.getToken();
	            if (token === 69 /* Identifier */ && scanner.getTokenValue() === "define") {
	                token = scanner.scan();
	                if (token !== 17 /* OpenParenToken */) {
	                    return true;
	                }
	                token = scanner.scan();
	                if (token === 9 /* StringLiteral */) {
	                    // looks like define ("modname", ... - skip string literal and comma
	                    token = scanner.scan();
	                    if (token === 24 /* CommaToken */) {
	                        token = scanner.scan();
	                    }
	                    else {
	                        // unexpected token
	                        return true;
	                    }
	                }
	                // should be start of dependency list
	                if (token !== 19 /* OpenBracketToken */) {
	                    return true;
	                }
	                // skip open bracket
	                token = scanner.scan();
	                var i = 0;
	                // scan until ']' or EOF
	                while (token !== 20 /* CloseBracketToken */ && token !== 1 /* EndOfFileToken */) {
	                    // record string literals as module names
	                    if (token === 9 /* StringLiteral */) {
	                        recordModuleName();
	                        i++;
	                    }
	                    token = scanner.scan();
	                }
	                return true;
	            }
	            return false;
	        }
	        function processImports() {
	            scanner.setText(sourceText);
	            scanner.scan();
	            // Look for:
	            //    import "mod";
	            //    import d from "mod"
	            //    import {a as A } from "mod";
	            //    import * as NS  from "mod"
	            //    import d, {a, b as B} from "mod"
	            //    import i = require("mod");
	            //
	            //    export * from "mod"
	            //    export {a as b} from "mod"
	            //    export import i = require("mod")
	            //    (for JavaScript files) require("mod")
	            while (true) {
	                if (scanner.getToken() === 1 /* EndOfFileToken */) {
	                    break;
	                }
	                // check if at least one of alternative have moved scanner forward
	                if (tryConsumeDeclare() ||
	                    tryConsumeImport() ||
	                    tryConsumeExport() ||
	                    (detectJavaScriptImports && (tryConsumeRequireCall(/*skipCurrentToken*/ false) || tryConsumeDefine()))) {
	                    continue;
	                }
	                else {
	                    scanner.scan();
	                }
	            }
	            scanner.setText(undefined);
	        }
	        if (readImportFiles) {
	            processImports();
	        }
	        processTripleSlashDirectives();
	        return { referencedFiles: referencedFiles, importedFiles: importedFiles, isLibFile: isNoDefaultLib, ambientExternalModules: ambientExternalModules };
	    }
	    ts.preProcessFile = preProcessFile;
	    /// Helpers
	    function getTargetLabel(referenceNode, labelName) {
	        while (referenceNode) {
	            if (referenceNode.kind === 210 /* LabeledStatement */ && referenceNode.label.text === labelName) {
	                return referenceNode.label;
	            }
	            referenceNode = referenceNode.parent;
	        }
	        return undefined;
	    }
	    function isJumpStatementTarget(node) {
	        return node.kind === 69 /* Identifier */ &&
	            (node.parent.kind === 206 /* BreakStatement */ || node.parent.kind === 205 /* ContinueStatement */) &&
	            node.parent.label === node;
	    }
	    function isLabelOfLabeledStatement(node) {
	        return node.kind === 69 /* Identifier */ &&
	            node.parent.kind === 210 /* LabeledStatement */ &&
	            node.parent.label === node;
	    }
	    /**
	     * Whether or not a 'node' is preceded by a label of the given string.
	     * Note: 'node' cannot be a SourceFile.
	     */
	    function isLabeledBy(node, labelName) {
	        for (var owner = node.parent; owner.kind === 210 /* LabeledStatement */; owner = owner.parent) {
	            if (owner.label.text === labelName) {
	                return true;
	            }
	        }
	        return false;
	    }
	    function isLabelName(node) {
	        return isLabelOfLabeledStatement(node) || isJumpStatementTarget(node);
	    }
	    function isRightSideOfQualifiedName(node) {
	        return node.parent.kind === 136 /* QualifiedName */ && node.parent.right === node;
	    }
	    function isRightSideOfPropertyAccess(node) {
	        return node && node.parent && node.parent.kind === 169 /* PropertyAccessExpression */ && node.parent.name === node;
	    }
	    function isCallExpressionTarget(node) {
	        if (isRightSideOfPropertyAccess(node)) {
	            node = node.parent;
	        }
	        return node && node.parent && node.parent.kind === 171 /* CallExpression */ && node.parent.expression === node;
	    }
	    function isNewExpressionTarget(node) {
	        if (isRightSideOfPropertyAccess(node)) {
	            node = node.parent;
	        }
	        return node && node.parent && node.parent.kind === 172 /* NewExpression */ && node.parent.expression === node;
	    }
	    function isNameOfModuleDeclaration(node) {
	        return node.parent.kind === 221 /* ModuleDeclaration */ && node.parent.name === node;
	    }
	    function isNameOfFunctionDeclaration(node) {
	        return node.kind === 69 /* Identifier */ &&
	            ts.isFunctionLike(node.parent) && node.parent.name === node;
	    }
	    /** Returns true if node is a name of an object literal property, e.g. "a" in x = { "a": 1 } */
	    function isNameOfPropertyAssignment(node) {
	        return (node.kind === 69 /* Identifier */ || node.kind === 9 /* StringLiteral */ || node.kind === 8 /* NumericLiteral */) &&
	            (node.parent.kind === 248 /* PropertyAssignment */ || node.parent.kind === 249 /* ShorthandPropertyAssignment */) && node.parent.name === node;
	    }
	    function isLiteralNameOfPropertyDeclarationOrIndexAccess(node) {
	        if (node.kind === 9 /* StringLiteral */ || node.kind === 8 /* NumericLiteral */) {
	            switch (node.parent.kind) {
	                case 142 /* PropertyDeclaration */:
	                case 141 /* PropertySignature */:
	                case 248 /* PropertyAssignment */:
	                case 250 /* EnumMember */:
	                case 144 /* MethodDeclaration */:
	                case 143 /* MethodSignature */:
	                case 146 /* GetAccessor */:
	                case 147 /* SetAccessor */:
	                case 221 /* ModuleDeclaration */:
	                    return node.parent.name === node;
	                case 170 /* ElementAccessExpression */:
	                    return node.parent.argumentExpression === node;
	            }
	        }
	        return false;
	    }
	    function isNameOfExternalModuleImportOrDeclaration(node) {
	        if (node.kind === 9 /* StringLiteral */) {
	            return isNameOfModuleDeclaration(node) ||
	                (ts.isExternalModuleImportEqualsDeclaration(node.parent.parent) && ts.getExternalModuleImportEqualsDeclarationExpression(node.parent.parent) === node);
	        }
	        return false;
	    }
	    /** Returns true if the position is within a comment */
	    function isInsideComment(sourceFile, token, position) {
	        // The position has to be: 1. in the leading trivia (before token.getStart()), and 2. within a comment
	        return position <= token.getStart(sourceFile) &&
	            (isInsideCommentRange(ts.getTrailingCommentRanges(sourceFile.text, token.getFullStart())) ||
	                isInsideCommentRange(ts.getLeadingCommentRanges(sourceFile.text, token.getFullStart())));
	        function isInsideCommentRange(comments) {
	            return ts.forEach(comments, function (comment) {
	                // either we are 1. completely inside the comment, or 2. at the end of the comment
	                if (comment.pos < position && position < comment.end) {
	                    return true;
	                }
	                else if (position === comment.end) {
	                    var text = sourceFile.text;
	                    var width = comment.end - comment.pos;
	                    // is single line comment or just /*
	                    if (width <= 2 || text.charCodeAt(comment.pos + 1) === 47 /* slash */) {
	                        return true;
	                    }
	                    else {
	                        // is unterminated multi-line comment
	                        return !(text.charCodeAt(comment.end - 1) === 47 /* slash */ &&
	                            text.charCodeAt(comment.end - 2) === 42 /* asterisk */);
	                    }
	                }
	                return false;
	            });
	        }
	    }
	    var SemanticMeaning;
	    (function (SemanticMeaning) {
	        SemanticMeaning[SemanticMeaning["None"] = 0] = "None";
	        SemanticMeaning[SemanticMeaning["Value"] = 1] = "Value";
	        SemanticMeaning[SemanticMeaning["Type"] = 2] = "Type";
	        SemanticMeaning[SemanticMeaning["Namespace"] = 4] = "Namespace";
	        SemanticMeaning[SemanticMeaning["All"] = 7] = "All";
	    })(SemanticMeaning || (SemanticMeaning = {}));
	    var BreakContinueSearchType;
	    (function (BreakContinueSearchType) {
	        BreakContinueSearchType[BreakContinueSearchType["None"] = 0] = "None";
	        BreakContinueSearchType[BreakContinueSearchType["Unlabeled"] = 1] = "Unlabeled";
	        BreakContinueSearchType[BreakContinueSearchType["Labeled"] = 2] = "Labeled";
	        BreakContinueSearchType[BreakContinueSearchType["All"] = 3] = "All";
	    })(BreakContinueSearchType || (BreakContinueSearchType = {}));
	    // A cache of completion entries for keywords, these do not change between sessions
	    var keywordCompletions = [];
	    for (var i = 70 /* FirstKeyword */; i <= 135 /* LastKeyword */; i++) {
	        keywordCompletions.push({
	            name: ts.tokenToString(i),
	            kind: ScriptElementKind.keyword,
	            kindModifiers: ScriptElementKindModifier.none,
	            sortText: "0"
	        });
	    }
	    /* @internal */ function getContainerNode(node) {
	        while (true) {
	            node = node.parent;
	            if (!node) {
	                return undefined;
	            }
	            switch (node.kind) {
	                case 251 /* SourceFile */:
	                case 144 /* MethodDeclaration */:
	                case 143 /* MethodSignature */:
	                case 216 /* FunctionDeclaration */:
	                case 176 /* FunctionExpression */:
	                case 146 /* GetAccessor */:
	                case 147 /* SetAccessor */:
	                case 217 /* ClassDeclaration */:
	                case 218 /* InterfaceDeclaration */:
	                case 220 /* EnumDeclaration */:
	                case 221 /* ModuleDeclaration */:
	                    return node;
	            }
	        }
	    }
	    ts.getContainerNode = getContainerNode;
	    /* @internal */ function getNodeKind(node) {
	        switch (node.kind) {
	            case 221 /* ModuleDeclaration */: return ScriptElementKind.moduleElement;
	            case 217 /* ClassDeclaration */: return ScriptElementKind.classElement;
	            case 218 /* InterfaceDeclaration */: return ScriptElementKind.interfaceElement;
	            case 219 /* TypeAliasDeclaration */: return ScriptElementKind.typeElement;
	            case 220 /* EnumDeclaration */: return ScriptElementKind.enumElement;
	            case 214 /* VariableDeclaration */:
	                return ts.isConst(node)
	                    ? ScriptElementKind.constElement
	                    : ts.isLet(node)
	                        ? ScriptElementKind.letElement
	                        : ScriptElementKind.variableElement;
	            case 216 /* FunctionDeclaration */: return ScriptElementKind.functionElement;
	            case 146 /* GetAccessor */: return ScriptElementKind.memberGetAccessorElement;
	            case 147 /* SetAccessor */: return ScriptElementKind.memberSetAccessorElement;
	            case 144 /* MethodDeclaration */:
	            case 143 /* MethodSignature */:
	                return ScriptElementKind.memberFunctionElement;
	            case 142 /* PropertyDeclaration */:
	            case 141 /* PropertySignature */:
	                return ScriptElementKind.memberVariableElement;
	            case 150 /* IndexSignature */: return ScriptElementKind.indexSignatureElement;
	            case 149 /* ConstructSignature */: return ScriptElementKind.constructSignatureElement;
	            case 148 /* CallSignature */: return ScriptElementKind.callSignatureElement;
	            case 145 /* Constructor */: return ScriptElementKind.constructorImplementationElement;
	            case 138 /* TypeParameter */: return ScriptElementKind.typeParameterElement;
	            case 250 /* EnumMember */: return ScriptElementKind.variableElement;
	            case 139 /* Parameter */: return (node.flags & 56 /* AccessibilityModifier */) ? ScriptElementKind.memberVariableElement : ScriptElementKind.parameterElement;
	            case 224 /* ImportEqualsDeclaration */:
	            case 229 /* ImportSpecifier */:
	            case 226 /* ImportClause */:
	            case 233 /* ExportSpecifier */:
	            case 227 /* NamespaceImport */:
	                return ScriptElementKind.alias;
	        }
	        return ScriptElementKind.unknown;
	    }
	    ts.getNodeKind = getNodeKind;
	    var CancellationTokenObject = (function () {
	        function CancellationTokenObject(cancellationToken) {
	            this.cancellationToken = cancellationToken;
	        }
	        CancellationTokenObject.prototype.isCancellationRequested = function () {
	            return this.cancellationToken && this.cancellationToken.isCancellationRequested();
	        };
	        CancellationTokenObject.prototype.throwIfCancellationRequested = function () {
	            if (this.isCancellationRequested()) {
	                throw new ts.OperationCanceledException();
	            }
	        };
	        return CancellationTokenObject;
	    }());
	    function createLanguageService(host, documentRegistry) {
	        if (documentRegistry === void 0) { documentRegistry = createDocumentRegistry(host.useCaseSensitiveFileNames && host.useCaseSensitiveFileNames(), host.getCurrentDirectory()); }
	        var syntaxTreeCache = new SyntaxTreeCache(host);
	        var ruleProvider;
	        var program;
	        var lastProjectVersion;
	        var useCaseSensitivefileNames = false;
	        var cancellationToken = new CancellationTokenObject(host.getCancellationToken && host.getCancellationToken());
	        var currentDirectory = host.getCurrentDirectory();
	        // Check if the localized messages json is set, otherwise query the host for it
	        if (!ts.localizedDiagnosticMessages && host.getLocalizedDiagnosticMessages) {
	            ts.localizedDiagnosticMessages = host.getLocalizedDiagnosticMessages();
	        }
	        function log(message) {
	            if (host.log) {
	                host.log(message);
	            }
	        }
	        var getCanonicalFileName = ts.createGetCanonicalFileName(useCaseSensitivefileNames);
	        function getValidSourceFile(fileName) {
	            var sourceFile = program.getSourceFile(fileName);
	            if (!sourceFile) {
	                throw new Error("Could not find file: '" + fileName + "'.");
	            }
	            return sourceFile;
	        }
	        function getRuleProvider(options) {
	            // Ensure rules are initialized and up to date wrt to formatting options
	            if (!ruleProvider) {
	                ruleProvider = new ts.formatting.RulesProvider();
	            }
	            ruleProvider.ensureUpToDate(options);
	            return ruleProvider;
	        }
	        function synchronizeHostData() {
	            // perform fast check if host supports it
	            if (host.getProjectVersion) {
	                var hostProjectVersion = host.getProjectVersion();
	                if (hostProjectVersion) {
	                    if (lastProjectVersion === hostProjectVersion) {
	                        return;
	                    }
	                    lastProjectVersion = hostProjectVersion;
	                }
	            }
	            // Get a fresh cache of the host information
	            var hostCache = new HostCache(host, getCanonicalFileName);
	            // If the program is already up-to-date, we can reuse it
	            if (programUpToDate()) {
	                return;
	            }
	            // IMPORTANT - It is critical from this moment onward that we do not check
	            // cancellation tokens.  We are about to mutate source files from a previous program
	            // instance.  If we cancel midway through, we may end up in an inconsistent state where
	            // the program points to old source files that have been invalidated because of
	            // incremental parsing.
	            var oldSettings = program && program.getCompilerOptions();
	            var newSettings = hostCache.compilationSettings();
	            var changesInCompilationSettingsAffectSyntax = oldSettings &&
	                (oldSettings.target !== newSettings.target ||
	                    oldSettings.module !== newSettings.module ||
	                    oldSettings.noResolve !== newSettings.noResolve ||
	                    oldSettings.jsx !== newSettings.jsx ||
	                    oldSettings.allowJs !== newSettings.allowJs);
	            // Now create a new compiler
	            var compilerHost = {
	                getSourceFile: getOrCreateSourceFile,
	                getCancellationToken: function () { return cancellationToken; },
	                getCanonicalFileName: getCanonicalFileName,
	                useCaseSensitiveFileNames: function () { return useCaseSensitivefileNames; },
	                getNewLine: function () { return ts.getNewLineOrDefaultFromHost(host); },
	                getDefaultLibFileName: function (options) { return host.getDefaultLibFileName(options); },
	                writeFile: function (fileName, data, writeByteOrderMark) { },
	                getCurrentDirectory: function () { return currentDirectory; },
	                fileExists: function (fileName) {
	                    // stub missing host functionality
	                    ts.Debug.assert(!host.resolveModuleNames);
	                    return hostCache.getOrCreateEntry(fileName) !== undefined;
	                },
	                readFile: function (fileName) {
	                    // stub missing host functionality
	                    var entry = hostCache.getOrCreateEntry(fileName);
	                    return entry && entry.scriptSnapshot.getText(0, entry.scriptSnapshot.getLength());
	                },
	                directoryExists: function (directoryName) {
	                    ts.Debug.assert(!host.resolveModuleNames);
	                    return ts.directoryProbablyExists(directoryName, host);
	                }
	            };
	            if (host.resolveModuleNames) {
	                compilerHost.resolveModuleNames = function (moduleNames, containingFile) { return host.resolveModuleNames(moduleNames, containingFile); };
	            }
	            var newProgram = ts.createProgram(hostCache.getRootFileNames(), newSettings, compilerHost, program);
	            // Release any files we have acquired in the old program but are
	            // not part of the new program.
	            if (program) {
	                var oldSourceFiles = program.getSourceFiles();
	                for (var _i = 0, oldSourceFiles_1 = oldSourceFiles; _i < oldSourceFiles_1.length; _i++) {
	                    var oldSourceFile = oldSourceFiles_1[_i];
	                    if (!newProgram.getSourceFile(oldSourceFile.fileName) || changesInCompilationSettingsAffectSyntax) {
	                        documentRegistry.releaseDocument(oldSourceFile.fileName, oldSettings);
	                    }
	                }
	            }
	            // hostCache is captured in the closure for 'getOrCreateSourceFile' but it should not be used past this point.
	            // It needs to be cleared to allow all collected snapshots to be released
	            hostCache = undefined;
	            program = newProgram;
	            // Make sure all the nodes in the program are both bound, and have their parent
	            // pointers set property.
	            program.getTypeChecker();
	            return;
	            function getOrCreateSourceFile(fileName) {
	                ts.Debug.assert(hostCache !== undefined);
	                // The program is asking for this file, check first if the host can locate it.
	                // If the host can not locate the file, then it does not exist. return undefined
	                // to the program to allow reporting of errors for missing files.
	                var hostFileInformation = hostCache.getOrCreateEntry(fileName);
	                if (!hostFileInformation) {
	                    return undefined;
	                }
	                // Check if the language version has changed since we last created a program; if they are the same,
	                // it is safe to reuse the souceFiles; if not, then the shape of the AST can change, and the oldSourceFile
	                // can not be reused. we have to dump all syntax trees and create new ones.
	                if (!changesInCompilationSettingsAffectSyntax) {
	                    // Check if the old program had this file already
	                    var oldSourceFile = program && program.getSourceFile(fileName);
	                    if (oldSourceFile) {
	                        // We already had a source file for this file name.  Go to the registry to
	                        // ensure that we get the right up to date version of it.  We need this to
	                        // address the following 'race'.  Specifically, say we have the following:
	                        //
	                        //      LS1
	                        //          \
	                        //           DocumentRegistry
	                        //          /
	                        //      LS2
	                        //
	                        // Each LS has a reference to file 'foo.ts' at version 1.  LS2 then updates
	                        // it's version of 'foo.ts' to version 2.  This will cause LS2 and the
	                        // DocumentRegistry to have version 2 of the document.  HOwever, LS1 will
	                        // have version 1.  And *importantly* this source file will be *corrupt*.
	                        // The act of creating version 2 of the file irrevocably damages the version
	                        // 1 file.
	                        //
	                        // So, later when we call into LS1, we need to make sure that it doesn't use
	                        // it's source file any more, and instead defers to DocumentRegistry to get
	                        // either version 1, version 2 (or some other version) depending on what the
	                        // host says should be used.
	                        return documentRegistry.updateDocument(fileName, newSettings, hostFileInformation.scriptSnapshot, hostFileInformation.version);
	                    }
	                }
	                // Could not find this file in the old program, create a new SourceFile for it.
	                return documentRegistry.acquireDocument(fileName, newSettings, hostFileInformation.scriptSnapshot, hostFileInformation.version);
	            }
	            function sourceFileUpToDate(sourceFile) {
	                if (!sourceFile) {
	                    return false;
	                }
	                var path = sourceFile.path || ts.toPath(sourceFile.fileName, currentDirectory, getCanonicalFileName);
	                return sourceFile.version === hostCache.getVersion(path);
	            }
	            function programUpToDate() {
	                // If we haven't create a program yet, then it is not up-to-date
	                if (!program) {
	                    return false;
	                }
	                // If number of files in the program do not match, it is not up-to-date
	                var rootFileNames = hostCache.getRootFileNames();
	                if (program.getSourceFiles().length !== rootFileNames.length) {
	                    return false;
	                }
	                // If any file is not up-to-date, then the whole program is not up-to-date
	                for (var _i = 0, rootFileNames_2 = rootFileNames; _i < rootFileNames_2.length; _i++) {
	                    var fileName = rootFileNames_2[_i];
	                    if (!sourceFileUpToDate(program.getSourceFile(fileName))) {
	                        return false;
	                    }
	                }
	                // If the compilation settings do no match, then the program is not up-to-date
	                return ts.compareDataObjects(program.getCompilerOptions(), hostCache.compilationSettings());
	            }
	        }
	        function getProgram() {
	            synchronizeHostData();
	            return program;
	        }
	        function cleanupSemanticCache() {
	            // TODO: Should we jettison the program (or it's type checker) here?
	        }
	        function dispose() {
	            if (program) {
	                ts.forEach(program.getSourceFiles(), function (f) {
	                    return documentRegistry.releaseDocument(f.fileName, program.getCompilerOptions());
	                });
	            }
	        }
	        /// Diagnostics
	        function getSyntacticDiagnostics(fileName) {
	            synchronizeHostData();
	            return program.getSyntacticDiagnostics(getValidSourceFile(fileName), cancellationToken);
	        }
	        /**
	         * getSemanticDiagnostiscs return array of Diagnostics. If '-d' is not enabled, only report semantic errors
	         * If '-d' enabled, report both semantic and emitter errors
	         */
	        function getSemanticDiagnostics(fileName) {
	            synchronizeHostData();
	            var targetSourceFile = getValidSourceFile(fileName);
	            // Only perform the action per file regardless of '-out' flag as LanguageServiceHost is expected to call this function per file.
	            // Therefore only get diagnostics for given file.
	            var semanticDiagnostics = program.getSemanticDiagnostics(targetSourceFile, cancellationToken);
	            if (!program.getCompilerOptions().declaration) {
	                return semanticDiagnostics;
	            }
	            // If '-d' is enabled, check for emitter error. One example of emitter error is export class implements non-export interface
	            var declarationDiagnostics = program.getDeclarationDiagnostics(targetSourceFile, cancellationToken);
	            return ts.concatenate(semanticDiagnostics, declarationDiagnostics);
	        }
	        function getCompilerOptionsDiagnostics() {
	            synchronizeHostData();
	            return program.getOptionsDiagnostics(cancellationToken).concat(program.getGlobalDiagnostics(cancellationToken));
	        }
	        /**
	         * Get the name to be display in completion from a given symbol.
	         *
	         * @return undefined if the name is of external module otherwise a name with striped of any quote
	         */
	        function getCompletionEntryDisplayNameForSymbol(symbol, target, performCharacterChecks, location) {
	            var displayName = ts.getDeclaredName(program.getTypeChecker(), symbol, location);
	            if (displayName) {
	                var firstCharCode = displayName.charCodeAt(0);
	                // First check of the displayName is not external module; if it is an external module, it is not valid entry
	                if ((symbol.flags & 1536 /* Namespace */) && (firstCharCode === 39 /* singleQuote */ || firstCharCode === 34 /* doubleQuote */)) {
	                    // If the symbol is external module, don't show it in the completion list
	                    // (i.e declare module "http" { const x; } | // <= request completion here, "http" should not be there)
	                    return undefined;
	                }
	            }
	            return getCompletionEntryDisplayName(displayName, target, performCharacterChecks);
	        }
	        /**
	         * Get a displayName from a given for completion list, performing any necessary quotes stripping
	         * and checking whether the name is valid identifier name.
	         */
	        function getCompletionEntryDisplayName(name, target, performCharacterChecks) {
	            if (!name) {
	                return undefined;
	            }
	            name = ts.stripQuotes(name);
	            if (!name) {
	                return undefined;
	            }
	            // If the user entered name for the symbol was quoted, removing the quotes is not enough, as the name could be an
	            // invalid identifier name. We need to check if whatever was inside the quotes is actually a valid identifier name.
	            // e.g "b a" is valid quoted name but when we strip off the quotes, it is invalid.
	            // We, thus, need to check if whatever was inside the quotes is actually a valid identifier name.
	            if (performCharacterChecks) {
	                if (!ts.isIdentifier(name, target)) {
	                    return undefined;
	                }
	            }
	            return name;
	        }
	        function getCompletionData(fileName, position) {
	            var typeChecker = program.getTypeChecker();
	            var sourceFile = getValidSourceFile(fileName);
	            var isJavaScriptFile = ts.isSourceFileJavaScript(sourceFile);
	            var isJsDocTagName = false;
	            var start = new Date().getTime();
	            var currentToken = ts.getTokenAtPosition(sourceFile, position);
	            log("getCompletionData: Get current token: " + (new Date().getTime() - start));
	            start = new Date().getTime();
	            // Completion not allowed inside comments, bail out if this is the case
	            var insideComment = isInsideComment(sourceFile, currentToken, position);
	            log("getCompletionData: Is inside comment: " + (new Date().getTime() - start));
	            if (insideComment) {
	                // The current position is next to the '@' sign, when no tag name being provided yet.
	                // Provide a full list of tag names
	                if (ts.hasDocComment(sourceFile, position) && sourceFile.text.charCodeAt(position - 1) === 64 /* at */) {
	                    isJsDocTagName = true;
	                }
	                // Completion should work inside certain JsDoc tags. For example:
	                //     /** @type {number | string} */
	                // Completion should work in the brackets
	                var insideJsDocTagExpression = false;
	                var tag = ts.getJsDocTagAtPosition(sourceFile, position);
	                if (tag) {
	                    if (tag.tagName.pos <= position && position <= tag.tagName.end) {
	                        isJsDocTagName = true;
	                    }
	                    switch (tag.kind) {
	                        case 272 /* JSDocTypeTag */:
	                        case 270 /* JSDocParameterTag */:
	                        case 271 /* JSDocReturnTag */:
	                            var tagWithExpression = tag;
	                            if (tagWithExpression.typeExpression) {
	                                insideJsDocTagExpression = tagWithExpression.typeExpression.pos < position && position < tagWithExpression.typeExpression.end;
	                            }
	                            break;
	                    }
	                }
	                if (isJsDocTagName) {
	                    return { symbols: undefined, isMemberCompletion: false, isNewIdentifierLocation: false, location: undefined, isRightOfDot: false, isJsDocTagName: isJsDocTagName };
	                }
	                if (!insideJsDocTagExpression) {
	                    // Proceed if the current position is in jsDoc tag expression; otherwise it is a normal
	                    // comment or the plain text part of a jsDoc comment, so no completion should be available
	                    log("Returning an empty list because completion was inside a regular comment or plain text part of a JsDoc comment.");
	                    return undefined;
	                }
	            }
	            start = new Date().getTime();
	            var previousToken = ts.findPrecedingToken(position, sourceFile);
	            log("getCompletionData: Get previous token 1: " + (new Date().getTime() - start));
	            // The decision to provide completion depends on the contextToken, which is determined through the previousToken.
	            // Note: 'previousToken' (and thus 'contextToken') can be undefined if we are the beginning of the file
	            var contextToken = previousToken;
	            // Check if the caret is at the end of an identifier; this is a partial identifier that we want to complete: e.g. a.toS|
	            // Skip this partial identifier and adjust the contextToken to the token that precedes it.
	            if (contextToken && position <= contextToken.end && ts.isWord(contextToken.kind)) {
	                var start_6 = new Date().getTime();
	                contextToken = ts.findPrecedingToken(contextToken.getFullStart(), sourceFile);
	                log("getCompletionData: Get previous token 2: " + (new Date().getTime() - start_6));
	            }
	            // Find the node where completion is requested on.
	            // Also determine whether we are trying to complete with members of that node
	            // or attributes of a JSX tag.
	            var node = currentToken;
	            var isRightOfDot = false;
	            var isRightOfOpenTag = false;
	            var isStartingCloseTag = false;
	            var location = ts.getTouchingPropertyName(sourceFile, position);
	            if (contextToken) {
	                // Bail out if this is a known invalid completion location
	                if (isCompletionListBlocker(contextToken)) {
	                    log("Returning an empty list because completion was requested in an invalid position.");
	                    return undefined;
	                }
	                var parent_11 = contextToken.parent, kind = contextToken.kind;
	                if (kind === 21 /* DotToken */) {
	                    if (parent_11.kind === 169 /* PropertyAccessExpression */) {
	                        node = contextToken.parent.expression;
	                        isRightOfDot = true;
	                    }
	                    else if (parent_11.kind === 136 /* QualifiedName */) {
	                        node = contextToken.parent.left;
	                        isRightOfDot = true;
	                    }
	                    else {
	                        // There is nothing that precedes the dot, so this likely just a stray character
	                        // or leading into a '...' token. Just bail out instead.
	                        return undefined;
	                    }
	                }
	                else if (sourceFile.languageVariant === 1 /* JSX */) {
	                    if (kind === 25 /* LessThanToken */) {
	                        isRightOfOpenTag = true;
	                        location = contextToken;
	                    }
	                    else if (kind === 39 /* SlashToken */ && contextToken.parent.kind === 240 /* JsxClosingElement */) {
	                        isStartingCloseTag = true;
	                        location = contextToken;
	                    }
	                }
	            }
	            var semanticStart = new Date().getTime();
	            var isMemberCompletion;
	            var isNewIdentifierLocation;
	            var symbols = [];
	            if (isRightOfDot) {
	                getTypeScriptMemberSymbols();
	            }
	            else if (isRightOfOpenTag) {
	                var tagSymbols = typeChecker.getJsxIntrinsicTagNames();
	                if (tryGetGlobalSymbols()) {
	                    symbols = tagSymbols.concat(symbols.filter(function (s) { return !!(s.flags & 107455 /* Value */); }));
	                }
	                else {
	                    symbols = tagSymbols;
	                }
	                isMemberCompletion = true;
	                isNewIdentifierLocation = false;
	            }
	            else if (isStartingCloseTag) {
	                var tagName = contextToken.parent.parent.openingElement.tagName;
	                var tagSymbol = typeChecker.getSymbolAtLocation(tagName);
	                if (!typeChecker.isUnknownSymbol(tagSymbol)) {
	                    symbols = [tagSymbol];
	                }
	                isMemberCompletion = true;
	                isNewIdentifierLocation = false;
	            }
	            else {
	                // For JavaScript or TypeScript, if we're not after a dot, then just try to get the
	                // global symbols in scope.  These results should be valid for either language as
	                // the set of symbols that can be referenced from this location.
	                if (!tryGetGlobalSymbols()) {
	                    return undefined;
	                }
	            }
	            log("getCompletionData: Semantic work: " + (new Date().getTime() - semanticStart));
	            return { symbols: symbols, isMemberCompletion: isMemberCompletion, isNewIdentifierLocation: isNewIdentifierLocation, location: location, isRightOfDot: (isRightOfDot || isRightOfOpenTag), isJsDocTagName: isJsDocTagName };
	            function getTypeScriptMemberSymbols() {
	                // Right of dot member completion list
	                isMemberCompletion = true;
	                isNewIdentifierLocation = false;
	                if (node.kind === 69 /* Identifier */ || node.kind === 136 /* QualifiedName */ || node.kind === 169 /* PropertyAccessExpression */) {
	                    var symbol = typeChecker.getSymbolAtLocation(node);
	                    // This is an alias, follow what it aliases
	                    if (symbol && symbol.flags & 8388608 /* Alias */) {
	                        symbol = typeChecker.getAliasedSymbol(symbol);
	                    }
	                    if (symbol && symbol.flags & 1952 /* HasExports */) {
	                        // Extract module or enum members
	                        var exportedSymbols = typeChecker.getExportsOfModule(symbol);
	                        ts.forEach(exportedSymbols, function (symbol) {
	                            if (typeChecker.isValidPropertyAccess((node.parent), symbol.name)) {
	                                symbols.push(symbol);
	                            }
	                        });
	                    }
	                }
	                var type = typeChecker.getTypeAtLocation(node);
	                addTypeProperties(type);
	            }
	            function addTypeProperties(type) {
	                if (type) {
	                    // Filter private properties
	                    for (var _i = 0, _a = type.getApparentProperties(); _i < _a.length; _i++) {
	                        var symbol = _a[_i];
	                        if (typeChecker.isValidPropertyAccess((node.parent), symbol.name)) {
	                            symbols.push(symbol);
	                        }
	                    }
	                    if (isJavaScriptFile && type.flags & 16384 /* Union */) {
	                        // In javascript files, for union types, we don't just get the members that
	                        // the individual types have in common, we also include all the members that
	                        // each individual type has.  This is because we're going to add all identifiers
	                        // anyways.  So we might as well elevate the members that were at least part
	                        // of the individual types to a higher status since we know what they are.
	                        var unionType = type;
	                        for (var _b = 0, _c = unionType.types; _b < _c.length; _b++) {
	                            var elementType = _c[_b];
	                            addTypeProperties(elementType);
	                        }
	                    }
	                }
	            }
	            function tryGetGlobalSymbols() {
	                var objectLikeContainer;
	                var namedImportsOrExports;
	                var jsxContainer;
	                if (objectLikeContainer = tryGetObjectLikeCompletionContainer(contextToken)) {
	                    return tryGetObjectLikeCompletionSymbols(objectLikeContainer);
	                }
	                if (namedImportsOrExports = tryGetNamedImportsOrExportsForCompletion(contextToken)) {
	                    // cursor is in an import clause
	                    // try to show exported member for imported module
	                    return tryGetImportOrExportClauseCompletionSymbols(namedImportsOrExports);
	                }
	                if (jsxContainer = tryGetContainingJsxElement(contextToken)) {
	                    var attrsType = void 0;
	                    if ((jsxContainer.kind === 237 /* JsxSelfClosingElement */) || (jsxContainer.kind === 238 /* JsxOpeningElement */)) {
	                        // Cursor is inside a JSX self-closing element or opening element
	                        attrsType = typeChecker.getJsxElementAttributesType(jsxContainer);
	                        if (attrsType) {
	                            symbols = filterJsxAttributes(typeChecker.getPropertiesOfType(attrsType), jsxContainer.attributes);
	                            isMemberCompletion = true;
	                            isNewIdentifierLocation = false;
	                            return true;
	                        }
	                    }
	                }
	                // Get all entities in the current scope.
	                isMemberCompletion = false;
	                isNewIdentifierLocation = isNewIdentifierDefinitionLocation(contextToken);
	                if (previousToken !== contextToken) {
	                    ts.Debug.assert(!!previousToken, "Expected 'contextToken' to be defined when different from 'previousToken'.");
	                }
	                // We need to find the node that will give us an appropriate scope to begin
	                // aggregating completion candidates. This is achieved in 'getScopeNode'
	                // by finding the first node that encompasses a position, accounting for whether a node
	                // is "complete" to decide whether a position belongs to the node.
	                //
	                // However, at the end of an identifier, we are interested in the scope of the identifier
	                // itself, but fall outside of the identifier. For instance:
	                //
	                //      xyz => x$
	                //
	                // the cursor is outside of both the 'x' and the arrow function 'xyz => x',
	                // so 'xyz' is not returned in our results.
	                //
	                // We define 'adjustedPosition' so that we may appropriately account for
	                // being at the end of an identifier. The intention is that if requesting completion
	                // at the end of an identifier, it should be effectively equivalent to requesting completion
	                // anywhere inside/at the beginning of the identifier. So in the previous case, the
	                // 'adjustedPosition' will work as if requesting completion in the following:
	                //
	                //      xyz => $x
	                //
	                // If previousToken !== contextToken, then
	                //   - 'contextToken' was adjusted to the token prior to 'previousToken'
	                //      because we were at the end of an identifier.
	                //   - 'previousToken' is defined.
	                var adjustedPosition = previousToken !== contextToken ?
	                    previousToken.getStart() :
	                    position;
	                var scopeNode = getScopeNode(contextToken, adjustedPosition, sourceFile) || sourceFile;
	                /// TODO filter meaning based on the current context
	                var symbolMeanings = 793056 /* Type */ | 107455 /* Value */ | 1536 /* Namespace */ | 8388608 /* Alias */;
	                symbols = typeChecker.getSymbolsInScope(scopeNode, symbolMeanings);
	                return true;
	            }
	            /**
	             * Finds the first node that "embraces" the position, so that one may
	             * accurately aggregate locals from the closest containing scope.
	             */
	            function getScopeNode(initialToken, position, sourceFile) {
	                var scope = initialToken;
	                while (scope && !ts.positionBelongsToNode(scope, position, sourceFile)) {
	                    scope = scope.parent;
	                }
	                return scope;
	            }
	            function isCompletionListBlocker(contextToken) {
	                var start = new Date().getTime();
	                var result = isInStringOrRegularExpressionOrTemplateLiteral(contextToken) ||
	                    isSolelyIdentifierDefinitionLocation(contextToken) ||
	                    isDotOfNumericLiteral(contextToken) ||
	                    isInJsxText(contextToken);
	                log("getCompletionsAtPosition: isCompletionListBlocker: " + (new Date().getTime() - start));
	                return result;
	            }
	            function isInJsxText(contextToken) {
	                if (contextToken.kind === 239 /* JsxText */) {
	                    return true;
	                }
	                if (contextToken.kind === 27 /* GreaterThanToken */ && contextToken.parent) {
	                    if (contextToken.parent.kind === 238 /* JsxOpeningElement */) {
	                        return true;
	                    }
	                    if (contextToken.parent.kind === 240 /* JsxClosingElement */ || contextToken.parent.kind === 237 /* JsxSelfClosingElement */) {
	                        return contextToken.parent.parent && contextToken.parent.parent.kind === 236 /* JsxElement */;
	                    }
	                }
	                return false;
	            }
	            function isNewIdentifierDefinitionLocation(previousToken) {
	                if (previousToken) {
	                    var containingNodeKind = previousToken.parent.kind;
	                    switch (previousToken.kind) {
	                        case 24 /* CommaToken */:
	                            return containingNodeKind === 171 /* CallExpression */ // func( a, |
	                                || containingNodeKind === 145 /* Constructor */ // constructor( a, |   /* public, protected, private keywords are allowed here, so show completion */
	                                || containingNodeKind === 172 /* NewExpression */ // new C(a, |
	                                || containingNodeKind === 167 /* ArrayLiteralExpression */ // [a, |
	                                || containingNodeKind === 184 /* BinaryExpression */ // const x = (a, |
	                                || containingNodeKind === 153 /* FunctionType */; // var x: (s: string, list|
	                        case 17 /* OpenParenToken */:
	                            return containingNodeKind === 171 /* CallExpression */ // func( |
	                                || containingNodeKind === 145 /* Constructor */ // constructor( |
	                                || containingNodeKind === 172 /* NewExpression */ // new C(a|
	                                || containingNodeKind === 175 /* ParenthesizedExpression */ // const x = (a|
	                                || containingNodeKind === 161 /* ParenthesizedType */; // function F(pred: (a| /* this can become an arrow function, where 'a' is the argument */
	                        case 19 /* OpenBracketToken */:
	                            return containingNodeKind === 167 /* ArrayLiteralExpression */ // [ |
	                                || containingNodeKind === 150 /* IndexSignature */ // [ | : string ]
	                                || containingNodeKind === 137 /* ComputedPropertyName */; // [ |    /* this can become an index signature */
	                        case 125 /* ModuleKeyword */: // module |
	                        case 126 /* NamespaceKeyword */:
	                            return true;
	                        case 21 /* DotToken */:
	                            return containingNodeKind === 221 /* ModuleDeclaration */; // module A.|
	                        case 15 /* OpenBraceToken */:
	                            return containingNodeKind === 217 /* ClassDeclaration */; // class A{ |
	                        case 56 /* EqualsToken */:
	                            return containingNodeKind === 214 /* VariableDeclaration */ // const x = a|
	                                || containingNodeKind === 184 /* BinaryExpression */; // x = a|
	                        case 12 /* TemplateHead */:
	                            return containingNodeKind === 186 /* TemplateExpression */; // `aa ${|
	                        case 13 /* TemplateMiddle */:
	                            return containingNodeKind === 193 /* TemplateSpan */; // `aa ${10} dd ${|
	                        case 112 /* PublicKeyword */:
	                        case 110 /* PrivateKeyword */:
	                        case 111 /* ProtectedKeyword */:
	                            return containingNodeKind === 142 /* PropertyDeclaration */; // class A{ public |
	                    }
	                    // Previous token may have been a keyword that was converted to an identifier.
	                    switch (previousToken.getText()) {
	                        case "public":
	                        case "protected":
	                        case "private":
	                            return true;
	                    }
	                }
	                return false;
	            }
	            function isInStringOrRegularExpressionOrTemplateLiteral(contextToken) {
	                if (contextToken.kind === 9 /* StringLiteral */
	                    || contextToken.kind === 163 /* StringLiteralType */
	                    || contextToken.kind === 10 /* RegularExpressionLiteral */
	                    || ts.isTemplateLiteralKind(contextToken.kind)) {
	                    var start_7 = contextToken.getStart();
	                    var end = contextToken.getEnd();
	                    // To be "in" one of these literals, the position has to be:
	                    //   1. entirely within the token text.
	                    //   2. at the end position of an unterminated token.
	                    //   3. at the end of a regular expression (due to trailing flags like '/foo/g').
	                    if (start_7 < position && position < end) {
	                        return true;
	                    }
	                    if (position === end) {
	                        return !!contextToken.isUnterminated
	                            || contextToken.kind === 10 /* RegularExpressionLiteral */;
	                    }
	                }
	                return false;
	            }
	            /**
	             * Aggregates relevant symbols for completion in object literals and object binding patterns.
	             * Relevant symbols are stored in the captured 'symbols' variable.
	             *
	             * @returns true if 'symbols' was successfully populated; false otherwise.
	             */
	            function tryGetObjectLikeCompletionSymbols(objectLikeContainer) {
	                // We're looking up possible property names from contextual/inferred/declared type.
	                isMemberCompletion = true;
	                var typeForObject;
	                var existingMembers;
	                if (objectLikeContainer.kind === 168 /* ObjectLiteralExpression */) {
	                    // We are completing on contextual types, but may also include properties
	                    // other than those within the declared type.
	                    isNewIdentifierLocation = true;
	                    typeForObject = typeChecker.getContextualType(objectLikeContainer);
	                    existingMembers = objectLikeContainer.properties;
	                }
	                else if (objectLikeContainer.kind === 164 /* ObjectBindingPattern */) {
	                    // We are *only* completing on properties from the type being destructured.
	                    isNewIdentifierLocation = false;
	                    var rootDeclaration = ts.getRootDeclaration(objectLikeContainer.parent);
	                    if (ts.isVariableLike(rootDeclaration)) {
	                        // We don't want to complete using the type acquired by the shape
	                        // of the binding pattern; we are only interested in types acquired
	                        // through type declaration or inference.
	                        if (rootDeclaration.initializer || rootDeclaration.type) {
	                            typeForObject = typeChecker.getTypeAtLocation(objectLikeContainer);
	                            existingMembers = objectLikeContainer.elements;
	                        }
	                    }
	                    else {
	                        ts.Debug.fail("Root declaration is not variable-like.");
	                    }
	                }
	                else {
	                    ts.Debug.fail("Expected object literal or binding pattern, got " + objectLikeContainer.kind);
	                }
	                if (!typeForObject) {
	                    return false;
	                }
	                var typeMembers = typeChecker.getPropertiesOfType(typeForObject);
	                if (typeMembers && typeMembers.length > 0) {
	                    // Add filtered items to the completion list
	                    symbols = filterObjectMembersList(typeMembers, existingMembers);
	                }
	                return true;
	            }
	            /**
	             * Aggregates relevant symbols for completion in import clauses and export clauses
	             * whose declarations have a module specifier; for instance, symbols will be aggregated for
	             *
	             *      import { | } from "moduleName";
	             *      export { a as foo, | } from "moduleName";
	             *
	             * but not for
	             *
	             *      export { | };
	             *
	             * Relevant symbols are stored in the captured 'symbols' variable.
	             *
	             * @returns true if 'symbols' was successfully populated; false otherwise.
	             */
	            function tryGetImportOrExportClauseCompletionSymbols(namedImportsOrExports) {
	                var declarationKind = namedImportsOrExports.kind === 228 /* NamedImports */ ?
	                    225 /* ImportDeclaration */ :
	                    231 /* ExportDeclaration */;
	                var importOrExportDeclaration = ts.getAncestor(namedImportsOrExports, declarationKind);
	                var moduleSpecifier = importOrExportDeclaration.moduleSpecifier;
	                if (!moduleSpecifier) {
	                    return false;
	                }
	                isMemberCompletion = true;
	                isNewIdentifierLocation = false;
	                var exports;
	                var moduleSpecifierSymbol = typeChecker.getSymbolAtLocation(importOrExportDeclaration.moduleSpecifier);
	                if (moduleSpecifierSymbol) {
	                    exports = typeChecker.getExportsOfModule(moduleSpecifierSymbol);
	                }
	                symbols = exports ? filterNamedImportOrExportCompletionItems(exports, namedImportsOrExports.elements) : emptyArray;
	                return true;
	            }
	            /**
	             * Returns the immediate owning object literal or binding pattern of a context token,
	             * on the condition that one exists and that the context implies completion should be given.
	             */
	            function tryGetObjectLikeCompletionContainer(contextToken) {
	                if (contextToken) {
	                    switch (contextToken.kind) {
	                        case 15 /* OpenBraceToken */: // const x = { |
	                        case 24 /* CommaToken */:
	                            var parent_12 = contextToken.parent;
	                            if (parent_12 && (parent_12.kind === 168 /* ObjectLiteralExpression */ || parent_12.kind === 164 /* ObjectBindingPattern */)) {
	                                return parent_12;
	                            }
	                            break;
	                    }
	                }
	                return undefined;
	            }
	            /**
	             * Returns the containing list of named imports or exports of a context token,
	             * on the condition that one exists and that the context implies completion should be given.
	             */
	            function tryGetNamedImportsOrExportsForCompletion(contextToken) {
	                if (contextToken) {
	                    switch (contextToken.kind) {
	                        case 15 /* OpenBraceToken */: // import { |
	                        case 24 /* CommaToken */:
	                            switch (contextToken.parent.kind) {
	                                case 228 /* NamedImports */:
	                                case 232 /* NamedExports */:
	                                    return contextToken.parent;
	                            }
	                    }
	                }
	                return undefined;
	            }
	            function tryGetContainingJsxElement(contextToken) {
	                if (contextToken) {
	                    var parent_13 = contextToken.parent;
	                    switch (contextToken.kind) {
	                        case 26 /* LessThanSlashToken */:
	                        case 39 /* SlashToken */:
	                        case 69 /* Identifier */:
	                        case 241 /* JsxAttribute */:
	                        case 242 /* JsxSpreadAttribute */:
	                            if (parent_13 && (parent_13.kind === 237 /* JsxSelfClosingElement */ || parent_13.kind === 238 /* JsxOpeningElement */)) {
	                                return parent_13;
	                            }
	                            else if (parent_13.kind === 241 /* JsxAttribute */) {
	                                return parent_13.parent;
	                            }
	                            break;
	                        // The context token is the closing } or " of an attribute, which means
	                        // its parent is a JsxExpression, whose parent is a JsxAttribute,
	                        // whose parent is a JsxOpeningLikeElement
	                        case 9 /* StringLiteral */:
	                            if (parent_13 && ((parent_13.kind === 241 /* JsxAttribute */) || (parent_13.kind === 242 /* JsxSpreadAttribute */))) {
	                                return parent_13.parent;
	                            }
	                            break;
	                        case 16 /* CloseBraceToken */:
	                            if (parent_13 &&
	                                parent_13.kind === 243 /* JsxExpression */ &&
	                                parent_13.parent &&
	                                (parent_13.parent.kind === 241 /* JsxAttribute */)) {
	                                return parent_13.parent.parent;
	                            }
	                            if (parent_13 && parent_13.kind === 242 /* JsxSpreadAttribute */) {
	                                return parent_13.parent;
	                            }
	                            break;
	                    }
	                }
	                return undefined;
	            }
	            function isFunction(kind) {
	                switch (kind) {
	                    case 176 /* FunctionExpression */:
	                    case 177 /* ArrowFunction */:
	                    case 216 /* FunctionDeclaration */:
	                    case 144 /* MethodDeclaration */:
	                    case 143 /* MethodSignature */:
	                    case 146 /* GetAccessor */:
	                    case 147 /* SetAccessor */:
	                    case 148 /* CallSignature */:
	                    case 149 /* ConstructSignature */:
	                    case 150 /* IndexSignature */:
	                        return true;
	                }
	                return false;
	            }
	            /**
	             * @returns true if we are certain that the currently edited location must define a new location; false otherwise.
	             */
	            function isSolelyIdentifierDefinitionLocation(contextToken) {
	                var containingNodeKind = contextToken.parent.kind;
	                switch (contextToken.kind) {
	                    case 24 /* CommaToken */:
	                        return containingNodeKind === 214 /* VariableDeclaration */ ||
	                            containingNodeKind === 215 /* VariableDeclarationList */ ||
	                            containingNodeKind === 196 /* VariableStatement */ ||
	                            containingNodeKind === 220 /* EnumDeclaration */ ||
	                            isFunction(containingNodeKind) ||
	                            containingNodeKind === 217 /* ClassDeclaration */ ||
	                            containingNodeKind === 189 /* ClassExpression */ ||
	                            containingNodeKind === 218 /* InterfaceDeclaration */ ||
	                            containingNodeKind === 165 /* ArrayBindingPattern */ ||
	                            containingNodeKind === 219 /* TypeAliasDeclaration */; // type Map, K, |
	                    case 21 /* DotToken */:
	                        return containingNodeKind === 165 /* ArrayBindingPattern */; // var [.|
	                    case 54 /* ColonToken */:
	                        return containingNodeKind === 166 /* BindingElement */; // var {x :html|
	                    case 19 /* OpenBracketToken */:
	                        return containingNodeKind === 165 /* ArrayBindingPattern */; // var [x|
	                    case 17 /* OpenParenToken */:
	                        return containingNodeKind === 247 /* CatchClause */ ||
	                            isFunction(containingNodeKind);
	                    case 15 /* OpenBraceToken */:
	                        return containingNodeKind === 220 /* EnumDeclaration */ ||
	                            containingNodeKind === 218 /* InterfaceDeclaration */ ||
	                            containingNodeKind === 156 /* TypeLiteral */; // const x : { |
	                    case 23 /* SemicolonToken */:
	                        return containingNodeKind === 141 /* PropertySignature */ &&
	                            contextToken.parent && contextToken.parent.parent &&
	                            (contextToken.parent.parent.kind === 218 /* InterfaceDeclaration */ ||
	                                contextToken.parent.parent.kind === 156 /* TypeLiteral */); // const x : { a; |
	                    case 25 /* LessThanToken */:
	                        return containingNodeKind === 217 /* ClassDeclaration */ ||
	                            containingNodeKind === 189 /* ClassExpression */ ||
	                            containingNodeKind === 218 /* InterfaceDeclaration */ ||
	                            containingNodeKind === 219 /* TypeAliasDeclaration */ ||
	                            isFunction(containingNodeKind);
	                    case 113 /* StaticKeyword */:
	                        return containingNodeKind === 142 /* PropertyDeclaration */;
	                    case 22 /* DotDotDotToken */:
	                        return containingNodeKind === 139 /* Parameter */ ||
	                            (contextToken.parent && contextToken.parent.parent &&
	                                contextToken.parent.parent.kind === 165 /* ArrayBindingPattern */); // var [...z|
	                    case 112 /* PublicKeyword */:
	                    case 110 /* PrivateKeyword */:
	                    case 111 /* ProtectedKeyword */:
	                        return containingNodeKind === 139 /* Parameter */;
	                    case 116 /* AsKeyword */:
	                        return containingNodeKind === 229 /* ImportSpecifier */ ||
	                            containingNodeKind === 233 /* ExportSpecifier */ ||
	                            containingNodeKind === 227 /* NamespaceImport */;
	                    case 73 /* ClassKeyword */:
	                    case 81 /* EnumKeyword */:
	                    case 107 /* InterfaceKeyword */:
	                    case 87 /* FunctionKeyword */:
	                    case 102 /* VarKeyword */:
	                    case 123 /* GetKeyword */:
	                    case 129 /* SetKeyword */:
	                    case 89 /* ImportKeyword */:
	                    case 108 /* LetKeyword */:
	                    case 74 /* ConstKeyword */:
	                    case 114 /* YieldKeyword */:
	                    case 132 /* TypeKeyword */:
	                        return true;
	                }
	                // Previous token may have been a keyword that was converted to an identifier.
	                switch (contextToken.getText()) {
	                    case "abstract":
	                    case "async":
	                    case "class":
	                    case "const":
	                    case "declare":
	                    case "enum":
	                    case "function":
	                    case "interface":
	                    case "let":
	                    case "private":
	                    case "protected":
	                    case "public":
	                    case "static":
	                    case "var":
	                    case "yield":
	                        return true;
	                }
	                return false;
	            }
	            function isDotOfNumericLiteral(contextToken) {
	                if (contextToken.kind === 8 /* NumericLiteral */) {
	                    var text = contextToken.getFullText();
	                    return text.charAt(text.length - 1) === ".";
	                }
	                return false;
	            }
	            /**
	             * Filters out completion suggestions for named imports or exports.
	             *
	             * @param exportsOfModule          The list of symbols which a module exposes.
	             * @param namedImportsOrExports    The list of existing import/export specifiers in the import/export clause.
	             *
	             * @returns Symbols to be suggested at an import/export clause, barring those whose named imports/exports
	             *          do not occur at the current position and have not otherwise been typed.
	             */
	            function filterNamedImportOrExportCompletionItems(exportsOfModule, namedImportsOrExports) {
	                var exisingImportsOrExports = {};
	                for (var _i = 0, namedImportsOrExports_1 = namedImportsOrExports; _i < namedImportsOrExports_1.length; _i++) {
	                    var element = namedImportsOrExports_1[_i];
	                    // If this is the current item we are editing right now, do not filter it out
	                    if (element.getStart() <= position && position <= element.getEnd()) {
	                        continue;
	                    }
	                    var name_35 = element.propertyName || element.name;
	                    exisingImportsOrExports[name_35.text] = true;
	                }
	                if (ts.isEmpty(exisingImportsOrExports)) {
	                    return exportsOfModule;
	                }
	                return ts.filter(exportsOfModule, function (e) { return !ts.lookUp(exisingImportsOrExports, e.name); });
	            }
	            /**
	             * Filters out completion suggestions for named imports or exports.
	             *
	             * @returns Symbols to be suggested in an object binding pattern or object literal expression, barring those whose declarations
	             *          do not occur at the current position and have not otherwise been typed.
	             */
	            function filterObjectMembersList(contextualMemberSymbols, existingMembers) {
	                if (!existingMembers || existingMembers.length === 0) {
	                    return contextualMemberSymbols;
	                }
	                var existingMemberNames = {};
	                for (var _i = 0, existingMembers_1 = existingMembers; _i < existingMembers_1.length; _i++) {
	                    var m = existingMembers_1[_i];
	                    // Ignore omitted expressions for missing members
	                    if (m.kind !== 248 /* PropertyAssignment */ &&
	                        m.kind !== 249 /* ShorthandPropertyAssignment */ &&
	                        m.kind !== 166 /* BindingElement */ &&
	                        m.kind !== 144 /* MethodDeclaration */) {
	                        continue;
	                    }
	                    // If this is the current item we are editing right now, do not filter it out
	                    if (m.getStart() <= position && position <= m.getEnd()) {
	                        continue;
	                    }
	                    var existingName = void 0;
	                    if (m.kind === 166 /* BindingElement */ && m.propertyName) {
	                        // include only identifiers in completion list
	                        if (m.propertyName.kind === 69 /* Identifier */) {
	                            existingName = m.propertyName.text;
	                        }
	                    }
	                    else {
	                        // TODO(jfreeman): Account for computed property name
	                        // NOTE: if one only performs this step when m.name is an identifier,
	                        // things like '__proto__' are not filtered out.
	                        existingName = m.name.text;
	                    }
	                    existingMemberNames[existingName] = true;
	                }
	                return ts.filter(contextualMemberSymbols, function (m) { return !ts.lookUp(existingMemberNames, m.name); });
	            }
	            /**
	             * Filters out completion suggestions from 'symbols' according to existing JSX attributes.
	             *
	             * @returns Symbols to be suggested in a JSX element, barring those whose attributes
	             *          do not occur at the current position and have not otherwise been typed.
	             */
	            function filterJsxAttributes(symbols, attributes) {
	                var seenNames = {};
	                for (var _i = 0, attributes_1 = attributes; _i < attributes_1.length; _i++) {
	                    var attr = attributes_1[_i];
	                    // If this is the current item we are editing right now, do not filter it out
	                    if (attr.getStart() <= position && position <= attr.getEnd()) {
	                        continue;
	                    }
	                    if (attr.kind === 241 /* JsxAttribute */) {
	                        seenNames[attr.name.text] = true;
	                    }
	                }
	                return ts.filter(symbols, function (a) { return !ts.lookUp(seenNames, a.name); });
	            }
	        }
	        function getCompletionsAtPosition(fileName, position) {
	            synchronizeHostData();
	            var completionData = getCompletionData(fileName, position);
	            if (!completionData) {
	                return undefined;
	            }
	            var symbols = completionData.symbols, isMemberCompletion = completionData.isMemberCompletion, isNewIdentifierLocation = completionData.isNewIdentifierLocation, location = completionData.location, isJsDocTagName = completionData.isJsDocTagName;
	            if (isJsDocTagName) {
	                // If the current position is a jsDoc tag name, only tag names should be provided for completion
	                return { isMemberCompletion: false, isNewIdentifierLocation: false, entries: getAllJsDocCompletionEntries() };
	            }
	            var sourceFile = getValidSourceFile(fileName);
	            var entries = [];
	            if (ts.isSourceFileJavaScript(sourceFile)) {
	                var uniqueNames = getCompletionEntriesFromSymbols(symbols, entries);
	                ts.addRange(entries, getJavaScriptCompletionEntries(sourceFile, location.pos, uniqueNames));
	            }
	            else {
	                if (!symbols || symbols.length === 0) {
	                    if (sourceFile.languageVariant === 1 /* JSX */ &&
	                        location.parent && location.parent.kind === 240 /* JsxClosingElement */) {
	                        // In the TypeScript JSX element, if such element is not defined. When users query for completion at closing tag,
	                        // instead of simply giving unknown value, the completion will return the tag-name of an associated opening-element.
	                        // For example:
	                        //     var x = <div> </ /*1*/>  completion list at "1" will contain "div" with type any
	                        var tagName = location.parent.parent.openingElement.tagName;
	                        entries.push({
	                            name: tagName.text,
	                            kind: undefined,
	                            kindModifiers: undefined,
	                            sortText: "0"
	                        });
	                    }
	                    else {
	                        return undefined;
	                    }
	                }
	                getCompletionEntriesFromSymbols(symbols, entries);
	            }
	            // Add keywords if this is not a member completion list
	            if (!isMemberCompletion && !isJsDocTagName) {
	                ts.addRange(entries, keywordCompletions);
	            }
	            return { isMemberCompletion: isMemberCompletion, isNewIdentifierLocation: isNewIdentifierLocation, entries: entries };
	            function getJavaScriptCompletionEntries(sourceFile, position, uniqueNames) {
	                var entries = [];
	                var target = program.getCompilerOptions().target;
	                var nameTable = getNameTable(sourceFile);
	                for (var name_36 in nameTable) {
	                    // Skip identifiers produced only from the current location
	                    if (nameTable[name_36] === position) {
	                        continue;
	                    }
	                    if (!uniqueNames[name_36]) {
	                        uniqueNames[name_36] = name_36;
	                        var displayName = getCompletionEntryDisplayName(name_36, target, /*performCharacterChecks*/ true);
	                        if (displayName) {
	                            var entry = {
	                                name: displayName,
	                                kind: ScriptElementKind.warning,
	                                kindModifiers: "",
	                                sortText: "1"
	                            };
	                            entries.push(entry);
	                        }
	                    }
	                }
	                return entries;
	            }
	            function getAllJsDocCompletionEntries() {
	                return jsDocCompletionEntries || (jsDocCompletionEntries = ts.map(jsDocTagNames, function (tagName) {
	                    return {
	                        name: tagName,
	                        kind: ScriptElementKind.keyword,
	                        kindModifiers: "",
	                        sortText: "0"
	                    };
	                }));
	            }
	            function createCompletionEntry(symbol, location) {
	                // Try to get a valid display name for this symbol, if we could not find one, then ignore it.
	                // We would like to only show things that can be added after a dot, so for instance numeric properties can
	                // not be accessed with a dot (a.1 <- invalid)
	                var displayName = getCompletionEntryDisplayNameForSymbol(symbol, program.getCompilerOptions().target, /*performCharacterChecks*/ true, location);
	                if (!displayName) {
	                    return undefined;
	                }
	                // TODO(drosen): Right now we just permit *all* semantic meanings when calling
	                // 'getSymbolKind' which is permissible given that it is backwards compatible; but
	                // really we should consider passing the meaning for the node so that we don't report
	                // that a suggestion for a value is an interface.  We COULD also just do what
	                // 'getSymbolModifiers' does, which is to use the first declaration.
	                // Use a 'sortText' of 0' so that all symbol completion entries come before any other
	                // entries (like JavaScript identifier entries).
	                return {
	                    name: displayName,
	                    kind: getSymbolKind(symbol, location),
	                    kindModifiers: getSymbolModifiers(symbol),
	                    sortText: "0"
	                };
	            }
	            function getCompletionEntriesFromSymbols(symbols, entries) {
	                var start = new Date().getTime();
	                var uniqueNames = {};
	                if (symbols) {
	                    for (var _i = 0, symbols_4 = symbols; _i < symbols_4.length; _i++) {
	                        var symbol = symbols_4[_i];
	                        var entry = createCompletionEntry(symbol, location);
	                        if (entry) {
	                            var id = ts.escapeIdentifier(entry.name);
	                            if (!ts.lookUp(uniqueNames, id)) {
	                                entries.push(entry);
	                                uniqueNames[id] = id;
	                            }
	                        }
	                    }
	                }
	                log("getCompletionsAtPosition: getCompletionEntriesFromSymbols: " + (new Date().getTime() - start));
	                return uniqueNames;
	            }
	        }
	        function getCompletionEntryDetails(fileName, position, entryName) {
	            synchronizeHostData();
	            // Compute all the completion symbols again.
	            var completionData = getCompletionData(fileName, position);
	            if (completionData) {
	                var symbols = completionData.symbols, location_2 = completionData.location;
	                // Find the symbol with the matching entry name.
	                var target_2 = program.getCompilerOptions().target;
	                // We don't need to perform character checks here because we're only comparing the
	                // name against 'entryName' (which is known to be good), not building a new
	                // completion entry.
	                var symbol = ts.forEach(symbols, function (s) { return getCompletionEntryDisplayNameForSymbol(s, target_2, /*performCharacterChecks*/ false, location_2) === entryName ? s : undefined; });
	                if (symbol) {
	                    var _a = getSymbolDisplayPartsDocumentationAndSymbolKind(symbol, getValidSourceFile(fileName), location_2, location_2, 7 /* All */), displayParts = _a.displayParts, documentation = _a.documentation, symbolKind = _a.symbolKind;
	                    return {
	                        name: entryName,
	                        kindModifiers: getSymbolModifiers(symbol),
	                        kind: symbolKind,
	                        displayParts: displayParts,
	                        documentation: documentation
	                    };
	                }
	            }
	            // Didn't find a symbol with this name.  See if we can find a keyword instead.
	            var keywordCompletion = ts.forEach(keywordCompletions, function (c) { return c.name === entryName; });
	            if (keywordCompletion) {
	                return {
	                    name: entryName,
	                    kind: ScriptElementKind.keyword,
	                    kindModifiers: ScriptElementKindModifier.none,
	                    displayParts: [ts.displayPart(entryName, SymbolDisplayPartKind.keyword)],
	                    documentation: undefined
	                };
	            }
	            return undefined;
	        }
	        // TODO(drosen): use contextual SemanticMeaning.
	        function getSymbolKind(symbol, location) {
	            var flags = symbol.getFlags();
	            if (flags & 32 /* Class */)
	                return ts.getDeclarationOfKind(symbol, 189 /* ClassExpression */) ?
	                    ScriptElementKind.localClassElement : ScriptElementKind.classElement;
	            if (flags & 384 /* Enum */)
	                return ScriptElementKind.enumElement;
	            if (flags & 524288 /* TypeAlias */)
	                return ScriptElementKind.typeElement;
	            if (flags & 64 /* Interface */)
	                return ScriptElementKind.interfaceElement;
	            if (flags & 262144 /* TypeParameter */)
	                return ScriptElementKind.typeParameterElement;
	            var result = getSymbolKindOfConstructorPropertyMethodAccessorFunctionOrVar(symbol, flags, location);
	            if (result === ScriptElementKind.unknown) {
	                if (flags & 262144 /* TypeParameter */)
	                    return ScriptElementKind.typeParameterElement;
	                if (flags & 8 /* EnumMember */)
	                    return ScriptElementKind.variableElement;
	                if (flags & 8388608 /* Alias */)
	                    return ScriptElementKind.alias;
	                if (flags & 1536 /* Module */)
	                    return ScriptElementKind.moduleElement;
	            }
	            return result;
	        }
	        function getSymbolKindOfConstructorPropertyMethodAccessorFunctionOrVar(symbol, flags, location) {
	            var typeChecker = program.getTypeChecker();
	            if (typeChecker.isUndefinedSymbol(symbol)) {
	                return ScriptElementKind.variableElement;
	            }
	            if (typeChecker.isArgumentsSymbol(symbol)) {
	                return ScriptElementKind.localVariableElement;
	            }
	            if (flags & 3 /* Variable */) {
	                if (ts.isFirstDeclarationOfSymbolParameter(symbol)) {
	                    return ScriptElementKind.parameterElement;
	                }
	                else if (symbol.valueDeclaration && ts.isConst(symbol.valueDeclaration)) {
	                    return ScriptElementKind.constElement;
	                }
	                else if (ts.forEach(symbol.declarations, ts.isLet)) {
	                    return ScriptElementKind.letElement;
	                }
	                return isLocalVariableOrFunction(symbol) ? ScriptElementKind.localVariableElement : ScriptElementKind.variableElement;
	            }
	            if (flags & 16 /* Function */)
	                return isLocalVariableOrFunction(symbol) ? ScriptElementKind.localFunctionElement : ScriptElementKind.functionElement;
	            if (flags & 32768 /* GetAccessor */)
	                return ScriptElementKind.memberGetAccessorElement;
	            if (flags & 65536 /* SetAccessor */)
	                return ScriptElementKind.memberSetAccessorElement;
	            if (flags & 8192 /* Method */)
	                return ScriptElementKind.memberFunctionElement;
	            if (flags & 16384 /* Constructor */)
	                return ScriptElementKind.constructorImplementationElement;
	            if (flags & 4 /* Property */) {
	                if (flags & 268435456 /* SyntheticProperty */) {
	                    // If union property is result of union of non method (property/accessors/variables), it is labeled as property
	                    var unionPropertyKind = ts.forEach(typeChecker.getRootSymbols(symbol), function (rootSymbol) {
	                        var rootSymbolFlags = rootSymbol.getFlags();
	                        if (rootSymbolFlags & (98308 /* PropertyOrAccessor */ | 3 /* Variable */)) {
	                            return ScriptElementKind.memberVariableElement;
	                        }
	                        ts.Debug.assert(!!(rootSymbolFlags & 8192 /* Method */));
	                    });
	                    if (!unionPropertyKind) {
	                        // If this was union of all methods,
	                        // make sure it has call signatures before we can label it as method
	                        var typeOfUnionProperty = typeChecker.getTypeOfSymbolAtLocation(symbol, location);
	                        if (typeOfUnionProperty.getCallSignatures().length) {
	                            return ScriptElementKind.memberFunctionElement;
	                        }
	                        return ScriptElementKind.memberVariableElement;
	                    }
	                    return unionPropertyKind;
	                }
	                return ScriptElementKind.memberVariableElement;
	            }
	            return ScriptElementKind.unknown;
	        }
	        function getSymbolModifiers(symbol) {
	            return symbol && symbol.declarations && symbol.declarations.length > 0
	                ? ts.getNodeModifiers(symbol.declarations[0])
	                : ScriptElementKindModifier.none;
	        }
	        // TODO(drosen): Currently completion entry details passes the SemanticMeaning.All instead of using semanticMeaning of location
	        function getSymbolDisplayPartsDocumentationAndSymbolKind(symbol, sourceFile, enclosingDeclaration, location, semanticMeaning) {
	            if (semanticMeaning === void 0) { semanticMeaning = getMeaningFromLocation(location); }
	            var typeChecker = program.getTypeChecker();
	            var displayParts = [];
	            var documentation;
	            var symbolFlags = symbol.flags;
	            var symbolKind = getSymbolKindOfConstructorPropertyMethodAccessorFunctionOrVar(symbol, symbolFlags, location);
	            var hasAddedSymbolInfo;
	            var type;
	            // Class at constructor site need to be shown as constructor apart from property,method, vars
	            if (symbolKind !== ScriptElementKind.unknown || symbolFlags & 32 /* Class */ || symbolFlags & 8388608 /* Alias */) {
	                // If it is accessor they are allowed only if location is at name of the accessor
	                if (symbolKind === ScriptElementKind.memberGetAccessorElement || symbolKind === ScriptElementKind.memberSetAccessorElement) {
	                    symbolKind = ScriptElementKind.memberVariableElement;
	                }
	                var signature = void 0;
	                type = typeChecker.getTypeOfSymbolAtLocation(symbol, location);
	                if (type) {
	                    if (location.parent && location.parent.kind === 169 /* PropertyAccessExpression */) {
	                        var right = location.parent.name;
	                        // Either the location is on the right of a property access, or on the left and the right is missing
	                        if (right === location || (right && right.getFullWidth() === 0)) {
	                            location = location.parent;
	                        }
	                    }
	                    // try get the call/construct signature from the type if it matches
	                    var callExpression = void 0;
	                    if (location.kind === 171 /* CallExpression */ || location.kind === 172 /* NewExpression */) {
	                        callExpression = location;
	                    }
	                    else if (isCallExpressionTarget(location) || isNewExpressionTarget(location)) {
	                        callExpression = location.parent;
	                    }
	                    if (callExpression) {
	                        var candidateSignatures = [];
	                        signature = typeChecker.getResolvedSignature(callExpression, candidateSignatures);
	                        if (!signature && candidateSignatures.length) {
	                            // Use the first candidate:
	                            signature = candidateSignatures[0];
	                        }
	                        var useConstructSignatures = callExpression.kind === 172 /* NewExpression */ || callExpression.expression.kind === 95 /* SuperKeyword */;
	                        var allSignatures = useConstructSignatures ? type.getConstructSignatures() : type.getCallSignatures();
	                        if (!ts.contains(allSignatures, signature.target) && !ts.contains(allSignatures, signature)) {
	                            // Get the first signature if there is one -- allSignatures may contain
	                            // either the original signature or its target, so check for either
	                            signature = allSignatures.length ? allSignatures[0] : undefined;
	                        }
	                        if (signature) {
	                            if (useConstructSignatures && (symbolFlags & 32 /* Class */)) {
	                                // Constructor
	                                symbolKind = ScriptElementKind.constructorImplementationElement;
	                                addPrefixForAnyFunctionOrVar(type.symbol, symbolKind);
	                            }
	                            else if (symbolFlags & 8388608 /* Alias */) {
	                                symbolKind = ScriptElementKind.alias;
	                                pushTypePart(symbolKind);
	                                displayParts.push(ts.spacePart());
	                                if (useConstructSignatures) {
	                                    displayParts.push(ts.keywordPart(92 /* NewKeyword */));
	                                    displayParts.push(ts.spacePart());
	                                }
	                                addFullSymbolName(symbol);
	                            }
	                            else {
	                                addPrefixForAnyFunctionOrVar(symbol, symbolKind);
	                            }
	                            switch (symbolKind) {
	                                case ScriptElementKind.memberVariableElement:
	                                case ScriptElementKind.variableElement:
	                                case ScriptElementKind.constElement:
	                                case ScriptElementKind.letElement:
	                                case ScriptElementKind.parameterElement:
	                                case ScriptElementKind.localVariableElement:
	                                    // If it is call or construct signature of lambda's write type name
	                                    displayParts.push(ts.punctuationPart(54 /* ColonToken */));
	                                    displayParts.push(ts.spacePart());
	                                    if (useConstructSignatures) {
	                                        displayParts.push(ts.keywordPart(92 /* NewKeyword */));
	                                        displayParts.push(ts.spacePart());
	                                    }
	                                    if (!(type.flags & 65536 /* Anonymous */)) {
	                                        ts.addRange(displayParts, ts.symbolToDisplayParts(typeChecker, type.symbol, enclosingDeclaration, /*meaning*/ undefined, 1 /* WriteTypeParametersOrArguments */));
	                                    }
	                                    addSignatureDisplayParts(signature, allSignatures, 8 /* WriteArrowStyleSignature */);
	                                    break;
	                                default:
	                                    // Just signature
	                                    addSignatureDisplayParts(signature, allSignatures);
	                            }
	                            hasAddedSymbolInfo = true;
	                        }
	                    }
	                    else if ((isNameOfFunctionDeclaration(location) && !(symbol.flags & 98304 /* Accessor */)) ||
	                        (location.kind === 121 /* ConstructorKeyword */ && location.parent.kind === 145 /* Constructor */)) {
	                        // get the signature from the declaration and write it
	                        var functionDeclaration = location.parent;
	                        var allSignatures = functionDeclaration.kind === 145 /* Constructor */ ? type.getConstructSignatures() : type.getCallSignatures();
	                        if (!typeChecker.isImplementationOfOverload(functionDeclaration)) {
	                            signature = typeChecker.getSignatureFromDeclaration(functionDeclaration);
	                        }
	                        else {
	                            signature = allSignatures[0];
	                        }
	                        if (functionDeclaration.kind === 145 /* Constructor */) {
	                            // show (constructor) Type(...) signature
	                            symbolKind = ScriptElementKind.constructorImplementationElement;
	                            addPrefixForAnyFunctionOrVar(type.symbol, symbolKind);
	                        }
	                        else {
	                            // (function/method) symbol(..signature)
	                            addPrefixForAnyFunctionOrVar(functionDeclaration.kind === 148 /* CallSignature */ &&
	                                !(type.symbol.flags & 2048 /* TypeLiteral */ || type.symbol.flags & 4096 /* ObjectLiteral */) ? type.symbol : symbol, symbolKind);
	                        }
	                        addSignatureDisplayParts(signature, allSignatures);
	                        hasAddedSymbolInfo = true;
	                    }
	                }
	            }
	            if (symbolFlags & 32 /* Class */ && !hasAddedSymbolInfo) {
	                if (ts.getDeclarationOfKind(symbol, 189 /* ClassExpression */)) {
	                    // Special case for class expressions because we would like to indicate that
	                    // the class name is local to the class body (similar to function expression)
	                    //      (local class) class <className>
	                    pushTypePart(ScriptElementKind.localClassElement);
	                }
	                else {
	                    // Class declaration has name which is not local.
	                    displayParts.push(ts.keywordPart(73 /* ClassKeyword */));
	                }
	                displayParts.push(ts.spacePart());
	                addFullSymbolName(symbol);
	                writeTypeParametersOfSymbol(symbol, sourceFile);
	            }
	            if ((symbolFlags & 64 /* Interface */) && (semanticMeaning & 2 /* Type */)) {
	                addNewLineIfDisplayPartsExist();
	                displayParts.push(ts.keywordPart(107 /* InterfaceKeyword */));
	                displayParts.push(ts.spacePart());
	                addFullSymbolName(symbol);
	                writeTypeParametersOfSymbol(symbol, sourceFile);
	            }
	            if (symbolFlags & 524288 /* TypeAlias */) {
	                addNewLineIfDisplayPartsExist();
	                displayParts.push(ts.keywordPart(132 /* TypeKeyword */));
	                displayParts.push(ts.spacePart());
	                addFullSymbolName(symbol);
	                writeTypeParametersOfSymbol(symbol, sourceFile);
	                displayParts.push(ts.spacePart());
	                displayParts.push(ts.operatorPart(56 /* EqualsToken */));
	                displayParts.push(ts.spacePart());
	                ts.addRange(displayParts, ts.typeToDisplayParts(typeChecker, typeChecker.getDeclaredTypeOfSymbol(symbol), enclosingDeclaration));
	            }
	            if (symbolFlags & 384 /* Enum */) {
	                addNewLineIfDisplayPartsExist();
	                if (ts.forEach(symbol.declarations, ts.isConstEnumDeclaration)) {
	                    displayParts.push(ts.keywordPart(74 /* ConstKeyword */));
	                    displayParts.push(ts.spacePart());
	                }
	                displayParts.push(ts.keywordPart(81 /* EnumKeyword */));
	                displayParts.push(ts.spacePart());
	                addFullSymbolName(symbol);
	            }
	            if (symbolFlags & 1536 /* Module */) {
	                addNewLineIfDisplayPartsExist();
	                var declaration = ts.getDeclarationOfKind(symbol, 221 /* ModuleDeclaration */);
	                var isNamespace = declaration && declaration.name && declaration.name.kind === 69 /* Identifier */;
	                displayParts.push(ts.keywordPart(isNamespace ? 126 /* NamespaceKeyword */ : 125 /* ModuleKeyword */));
	                displayParts.push(ts.spacePart());
	                addFullSymbolName(symbol);
	            }
	            if ((symbolFlags & 262144 /* TypeParameter */) && (semanticMeaning & 2 /* Type */)) {
	                addNewLineIfDisplayPartsExist();
	                displayParts.push(ts.punctuationPart(17 /* OpenParenToken */));
	                displayParts.push(ts.textPart("type parameter"));
	                displayParts.push(ts.punctuationPart(18 /* CloseParenToken */));
	                displayParts.push(ts.spacePart());
	                addFullSymbolName(symbol);
	                displayParts.push(ts.spacePart());
	                displayParts.push(ts.keywordPart(90 /* InKeyword */));
	                displayParts.push(ts.spacePart());
	                if (symbol.parent) {
	                    // Class/Interface type parameter
	                    addFullSymbolName(symbol.parent, enclosingDeclaration);
	                    writeTypeParametersOfSymbol(symbol.parent, enclosingDeclaration);
	                }
	                else {
	                    // Method/function type parameter
	                    var declaration = ts.getDeclarationOfKind(symbol, 138 /* TypeParameter */);
	                    ts.Debug.assert(declaration !== undefined);
	                    declaration = declaration.parent;
	                    if (declaration) {
	                        if (ts.isFunctionLikeKind(declaration.kind)) {
	                            var signature = typeChecker.getSignatureFromDeclaration(declaration);
	                            if (declaration.kind === 149 /* ConstructSignature */) {
	                                displayParts.push(ts.keywordPart(92 /* NewKeyword */));
	                                displayParts.push(ts.spacePart());
	                            }
	                            else if (declaration.kind !== 148 /* CallSignature */ && declaration.name) {
	                                addFullSymbolName(declaration.symbol);
	                            }
	                            ts.addRange(displayParts, ts.signatureToDisplayParts(typeChecker, signature, sourceFile, 32 /* WriteTypeArgumentsOfSignature */));
	                        }
	                        else {
	                            // Type alias type parameter
	                            // For example
	                            //      type list<T> = T[];  // Both T will go through same code path
	                            displayParts.push(ts.keywordPart(132 /* TypeKeyword */));
	                            displayParts.push(ts.spacePart());
	                            addFullSymbolName(declaration.symbol);
	                            writeTypeParametersOfSymbol(declaration.symbol, sourceFile);
	                        }
	                    }
	                }
	            }
	            if (symbolFlags & 8 /* EnumMember */) {
	                addPrefixForAnyFunctionOrVar(symbol, "enum member");
	                var declaration = symbol.declarations[0];
	                if (declaration.kind === 250 /* EnumMember */) {
	                    var constantValue = typeChecker.getConstantValue(declaration);
	                    if (constantValue !== undefined) {
	                        displayParts.push(ts.spacePart());
	                        displayParts.push(ts.operatorPart(56 /* EqualsToken */));
	                        displayParts.push(ts.spacePart());
	                        displayParts.push(ts.displayPart(constantValue.toString(), SymbolDisplayPartKind.numericLiteral));
	                    }
	                }
	            }
	            if (symbolFlags & 8388608 /* Alias */) {
	                addNewLineIfDisplayPartsExist();
	                displayParts.push(ts.keywordPart(89 /* ImportKeyword */));
	                displayParts.push(ts.spacePart());
	                addFullSymbolName(symbol);
	                ts.forEach(symbol.declarations, function (declaration) {
	                    if (declaration.kind === 224 /* ImportEqualsDeclaration */) {
	                        var importEqualsDeclaration = declaration;
	                        if (ts.isExternalModuleImportEqualsDeclaration(importEqualsDeclaration)) {
	                            displayParts.push(ts.spacePart());
	                            displayParts.push(ts.operatorPart(56 /* EqualsToken */));
	                            displayParts.push(ts.spacePart());
	                            displayParts.push(ts.keywordPart(127 /* RequireKeyword */));
	                            displayParts.push(ts.punctuationPart(17 /* OpenParenToken */));
	                            displayParts.push(ts.displayPart(ts.getTextOfNode(ts.getExternalModuleImportEqualsDeclarationExpression(importEqualsDeclaration)), SymbolDisplayPartKind.stringLiteral));
	                            displayParts.push(ts.punctuationPart(18 /* CloseParenToken */));
	                        }
	                        else {
	                            var internalAliasSymbol = typeChecker.getSymbolAtLocation(importEqualsDeclaration.moduleReference);
	                            if (internalAliasSymbol) {
	                                displayParts.push(ts.spacePart());
	                                displayParts.push(ts.operatorPart(56 /* EqualsToken */));
	                                displayParts.push(ts.spacePart());
	                                addFullSymbolName(internalAliasSymbol, enclosingDeclaration);
	                            }
	                        }
	                        return true;
	                    }
	                });
	            }
	            if (!hasAddedSymbolInfo) {
	                if (symbolKind !== ScriptElementKind.unknown) {
	                    if (type) {
	                        addPrefixForAnyFunctionOrVar(symbol, symbolKind);
	                        // For properties, variables and local vars: show the type
	                        if (symbolKind === ScriptElementKind.memberVariableElement ||
	                            symbolFlags & 3 /* Variable */ ||
	                            symbolKind === ScriptElementKind.localVariableElement) {
	                            displayParts.push(ts.punctuationPart(54 /* ColonToken */));
	                            displayParts.push(ts.spacePart());
	                            // If the type is type parameter, format it specially
	                            if (type.symbol && type.symbol.flags & 262144 /* TypeParameter */) {
	                                var typeParameterParts = ts.mapToDisplayParts(function (writer) {
	                                    typeChecker.getSymbolDisplayBuilder().buildTypeParameterDisplay(type, writer, enclosingDeclaration);
	                                });
	                                ts.addRange(displayParts, typeParameterParts);
	                            }
	                            else {
	                                ts.addRange(displayParts, ts.typeToDisplayParts(typeChecker, type, enclosingDeclaration));
	                            }
	                        }
	                        else if (symbolFlags & 16 /* Function */ ||
	                            symbolFlags & 8192 /* Method */ ||
	                            symbolFlags & 16384 /* Constructor */ ||
	                            symbolFlags & 131072 /* Signature */ ||
	                            symbolFlags & 98304 /* Accessor */ ||
	                            symbolKind === ScriptElementKind.memberFunctionElement) {
	                            var allSignatures = type.getCallSignatures();
	                            addSignatureDisplayParts(allSignatures[0], allSignatures);
	                        }
	                    }
	                }
	                else {
	                    symbolKind = getSymbolKind(symbol, location);
	                }
	            }
	            if (!documentation) {
	                documentation = symbol.getDocumentationComment();
	            }
	            return { displayParts: displayParts, documentation: documentation, symbolKind: symbolKind };
	            function addNewLineIfDisplayPartsExist() {
	                if (displayParts.length) {
	                    displayParts.push(ts.lineBreakPart());
	                }
	            }
	            function addFullSymbolName(symbol, enclosingDeclaration) {
	                var fullSymbolDisplayParts = ts.symbolToDisplayParts(typeChecker, symbol, enclosingDeclaration || sourceFile, /*meaning*/ undefined, 1 /* WriteTypeParametersOrArguments */ | 2 /* UseOnlyExternalAliasing */);
	                ts.addRange(displayParts, fullSymbolDisplayParts);
	            }
	            function addPrefixForAnyFunctionOrVar(symbol, symbolKind) {
	                addNewLineIfDisplayPartsExist();
	                if (symbolKind) {
	                    pushTypePart(symbolKind);
	                    displayParts.push(ts.spacePart());
	                    addFullSymbolName(symbol);
	                }
	            }
	            function pushTypePart(symbolKind) {
	                switch (symbolKind) {
	                    case ScriptElementKind.variableElement:
	                    case ScriptElementKind.functionElement:
	                    case ScriptElementKind.letElement:
	                    case ScriptElementKind.constElement:
	                    case ScriptElementKind.constructorImplementationElement:
	                        displayParts.push(ts.textOrKeywordPart(symbolKind));
	                        return;
	                    default:
	                        displayParts.push(ts.punctuationPart(17 /* OpenParenToken */));
	                        displayParts.push(ts.textOrKeywordPart(symbolKind));
	                        displayParts.push(ts.punctuationPart(18 /* CloseParenToken */));
	                        return;
	                }
	            }
	            function addSignatureDisplayParts(signature, allSignatures, flags) {
	                ts.addRange(displayParts, ts.signatureToDisplayParts(typeChecker, signature, enclosingDeclaration, flags | 32 /* WriteTypeArgumentsOfSignature */));
	                if (allSignatures.length > 1) {
	                    displayParts.push(ts.spacePart());
	                    displayParts.push(ts.punctuationPart(17 /* OpenParenToken */));
	                    displayParts.push(ts.operatorPart(35 /* PlusToken */));
	                    displayParts.push(ts.displayPart((allSignatures.length - 1).toString(), SymbolDisplayPartKind.numericLiteral));
	                    displayParts.push(ts.spacePart());
	                    displayParts.push(ts.textPart(allSignatures.length === 2 ? "overload" : "overloads"));
	                    displayParts.push(ts.punctuationPart(18 /* CloseParenToken */));
	                }
	                documentation = signature.getDocumentationComment();
	            }
	            function writeTypeParametersOfSymbol(symbol, enclosingDeclaration) {
	                var typeParameterParts = ts.mapToDisplayParts(function (writer) {
	                    typeChecker.getSymbolDisplayBuilder().buildTypeParameterDisplayFromSymbol(symbol, writer, enclosingDeclaration);
	                });
	                ts.addRange(displayParts, typeParameterParts);
	            }
	        }
	        function getQuickInfoAtPosition(fileName, position) {
	            synchronizeHostData();
	            var sourceFile = getValidSourceFile(fileName);
	            var node = ts.getTouchingPropertyName(sourceFile, position);
	            if (!node) {
	                return undefined;
	            }
	            if (isLabelName(node)) {
	                return undefined;
	            }
	            var typeChecker = program.getTypeChecker();
	            var symbol = typeChecker.getSymbolAtLocation(node);
	            if (!symbol || typeChecker.isUnknownSymbol(symbol)) {
	                // Try getting just type at this position and show
	                switch (node.kind) {
	                    case 69 /* Identifier */:
	                    case 169 /* PropertyAccessExpression */:
	                    case 136 /* QualifiedName */:
	                    case 97 /* ThisKeyword */:
	                    case 162 /* ThisType */:
	                    case 95 /* SuperKeyword */:
	                        // For the identifiers/this/super etc get the type at position
	                        var type = typeChecker.getTypeAtLocation(node);
	                        if (type) {
	                            return {
	                                kind: ScriptElementKind.unknown,
	                                kindModifiers: ScriptElementKindModifier.none,
	                                textSpan: ts.createTextSpan(node.getStart(), node.getWidth()),
	                                displayParts: ts.typeToDisplayParts(typeChecker, type, getContainerNode(node)),
	                                documentation: type.symbol ? type.symbol.getDocumentationComment() : undefined
	                            };
	                        }
	                }
	                return undefined;
	            }
	            var displayPartsDocumentationsAndKind = getSymbolDisplayPartsDocumentationAndSymbolKind(symbol, sourceFile, getContainerNode(node), node);
	            return {
	                kind: displayPartsDocumentationsAndKind.symbolKind,
	                kindModifiers: getSymbolModifiers(symbol),
	                textSpan: ts.createTextSpan(node.getStart(), node.getWidth()),
	                displayParts: displayPartsDocumentationsAndKind.displayParts,
	                documentation: displayPartsDocumentationsAndKind.documentation
	            };
	        }
	        function createDefinitionInfo(node, symbolKind, symbolName, containerName) {
	            return {
	                fileName: node.getSourceFile().fileName,
	                textSpan: ts.createTextSpanFromBounds(node.getStart(), node.getEnd()),
	                kind: symbolKind,
	                name: symbolName,
	                containerKind: undefined,
	                containerName: containerName
	            };
	        }
	        function getDefinitionFromSymbol(symbol, node) {
	            var typeChecker = program.getTypeChecker();
	            var result = [];
	            var declarations = symbol.getDeclarations();
	            var symbolName = typeChecker.symbolToString(symbol); // Do not get scoped name, just the name of the symbol
	            var symbolKind = getSymbolKind(symbol, node);
	            var containerSymbol = symbol.parent;
	            var containerName = containerSymbol ? typeChecker.symbolToString(containerSymbol, node) : "";
	            if (!tryAddConstructSignature(symbol, node, symbolKind, symbolName, containerName, result) &&
	                !tryAddCallSignature(symbol, node, symbolKind, symbolName, containerName, result)) {
	                // Just add all the declarations.
	                ts.forEach(declarations, function (declaration) {
	                    result.push(createDefinitionInfo(declaration, symbolKind, symbolName, containerName));
	                });
	            }
	            return result;
	            function tryAddConstructSignature(symbol, location, symbolKind, symbolName, containerName, result) {
	                // Applicable only if we are in a new expression, or we are on a constructor declaration
	                // and in either case the symbol has a construct signature definition, i.e. class
	                if (isNewExpressionTarget(location) || location.kind === 121 /* ConstructorKeyword */) {
	                    if (symbol.flags & 32 /* Class */) {
	                        // Find the first class-like declaration and try to get the construct signature.
	                        for (var _i = 0, _a = symbol.getDeclarations(); _i < _a.length; _i++) {
	                            var declaration = _a[_i];
	                            if (ts.isClassLike(declaration)) {
	                                return tryAddSignature(declaration.members, 
	                                /*selectConstructors*/ true, symbolKind, symbolName, containerName, result);
	                            }
	                        }
	                        ts.Debug.fail("Expected declaration to have at least one class-like declaration");
	                    }
	                }
	                return false;
	            }
	            function tryAddCallSignature(symbol, location, symbolKind, symbolName, containerName, result) {
	                if (isCallExpressionTarget(location) || isNewExpressionTarget(location) || isNameOfFunctionDeclaration(location)) {
	                    return tryAddSignature(symbol.declarations, /*selectConstructors*/ false, symbolKind, symbolName, containerName, result);
	                }
	                return false;
	            }
	            function tryAddSignature(signatureDeclarations, selectConstructors, symbolKind, symbolName, containerName, result) {
	                var declarations = [];
	                var definition;
	                ts.forEach(signatureDeclarations, function (d) {
	                    if ((selectConstructors && d.kind === 145 /* Constructor */) ||
	                        (!selectConstructors && (d.kind === 216 /* FunctionDeclaration */ || d.kind === 144 /* MethodDeclaration */ || d.kind === 143 /* MethodSignature */))) {
	                        declarations.push(d);
	                        if (d.body)
	                            definition = d;
	                    }
	                });
	                if (definition) {
	                    result.push(createDefinitionInfo(definition, symbolKind, symbolName, containerName));
	                    return true;
	                }
	                else if (declarations.length) {
	                    result.push(createDefinitionInfo(ts.lastOrUndefined(declarations), symbolKind, symbolName, containerName));
	                    return true;
	                }
	                return false;
	            }
	        }
	        /// Goto definition
	        function getDefinitionAtPosition(fileName, position) {
	            synchronizeHostData();
	            var sourceFile = getValidSourceFile(fileName);
	            var node = ts.getTouchingPropertyName(sourceFile, position);
	            if (!node) {
	                return undefined;
	            }
	            // Labels
	            if (isJumpStatementTarget(node)) {
	                var labelName = node.text;
	                var label = getTargetLabel(node.parent, node.text);
	                return label ? [createDefinitionInfo(label, ScriptElementKind.label, labelName, /*containerName*/ undefined)] : undefined;
	            }
	            /// Triple slash reference comments
	            var comment = ts.forEach(sourceFile.referencedFiles, function (r) { return (r.pos <= position && position < r.end) ? r : undefined; });
	            if (comment) {
	                var referenceFile = ts.tryResolveScriptReference(program, sourceFile, comment);
	                if (referenceFile) {
	                    return [{
	                            fileName: referenceFile.fileName,
	                            textSpan: ts.createTextSpanFromBounds(0, 0),
	                            kind: ScriptElementKind.scriptElement,
	                            name: comment.fileName,
	                            containerName: undefined,
	                            containerKind: undefined
	                        }];
	                }
	                return undefined;
	            }
	            var typeChecker = program.getTypeChecker();
	            var symbol = typeChecker.getSymbolAtLocation(node);
	            // Could not find a symbol e.g. node is string or number keyword,
	            // or the symbol was an internal symbol and does not have a declaration e.g. undefined symbol
	            if (!symbol) {
	                return undefined;
	            }
	            // If this is an alias, and the request came at the declaration location
	            // get the aliased symbol instead. This allows for goto def on an import e.g.
	            //   import {A, B} from "mod";
	            // to jump to the implementation directly.
	            if (symbol.flags & 8388608 /* Alias */) {
	                var declaration = symbol.declarations[0];
	                if (node.kind === 69 /* Identifier */ && node.parent === declaration) {
	                    symbol = typeChecker.getAliasedSymbol(symbol);
	                }
	            }
	            // Because name in short-hand property assignment has two different meanings: property name and property value,
	            // using go-to-definition at such position should go to the variable declaration of the property value rather than
	            // go to the declaration of the property name (in this case stay at the same position). However, if go-to-definition
	            // is performed at the location of property access, we would like to go to definition of the property in the short-hand
	            // assignment. This case and others are handled by the following code.
	            if (node.parent.kind === 249 /* ShorthandPropertyAssignment */) {
	                var shorthandSymbol = typeChecker.getShorthandAssignmentValueSymbol(symbol.valueDeclaration);
	                if (!shorthandSymbol) {
	                    return [];
	                }
	                var shorthandDeclarations = shorthandSymbol.getDeclarations();
	                var shorthandSymbolKind_1 = getSymbolKind(shorthandSymbol, node);
	                var shorthandSymbolName_1 = typeChecker.symbolToString(shorthandSymbol);
	                var shorthandContainerName_1 = typeChecker.symbolToString(symbol.parent, node);
	                return ts.map(shorthandDeclarations, function (declaration) { return createDefinitionInfo(declaration, shorthandSymbolKind_1, shorthandSymbolName_1, shorthandContainerName_1); });
	            }
	            return getDefinitionFromSymbol(symbol, node);
	        }
	        /// Goto type
	        function getTypeDefinitionAtPosition(fileName, position) {
	            synchronizeHostData();
	            var sourceFile = getValidSourceFile(fileName);
	            var node = ts.getTouchingPropertyName(sourceFile, position);
	            if (!node) {
	                return undefined;
	            }
	            var typeChecker = program.getTypeChecker();
	            var symbol = typeChecker.getSymbolAtLocation(node);
	            if (!symbol) {
	                return undefined;
	            }
	            var type = typeChecker.getTypeOfSymbolAtLocation(symbol, node);
	            if (!type) {
	                return undefined;
	            }
	            if (type.flags & 16384 /* Union */) {
	                var result_4 = [];
	                ts.forEach(type.types, function (t) {
	                    if (t.symbol) {
	                        ts.addRange(/*to*/ result_4, /*from*/ getDefinitionFromSymbol(t.symbol, node));
	                    }
	                });
	                return result_4;
	            }
	            if (!type.symbol) {
	                return undefined;
	            }
	            return getDefinitionFromSymbol(type.symbol, node);
	        }
	        function getOccurrencesAtPosition(fileName, position) {
	            var results = getOccurrencesAtPositionCore(fileName, position);
	            if (results) {
	                var sourceFile_2 = getCanonicalFileName(ts.normalizeSlashes(fileName));
	                // Get occurrences only supports reporting occurrences for the file queried.  So
	                // filter down to that list.
	                results = ts.filter(results, function (r) { return getCanonicalFileName(ts.normalizeSlashes(r.fileName)) === sourceFile_2; });
	            }
	            return results;
	        }
	        function getDocumentHighlights(fileName, position, filesToSearch) {
	            synchronizeHostData();
	            filesToSearch = ts.map(filesToSearch, ts.normalizeSlashes);
	            var sourceFilesToSearch = ts.filter(program.getSourceFiles(), function (f) { return ts.contains(filesToSearch, f.fileName); });
	            var sourceFile = getValidSourceFile(fileName);
	            var node = ts.getTouchingWord(sourceFile, position);
	            if (!node) {
	                return undefined;
	            }
	            return getSemanticDocumentHighlights(node) || getSyntacticDocumentHighlights(node);
	            function getHighlightSpanForNode(node) {
	                var start = node.getStart();
	                var end = node.getEnd();
	                return {
	                    fileName: sourceFile.fileName,
	                    textSpan: ts.createTextSpanFromBounds(start, end),
	                    kind: HighlightSpanKind.none
	                };
	            }
	            function getSemanticDocumentHighlights(node) {
	                if (node.kind === 69 /* Identifier */ ||
	                    node.kind === 97 /* ThisKeyword */ ||
	                    node.kind === 162 /* ThisType */ ||
	                    node.kind === 95 /* SuperKeyword */ ||
	                    isLiteralNameOfPropertyDeclarationOrIndexAccess(node) ||
	                    isNameOfExternalModuleImportOrDeclaration(node)) {
	                    var referencedSymbols = getReferencedSymbolsForNode(node, sourceFilesToSearch, /*findInStrings*/ false, /*findInComments*/ false);
	                    return convertReferencedSymbols(referencedSymbols);
	                }
	                return undefined;
	                function convertReferencedSymbols(referencedSymbols) {
	                    if (!referencedSymbols) {
	                        return undefined;
	                    }
	                    var fileNameToDocumentHighlights = {};
	                    var result = [];
	                    for (var _i = 0, referencedSymbols_1 = referencedSymbols; _i < referencedSymbols_1.length; _i++) {
	                        var referencedSymbol = referencedSymbols_1[_i];
	                        for (var _a = 0, _b = referencedSymbol.references; _a < _b.length; _a++) {
	                            var referenceEntry = _b[_a];
	                            var fileName_1 = referenceEntry.fileName;
	                            var documentHighlights = ts.getProperty(fileNameToDocumentHighlights, fileName_1);
	                            if (!documentHighlights) {
	                                documentHighlights = { fileName: fileName_1, highlightSpans: [] };
	                                fileNameToDocumentHighlights[fileName_1] = documentHighlights;
	                                result.push(documentHighlights);
	                            }
	                            documentHighlights.highlightSpans.push({
	                                textSpan: referenceEntry.textSpan,
	                                kind: referenceEntry.isWriteAccess ? HighlightSpanKind.writtenReference : HighlightSpanKind.reference
	                            });
	                        }
	                    }
	                    return result;
	                }
	            }
	            function getSyntacticDocumentHighlights(node) {
	                var fileName = sourceFile.fileName;
	                var highlightSpans = getHighlightSpans(node);
	                if (!highlightSpans || highlightSpans.length === 0) {
	                    return undefined;
	                }
	                return [{ fileName: fileName, highlightSpans: highlightSpans }];
	                // returns true if 'node' is defined and has a matching 'kind'.
	                function hasKind(node, kind) {
	                    return node !== undefined && node.kind === kind;
	                }
	                // Null-propagating 'parent' function.
	                function parent(node) {
	                    return node && node.parent;
	                }
	                function getHighlightSpans(node) {
	                    if (node) {
	                        switch (node.kind) {
	                            case 88 /* IfKeyword */:
	                            case 80 /* ElseKeyword */:
	                                if (hasKind(node.parent, 199 /* IfStatement */)) {
	                                    return getIfElseOccurrences(node.parent);
	                                }
	                                break;
	                            case 94 /* ReturnKeyword */:
	                                if (hasKind(node.parent, 207 /* ReturnStatement */)) {
	                                    return getReturnOccurrences(node.parent);
	                                }
	                                break;
	                            case 98 /* ThrowKeyword */:
	                                if (hasKind(node.parent, 211 /* ThrowStatement */)) {
	                                    return getThrowOccurrences(node.parent);
	                                }
	                                break;
	                            case 72 /* CatchKeyword */:
	                                if (hasKind(parent(parent(node)), 212 /* TryStatement */)) {
	                                    return getTryCatchFinallyOccurrences(node.parent.parent);
	                                }
	                                break;
	                            case 100 /* TryKeyword */:
	                            case 85 /* FinallyKeyword */:
	                                if (hasKind(parent(node), 212 /* TryStatement */)) {
	                                    return getTryCatchFinallyOccurrences(node.parent);
	                                }
	                                break;
	                            case 96 /* SwitchKeyword */:
	                                if (hasKind(node.parent, 209 /* SwitchStatement */)) {
	                                    return getSwitchCaseDefaultOccurrences(node.parent);
	                                }
	                                break;
	                            case 71 /* CaseKeyword */:
	                            case 77 /* DefaultKeyword */:
	                                if (hasKind(parent(parent(parent(node))), 209 /* SwitchStatement */)) {
	                                    return getSwitchCaseDefaultOccurrences(node.parent.parent.parent);
	                                }
	                                break;
	                            case 70 /* BreakKeyword */:
	                            case 75 /* ContinueKeyword */:
	                                if (hasKind(node.parent, 206 /* BreakStatement */) || hasKind(node.parent, 205 /* ContinueStatement */)) {
	                                    return getBreakOrContinueStatementOccurrences(node.parent);
	                                }
	                                break;
	                            case 86 /* ForKeyword */:
	                                if (hasKind(node.parent, 202 /* ForStatement */) ||
	                                    hasKind(node.parent, 203 /* ForInStatement */) ||
	                                    hasKind(node.parent, 204 /* ForOfStatement */)) {
	                                    return getLoopBreakContinueOccurrences(node.parent);
	                                }
	                                break;
	                            case 104 /* WhileKeyword */:
	                            case 79 /* DoKeyword */:
	                                if (hasKind(node.parent, 201 /* WhileStatement */) || hasKind(node.parent, 200 /* DoStatement */)) {
	                                    return getLoopBreakContinueOccurrences(node.parent);
	                                }
	                                break;
	                            case 121 /* ConstructorKeyword */:
	                                if (hasKind(node.parent, 145 /* Constructor */)) {
	                                    return getConstructorOccurrences(node.parent);
	                                }
	                                break;
	                            case 123 /* GetKeyword */:
	                            case 129 /* SetKeyword */:
	                                if (hasKind(node.parent, 146 /* GetAccessor */) || hasKind(node.parent, 147 /* SetAccessor */)) {
	                                    return getGetAndSetOccurrences(node.parent);
	                                }
	                                break;
	                            default:
	                                if (ts.isModifierKind(node.kind) && node.parent &&
	                                    (ts.isDeclaration(node.parent) || node.parent.kind === 196 /* VariableStatement */)) {
	                                    return getModifierOccurrences(node.kind, node.parent);
	                                }
	                        }
	                    }
	                    return undefined;
	                }
	                /**
	                 * Aggregates all throw-statements within this node *without* crossing
	                 * into function boundaries and try-blocks with catch-clauses.
	                 */
	                function aggregateOwnedThrowStatements(node) {
	                    var statementAccumulator = [];
	                    aggregate(node);
	                    return statementAccumulator;
	                    function aggregate(node) {
	                        if (node.kind === 211 /* ThrowStatement */) {
	                            statementAccumulator.push(node);
	                        }
	                        else if (node.kind === 212 /* TryStatement */) {
	                            var tryStatement = node;
	                            if (tryStatement.catchClause) {
	                                aggregate(tryStatement.catchClause);
	                            }
	                            else {
	                                // Exceptions thrown within a try block lacking a catch clause
	                                // are "owned" in the current context.
	                                aggregate(tryStatement.tryBlock);
	                            }
	                            if (tryStatement.finallyBlock) {
	                                aggregate(tryStatement.finallyBlock);
	                            }
	                        }
	                        else if (!ts.isFunctionLike(node)) {
	                            ts.forEachChild(node, aggregate);
	                        }
	                    }
	                }
	                /**
	                 * For lack of a better name, this function takes a throw statement and returns the
	                 * nearest ancestor that is a try-block (whose try statement has a catch clause),
	                 * function-block, or source file.
	                 */
	                function getThrowStatementOwner(throwStatement) {
	                    var child = throwStatement;
	                    while (child.parent) {
	                        var parent_14 = child.parent;
	                        if (ts.isFunctionBlock(parent_14) || parent_14.kind === 251 /* SourceFile */) {
	                            return parent_14;
	                        }
	                        // A throw-statement is only owned by a try-statement if the try-statement has
	                        // a catch clause, and if the throw-statement occurs within the try block.
	                        if (parent_14.kind === 212 /* TryStatement */) {
	                            var tryStatement = parent_14;
	                            if (tryStatement.tryBlock === child && tryStatement.catchClause) {
	                                return child;
	                            }
	                        }
	                        child = parent_14;
	                    }
	                    return undefined;
	                }
	                function aggregateAllBreakAndContinueStatements(node) {
	                    var statementAccumulator = [];
	                    aggregate(node);
	                    return statementAccumulator;
	                    function aggregate(node) {
	                        if (node.kind === 206 /* BreakStatement */ || node.kind === 205 /* ContinueStatement */) {
	                            statementAccumulator.push(node);
	                        }
	                        else if (!ts.isFunctionLike(node)) {
	                            ts.forEachChild(node, aggregate);
	                        }
	                    }
	                }
	                function ownsBreakOrContinueStatement(owner, statement) {
	                    var actualOwner = getBreakOrContinueOwner(statement);
	                    return actualOwner && actualOwner === owner;
	                }
	                function getBreakOrContinueOwner(statement) {
	                    for (var node_2 = statement.parent; node_2; node_2 = node_2.parent) {
	                        switch (node_2.kind) {
	                            case 209 /* SwitchStatement */:
	                                if (statement.kind === 205 /* ContinueStatement */) {
	                                    continue;
	                                }
	                            // Fall through.
	                            case 202 /* ForStatement */:
	                            case 203 /* ForInStatement */:
	                            case 204 /* ForOfStatement */:
	                            case 201 /* WhileStatement */:
	                            case 200 /* DoStatement */:
	                                if (!statement.label || isLabeledBy(node_2, statement.label.text)) {
	                                    return node_2;
	                                }
	                                break;
	                            default:
	                                // Don't cross function boundaries.
	                                if (ts.isFunctionLike(node_2)) {
	                                    return undefined;
	                                }
	                                break;
	                        }
	                    }
	                    return undefined;
	                }
	                function getModifierOccurrences(modifier, declaration) {
	                    var container = declaration.parent;
	                    // Make sure we only highlight the keyword when it makes sense to do so.
	                    if (ts.isAccessibilityModifier(modifier)) {
	                        if (!(container.kind === 217 /* ClassDeclaration */ ||
	                            container.kind === 189 /* ClassExpression */ ||
	                            (declaration.kind === 139 /* Parameter */ && hasKind(container, 145 /* Constructor */)))) {
	                            return undefined;
	                        }
	                    }
	                    else if (modifier === 113 /* StaticKeyword */) {
	                        if (!(container.kind === 217 /* ClassDeclaration */ || container.kind === 189 /* ClassExpression */)) {
	                            return undefined;
	                        }
	                    }
	                    else if (modifier === 82 /* ExportKeyword */ || modifier === 122 /* DeclareKeyword */) {
	                        if (!(container.kind === 222 /* ModuleBlock */ || container.kind === 251 /* SourceFile */)) {
	                            return undefined;
	                        }
	                    }
	                    else if (modifier === 115 /* AbstractKeyword */) {
	                        if (!(container.kind === 217 /* ClassDeclaration */ || declaration.kind === 217 /* ClassDeclaration */)) {
	                            return undefined;
	                        }
	                    }
	                    else {
	                        // unsupported modifier
	                        return undefined;
	                    }
	                    var keywords = [];
	                    var modifierFlag = getFlagFromModifier(modifier);
	                    var nodes;
	                    switch (container.kind) {
	                        case 222 /* ModuleBlock */:
	                        case 251 /* SourceFile */:
	                            // Container is either a class declaration or the declaration is a classDeclaration
	                            if (modifierFlag & 128 /* Abstract */) {
	                                nodes = declaration.members.concat(declaration);
	                            }
	                            else {
	                                nodes = container.statements;
	                            }
	                            break;
	                        case 145 /* Constructor */:
	                            nodes = container.parameters.concat(container.parent.members);
	                            break;
	                        case 217 /* ClassDeclaration */:
	                        case 189 /* ClassExpression */:
	                            nodes = container.members;
	                            // If we're an accessibility modifier, we're in an instance member and should search
	                            // the constructor's parameter list for instance members as well.
	                            if (modifierFlag & 56 /* AccessibilityModifier */) {
	                                var constructor = ts.forEach(container.members, function (member) {
	                                    return member.kind === 145 /* Constructor */ && member;
	                                });
	                                if (constructor) {
	                                    nodes = nodes.concat(constructor.parameters);
	                                }
	                            }
	                            else if (modifierFlag & 128 /* Abstract */) {
	                                nodes = nodes.concat(container);
	                            }
	                            break;
	                        default:
	                            ts.Debug.fail("Invalid container kind.");
	                    }
	                    ts.forEach(nodes, function (node) {
	                        if (node.modifiers && node.flags & modifierFlag) {
	                            ts.forEach(node.modifiers, function (child) { return pushKeywordIf(keywords, child, modifier); });
	                        }
	                    });
	                    return ts.map(keywords, getHighlightSpanForNode);
	                    function getFlagFromModifier(modifier) {
	                        switch (modifier) {
	                            case 112 /* PublicKeyword */:
	                                return 8 /* Public */;
	                            case 110 /* PrivateKeyword */:
	                                return 16 /* Private */;
	                            case 111 /* ProtectedKeyword */:
	                                return 32 /* Protected */;
	                            case 113 /* StaticKeyword */:
	                                return 64 /* Static */;
	                            case 82 /* ExportKeyword */:
	                                return 2 /* Export */;
	                            case 122 /* DeclareKeyword */:
	                                return 4 /* Ambient */;
	                            case 115 /* AbstractKeyword */:
	                                return 128 /* Abstract */;
	                            default:
	                                ts.Debug.fail();
	                        }
	                    }
	                }
	                function pushKeywordIf(keywordList, token) {
	                    var expected = [];
	                    for (var _i = 2; _i < arguments.length; _i++) {
	                        expected[_i - 2] = arguments[_i];
	                    }
	                    if (token && ts.contains(expected, token.kind)) {
	                        keywordList.push(token);
	                        return true;
	                    }
	                    return false;
	                }
	                function getGetAndSetOccurrences(accessorDeclaration) {
	                    var keywords = [];
	                    tryPushAccessorKeyword(accessorDeclaration.symbol, 146 /* GetAccessor */);
	                    tryPushAccessorKeyword(accessorDeclaration.symbol, 147 /* SetAccessor */);
	                    return ts.map(keywords, getHighlightSpanForNode);
	                    function tryPushAccessorKeyword(accessorSymbol, accessorKind) {
	                        var accessor = ts.getDeclarationOfKind(accessorSymbol, accessorKind);
	                        if (accessor) {
	                            ts.forEach(accessor.getChildren(), function (child) { return pushKeywordIf(keywords, child, 123 /* GetKeyword */, 129 /* SetKeyword */); });
	                        }
	                    }
	                }
	                function getConstructorOccurrences(constructorDeclaration) {
	                    var declarations = constructorDeclaration.symbol.getDeclarations();
	                    var keywords = [];
	                    ts.forEach(declarations, function (declaration) {
	                        ts.forEach(declaration.getChildren(), function (token) {
	                            return pushKeywordIf(keywords, token, 121 /* ConstructorKeyword */);
	                        });
	                    });
	                    return ts.map(keywords, getHighlightSpanForNode);
	                }
	                function getLoopBreakContinueOccurrences(loopNode) {
	                    var keywords = [];
	                    if (pushKeywordIf(keywords, loopNode.getFirstToken(), 86 /* ForKeyword */, 104 /* WhileKeyword */, 79 /* DoKeyword */)) {
	                        // If we succeeded and got a do-while loop, then start looking for a 'while' keyword.
	                        if (loopNode.kind === 200 /* DoStatement */) {
	                            var loopTokens = loopNode.getChildren();
	                            for (var i = loopTokens.length - 1; i >= 0; i--) {
	                                if (pushKeywordIf(keywords, loopTokens[i], 104 /* WhileKeyword */)) {
	                                    break;
	                                }
	                            }
	                        }
	                    }
	                    var breaksAndContinues = aggregateAllBreakAndContinueStatements(loopNode.statement);
	                    ts.forEach(breaksAndContinues, function (statement) {
	                        if (ownsBreakOrContinueStatement(loopNode, statement)) {
	                            pushKeywordIf(keywords, statement.getFirstToken(), 70 /* BreakKeyword */, 75 /* ContinueKeyword */);
	                        }
	                    });
	                    return ts.map(keywords, getHighlightSpanForNode);
	                }
	                function getBreakOrContinueStatementOccurrences(breakOrContinueStatement) {
	                    var owner = getBreakOrContinueOwner(breakOrContinueStatement);
	                    if (owner) {
	                        switch (owner.kind) {
	                            case 202 /* ForStatement */:
	                            case 203 /* ForInStatement */:
	                            case 204 /* ForOfStatement */:
	                            case 200 /* DoStatement */:
	                            case 201 /* WhileStatement */:
	                                return getLoopBreakContinueOccurrences(owner);
	                            case 209 /* SwitchStatement */:
	                                return getSwitchCaseDefaultOccurrences(owner);
	                        }
	                    }
	                    return undefined;
	                }
	                function getSwitchCaseDefaultOccurrences(switchStatement) {
	                    var keywords = [];
	                    pushKeywordIf(keywords, switchStatement.getFirstToken(), 96 /* SwitchKeyword */);
	                    // Go through each clause in the switch statement, collecting the 'case'/'default' keywords.
	                    ts.forEach(switchStatement.caseBlock.clauses, function (clause) {
	                        pushKeywordIf(keywords, clause.getFirstToken(), 71 /* CaseKeyword */, 77 /* DefaultKeyword */);
	                        var breaksAndContinues = aggregateAllBreakAndContinueStatements(clause);
	                        ts.forEach(breaksAndContinues, function (statement) {
	                            if (ownsBreakOrContinueStatement(switchStatement, statement)) {
	                                pushKeywordIf(keywords, statement.getFirstToken(), 70 /* BreakKeyword */);
	                            }
	                        });
	                    });
	                    return ts.map(keywords, getHighlightSpanForNode);
	                }
	                function getTryCatchFinallyOccurrences(tryStatement) {
	                    var keywords = [];
	                    pushKeywordIf(keywords, tryStatement.getFirstToken(), 100 /* TryKeyword */);
	                    if (tryStatement.catchClause) {
	                        pushKeywordIf(keywords, tryStatement.catchClause.getFirstToken(), 72 /* CatchKeyword */);
	                    }
	                    if (tryStatement.finallyBlock) {
	                        var finallyKeyword = ts.findChildOfKind(tryStatement, 85 /* FinallyKeyword */, sourceFile);
	                        pushKeywordIf(keywords, finallyKeyword, 85 /* FinallyKeyword */);
	                    }
	                    return ts.map(keywords, getHighlightSpanForNode);
	                }
	                function getThrowOccurrences(throwStatement) {
	                    var owner = getThrowStatementOwner(throwStatement);
	                    if (!owner) {
	                        return undefined;
	                    }
	                    var keywords = [];
	                    ts.forEach(aggregateOwnedThrowStatements(owner), function (throwStatement) {
	                        pushKeywordIf(keywords, throwStatement.getFirstToken(), 98 /* ThrowKeyword */);
	                    });
	                    // If the "owner" is a function, then we equate 'return' and 'throw' statements in their
	                    // ability to "jump out" of the function, and include occurrences for both.
	                    if (ts.isFunctionBlock(owner)) {
	                        ts.forEachReturnStatement(owner, function (returnStatement) {
	                            pushKeywordIf(keywords, returnStatement.getFirstToken(), 94 /* ReturnKeyword */);
	                        });
	                    }
	                    return ts.map(keywords, getHighlightSpanForNode);
	                }
	                function getReturnOccurrences(returnStatement) {
	                    var func = ts.getContainingFunction(returnStatement);
	                    // If we didn't find a containing function with a block body, bail out.
	                    if (!(func && hasKind(func.body, 195 /* Block */))) {
	                        return undefined;
	                    }
	                    var keywords = [];
	                    ts.forEachReturnStatement(func.body, function (returnStatement) {
	                        pushKeywordIf(keywords, returnStatement.getFirstToken(), 94 /* ReturnKeyword */);
	                    });
	                    // Include 'throw' statements that do not occur within a try block.
	                    ts.forEach(aggregateOwnedThrowStatements(func.body), function (throwStatement) {
	                        pushKeywordIf(keywords, throwStatement.getFirstToken(), 98 /* ThrowKeyword */);
	                    });
	                    return ts.map(keywords, getHighlightSpanForNode);
	                }
	                function getIfElseOccurrences(ifStatement) {
	                    var keywords = [];
	                    // Traverse upwards through all parent if-statements linked by their else-branches.
	                    while (hasKind(ifStatement.parent, 199 /* IfStatement */) && ifStatement.parent.elseStatement === ifStatement) {
	                        ifStatement = ifStatement.parent;
	                    }
	                    // Now traverse back down through the else branches, aggregating if/else keywords of if-statements.
	                    while (ifStatement) {
	                        var children = ifStatement.getChildren();
	                        pushKeywordIf(keywords, children[0], 88 /* IfKeyword */);
	                        // Generally the 'else' keyword is second-to-last, so we traverse backwards.
	                        for (var i = children.length - 1; i >= 0; i--) {
	                            if (pushKeywordIf(keywords, children[i], 80 /* ElseKeyword */)) {
	                                break;
	                            }
	                        }
	                        if (!hasKind(ifStatement.elseStatement, 199 /* IfStatement */)) {
	                            break;
	                        }
	                        ifStatement = ifStatement.elseStatement;
	                    }
	                    var result = [];
	                    // We'd like to highlight else/ifs together if they are only separated by whitespace
	                    // (i.e. the keywords are separated by no comments, no newlines).
	                    for (var i = 0; i < keywords.length; i++) {
	                        if (keywords[i].kind === 80 /* ElseKeyword */ && i < keywords.length - 1) {
	                            var elseKeyword = keywords[i];
	                            var ifKeyword = keywords[i + 1]; // this *should* always be an 'if' keyword.
	                            var shouldCombindElseAndIf = true;
	                            // Avoid recalculating getStart() by iterating backwards.
	                            for (var j = ifKeyword.getStart() - 1; j >= elseKeyword.end; j--) {
	                                if (!ts.isWhiteSpace(sourceFile.text.charCodeAt(j))) {
	                                    shouldCombindElseAndIf = false;
	                                    break;
	                                }
	                            }
	                            if (shouldCombindElseAndIf) {
	                                result.push({
	                                    fileName: fileName,
	                                    textSpan: ts.createTextSpanFromBounds(elseKeyword.getStart(), ifKeyword.end),
	                                    kind: HighlightSpanKind.reference
	                                });
	                                i++; // skip the next keyword
	                                continue;
	                            }
	                        }
	                        // Ordinary case: just highlight the keyword.
	                        result.push(getHighlightSpanForNode(keywords[i]));
	                    }
	                    return result;
	                }
	            }
	        }
	        /// References and Occurrences
	        function getOccurrencesAtPositionCore(fileName, position) {
	            synchronizeHostData();
	            return convertDocumentHighlights(getDocumentHighlights(fileName, position, [fileName]));
	            function convertDocumentHighlights(documentHighlights) {
	                if (!documentHighlights) {
	                    return undefined;
	                }
	                var result = [];
	                for (var _i = 0, documentHighlights_1 = documentHighlights; _i < documentHighlights_1.length; _i++) {
	                    var entry = documentHighlights_1[_i];
	                    for (var _a = 0, _b = entry.highlightSpans; _a < _b.length; _a++) {
	                        var highlightSpan = _b[_a];
	                        result.push({
	                            fileName: entry.fileName,
	                            textSpan: highlightSpan.textSpan,
	                            isWriteAccess: highlightSpan.kind === HighlightSpanKind.writtenReference
	                        });
	                    }
	                }
	                return result;
	            }
	        }
	        function convertReferences(referenceSymbols) {
	            if (!referenceSymbols) {
	                return undefined;
	            }
	            var referenceEntries = [];
	            for (var _i = 0, referenceSymbols_1 = referenceSymbols; _i < referenceSymbols_1.length; _i++) {
	                var referenceSymbol = referenceSymbols_1[_i];
	                ts.addRange(referenceEntries, referenceSymbol.references);
	            }
	            return referenceEntries;
	        }
	        function findRenameLocations(fileName, position, findInStrings, findInComments) {
	            var referencedSymbols = findReferencedSymbols(fileName, position, findInStrings, findInComments);
	            return convertReferences(referencedSymbols);
	        }
	        function getReferencesAtPosition(fileName, position) {
	            var referencedSymbols = findReferencedSymbols(fileName, position, /*findInStrings*/ false, /*findInComments*/ false);
	            return convertReferences(referencedSymbols);
	        }
	        function findReferences(fileName, position) {
	            var referencedSymbols = findReferencedSymbols(fileName, position, /*findInStrings*/ false, /*findInComments*/ false);
	            // Only include referenced symbols that have a valid definition.
	            return ts.filter(referencedSymbols, function (rs) { return !!rs.definition; });
	        }
	        function findReferencedSymbols(fileName, position, findInStrings, findInComments) {
	            synchronizeHostData();
	            var sourceFile = getValidSourceFile(fileName);
	            var node = ts.getTouchingPropertyName(sourceFile, position);
	            if (!node) {
	                return undefined;
	            }
	            if (node.kind !== 69 /* Identifier */ &&
	                // TODO (drosen): This should be enabled in a later release - currently breaks rename.
	                // node.kind !== SyntaxKind.ThisKeyword &&
	                // node.kind !== SyntaxKind.SuperKeyword &&
	                !isLiteralNameOfPropertyDeclarationOrIndexAccess(node) &&
	                !isNameOfExternalModuleImportOrDeclaration(node)) {
	                return undefined;
	            }
	            ts.Debug.assert(node.kind === 69 /* Identifier */ || node.kind === 8 /* NumericLiteral */ || node.kind === 9 /* StringLiteral */);
	            return getReferencedSymbolsForNode(node, program.getSourceFiles(), findInStrings, findInComments);
	        }
	        function getReferencedSymbolsForNode(node, sourceFiles, findInStrings, findInComments) {
	            var typeChecker = program.getTypeChecker();
	            // Labels
	            if (isLabelName(node)) {
	                if (isJumpStatementTarget(node)) {
	                    var labelDefinition = getTargetLabel(node.parent, node.text);
	                    // if we have a label definition, look within its statement for references, if not, then
	                    // the label is undefined and we have no results..
	                    return labelDefinition ? getLabelReferencesInNode(labelDefinition.parent, labelDefinition) : undefined;
	                }
	                else {
	                    // it is a label definition and not a target, search within the parent labeledStatement
	                    return getLabelReferencesInNode(node.parent, node);
	                }
	            }
	            if (node.kind === 97 /* ThisKeyword */ || node.kind === 162 /* ThisType */) {
	                return getReferencesForThisKeyword(node, sourceFiles);
	            }
	            if (node.kind === 95 /* SuperKeyword */) {
	                return getReferencesForSuperKeyword(node);
	            }
	            var symbol = typeChecker.getSymbolAtLocation(node);
	            // Could not find a symbol e.g. unknown identifier
	            if (!symbol) {
	                // Can't have references to something that we have no symbol for.
	                return undefined;
	            }
	            var declarations = symbol.declarations;
	            // The symbol was an internal symbol and does not have a declaration e.g. undefined symbol
	            if (!declarations || !declarations.length) {
	                return undefined;
	            }
	            var result;
	            // Compute the meaning from the location and the symbol it references
	            var searchMeaning = getIntersectingMeaningFromDeclarations(getMeaningFromLocation(node), declarations);
	            // Get the text to search for.
	            // Note: if this is an external module symbol, the name doesn't include quotes.
	            var declaredName = ts.stripQuotes(ts.getDeclaredName(typeChecker, symbol, node));
	            // Try to get the smallest valid scope that we can limit our search to;
	            // otherwise we'll need to search globally (i.e. include each file).
	            var scope = getSymbolScope(symbol);
	            // Maps from a symbol ID to the ReferencedSymbol entry in 'result'.
	            var symbolToIndex = [];
	            if (scope) {
	                result = [];
	                getReferencesInNode(scope, symbol, declaredName, node, searchMeaning, findInStrings, findInComments, result, symbolToIndex);
	            }
	            else {
	                var internedName = getInternedName(symbol, node, declarations);
	                for (var _i = 0, sourceFiles_3 = sourceFiles; _i < sourceFiles_3.length; _i++) {
	                    var sourceFile = sourceFiles_3[_i];
	                    cancellationToken.throwIfCancellationRequested();
	                    var nameTable = getNameTable(sourceFile);
	                    if (ts.lookUp(nameTable, internedName) !== undefined) {
	                        result = result || [];
	                        getReferencesInNode(sourceFile, symbol, declaredName, node, searchMeaning, findInStrings, findInComments, result, symbolToIndex);
	                    }
	                }
	            }
	            return result;
	            function getDefinition(symbol) {
	                var info = getSymbolDisplayPartsDocumentationAndSymbolKind(symbol, node.getSourceFile(), getContainerNode(node), node);
	                var name = ts.map(info.displayParts, function (p) { return p.text; }).join("");
	                var declarations = symbol.declarations;
	                if (!declarations || declarations.length === 0) {
	                    return undefined;
	                }
	                return {
	                    containerKind: "",
	                    containerName: "",
	                    name: name,
	                    kind: info.symbolKind,
	                    fileName: declarations[0].getSourceFile().fileName,
	                    textSpan: ts.createTextSpan(declarations[0].getStart(), 0)
	                };
	            }
	            function isImportSpecifierSymbol(symbol) {
	                return (symbol.flags & 8388608 /* Alias */) && !!ts.getDeclarationOfKind(symbol, 229 /* ImportSpecifier */);
	            }
	            function getInternedName(symbol, location, declarations) {
	                // If this is an export or import specifier it could have been renamed using the 'as' syntax.
	                // If so we want to search for whatever under the cursor.
	                if (ts.isImportOrExportSpecifierName(location)) {
	                    return location.getText();
	                }
	                // Try to get the local symbol if we're dealing with an 'export default'
	                // since that symbol has the "true" name.
	                var localExportDefaultSymbol = ts.getLocalSymbolForExportDefault(symbol);
	                symbol = localExportDefaultSymbol || symbol;
	                return ts.stripQuotes(symbol.name);
	            }
	            /**
	             * Determines the smallest scope in which a symbol may have named references.
	             * Note that not every construct has been accounted for. This function can
	             * probably be improved.
	             *
	             * @returns undefined if the scope cannot be determined, implying that
	             * a reference to a symbol can occur anywhere.
	             */
	            function getSymbolScope(symbol) {
	                // If this is the symbol of a named function expression or named class expression,
	                // then named references are limited to its own scope.
	                var valueDeclaration = symbol.valueDeclaration;
	                if (valueDeclaration && (valueDeclaration.kind === 176 /* FunctionExpression */ || valueDeclaration.kind === 189 /* ClassExpression */)) {
	                    return valueDeclaration;
	                }
	                // If this is private property or method, the scope is the containing class
	                if (symbol.flags & (4 /* Property */ | 8192 /* Method */)) {
	                    var privateDeclaration = ts.forEach(symbol.getDeclarations(), function (d) { return (d.flags & 16 /* Private */) ? d : undefined; });
	                    if (privateDeclaration) {
	                        return ts.getAncestor(privateDeclaration, 217 /* ClassDeclaration */);
	                    }
	                }
	                // If the symbol is an import we would like to find it if we are looking for what it imports.
	                // So consider it visibile outside its declaration scope.
	                if (symbol.flags & 8388608 /* Alias */) {
	                    return undefined;
	                }
	                // if this symbol is visible from its parent container, e.g. exported, then bail out
	                // if symbol correspond to the union property - bail out
	                if (symbol.parent || (symbol.flags & 268435456 /* SyntheticProperty */)) {
	                    return undefined;
	                }
	                var scope;
	                var declarations = symbol.getDeclarations();
	                if (declarations) {
	                    for (var _i = 0, declarations_8 = declarations; _i < declarations_8.length; _i++) {
	                        var declaration = declarations_8[_i];
	                        var container = getContainerNode(declaration);
	                        if (!container) {
	                            return undefined;
	                        }
	                        if (scope && scope !== container) {
	                            // Different declarations have different containers, bail out
	                            return undefined;
	                        }
	                        if (container.kind === 251 /* SourceFile */ && !ts.isExternalModule(container)) {
	                            // This is a global variable and not an external module, any declaration defined
	                            // within this scope is visible outside the file
	                            return undefined;
	                        }
	                        // The search scope is the container node
	                        scope = container;
	                    }
	                }
	                return scope;
	            }
	            function getPossibleSymbolReferencePositions(sourceFile, symbolName, start, end) {
	                var positions = [];
	                /// TODO: Cache symbol existence for files to save text search
	                // Also, need to make this work for unicode escapes.
	                // Be resilient in the face of a symbol with no name or zero length name
	                if (!symbolName || !symbolName.length) {
	                    return positions;
	                }
	                var text = sourceFile.text;
	                var sourceLength = text.length;
	                var symbolNameLength = symbolName.length;
	                var position = text.indexOf(symbolName, start);
	                while (position >= 0) {
	                    cancellationToken.throwIfCancellationRequested();
	                    // If we are past the end, stop looking
	                    if (position > end)
	                        break;
	                    // We found a match.  Make sure it's not part of a larger word (i.e. the char
	                    // before and after it have to be a non-identifier char).
	                    var endPosition = position + symbolNameLength;
	                    if ((position === 0 || !ts.isIdentifierPart(text.charCodeAt(position - 1), 2 /* Latest */)) &&
	                        (endPosition === sourceLength || !ts.isIdentifierPart(text.charCodeAt(endPosition), 2 /* Latest */))) {
	                        // Found a real match.  Keep searching.
	                        positions.push(position);
	                    }
	                    position = text.indexOf(symbolName, position + symbolNameLength + 1);
	                }
	                return positions;
	            }
	            function getLabelReferencesInNode(container, targetLabel) {
	                var references = [];
	                var sourceFile = container.getSourceFile();
	                var labelName = targetLabel.text;
	                var possiblePositions = getPossibleSymbolReferencePositions(sourceFile, labelName, container.getStart(), container.getEnd());
	                ts.forEach(possiblePositions, function (position) {
	                    cancellationToken.throwIfCancellationRequested();
	                    var node = ts.getTouchingWord(sourceFile, position);
	                    if (!node || node.getWidth() !== labelName.length) {
	                        return;
	                    }
	                    // Only pick labels that are either the target label, or have a target that is the target label
	                    if (node === targetLabel ||
	                        (isJumpStatementTarget(node) && getTargetLabel(node, labelName) === targetLabel)) {
	                        references.push(getReferenceEntryFromNode(node));
	                    }
	                });
	                var definition = {
	                    containerKind: "",
	                    containerName: "",
	                    fileName: targetLabel.getSourceFile().fileName,
	                    kind: ScriptElementKind.label,
	                    name: labelName,
	                    textSpan: ts.createTextSpanFromBounds(targetLabel.getStart(), targetLabel.getEnd())
	                };
	                return [{ definition: definition, references: references }];
	            }
	            function isValidReferencePosition(node, searchSymbolName) {
	                if (node) {
	                    // Compare the length so we filter out strict superstrings of the symbol we are looking for
	                    switch (node.kind) {
	                        case 69 /* Identifier */:
	                            return node.getWidth() === searchSymbolName.length;
	                        case 9 /* StringLiteral */:
	                            if (isLiteralNameOfPropertyDeclarationOrIndexAccess(node) ||
	                                isNameOfExternalModuleImportOrDeclaration(node)) {
	                                // For string literals we have two additional chars for the quotes
	                                return node.getWidth() === searchSymbolName.length + 2;
	                            }
	                            break;
	                        case 8 /* NumericLiteral */:
	                            if (isLiteralNameOfPropertyDeclarationOrIndexAccess(node)) {
	                                return node.getWidth() === searchSymbolName.length;
	                            }
	                            break;
	                    }
	                }
	                return false;
	            }
	            /** Search within node "container" for references for a search value, where the search value is defined as a
	              * tuple of(searchSymbol, searchText, searchLocation, and searchMeaning).
	              * searchLocation: a node where the search value
	              */
	            function getReferencesInNode(container, searchSymbol, searchText, searchLocation, searchMeaning, findInStrings, findInComments, result, symbolToIndex) {
	                var sourceFile = container.getSourceFile();
	                var tripleSlashDirectivePrefixRegex = /^\/\/\/\s*</;
	                var possiblePositions = getPossibleSymbolReferencePositions(sourceFile, searchText, container.getStart(), container.getEnd());
	                if (possiblePositions.length) {
	                    // Build the set of symbols to search for, initially it has only the current symbol
	                    var searchSymbols_1 = populateSearchSymbolSet(searchSymbol, searchLocation);
	                    ts.forEach(possiblePositions, function (position) {
	                        cancellationToken.throwIfCancellationRequested();
	                        var referenceLocation = ts.getTouchingPropertyName(sourceFile, position);
	                        if (!isValidReferencePosition(referenceLocation, searchText)) {
	                            // This wasn't the start of a token.  Check to see if it might be a
	                            // match in a comment or string if that's what the caller is asking
	                            // for.
	                            if ((findInStrings && ts.isInString(sourceFile, position)) ||
	                                (findInComments && isInNonReferenceComment(sourceFile, position))) {
	                                // In the case where we're looking inside comments/strings, we don't have
	                                // an actual definition.  So just use 'undefined' here.  Features like
	                                // 'Rename' won't care (as they ignore the definitions), and features like
	                                // 'FindReferences' will just filter out these results.
	                                result.push({
	                                    definition: undefined,
	                                    references: [{
	                                            fileName: sourceFile.fileName,
	                                            textSpan: ts.createTextSpan(position, searchText.length),
	                                            isWriteAccess: false
	                                        }]
	                                });
	                            }
	                            return;
	                        }
	                        if (!(getMeaningFromLocation(referenceLocation) & searchMeaning)) {
	                            return;
	                        }
	                        var referenceSymbol = typeChecker.getSymbolAtLocation(referenceLocation);
	                        if (referenceSymbol) {
	                            var referenceSymbolDeclaration = referenceSymbol.valueDeclaration;
	                            var shorthandValueSymbol = typeChecker.getShorthandAssignmentValueSymbol(referenceSymbolDeclaration);
	                            var relatedSymbol = getRelatedSymbol(searchSymbols_1, referenceSymbol, referenceLocation);
	                            if (relatedSymbol) {
	                                var referencedSymbol = getReferencedSymbol(relatedSymbol);
	                                referencedSymbol.references.push(getReferenceEntryFromNode(referenceLocation));
	                            }
	                            else if (!(referenceSymbol.flags & 67108864 /* Transient */) && searchSymbols_1.indexOf(shorthandValueSymbol) >= 0) {
	                                var referencedSymbol = getReferencedSymbol(shorthandValueSymbol);
	                                referencedSymbol.references.push(getReferenceEntryFromNode(referenceSymbolDeclaration.name));
	                            }
	                        }
	                    });
	                }
	                return;
	                function getReferencedSymbol(symbol) {
	                    var symbolId = ts.getSymbolId(symbol);
	                    var index = symbolToIndex[symbolId];
	                    if (index === undefined) {
	                        index = result.length;
	                        symbolToIndex[symbolId] = index;
	                        result.push({
	                            definition: getDefinition(symbol),
	                            references: []
	                        });
	                    }
	                    return result[index];
	                }
	                function isInNonReferenceComment(sourceFile, position) {
	                    return ts.isInCommentHelper(sourceFile, position, isNonReferenceComment);
	                    function isNonReferenceComment(c) {
	                        var commentText = sourceFile.text.substring(c.pos, c.end);
	                        return !tripleSlashDirectivePrefixRegex.test(commentText);
	                    }
	                }
	            }
	            function getReferencesForSuperKeyword(superKeyword) {
	                var searchSpaceNode = ts.getSuperContainer(superKeyword, /*stopOnFunctions*/ false);
	                if (!searchSpaceNode) {
	                    return undefined;
	                }
	                // Whether 'super' occurs in a static context within a class.
	                var staticFlag = 64 /* Static */;
	                switch (searchSpaceNode.kind) {
	                    case 142 /* PropertyDeclaration */:
	                    case 141 /* PropertySignature */:
	                    case 144 /* MethodDeclaration */:
	                    case 143 /* MethodSignature */:
	                    case 145 /* Constructor */:
	                    case 146 /* GetAccessor */:
	                    case 147 /* SetAccessor */:
	                        staticFlag &= searchSpaceNode.flags;
	                        searchSpaceNode = searchSpaceNode.parent; // re-assign to be the owning class
	                        break;
	                    default:
	                        return undefined;
	                }
	                var references = [];
	                var sourceFile = searchSpaceNode.getSourceFile();
	                var possiblePositions = getPossibleSymbolReferencePositions(sourceFile, "super", searchSpaceNode.getStart(), searchSpaceNode.getEnd());
	                ts.forEach(possiblePositions, function (position) {
	                    cancellationToken.throwIfCancellationRequested();
	                    var node = ts.getTouchingWord(sourceFile, position);
	                    if (!node || node.kind !== 95 /* SuperKeyword */) {
	                        return;
	                    }
	                    var container = ts.getSuperContainer(node, /*stopOnFunctions*/ false);
	                    // If we have a 'super' container, we must have an enclosing class.
	                    // Now make sure the owning class is the same as the search-space
	                    // and has the same static qualifier as the original 'super's owner.
	                    if (container && (64 /* Static */ & container.flags) === staticFlag && container.parent.symbol === searchSpaceNode.symbol) {
	                        references.push(getReferenceEntryFromNode(node));
	                    }
	                });
	                var definition = getDefinition(searchSpaceNode.symbol);
	                return [{ definition: definition, references: references }];
	            }
	            function getReferencesForThisKeyword(thisOrSuperKeyword, sourceFiles) {
	                var searchSpaceNode = ts.getThisContainer(thisOrSuperKeyword, /* includeArrowFunctions */ false);
	                // Whether 'this' occurs in a static context within a class.
	                var staticFlag = 64 /* Static */;
	                switch (searchSpaceNode.kind) {
	                    case 144 /* MethodDeclaration */:
	                    case 143 /* MethodSignature */:
	                        if (ts.isObjectLiteralMethod(searchSpaceNode)) {
	                            break;
	                        }
	                    // fall through
	                    case 142 /* PropertyDeclaration */:
	                    case 141 /* PropertySignature */:
	                    case 145 /* Constructor */:
	                    case 146 /* GetAccessor */:
	                    case 147 /* SetAccessor */:
	                        staticFlag &= searchSpaceNode.flags;
	                        searchSpaceNode = searchSpaceNode.parent; // re-assign to be the owning class
	                        break;
	                    case 251 /* SourceFile */:
	                        if (ts.isExternalModule(searchSpaceNode)) {
	                            return undefined;
	                        }
	                    // Fall through
	                    case 216 /* FunctionDeclaration */:
	                    case 176 /* FunctionExpression */:
	                        break;
	                    // Computed properties in classes are not handled here because references to this are illegal,
	                    // so there is no point finding references to them.
	                    default:
	                        return undefined;
	                }
	                var references = [];
	                var possiblePositions;
	                if (searchSpaceNode.kind === 251 /* SourceFile */) {
	                    ts.forEach(sourceFiles, function (sourceFile) {
	                        possiblePositions = getPossibleSymbolReferencePositions(sourceFile, "this", sourceFile.getStart(), sourceFile.getEnd());
	                        getThisReferencesInFile(sourceFile, sourceFile, possiblePositions, references);
	                    });
	                }
	                else {
	                    var sourceFile = searchSpaceNode.getSourceFile();
	                    possiblePositions = getPossibleSymbolReferencePositions(sourceFile, "this", searchSpaceNode.getStart(), searchSpaceNode.getEnd());
	                    getThisReferencesInFile(sourceFile, searchSpaceNode, possiblePositions, references);
	                }
	                return [{
	                        definition: {
	                            containerKind: "",
	                            containerName: "",
	                            fileName: node.getSourceFile().fileName,
	                            kind: ScriptElementKind.variableElement,
	                            name: "this",
	                            textSpan: ts.createTextSpanFromBounds(node.getStart(), node.getEnd())
	                        },
	                        references: references
	                    }];
	                function getThisReferencesInFile(sourceFile, searchSpaceNode, possiblePositions, result) {
	                    ts.forEach(possiblePositions, function (position) {
	                        cancellationToken.throwIfCancellationRequested();
	                        var node = ts.getTouchingWord(sourceFile, position);
	                        if (!node || (node.kind !== 97 /* ThisKeyword */ && node.kind !== 162 /* ThisType */)) {
	                            return;
	                        }
	                        var container = ts.getThisContainer(node, /* includeArrowFunctions */ false);
	                        switch (searchSpaceNode.kind) {
	                            case 176 /* FunctionExpression */:
	                            case 216 /* FunctionDeclaration */:
	                                if (searchSpaceNode.symbol === container.symbol) {
	                                    result.push(getReferenceEntryFromNode(node));
	                                }
	                                break;
	                            case 144 /* MethodDeclaration */:
	                            case 143 /* MethodSignature */:
	                                if (ts.isObjectLiteralMethod(searchSpaceNode) && searchSpaceNode.symbol === container.symbol) {
	                                    result.push(getReferenceEntryFromNode(node));
	                                }
	                                break;
	                            case 189 /* ClassExpression */:
	                            case 217 /* ClassDeclaration */:
	                                // Make sure the container belongs to the same class
	                                // and has the appropriate static modifier from the original container.
	                                if (container.parent && searchSpaceNode.symbol === container.parent.symbol && (container.flags & 64 /* Static */) === staticFlag) {
	                                    result.push(getReferenceEntryFromNode(node));
	                                }
	                                break;
	                            case 251 /* SourceFile */:
	                                if (container.kind === 251 /* SourceFile */ && !ts.isExternalModule(container)) {
	                                    result.push(getReferenceEntryFromNode(node));
	                                }
	                                break;
	                        }
	                    });
	                }
	            }
	            function populateSearchSymbolSet(symbol, location) {
	                // The search set contains at least the current symbol
	                var result = [symbol];
	                // If the symbol is an alias, add what it alaises to the list
	                if (isImportSpecifierSymbol(symbol)) {
	                    result.push(typeChecker.getAliasedSymbol(symbol));
	                }
	                // For export specifiers, the exported name can be refering to a local symbol, e.g.:
	                //     import {a} from "mod";
	                //     export {a as somethingElse}
	                // We want the *local* declaration of 'a' as declared in the import,
	                // *not* as declared within "mod" (or farther)
	                if (location.parent.kind === 233 /* ExportSpecifier */) {
	                    result.push(typeChecker.getExportSpecifierLocalTargetSymbol(location.parent));
	                }
	                // If the location is in a context sensitive location (i.e. in an object literal) try
	                // to get a contextual type for it, and add the property symbol from the contextual
	                // type to the search set
	                if (isNameOfPropertyAssignment(location)) {
	                    ts.forEach(getPropertySymbolsFromContextualType(location), function (contextualSymbol) {
	                        ts.addRange(result, typeChecker.getRootSymbols(contextualSymbol));
	                    });
	                    /* Because in short-hand property assignment, location has two meaning : property name and as value of the property
	                     * When we do findAllReference at the position of the short-hand property assignment, we would want to have references to position of
	                     * property name and variable declaration of the identifier.
	                     * Like in below example, when querying for all references for an identifier 'name', of the property assignment, the language service
	                     * should show both 'name' in 'obj' and 'name' in variable declaration
	                     *      const name = "Foo";
	                     *      const obj = { name };
	                     * In order to do that, we will populate the search set with the value symbol of the identifier as a value of the property assignment
	                     * so that when matching with potential reference symbol, both symbols from property declaration and variable declaration
	                     * will be included correctly.
	                     */
	                    var shorthandValueSymbol = typeChecker.getShorthandAssignmentValueSymbol(location.parent);
	                    if (shorthandValueSymbol) {
	                        result.push(shorthandValueSymbol);
	                    }
	                }
	                // If the symbol.valueDeclaration is a property parameter declaration,
	                // we should include both parameter declaration symbol and property declaration symbol
	                // Parameter Declaration symbol is only visible within function scope, so the symbol is stored in contructor.locals.
	                // Property Declaration symbol is a member of the class, so the symbol is stored in its class Declaration.symbol.members
	                if (symbol.valueDeclaration && symbol.valueDeclaration.kind === 139 /* Parameter */ &&
	                    ts.isParameterPropertyDeclaration(symbol.valueDeclaration)) {
	                    result = result.concat(typeChecker.getSymbolsOfParameterPropertyDeclaration(symbol.valueDeclaration, symbol.name));
	                }
	                // If this is a union property, add all the symbols from all its source symbols in all unioned types.
	                // If the symbol is an instantiation from a another symbol (e.g. widened symbol) , add the root the list
	                ts.forEach(typeChecker.getRootSymbols(symbol), function (rootSymbol) {
	                    if (rootSymbol !== symbol) {
	                        result.push(rootSymbol);
	                    }
	                    // Add symbol of properties/methods of the same name in base classes and implemented interfaces definitions
	                    if (rootSymbol.parent && rootSymbol.parent.flags & (32 /* Class */ | 64 /* Interface */)) {
	                        getPropertySymbolsFromBaseTypes(rootSymbol.parent, rootSymbol.getName(), result, /*previousIterationSymbolsCache*/ {});
	                    }
	                });
	                return result;
	            }
	            /**
	             * Find symbol of the given property-name and add the symbol to the given result array
	             * @param symbol a symbol to start searching for the given propertyName
	             * @param propertyName a name of property to serach for
	             * @param result an array of symbol of found property symbols
	             * @param previousIterationSymbolsCache a cache of symbol from previous iterations of calling this function to prevent infinite revisitng of the same symbol.
	             *                                The value of previousIterationSymbol is undefined when the function is first called.
	             */
	            function getPropertySymbolsFromBaseTypes(symbol, propertyName, result, previousIterationSymbolsCache) {
	                if (!symbol) {
	                    return;
	                }
	                // If the current symbol is the same as the previous-iteration symbol, we can just return the symbol that has already been visited
	                // This is particularly important for the following cases, so that we do not infinitely visit the same symbol.
	                // For example:
	                //      interface C extends C {
	                //          /*findRef*/propName: string;
	                //      }
	                // The first time getPropertySymbolsFromBaseTypes is called when finding-all-references at propName,
	                // the symbol argument will be the symbol of an interface "C" and previousIterationSymbol is undefined,
	                // the function will add any found symbol of the property-name, then its sub-routine will call
	                // getPropertySymbolsFromBaseTypes again to walk up any base types to prevent revisiting already
	                // visited symbol, interface "C", the sub-routine will pass the current symbol as previousIterationSymbol.
	                if (ts.hasProperty(previousIterationSymbolsCache, symbol.name)) {
	                    return;
	                }
	                if (symbol.flags & (32 /* Class */ | 64 /* Interface */)) {
	                    ts.forEach(symbol.getDeclarations(), function (declaration) {
	                        if (declaration.kind === 217 /* ClassDeclaration */) {
	                            getPropertySymbolFromTypeReference(ts.getClassExtendsHeritageClauseElement(declaration));
	                            ts.forEach(ts.getClassImplementsHeritageClauseElements(declaration), getPropertySymbolFromTypeReference);
	                        }
	                        else if (declaration.kind === 218 /* InterfaceDeclaration */) {
	                            ts.forEach(ts.getInterfaceBaseTypeNodes(declaration), getPropertySymbolFromTypeReference);
	                        }
	                    });
	                }
	                return;
	                function getPropertySymbolFromTypeReference(typeReference) {
	                    if (typeReference) {
	                        var type = typeChecker.getTypeAtLocation(typeReference);
	                        if (type) {
	                            var propertySymbol = typeChecker.getPropertyOfType(type, propertyName);
	                            if (propertySymbol) {
	                                result.push(propertySymbol);
	                            }
	                            // Visit the typeReference as well to see if it directly or indirectly use that property
	                            previousIterationSymbolsCache[symbol.name] = symbol;
	                            getPropertySymbolsFromBaseTypes(type.symbol, propertyName, result, previousIterationSymbolsCache);
	                        }
	                    }
	                }
	            }
	            function getRelatedSymbol(searchSymbols, referenceSymbol, referenceLocation) {
	                if (searchSymbols.indexOf(referenceSymbol) >= 0) {
	                    return referenceSymbol;
	                }
	                // If the reference symbol is an alias, check if what it is aliasing is one of the search
	                // symbols.
	                if (isImportSpecifierSymbol(referenceSymbol)) {
	                    var aliasedSymbol = typeChecker.getAliasedSymbol(referenceSymbol);
	                    if (searchSymbols.indexOf(aliasedSymbol) >= 0) {
	                        return aliasedSymbol;
	                    }
	                }
	                // For export specifiers, it can be a local symbol, e.g. 
	                //     import {a} from "mod";
	                //     export {a as somethingElse}
	                // We want the local target of the export (i.e. the import symbol) and not the final target (i.e. "mod".a)
	                if (referenceLocation.parent.kind === 233 /* ExportSpecifier */) {
	                    var aliasedSymbol = typeChecker.getExportSpecifierLocalTargetSymbol(referenceLocation.parent);
	                    if (searchSymbols.indexOf(aliasedSymbol) >= 0) {
	                        return aliasedSymbol;
	                    }
	                }
	                // If the reference location is in an object literal, try to get the contextual type for the
	                // object literal, lookup the property symbol in the contextual type, and use this symbol to
	                // compare to our searchSymbol
	                if (isNameOfPropertyAssignment(referenceLocation)) {
	                    return ts.forEach(getPropertySymbolsFromContextualType(referenceLocation), function (contextualSymbol) {
	                        return ts.forEach(typeChecker.getRootSymbols(contextualSymbol), function (s) { return searchSymbols.indexOf(s) >= 0 ? s : undefined; });
	                    });
	                }
	                // Unwrap symbols to get to the root (e.g. transient symbols as a result of widening)
	                // Or a union property, use its underlying unioned symbols
	                return ts.forEach(typeChecker.getRootSymbols(referenceSymbol), function (rootSymbol) {
	                    // if it is in the list, then we are done
	                    if (searchSymbols.indexOf(rootSymbol) >= 0) {
	                        return rootSymbol;
	                    }
	                    // Finally, try all properties with the same name in any type the containing type extended or implemented, and
	                    // see if any is in the list
	                    if (rootSymbol.parent && rootSymbol.parent.flags & (32 /* Class */ | 64 /* Interface */)) {
	                        var result_5 = [];
	                        getPropertySymbolsFromBaseTypes(rootSymbol.parent, rootSymbol.getName(), result_5, /*previousIterationSymbolsCache*/ {});
	                        return ts.forEach(result_5, function (s) { return searchSymbols.indexOf(s) >= 0 ? s : undefined; });
	                    }
	                    return undefined;
	                });
	            }
	            function getPropertySymbolsFromContextualType(node) {
	                if (isNameOfPropertyAssignment(node)) {
	                    var objectLiteral = node.parent.parent;
	                    var contextualType = typeChecker.getContextualType(objectLiteral);
	                    var name_37 = node.text;
	                    if (contextualType) {
	                        if (contextualType.flags & 16384 /* Union */) {
	                            // This is a union type, first see if the property we are looking for is a union property (i.e. exists in all types)
	                            // if not, search the constituent types for the property
	                            var unionProperty = contextualType.getProperty(name_37);
	                            if (unionProperty) {
	                                return [unionProperty];
	                            }
	                            else {
	                                var result_6 = [];
	                                ts.forEach(contextualType.types, function (t) {
	                                    var symbol = t.getProperty(name_37);
	                                    if (symbol) {
	                                        result_6.push(symbol);
	                                    }
	                                });
	                                return result_6;
	                            }
	                        }
	                        else {
	                            var symbol_1 = contextualType.getProperty(name_37);
	                            if (symbol_1) {
	                                return [symbol_1];
	                            }
	                        }
	                    }
	                }
	                return undefined;
	            }
	            /** Given an initial searchMeaning, extracted from a location, widen the search scope based on the declarations
	              * of the corresponding symbol. e.g. if we are searching for "Foo" in value position, but "Foo" references a class
	              * then we need to widen the search to include type positions as well.
	              * On the contrary, if we are searching for "Bar" in type position and we trace bar to an interface, and an uninstantiated
	              * module, we want to keep the search limited to only types, as the two declarations (interface and uninstantiated module)
	              * do not intersect in any of the three spaces.
	              */
	            function getIntersectingMeaningFromDeclarations(meaning, declarations) {
	                if (declarations) {
	                    var lastIterationMeaning = void 0;
	                    do {
	                        // The result is order-sensitive, for instance if initialMeaning === Namespace, and declarations = [class, instantiated module]
	                        // we need to consider both as they initialMeaning intersects with the module in the namespace space, and the module
	                        // intersects with the class in the value space.
	                        // To achieve that we will keep iterating until the result stabilizes.
	                        // Remember the last meaning
	                        lastIterationMeaning = meaning;
	                        for (var _i = 0, declarations_9 = declarations; _i < declarations_9.length; _i++) {
	                            var declaration = declarations_9[_i];
	                            var declarationMeaning = getMeaningFromDeclaration(declaration);
	                            if (declarationMeaning & meaning) {
	                                meaning |= declarationMeaning;
	                            }
	                        }
	                    } while (meaning !== lastIterationMeaning);
	                }
	                return meaning;
	            }
	        }
	        function getReferenceEntryFromNode(node) {
	            var start = node.getStart();
	            var end = node.getEnd();
	            if (node.kind === 9 /* StringLiteral */) {
	                start += 1;
	                end -= 1;
	            }
	            return {
	                fileName: node.getSourceFile().fileName,
	                textSpan: ts.createTextSpanFromBounds(start, end),
	                isWriteAccess: isWriteAccess(node)
	            };
	        }
	        /** A node is considered a writeAccess iff it is a name of a declaration or a target of an assignment */
	        function isWriteAccess(node) {
	            if (node.kind === 69 /* Identifier */ && ts.isDeclarationName(node)) {
	                return true;
	            }
	            var parent = node.parent;
	            if (parent) {
	                if (parent.kind === 183 /* PostfixUnaryExpression */ || parent.kind === 182 /* PrefixUnaryExpression */) {
	                    return true;
	                }
	                else if (parent.kind === 184 /* BinaryExpression */ && parent.left === node) {
	                    var operator = parent.operatorToken.kind;
	                    return 56 /* FirstAssignment */ <= operator && operator <= 68 /* LastAssignment */;
	                }
	            }
	            return false;
	        }
	        /// NavigateTo
	        function getNavigateToItems(searchValue, maxResultCount) {
	            synchronizeHostData();
	            return ts.NavigateTo.getNavigateToItems(program, cancellationToken, searchValue, maxResultCount);
	        }
	        function getEmitOutput(fileName) {
	            synchronizeHostData();
	            var sourceFile = getValidSourceFile(fileName);
	            var outputFiles = [];
	            function writeFile(fileName, data, writeByteOrderMark) {
	                outputFiles.push({
	                    name: fileName,
	                    writeByteOrderMark: writeByteOrderMark,
	                    text: data
	                });
	            }
	            var emitOutput = program.emit(sourceFile, writeFile, cancellationToken);
	            return {
	                outputFiles: outputFiles,
	                emitSkipped: emitOutput.emitSkipped
	            };
	        }
	        function getMeaningFromDeclaration(node) {
	            switch (node.kind) {
	                case 139 /* Parameter */:
	                case 214 /* VariableDeclaration */:
	                case 166 /* BindingElement */:
	                case 142 /* PropertyDeclaration */:
	                case 141 /* PropertySignature */:
	                case 248 /* PropertyAssignment */:
	                case 249 /* ShorthandPropertyAssignment */:
	                case 250 /* EnumMember */:
	                case 144 /* MethodDeclaration */:
	                case 143 /* MethodSignature */:
	                case 145 /* Constructor */:
	                case 146 /* GetAccessor */:
	                case 147 /* SetAccessor */:
	                case 216 /* FunctionDeclaration */:
	                case 176 /* FunctionExpression */:
	                case 177 /* ArrowFunction */:
	                case 247 /* CatchClause */:
	                    return 1 /* Value */;
	                case 138 /* TypeParameter */:
	                case 218 /* InterfaceDeclaration */:
	                case 219 /* TypeAliasDeclaration */:
	                case 156 /* TypeLiteral */:
	                    return 2 /* Type */;
	                case 217 /* ClassDeclaration */:
	                case 220 /* EnumDeclaration */:
	                    return 1 /* Value */ | 2 /* Type */;
	                case 221 /* ModuleDeclaration */:
	                    if (ts.isAmbientModule(node)) {
	                        return 4 /* Namespace */ | 1 /* Value */;
	                    }
	                    else if (ts.getModuleInstanceState(node) === 1 /* Instantiated */) {
	                        return 4 /* Namespace */ | 1 /* Value */;
	                    }
	                    else {
	                        return 4 /* Namespace */;
	                    }
	                case 228 /* NamedImports */:
	                case 229 /* ImportSpecifier */:
	                case 224 /* ImportEqualsDeclaration */:
	                case 225 /* ImportDeclaration */:
	                case 230 /* ExportAssignment */:
	                case 231 /* ExportDeclaration */:
	                    return 1 /* Value */ | 2 /* Type */ | 4 /* Namespace */;
	                // An external module can be a Value
	                case 251 /* SourceFile */:
	                    return 4 /* Namespace */ | 1 /* Value */;
	            }
	            return 1 /* Value */ | 2 /* Type */ | 4 /* Namespace */;
	        }
	        function isTypeReference(node) {
	            if (ts.isRightSideOfQualifiedNameOrPropertyAccess(node)) {
	                node = node.parent;
	            }
	            return node.parent.kind === 152 /* TypeReference */ ||
	                (node.parent.kind === 191 /* ExpressionWithTypeArguments */ && !ts.isExpressionWithTypeArgumentsInClassExtendsClause(node.parent)) ||
	                (node.kind === 97 /* ThisKeyword */ && !ts.isExpression(node)) ||
	                node.kind === 162 /* ThisType */;
	        }
	        function isNamespaceReference(node) {
	            return isQualifiedNameNamespaceReference(node) || isPropertyAccessNamespaceReference(node);
	        }
	        function isPropertyAccessNamespaceReference(node) {
	            var root = node;
	            var isLastClause = true;
	            if (root.parent.kind === 169 /* PropertyAccessExpression */) {
	                while (root.parent && root.parent.kind === 169 /* PropertyAccessExpression */) {
	                    root = root.parent;
	                }
	                isLastClause = root.name === node;
	            }
	            if (!isLastClause && root.parent.kind === 191 /* ExpressionWithTypeArguments */ && root.parent.parent.kind === 246 /* HeritageClause */) {
	                var decl = root.parent.parent.parent;
	                return (decl.kind === 217 /* ClassDeclaration */ && root.parent.parent.token === 106 /* ImplementsKeyword */) ||
	                    (decl.kind === 218 /* InterfaceDeclaration */ && root.parent.parent.token === 83 /* ExtendsKeyword */);
	            }
	            return false;
	        }
	        function isQualifiedNameNamespaceReference(node) {
	            var root = node;
	            var isLastClause = true;
	            if (root.parent.kind === 136 /* QualifiedName */) {
	                while (root.parent && root.parent.kind === 136 /* QualifiedName */) {
	                    root = root.parent;
	                }
	                isLastClause = root.right === node;
	            }
	            return root.parent.kind === 152 /* TypeReference */ && !isLastClause;
	        }
	        function isInRightSideOfImport(node) {
	            while (node.parent.kind === 136 /* QualifiedName */) {
	                node = node.parent;
	            }
	            return ts.isInternalModuleImportEqualsDeclaration(node.parent) && node.parent.moduleReference === node;
	        }
	        function getMeaningFromRightHandSideOfImportEquals(node) {
	            ts.Debug.assert(node.kind === 69 /* Identifier */);
	            //     import a = |b|; // Namespace
	            //     import a = |b.c|; // Value, type, namespace
	            //     import a = |b.c|.d; // Namespace
	            if (node.parent.kind === 136 /* QualifiedName */ &&
	                node.parent.right === node &&
	                node.parent.parent.kind === 224 /* ImportEqualsDeclaration */) {
	                return 1 /* Value */ | 2 /* Type */ | 4 /* Namespace */;
	            }
	            return 4 /* Namespace */;
	        }
	        function getMeaningFromLocation(node) {
	            if (node.parent.kind === 230 /* ExportAssignment */) {
	                return 1 /* Value */ | 2 /* Type */ | 4 /* Namespace */;
	            }
	            else if (isInRightSideOfImport(node)) {
	                return getMeaningFromRightHandSideOfImportEquals(node);
	            }
	            else if (ts.isDeclarationName(node)) {
	                return getMeaningFromDeclaration(node.parent);
	            }
	            else if (isTypeReference(node)) {
	                return 2 /* Type */;
	            }
	            else if (isNamespaceReference(node)) {
	                return 4 /* Namespace */;
	            }
	            else {
	                return 1 /* Value */;
	            }
	        }
	        // Signature help
	        /**
	         * This is a semantic operation.
	         */
	        function getSignatureHelpItems(fileName, position) {
	            synchronizeHostData();
	            var sourceFile = getValidSourceFile(fileName);
	            return ts.SignatureHelp.getSignatureHelpItems(program, sourceFile, position, cancellationToken);
	        }
	        /// Syntactic features
	        function getSourceFile(fileName) {
	            return syntaxTreeCache.getCurrentSourceFile(fileName);
	        }
	        function getNameOrDottedNameSpan(fileName, startPos, endPos) {
	            var sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
	            // Get node at the location
	            var node = ts.getTouchingPropertyName(sourceFile, startPos);
	            if (!node) {
	                return;
	            }
	            switch (node.kind) {
	                case 169 /* PropertyAccessExpression */:
	                case 136 /* QualifiedName */:
	                case 9 /* StringLiteral */:
	                case 163 /* StringLiteralType */:
	                case 84 /* FalseKeyword */:
	                case 99 /* TrueKeyword */:
	                case 93 /* NullKeyword */:
	                case 95 /* SuperKeyword */:
	                case 97 /* ThisKeyword */:
	                case 162 /* ThisType */:
	                case 69 /* Identifier */:
	                    break;
	                // Cant create the text span
	                default:
	                    return;
	            }
	            var nodeForStartPos = node;
	            while (true) {
	                if (isRightSideOfPropertyAccess(nodeForStartPos) || isRightSideOfQualifiedName(nodeForStartPos)) {
	                    // If on the span is in right side of the the property or qualified name, return the span from the qualified name pos to end of this node
	                    nodeForStartPos = nodeForStartPos.parent;
	                }
	                else if (isNameOfModuleDeclaration(nodeForStartPos)) {
	                    // If this is name of a module declarations, check if this is right side of dotted module name
	                    // If parent of the module declaration which is parent of this node is module declaration and its body is the module declaration that this node is name of
	                    // Then this name is name from dotted module
	                    if (nodeForStartPos.parent.parent.kind === 221 /* ModuleDeclaration */ &&
	                        nodeForStartPos.parent.parent.body === nodeForStartPos.parent) {
	                        // Use parent module declarations name for start pos
	                        nodeForStartPos = nodeForStartPos.parent.parent.name;
	                    }
	                    else {
	                        // We have to use this name for start pos
	                        break;
	                    }
	                }
	                else {
	                    // Is not a member expression so we have found the node for start pos
	                    break;
	                }
	            }
	            return ts.createTextSpanFromBounds(nodeForStartPos.getStart(), node.getEnd());
	        }
	        function getBreakpointStatementAtPosition(fileName, position) {
	            // doesn't use compiler - no need to synchronize with host
	            var sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
	            return ts.BreakpointResolver.spanInSourceFileAtLocation(sourceFile, position);
	        }
	        function getNavigationBarItems(fileName) {
	            var sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
	            return ts.NavigationBar.getNavigationBarItems(sourceFile, host.getCompilationSettings());
	        }
	        function getSemanticClassifications(fileName, span) {
	            return convertClassifications(getEncodedSemanticClassifications(fileName, span));
	        }
	        function checkForClassificationCancellation(kind) {
	            // We don't want to actually call back into our host on every node to find out if we've
	            // been canceled.  That would be an enormous amount of chattyness, along with the all
	            // the overhead of marshalling the data to/from the host.  So instead we pick a few
	            // reasonable node kinds to bother checking on.  These node kinds represent high level
	            // constructs that we would expect to see commonly, but just at a far less frequent
	            // interval.
	            //
	            // For example, in checker.ts (around 750k) we only have around 600 of these constructs.
	            // That means we're calling back into the host around every 1.2k of the file we process.
	            // Lib.d.ts has similar numbers.
	            switch (kind) {
	                case 221 /* ModuleDeclaration */:
	                case 217 /* ClassDeclaration */:
	                case 218 /* InterfaceDeclaration */:
	                case 216 /* FunctionDeclaration */:
	                    cancellationToken.throwIfCancellationRequested();
	            }
	        }
	        function getEncodedSemanticClassifications(fileName, span) {
	            synchronizeHostData();
	            var sourceFile = getValidSourceFile(fileName);
	            var typeChecker = program.getTypeChecker();
	            var result = [];
	            var classifiableNames = program.getClassifiableNames();
	            processNode(sourceFile);
	            return { spans: result, endOfLineState: 0 /* None */ };
	            function pushClassification(start, length, type) {
	                result.push(start);
	                result.push(length);
	                result.push(type);
	            }
	            function classifySymbol(symbol, meaningAtPosition) {
	                var flags = symbol.getFlags();
	                if ((flags & 788448 /* Classifiable */) === 0 /* None */) {
	                    return;
	                }
	                if (flags & 32 /* Class */) {
	                    return 11 /* className */;
	                }
	                else if (flags & 384 /* Enum */) {
	                    return 12 /* enumName */;
	                }
	                else if (flags & 524288 /* TypeAlias */) {
	                    return 16 /* typeAliasName */;
	                }
	                else if (meaningAtPosition & 2 /* Type */) {
	                    if (flags & 64 /* Interface */) {
	                        return 13 /* interfaceName */;
	                    }
	                    else if (flags & 262144 /* TypeParameter */) {
	                        return 15 /* typeParameterName */;
	                    }
	                }
	                else if (flags & 1536 /* Module */) {
	                    // Only classify a module as such if
	                    //  - It appears in a namespace context.
	                    //  - There exists a module declaration which actually impacts the value side.
	                    if (meaningAtPosition & 4 /* Namespace */ ||
	                        (meaningAtPosition & 1 /* Value */ && hasValueSideModule(symbol))) {
	                        return 14 /* moduleName */;
	                    }
	                }
	                return undefined;
	                /**
	                 * Returns true if there exists a module that introduces entities on the value side.
	                 */
	                function hasValueSideModule(symbol) {
	                    return ts.forEach(symbol.declarations, function (declaration) {
	                        return declaration.kind === 221 /* ModuleDeclaration */ &&
	                            ts.getModuleInstanceState(declaration) === 1 /* Instantiated */;
	                    });
	                }
	            }
	            function processNode(node) {
	                // Only walk into nodes that intersect the requested span.
	                if (node && ts.textSpanIntersectsWith(span, node.getFullStart(), node.getFullWidth())) {
	                    var kind = node.kind;
	                    checkForClassificationCancellation(kind);
	                    if (kind === 69 /* Identifier */ && !ts.nodeIsMissing(node)) {
	                        var identifier = node;
	                        // Only bother calling into the typechecker if this is an identifier that
	                        // could possibly resolve to a type name.  This makes classification run
	                        // in a third of the time it would normally take.
	                        if (classifiableNames[identifier.text]) {
	                            var symbol = typeChecker.getSymbolAtLocation(node);
	                            if (symbol) {
	                                var type = classifySymbol(symbol, getMeaningFromLocation(node));
	                                if (type) {
	                                    pushClassification(node.getStart(), node.getWidth(), type);
	                                }
	                            }
	                        }
	                    }
	                    ts.forEachChild(node, processNode);
	                }
	            }
	        }
	        function getClassificationTypeName(type) {
	            switch (type) {
	                case 1 /* comment */: return ClassificationTypeNames.comment;
	                case 2 /* identifier */: return ClassificationTypeNames.identifier;
	                case 3 /* keyword */: return ClassificationTypeNames.keyword;
	                case 4 /* numericLiteral */: return ClassificationTypeNames.numericLiteral;
	                case 5 /* operator */: return ClassificationTypeNames.operator;
	                case 6 /* stringLiteral */: return ClassificationTypeNames.stringLiteral;
	                case 8 /* whiteSpace */: return ClassificationTypeNames.whiteSpace;
	                case 9 /* text */: return ClassificationTypeNames.text;
	                case 10 /* punctuation */: return ClassificationTypeNames.punctuation;
	                case 11 /* className */: return ClassificationTypeNames.className;
	                case 12 /* enumName */: return ClassificationTypeNames.enumName;
	                case 13 /* interfaceName */: return ClassificationTypeNames.interfaceName;
	                case 14 /* moduleName */: return ClassificationTypeNames.moduleName;
	                case 15 /* typeParameterName */: return ClassificationTypeNames.typeParameterName;
	                case 16 /* typeAliasName */: return ClassificationTypeNames.typeAliasName;
	                case 17 /* parameterName */: return ClassificationTypeNames.parameterName;
	                case 18 /* docCommentTagName */: return ClassificationTypeNames.docCommentTagName;
	                case 19 /* jsxOpenTagName */: return ClassificationTypeNames.jsxOpenTagName;
	                case 20 /* jsxCloseTagName */: return ClassificationTypeNames.jsxCloseTagName;
	                case 21 /* jsxSelfClosingTagName */: return ClassificationTypeNames.jsxSelfClosingTagName;
	                case 22 /* jsxAttribute */: return ClassificationTypeNames.jsxAttribute;
	                case 23 /* jsxText */: return ClassificationTypeNames.jsxText;
	                case 24 /* jsxAttributeStringLiteralValue */: return ClassificationTypeNames.jsxAttributeStringLiteralValue;
	            }
	        }
	        function convertClassifications(classifications) {
	            ts.Debug.assert(classifications.spans.length % 3 === 0);
	            var dense = classifications.spans;
	            var result = [];
	            for (var i = 0, n = dense.length; i < n; i += 3) {
	                result.push({
	                    textSpan: ts.createTextSpan(dense[i], dense[i + 1]),
	                    classificationType: getClassificationTypeName(dense[i + 2])
	                });
	            }
	            return result;
	        }
	        function getSyntacticClassifications(fileName, span) {
	            return convertClassifications(getEncodedSyntacticClassifications(fileName, span));
	        }
	        function getEncodedSyntacticClassifications(fileName, span) {
	            // doesn't use compiler - no need to synchronize with host
	            var sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
	            var spanStart = span.start;
	            var spanLength = span.length;
	            // Make a scanner we can get trivia from.
	            var triviaScanner = ts.createScanner(2 /* Latest */, /*skipTrivia*/ false, sourceFile.languageVariant, sourceFile.text);
	            var mergeConflictScanner = ts.createScanner(2 /* Latest */, /*skipTrivia*/ false, sourceFile.languageVariant, sourceFile.text);
	            var result = [];
	            processElement(sourceFile);
	            return { spans: result, endOfLineState: 0 /* None */ };
	            function pushClassification(start, length, type) {
	                result.push(start);
	                result.push(length);
	                result.push(type);
	            }
	            function classifyLeadingTriviaAndGetTokenStart(token) {
	                triviaScanner.setTextPos(token.pos);
	                while (true) {
	                    var start = triviaScanner.getTextPos();
	                    // only bother scanning if we have something that could be trivia.
	                    if (!ts.couldStartTrivia(sourceFile.text, start)) {
	                        return start;
	                    }
	                    var kind = triviaScanner.scan();
	                    var end = triviaScanner.getTextPos();
	                    var width = end - start;
	                    // The moment we get something that isn't trivia, then stop processing.
	                    if (!ts.isTrivia(kind)) {
	                        return start;
	                    }
	                    // Don't bother with newlines/whitespace.
	                    if (kind === 4 /* NewLineTrivia */ || kind === 5 /* WhitespaceTrivia */) {
	                        continue;
	                    }
	                    // Only bother with the trivia if it at least intersects the span of interest.
	                    if (ts.isComment(kind)) {
	                        classifyComment(token, kind, start, width);
	                        // Classifying a comment might cause us to reuse the trivia scanner
	                        // (because of jsdoc comments).  So after we classify the comment make
	                        // sure we set the scanner position back to where it needs to be.
	                        triviaScanner.setTextPos(end);
	                        continue;
	                    }
	                    if (kind === 7 /* ConflictMarkerTrivia */) {
	                        var text = sourceFile.text;
	                        var ch = text.charCodeAt(start);
	                        // for the <<<<<<< and >>>>>>> markers, we just add them in as comments
	                        // in the classification stream.
	                        if (ch === 60 /* lessThan */ || ch === 62 /* greaterThan */) {
	                            pushClassification(start, width, 1 /* comment */);
	                            continue;
	                        }
	                        // for the ======== add a comment for the first line, and then lex all
	                        // subsequent lines up until the end of the conflict marker.
	                        ts.Debug.assert(ch === 61 /* equals */);
	                        classifyDisabledMergeCode(text, start, end);
	                    }
	                }
	            }
	            function classifyComment(token, kind, start, width) {
	                if (kind === 3 /* MultiLineCommentTrivia */) {
	                    // See if this is a doc comment.  If so, we'll classify certain portions of it
	                    // specially.
	                    var docCommentAndDiagnostics = ts.parseIsolatedJSDocComment(sourceFile.text, start, width);
	                    if (docCommentAndDiagnostics && docCommentAndDiagnostics.jsDocComment) {
	                        docCommentAndDiagnostics.jsDocComment.parent = token;
	                        classifyJSDocComment(docCommentAndDiagnostics.jsDocComment);
	                        return;
	                    }
	                }
	                // Simple comment.  Just add as is.
	                pushCommentRange(start, width);
	            }
	            function pushCommentRange(start, width) {
	                pushClassification(start, width, 1 /* comment */);
	            }
	            function classifyJSDocComment(docComment) {
	                var pos = docComment.pos;
	                for (var _i = 0, _a = docComment.tags; _i < _a.length; _i++) {
	                    var tag = _a[_i];
	                    // As we walk through each tag, classify the portion of text from the end of
	                    // the last tag (or the start of the entire doc comment) as 'comment'.
	                    if (tag.pos !== pos) {
	                        pushCommentRange(pos, tag.pos - pos);
	                    }
	                    pushClassification(tag.atToken.pos, tag.atToken.end - tag.atToken.pos, 10 /* punctuation */);
	                    pushClassification(tag.tagName.pos, tag.tagName.end - tag.tagName.pos, 18 /* docCommentTagName */);
	                    pos = tag.tagName.end;
	                    switch (tag.kind) {
	                        case 270 /* JSDocParameterTag */:
	                            processJSDocParameterTag(tag);
	                            break;
	                        case 273 /* JSDocTemplateTag */:
	                            processJSDocTemplateTag(tag);
	                            break;
	                        case 272 /* JSDocTypeTag */:
	                            processElement(tag.typeExpression);
	                            break;
	                        case 271 /* JSDocReturnTag */:
	                            processElement(tag.typeExpression);
	                            break;
	                    }
	                    pos = tag.end;
	                }
	                if (pos !== docComment.end) {
	                    pushCommentRange(pos, docComment.end - pos);
	                }
	                return;
	                function processJSDocParameterTag(tag) {
	                    if (tag.preParameterName) {
	                        pushCommentRange(pos, tag.preParameterName.pos - pos);
	                        pushClassification(tag.preParameterName.pos, tag.preParameterName.end - tag.preParameterName.pos, 17 /* parameterName */);
	                        pos = tag.preParameterName.end;
	                    }
	                    if (tag.typeExpression) {
	                        pushCommentRange(pos, tag.typeExpression.pos - pos);
	                        processElement(tag.typeExpression);
	                        pos = tag.typeExpression.end;
	                    }
	                    if (tag.postParameterName) {
	                        pushCommentRange(pos, tag.postParameterName.pos - pos);
	                        pushClassification(tag.postParameterName.pos, tag.postParameterName.end - tag.postParameterName.pos, 17 /* parameterName */);
	                        pos = tag.postParameterName.end;
	                    }
	                }
	            }
	            function processJSDocTemplateTag(tag) {
	                for (var _i = 0, _a = tag.getChildren(); _i < _a.length; _i++) {
	                    var child = _a[_i];
	                    processElement(child);
	                }
	            }
	            function classifyDisabledMergeCode(text, start, end) {
	                // Classify the line that the ======= marker is on as a comment.  Then just lex
	                // all further tokens and add them to the result.
	                var i;
	                for (i = start; i < end; i++) {
	                    if (ts.isLineBreak(text.charCodeAt(i))) {
	                        break;
	                    }
	                }
	                pushClassification(start, i - start, 1 /* comment */);
	                mergeConflictScanner.setTextPos(i);
	                while (mergeConflictScanner.getTextPos() < end) {
	                    classifyDisabledCodeToken();
	                }
	            }
	            function classifyDisabledCodeToken() {
	                var start = mergeConflictScanner.getTextPos();
	                var tokenKind = mergeConflictScanner.scan();
	                var end = mergeConflictScanner.getTextPos();
	                var type = classifyTokenType(tokenKind);
	                if (type) {
	                    pushClassification(start, end - start, type);
	                }
	            }
	            /**
	             * Returns true if node should be treated as classified and no further processing is required.
	             * False will mean that node is not classified and traverse routine should recurse into node contents.
	             */
	            function tryClassifyNode(node) {
	                if (ts.nodeIsMissing(node)) {
	                    return true;
	                }
	                var classifiedElementName = tryClassifyJsxElementName(node);
	                if (!ts.isToken(node) && node.kind !== 239 /* JsxText */ && classifiedElementName === undefined) {
	                    return false;
	                }
	                var tokenStart = node.kind === 239 /* JsxText */ ? node.pos : classifyLeadingTriviaAndGetTokenStart(node);
	                var tokenWidth = node.end - tokenStart;
	                ts.Debug.assert(tokenWidth >= 0);
	                if (tokenWidth > 0) {
	                    var type = classifiedElementName || classifyTokenType(node.kind, node);
	                    if (type) {
	                        pushClassification(tokenStart, tokenWidth, type);
	                    }
	                }
	                return true;
	            }
	            function tryClassifyJsxElementName(token) {
	                switch (token.parent && token.parent.kind) {
	                    case 238 /* JsxOpeningElement */:
	                        if (token.parent.tagName === token) {
	                            return 19 /* jsxOpenTagName */;
	                        }
	                        break;
	                    case 240 /* JsxClosingElement */:
	                        if (token.parent.tagName === token) {
	                            return 20 /* jsxCloseTagName */;
	                        }
	                        break;
	                    case 237 /* JsxSelfClosingElement */:
	                        if (token.parent.tagName === token) {
	                            return 21 /* jsxSelfClosingTagName */;
	                        }
	                        break;
	                    case 241 /* JsxAttribute */:
	                        if (token.parent.name === token) {
	                            return 22 /* jsxAttribute */;
	                        }
	                        break;
	                }
	                return undefined;
	            }
	            // for accurate classification, the actual token should be passed in.  however, for
	            // cases like 'disabled merge code' classification, we just get the token kind and
	            // classify based on that instead.
	            function classifyTokenType(tokenKind, token) {
	                if (ts.isKeyword(tokenKind)) {
	                    return 3 /* keyword */;
	                }
	                // Special case < and >  If they appear in a generic context they are punctuation,
	                // not operators.
	                if (tokenKind === 25 /* LessThanToken */ || tokenKind === 27 /* GreaterThanToken */) {
	                    // If the node owning the token has a type argument list or type parameter list, then
	                    // we can effectively assume that a '<' and '>' belong to those lists.
	                    if (token && ts.getTypeArgumentOrTypeParameterList(token.parent)) {
	                        return 10 /* punctuation */;
	                    }
	                }
	                if (ts.isPunctuation(tokenKind)) {
	                    if (token) {
	                        if (tokenKind === 56 /* EqualsToken */) {
	                            // the '=' in a variable declaration is special cased here.
	                            if (token.parent.kind === 214 /* VariableDeclaration */ ||
	                                token.parent.kind === 142 /* PropertyDeclaration */ ||
	                                token.parent.kind === 139 /* Parameter */ ||
	                                token.parent.kind === 241 /* JsxAttribute */) {
	                                return 5 /* operator */;
	                            }
	                        }
	                        if (token.parent.kind === 184 /* BinaryExpression */ ||
	                            token.parent.kind === 182 /* PrefixUnaryExpression */ ||
	                            token.parent.kind === 183 /* PostfixUnaryExpression */ ||
	                            token.parent.kind === 185 /* ConditionalExpression */) {
	                            return 5 /* operator */;
	                        }
	                    }
	                    return 10 /* punctuation */;
	                }
	                else if (tokenKind === 8 /* NumericLiteral */) {
	                    return 4 /* numericLiteral */;
	                }
	                else if (tokenKind === 9 /* StringLiteral */ || tokenKind === 163 /* StringLiteralType */) {
	                    return token.parent.kind === 241 /* JsxAttribute */ ? 24 /* jsxAttributeStringLiteralValue */ : 6 /* stringLiteral */;
	                }
	                else if (tokenKind === 10 /* RegularExpressionLiteral */) {
	                    // TODO: we should get another classification type for these literals.
	                    return 6 /* stringLiteral */;
	                }
	                else if (ts.isTemplateLiteralKind(tokenKind)) {
	                    // TODO (drosen): we should *also* get another classification type for these literals.
	                    return 6 /* stringLiteral */;
	                }
	                else if (tokenKind === 239 /* JsxText */) {
	                    return 23 /* jsxText */;
	                }
	                else if (tokenKind === 69 /* Identifier */) {
	                    if (token) {
	                        switch (token.parent.kind) {
	                            case 217 /* ClassDeclaration */:
	                                if (token.parent.name === token) {
	                                    return 11 /* className */;
	                                }
	                                return;
	                            case 138 /* TypeParameter */:
	                                if (token.parent.name === token) {
	                                    return 15 /* typeParameterName */;
	                                }
	                                return;
	                            case 218 /* InterfaceDeclaration */:
	                                if (token.parent.name === token) {
	                                    return 13 /* interfaceName */;
	                                }
	                                return;
	                            case 220 /* EnumDeclaration */:
	                                if (token.parent.name === token) {
	                                    return 12 /* enumName */;
	                                }
	                                return;
	                            case 221 /* ModuleDeclaration */:
	                                if (token.parent.name === token) {
	                                    return 14 /* moduleName */;
	                                }
	                                return;
	                            case 139 /* Parameter */:
	                                if (token.parent.name === token) {
	                                    return 17 /* parameterName */;
	                                }
	                                return;
	                        }
	                    }
	                    return 2 /* identifier */;
	                }
	            }
	            function processElement(element) {
	                if (!element) {
	                    return;
	                }
	                // Ignore nodes that don't intersect the original span to classify.
	                if (ts.decodedTextSpanIntersectsWith(spanStart, spanLength, element.pos, element.getFullWidth())) {
	                    checkForClassificationCancellation(element.kind);
	                    var children = element.getChildren(sourceFile);
	                    for (var i = 0, n = children.length; i < n; i++) {
	                        var child = children[i];
	                        if (!tryClassifyNode(child)) {
	                            // Recurse into our child nodes.
	                            processElement(child);
	                        }
	                    }
	                }
	            }
	        }
	        function getOutliningSpans(fileName) {
	            // doesn't use compiler - no need to synchronize with host
	            var sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
	            return ts.OutliningElementsCollector.collectElements(sourceFile);
	        }
	        function getBraceMatchingAtPosition(fileName, position) {
	            var sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
	            var result = [];
	            var token = ts.getTouchingToken(sourceFile, position);
	            if (token.getStart(sourceFile) === position) {
	                var matchKind = getMatchingTokenKind(token);
	                // Ensure that there is a corresponding token to match ours.
	                if (matchKind) {
	                    var parentElement = token.parent;
	                    var childNodes = parentElement.getChildren(sourceFile);
	                    for (var _i = 0, childNodes_1 = childNodes; _i < childNodes_1.length; _i++) {
	                        var current = childNodes_1[_i];
	                        if (current.kind === matchKind) {
	                            var range1 = ts.createTextSpan(token.getStart(sourceFile), token.getWidth(sourceFile));
	                            var range2 = ts.createTextSpan(current.getStart(sourceFile), current.getWidth(sourceFile));
	                            // We want to order the braces when we return the result.
	                            if (range1.start < range2.start) {
	                                result.push(range1, range2);
	                            }
	                            else {
	                                result.push(range2, range1);
	                            }
	                            break;
	                        }
	                    }
	                }
	            }
	            return result;
	            function getMatchingTokenKind(token) {
	                switch (token.kind) {
	                    case 15 /* OpenBraceToken */: return 16 /* CloseBraceToken */;
	                    case 17 /* OpenParenToken */: return 18 /* CloseParenToken */;
	                    case 19 /* OpenBracketToken */: return 20 /* CloseBracketToken */;
	                    case 25 /* LessThanToken */: return 27 /* GreaterThanToken */;
	                    case 16 /* CloseBraceToken */: return 15 /* OpenBraceToken */;
	                    case 18 /* CloseParenToken */: return 17 /* OpenParenToken */;
	                    case 20 /* CloseBracketToken */: return 19 /* OpenBracketToken */;
	                    case 27 /* GreaterThanToken */: return 25 /* LessThanToken */;
	                }
	                return undefined;
	            }
	        }
	        function getIndentationAtPosition(fileName, position, editorOptions) {
	            var start = new Date().getTime();
	            var sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
	            log("getIndentationAtPosition: getCurrentSourceFile: " + (new Date().getTime() - start));
	            start = new Date().getTime();
	            var result = ts.formatting.SmartIndenter.getIndentation(position, sourceFile, editorOptions);
	            log("getIndentationAtPosition: computeIndentation  : " + (new Date().getTime() - start));
	            return result;
	        }
	        function getFormattingEditsForRange(fileName, start, end, options) {
	            var sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
	            return ts.formatting.formatSelection(start, end, sourceFile, getRuleProvider(options), options);
	        }
	        function getFormattingEditsForDocument(fileName, options) {
	            var sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
	            return ts.formatting.formatDocument(sourceFile, getRuleProvider(options), options);
	        }
	        function getFormattingEditsAfterKeystroke(fileName, position, key, options) {
	            var sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
	            if (key === "}") {
	                return ts.formatting.formatOnClosingCurly(position, sourceFile, getRuleProvider(options), options);
	            }
	            else if (key === ";") {
	                return ts.formatting.formatOnSemicolon(position, sourceFile, getRuleProvider(options), options);
	            }
	            else if (key === "\n") {
	                return ts.formatting.formatOnEnter(position, sourceFile, getRuleProvider(options), options);
	            }
	            return [];
	        }
	        /**
	         * Checks if position points to a valid position to add JSDoc comments, and if so,
	         * returns the appropriate template. Otherwise returns an empty string.
	         * Valid positions are
	         *      - outside of comments, statements, and expressions, and
	         *      - preceding a:
	         *          - function/constructor/method declaration
	         *          - class declarations
	         *          - variable statements
	         *          - namespace declarations
	         *
	         * Hosts should ideally check that:
	         * - The line is all whitespace up to 'position' before performing the insertion.
	         * - If the keystroke sequence "/\*\*" induced the call, we also check that the next
	         * non-whitespace character is '*', which (approximately) indicates whether we added
	         * the second '*' to complete an existing (JSDoc) comment.
	         * @param fileName The file in which to perform the check.
	         * @param position The (character-indexed) position in the file where the check should
	         * be performed.
	         */
	        function getDocCommentTemplateAtPosition(fileName, position) {
	            var sourceFile = syntaxTreeCache.getCurrentSourceFile(fileName);
	            // Check if in a context where we don't want to perform any insertion
	            if (ts.isInString(sourceFile, position) || ts.isInComment(sourceFile, position) || ts.hasDocComment(sourceFile, position)) {
	                return undefined;
	            }
	            var tokenAtPos = ts.getTokenAtPosition(sourceFile, position);
	            var tokenStart = tokenAtPos.getStart();
	            if (!tokenAtPos || tokenStart < position) {
	                return undefined;
	            }
	            // TODO: add support for:
	            // - enums/enum members
	            // - interfaces
	            // - property declarations
	            // - potentially property assignments
	            var commentOwner;
	            findOwner: for (commentOwner = tokenAtPos; commentOwner; commentOwner = commentOwner.parent) {
	                switch (commentOwner.kind) {
	                    case 216 /* FunctionDeclaration */:
	                    case 144 /* MethodDeclaration */:
	                    case 145 /* Constructor */:
	                    case 217 /* ClassDeclaration */:
	                    case 196 /* VariableStatement */:
	                        break findOwner;
	                    case 251 /* SourceFile */:
	                        return undefined;
	                    case 221 /* ModuleDeclaration */:
	                        // If in walking up the tree, we hit a a nested namespace declaration,
	                        // then we must be somewhere within a dotted namespace name; however we don't
	                        // want to give back a JSDoc template for the 'b' or 'c' in 'namespace a.b.c { }'.
	                        if (commentOwner.parent.kind === 221 /* ModuleDeclaration */) {
	                            return undefined;
	                        }
	                        break findOwner;
	                }
	            }
	            if (!commentOwner || commentOwner.getStart() < position) {
	                return undefined;
	            }
	            var parameters = getParametersForJsDocOwningNode(commentOwner);
	            var posLineAndChar = sourceFile.getLineAndCharacterOfPosition(position);
	            var lineStart = sourceFile.getLineStarts()[posLineAndChar.line];
	            var indentationStr = sourceFile.text.substr(lineStart, posLineAndChar.character);
	            var newLine = ts.getNewLineOrDefaultFromHost(host);
	            var docParams = "";
	            for (var i = 0, numParams = parameters.length; i < numParams; i++) {
	                var currentName = parameters[i].name;
	                var paramName = currentName.kind === 69 /* Identifier */ ?
	                    currentName.text :
	                    "param" + i;
	                docParams += indentationStr + " * @param " + paramName + newLine;
	            }
	            // A doc comment consists of the following
	            // * The opening comment line
	            // * the first line (without a param) for the object's untagged info (this is also where the caret ends up)
	            // * the '@param'-tagged lines
	            // * TODO: other tags.
	            // * the closing comment line
	            // * if the caret was directly in front of the object, then we add an extra line and indentation.
	            var preamble = "/**" + newLine +
	                indentationStr + " * ";
	            var result = preamble + newLine +
	                docParams +
	                indentationStr + " */" +
	                (tokenStart === position ? newLine + indentationStr : "");
	            return { newText: result, caretOffset: preamble.length };
	        }
	        function getParametersForJsDocOwningNode(commentOwner) {
	            if (ts.isFunctionLike(commentOwner)) {
	                return commentOwner.parameters;
	            }
	            if (commentOwner.kind === 196 /* VariableStatement */) {
	                var varStatement = commentOwner;
	                var varDeclarations = varStatement.declarationList.declarations;
	                if (varDeclarations.length === 1 && varDeclarations[0].initializer) {
	                    return getParametersFromRightHandSideOfAssignment(varDeclarations[0].initializer);
	                }
	            }
	            return emptyArray;
	        }
	        /**
	         * Digs into an an initializer or RHS operand of an assignment operation
	         * to get the parameters of an apt signature corresponding to a
	         * function expression or a class expression.
	         *
	         * @param rightHandSide the expression which may contain an appropriate set of parameters
	         * @returns the parameters of a signature found on the RHS if one exists; otherwise 'emptyArray'.
	         */
	        function getParametersFromRightHandSideOfAssignment(rightHandSide) {
	            while (rightHandSide.kind === 175 /* ParenthesizedExpression */) {
	                rightHandSide = rightHandSide.expression;
	            }
	            switch (rightHandSide.kind) {
	                case 176 /* FunctionExpression */:
	                case 177 /* ArrowFunction */:
	                    return rightHandSide.parameters;
	                case 189 /* ClassExpression */:
	                    for (var _i = 0, _a = rightHandSide.members; _i < _a.length; _i++) {
	                        var member = _a[_i];
	                        if (member.kind === 145 /* Constructor */) {
	                            return member.parameters;
	                        }
	                    }
	                    break;
	            }
	            return emptyArray;
	        }
	        function getTodoComments(fileName, descriptors) {
	            // Note: while getting todo comments seems like a syntactic operation, we actually
	            // treat it as a semantic operation here.  This is because we expect our host to call
	            // this on every single file.  If we treat this syntactically, then that will cause
	            // us to populate and throw away the tree in our syntax tree cache for each file.  By
	            // treating this as a semantic operation, we can access any tree without throwing
	            // anything away.
	            synchronizeHostData();
	            var sourceFile = getValidSourceFile(fileName);
	            cancellationToken.throwIfCancellationRequested();
	            var fileContents = sourceFile.text;
	            var result = [];
	            if (descriptors.length > 0) {
	                var regExp = getTodoCommentsRegExp();
	                var matchArray = void 0;
	                while (matchArray = regExp.exec(fileContents)) {
	                    cancellationToken.throwIfCancellationRequested();
	                    // If we got a match, here is what the match array will look like.  Say the source text is:
	                    //
	                    //      "    // hack   1"
	                    //
	                    // The result array with the regexp:    will be:
	                    //
	                    //      ["// hack   1", "// ", "hack   1", undefined, "hack"]
	                    //
	                    // Here are the relevant capture groups:
	                    //  0) The full match for the entire regexp.
	                    //  1) The preamble to the message portion.
	                    //  2) The message portion.
	                    //  3...N) The descriptor that was matched - by index.  'undefined' for each
	                    //         descriptor that didn't match.  an actual value if it did match.
	                    //
	                    //  i.e. 'undefined' in position 3 above means TODO(jason) didn't match.
	                    //       "hack"      in position 4 means HACK did match.
	                    var firstDescriptorCaptureIndex = 3;
	                    ts.Debug.assert(matchArray.length === descriptors.length + firstDescriptorCaptureIndex);
	                    var preamble = matchArray[1];
	                    var matchPosition = matchArray.index + preamble.length;
	                    // OK, we have found a match in the file.  This is only an acceptable match if
	                    // it is contained within a comment.
	                    var token = ts.getTokenAtPosition(sourceFile, matchPosition);
	                    if (!isInsideComment(sourceFile, token, matchPosition)) {
	                        continue;
	                    }
	                    var descriptor = undefined;
	                    for (var i = 0, n = descriptors.length; i < n; i++) {
	                        if (matchArray[i + firstDescriptorCaptureIndex]) {
	                            descriptor = descriptors[i];
	                        }
	                    }
	                    ts.Debug.assert(descriptor !== undefined);
	                    // We don't want to match something like 'TODOBY', so we make sure a non
	                    // letter/digit follows the match.
	                    if (isLetterOrDigit(fileContents.charCodeAt(matchPosition + descriptor.text.length))) {
	                        continue;
	                    }
	                    var message = matchArray[2];
	                    result.push({
	                        descriptor: descriptor,
	                        message: message,
	                        position: matchPosition
	                    });
	                }
	            }
	            return result;
	            function escapeRegExp(str) {
	                return str.replace(/[\-\[\]\/\{\}\(\)\*\+\?\.\\\^\$\|]/g, "\\$&");
	            }
	            function getTodoCommentsRegExp() {
	                // NOTE: ?:  means 'non-capture group'.  It allows us to have groups without having to
	                // filter them out later in the final result array.
	                // TODO comments can appear in one of the following forms:
	                //
	                //  1)      // TODO     or  /////////// TODO
	                //
	                //  2)      /* TODO     or  /********** TODO
	                //
	                //  3)      /*
	                //           *   TODO
	                //           */
	                //
	                // The following three regexps are used to match the start of the text up to the TODO
	                // comment portion.
	                var singleLineCommentStart = /(?:\/\/+\s*)/.source;
	                var multiLineCommentStart = /(?:\/\*+\s*)/.source;
	                var anyNumberOfSpacesAndAsterixesAtStartOfLine = /(?:^(?:\s|\*)*)/.source;
	                // Match any of the above three TODO comment start regexps.
	                // Note that the outermost group *is* a capture group.  We want to capture the preamble
	                // so that we can determine the starting position of the TODO comment match.
	                var preamble = "(" + anyNumberOfSpacesAndAsterixesAtStartOfLine + "|" + singleLineCommentStart + "|" + multiLineCommentStart + ")";
	                // Takes the descriptors and forms a regexp that matches them as if they were literals.
	                // For example, if the descriptors are "TODO(jason)" and "HACK", then this will be:
	                //
	                //      (?:(TODO\(jason\))|(HACK))
	                //
	                // Note that the outermost group is *not* a capture group, but the innermost groups
	                // *are* capture groups.  By capturing the inner literals we can determine after
	                // matching which descriptor we are dealing with.
	                var literals = "(?:" + ts.map(descriptors, function (d) { return "(" + escapeRegExp(d.text) + ")"; }).join("|") + ")";
	                // After matching a descriptor literal, the following regexp matches the rest of the
	                // text up to the end of the line (or */).
	                var endOfLineOrEndOfComment = /(?:$|\*\/)/.source;
	                var messageRemainder = /(?:.*?)/.source;
	                // This is the portion of the match we'll return as part of the TODO comment result. We
	                // match the literal portion up to the end of the line or end of comment.
	                var messagePortion = "(" + literals + messageRemainder + ")";
	                var regExpString = preamble + messagePortion + endOfLineOrEndOfComment;
	                // The final regexp will look like this:
	                // /((?:\/\/+\s*)|(?:\/\*+\s*)|(?:^(?:\s|\*)*))((?:(TODO\(jason\))|(HACK))(?:.*?))(?:$|\*\/)/gim
	                // The flags of the regexp are important here.
	                //  'g' is so that we are doing a global search and can find matches several times
	                //  in the input.
	                //
	                //  'i' is for case insensitivity (We do this to match C# TODO comment code).
	                //
	                //  'm' is so we can find matches in a multi-line input.
	                return new RegExp(regExpString, "gim");
	            }
	            function isLetterOrDigit(char) {
	                return (char >= 97 /* a */ && char <= 122 /* z */) ||
	                    (char >= 65 /* A */ && char <= 90 /* Z */) ||
	                    (char >= 48 /* _0 */ && char <= 57 /* _9 */);
	            }
	        }
	        function getRenameInfo(fileName, position) {
	            synchronizeHostData();
	            var sourceFile = getValidSourceFile(fileName);
	            var typeChecker = program.getTypeChecker();
	            var node = ts.getTouchingWord(sourceFile, position);
	            // Can only rename an identifier.
	            if (node && node.kind === 69 /* Identifier */) {
	                var symbol = typeChecker.getSymbolAtLocation(node);
	                // Only allow a symbol to be renamed if it actually has at least one declaration.
	                if (symbol) {
	                    var declarations = symbol.getDeclarations();
	                    if (declarations && declarations.length > 0) {
	                        // Disallow rename for elements that are defined in the standard TypeScript library.
	                        var defaultLibFileName = host.getDefaultLibFileName(host.getCompilationSettings());
	                        var canonicalDefaultLibName = getCanonicalFileName(ts.normalizePath(defaultLibFileName));
	                        if (defaultLibFileName) {
	                            for (var _i = 0, declarations_10 = declarations; _i < declarations_10.length; _i++) {
	                                var current = declarations_10[_i];
	                                var sourceFile_3 = current.getSourceFile();
	                                // TODO (drosen): When is there no source file?
	                                if (!sourceFile_3) {
	                                    continue;
	                                }
	                                var canonicalName = getCanonicalFileName(ts.normalizePath(sourceFile_3.fileName));
	                                if (canonicalName === canonicalDefaultLibName) {
	                                    return getRenameInfoError(ts.getLocaleSpecificMessage(ts.Diagnostics.You_cannot_rename_elements_that_are_defined_in_the_standard_TypeScript_library));
	                                }
	                            }
	                        }
	                        var displayName = ts.stripQuotes(ts.getDeclaredName(typeChecker, symbol, node));
	                        var kind = getSymbolKind(symbol, node);
	                        if (kind) {
	                            return {
	                                canRename: true,
	                                kind: kind,
	                                displayName: displayName,
	                                localizedErrorMessage: undefined,
	                                fullDisplayName: typeChecker.getFullyQualifiedName(symbol),
	                                kindModifiers: getSymbolModifiers(symbol),
	                                triggerSpan: ts.createTextSpan(node.getStart(), node.getWidth())
	                            };
	                        }
	                    }
	                }
	            }
	            return getRenameInfoError(ts.getLocaleSpecificMessage(ts.Diagnostics.You_cannot_rename_this_element));
	            function getRenameInfoError(localizedErrorMessage) {
	                return {
	                    canRename: false,
	                    localizedErrorMessage: localizedErrorMessage,
	                    displayName: undefined,
	                    fullDisplayName: undefined,
	                    kind: undefined,
	                    kindModifiers: undefined,
	                    triggerSpan: undefined
	                };
	            }
	        }
	        return {
	            dispose: dispose,
	            cleanupSemanticCache: cleanupSemanticCache,
	            getSyntacticDiagnostics: getSyntacticDiagnostics,
	            getSemanticDiagnostics: getSemanticDiagnostics,
	            getCompilerOptionsDiagnostics: getCompilerOptionsDiagnostics,
	            getSyntacticClassifications: getSyntacticClassifications,
	            getSemanticClassifications: getSemanticClassifications,
	            getEncodedSyntacticClassifications: getEncodedSyntacticClassifications,
	            getEncodedSemanticClassifications: getEncodedSemanticClassifications,
	            getCompletionsAtPosition: getCompletionsAtPosition,
	            getCompletionEntryDetails: getCompletionEntryDetails,
	            getSignatureHelpItems: getSignatureHelpItems,
	            getQuickInfoAtPosition: getQuickInfoAtPosition,
	            getDefinitionAtPosition: getDefinitionAtPosition,
	            getTypeDefinitionAtPosition: getTypeDefinitionAtPosition,
	            getReferencesAtPosition: getReferencesAtPosition,
	            findReferences: findReferences,
	            getOccurrencesAtPosition: getOccurrencesAtPosition,
	            getDocumentHighlights: getDocumentHighlights,
	            getNameOrDottedNameSpan: getNameOrDottedNameSpan,
	            getBreakpointStatementAtPosition: getBreakpointStatementAtPosition,
	            getNavigateToItems: getNavigateToItems,
	            getRenameInfo: getRenameInfo,
	            findRenameLocations: findRenameLocations,
	            getNavigationBarItems: getNavigationBarItems,
	            getOutliningSpans: getOutliningSpans,
	            getTodoComments: getTodoComments,
	            getBraceMatchingAtPosition: getBraceMatchingAtPosition,
	            getIndentationAtPosition: getIndentationAtPosition,
	            getFormattingEditsForRange: getFormattingEditsForRange,
	            getFormattingEditsForDocument: getFormattingEditsForDocument,
	            getFormattingEditsAfterKeystroke: getFormattingEditsAfterKeystroke,
	            getDocCommentTemplateAtPosition: getDocCommentTemplateAtPosition,
	            getEmitOutput: getEmitOutput,
	            getSourceFile: getSourceFile,
	            getProgram: getProgram
	        };
	    }
	    ts.createLanguageService = createLanguageService;
	    /* @internal */
	    function getNameTable(sourceFile) {
	        if (!sourceFile.nameTable) {
	            initializeNameTable(sourceFile);
	        }
	        return sourceFile.nameTable;
	    }
	    ts.getNameTable = getNameTable;
	    function initializeNameTable(sourceFile) {
	        var nameTable = {};
	        walk(sourceFile);
	        sourceFile.nameTable = nameTable;
	        function walk(node) {
	            switch (node.kind) {
	                case 69 /* Identifier */:
	                    nameTable[node.text] = nameTable[node.text] === undefined ? node.pos : -1;
	                    break;
	                case 9 /* StringLiteral */:
	                case 8 /* NumericLiteral */:
	                    // We want to store any numbers/strings if they were a name that could be
	                    // related to a declaration.  So, if we have 'import x = require("something")'
	                    // then we want 'something' to be in the name table.  Similarly, if we have
	                    // "a['propname']" then we want to store "propname" in the name table.
	                    if (ts.isDeclarationName(node) ||
	                        node.parent.kind === 235 /* ExternalModuleReference */ ||
	                        isArgumentOfElementAccessExpression(node)) {
	                        nameTable[node.text] = nameTable[node.text] === undefined ? node.pos : -1;
	                    }
	                    break;
	                default:
	                    ts.forEachChild(node, walk);
	            }
	        }
	    }
	    function isArgumentOfElementAccessExpression(node) {
	        return node &&
	            node.parent &&
	            node.parent.kind === 170 /* ElementAccessExpression */ &&
	            node.parent.argumentExpression === node;
	    }
	    /// Classifier
	    function createClassifier() {
	        var scanner = ts.createScanner(2 /* Latest */, /*skipTrivia*/ false);
	        /// We do not have a full parser support to know when we should parse a regex or not
	        /// If we consider every slash token to be a regex, we could be missing cases like "1/2/3", where
	        /// we have a series of divide operator. this list allows us to be more accurate by ruling out
	        /// locations where a regexp cannot exist.
	        var noRegexTable = [];
	        noRegexTable[69 /* Identifier */] = true;
	        noRegexTable[9 /* StringLiteral */] = true;
	        noRegexTable[8 /* NumericLiteral */] = true;
	        noRegexTable[10 /* RegularExpressionLiteral */] = true;
	        noRegexTable[97 /* ThisKeyword */] = true;
	        noRegexTable[41 /* PlusPlusToken */] = true;
	        noRegexTable[42 /* MinusMinusToken */] = true;
	        noRegexTable[18 /* CloseParenToken */] = true;
	        noRegexTable[20 /* CloseBracketToken */] = true;
	        noRegexTable[16 /* CloseBraceToken */] = true;
	        noRegexTable[99 /* TrueKeyword */] = true;
	        noRegexTable[84 /* FalseKeyword */] = true;
	        // Just a stack of TemplateHeads and OpenCurlyBraces, used to perform rudimentary (inexact)
	        // classification on template strings. Because of the context free nature of templates,
	        // the only precise way to classify a template portion would be by propagating the stack across
	        // lines, just as we do with the end-of-line state. However, this is a burden for implementers,
	        // and the behavior is entirely subsumed by the syntactic classifier anyway, so we instead
	        // flatten any nesting when the template stack is non-empty and encode it in the end-of-line state.
	        // Situations in which this fails are
	        //  1) When template strings are nested across different lines:
	        //          `hello ${ `world
	        //          ` }`
	        //
	        //     Where on the second line, you will get the closing of a template,
	        //     a closing curly, and a new template.
	        //
	        //  2) When substitution expressions have curly braces and the curly brace falls on the next line:
	        //          `hello ${ () => {
	        //          return "world" } } `
	        //
	        //     Where on the second line, you will get the 'return' keyword,
	        //     a string literal, and a template end consisting of '} } `'.
	        var templateStack = [];
	        /** Returns true if 'keyword2' can legally follow 'keyword1' in any language construct. */
	        function canFollow(keyword1, keyword2) {
	            if (ts.isAccessibilityModifier(keyword1)) {
	                if (keyword2 === 123 /* GetKeyword */ ||
	                    keyword2 === 129 /* SetKeyword */ ||
	                    keyword2 === 121 /* ConstructorKeyword */ ||
	                    keyword2 === 113 /* StaticKeyword */) {
	                    // Allow things like "public get", "public constructor" and "public static".
	                    // These are all legal.
	                    return true;
	                }
	                // Any other keyword following "public" is actually an identifier an not a real
	                // keyword.
	                return false;
	            }
	            // Assume any other keyword combination is legal.  This can be refined in the future
	            // if there are more cases we want the classifier to be better at.
	            return true;
	        }
	        function convertClassifications(classifications, text) {
	            var entries = [];
	            var dense = classifications.spans;
	            var lastEnd = 0;
	            for (var i = 0, n = dense.length; i < n; i += 3) {
	                var start = dense[i];
	                var length_3 = dense[i + 1];
	                var type = dense[i + 2];
	                // Make a whitespace entry between the last item and this one.
	                if (lastEnd >= 0) {
	                    var whitespaceLength_1 = start - lastEnd;
	                    if (whitespaceLength_1 > 0) {
	                        entries.push({ length: whitespaceLength_1, classification: TokenClass.Whitespace });
	                    }
	                }
	                entries.push({ length: length_3, classification: convertClassification(type) });
	                lastEnd = start + length_3;
	            }
	            var whitespaceLength = text.length - lastEnd;
	            if (whitespaceLength > 0) {
	                entries.push({ length: whitespaceLength, classification: TokenClass.Whitespace });
	            }
	            return { entries: entries, finalLexState: classifications.endOfLineState };
	        }
	        function convertClassification(type) {
	            switch (type) {
	                case 1 /* comment */: return TokenClass.Comment;
	                case 3 /* keyword */: return TokenClass.Keyword;
	                case 4 /* numericLiteral */: return TokenClass.NumberLiteral;
	                case 5 /* operator */: return TokenClass.Operator;
	                case 6 /* stringLiteral */: return TokenClass.StringLiteral;
	                case 8 /* whiteSpace */: return TokenClass.Whitespace;
	                case 10 /* punctuation */: return TokenClass.Punctuation;
	                case 2 /* identifier */:
	                case 11 /* className */:
	                case 12 /* enumName */:
	                case 13 /* interfaceName */:
	                case 14 /* moduleName */:
	                case 15 /* typeParameterName */:
	                case 16 /* typeAliasName */:
	                case 9 /* text */:
	                case 17 /* parameterName */:
	                default:
	                    return TokenClass.Identifier;
	            }
	        }
	        function getClassificationsForLine(text, lexState, syntacticClassifierAbsent) {
	            return convertClassifications(getEncodedLexicalClassifications(text, lexState, syntacticClassifierAbsent), text);
	        }
	        // If there is a syntactic classifier ('syntacticClassifierAbsent' is false),
	        // we will be more conservative in order to avoid conflicting with the syntactic classifier.
	        function getEncodedLexicalClassifications(text, lexState, syntacticClassifierAbsent) {
	            var offset = 0;
	            var token = 0 /* Unknown */;
	            var lastNonTriviaToken = 0 /* Unknown */;
	            // Empty out the template stack for reuse.
	            while (templateStack.length > 0) {
	                templateStack.pop();
	            }
	            // If we're in a string literal, then prepend: "\
	            // (and a newline).  That way when we lex we'll think we're still in a string literal.
	            //
	            // If we're in a multiline comment, then prepend: /*
	            // (and a newline).  That way when we lex we'll think we're still in a multiline comment.
	            switch (lexState) {
	                case 3 /* InDoubleQuoteStringLiteral */:
	                    text = "\"\\\n" + text;
	                    offset = 3;
	                    break;
	                case 2 /* InSingleQuoteStringLiteral */:
	                    text = "'\\\n" + text;
	                    offset = 3;
	                    break;
	                case 1 /* InMultiLineCommentTrivia */:
	                    text = "/*\n" + text;
	                    offset = 3;
	                    break;
	                case 4 /* InTemplateHeadOrNoSubstitutionTemplate */:
	                    text = "`\n" + text;
	                    offset = 2;
	                    break;
	                case 5 /* InTemplateMiddleOrTail */:
	                    text = "}\n" + text;
	                    offset = 2;
	                // fallthrough
	                case 6 /* InTemplateSubstitutionPosition */:
	                    templateStack.push(12 /* TemplateHead */);
	                    break;
	            }
	            scanner.setText(text);
	            var result = {
	                endOfLineState: 0 /* None */,
	                spans: []
	            };
	            // We can run into an unfortunate interaction between the lexical and syntactic classifier
	            // when the user is typing something generic.  Consider the case where the user types:
	            //
	            //      Foo<number
	            //
	            // From the lexical classifier's perspective, 'number' is a keyword, and so the word will
	            // be classified as such.  However, from the syntactic classifier's tree-based perspective
	            // this is simply an expression with the identifier 'number' on the RHS of the less than
	            // token.  So the classification will go back to being an identifier.  The moment the user
	            // types again, number will become a keyword, then an identifier, etc. etc.
	            //
	            // To try to avoid this problem, we avoid classifying contextual keywords as keywords
	            // when the user is potentially typing something generic.  We just can't do a good enough
	            // job at the lexical level, and so well leave it up to the syntactic classifier to make
	            // the determination.
	            //
	            // In order to determine if the user is potentially typing something generic, we use a
	            // weak heuristic where we track < and > tokens.  It's a weak heuristic, but should
	            // work well enough in practice.
	            var angleBracketStack = 0;
	            do {
	                token = scanner.scan();
	                if (!ts.isTrivia(token)) {
	                    if ((token === 39 /* SlashToken */ || token === 61 /* SlashEqualsToken */) && !noRegexTable[lastNonTriviaToken]) {
	                        if (scanner.reScanSlashToken() === 10 /* RegularExpressionLiteral */) {
	                            token = 10 /* RegularExpressionLiteral */;
	                        }
	                    }
	                    else if (lastNonTriviaToken === 21 /* DotToken */ && isKeyword(token)) {
	                        token = 69 /* Identifier */;
	                    }
	                    else if (isKeyword(lastNonTriviaToken) && isKeyword(token) && !canFollow(lastNonTriviaToken, token)) {
	                        // We have two keywords in a row.  Only treat the second as a keyword if
	                        // it's a sequence that could legally occur in the language.  Otherwise
	                        // treat it as an identifier.  This way, if someone writes "private var"
	                        // we recognize that 'var' is actually an identifier here.
	                        token = 69 /* Identifier */;
	                    }
	                    else if (lastNonTriviaToken === 69 /* Identifier */ &&
	                        token === 25 /* LessThanToken */) {
	                        // Could be the start of something generic.  Keep track of that by bumping
	                        // up the current count of generic contexts we may be in.
	                        angleBracketStack++;
	                    }
	                    else if (token === 27 /* GreaterThanToken */ && angleBracketStack > 0) {
	                        // If we think we're currently in something generic, then mark that that
	                        // generic entity is complete.
	                        angleBracketStack--;
	                    }
	                    else if (token === 117 /* AnyKeyword */ ||
	                        token === 130 /* StringKeyword */ ||
	                        token === 128 /* NumberKeyword */ ||
	                        token === 120 /* BooleanKeyword */ ||
	                        token === 131 /* SymbolKeyword */) {
	                        if (angleBracketStack > 0 && !syntacticClassifierAbsent) {
	                            // If it looks like we're could be in something generic, don't classify this
	                            // as a keyword.  We may just get overwritten by the syntactic classifier,
	                            // causing a noisy experience for the user.
	                            token = 69 /* Identifier */;
	                        }
	                    }
	                    else if (token === 12 /* TemplateHead */) {
	                        templateStack.push(token);
	                    }
	                    else if (token === 15 /* OpenBraceToken */) {
	                        // If we don't have anything on the template stack,
	                        // then we aren't trying to keep track of a previously scanned template head.
	                        if (templateStack.length > 0) {
	                            templateStack.push(token);
	                        }
	                    }
	                    else if (token === 16 /* CloseBraceToken */) {
	                        // If we don't have anything on the template stack,
	                        // then we aren't trying to keep track of a previously scanned template head.
	                        if (templateStack.length > 0) {
	                            var lastTemplateStackToken = ts.lastOrUndefined(templateStack);
	                            if (lastTemplateStackToken === 12 /* TemplateHead */) {
	                                token = scanner.reScanTemplateToken();
	                                // Only pop on a TemplateTail; a TemplateMiddle indicates there is more for us.
	                                if (token === 14 /* TemplateTail */) {
	                                    templateStack.pop();
	                                }
	                                else {
	                                    ts.Debug.assert(token === 13 /* TemplateMiddle */, "Should have been a template middle. Was " + token);
	                                }
	                            }
	                            else {
	                                ts.Debug.assert(lastTemplateStackToken === 15 /* OpenBraceToken */, "Should have been an open brace. Was: " + token);
	                                templateStack.pop();
	                            }
	                        }
	                    }
	                    lastNonTriviaToken = token;
	                }
	                processToken();
	            } while (token !== 1 /* EndOfFileToken */);
	            return result;
	            function processToken() {
	                var start = scanner.getTokenPos();
	                var end = scanner.getTextPos();
	                addResult(start, end, classFromKind(token));
	                if (end >= text.length) {
	                    if (token === 9 /* StringLiteral */ || token === 163 /* StringLiteralType */) {
	                        // Check to see if we finished up on a multiline string literal.
	                        var tokenText = scanner.getTokenText();
	                        if (scanner.isUnterminated()) {
	                            var lastCharIndex = tokenText.length - 1;
	                            var numBackslashes = 0;
	                            while (tokenText.charCodeAt(lastCharIndex - numBackslashes) === 92 /* backslash */) {
	                                numBackslashes++;
	                            }
	                            // If we have an odd number of backslashes, then the multiline string is unclosed
	                            if (numBackslashes & 1) {
	                                var quoteChar = tokenText.charCodeAt(0);
	                                result.endOfLineState = quoteChar === 34 /* doubleQuote */
	                                    ? 3 /* InDoubleQuoteStringLiteral */
	                                    : 2 /* InSingleQuoteStringLiteral */;
	                            }
	                        }
	                    }
	                    else if (token === 3 /* MultiLineCommentTrivia */) {
	                        // Check to see if the multiline comment was unclosed.
	                        if (scanner.isUnterminated()) {
	                            result.endOfLineState = 1 /* InMultiLineCommentTrivia */;
	                        }
	                    }
	                    else if (ts.isTemplateLiteralKind(token)) {
	                        if (scanner.isUnterminated()) {
	                            if (token === 14 /* TemplateTail */) {
	                                result.endOfLineState = 5 /* InTemplateMiddleOrTail */;
	                            }
	                            else if (token === 11 /* NoSubstitutionTemplateLiteral */) {
	                                result.endOfLineState = 4 /* InTemplateHeadOrNoSubstitutionTemplate */;
	                            }
	                            else {
	                                ts.Debug.fail("Only 'NoSubstitutionTemplateLiteral's and 'TemplateTail's can be unterminated; got SyntaxKind #" + token);
	                            }
	                        }
	                    }
	                    else if (templateStack.length > 0 && ts.lastOrUndefined(templateStack) === 12 /* TemplateHead */) {
	                        result.endOfLineState = 6 /* InTemplateSubstitutionPosition */;
	                    }
	                }
	            }
	            function addResult(start, end, classification) {
	                if (classification === 8 /* whiteSpace */) {
	                    // Don't bother with whitespace classifications.  They're not needed.
	                    return;
	                }
	                if (start === 0 && offset > 0) {
	                    // We're classifying the first token, and this was a case where we prepended
	                    // text.  We should consider the start of this token to be at the start of
	                    // the original text.
	                    start += offset;
	                }
	                // All our tokens are in relation to the augmented text.  Move them back to be
	                // relative to the original text.
	                start -= offset;
	                end -= offset;
	                var length = end - start;
	                if (length > 0) {
	                    result.spans.push(start);
	                    result.spans.push(length);
	                    result.spans.push(classification);
	                }
	            }
	        }
	        function isBinaryExpressionOperatorToken(token) {
	            switch (token) {
	                case 37 /* AsteriskToken */:
	                case 39 /* SlashToken */:
	                case 40 /* PercentToken */:
	                case 35 /* PlusToken */:
	                case 36 /* MinusToken */:
	                case 43 /* LessThanLessThanToken */:
	                case 44 /* GreaterThanGreaterThanToken */:
	                case 45 /* GreaterThanGreaterThanGreaterThanToken */:
	                case 25 /* LessThanToken */:
	                case 27 /* GreaterThanToken */:
	                case 28 /* LessThanEqualsToken */:
	                case 29 /* GreaterThanEqualsToken */:
	                case 91 /* InstanceOfKeyword */:
	                case 90 /* InKeyword */:
	                case 116 /* AsKeyword */:
	                case 30 /* EqualsEqualsToken */:
	                case 31 /* ExclamationEqualsToken */:
	                case 32 /* EqualsEqualsEqualsToken */:
	                case 33 /* ExclamationEqualsEqualsToken */:
	                case 46 /* AmpersandToken */:
	                case 48 /* CaretToken */:
	                case 47 /* BarToken */:
	                case 51 /* AmpersandAmpersandToken */:
	                case 52 /* BarBarToken */:
	                case 67 /* BarEqualsToken */:
	                case 66 /* AmpersandEqualsToken */:
	                case 68 /* CaretEqualsToken */:
	                case 63 /* LessThanLessThanEqualsToken */:
	                case 64 /* GreaterThanGreaterThanEqualsToken */:
	                case 65 /* GreaterThanGreaterThanGreaterThanEqualsToken */:
	                case 57 /* PlusEqualsToken */:
	                case 58 /* MinusEqualsToken */:
	                case 59 /* AsteriskEqualsToken */:
	                case 61 /* SlashEqualsToken */:
	                case 62 /* PercentEqualsToken */:
	                case 56 /* EqualsToken */:
	                case 24 /* CommaToken */:
	                    return true;
	                default:
	                    return false;
	            }
	        }
	        function isPrefixUnaryExpressionOperatorToken(token) {
	            switch (token) {
	                case 35 /* PlusToken */:
	                case 36 /* MinusToken */:
	                case 50 /* TildeToken */:
	                case 49 /* ExclamationToken */:
	                case 41 /* PlusPlusToken */:
	                case 42 /* MinusMinusToken */:
	                    return true;
	                default:
	                    return false;
	            }
	        }
	        function isKeyword(token) {
	            return token >= 70 /* FirstKeyword */ && token <= 135 /* LastKeyword */;
	        }
	        function classFromKind(token) {
	            if (isKeyword(token)) {
	                return 3 /* keyword */;
	            }
	            else if (isBinaryExpressionOperatorToken(token) || isPrefixUnaryExpressionOperatorToken(token)) {
	                return 5 /* operator */;
	            }
	            else if (token >= 15 /* FirstPunctuation */ && token <= 68 /* LastPunctuation */) {
	                return 10 /* punctuation */;
	            }
	            switch (token) {
	                case 8 /* NumericLiteral */:
	                    return 4 /* numericLiteral */;
	                case 9 /* StringLiteral */:
	                case 163 /* StringLiteralType */:
	                    return 6 /* stringLiteral */;
	                case 10 /* RegularExpressionLiteral */:
	                    return 7 /* regularExpressionLiteral */;
	                case 7 /* ConflictMarkerTrivia */:
	                case 3 /* MultiLineCommentTrivia */:
	                case 2 /* SingleLineCommentTrivia */:
	                    return 1 /* comment */;
	                case 5 /* WhitespaceTrivia */:
	                case 4 /* NewLineTrivia */:
	                    return 8 /* whiteSpace */;
	                case 69 /* Identifier */:
	                default:
	                    if (ts.isTemplateLiteralKind(token)) {
	                        return 6 /* stringLiteral */;
	                    }
	                    return 2 /* identifier */;
	            }
	        }
	        return {
	            getClassificationsForLine: getClassificationsForLine,
	            getEncodedLexicalClassifications: getEncodedLexicalClassifications
	        };
	    }
	    ts.createClassifier = createClassifier;
	    /**
	      * Get the path of the default library files (lib.d.ts) as distributed with the typescript
	      * node package.
	      * The functionality is not supported if the ts module is consumed outside of a node module.
	      */
	    function getDefaultLibFilePath(options) {
	        // Check __dirname is defined and that we are on a node.js system.
	        if (true) {
	            return __dirname + ts.directorySeparator + ts.getDefaultLibFileName(options);
	        }
	        throw new Error("getDefaultLibFilePath is only supported when consumed as a node module. ");
	    }
	    ts.getDefaultLibFilePath = getDefaultLibFilePath;
	    function initializeServices() {
	        ts.objectAllocator = {
	            getNodeConstructor: function () { return NodeObject; },
	            getSourceFileConstructor: function () { return SourceFileObject; },
	            getSymbolConstructor: function () { return SymbolObject; },
	            getTypeConstructor: function () { return TypeObject; },
	            getSignatureConstructor: function () { return SignatureObject; }
	        };
	    }
	    initializeServices();
	})(ts || (ts = {}));
	// Copyright (c) Microsoft. All rights reserved. Licensed under the Apache License, Version 2.0. 
	// See LICENSE.txt in the project root for complete license information.
	/// <reference path='services.ts' />
	/* @internal */
	var ts;
	(function (ts) {
	    var BreakpointResolver;
	    (function (BreakpointResolver) {
	        /**
	         * Get the breakpoint span in given sourceFile
	         */
	        function spanInSourceFileAtLocation(sourceFile, position) {
	            // Cannot set breakpoint in dts file
	            if (sourceFile.flags & 4096 /* DeclarationFile */) {
	                return undefined;
	            }
	            var tokenAtLocation = ts.getTokenAtPosition(sourceFile, position);
	            var lineOfPosition = sourceFile.getLineAndCharacterOfPosition(position).line;
	            if (sourceFile.getLineAndCharacterOfPosition(tokenAtLocation.getStart(sourceFile)).line > lineOfPosition) {
	                // Get previous token if the token is returned starts on new line
	                // eg: let x =10; |--- cursor is here
	                //     let y = 10; 
	                // token at position will return let keyword on second line as the token but we would like to use 
	                // token on same line if trailing trivia (comments or white spaces on same line) part of the last token on that line
	                tokenAtLocation = ts.findPrecedingToken(tokenAtLocation.pos, sourceFile);
	                // Its a blank line
	                if (!tokenAtLocation || sourceFile.getLineAndCharacterOfPosition(tokenAtLocation.getEnd()).line !== lineOfPosition) {
	                    return undefined;
	                }
	            }
	            // Cannot set breakpoint in ambient declarations
	            if (ts.isInAmbientContext(tokenAtLocation)) {
	                return undefined;
	            }
	            // Get the span in the node based on its syntax
	            return spanInNode(tokenAtLocation);
	            function textSpan(startNode, endNode) {
	                var start = startNode.decorators ?
	                    ts.skipTrivia(sourceFile.text, startNode.decorators.end) :
	                    startNode.getStart(sourceFile);
	                return ts.createTextSpanFromBounds(start, (endNode || startNode).getEnd());
	            }
	            function textSpanEndingAtNextToken(startNode, previousTokenToFindNextEndToken) {
	                return textSpan(startNode, ts.findNextToken(previousTokenToFindNextEndToken, previousTokenToFindNextEndToken.parent));
	            }
	            function spanInNodeIfStartsOnSameLine(node, otherwiseOnNode) {
	                if (node && lineOfPosition === sourceFile.getLineAndCharacterOfPosition(node.getStart(sourceFile)).line) {
	                    return spanInNode(node);
	                }
	                return spanInNode(otherwiseOnNode);
	            }
	            function spanInNodeArray(nodeArray) {
	                return ts.createTextSpanFromBounds(ts.skipTrivia(sourceFile.text, nodeArray.pos), nodeArray.end);
	            }
	            function spanInPreviousNode(node) {
	                return spanInNode(ts.findPrecedingToken(node.pos, sourceFile));
	            }
	            function spanInNextNode(node) {
	                return spanInNode(ts.findNextToken(node, node.parent));
	            }
	            function spanInNode(node) {
	                if (node) {
	                    switch (node.kind) {
	                        case 196 /* VariableStatement */:
	                            // Span on first variable declaration
	                            return spanInVariableDeclaration(node.declarationList.declarations[0]);
	                        case 214 /* VariableDeclaration */:
	                        case 142 /* PropertyDeclaration */:
	                        case 141 /* PropertySignature */:
	                            return spanInVariableDeclaration(node);
	                        case 139 /* Parameter */:
	                            return spanInParameterDeclaration(node);
	                        case 216 /* FunctionDeclaration */:
	                        case 144 /* MethodDeclaration */:
	                        case 143 /* MethodSignature */:
	                        case 146 /* GetAccessor */:
	                        case 147 /* SetAccessor */:
	                        case 145 /* Constructor */:
	                        case 176 /* FunctionExpression */:
	                        case 177 /* ArrowFunction */:
	                            return spanInFunctionDeclaration(node);
	                        case 195 /* Block */:
	                            if (ts.isFunctionBlock(node)) {
	                                return spanInFunctionBlock(node);
	                            }
	                        // Fall through
	                        case 222 /* ModuleBlock */:
	                            return spanInBlock(node);
	                        case 247 /* CatchClause */:
	                            return spanInBlock(node.block);
	                        case 198 /* ExpressionStatement */:
	                            // span on the expression
	                            return textSpan(node.expression);
	                        case 207 /* ReturnStatement */:
	                            // span on return keyword and expression if present
	                            return textSpan(node.getChildAt(0), node.expression);
	                        case 201 /* WhileStatement */:
	                            // Span on while(...)
	                            return textSpanEndingAtNextToken(node, node.expression);
	                        case 200 /* DoStatement */:
	                            // span in statement of the do statement
	                            return spanInNode(node.statement);
	                        case 213 /* DebuggerStatement */:
	                            // span on debugger keyword
	                            return textSpan(node.getChildAt(0));
	                        case 199 /* IfStatement */:
	                            // set on if(..) span
	                            return textSpanEndingAtNextToken(node, node.expression);
	                        case 210 /* LabeledStatement */:
	                            // span in statement
	                            return spanInNode(node.statement);
	                        case 206 /* BreakStatement */:
	                        case 205 /* ContinueStatement */:
	                            // On break or continue keyword and label if present
	                            return textSpan(node.getChildAt(0), node.label);
	                        case 202 /* ForStatement */:
	                            return spanInForStatement(node);
	                        case 203 /* ForInStatement */:
	                            // span of for (a in ...)
	                            return textSpanEndingAtNextToken(node, node.expression);
	                        case 204 /* ForOfStatement */:
	                            // span in initializer
	                            return spanInInitializerOfForLike(node);
	                        case 209 /* SwitchStatement */:
	                            // span on switch(...)
	                            return textSpanEndingAtNextToken(node, node.expression);
	                        case 244 /* CaseClause */:
	                        case 245 /* DefaultClause */:
	                            // span in first statement of the clause
	                            return spanInNode(node.statements[0]);
	                        case 212 /* TryStatement */:
	                            // span in try block
	                            return spanInBlock(node.tryBlock);
	                        case 211 /* ThrowStatement */:
	                            // span in throw ...
	                            return textSpan(node, node.expression);
	                        case 230 /* ExportAssignment */:
	                            // span on export = id
	                            return textSpan(node, node.expression);
	                        case 224 /* ImportEqualsDeclaration */:
	                            // import statement without including semicolon
	                            return textSpan(node, node.moduleReference);
	                        case 225 /* ImportDeclaration */:
	                            // import statement without including semicolon
	                            return textSpan(node, node.moduleSpecifier);
	                        case 231 /* ExportDeclaration */:
	                            // import statement without including semicolon
	                            return textSpan(node, node.moduleSpecifier);
	                        case 221 /* ModuleDeclaration */:
	                            // span on complete module if it is instantiated
	                            if (ts.getModuleInstanceState(node) !== 1 /* Instantiated */) {
	                                return undefined;
	                            }
	                        case 217 /* ClassDeclaration */:
	                        case 220 /* EnumDeclaration */:
	                        case 250 /* EnumMember */:
	                        case 166 /* BindingElement */:
	                            // span on complete node
	                            return textSpan(node);
	                        case 208 /* WithStatement */:
	                            // span in statement
	                            return spanInNode(node.statement);
	                        case 140 /* Decorator */:
	                            return spanInNodeArray(node.parent.decorators);
	                        case 164 /* ObjectBindingPattern */:
	                        case 165 /* ArrayBindingPattern */:
	                            return spanInBindingPattern(node);
	                        // No breakpoint in interface, type alias
	                        case 218 /* InterfaceDeclaration */:
	                        case 219 /* TypeAliasDeclaration */:
	                            return undefined;
	                        // Tokens:
	                        case 23 /* SemicolonToken */:
	                        case 1 /* EndOfFileToken */:
	                            return spanInNodeIfStartsOnSameLine(ts.findPrecedingToken(node.pos, sourceFile));
	                        case 24 /* CommaToken */:
	                            return spanInPreviousNode(node);
	                        case 15 /* OpenBraceToken */:
	                            return spanInOpenBraceToken(node);
	                        case 16 /* CloseBraceToken */:
	                            return spanInCloseBraceToken(node);
	                        case 20 /* CloseBracketToken */:
	                            return spanInCloseBracketToken(node);
	                        case 17 /* OpenParenToken */:
	                            return spanInOpenParenToken(node);
	                        case 18 /* CloseParenToken */:
	                            return spanInCloseParenToken(node);
	                        case 54 /* ColonToken */:
	                            return spanInColonToken(node);
	                        case 27 /* GreaterThanToken */:
	                        case 25 /* LessThanToken */:
	                            return spanInGreaterThanOrLessThanToken(node);
	                        // Keywords:
	                        case 104 /* WhileKeyword */:
	                            return spanInWhileKeyword(node);
	                        case 80 /* ElseKeyword */:
	                        case 72 /* CatchKeyword */:
	                        case 85 /* FinallyKeyword */:
	                            return spanInNextNode(node);
	                        case 135 /* OfKeyword */:
	                            return spanInOfKeyword(node);
	                        default:
	                            // Destructuring pattern in destructuring assignment
	                            // [a, b, c] of
	                            // [a, b, c] = expression
	                            if (ts.isArrayLiteralOrObjectLiteralDestructuringPattern(node)) {
	                                return spanInArrayLiteralOrObjectLiteralDestructuringPattern(node);
	                            }
	                            // Set breakpoint on identifier element of destructuring pattern
	                            // a or ...c  or d: x from 
	                            // [a, b, ...c] or { a, b } or { d: x } from destructuring pattern
	                            if ((node.kind === 69 /* Identifier */ ||
	                                node.kind == 188 /* SpreadElementExpression */ ||
	                                node.kind === 248 /* PropertyAssignment */ ||
	                                node.kind === 249 /* ShorthandPropertyAssignment */) &&
	                                ts.isArrayLiteralOrObjectLiteralDestructuringPattern(node.parent)) {
	                                return textSpan(node);
	                            }
	                            if (node.kind === 184 /* BinaryExpression */) {
	                                var binaryExpression = node;
	                                // Set breakpoint in destructuring pattern if its destructuring assignment
	                                // [a, b, c] or {a, b, c} of
	                                // [a, b, c] = expression or 
	                                // {a, b, c} = expression
	                                if (ts.isArrayLiteralOrObjectLiteralDestructuringPattern(binaryExpression.left)) {
	                                    return spanInArrayLiteralOrObjectLiteralDestructuringPattern(binaryExpression.left);
	                                }
	                                if (binaryExpression.operatorToken.kind === 56 /* EqualsToken */ &&
	                                    ts.isArrayLiteralOrObjectLiteralDestructuringPattern(binaryExpression.parent)) {
	                                    // Set breakpoint on assignment expression element of destructuring pattern
	                                    // a = expression of 
	                                    // [a = expression, b, c] = someExpression or 
	                                    // { a = expression, b, c } = someExpression
	                                    return textSpan(node);
	                                }
	                                if (binaryExpression.operatorToken.kind === 24 /* CommaToken */) {
	                                    return spanInNode(binaryExpression.left);
	                                }
	                            }
	                            if (ts.isExpression(node)) {
	                                switch (node.parent.kind) {
	                                    case 200 /* DoStatement */:
	                                        // Set span as if on while keyword
	                                        return spanInPreviousNode(node);
	                                    case 140 /* Decorator */:
	                                        // Set breakpoint on the decorator emit
	                                        return spanInNode(node.parent);
	                                    case 202 /* ForStatement */:
	                                    case 204 /* ForOfStatement */:
	                                        return textSpan(node);
	                                    case 184 /* BinaryExpression */:
	                                        if (node.parent.operatorToken.kind === 24 /* CommaToken */) {
	                                            // if this is comma expression, the breakpoint is possible in this expression
	                                            return textSpan(node);
	                                        }
	                                        break;
	                                    case 177 /* ArrowFunction */:
	                                        if (node.parent.body === node) {
	                                            // If this is body of arrow function, it is allowed to have the breakpoint
	                                            return textSpan(node);
	                                        }
	                                        break;
	                                }
	                            }
	                            // If this is name of property assignment, set breakpoint in the initializer
	                            if (node.parent.kind === 248 /* PropertyAssignment */ &&
	                                node.parent.name === node &&
	                                !ts.isArrayLiteralOrObjectLiteralDestructuringPattern(node.parent.parent)) {
	                                return spanInNode(node.parent.initializer);
	                            }
	                            // Breakpoint in type assertion goes to its operand
	                            if (node.parent.kind === 174 /* TypeAssertionExpression */ && node.parent.type === node) {
	                                return spanInNextNode(node.parent.type);
	                            }
	                            // return type of function go to previous token
	                            if (ts.isFunctionLike(node.parent) && node.parent.type === node) {
	                                return spanInPreviousNode(node);
	                            }
	                            // initializer of variable/parameter declaration go to previous node
	                            if ((node.parent.kind === 214 /* VariableDeclaration */ ||
	                                node.parent.kind === 139 /* Parameter */)) {
	                                var paramOrVarDecl = node.parent;
	                                if (paramOrVarDecl.initializer === node ||
	                                    paramOrVarDecl.type === node ||
	                                    ts.isAssignmentOperator(node.kind)) {
	                                    return spanInPreviousNode(node);
	                                }
	                            }
	                            if (node.parent.kind === 184 /* BinaryExpression */) {
	                                var binaryExpression = node.parent;
	                                if (ts.isArrayLiteralOrObjectLiteralDestructuringPattern(binaryExpression.left) &&
	                                    (binaryExpression.right === node ||
	                                        binaryExpression.operatorToken === node)) {
	                                    // If initializer of destructuring assignment move to previous token
	                                    return spanInPreviousNode(node);
	                                }
	                            }
	                            // Default go to parent to set the breakpoint
	                            return spanInNode(node.parent);
	                    }
	                }
	                function textSpanFromVariableDeclaration(variableDeclaration) {
	                    var declarations = variableDeclaration.parent.declarations;
	                    if (declarations && declarations[0] === variableDeclaration) {
	                        // First declaration - include let keyword
	                        return textSpan(ts.findPrecedingToken(variableDeclaration.pos, sourceFile, variableDeclaration.parent), variableDeclaration);
	                    }
	                    else {
	                        // Span only on this declaration
	                        return textSpan(variableDeclaration);
	                    }
	                }
	                function spanInVariableDeclaration(variableDeclaration) {
	                    // If declaration of for in statement, just set the span in parent
	                    if (variableDeclaration.parent.parent.kind === 203 /* ForInStatement */) {
	                        return spanInNode(variableDeclaration.parent.parent);
	                    }
	                    // If this is a destructuring pattern set breakpoint in binding pattern
	                    if (ts.isBindingPattern(variableDeclaration.name)) {
	                        return spanInBindingPattern(variableDeclaration.name);
	                    }
	                    // Breakpoint is possible in variableDeclaration only if there is initialization
	                    // or its declaration from 'for of'
	                    if (variableDeclaration.initializer ||
	                        (variableDeclaration.flags & 2 /* Export */) ||
	                        variableDeclaration.parent.parent.kind === 204 /* ForOfStatement */) {
	                        return textSpanFromVariableDeclaration(variableDeclaration);
	                    }
	                    var declarations = variableDeclaration.parent.declarations;
	                    if (declarations && declarations[0] !== variableDeclaration) {
	                        // If we cant set breakpoint on this declaration, set it on previous one
	                        // Because the variable declaration may be binding pattern and 
	                        // we would like to set breakpoint in last binding element if thats the case,
	                        // use preceding token instead
	                        return spanInNode(ts.findPrecedingToken(variableDeclaration.pos, sourceFile, variableDeclaration.parent));
	                    }
	                }
	                function canHaveSpanInParameterDeclaration(parameter) {
	                    // Breakpoint is possible on parameter only if it has initializer, is a rest parameter, or has public or private modifier
	                    return !!parameter.initializer || parameter.dotDotDotToken !== undefined ||
	                        !!(parameter.flags & 8 /* Public */) || !!(parameter.flags & 16 /* Private */);
	                }
	                function spanInParameterDeclaration(parameter) {
	                    if (ts.isBindingPattern(parameter.name)) {
	                        // set breakpoint in binding pattern
	                        return spanInBindingPattern(parameter.name);
	                    }
	                    else if (canHaveSpanInParameterDeclaration(parameter)) {
	                        return textSpan(parameter);
	                    }
	                    else {
	                        var functionDeclaration = parameter.parent;
	                        var indexOfParameter = ts.indexOf(functionDeclaration.parameters, parameter);
	                        if (indexOfParameter) {
	                            // Not a first parameter, go to previous parameter
	                            return spanInParameterDeclaration(functionDeclaration.parameters[indexOfParameter - 1]);
	                        }
	                        else {
	                            // Set breakpoint in the function declaration body
	                            return spanInNode(functionDeclaration.body);
	                        }
	                    }
	                }
	                function canFunctionHaveSpanInWholeDeclaration(functionDeclaration) {
	                    return !!(functionDeclaration.flags & 2 /* Export */) ||
	                        (functionDeclaration.parent.kind === 217 /* ClassDeclaration */ && functionDeclaration.kind !== 145 /* Constructor */);
	                }
	                function spanInFunctionDeclaration(functionDeclaration) {
	                    // No breakpoints in the function signature
	                    if (!functionDeclaration.body) {
	                        return undefined;
	                    }
	                    if (canFunctionHaveSpanInWholeDeclaration(functionDeclaration)) {
	                        // Set the span on whole function declaration
	                        return textSpan(functionDeclaration);
	                    }
	                    // Set span in function body
	                    return spanInNode(functionDeclaration.body);
	                }
	                function spanInFunctionBlock(block) {
	                    var nodeForSpanInBlock = block.statements.length ? block.statements[0] : block.getLastToken();
	                    if (canFunctionHaveSpanInWholeDeclaration(block.parent)) {
	                        return spanInNodeIfStartsOnSameLine(block.parent, nodeForSpanInBlock);
	                    }
	                    return spanInNode(nodeForSpanInBlock);
	                }
	                function spanInBlock(block) {
	                    switch (block.parent.kind) {
	                        case 221 /* ModuleDeclaration */:
	                            if (ts.getModuleInstanceState(block.parent) !== 1 /* Instantiated */) {
	                                return undefined;
	                            }
	                        // Set on parent if on same line otherwise on first statement
	                        case 201 /* WhileStatement */:
	                        case 199 /* IfStatement */:
	                        case 203 /* ForInStatement */:
	                            return spanInNodeIfStartsOnSameLine(block.parent, block.statements[0]);
	                        // Set span on previous token if it starts on same line otherwise on the first statement of the block
	                        case 202 /* ForStatement */:
	                        case 204 /* ForOfStatement */:
	                            return spanInNodeIfStartsOnSameLine(ts.findPrecedingToken(block.pos, sourceFile, block.parent), block.statements[0]);
	                    }
	                    // Default action is to set on first statement
	                    return spanInNode(block.statements[0]);
	                }
	                function spanInInitializerOfForLike(forLikeStaement) {
	                    if (forLikeStaement.initializer.kind === 215 /* VariableDeclarationList */) {
	                        // declaration list, set breakpoint in first declaration
	                        var variableDeclarationList = forLikeStaement.initializer;
	                        if (variableDeclarationList.declarations.length > 0) {
	                            return spanInNode(variableDeclarationList.declarations[0]);
	                        }
	                    }
	                    else {
	                        // Expression - set breakpoint in it
	                        return spanInNode(forLikeStaement.initializer);
	                    }
	                }
	                function spanInForStatement(forStatement) {
	                    if (forStatement.initializer) {
	                        return spanInInitializerOfForLike(forStatement);
	                    }
	                    if (forStatement.condition) {
	                        return textSpan(forStatement.condition);
	                    }
	                    if (forStatement.incrementor) {
	                        return textSpan(forStatement.incrementor);
	                    }
	                }
	                function spanInBindingPattern(bindingPattern) {
	                    // Set breakpoint in first binding element
	                    var firstBindingElement = ts.forEach(bindingPattern.elements, function (element) { return element.kind !== 190 /* OmittedExpression */ ? element : undefined; });
	                    if (firstBindingElement) {
	                        return spanInNode(firstBindingElement);
	                    }
	                    // Empty binding pattern of binding element, set breakpoint on binding element
	                    if (bindingPattern.parent.kind === 166 /* BindingElement */) {
	                        return textSpan(bindingPattern.parent);
	                    }
	                    // Variable declaration is used as the span
	                    return textSpanFromVariableDeclaration(bindingPattern.parent);
	                }
	                function spanInArrayLiteralOrObjectLiteralDestructuringPattern(node) {
	                    ts.Debug.assert(node.kind !== 165 /* ArrayBindingPattern */ && node.kind !== 164 /* ObjectBindingPattern */);
	                    var elements = node.kind === 167 /* ArrayLiteralExpression */ ?
	                        node.elements :
	                        node.properties;
	                    var firstBindingElement = ts.forEach(elements, function (element) { return element.kind !== 190 /* OmittedExpression */ ? element : undefined; });
	                    if (firstBindingElement) {
	                        return spanInNode(firstBindingElement);
	                    }
	                    // Could be ArrayLiteral from destructuring assignment or 
	                    // just nested element in another destructuring assignment
	                    // set breakpoint on assignment when parent is destructuring assignment
	                    // Otherwise set breakpoint for this element
	                    return textSpan(node.parent.kind === 184 /* BinaryExpression */ ? node.parent : node);
	                }
	                // Tokens:
	                function spanInOpenBraceToken(node) {
	                    switch (node.parent.kind) {
	                        case 220 /* EnumDeclaration */:
	                            var enumDeclaration = node.parent;
	                            return spanInNodeIfStartsOnSameLine(ts.findPrecedingToken(node.pos, sourceFile, node.parent), enumDeclaration.members.length ? enumDeclaration.members[0] : enumDeclaration.getLastToken(sourceFile));
	                        case 217 /* ClassDeclaration */:
	                            var classDeclaration = node.parent;
	                            return spanInNodeIfStartsOnSameLine(ts.findPrecedingToken(node.pos, sourceFile, node.parent), classDeclaration.members.length ? classDeclaration.members[0] : classDeclaration.getLastToken(sourceFile));
	                        case 223 /* CaseBlock */:
	                            return spanInNodeIfStartsOnSameLine(node.parent.parent, node.parent.clauses[0]);
	                    }
	                    // Default to parent node
	                    return spanInNode(node.parent);
	                }
	                function spanInCloseBraceToken(node) {
	                    switch (node.parent.kind) {
	                        case 222 /* ModuleBlock */:
	                            // If this is not instantiated module block no bp span
	                            if (ts.getModuleInstanceState(node.parent.parent) !== 1 /* Instantiated */) {
	                                return undefined;
	                            }
	                        case 220 /* EnumDeclaration */:
	                        case 217 /* ClassDeclaration */:
	                            // Span on close brace token
	                            return textSpan(node);
	                        case 195 /* Block */:
	                            if (ts.isFunctionBlock(node.parent)) {
	                                // Span on close brace token
	                                return textSpan(node);
	                            }
	                        // fall through.
	                        case 247 /* CatchClause */:
	                            return spanInNode(ts.lastOrUndefined(node.parent.statements));
	                        case 223 /* CaseBlock */:
	                            // breakpoint in last statement of the last clause
	                            var caseBlock = node.parent;
	                            var lastClause = ts.lastOrUndefined(caseBlock.clauses);
	                            if (lastClause) {
	                                return spanInNode(ts.lastOrUndefined(lastClause.statements));
	                            }
	                            return undefined;
	                        case 164 /* ObjectBindingPattern */:
	                            // Breakpoint in last binding element or binding pattern if it contains no elements
	                            var bindingPattern = node.parent;
	                            return spanInNode(ts.lastOrUndefined(bindingPattern.elements) || bindingPattern);
	                        // Default to parent node
	                        default:
	                            if (ts.isArrayLiteralOrObjectLiteralDestructuringPattern(node.parent)) {
	                                // Breakpoint in last binding element or binding pattern if it contains no elements
	                                var objectLiteral = node.parent;
	                                return textSpan(ts.lastOrUndefined(objectLiteral.properties) || objectLiteral);
	                            }
	                            return spanInNode(node.parent);
	                    }
	                }
	                function spanInCloseBracketToken(node) {
	                    switch (node.parent.kind) {
	                        case 165 /* ArrayBindingPattern */:
	                            // Breakpoint in last binding element or binding pattern if it contains no elements
	                            var bindingPattern = node.parent;
	                            return textSpan(ts.lastOrUndefined(bindingPattern.elements) || bindingPattern);
	                        default:
	                            if (ts.isArrayLiteralOrObjectLiteralDestructuringPattern(node.parent)) {
	                                // Breakpoint in last binding element or binding pattern if it contains no elements
	                                var arrayLiteral = node.parent;
	                                return textSpan(ts.lastOrUndefined(arrayLiteral.elements) || arrayLiteral);
	                            }
	                            // Default to parent node
	                            return spanInNode(node.parent);
	                    }
	                }
	                function spanInOpenParenToken(node) {
	                    if (node.parent.kind === 200 /* DoStatement */ ||
	                        node.parent.kind === 171 /* CallExpression */ ||
	                        node.parent.kind === 172 /* NewExpression */) {
	                        return spanInPreviousNode(node);
	                    }
	                    if (node.parent.kind === 175 /* ParenthesizedExpression */) {
	                        return spanInNextNode(node);
	                    }
	                    // Default to parent node
	                    return spanInNode(node.parent);
	                }
	                function spanInCloseParenToken(node) {
	                    // Is this close paren token of parameter list, set span in previous token
	                    switch (node.parent.kind) {
	                        case 176 /* FunctionExpression */:
	                        case 216 /* FunctionDeclaration */:
	                        case 177 /* ArrowFunction */:
	                        case 144 /* MethodDeclaration */:
	                        case 143 /* MethodSignature */:
	                        case 146 /* GetAccessor */:
	                        case 147 /* SetAccessor */:
	                        case 145 /* Constructor */:
	                        case 201 /* WhileStatement */:
	                        case 200 /* DoStatement */:
	                        case 202 /* ForStatement */:
	                        case 204 /* ForOfStatement */:
	                        case 171 /* CallExpression */:
	                        case 172 /* NewExpression */:
	                        case 175 /* ParenthesizedExpression */:
	                            return spanInPreviousNode(node);
	                        // Default to parent node
	                        default:
	                            return spanInNode(node.parent);
	                    }
	                }
	                function spanInColonToken(node) {
	                    // Is this : specifying return annotation of the function declaration
	                    if (ts.isFunctionLike(node.parent) ||
	                        node.parent.kind === 248 /* PropertyAssignment */ ||
	                        node.parent.kind === 139 /* Parameter */) {
	                        return spanInPreviousNode(node);
	                    }
	                    return spanInNode(node.parent);
	                }
	                function spanInGreaterThanOrLessThanToken(node) {
	                    if (node.parent.kind === 174 /* TypeAssertionExpression */) {
	                        return spanInNextNode(node);
	                    }
	                    return spanInNode(node.parent);
	                }
	                function spanInWhileKeyword(node) {
	                    if (node.parent.kind === 200 /* DoStatement */) {
	                        // Set span on while expression
	                        return textSpanEndingAtNextToken(node, node.parent.expression);
	                    }
	                    // Default to parent node
	                    return spanInNode(node.parent);
	                }
	                function spanInOfKeyword(node) {
	                    if (node.parent.kind === 204 /* ForOfStatement */) {
	                        // set using next token
	                        return spanInNextNode(node);
	                    }
	                    // Default to parent node
	                    return spanInNode(node.parent);
	                }
	            }
	        }
	        BreakpointResolver.spanInSourceFileAtLocation = spanInSourceFileAtLocation;
	    })(BreakpointResolver = ts.BreakpointResolver || (ts.BreakpointResolver = {}));
	})(ts || (ts = {}));
	//
	// Copyright (c) Microsoft Corporation.  All rights reserved.
	//
	// Licensed under the Apache License, Version 2.0 (the "License");
	// you may not use this file except in compliance with the License.
	// You may obtain a copy of the License at
	//   http://www.apache.org/licenses/LICENSE-2.0
	//
	// Unless required by applicable law or agreed to in writing, software
	// distributed under the License is distributed on an "AS IS" BASIS,
	// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
	// See the License for the specific language governing permissions and
	// limitations under the License.
	//
	/// <reference path='services.ts' />
	/* @internal */
	var debugObjectHost = this;
	// We need to use 'null' to interface with the managed side.
	/* tslint:disable:no-null */
	/* tslint:disable:no-in-operator */
	/* @internal */
	var ts;
	(function (ts) {
	    function logInternalError(logger, err) {
	        if (logger) {
	            logger.log("*INTERNAL ERROR* - Exception in typescript services: " + err.message);
	        }
	    }
	    var ScriptSnapshotShimAdapter = (function () {
	        function ScriptSnapshotShimAdapter(scriptSnapshotShim) {
	            this.scriptSnapshotShim = scriptSnapshotShim;
	        }
	        ScriptSnapshotShimAdapter.prototype.getText = function (start, end) {
	            return this.scriptSnapshotShim.getText(start, end);
	        };
	        ScriptSnapshotShimAdapter.prototype.getLength = function () {
	            return this.scriptSnapshotShim.getLength();
	        };
	        ScriptSnapshotShimAdapter.prototype.getChangeRange = function (oldSnapshot) {
	            var oldSnapshotShim = oldSnapshot;
	            var encoded = this.scriptSnapshotShim.getChangeRange(oldSnapshotShim.scriptSnapshotShim);
	            // TODO: should this be '==='?
	            if (encoded == null) {
	                return null;
	            }
	            var decoded = JSON.parse(encoded);
	            return ts.createTextChangeRange(ts.createTextSpan(decoded.span.start, decoded.span.length), decoded.newLength);
	        };
	        ScriptSnapshotShimAdapter.prototype.dispose = function () {
	            // if scriptSnapshotShim is a COM object then property check becomes method call with no arguments
	            // 'in' does not have this effect
	            if ("dispose" in this.scriptSnapshotShim) {
	                this.scriptSnapshotShim.dispose();
	            }
	        };
	        return ScriptSnapshotShimAdapter;
	    }());
	    var LanguageServiceShimHostAdapter = (function () {
	        function LanguageServiceShimHostAdapter(shimHost) {
	            var _this = this;
	            this.shimHost = shimHost;
	            this.loggingEnabled = false;
	            this.tracingEnabled = false;
	            // if shimHost is a COM object then property check will become method call with no arguments.
	            // 'in' does not have this effect. 
	            if ("getModuleResolutionsForFile" in this.shimHost) {
	                this.resolveModuleNames = function (moduleNames, containingFile) {
	                    var resolutionsInFile = JSON.parse(_this.shimHost.getModuleResolutionsForFile(containingFile));
	                    return ts.map(moduleNames, function (name) {
	                        var result = ts.lookUp(resolutionsInFile, name);
	                        return result ? { resolvedFileName: result } : undefined;
	                    });
	                };
	            }
	            if ("directoryExists" in this.shimHost) {
	                this.directoryExists = function (directoryName) { return _this.shimHost.directoryExists(directoryName); };
	            }
	        }
	        LanguageServiceShimHostAdapter.prototype.log = function (s) {
	            if (this.loggingEnabled) {
	                this.shimHost.log(s);
	            }
	        };
	        LanguageServiceShimHostAdapter.prototype.trace = function (s) {
	            if (this.tracingEnabled) {
	                this.shimHost.trace(s);
	            }
	        };
	        LanguageServiceShimHostAdapter.prototype.error = function (s) {
	            this.shimHost.error(s);
	        };
	        LanguageServiceShimHostAdapter.prototype.getProjectVersion = function () {
	            if (!this.shimHost.getProjectVersion) {
	                // shimmed host does not support getProjectVersion
	                return undefined;
	            }
	            return this.shimHost.getProjectVersion();
	        };
	        LanguageServiceShimHostAdapter.prototype.useCaseSensitiveFileNames = function () {
	            return this.shimHost.useCaseSensitiveFileNames ? this.shimHost.useCaseSensitiveFileNames() : false;
	        };
	        LanguageServiceShimHostAdapter.prototype.getCompilationSettings = function () {
	            var settingsJson = this.shimHost.getCompilationSettings();
	            // TODO: should this be '==='?
	            if (settingsJson == null || settingsJson == "") {
	                throw Error("LanguageServiceShimHostAdapter.getCompilationSettings: empty compilationSettings");
	            }
	            return JSON.parse(settingsJson);
	        };
	        LanguageServiceShimHostAdapter.prototype.getScriptFileNames = function () {
	            var encoded = this.shimHost.getScriptFileNames();
	            return this.files = JSON.parse(encoded);
	        };
	        LanguageServiceShimHostAdapter.prototype.getScriptSnapshot = function (fileName) {
	            var scriptSnapshot = this.shimHost.getScriptSnapshot(fileName);
	            return scriptSnapshot && new ScriptSnapshotShimAdapter(scriptSnapshot);
	        };
	        LanguageServiceShimHostAdapter.prototype.getScriptVersion = function (fileName) {
	            return this.shimHost.getScriptVersion(fileName);
	        };
	        LanguageServiceShimHostAdapter.prototype.getLocalizedDiagnosticMessages = function () {
	            var diagnosticMessagesJson = this.shimHost.getLocalizedDiagnosticMessages();
	            if (diagnosticMessagesJson == null || diagnosticMessagesJson == "") {
	                return null;
	            }
	            try {
	                return JSON.parse(diagnosticMessagesJson);
	            }
	            catch (e) {
	                this.log(e.description || "diagnosticMessages.generated.json has invalid JSON format");
	                return null;
	            }
	        };
	        LanguageServiceShimHostAdapter.prototype.getCancellationToken = function () {
	            var hostCancellationToken = this.shimHost.getCancellationToken();
	            return new ThrottledCancellationToken(hostCancellationToken);
	        };
	        LanguageServiceShimHostAdapter.prototype.getCurrentDirectory = function () {
	            return this.shimHost.getCurrentDirectory();
	        };
	        LanguageServiceShimHostAdapter.prototype.getDefaultLibFileName = function (options) {
	            return this.shimHost.getDefaultLibFileName(JSON.stringify(options));
	        };
	        return LanguageServiceShimHostAdapter;
	    }());
	    ts.LanguageServiceShimHostAdapter = LanguageServiceShimHostAdapter;
	    /** A cancellation that throttles calls to the host */
	    var ThrottledCancellationToken = (function () {
	        function ThrottledCancellationToken(hostCancellationToken) {
	            this.hostCancellationToken = hostCancellationToken;
	            // Store when we last tried to cancel.  Checking cancellation can be expensive (as we have
	            // to marshall over to the host layer).  So we only bother actually checking once enough
	            // time has passed.
	            this.lastCancellationCheckTime = 0;
	        }
	        ThrottledCancellationToken.prototype.isCancellationRequested = function () {
	            var time = Date.now();
	            var duration = Math.abs(time - this.lastCancellationCheckTime);
	            if (duration > 10) {
	                // Check no more than once every 10 ms.
	                this.lastCancellationCheckTime = time;
	                return this.hostCancellationToken.isCancellationRequested();
	            }
	            return false;
	        };
	        return ThrottledCancellationToken;
	    }());
	    var CoreServicesShimHostAdapter = (function () {
	        function CoreServicesShimHostAdapter(shimHost) {
	            var _this = this;
	            this.shimHost = shimHost;
	            if ("directoryExists" in this.shimHost) {
	                this.directoryExists = function (directoryName) { return _this.shimHost.directoryExists(directoryName); };
	            }
	        }
	        CoreServicesShimHostAdapter.prototype.readDirectory = function (rootDir, extension, exclude) {
	            var encoded = this.shimHost.readDirectory(rootDir, extension, JSON.stringify(exclude));
	            return JSON.parse(encoded);
	        };
	        CoreServicesShimHostAdapter.prototype.fileExists = function (fileName) {
	            return this.shimHost.fileExists(fileName);
	        };
	        CoreServicesShimHostAdapter.prototype.readFile = function (fileName) {
	            return this.shimHost.readFile(fileName);
	        };
	        return CoreServicesShimHostAdapter;
	    }());
	    ts.CoreServicesShimHostAdapter = CoreServicesShimHostAdapter;
	    function simpleForwardCall(logger, actionDescription, action, logPerformance) {
	        var start;
	        if (logPerformance) {
	            logger.log(actionDescription);
	            start = Date.now();
	        }
	        var result = action();
	        if (logPerformance) {
	            var end = Date.now();
	            logger.log(actionDescription + " completed in " + (end - start) + " msec");
	            if (typeof result === "string") {
	                var str = result;
	                if (str.length > 128) {
	                    str = str.substring(0, 128) + "...";
	                }
	                logger.log("  result.length=" + str.length + ", result='" + JSON.stringify(str) + "'");
	            }
	        }
	        return result;
	    }
	    function forwardJSONCall(logger, actionDescription, action, logPerformance) {
	        try {
	            var result = simpleForwardCall(logger, actionDescription, action, logPerformance);
	            return JSON.stringify({ result: result });
	        }
	        catch (err) {
	            if (err instanceof ts.OperationCanceledException) {
	                return JSON.stringify({ canceled: true });
	            }
	            logInternalError(logger, err);
	            err.description = actionDescription;
	            return JSON.stringify({ error: err });
	        }
	    }
	    var ShimBase = (function () {
	        function ShimBase(factory) {
	            this.factory = factory;
	            factory.registerShim(this);
	        }
	        ShimBase.prototype.dispose = function (dummy) {
	            this.factory.unregisterShim(this);
	        };
	        return ShimBase;
	    }());
	    function realizeDiagnostics(diagnostics, newLine) {
	        return diagnostics.map(function (d) { return realizeDiagnostic(d, newLine); });
	    }
	    ts.realizeDiagnostics = realizeDiagnostics;
	    function realizeDiagnostic(diagnostic, newLine) {
	        return {
	            message: ts.flattenDiagnosticMessageText(diagnostic.messageText, newLine),
	            start: diagnostic.start,
	            length: diagnostic.length,
	            /// TODO: no need for the tolowerCase call
	            category: ts.DiagnosticCategory[diagnostic.category].toLowerCase(),
	            code: diagnostic.code
	        };
	    }
	    var LanguageServiceShimObject = (function (_super) {
	        __extends(LanguageServiceShimObject, _super);
	        function LanguageServiceShimObject(factory, host, languageService) {
	            _super.call(this, factory);
	            this.host = host;
	            this.languageService = languageService;
	            this.logPerformance = false;
	            this.logger = this.host;
	        }
	        LanguageServiceShimObject.prototype.forwardJSONCall = function (actionDescription, action) {
	            return forwardJSONCall(this.logger, actionDescription, action, this.logPerformance);
	        };
	        /// DISPOSE
	        /**
	         * Ensure (almost) deterministic release of internal Javascript resources when
	         * some external native objects holds onto us (e.g. Com/Interop).
	         */
	        LanguageServiceShimObject.prototype.dispose = function (dummy) {
	            this.logger.log("dispose()");
	            this.languageService.dispose();
	            this.languageService = null;
	            // force a GC
	            if (debugObjectHost && debugObjectHost.CollectGarbage) {
	                debugObjectHost.CollectGarbage();
	                this.logger.log("CollectGarbage()");
	            }
	            this.logger = null;
	            _super.prototype.dispose.call(this, dummy);
	        };
	        /// REFRESH
	        /**
	         * Update the list of scripts known to the compiler
	         */
	        LanguageServiceShimObject.prototype.refresh = function (throwOnError) {
	            this.forwardJSONCall("refresh(" + throwOnError + ")", function () { return null; });
	        };
	        LanguageServiceShimObject.prototype.cleanupSemanticCache = function () {
	            var _this = this;
	            this.forwardJSONCall("cleanupSemanticCache()", function () {
	                _this.languageService.cleanupSemanticCache();
	                return null;
	            });
	        };
	        LanguageServiceShimObject.prototype.realizeDiagnostics = function (diagnostics) {
	            var newLine = ts.getNewLineOrDefaultFromHost(this.host);
	            return ts.realizeDiagnostics(diagnostics, newLine);
	        };
	        LanguageServiceShimObject.prototype.getSyntacticClassifications = function (fileName, start, length) {
	            var _this = this;
	            return this.forwardJSONCall("getSyntacticClassifications('" + fileName + "', " + start + ", " + length + ")", function () { return _this.languageService.getSyntacticClassifications(fileName, ts.createTextSpan(start, length)); });
	        };
	        LanguageServiceShimObject.prototype.getSemanticClassifications = function (fileName, start, length) {
	            var _this = this;
	            return this.forwardJSONCall("getSemanticClassifications('" + fileName + "', " + start + ", " + length + ")", function () { return _this.languageService.getSemanticClassifications(fileName, ts.createTextSpan(start, length)); });
	        };
	        LanguageServiceShimObject.prototype.getEncodedSyntacticClassifications = function (fileName, start, length) {
	            var _this = this;
	            return this.forwardJSONCall("getEncodedSyntacticClassifications('" + fileName + "', " + start + ", " + length + ")", 
	            // directly serialize the spans out to a string.  This is much faster to decode
	            // on the managed side versus a full JSON array.
	            function () { return convertClassifications(_this.languageService.getEncodedSyntacticClassifications(fileName, ts.createTextSpan(start, length))); });
	        };
	        LanguageServiceShimObject.prototype.getEncodedSemanticClassifications = function (fileName, start, length) {
	            var _this = this;
	            return this.forwardJSONCall("getEncodedSemanticClassifications('" + fileName + "', " + start + ", " + length + ")", 
	            // directly serialize the spans out to a string.  This is much faster to decode
	            // on the managed side versus a full JSON array.
	            function () { return convertClassifications(_this.languageService.getEncodedSemanticClassifications(fileName, ts.createTextSpan(start, length))); });
	        };
	        LanguageServiceShimObject.prototype.getSyntacticDiagnostics = function (fileName) {
	            var _this = this;
	            return this.forwardJSONCall("getSyntacticDiagnostics('" + fileName + "')", function () {
	                var diagnostics = _this.languageService.getSyntacticDiagnostics(fileName);
	                return _this.realizeDiagnostics(diagnostics);
	            });
	        };
	        LanguageServiceShimObject.prototype.getSemanticDiagnostics = function (fileName) {
	            var _this = this;
	            return this.forwardJSONCall("getSemanticDiagnostics('" + fileName + "')", function () {
	                var diagnostics = _this.languageService.getSemanticDiagnostics(fileName);
	                return _this.realizeDiagnostics(diagnostics);
	            });
	        };
	        LanguageServiceShimObject.prototype.getCompilerOptionsDiagnostics = function () {
	            var _this = this;
	            return this.forwardJSONCall("getCompilerOptionsDiagnostics()", function () {
	                var diagnostics = _this.languageService.getCompilerOptionsDiagnostics();
	                return _this.realizeDiagnostics(diagnostics);
	            });
	        };
	        /// QUICKINFO
	        /**
	         * Computes a string representation of the type at the requested position
	         * in the active file.
	         */
	        LanguageServiceShimObject.prototype.getQuickInfoAtPosition = function (fileName, position) {
	            var _this = this;
	            return this.forwardJSONCall("getQuickInfoAtPosition('" + fileName + "', " + position + ")", function () { return _this.languageService.getQuickInfoAtPosition(fileName, position); });
	        };
	        /// NAMEORDOTTEDNAMESPAN
	        /**
	         * Computes span information of the name or dotted name at the requested position
	         * in the active file.
	         */
	        LanguageServiceShimObject.prototype.getNameOrDottedNameSpan = function (fileName, startPos, endPos) {
	            var _this = this;
	            return this.forwardJSONCall("getNameOrDottedNameSpan('" + fileName + "', " + startPos + ", " + endPos + ")", function () { return _this.languageService.getNameOrDottedNameSpan(fileName, startPos, endPos); });
	        };
	        /**
	         * STATEMENTSPAN
	         * Computes span information of statement at the requested position in the active file.
	         */
	        LanguageServiceShimObject.prototype.getBreakpointStatementAtPosition = function (fileName, position) {
	            var _this = this;
	            return this.forwardJSONCall("getBreakpointStatementAtPosition('" + fileName + "', " + position + ")", function () { return _this.languageService.getBreakpointStatementAtPosition(fileName, position); });
	        };
	        /// SIGNATUREHELP
	        LanguageServiceShimObject.prototype.getSignatureHelpItems = function (fileName, position) {
	            var _this = this;
	            return this.forwardJSONCall("getSignatureHelpItems('" + fileName + "', " + position + ")", function () { return _this.languageService.getSignatureHelpItems(fileName, position); });
	        };
	        /// GOTO DEFINITION
	        /**
	         * Computes the definition location and file for the symbol
	         * at the requested position.
	         */
	        LanguageServiceShimObject.prototype.getDefinitionAtPosition = function (fileName, position) {
	            var _this = this;
	            return this.forwardJSONCall("getDefinitionAtPosition('" + fileName + "', " + position + ")", function () { return _this.languageService.getDefinitionAtPosition(fileName, position); });
	        };
	        /// GOTO Type
	        /**
	         * Computes the definition location of the type of the symbol
	         * at the requested position.
	         */
	        LanguageServiceShimObject.prototype.getTypeDefinitionAtPosition = function (fileName, position) {
	            var _this = this;
	            return this.forwardJSONCall("getTypeDefinitionAtPosition('" + fileName + "', " + position + ")", function () { return _this.languageService.getTypeDefinitionAtPosition(fileName, position); });
	        };
	        LanguageServiceShimObject.prototype.getRenameInfo = function (fileName, position) {
	            var _this = this;
	            return this.forwardJSONCall("getRenameInfo('" + fileName + "', " + position + ")", function () { return _this.languageService.getRenameInfo(fileName, position); });
	        };
	        LanguageServiceShimObject.prototype.findRenameLocations = function (fileName, position, findInStrings, findInComments) {
	            var _this = this;
	            return this.forwardJSONCall("findRenameLocations('" + fileName + "', " + position + ", " + findInStrings + ", " + findInComments + ")", function () { return _this.languageService.findRenameLocations(fileName, position, findInStrings, findInComments); });
	        };
	        /// GET BRACE MATCHING
	        LanguageServiceShimObject.prototype.getBraceMatchingAtPosition = function (fileName, position) {
	            var _this = this;
	            return this.forwardJSONCall("getBraceMatchingAtPosition('" + fileName + "', " + position + ")", function () { return _this.languageService.getBraceMatchingAtPosition(fileName, position); });
	        };
	        /// GET SMART INDENT
	        LanguageServiceShimObject.prototype.getIndentationAtPosition = function (fileName, position, options /*Services.EditorOptions*/) {
	            var _this = this;
	            return this.forwardJSONCall("getIndentationAtPosition('" + fileName + "', " + position + ")", function () {
	                var localOptions = JSON.parse(options);
	                return _this.languageService.getIndentationAtPosition(fileName, position, localOptions);
	            });
	        };
	        /// GET REFERENCES
	        LanguageServiceShimObject.prototype.getReferencesAtPosition = function (fileName, position) {
	            var _this = this;
	            return this.forwardJSONCall("getReferencesAtPosition('" + fileName + "', " + position + ")", function () { return _this.languageService.getReferencesAtPosition(fileName, position); });
	        };
	        LanguageServiceShimObject.prototype.findReferences = function (fileName, position) {
	            var _this = this;
	            return this.forwardJSONCall("findReferences('" + fileName + "', " + position + ")", function () { return _this.languageService.findReferences(fileName, position); });
	        };
	        LanguageServiceShimObject.prototype.getOccurrencesAtPosition = function (fileName, position) {
	            var _this = this;
	            return this.forwardJSONCall("getOccurrencesAtPosition('" + fileName + "', " + position + ")", function () { return _this.languageService.getOccurrencesAtPosition(fileName, position); });
	        };
	        LanguageServiceShimObject.prototype.getDocumentHighlights = function (fileName, position, filesToSearch) {
	            var _this = this;
	            return this.forwardJSONCall("getDocumentHighlights('" + fileName + "', " + position + ")", function () {
	                var results = _this.languageService.getDocumentHighlights(fileName, position, JSON.parse(filesToSearch));
	                // workaround for VS document higlighting issue - keep only items from the initial file
	                var normalizedName = ts.normalizeSlashes(fileName).toLowerCase();
	                return ts.filter(results, function (r) { return ts.normalizeSlashes(r.fileName).toLowerCase() === normalizedName; });
	            });
	        };
	        /// COMPLETION LISTS
	        /**
	         * Get a string based representation of the completions
	         * to provide at the given source position and providing a member completion
	         * list if requested.
	         */
	        LanguageServiceShimObject.prototype.getCompletionsAtPosition = function (fileName, position) {
	            var _this = this;
	            return this.forwardJSONCall("getCompletionsAtPosition('" + fileName + "', " + position + ")", function () { return _this.languageService.getCompletionsAtPosition(fileName, position); });
	        };
	        /** Get a string based representation of a completion list entry details */
	        LanguageServiceShimObject.prototype.getCompletionEntryDetails = function (fileName, position, entryName) {
	            var _this = this;
	            return this.forwardJSONCall("getCompletionEntryDetails('" + fileName + "', " + position + ", '" + entryName + "')", function () { return _this.languageService.getCompletionEntryDetails(fileName, position, entryName); });
	        };
	        LanguageServiceShimObject.prototype.getFormattingEditsForRange = function (fileName, start, end, options /*Services.FormatCodeOptions*/) {
	            var _this = this;
	            return this.forwardJSONCall("getFormattingEditsForRange('" + fileName + "', " + start + ", " + end + ")", function () {
	                var localOptions = JSON.parse(options);
	                return _this.languageService.getFormattingEditsForRange(fileName, start, end, localOptions);
	            });
	        };
	        LanguageServiceShimObject.prototype.getFormattingEditsForDocument = function (fileName, options /*Services.FormatCodeOptions*/) {
	            var _this = this;
	            return this.forwardJSONCall("getFormattingEditsForDocument('" + fileName + "')", function () {
	                var localOptions = JSON.parse(options);
	                return _this.languageService.getFormattingEditsForDocument(fileName, localOptions);
	            });
	        };
	        LanguageServiceShimObject.prototype.getFormattingEditsAfterKeystroke = function (fileName, position, key, options /*Services.FormatCodeOptions*/) {
	            var _this = this;
	            return this.forwardJSONCall("getFormattingEditsAfterKeystroke('" + fileName + "', " + position + ", '" + key + "')", function () {
	                var localOptions = JSON.parse(options);
	                return _this.languageService.getFormattingEditsAfterKeystroke(fileName, position, key, localOptions);
	            });
	        };
	        LanguageServiceShimObject.prototype.getDocCommentTemplateAtPosition = function (fileName, position) {
	            var _this = this;
	            return this.forwardJSONCall("getDocCommentTemplateAtPosition('" + fileName + "', " + position + ")", function () { return _this.languageService.getDocCommentTemplateAtPosition(fileName, position); });
	        };
	        /// NAVIGATE TO
	        /** Return a list of symbols that are interesting to navigate to */
	        LanguageServiceShimObject.prototype.getNavigateToItems = function (searchValue, maxResultCount) {
	            var _this = this;
	            return this.forwardJSONCall("getNavigateToItems('" + searchValue + "', " + maxResultCount + ")", function () { return _this.languageService.getNavigateToItems(searchValue, maxResultCount); });
	        };
	        LanguageServiceShimObject.prototype.getNavigationBarItems = function (fileName) {
	            var _this = this;
	            return this.forwardJSONCall("getNavigationBarItems('" + fileName + "')", function () { return _this.languageService.getNavigationBarItems(fileName); });
	        };
	        LanguageServiceShimObject.prototype.getOutliningSpans = function (fileName) {
	            var _this = this;
	            return this.forwardJSONCall("getOutliningSpans('" + fileName + "')", function () { return _this.languageService.getOutliningSpans(fileName); });
	        };
	        LanguageServiceShimObject.prototype.getTodoComments = function (fileName, descriptors) {
	            var _this = this;
	            return this.forwardJSONCall("getTodoComments('" + fileName + "')", function () { return _this.languageService.getTodoComments(fileName, JSON.parse(descriptors)); });
	        };
	        /// Emit
	        LanguageServiceShimObject.prototype.getEmitOutput = function (fileName) {
	            var _this = this;
	            return this.forwardJSONCall("getEmitOutput('" + fileName + "')", function () { return _this.languageService.getEmitOutput(fileName); });
	        };
	        return LanguageServiceShimObject;
	    }(ShimBase));
	    function convertClassifications(classifications) {
	        return { spans: classifications.spans.join(","), endOfLineState: classifications.endOfLineState };
	    }
	    var ClassifierShimObject = (function (_super) {
	        __extends(ClassifierShimObject, _super);
	        function ClassifierShimObject(factory, logger) {
	            _super.call(this, factory);
	            this.logger = logger;
	            this.logPerformance = false;
	            this.classifier = ts.createClassifier();
	        }
	        ClassifierShimObject.prototype.getEncodedLexicalClassifications = function (text, lexState, syntacticClassifierAbsent) {
	            var _this = this;
	            return forwardJSONCall(this.logger, "getEncodedLexicalClassifications", function () { return convertClassifications(_this.classifier.getEncodedLexicalClassifications(text, lexState, syntacticClassifierAbsent)); }, this.logPerformance);
	        };
	        /// COLORIZATION
	        ClassifierShimObject.prototype.getClassificationsForLine = function (text, lexState, classifyKeywordsInGenerics) {
	            var classification = this.classifier.getClassificationsForLine(text, lexState, classifyKeywordsInGenerics);
	            var result = "";
	            for (var _i = 0, _a = classification.entries; _i < _a.length; _i++) {
	                var item = _a[_i];
	                result += item.length + "\n";
	                result += item.classification + "\n";
	            }
	            result += classification.finalLexState;
	            return result;
	        };
	        return ClassifierShimObject;
	    }(ShimBase));
	    var CoreServicesShimObject = (function (_super) {
	        __extends(CoreServicesShimObject, _super);
	        function CoreServicesShimObject(factory, logger, host) {
	            _super.call(this, factory);
	            this.logger = logger;
	            this.host = host;
	            this.logPerformance = false;
	        }
	        CoreServicesShimObject.prototype.forwardJSONCall = function (actionDescription, action) {
	            return forwardJSONCall(this.logger, actionDescription, action, this.logPerformance);
	        };
	        CoreServicesShimObject.prototype.resolveModuleName = function (fileName, moduleName, compilerOptionsJson) {
	            var _this = this;
	            return this.forwardJSONCall("resolveModuleName('" + fileName + "')", function () {
	                var compilerOptions = JSON.parse(compilerOptionsJson);
	                var result = ts.resolveModuleName(moduleName, ts.normalizeSlashes(fileName), compilerOptions, _this.host);
	                return {
	                    resolvedFileName: result.resolvedModule ? result.resolvedModule.resolvedFileName : undefined,
	                    failedLookupLocations: result.failedLookupLocations
	                };
	            });
	        };
	        CoreServicesShimObject.prototype.getPreProcessedFileInfo = function (fileName, sourceTextSnapshot) {
	            return this.forwardJSONCall("getPreProcessedFileInfo('" + fileName + "')", function () {
	                // for now treat files as JavaScript 
	                var result = ts.preProcessFile(sourceTextSnapshot.getText(0, sourceTextSnapshot.getLength()), /* readImportFiles */ true, /* detectJavaScriptImports */ true);
	                var convertResult = {
	                    referencedFiles: [],
	                    importedFiles: [],
	                    ambientExternalModules: result.ambientExternalModules,
	                    isLibFile: result.isLibFile
	                };
	                ts.forEach(result.referencedFiles, function (refFile) {
	                    convertResult.referencedFiles.push({
	                        path: ts.normalizePath(refFile.fileName),
	                        position: refFile.pos,
	                        length: refFile.end - refFile.pos
	                    });
	                });
	                ts.forEach(result.importedFiles, function (importedFile) {
	                    convertResult.importedFiles.push({
	                        path: ts.normalizeSlashes(importedFile.fileName),
	                        position: importedFile.pos,
	                        length: importedFile.end - importedFile.pos
	                    });
	                });
	                return convertResult;
	            });
	        };
	        CoreServicesShimObject.prototype.getTSConfigFileInfo = function (fileName, sourceTextSnapshot) {
	            var _this = this;
	            return this.forwardJSONCall("getTSConfigFileInfo('" + fileName + "')", function () {
	                var text = sourceTextSnapshot.getText(0, sourceTextSnapshot.getLength());
	                var result = ts.parseConfigFileTextToJson(fileName, text);
	                if (result.error) {
	                    return {
	                        options: {},
	                        files: [],
	                        errors: [realizeDiagnostic(result.error, "\r\n")]
	                    };
	                }
	                var normalizedFileName = ts.normalizeSlashes(fileName);
	                var configFile = ts.parseJsonConfigFileContent(result.config, _this.host, ts.getDirectoryPath(normalizedFileName), /*existingOptions*/ {}, normalizedFileName);
	                return {
	                    options: configFile.options,
	                    files: configFile.fileNames,
	                    errors: realizeDiagnostics(configFile.errors, "\r\n")
	                };
	            });
	        };
	        CoreServicesShimObject.prototype.getDefaultCompilationSettings = function () {
	            return this.forwardJSONCall("getDefaultCompilationSettings()", function () { return ts.getDefaultCompilerOptions(); });
	        };
	        return CoreServicesShimObject;
	    }(ShimBase));
	    var TypeScriptServicesFactory = (function () {
	        function TypeScriptServicesFactory() {
	            this._shims = [];
	        }
	        /*
	         * Returns script API version.
	         */
	        TypeScriptServicesFactory.prototype.getServicesVersion = function () {
	            return ts.servicesVersion;
	        };
	        TypeScriptServicesFactory.prototype.createLanguageServiceShim = function (host) {
	            try {
	                if (this.documentRegistry === undefined) {
	                    this.documentRegistry = ts.createDocumentRegistry(host.useCaseSensitiveFileNames && host.useCaseSensitiveFileNames(), host.getCurrentDirectory());
	                }
	                var hostAdapter = new LanguageServiceShimHostAdapter(host);
	                var languageService = ts.createLanguageService(hostAdapter, this.documentRegistry);
	                return new LanguageServiceShimObject(this, host, languageService);
	            }
	            catch (err) {
	                logInternalError(host, err);
	                throw err;
	            }
	        };
	        TypeScriptServicesFactory.prototype.createClassifierShim = function (logger) {
	            try {
	                return new ClassifierShimObject(this, logger);
	            }
	            catch (err) {
	                logInternalError(logger, err);
	                throw err;
	            }
	        };
	        TypeScriptServicesFactory.prototype.createCoreServicesShim = function (host) {
	            try {
	                var adapter = new CoreServicesShimHostAdapter(host);
	                return new CoreServicesShimObject(this, host, adapter);
	            }
	            catch (err) {
	                logInternalError(host, err);
	                throw err;
	            }
	        };
	        TypeScriptServicesFactory.prototype.close = function () {
	            // Forget all the registered shims
	            this._shims = [];
	            this.documentRegistry = undefined;
	        };
	        TypeScriptServicesFactory.prototype.registerShim = function (shim) {
	            this._shims.push(shim);
	        };
	        TypeScriptServicesFactory.prototype.unregisterShim = function (shim) {
	            for (var i = 0, n = this._shims.length; i < n; i++) {
	                if (this._shims[i] === shim) {
	                    delete this._shims[i];
	                    return;
	                }
	            }
	            throw new Error("Invalid operation");
	        };
	        return TypeScriptServicesFactory;
	    }());
	    ts.TypeScriptServicesFactory = TypeScriptServicesFactory;
	    if (typeof module !== "undefined" && module.exports) {
	        module.exports = ts;
	    }
	})(ts || (ts = {}));
	/* tslint:enable:no-in-operator */
	/* tslint:enable:no-null */
	/// TODO: this is used by VS, clean this up on both sides of the interface
	/* @internal */
	var TypeScript;
	(function (TypeScript) {
	    var Services;
	    (function (Services) {
	        Services.TypeScriptServicesFactory = ts.TypeScriptServicesFactory;
	    })(Services = TypeScript.Services || (TypeScript.Services = {}));
	})(TypeScript || (TypeScript = {}));
	/* tslint:disable:no-unused-variable */
	// 'toolsVersion' gets consumed by the managed side, so it's not unused.
	// TODO: it should be moved into a namespace though.
	/* @internal */
	var toolsVersion = "1.8";
	/* tslint:enable:no-unused-variable */ 
	
	/* WEBPACK VAR INJECTION */}.call(exports, __webpack_require__(56), "node_modules/raml-definition-system/node_modules/ts-structure-parser/node_modules/typescript/lib/typescript.js", (function() { return this; }()), "node_modules/raml-definition-system/node_modules/ts-structure-parser/node_modules/typescript/lib"))

/***/ },
/* 167 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	var parser = (function () {
	    "use strict";
	    /*
	     * Generated by PEG.js 0.9.0.
	     *
	     * http://pegjs.org/
	     */
	    function peg$subclass(child, parent) {
	        function ctor() { this.constructor = child; }
	        ctor.prototype = parent.prototype;
	        child.prototype = new ctor();
	    }
	    function peg$SyntaxError(message, expected, found, location) {
	        this.message = message;
	        this.expected = expected;
	        this.found = found;
	        this.location = location;
	        this.name = "SyntaxError";
	        if (typeof Error.captureStackTrace === "function") {
	            Error.captureStackTrace(this, peg$SyntaxError);
	        }
	    }
	    peg$subclass(peg$SyntaxError, Error);
	    function peg$parse(input) {
	        var options = arguments.length > 1 ? arguments[1] : {}, parser = this, peg$FAILED = {}, peg$startRuleFunctions = { Term: peg$parseTerm }, peg$startRuleFunction = peg$parseTerm, peg$c0 = "|", peg$c1 = { type: "literal", value: "|", description: "\"|\"" }, peg$c2 = function (first, rest) {
	            return rest ? { "type": "union", "first": first, "rest": rest[3] } : first;
	        }, peg$c3 = "(", peg$c4 = { type: "literal", value: "(", description: "\"(\"" }, peg$c5 = ")", peg$c6 = { type: "literal", value: ")", description: "\")\"" }, peg$c7 = "[]", peg$c8 = { type: "literal", value: "[]", description: "\"[]\"" }, peg$c9 = function (expr, arr) { return { "type": "parens", "expr": expr, "arr": arr.length }; }, peg$c10 = "<", peg$c11 = { type: "literal", value: "<", description: "\"<\"" }, peg$c12 = ">", peg$c13 = { type: "literal", value: ">", description: "\">\"" }, peg$c14 = function (first, other) { return [first].concat(other); }, peg$c15 = ",", peg$c16 = { type: "literal", value: ",", description: "\",\"" }, peg$c17 = function (r) { return r; }, peg$c18 = { type: "other", description: "name" }, peg$c19 = function (r, c) { return { "type": "name", "value": r.join(""), "arr": (c.length) }; }, peg$c20 = { type: "other", description: "whitespace" }, peg$c21 = /^[ \t\n\r]/, peg$c22 = { type: "class", value: "[ \\t\\n\\r]", description: "[ \\t\\n\\r]" }, peg$c23 = /^[A-Z]/, peg$c24 = { type: "class", value: "[A-Z]", description: "[A-Z]" }, peg$c25 = "_", peg$c26 = { type: "literal", value: "_", description: "\"_\"" }, peg$c27 = "-", peg$c28 = { type: "literal", value: "-", description: "\"-\"" }, peg$c29 = ".", peg$c30 = { type: "literal", value: ".", description: "\".\"" }, peg$c31 = /^[a-z]/, peg$c32 = { type: "class", value: "[a-z]", description: "[a-z]" }, peg$c33 = /^[0-9]/, peg$c34 = { type: "class", value: "[0-9]", description: "[0-9]" }, peg$c35 = "?", peg$c36 = { type: "literal", value: "?", description: "\"?\"" }, peg$currPos = 0, peg$savedPos = 0, peg$posDetailsCache = [{ line: 1, column: 1, seenCR: false }], peg$maxFailPos = 0, peg$maxFailExpected = [], peg$silentFails = 0, peg$result;
	        if ("startRule" in options) {
	            if (!(options.startRule in peg$startRuleFunctions)) {
	                throw new Error("Can't start parsing from rule \"" + options.startRule + "\".");
	            }
	            peg$startRuleFunction = peg$startRuleFunctions[options.startRule];
	        }
	        function text() {
	            return input.substring(peg$savedPos, peg$currPos);
	        }
	        function location() {
	            return peg$computeLocation(peg$savedPos, peg$currPos);
	        }
	        function expected(description) {
	            throw peg$buildException(null, [{ type: "other", description: description }], input.substring(peg$savedPos, peg$currPos), peg$computeLocation(peg$savedPos, peg$currPos));
	        }
	        function error(message) {
	            throw peg$buildException(message, null, input.substring(peg$savedPos, peg$currPos), peg$computeLocation(peg$savedPos, peg$currPos));
	        }
	        function peg$computePosDetails(pos) {
	            var details = peg$posDetailsCache[pos], p, ch;
	            if (details) {
	                return details;
	            }
	            else {
	                p = pos - 1;
	                while (!peg$posDetailsCache[p]) {
	                    p--;
	                }
	                details = peg$posDetailsCache[p];
	                details = {
	                    line: details.line,
	                    column: details.column,
	                    seenCR: details.seenCR
	                };
	                while (p < pos) {
	                    ch = input.charAt(p);
	                    if (ch === "\n") {
	                        if (!details.seenCR) {
	                            details.line++;
	                        }
	                        details.column = 1;
	                        details.seenCR = false;
	                    }
	                    else if (ch === "\r" || ch === "\u2028" || ch === "\u2029") {
	                        details.line++;
	                        details.column = 1;
	                        details.seenCR = true;
	                    }
	                    else {
	                        details.column++;
	                        details.seenCR = false;
	                    }
	                    p++;
	                }
	                peg$posDetailsCache[pos] = details;
	                return details;
	            }
	        }
	        function peg$computeLocation(startPos, endPos) {
	            var startPosDetails = peg$computePosDetails(startPos), endPosDetails = peg$computePosDetails(endPos);
	            return {
	                start: {
	                    offset: startPos,
	                    line: startPosDetails.line,
	                    column: startPosDetails.column
	                },
	                end: {
	                    offset: endPos,
	                    line: endPosDetails.line,
	                    column: endPosDetails.column
	                }
	            };
	        }
	        function peg$fail(expected) {
	            if (peg$currPos < peg$maxFailPos) {
	                return;
	            }
	            if (peg$currPos > peg$maxFailPos) {
	                peg$maxFailPos = peg$currPos;
	                peg$maxFailExpected = [];
	            }
	            peg$maxFailExpected.push(expected);
	        }
	        function peg$buildException(message, expected, found, location) {
	            function cleanupExpected(expected) {
	                var i = 1;
	                expected.sort(function (a, b) {
	                    if (a.description < b.description) {
	                        return -1;
	                    }
	                    else if (a.description > b.description) {
	                        return 1;
	                    }
	                    else {
	                        return 0;
	                    }
	                });
	                while (i < expected.length) {
	                    if (expected[i - 1] === expected[i]) {
	                        expected.splice(i, 1);
	                    }
	                    else {
	                        i++;
	                    }
	                }
	            }
	            function buildMessage(expected, found) {
	                function stringEscape(s) {
	                    function hex(ch) { return ch.charCodeAt(0).toString(16).toUpperCase(); }
	                    return s
	                        .replace(/\\/g, '\\\\')
	                        .replace(/"/g, '\\"')
	                        .replace(/\x08/g, '\\b')
	                        .replace(/\t/g, '\\t')
	                        .replace(/\n/g, '\\n')
	                        .replace(/\f/g, '\\f')
	                        .replace(/\r/g, '\\r')
	                        .replace(/[\x00-\x07\x0B\x0E\x0F]/g, function (ch) { return '\\x0' + hex(ch); })
	                        .replace(/[\x10-\x1F\x80-\xFF]/g, function (ch) { return '\\x' + hex(ch); })
	                        .replace(/[\u0100-\u0FFF]/g, function (ch) { return '\\u0' + hex(ch); })
	                        .replace(/[\u1000-\uFFFF]/g, function (ch) { return '\\u' + hex(ch); });
	                }
	                var expectedDescs = new Array(expected.length), expectedDesc, foundDesc, i;
	                for (i = 0; i < expected.length; i++) {
	                    expectedDescs[i] = expected[i].description;
	                }
	                expectedDesc = expected.length > 1
	                    ? expectedDescs.slice(0, -1).join(", ")
	                        + " or "
	                        + expectedDescs[expected.length - 1]
	                    : expectedDescs[0];
	                foundDesc = found ? "\"" + stringEscape(found) + "\"" : "end of input";
	                return "Expected " + expectedDesc + " but " + foundDesc + " found.";
	            }
	            if (expected !== null) {
	                cleanupExpected(expected);
	            }
	            return new peg$SyntaxError(message !== null ? message : buildMessage(expected, found), expected, found, location);
	        }
	        function peg$parseTerm() {
	            var s0, s1, s2, s3, s4, s5, s6, s7;
	            s0 = peg$currPos;
	            s1 = peg$parse_();
	            if (s1 !== peg$FAILED) {
	                s2 = peg$parseFactor();
	                if (s2 !== peg$FAILED) {
	                    s3 = peg$currPos;
	                    s4 = peg$parse_();
	                    if (s4 !== peg$FAILED) {
	                        if (input.charCodeAt(peg$currPos) === 124) {
	                            s5 = peg$c0;
	                            peg$currPos++;
	                        }
	                        else {
	                            s5 = peg$FAILED;
	                            if (peg$silentFails === 0) {
	                                peg$fail(peg$c1);
	                            }
	                        }
	                        if (s5 !== peg$FAILED) {
	                            s6 = peg$parse_();
	                            if (s6 !== peg$FAILED) {
	                                s7 = peg$parseTerm();
	                                if (s7 !== peg$FAILED) {
	                                    s4 = [s4, s5, s6, s7];
	                                    s3 = s4;
	                                }
	                                else {
	                                    peg$currPos = s3;
	                                    s3 = peg$FAILED;
	                                }
	                            }
	                            else {
	                                peg$currPos = s3;
	                                s3 = peg$FAILED;
	                            }
	                        }
	                        else {
	                            peg$currPos = s3;
	                            s3 = peg$FAILED;
	                        }
	                    }
	                    else {
	                        peg$currPos = s3;
	                        s3 = peg$FAILED;
	                    }
	                    if (s3 === peg$FAILED) {
	                        s3 = null;
	                    }
	                    if (s3 !== peg$FAILED) {
	                        peg$savedPos = s0;
	                        s1 = peg$c2(s2, s3);
	                        s0 = s1;
	                    }
	                    else {
	                        peg$currPos = s0;
	                        s0 = peg$FAILED;
	                    }
	                }
	                else {
	                    peg$currPos = s0;
	                    s0 = peg$FAILED;
	                }
	            }
	            else {
	                peg$currPos = s0;
	                s0 = peg$FAILED;
	            }
	            return s0;
	        }
	        function peg$parseFactor() {
	            var s0, s1, s2, s3, s4, s5, s6, s7, s8, s9;
	            s0 = peg$currPos;
	            if (input.charCodeAt(peg$currPos) === 40) {
	                s1 = peg$c3;
	                peg$currPos++;
	            }
	            else {
	                s1 = peg$FAILED;
	                if (peg$silentFails === 0) {
	                    peg$fail(peg$c4);
	                }
	            }
	            if (s1 !== peg$FAILED) {
	                s2 = peg$parse_();
	                if (s2 !== peg$FAILED) {
	                    s3 = peg$parseTerm();
	                    if (s3 !== peg$FAILED) {
	                        s4 = peg$parse_();
	                        if (s4 !== peg$FAILED) {
	                            if (input.charCodeAt(peg$currPos) === 41) {
	                                s5 = peg$c5;
	                                peg$currPos++;
	                            }
	                            else {
	                                s5 = peg$FAILED;
	                                if (peg$silentFails === 0) {
	                                    peg$fail(peg$c6);
	                                }
	                            }
	                            if (s5 !== peg$FAILED) {
	                                s6 = [];
	                                s7 = peg$currPos;
	                                s8 = peg$parse_();
	                                if (s8 !== peg$FAILED) {
	                                    if (input.substr(peg$currPos, 2) === peg$c7) {
	                                        s9 = peg$c7;
	                                        peg$currPos += 2;
	                                    }
	                                    else {
	                                        s9 = peg$FAILED;
	                                        if (peg$silentFails === 0) {
	                                            peg$fail(peg$c8);
	                                        }
	                                    }
	                                    if (s9 !== peg$FAILED) {
	                                        s8 = [s8, s9];
	                                        s7 = s8;
	                                    }
	                                    else {
	                                        peg$currPos = s7;
	                                        s7 = peg$FAILED;
	                                    }
	                                }
	                                else {
	                                    peg$currPos = s7;
	                                    s7 = peg$FAILED;
	                                }
	                                while (s7 !== peg$FAILED) {
	                                    s6.push(s7);
	                                    s7 = peg$currPos;
	                                    s8 = peg$parse_();
	                                    if (s8 !== peg$FAILED) {
	                                        if (input.substr(peg$currPos, 2) === peg$c7) {
	                                            s9 = peg$c7;
	                                            peg$currPos += 2;
	                                        }
	                                        else {
	                                            s9 = peg$FAILED;
	                                            if (peg$silentFails === 0) {
	                                                peg$fail(peg$c8);
	                                            }
	                                        }
	                                        if (s9 !== peg$FAILED) {
	                                            s8 = [s8, s9];
	                                            s7 = s8;
	                                        }
	                                        else {
	                                            peg$currPos = s7;
	                                            s7 = peg$FAILED;
	                                        }
	                                    }
	                                    else {
	                                        peg$currPos = s7;
	                                        s7 = peg$FAILED;
	                                    }
	                                }
	                                if (s6 !== peg$FAILED) {
	                                    peg$savedPos = s0;
	                                    s1 = peg$c9(s3, s6);
	                                    s0 = s1;
	                                }
	                                else {
	                                    peg$currPos = s0;
	                                    s0 = peg$FAILED;
	                                }
	                            }
	                            else {
	                                peg$currPos = s0;
	                                s0 = peg$FAILED;
	                            }
	                        }
	                        else {
	                            peg$currPos = s0;
	                            s0 = peg$FAILED;
	                        }
	                    }
	                    else {
	                        peg$currPos = s0;
	                        s0 = peg$FAILED;
	                    }
	                }
	                else {
	                    peg$currPos = s0;
	                    s0 = peg$FAILED;
	                }
	            }
	            else {
	                peg$currPos = s0;
	                s0 = peg$FAILED;
	            }
	            if (s0 === peg$FAILED) {
	                s0 = peg$parseLiteral();
	            }
	            return s0;
	        }
	        function peg$parseTypeParams() {
	            var s0, s1, s2, s3, s4;
	            s0 = peg$currPos;
	            if (input.charCodeAt(peg$currPos) === 60) {
	                s1 = peg$c10;
	                peg$currPos++;
	            }
	            else {
	                s1 = peg$FAILED;
	                if (peg$silentFails === 0) {
	                    peg$fail(peg$c11);
	                }
	            }
	            if (s1 !== peg$FAILED) {
	                s2 = peg$parseTerm();
	                if (s2 !== peg$FAILED) {
	                    s3 = [];
	                    s4 = peg$parseExtraParam();
	                    while (s4 !== peg$FAILED) {
	                        s3.push(s4);
	                        s4 = peg$parseExtraParam();
	                    }
	                    if (s3 !== peg$FAILED) {
	                        if (input.charCodeAt(peg$currPos) === 62) {
	                            s4 = peg$c12;
	                            peg$currPos++;
	                        }
	                        else {
	                            s4 = peg$FAILED;
	                            if (peg$silentFails === 0) {
	                                peg$fail(peg$c13);
	                            }
	                        }
	                        if (s4 !== peg$FAILED) {
	                            peg$savedPos = s0;
	                            s1 = peg$c14(s2, s3);
	                            s0 = s1;
	                        }
	                        else {
	                            peg$currPos = s0;
	                            s0 = peg$FAILED;
	                        }
	                    }
	                    else {
	                        peg$currPos = s0;
	                        s0 = peg$FAILED;
	                    }
	                }
	                else {
	                    peg$currPos = s0;
	                    s0 = peg$FAILED;
	                }
	            }
	            else {
	                peg$currPos = s0;
	                s0 = peg$FAILED;
	            }
	            return s0;
	        }
	        function peg$parseExtraParam() {
	            var s0, s1, s2;
	            s0 = peg$currPos;
	            if (input.charCodeAt(peg$currPos) === 44) {
	                s1 = peg$c15;
	                peg$currPos++;
	            }
	            else {
	                s1 = peg$FAILED;
	                if (peg$silentFails === 0) {
	                    peg$fail(peg$c16);
	                }
	            }
	            if (s1 !== peg$FAILED) {
	                s2 = peg$parseTerm();
	                if (s2 !== peg$FAILED) {
	                    peg$savedPos = s0;
	                    s1 = peg$c17(s2);
	                    s0 = s1;
	                }
	                else {
	                    peg$currPos = s0;
	                    s0 = peg$FAILED;
	                }
	            }
	            else {
	                peg$currPos = s0;
	                s0 = peg$FAILED;
	            }
	            return s0;
	        }
	        function peg$parseLiteral() {
	            var s0, s1, s2, s3, s4, s5;
	            peg$silentFails++;
	            s0 = peg$currPos;
	            s1 = [];
	            s2 = peg$parsechar();
	            if (s2 !== peg$FAILED) {
	                while (s2 !== peg$FAILED) {
	                    s1.push(s2);
	                    s2 = peg$parsechar();
	                }
	            }
	            else {
	                s1 = peg$FAILED;
	            }
	            if (s1 !== peg$FAILED) {
	                s2 = [];
	                s3 = peg$currPos;
	                s4 = peg$parse_();
	                if (s4 !== peg$FAILED) {
	                    if (input.substr(peg$currPos, 2) === peg$c7) {
	                        s5 = peg$c7;
	                        peg$currPos += 2;
	                    }
	                    else {
	                        s5 = peg$FAILED;
	                        if (peg$silentFails === 0) {
	                            peg$fail(peg$c8);
	                        }
	                    }
	                    if (s5 !== peg$FAILED) {
	                        s4 = [s4, s5];
	                        s3 = s4;
	                    }
	                    else {
	                        peg$currPos = s3;
	                        s3 = peg$FAILED;
	                    }
	                }
	                else {
	                    peg$currPos = s3;
	                    s3 = peg$FAILED;
	                }
	                while (s3 !== peg$FAILED) {
	                    s2.push(s3);
	                    s3 = peg$currPos;
	                    s4 = peg$parse_();
	                    if (s4 !== peg$FAILED) {
	                        if (input.substr(peg$currPos, 2) === peg$c7) {
	                            s5 = peg$c7;
	                            peg$currPos += 2;
	                        }
	                        else {
	                            s5 = peg$FAILED;
	                            if (peg$silentFails === 0) {
	                                peg$fail(peg$c8);
	                            }
	                        }
	                        if (s5 !== peg$FAILED) {
	                            s4 = [s4, s5];
	                            s3 = s4;
	                        }
	                        else {
	                            peg$currPos = s3;
	                            s3 = peg$FAILED;
	                        }
	                    }
	                    else {
	                        peg$currPos = s3;
	                        s3 = peg$FAILED;
	                    }
	                }
	                if (s2 !== peg$FAILED) {
	                    peg$savedPos = s0;
	                    s1 = peg$c19(s1, s2);
	                    s0 = s1;
	                }
	                else {
	                    peg$currPos = s0;
	                    s0 = peg$FAILED;
	                }
	            }
	            else {
	                peg$currPos = s0;
	                s0 = peg$FAILED;
	            }
	            peg$silentFails--;
	            if (s0 === peg$FAILED) {
	                s1 = peg$FAILED;
	                if (peg$silentFails === 0) {
	                    peg$fail(peg$c18);
	                }
	            }
	            return s0;
	        }
	        function peg$parse_() {
	            var s0, s1;
	            peg$silentFails++;
	            s0 = [];
	            if (peg$c21.test(input.charAt(peg$currPos))) {
	                s1 = input.charAt(peg$currPos);
	                peg$currPos++;
	            }
	            else {
	                s1 = peg$FAILED;
	                if (peg$silentFails === 0) {
	                    peg$fail(peg$c22);
	                }
	            }
	            while (s1 !== peg$FAILED) {
	                s0.push(s1);
	                if (peg$c21.test(input.charAt(peg$currPos))) {
	                    s1 = input.charAt(peg$currPos);
	                    peg$currPos++;
	                }
	                else {
	                    s1 = peg$FAILED;
	                    if (peg$silentFails === 0) {
	                        peg$fail(peg$c22);
	                    }
	                }
	            }
	            peg$silentFails--;
	            if (s0 === peg$FAILED) {
	                s1 = peg$FAILED;
	                if (peg$silentFails === 0) {
	                    peg$fail(peg$c20);
	                }
	            }
	            return s0;
	        }
	        function peg$parsechar() {
	            var s0;
	            if (peg$c23.test(input.charAt(peg$currPos))) {
	                s0 = input.charAt(peg$currPos);
	                peg$currPos++;
	            }
	            else {
	                s0 = peg$FAILED;
	                if (peg$silentFails === 0) {
	                    peg$fail(peg$c24);
	                }
	            }
	            if (s0 === peg$FAILED) {
	                if (input.charCodeAt(peg$currPos) === 95) {
	                    s0 = peg$c25;
	                    peg$currPos++;
	                }
	                else {
	                    s0 = peg$FAILED;
	                    if (peg$silentFails === 0) {
	                        peg$fail(peg$c26);
	                    }
	                }
	                if (s0 === peg$FAILED) {
	                    if (input.charCodeAt(peg$currPos) === 45) {
	                        s0 = peg$c27;
	                        peg$currPos++;
	                    }
	                    else {
	                        s0 = peg$FAILED;
	                        if (peg$silentFails === 0) {
	                            peg$fail(peg$c28);
	                        }
	                    }
	                    if (s0 === peg$FAILED) {
	                        if (input.charCodeAt(peg$currPos) === 46) {
	                            s0 = peg$c29;
	                            peg$currPos++;
	                        }
	                        else {
	                            s0 = peg$FAILED;
	                            if (peg$silentFails === 0) {
	                                peg$fail(peg$c30);
	                            }
	                        }
	                        if (s0 === peg$FAILED) {
	                            if (peg$c31.test(input.charAt(peg$currPos))) {
	                                s0 = input.charAt(peg$currPos);
	                                peg$currPos++;
	                            }
	                            else {
	                                s0 = peg$FAILED;
	                                if (peg$silentFails === 0) {
	                                    peg$fail(peg$c32);
	                                }
	                            }
	                            if (s0 === peg$FAILED) {
	                                if (peg$c33.test(input.charAt(peg$currPos))) {
	                                    s0 = input.charAt(peg$currPos);
	                                    peg$currPos++;
	                                }
	                                else {
	                                    s0 = peg$FAILED;
	                                    if (peg$silentFails === 0) {
	                                        peg$fail(peg$c34);
	                                    }
	                                }
	                                if (s0 === peg$FAILED) {
	                                    if (input.charCodeAt(peg$currPos) === 63) {
	                                        s0 = peg$c35;
	                                        peg$currPos++;
	                                    }
	                                    else {
	                                        s0 = peg$FAILED;
	                                        if (peg$silentFails === 0) {
	                                            peg$fail(peg$c36);
	                                        }
	                                    }
	                                }
	                            }
	                        }
	                    }
	                }
	            }
	            return s0;
	        }
	        peg$result = peg$startRuleFunction();
	        if (peg$result !== peg$FAILED && peg$currPos === input.length) {
	            return peg$result;
	        }
	        else {
	            if (peg$result !== peg$FAILED && peg$currPos < input.length) {
	                peg$fail({ type: "end", description: "end of input" });
	            }
	            throw peg$buildException(null, peg$maxFailExpected, peg$maxFailPos < input.length ? input.charAt(peg$maxFailPos) : null, peg$maxFailPos < input.length
	                ? peg$computeLocation(peg$maxFailPos, peg$maxFailPos + 1)
	                : peg$computeLocation(peg$maxFailPos, peg$maxFailPos));
	        }
	    }
	    return {
	        SyntaxError: peg$SyntaxError,
	        parse: peg$parse
	    };
	})();
	module.exports = parser;
	//# sourceMappingURL=typeExpressionParser.js.map

/***/ },
/* 168 */
/***/ function(module, exports, __webpack_require__) {

	/* (ignored) */

/***/ },
/* 169 */
/***/ function(module, exports, __webpack_require__) {

	module.exports = function(module) {
		if(!module.webpackPolyfill) {
			module.deprecate = function() {};
			module.paths = [];
			// module.parent = undefined by default
			module.children = [];
			module.webpackPolyfill = 1;
		}
		return module;
	}


/***/ },
/* 170 */
/***/ function(module, exports, __webpack_require__) {

	var lookup = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';

	;(function (exports) {
		'use strict';

	  var Arr = (typeof Uint8Array !== 'undefined')
	    ? Uint8Array
	    : Array

		var PLUS   = '+'.charCodeAt(0)
		var SLASH  = '/'.charCodeAt(0)
		var NUMBER = '0'.charCodeAt(0)
		var LOWER  = 'a'.charCodeAt(0)
		var UPPER  = 'A'.charCodeAt(0)
		var PLUS_URL_SAFE = '-'.charCodeAt(0)
		var SLASH_URL_SAFE = '_'.charCodeAt(0)

		function decode (elt) {
			var code = elt.charCodeAt(0)
			if (code === PLUS ||
			    code === PLUS_URL_SAFE)
				return 62 // '+'
			if (code === SLASH ||
			    code === SLASH_URL_SAFE)
				return 63 // '/'
			if (code < NUMBER)
				return -1 //no match
			if (code < NUMBER + 10)
				return code - NUMBER + 26 + 26
			if (code < UPPER + 26)
				return code - UPPER
			if (code < LOWER + 26)
				return code - LOWER + 26
		}

		function b64ToByteArray (b64) {
			var i, j, l, tmp, placeHolders, arr

			if (b64.length % 4 > 0) {
				throw new Error('Invalid string. Length must be a multiple of 4')
			}

			// the number of equal signs (place holders)
			// if there are two placeholders, than the two characters before it
			// represent one byte
			// if there is only one, then the three characters before it represent 2 bytes
			// this is just a cheap hack to not do indexOf twice
			var len = b64.length
			placeHolders = '=' === b64.charAt(len - 2) ? 2 : '=' === b64.charAt(len - 1) ? 1 : 0

			// base64 is 4/3 + up to two characters of the original data
			arr = new Arr(b64.length * 3 / 4 - placeHolders)

			// if there are placeholders, only get up to the last complete 4 chars
			l = placeHolders > 0 ? b64.length - 4 : b64.length

			var L = 0

			function push (v) {
				arr[L++] = v
			}

			for (i = 0, j = 0; i < l; i += 4, j += 3) {
				tmp = (decode(b64.charAt(i)) << 18) | (decode(b64.charAt(i + 1)) << 12) | (decode(b64.charAt(i + 2)) << 6) | decode(b64.charAt(i + 3))
				push((tmp & 0xFF0000) >> 16)
				push((tmp & 0xFF00) >> 8)
				push(tmp & 0xFF)
			}

			if (placeHolders === 2) {
				tmp = (decode(b64.charAt(i)) << 2) | (decode(b64.charAt(i + 1)) >> 4)
				push(tmp & 0xFF)
			} else if (placeHolders === 1) {
				tmp = (decode(b64.charAt(i)) << 10) | (decode(b64.charAt(i + 1)) << 4) | (decode(b64.charAt(i + 2)) >> 2)
				push((tmp >> 8) & 0xFF)
				push(tmp & 0xFF)
			}

			return arr
		}

		function uint8ToBase64 (uint8) {
			var i,
				extraBytes = uint8.length % 3, // if we have 1 byte left, pad 2 bytes
				output = "",
				temp, length

			function encode (num) {
				return lookup.charAt(num)
			}

			function tripletToBase64 (num) {
				return encode(num >> 18 & 0x3F) + encode(num >> 12 & 0x3F) + encode(num >> 6 & 0x3F) + encode(num & 0x3F)
			}

			// go through the array every three bytes, we'll deal with trailing stuff later
			for (i = 0, length = uint8.length - extraBytes; i < length; i += 3) {
				temp = (uint8[i] << 16) + (uint8[i + 1] << 8) + (uint8[i + 2])
				output += tripletToBase64(temp)
			}

			// pad the end with zeros, but make sure to not forget the extra bytes
			switch (extraBytes) {
				case 1:
					temp = uint8[uint8.length - 1]
					output += encode(temp >> 2)
					output += encode((temp << 4) & 0x3F)
					output += '=='
					break
				case 2:
					temp = (uint8[uint8.length - 2] << 8) + (uint8[uint8.length - 1])
					output += encode(temp >> 10)
					output += encode((temp >> 4) & 0x3F)
					output += encode((temp << 2) & 0x3F)
					output += '='
					break
			}

			return output
		}

		exports.toByteArray = b64ToByteArray
		exports.fromByteArray = uint8ToBase64
	}(typeof exports === 'undefined' ? (this.base64js = {}) : exports))


/***/ },
/* 171 */
/***/ function(module, exports, __webpack_require__) {

	module.exports = [
		{
			"code": "1xx",
			"phrase": "**Informational**",
			"description": "\"indicates an interim response for communicating connection status or request progress prior to completing the requested action and sending a final response.\" ~ [sure](http://www.urbandictionary.com/define.php?term=sure)",
			"spec_title": "RFC7231#6.2",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.2"
		},
		{
			"code": "100",
			"phrase": "Continue",
			"description": "\"indicates that the initial part of a request has been received and has not yet been rejected by the server.\"",
			"spec_title": "RFC7231#6.2.1",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.2.1"
		},
		{
			"code": "101",
			"phrase": "Switching Protocols",
			"description": "\"indicates that the server understands and is willing to comply with the client's request, via the Upgrade header field, for a change in the application protocol being used on this connection.\"",
			"spec_title": "RFC7231#6.2.2",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.2.2"
		},
		{
			"code": "2xx",
			"phrase": "**Successful**",
			"description": "\"indicates that the client's request was successfully received, understood, and accepted.\" ~ [cool](https://twitter.com/DanaDanger/status/183316183494311936)",
			"spec_title": "RFC7231#6.3",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.3"
		},
		{
			"code": "200",
			"phrase": "OK",
			"description": "\"indicates that the request has succeeded.\"",
			"spec_title": "RFC7231#6.3.1",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.3.1"
		},
		{
			"code": "201",
			"phrase": "Created",
			"description": "\"indicates that the request has been fulfilled and has resulted in one or more new resources being created.\"",
			"spec_title": "RFC7231#6.3.2",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.3.2"
		},
		{
			"code": "202",
			"phrase": "Accepted",
			"description": "\"indicates that the request has been accepted for processing, but the processing has not been completed.\"",
			"spec_title": "RFC7231#6.3.3",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.3.3"
		},
		{
			"code": "203",
			"phrase": "Non-Authoritative Information",
			"description": "\"indicates that the request was successful but the enclosed payload has been modified from that of the origin server's 200 (OK) response by a transforming proxy.\"",
			"spec_title": "RFC7231#6.3.4",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.3.4"
		},
		{
			"code": "204",
			"phrase": "No Content",
			"description": "\"indicates that the server has successfully fulfilled the request and that there is no additional content to send in the response payload body.\"",
			"spec_title": "RFC7231#6.3.5",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.3.5"
		},
		{
			"code": "205",
			"phrase": "Reset Content",
			"description": "\"indicates that the server has fulfilled the request and desires that the user agent reset the \"document view\", which caused the request to be sent, to its original state as received from the origin server.\"",
			"spec_title": "RFC7231#6.3.6",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.3.6"
		},
		{
			"code": "206",
			"phrase": "Partial Content",
			"description": "\"indicates that the server is successfully fulfilling a range request for the target resource by transferring one or more parts of the selected representation that correspond to the satisfiable ranges found in the requests's Range header field.\"",
			"spec_title": "RFC7233#4.1",
			"spec_href": "http://tools.ietf.org/html/rfc7233#section-4.1"
		},
		{
			"code": "3xx",
			"phrase": "**Redirection**",
			"description": "\"indicates that further action needs to be taken by the user agent in order to fulfill the request.\" ~ [ask that dude over there](https://twitter.com/DanaDanger/status/183316183494311936)",
			"spec_title": "RFC7231#6.4",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.4"
		},
		{
			"code": "300",
			"phrase": "Multiple Choices",
			"description": "\"indicates that the target resource has more than one representation, each with its own more specific identifier, and information about the alternatives is being provided so that the user (or user agent) can select a preferred representation by redirecting its request to one or more of those identifiers.\"",
			"spec_title": "RFC7231#6.4.1",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.4.1"
		},
		{
			"code": "301",
			"phrase": "Moved Permanently",
			"description": "\"indicates that the target resource has been assigned a new permanent URI and any future references to this resource ought to use one of the enclosed URIs.\"",
			"spec_title": "RFC7231#6.4.2",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.4.2"
		},
		{
			"code": "302",
			"phrase": "Found",
			"description": "\"indicates that the target resource resides temporarily under a different URI.\"",
			"spec_title": "RFC7231#6.4.3",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.4.3"
		},
		{
			"code": "303",
			"phrase": "See Other",
			"description": "\"indicates that the server is redirecting the user agent to a different resource, as indicated by a URI in the Location header field, that is intended to provide an indirect response to the original request.\"",
			"spec_title": "RFC7231#6.4.4",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.4.4"
		},
		{
			"code": "304",
			"phrase": "Not Modified",
			"description": "\"indicates that a conditional GET request has been received and would have resulted in a 200 (OK) response if it were not for the fact that the condition has evaluated to false.\"",
			"spec_title": "RFC7232#4.1",
			"spec_href": "http://tools.ietf.org/html/rfc7232#section-4.1"
		},
		{
			"code": "305",
			"phrase": "Use Proxy",
			"description": "*deprecated*",
			"spec_title": "RFC7231#6.4.5",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.4.5"
		},
		{
			"code": "307",
			"phrase": "Temporary Redirect",
			"description": "\"indicates that the target resource resides temporarily under a different URI and the user agent MUST NOT change the request method if it performs an automatic redirection to that URI.\"",
			"spec_title": "RFC7231#6.4.7",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.4.7"
		},
		{
			"code": "4xx",
			"phrase": "**Client Error**",
			"description": "\"indicates that the client seems to have erred.\" ~ [*you* fucked up](https://twitter.com/DanaDanger/status/183316183494311936)",
			"spec_title": "RFC7231#6.5",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.5"
		},
		{
			"code": "400",
			"phrase": "Bad Request",
			"description": "\"indicates that the server cannot or will not process the request because the received syntax is invalid, nonsensical, or exceeds some limitation on what the server is willing to process.\"",
			"spec_title": "RFC7231#6.5.1",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.5.1"
		},
		{
			"code": "401",
			"phrase": "Unauthorized",
			"description": "\"indicates that the request has not been applied because it lacks valid authentication credentials for the target resource.\"",
			"spec_title": "RFC7235#6.3.1",
			"spec_href": "http://tools.ietf.org/html/rfc7235#section-3.1"
		},
		{
			"code": "402",
			"phrase": "Payment Required",
			"description": "*reserved*",
			"spec_title": "RFC7231#6.5.2",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.5.2"
		},
		{
			"code": "403",
			"phrase": "Forbidden",
			"description": "\"indicates that the server understood the request but refuses to authorize it.\"",
			"spec_title": "RFC7231#6.5.3",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.5.3"
		},
		{
			"code": "404",
			"phrase": "Not Found",
			"description": "\"indicates that the origin server did not find a current representation for the target resource or is not willing to disclose that one exists.\"",
			"spec_title": "RFC7231#6.5.4",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.5.4"
		},
		{
			"code": "405",
			"phrase": "Method Not Allowed",
			"description": "\"indicates that the method specified in the request-line is known by the origin server but not supported by the target resource.\"",
			"spec_title": "RFC7231#6.5.5",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.5.5"
		},
		{
			"code": "406",
			"phrase": "Not Acceptable",
			"description": "\"indicates that the target resource does not have a current representation that would be acceptable to the user agent, according to the proactive negotiation header fields received in the request, and the server is unwilling to supply a default representation.\"",
			"spec_title": "RFC7231#6.5.6",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.5.6"
		},
		{
			"code": "407",
			"phrase": "Proxy Authentication Required",
			"description": "\"is similar to 401 (Unauthorized), but indicates that the client needs to authenticate itself in order to use a proxy.\"",
			"spec_title": "RFC7231#6.3.2",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.3.2"
		},
		{
			"code": "408",
			"phrase": "Request Timeout",
			"description": "\"indicates that the server did not receive a complete request message within the time that it was prepared to wait.\"",
			"spec_title": "RFC7231#6.5.7",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.5.7"
		},
		{
			"code": "409",
			"phrase": "Conflict",
			"description": "\"indicates that the request could not be completed due to a conflict with the current state of the resource.\"",
			"spec_title": "RFC7231#6.5.8",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.5.8"
		},
		{
			"code": "410",
			"phrase": "Gone",
			"description": "\"indicates that access to the target resource is no longer available at the origin server and that this condition is likely to be permanent.\"",
			"spec_title": "RFC7231#6.5.9",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.5.9"
		},
		{
			"code": "411",
			"phrase": "Length Required",
			"description": "\"indicates that the server refuses to accept the request without a defined Content-Length.\"",
			"spec_title": "RFC7231#6.5.10",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.5.10"
		},
		{
			"code": "412",
			"phrase": "Precondition Failed",
			"description": "\"indicates that one or more preconditions given in the request header fields evaluated to false when tested on the server.\"",
			"spec_title": "RFC7232#4.2",
			"spec_href": "http://tools.ietf.org/html/rfc7232#section-4.2"
		},
		{
			"code": "413",
			"phrase": "Payload Too Large",
			"description": "\"indicates that the server is refusing to process a request because the request payload is larger than the server is willing or able to process.\"",
			"spec_title": "RFC7231#6.5.11",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.5.11"
		},
		{
			"code": "414",
			"phrase": "URI Too Long",
			"description": "\"indicates that the server is refusing to service the request because the request-target is longer than the server is willing to interpret.\"",
			"spec_title": "RFC7231#6.5.12",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.5.12"
		},
		{
			"code": "415",
			"phrase": "Unsupported Media Type",
			"description": "\"indicates that the origin server is refusing to service the request because the payload is in a format not supported by the target resource for this method.\"",
			"spec_title": "RFC7231#6.5.13",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.5.13"
		},
		{
			"code": "416",
			"phrase": "Range Not Satisfiable",
			"description": "\"indicates that none of the ranges in the request's Range header field overlap the current extent of the selected resource or that the set of ranges requested has been rejected due to invalid ranges or an excessive request of small or overlapping ranges.\"",
			"spec_title": "RFC7233#4.4",
			"spec_href": "http://tools.ietf.org/html/rfc7233#section-4.4"
		},
		{
			"code": "417",
			"phrase": "Expectation Failed",
			"description": "\"indicates that the expectation given in the request's Expect header field could not be met by at least one of the inbound servers.\"",
			"spec_title": "RFC7231#6.5.14",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.5.14"
		},
		{
			"code": "426",
			"phrase": "Upgrade Required",
			"description": "\"indicates that the server refuses to perform the request using the current protocol but might be willing to do so after the client upgrades to a different protocol.\"",
			"spec_title": "RFC7231#6.5.15",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.5.15"
		},
		{
			"code": "5xx",
			"phrase": "**Server Error**",
			"description": "\"indicates that the server is aware that it has erred or is incapable of performing the requested method.\" ~ [*we* fucked up](https://twitter.com/DanaDanger/status/183316183494311936)",
			"spec_title": "RFC7231#6.6",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.6"
		},
		{
			"code": "500",
			"phrase": "Internal Server Error",
			"description": "\"indicates that the server encountered an unexpected condition that prevented it from fulfilling the request.\"",
			"spec_title": "RFC7231#6.6.1",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.6.1"
		},
		{
			"code": "501",
			"phrase": "Not Implemented",
			"description": "\"indicates that the server does not support the functionality required to fulfill the request.\"",
			"spec_title": "RFC7231#6.6.2",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.6.2"
		},
		{
			"code": "502",
			"phrase": "Bad Gateway",
			"description": "\"indicates that the server, while acting as a gateway or proxy, received an invalid response from an inbound server it accessed while attempting to fulfill the request.\"",
			"spec_title": "RFC7231#6.6.3",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.6.3"
		},
		{
			"code": "503",
			"phrase": "Service Unavailable",
			"description": "\"indicates that the server is currently unable to handle the request due to a temporary overload or scheduled maintenance, which will likely be alleviated after some delay.\"",
			"spec_title": "RFC7231#6.6.4",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.6.4"
		},
		{
			"code": "504",
			"phrase": "Gateway Time-out",
			"description": "\"indicates that the server, while acting as a gateway or proxy, did not receive a timely response from an upstream server it needed to access in order to complete the request.\"",
			"spec_title": "RFC7231#6.6.5",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.6.5"
		},
		{
			"code": "505",
			"phrase": "HTTP Version Not Supported",
			"description": "\"indicates that the server does not support, or refuses to support, the protocol version that was used in the request message.\"",
			"spec_title": "RFC7231#6.6.6",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-6.6.6"
		},
		{
			"code": "102",
			"phrase": "Processing",
			"description": "\"is an interim response used to inform the client that the server has accepted the complete request, but has not yet completed it.\"",
			"spec_title": "RFC5218#10.1",
			"spec_href": "http://tools.ietf.org/html/rfc2518#section-10.1"
		},
		{
			"code": "207",
			"phrase": "Multi-Status",
			"description": "\"provides status for multiple independent operations.\"",
			"spec_title": "RFC5218#10.2",
			"spec_href": "http://tools.ietf.org/html/rfc2518#section-10.2"
		},
		{
			"code": "226",
			"phrase": "IM Used",
			"description": "\"The server has fulfilled a GET request for the resource, and the response is a representation of the result of one or more instance-manipulations applied to the current instance.\"",
			"spec_title": "RFC3229#10.4.1",
			"spec_href": "http://tools.ietf.org/html/rfc3229#section-10.4.1"
		},
		{
			"code": "308",
			"phrase": "Permanent Redirect",
			"description": "\"The target resource has been assigned a new permanent URI and any future references to this resource SHOULD use one of the returned URIs. [...] This status code is similar to 301 Moved Permanently (Section 7.3.2 of rfc7231), except that it does not allow rewriting the request method from POST to GET.\"",
			"spec_title": "RFC7238",
			"spec_href": "http://tools.ietf.org/html/rfc7238"
		},
		{
			"code": "422",
			"phrase": "Unprocessable Entity",
			"description": "\"means the server understands the content type of the request entity (hence a 415(Unsupported Media Type) status code is inappropriate), and the syntax of the request entity is correct (thus a 400 (Bad Request) status code is inappropriate) but was unable to process the contained instructions.\"",
			"spec_title": "RFC5218#10.3",
			"spec_href": "http://tools.ietf.org/html/rfc2518#section-10.3"
		},
		{
			"code": "423",
			"phrase": "Locked",
			"description": "\"means the source or destination resource of a method is locked.\"",
			"spec_title": "RFC5218#10.4",
			"spec_href": "http://tools.ietf.org/html/rfc2518#section-10.4"
		},
		{
			"code": "424",
			"phrase": "Failed Dependency",
			"description": "\"means that the method could not be performed on the resource because the requested action depended on another action and that action failed.\"",
			"spec_title": "RFC5218#10.5",
			"spec_href": "http://tools.ietf.org/html/rfc2518#section-10.5"
		},
		{
			"code": "428",
			"phrase": "Precondition Required",
			"description": "\"indicates that the origin server requires the request to be conditional.\"",
			"spec_title": "RFC6585#3",
			"spec_href": "http://tools.ietf.org/html/rfc6585#section-3"
		},
		{
			"code": "429",
			"phrase": "Too Many Requests",
			"description": "\"indicates that the user has sent too many requests in a given amount of time (\"rate limiting\").\"",
			"spec_title": "RFC6585#4",
			"spec_href": "http://tools.ietf.org/html/rfc6585#section-4"
		},
		{
			"code": "431",
			"phrase": "Request Header Fields Too Large",
			"description": "\"indicates that the server is unwilling to process the request because its header fields are too large.\"",
			"spec_title": "RFC6585#5",
			"spec_href": "http://tools.ietf.org/html/rfc6585#section-5"
		},
		{
			"code": "451",
			"phrase": "Unavailable For Legal Reasons",
			"description": "\"This status code indicates that the server is denying access to the resource in response to a legal demand.\"",
			"spec_title": "draft-tbray-http-legally-restricted-status",
			"spec_href": "http://tools.ietf.org/html/draft-tbray-http-legally-restricted-status"
		},
		{
			"code": "506",
			"phrase": "Variant Also Negotiates",
			"description": "\"indicates that the server has an internal configuration error: the chosen variant resource is configured to engage in transparent content negotiation itself, and is therefore not a proper end point in the negotiation process.\"",
			"spec_title": "RFC2295#8.1",
			"spec_href": "http://tools.ietf.org/html/rfc2295#section-8.1"
		},
		{
			"code": "507",
			"phrase": "Insufficient Storage",
			"description": "\"means the method could not be performed on the resource because the server is unable to store the representation needed to successfully complete the request.\"",
			"spec_title": "RFC5218#10.6",
			"spec_href": "http://tools.ietf.org/html/rfc2518#section-10.6"
		},
		{
			"code": "511",
			"phrase": "Network Authentication Required",
			"description": "\"indicates that the client needs to authenticate to gain network access.\"",
			"spec_title": "RFC6585#6",
			"spec_href": "http://tools.ietf.org/html/rfc6585#section-6"
		},
		{
			"code": "7xx",
			"phrase": "**Developer Error**",
			"description": "[err](http://www.urbandictionary.com/define.php?term=err)",
			"spec_title": "7xx-rfc",
			"spec_href": "http://documentup.com/joho/7XX-rfc"
		}
	];

/***/ },
/* 172 */
/***/ function(module, exports, __webpack_require__) {

	module.exports = [
		{
			"method": "CONNECT",
			"description": "\"requests that the recipient establish a tunnel to the destination origin server identified by the request-target and, if successful, thereafter restrict its behavior to blind forwarding of packets, in both directions, until the connection is closed.\"",
			"safe": true,
			"idempotent": true,
			"cacheable": false,
			"spec_title": "RFC7231#4.3.6",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-4.3.6"
		},
		{
			"method": "DELETE",
			"description": "\"requests that the origin server remove the association between the target resource and its current functionality.\"",
			"safe": false,
			"idempotent": true,
			"cacheable": false,
			"spec_title": "RFC7231#4.3.5",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-4.3.5"
		},
		{
			"method": "GET",
			"description": "\"requests transfer of a current selected representation for the target resource.\"",
			"safe": true,
			"idempotent": true,
			"cacheable": true,
			"spec_title": "RFC7231#4.3.1",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-4.3.1"
		},
		{
			"method": "HEAD",
			"description": "\"is identical to GET except that the server MUST NOT send a message body in the response (i.e., the response terminates at the end of the header block).\"",
			"safe": true,
			"idempotent": true,
			"cacheable": true,
			"spec_title": "RFC7231#4.3.2",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-4.3.2"
		},
		{
			"method": "OPTIONS",
			"description": "\"requests information about the communication options available on the request/response chain identified by the effective request URI.\"",
			"safe": true,
			"idempotent": true,
			"cacheable": false,
			"spec_title": "RFC7231#4.3.7",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-4.3.7"
		},
		{
			"method": "POST",
			"description": "\"requests that the target resource process the representation enclosed in the request according to the resource's own specific semantics.\"",
			"safe": false,
			"idempotent": false,
			"cacheable": false,
			"spec_title": "RFC7231#4.3.3",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-4.3.3"
		},
		{
			"method": "PUT",
			"description": "\"requests that the state of the target resource be created or replaced with the state defined by the representation enclosed in the request message payload.\"",
			"safe": false,
			"idempotent": true,
			"cacheable": false,
			"spec_title": "RFC7231#4.3.4",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-4.3.4"
		},
		{
			"method": "TRACE",
			"description": "\"is used to invoke a remote, application-layer loopback of the request message.\"",
			"safe": true,
			"idempotent": true,
			"cacheable": false,
			"spec_title": "RFC7231#4.3.8",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-4.3.8"
		},
		{
			"method": "ACL",
			"description": "",
			"safe": false,
			"idempotent": true,
			"cacheable": "",
			"spec_title": "RFC3744#8.1",
			"spec_href": "http://tools.ietf.org/html/rfc3744#section-8.1"
		},
		{
			"method": "BASELINE-CONTROL",
			"description": "",
			"safe": false,
			"idempotent": true,
			"cacheable": "",
			"spec_title": "RFC3253#12.6",
			"spec_href": "http://tools.ietf.org/html/rfc3253#section-12.6"
		},
		{
			"method": "BIND",
			"description": "",
			"safe": false,
			"idempotent": true,
			"cacheable": "",
			"spec_title": "RFC5842#4",
			"spec_href": "http://tools.ietf.org/html/rfc5842#section-4"
		},
		{
			"method": "CHECKIN",
			"description": "",
			"safe": false,
			"idempotent": true,
			"cacheable": "",
			"spec_title": "RFC3253#4.4",
			"spec_href": "http://tools.ietf.org/html/rfc3253#section-4.4"
		},
		{
			"method": "CHECKOUT",
			"description": "",
			"safe": false,
			"idempotent": true,
			"cacheable": "",
			"spec_title": "RFC3253#4.3",
			"spec_href": "http://tools.ietf.org/html/rfc3253#section-4.3"
		},
		{
			"method": "COPY",
			"description": "",
			"safe": false,
			"idempotent": true,
			"cacheable": "",
			"spec_title": "RFC4918#9.8",
			"spec_href": "http://tools.ietf.org/html/rfc4918#section-9.8"
		},
		{
			"method": "LABEL",
			"description": "",
			"safe": false,
			"idempotent": true,
			"cacheable": "",
			"spec_title": "RFC3253#8.2",
			"spec_href": "http://tools.ietf.org/html/rfc3253#section-8.2"
		},
		{
			"method": "LINK",
			"description": "",
			"safe": false,
			"idempotent": true,
			"cacheable": "",
			"spec_title": "RFC2068#19.6.1.2",
			"spec_href": "http://tools.ietf.org/html/rfc2068#section-19.6.1.2"
		},
		{
			"method": "LOCK",
			"description": "",
			"safe": false,
			"idempotent": false,
			"cacheable": "",
			"spec_title": "RFC4918#9.10",
			"spec_href": "http://tools.ietf.org/html/rfc4918#section-9.10"
		},
		{
			"method": "MERGE",
			"description": "",
			"safe": false,
			"idempotent": true,
			"cacheable": "",
			"spec_title": "RFC3253#11.2",
			"spec_href": "http://tools.ietf.org/html/rfc3253#section-11.2"
		},
		{
			"method": "MKACTIVITY",
			"description": "",
			"safe": false,
			"idempotent": true,
			"cacheable": "",
			"spec_title": "RFC3253#13.5",
			"spec_href": "http://tools.ietf.org/html/rfc3253#section-13.5"
		},
		{
			"method": "MKCALENDAR",
			"description": "",
			"safe": false,
			"idempotent": true,
			"cacheable": "",
			"spec_title": "RFC4791#5.3.1",
			"spec_href": "http://tools.ietf.org/html/rfc4791#section-5.3.1"
		},
		{
			"method": "MKCOL",
			"description": "",
			"safe": false,
			"idempotent": true,
			"cacheable": "",
			"spec_title": "RFC4918#9.3",
			"spec_href": "http://tools.ietf.org/html/rfc4918#section-9.3"
		},
		{
			"method": "MKREDIRECTREF",
			"description": "",
			"safe": false,
			"idempotent": true,
			"cacheable": "",
			"spec_title": "RFC4437#6",
			"spec_href": "http://tools.ietf.org/html/rfc4437#section-6"
		},
		{
			"method": "MKWORKSPACE",
			"description": "",
			"safe": false,
			"idempotent": true,
			"cacheable": "",
			"spec_title": "RFC3253#6.3",
			"spec_href": "http://tools.ietf.org/html/rfc3253#section-6.3"
		},
		{
			"method": "MOVE",
			"description": "",
			"safe": false,
			"idempotent": true,
			"cacheable": "",
			"spec_title": "RFC4918#9.9",
			"spec_href": "http://tools.ietf.org/html/rfc4918#section-9.9"
		},
		{
			"method": "ORDERPATCH",
			"description": "",
			"safe": false,
			"idempotent": true,
			"cacheable": "",
			"spec_title": "RFC3648#7",
			"spec_href": "http://tools.ietf.org/html/rfc3648#section-7"
		},
		{
			"method": "PATCH",
			"description": "\"requests that a set of changes described in the request entity be applied to the resource identified by the Request-URI.\"",
			"safe": false,
			"idempotent": false,
			"cacheable": false,
			"spec_title": "RFC5789",
			"spec_href": "http://tools.ietf.org/html/rfc5789#section-2"
		},
		{
			"method": "PROPFIND",
			"description": "",
			"safe": true,
			"idempotent": true,
			"cacheable": "",
			"spec_title": "RFC4918#9.1",
			"spec_href": "http://tools.ietf.org/html/rfc4918#section-9.1"
		},
		{
			"method": "PROPPATCH",
			"description": "",
			"safe": false,
			"idempotent": true,
			"cacheable": "",
			"spec_title": "RFC4918#9.2",
			"spec_href": "http://tools.ietf.org/html/rfc4918#section-9.2"
		},
		{
			"method": "REBIND",
			"description": "",
			"safe": false,
			"idempotent": true,
			"cacheable": "",
			"spec_title": "RFC5842#6",
			"spec_href": "http://tools.ietf.org/html/rfc5842#section-6"
		},
		{
			"method": "REPORT",
			"description": "",
			"safe": true,
			"idempotent": true,
			"cacheable": "",
			"spec_title": "RFC3253#3.6",
			"spec_href": "http://tools.ietf.org/html/rfc3253#section-3.6"
		},
		{
			"method": "SEARCH",
			"description": "",
			"safe": true,
			"idempotent": true,
			"cacheable": "",
			"spec_title": "RFC5323#2",
			"spec_href": "http://tools.ietf.org/html/rfc5323#section-2"
		},
		{
			"method": "UNBIND",
			"description": "",
			"safe": false,
			"idempotent": true,
			"cacheable": "",
			"spec_title": "RFC5842#5",
			"spec_href": "http://tools.ietf.org/html/rfc5842#section-5"
		},
		{
			"method": "UNCHECKOUT",
			"description": "",
			"safe": false,
			"idempotent": true,
			"cacheable": "",
			"spec_title": "RFC3253#4.5",
			"spec_href": "http://tools.ietf.org/html/rfc3253#section-4.5"
		},
		{
			"method": "UNLINK",
			"description": "",
			"safe": false,
			"idempotent": true,
			"cacheable": "",
			"spec_title": "RFC2068#19.6.1.3",
			"spec_href": "http://tools.ietf.org/html/rfc2068#section-19.6.1.3"
		},
		{
			"method": "UNLOCK",
			"description": "",
			"safe": false,
			"idempotent": true,
			"cacheable": "",
			"spec_title": "RFC4918#9.11",
			"spec_href": "http://tools.ietf.org/html/rfc4918#section-9.11"
		},
		{
			"method": "UPDATE",
			"description": "",
			"safe": false,
			"idempotent": true,
			"cacheable": "",
			"spec_title": "RFC3253#7.1",
			"spec_href": "http://tools.ietf.org/html/rfc3253#section-7.1"
		},
		{
			"method": "UPDATEREDIRECTREF",
			"description": "",
			"safe": false,
			"idempotent": true,
			"cacheable": "",
			"spec_title": "RFC4437#7",
			"spec_href": "http://tools.ietf.org/html/rfc4437#section-7"
		},
		{
			"method": "VERSION-CONTROL",
			"description": "",
			"safe": false,
			"idempotent": true,
			"cacheable": "",
			"spec_title": "RFC3253#3.5",
			"spec_href": "http://tools.ietf.org/html/rfc3253#section-3.5"
		}
	];

/***/ },
/* 173 */
/***/ function(module, exports, __webpack_require__) {

	module.exports = [
		{
			"header": "Content-Encoding",
			"description": "\"indicates what content codings have been applied to the representation, beyond those inherent in the media type, and thus what decoding mechanisms have to be applied in order to obtain data in the media type referenced by the Content-Type header field.\"",
			"spec_title": "RFC7231#3.1.2.2",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-3.1.2.2"
		},
		{
			"header": "Content-Language",
			"description": "\"describes the natural language(s) of the intended audience for the representation.\"",
			"spec_title": "RFC7231#3.1.3.2",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-3.1.3.2"
		},
		{
			"header": "Content-Location",
			"description": "\"references a URI that can be used as an identifier for a specific resource corresponding to the representation in this message's payload.\"",
			"spec_title": "RFC7231#3.1.4.2",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-3.1.4.2"
		},
		{
			"header": "Content-Type",
			"description": "\"indicates the media type of the associated representation: either the representation enclosed in the message payload or the selected representation, as determined by the message semantics.\"",
			"spec_title": "RFC7231#3.1.1.5",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-3.1.1.5"
		},
		{
			"header": "Content-Length",
			"description": "\"can provide the anticipated size, as a decimal number of octets, for a potential payload body.\"",
			"spec_title": "RFC7230#3.3.2",
			"spec_href": "http://tools.ietf.org/html/rfc7230#section-3.3.2"
		},
		{
			"header": "Content-Range",
			"description": "\"is sent in a single part 206 (Partial Content) response to indicate the partial range of the selected representation enclosed as the message payload, sent in each part of a multipart 206 response to indicate the range enclosed within each body part, and sent in 416 (Range Not Satisfiable) responses to provide information about the selected representation.\"",
			"spec_title": "RFC7233#4.2",
			"spec_href": "http://tools.ietf.org/html/rfc7233#section-4.2"
		},
		{
			"header": "Transfer-Encoding",
			"description": "\"lists the transfer coding names corresponding to the sequence of transfer codings that have been (or will be) applied to the payload body in order to form the message body.\"",
			"spec_title": "RFC7230#3.3.1",
			"spec_href": "http://tools.ietf.org/html/rfc7230#section-3.3.1"
		},
		{
			"header": "Cache-Control",
			"description": "\"is used to specify directives for caches along the request/response chain.\"",
			"spec_title": "RFC7234#7.2",
			"spec_href": "http://tools.ietf.org/html/rfc7234#section-7.2"
		},
		{
			"header": "Expect",
			"description": "\"is used to indicate that particular server behaviors are required by the client.\"",
			"spec_title": "RFC7231#5.1.1",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-5.1.1"
		},
		{
			"header": "Host",
			"description": "\"provides the host and port information from the target URI, enabling the origin server to distinguish among resources while servicing requests for multiple host names on a single IP address.\"",
			"spec_title": "RFC7230#5.4",
			"spec_href": "http://tools.ietf.org/html/rfc7230#section-5.4"
		},
		{
			"header": "Max-Forwards",
			"description": "\"provides a mechanism with the TRACE and OPTIONS methods to limit the number of times that the request is forwarded by proxies.\"",
			"spec_title": "RFC7231#5.1.2",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-5.1.2"
		},
		{
			"header": "Pragma",
			"description": "\"allows backwards compatibility with HTTP/1.0 caches, so that clients can specify a \"no-cache\" request that they will understand (as Cache-Control was not defined until HTTP/1.1).\"",
			"spec_title": "RFC7234#7.4",
			"spec_href": "http://tools.ietf.org/html/rfc7234#section-7.4"
		},
		{
			"header": "Range",
			"description": "\"modifies the method semantics to request transfer of only one or more subranges of the selected representation data, rather than the entire selected representation data.\"",
			"spec_title": "RFC7233#3.1",
			"spec_href": "http://tools.ietf.org/html/rfc7233#section-3.1"
		},
		{
			"header": "TE",
			"description": "\"indicates what transfer codings, besides chunked, the client is willing to accept in response, and whether or not the client is willing to accept trailer fields in a chunked transfer coding.\"",
			"spec_title": "RFC7230#4.3",
			"spec_href": "http://tools.ietf.org/html/rfc7230#section-4.3"
		},
		{
			"header": "If-Match",
			"description": "\"can be used to make a request method conditional on the current existence or value of an entity-tag for one or more representations of the target resource.\"",
			"spec_title": "RFC7232#3.1",
			"spec_href": "http://tools.ietf.org/html/rfc7232#section-3.1"
		},
		{
			"header": "If-Modified-Since",
			"description": "\"can be used with GET or HEAD to make the method conditional by modification date: if the selected representation has not been modified since the time specified in this field, then do not perform the request method; instead, respond as detailed below.\"",
			"spec_title": "RFC7232#3.3",
			"spec_href": "http://tools.ietf.org/html/rfc7232#section-3.3"
		},
		{
			"header": "If-None-Match",
			"description": "\"can be used to make a request method conditional on not matching any of the current entity-tag values for representations of the target resource.\"",
			"spec_title": "RFC7232#3.2",
			"spec_href": "http://tools.ietf.org/html/rfc7232#section-3.2"
		},
		{
			"header": "If-Range",
			"description": "\"Informally, its meaning is: if the representation is unchanged, send me the part(s) that I am requesting in Range; otherwise, send me the entire representation.\"",
			"spec_title": "RFC7233#3.2",
			"spec_href": "http://tools.ietf.org/html/rfc7233#section-3.2"
		},
		{
			"header": "If-Unmodified-Since",
			"description": "\"can be used to make a request method conditional by modification date: if the selected representation has been modified since the time specified in this field, then the server MUST NOT perform the requested operation and MUST instead respond with the 412 (Precondition Failed) status code.\"",
			"spec_title": "RFC7232#3.4",
			"spec_href": "http://tools.ietf.org/html/rfc7232#section-3.4"
		},
		{
			"header": "Accept",
			"description": "\"can be used to specify certain media types which are acceptable for the response.\"",
			"spec_title": "RFC7231#5.3.2",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-5.3.2"
		},
		{
			"header": "Accept-Charset",
			"description": "\"can be sent by a user agent to indicate what charsets are acceptable in textual response content.\"",
			"spec_title": "RFC7231#5.3.3",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-5.3.3"
		},
		{
			"header": "Accept-Encoding",
			"description": "\"can be used by user agents to indicate what response content-codings are acceptable in the response.\"",
			"spec_title": "RFC7231#5.3.4",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-5.3.4"
		},
		{
			"header": "Accept-Language",
			"description": "\"can be used by user agents to indicate the set of natural languages that are preferred in the response.\"",
			"spec_title": "RFC7231#5.3.5",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-5.3.5"
		},
		{
			"header": "Authorization",
			"description": "\"allows a user agent to authenticate itself with a server -- usually, but not necessarily, after receiving a 401 (Unauthorized) response.\"",
			"spec_title": "RFC7235#4.1",
			"spec_href": "http://tools.ietf.org/html/rfc7235#section-4.1"
		},
		{
			"header": "Proxy-Authorization",
			"description": "\"allows the client to identify itself (or its user) to a proxy that requires authentication.\"",
			"spec_title": "RFC7235#4.3",
			"spec_href": "http://tools.ietf.org/html/rfc7235#section-4.3"
		},
		{
			"header": "DNT",
			"description": "\"defined as the means for expressing a user's tracking preference via HTTP.\"",
			"spec_title": "Tracking Preference Expression (DNT)",
			"spec_href": "http://www.w3.org/TR/tracking-dnt/#dnt-header-field"
		},
		{
			"header": "From",
			"description": "\"contains an Internet email address for a human user who controls the requesting user agent.\"",
			"spec_title": "RFC7231#5.5.1",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-5.5.1"
		},
		{
			"header": "Referer",
			"description": "\"allows the user agent to specify a URI reference for the resource from which the target URI was obtained (i.e., the \"referrer\", though the field name is misspelled).\"",
			"spec_title": "RFC7231#5.5.2",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-5.5.2"
		},
		{
			"header": "User-Agent",
			"description": "\"contains information about the user agent originating the request, which is often used by servers to help identify the scope of reported interoperability problems, to work around or tailor responses to avoid particular user agent limitations, and for analytics regarding browser or operating system use.\"",
			"spec_title": "RFC7231#5.5.3",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-5.5.3"
		},
		{
			"header": "Age",
			"description": "\"conveys the sender's estimate of the amount of time since the response was generated or successfully validated at the origin server.\"",
			"spec_title": "RFC7234#5.1",
			"spec_href": "http://tools.ietf.org/html/rfc7234#section-5.1"
		},
		{
			"header": "Cache-Control",
			"description": "\"is used to specify directives for caches along the request/response chain.\"",
			"spec_title": "RFC7234#7.2",
			"spec_href": "http://tools.ietf.org/html/rfc7234#section-7.2"
		},
		{
			"header": "Expires",
			"description": "\"gives the date/time after which the response is considered stale.\"",
			"spec_title": "RFC7234#7.3",
			"spec_href": "http://tools.ietf.org/html/rfc7234#section-7.3"
		},
		{
			"header": "Date",
			"description": "\"represents the date and time at which the message was originated\"",
			"spec_title": "RFC7231#7.1.1.2",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-7.1.1.2"
		},
		{
			"header": "Location",
			"description": "\"is used in some responses to refer to a specific resource in relation to the response.\"",
			"spec_title": "RFC7231#7.1.2",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-7.1.2"
		},
		{
			"header": "Retry-After",
			"description": "\"indicates how long the user agent ought to wait before making a follow-up request.\"",
			"spec_title": "RFC7231#7.1.3",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-7.1.3"
		},
		{
			"header": "Tk",
			"description": "\"defined as an OPTIONAL means for indicating the tracking status that applied to the corresponding request and as a REQUIRED means for indicating that a state-changing request has resulted in an interactive change to the tracking status. \"",
			"spec_title": "Tracking Preference Expression (DNT)",
			"spec_href": "http://www.w3.org/TR/tracking-dnt/#response-header-field"
		},
		{
			"header": "Vary",
			"description": "\"describes what parts of a request message, aside from the method and request target, might influence the origin server's process for selecting and representing the response.\"",
			"spec_title": "RFC7231#7.1.4",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-7.1.4"
		},
		{
			"header": "Warning",
			"description": "\"is used to carry additional information about the status or transformation of a message that might not be reflected in the message.\"",
			"spec_title": "RFC7234#7.6",
			"spec_href": "http://tools.ietf.org/html/rfc7234#section-7.6"
		},
		{
			"header": "ETag",
			"description": "\"provides the current entity-tag for the selected representation, as determined at the conclusion of handling the request.\"",
			"spec_title": "RFC7232#2.3",
			"spec_href": "http://tools.ietf.org/html/rfc7232#section-2.3"
		},
		{
			"header": "Last-Modified",
			"description": "\"provides a timestamp indicating the date and time at which the origin server believes the selected representation was last modified, as determined at the conclusion of handling the request.\"",
			"spec_title": "RFC7232#2.2",
			"spec_href": "http://tools.ietf.org/html/rfc7232#section-2.2"
		},
		{
			"header": "WWW-Authenticate",
			"description": "\"consists of at least one challenge that indicates the authentication scheme(s) and parameters applicable to the effective request URI.\"",
			"spec_title": "RFC7235#4.4",
			"spec_href": "http://tools.ietf.org/html/rfc7235#section-4.4"
		},
		{
			"header": "Proxy-Authenticate",
			"description": "\"consists of at least one challenge that indicates the authentication scheme(s) and parameters applicable to the proxy for this effective request URI.\"",
			"spec_title": "RFC7235#4.2",
			"spec_href": "http://tools.ietf.org/html/rfc7235#section-4.2"
		},
		{
			"header": "Accept-Ranges",
			"description": "\"allows a server to indicate that it supports range requests for the target resource.\"",
			"spec_title": "RFC7233#2.3",
			"spec_href": "http://tools.ietf.org/html/rfc7233#section-2.3"
		},
		{
			"header": "Allow",
			"description": "\"lists the set of methods advertised as supported by the target resource.\"",
			"spec_title": "RFC7231#7.4.1",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-7.4.1"
		},
		{
			"header": "Server",
			"description": "\"contains information about the software used by the origin server to handle the request, which is often used by clients to help identify the scope of reported interoperability problems, to work around or tailor requests to avoid particular server limitations, and for analytics regarding server or operating system use.\"",
			"spec_title": "RFC7231#7.4.2",
			"spec_href": "http://tools.ietf.org/html/rfc7231#section-7.4.2"
		},
		{
			"header": "Accept-Patch",
			"description": "\"used to specify the patch document formats accepted by the server.\"",
			"spec_title": "RFC5789#3.1",
			"spec_href": "http://tools.ietf.org/html/rfc5789#section-3.1"
		},
		{
			"header": "Accept-Post",
			"description": "\"indicates server support for specific media types for entity bodies in HTTP POST requests.\"",
			"spec_title": "draft-wilde-accept-post",
			"spec_href": "http://tools.ietf.org/html/draft-wilde-accept-post"
		},
		{
			"header": "Access-Control-Allow-Credentials",
			"description": "\"indicates whether the response to request can be exposed when the omit credentials flag is unset\"",
			"spec_title": "CORS",
			"spec_href": "http://www.w3.org/TR/cors/#access-control-allow-credentials-response-header"
		},
		{
			"header": "Access-Control-Allow-Headers",
			"description": "\"indicates, as part of the response to a preflight request, which header field names can be used during the actual request\"",
			"spec_title": "CORS",
			"spec_href": "http://www.w3.org/TR/cors/#access-control-allow-headers-response-header"
		},
		{
			"header": "Access-Control-Allow-Methods",
			"description": "\"indicates, as part of the response to a preflight request, which methods can be used during the actual request\"",
			"spec_title": "CORS",
			"spec_href": "http://www.w3.org/TR/cors/#access-control-allow-methods-response-header"
		},
		{
			"header": "Access-Control-Allow-Origin",
			"description": "\"indicates whether a resource can be shared\"",
			"spec_title": "CORS",
			"spec_href": "http://www.w3.org/TR/cors/#access-control-allow-origin-response-header"
		},
		{
			"header": "Access-Control-Expose-Headers",
			"description": "\"indicates which headers are safe to expose to the API of a CORS API specification\"",
			"spec_title": "CORS",
			"spec_href": "http://www.w3.org/TR/cors/#access-control-expose-headers-response-header"
		},
		{
			"header": "Access-Control-Max-Age",
			"description": "\"indicates how long the results of a preflight request can be cached in a preflight result cache\"",
			"spec_title": "CORS",
			"spec_href": "http://www.w3.org/TR/cors/#access-control-max-age-response-header"
		},
		{
			"header": "Access-Control-Request-Headers",
			"description": "\"indicates which headers will be used in the actual request as part of the preflight request\"",
			"spec_title": "CORS",
			"spec_href": "http://www.w3.org/TR/cors/#access-control-request-headers-request-header"
		},
		{
			"header": "Access-Control-Request-Method",
			"description": "\"indicates which method will be used in the actual request as part of the preflight request\"",
			"spec_title": "CORS",
			"spec_href": "http://www.w3.org/TR/cors/#access-control-request-method-request-header"
		},
		{
			"header": "Content-Disposition",
			"description": "\"standard\"",
			"spec_title": "RFC6266",
			"spec_href": "http://tools.ietf.org/html/rfc6266"
		},
		{
			"header": "Content-Security-Policy",
			"description": "\"is the preferred mechanism for delivering a CSP policy\"",
			"spec_title": "CSP",
			"spec_href": "http://www.w3.org/TR/CSP/#content-security-policy-header-field"
		},
		{
			"header": "Content-Security-Policy-Report-Only",
			"description": "\"lets servers experiment with policies by monitoring (rather than enforcing) a policy\"",
			"spec_title": "CSP",
			"spec_href": "http://www.w3.org/TR/CSP/#content-security-policy-report-only-header-field"
		},
		{
			"header": "Cookie",
			"description": "\"standard\"",
			"spec_title": "RFC6265",
			"spec_href": "http://tools.ietf.org/html/rfc6265"
		},
		{
			"header": "Forwarded",
			"description": "\"standard\"",
			"spec_title": "RFC7239",
			"spec_href": "http://tools.ietf.org/html/rfc7239"
		},
		{
			"header": "Link",
			"description": "\"provides a means for serialising one or more links in HTTP headers.\"",
			"spec_title": "RFC5988#5",
			"spec_href": "http://tools.ietf.org/html/rfc5988#section-5"
		},
		{
			"header": "Origin",
			"description": "\"standard\"",
			"spec_title": "RFC6454",
			"spec_href": "http://tools.ietf.org/html/rfc6454"
		},
		{
			"header": "Prefer",
			"description": "\"is used to indicate that particular server behaviors are preferred by the client, but not required for successful completion of the request.\"",
			"spec_title": "draft-snell-http-prefer#2",
			"spec_href": "http://tools.ietf.org/html/draft-snell-http-prefer#section-2"
		},
		{
			"header": "Preference-Applied",
			"description": "\"MAY be included within a response message as an indication as to which Prefer tokens were honored by the server and applied to the processing of a request.\"",
			"spec_title": "draft-snell-http-prefer#3",
			"spec_href": "http://tools.ietf.org/html/draft-snell-http-prefer#section-3"
		},
		{
			"header": "Set-Cookie",
			"description": "\"standard\"",
			"spec_title": "RFC6265",
			"spec_href": "http://tools.ietf.org/html/rfc6265"
		},
		{
			"header": "Strict-Transport-Security",
			"description": "\"standard\"",
			"spec_title": "RFC6797",
			"spec_href": "http://tools.ietf.org/html/rfc6797"
		},
		{
			"header": "Via",
			"description": "\"\"",
			"spec_title": "RFC7230#5.7.1",
			"spec_href": "http://tools.ietf.org/html/rfc7230#section-5.7.1"
		},
		{
			"header": "A-IM",
			"description": "\"\"",
			"spec_title": "RFC3229#10.5.3",
			"spec_href": "http://tools.ietf.org/html/rfc3229#section-10.5.3"
		},
		{
			"header": "Accept-Features",
			"description": "\"can be used by a user agent to give information about the presence or absence of certain features in the feature set of the current request.\"",
			"spec_title": "RFC2295#8.2",
			"spec_href": "http://tools.ietf.org/html/rfc2295#section-8.2"
		},
		{
			"header": "Alt-Svc",
			"description": "\"is advertising the availability of alternate services to HTTP/1.1 and HTTP/2.0 clients by adding an Alt-Svc header field to responses.\"",
			"spec_title": "draft-nottingham-httpbis-alt-svc",
			"spec_href": "http://tools.ietf.org/html/draft-nottingham-httpbis-alt-svc"
		},
		{
			"header": "Alternates",
			"description": "\"is used to convey the list of variants bound to a negotiable resource.\"",
			"spec_title": "RFC2295#8.3",
			"spec_href": "http://tools.ietf.org/html/rfc2295#section-8.3"
		},
		{
			"header": "Apply-To-Redirect-Ref",
			"description": "\"\"",
			"spec_title": "RFC4437",
			"spec_href": "http://tools.ietf.org/html/rfc4437"
		},
		{
			"header": "CH",
			"description": "\"describes an example list of client preferences that the server can use to adapt and optimize the resource to satisfy a given request.\"",
			"spec_title": "draft-grigorik-http-client-hints",
			"spec_href": "http://tools.ietf.org/html/draft-grigorik-http-client-hints"
		},
		{
			"header": "Content-Base",
			"description": "\"obsoleted\"",
			"spec_title": "RFC2068",
			"spec_href": "http://tools.ietf.org/html/rfc2068"
		},
		{
			"header": "Cookie2",
			"description": "\"obsoleted\"",
			"spec_title": "RFC2965",
			"spec_href": "http://tools.ietf.org/html/rfc2965"
		},
		{
			"header": "DASL",
			"description": "\"standard\"",
			"spec_title": "RFC5323",
			"spec_href": "http://tools.ietf.org/html/rfc5323"
		},
		{
			"header": "DAV",
			"description": "\"standard\"",
			"spec_title": "RFC4918",
			"spec_href": "http://tools.ietf.org/html/rfc4918"
		},
		{
			"header": "Delta-Base",
			"description": "\"\"",
			"spec_title": "RFC3229#10.5.1",
			"spec_href": "http://tools.ietf.org/html/rfc3229#section-10.5.1"
		},
		{
			"header": "Depth",
			"description": "\"standard\"",
			"spec_title": "RFC4918",
			"spec_href": "http://tools.ietf.org/html/rfc4918"
		},
		{
			"header": "Destination",
			"description": "\"standard\"",
			"spec_title": "RFC4918",
			"spec_href": "http://tools.ietf.org/html/rfc4918"
		},
		{
			"header": "IM",
			"description": "\"\"",
			"spec_title": "RFC3229#10.5.2",
			"spec_href": "http://tools.ietf.org/html/rfc3229#section-10.5.2"
		},
		{
			"header": "If",
			"description": "\"standard\"",
			"spec_title": "RFC4918",
			"spec_href": "http://tools.ietf.org/html/rfc4918"
		},
		{
			"header": "If-Schedule-Tag-Match",
			"description": "\"standard\"",
			"spec_title": "RFC6638",
			"spec_href": "http://tools.ietf.org/html/rfc6638"
		},
		{
			"header": "Last-Event-ID",
			"description": "\"The value of the event source's last event ID string, encoded as UTF-8.\"",
			"spec_title": "Server-Sent Events",
			"spec_href": "http://www.w3.org/TR/eventsource/#last-event-id"
		},
		{
			"header": "Link-Template",
			"description": "\"provides a means for serialising one or more links into HTTP headers.\"",
			"spec_title": "draft-nottingham-link-template",
			"spec_href": "http://tools.ietf.org/html/draft-nottingham-link-template"
		},
		{
			"header": "Lock-Token",
			"description": "\"standard\"",
			"spec_title": "RFC4918",
			"spec_href": "http://tools.ietf.org/html/rfc4918"
		},
		{
			"header": "Negotiate",
			"description": "\"can contain directives for any content negotiation process initiated by the request.\"",
			"spec_title": "RFC2295#8.4",
			"spec_href": "http://tools.ietf.org/html/rfc2295#section-8.4"
		},
		{
			"header": "Nice",
			"description": "\"indicates that a request is less important than a request that doesn't bear this header.\"",
			"spec_title": "draft-thomson-http-nice",
			"spec_href": "http://tools.ietf.org/html/draft-thomson-http-nice"
		},
		{
			"header": "Overwrite",
			"description": "\"standard\"",
			"spec_title": "RFC4918",
			"spec_href": "http://tools.ietf.org/html/rfc4918"
		},
		{
			"header": "Redirect-Ref",
			"description": "\"\"",
			"spec_title": "RFC4437",
			"spec_href": "http://tools.ietf.org/html/rfc4437"
		},
		{
			"header": "Schedule-Reply",
			"description": "\"standard\"",
			"spec_title": "RFC6638",
			"spec_href": "http://tools.ietf.org/html/rfc6638"
		},
		{
			"header": "Schedule-Tag",
			"description": "\"standard\"",
			"spec_title": "RFC6638",
			"spec_href": "http://tools.ietf.org/html/rfc6638"
		},
		{
			"header": "Sec-WebSocket-Accept",
			"description": "\"standard\"",
			"spec_title": "RFC6455",
			"spec_href": "http://tools.ietf.org/html/rfc6455"
		},
		{
			"header": "Sec-WebSocket-Extensions",
			"description": "\"standard\"",
			"spec_title": "RFC6455",
			"spec_href": "http://tools.ietf.org/html/rfc6455"
		},
		{
			"header": "Sec-WebSocket-Key",
			"description": "\"standard\"",
			"spec_title": "RFC6455",
			"spec_href": "http://tools.ietf.org/html/rfc6455"
		},
		{
			"header": "Sec-WebSocket-Protocol",
			"description": "\"standard\"",
			"spec_title": "RFC6455",
			"spec_href": "http://tools.ietf.org/html/rfc6455"
		},
		{
			"header": "Sec-WebSocket-Version",
			"description": "\"standard\"",
			"spec_title": "RFC6455",
			"spec_href": "http://tools.ietf.org/html/rfc6455"
		},
		{
			"header": "Set-Cookie2",
			"description": "\"obsoleted\"",
			"spec_title": "RFC2965",
			"spec_href": "http://tools.ietf.org/html/rfc2965"
		},
		{
			"header": "SLUG",
			"description": "\"standard\"",
			"spec_title": "RFC5023",
			"spec_href": "http://tools.ietf.org/html/rfc5023"
		},
		{
			"header": "TCN",
			"description": "\"is used by a server to signal that the resource is transparently negotiated.\"",
			"spec_title": "RFC2295#8.5",
			"spec_href": "http://tools.ietf.org/html/rfc2295#section-8.5"
		},
		{
			"header": "Timeout",
			"description": "\"standard\"",
			"spec_title": "RFC4918",
			"spec_href": "http://tools.ietf.org/html/rfc4918"
		},
		{
			"header": "Variant-Vary",
			"description": "\"can be used in a choice response to record any vary information which applies to the variant data (the entity body combined with some of the entity headers) contained in the response, rather than to the response as a whole.\"",
			"spec_title": "RFC2295#8.6",
			"spec_href": "http://tools.ietf.org/html/rfc2295#section-8.6"
		},
		{
			"header": "X-Frame-Options",
			"description": "\"indicates a policy that specifies whether the browser should render the transmitted resource within a <frame> or an <iframe>. Servers can declare this policy in the header of their HTTP responses to prevent clickjacking attacks, which ensures that their content is not embedded into other pages or frames.\"",
			"spec_title": "RFC7034",
			"spec_href": "http://tools.ietf.org/html/rfc7034"
		}
	];

/***/ },
/* 174 */
/***/ function(module, exports, __webpack_require__) {

	module.exports = [
		{
			"relation": "about",
			"description": "\"Refers to a resource that is the subject of the link's context.\"",
			"spec_title": "RFC6903",
			"spec_href": "http://tools.ietf.org/html/rfc6903"
		},
		{
			"relation": "alternate",
			"description": "\"Refers to a substitute for this context\"",
			"spec_title": "HTML5links",
			"spec_href": "http://www.w3.org/TR/html5/links.html#link-type-alternate"
		},
		{
			"relation": "appendix",
			"description": "\"Refers to an appendix.\"",
			"spec_title": "HTML401",
			"spec_href": "http://www.w3.org/TR/1999/REC-html401-19991224"
		},
		{
			"relation": "archives",
			"description": "\"Refers to a collection of records, documents, or other materials of historical interest.\"",
			"spec_title": "HTML5linksWD",
			"spec_href": "http://www.w3.org/TR/2011/WD-html5-20110113/links.html#rel-archives"
		},
		{
			"relation": "author",
			"description": "\"Refers to the context's author.\"",
			"spec_title": "HTML5links",
			"spec_href": "http://www.w3.org/TR/html5/links.html#link-type-author"
		},
		{
			"relation": "bookmark",
			"description": "\"Gives a permanent link to use for bookmarking purposes.\"",
			"spec_title": "HTML5links",
			"spec_href": "http://www.w3.org/TR/html5/links.html#link-type-bookmark"
		},
		{
			"relation": "canonical",
			"description": "\"Designates the preferred version of a resource (the IRI and its contents).\"",
			"spec_title": "RFC6596",
			"spec_href": "http://tools.ietf.org/html/rfc6596"
		},
		{
			"relation": "chapter",
			"description": "\"Refers to a chapter in a collection of resources.\"",
			"spec_title": "HTML401",
			"spec_href": "http://www.w3.org/TR/1999/REC-html401-19991224"
		},
		{
			"relation": "collection",
			"description": "\"The target IRI points to a resource which represents the collection resource for the context IRI.\"",
			"spec_title": "RFC6573",
			"spec_href": "http://tools.ietf.org/html/rfc6573"
		},
		{
			"relation": "contents",
			"description": "\"Refers to a table of contents.\"",
			"spec_title": "HTML401",
			"spec_href": "http://www.w3.org/TR/1999/REC-html401-19991224"
		},
		{
			"relation": "copyright",
			"description": "\"Refers to a copyright statement that applies to the link's context.\"",
			"spec_title": "HTML401",
			"spec_href": "http://www.w3.org/TR/1999/REC-html401-19991224"
		},
		{
			"relation": "create-form",
			"description": "\"The target IRI points to a resource where a submission form can be obtained.\"",
			"spec_title": "RFC6861",
			"spec_href": "http://tools.ietf.org/html/rfc6861"
		},
		{
			"relation": "current",
			"description": "\"Refers to a resource containing the most recent item(s) in a collection of resources.\"",
			"spec_title": "RFC5005",
			"spec_href": "http://tools.ietf.org/html/rfc5005"
		},
		{
			"relation": "describedby",
			"description": "\"Refers to a resource providing information about the link's context.\"",
			"spec_title": "POWDER",
			"spec_href": "http://www.w3.org/TR/powder-dr/#assoc-linking"
		},
		{
			"relation": "describes",
			"description": "\"The relationship A 'describes' B asserts that resource A provides a description of resource B. There are no constraints on the format or representation of either A or B, neither are there any further constraints on either resource.\"",
			"spec_title": "RFC6892",
			"spec_href": "http://tools.ietf.org/html/rfc6892"
		},
		{
			"relation": "disclosure",
			"description": "\"Refers to a list of patent disclosures made with respect to material for which `disclosure` relation is specified.\"",
			"spec_title": "RFC6579",
			"spec_href": "http://tools.ietf.org/html/rfc6579"
		},
		{
			"relation": "duplicate",
			"description": "\"Refers to a resource whose available representations are byte-for-byte identical with the corresponding representations of the context IRI.\"",
			"spec_title": "RFC6249",
			"spec_href": "http://tools.ietf.org/html/rfc6249"
		},
		{
			"relation": "edit",
			"description": "\"Refers to a resource that can be used to edit the link's context.\"",
			"spec_title": "RFC5023",
			"spec_href": "http://tools.ietf.org/html/rfc5023"
		},
		{
			"relation": "edit-form",
			"description": "\"The target IRI points to a resource where a submission form for editing associated resource can be obtained.\"",
			"spec_title": "RFC6861",
			"spec_href": "http://tools.ietf.org/html/rfc6861"
		},
		{
			"relation": "edit-media",
			"description": "\"Refers to a resource that can be used to edit media associated with the link's context.\"",
			"spec_title": "RFC5023",
			"spec_href": "http://tools.ietf.org/html/rfc5023"
		},
		{
			"relation": "enclosure",
			"description": "\"Identifies a related resource that is potentially large and might require special handling.\"",
			"spec_title": "RFC4287",
			"spec_href": "http://tools.ietf.org/html/rfc4287"
		},
		{
			"relation": "first",
			"description": "\"An IRI that refers to the furthest preceding resource in a series of resources.\"",
			"spec_title": "RFC5988",
			"spec_href": "http://tools.ietf.org/html/rfc5988"
		},
		{
			"relation": "glossary",
			"description": "\"Refers to a glossary of terms.\"",
			"spec_title": "HTML401",
			"spec_href": "http://www.w3.org/TR/1999/REC-html401-19991224"
		},
		{
			"relation": "help",
			"description": "\"Refers to context-sensitive help.\"",
			"spec_title": "HTML5links",
			"spec_href": "http://www.w3.org/TR/html5/links.html#link-type-help"
		},
		{
			"relation": "hosts",
			"description": "\"Refers to a resource hosted by the server indicated by the link context.\"",
			"spec_title": "RFC6690",
			"spec_href": "http://tools.ietf.org/html/rfc6690"
		},
		{
			"relation": "hub",
			"description": "\"Refers to a hub that enables registration for notification of updates to the context.\"",
			"spec_title": "pubsubhubbub",
			"spec_href": "http://pubsubhubbub.googlecode.com"
		},
		{
			"relation": "icon",
			"description": "\"Refers to an icon representing the link's context.\"",
			"spec_title": "HTML5links",
			"spec_href": "http://www.w3.org/TR/html5/links.html#link-type-icon"
		},
		{
			"relation": "index",
			"description": "\"Refers to an index.\"",
			"spec_title": "HTML401",
			"spec_href": "http://www.w3.org/TR/1999/REC-html401-19991224"
		},
		{
			"relation": "item",
			"description": "\"The target IRI points to a resource that is a member of the collection represented by the context IRI.\"",
			"spec_title": "RFC6573",
			"spec_href": "http://tools.ietf.org/html/rfc6573"
		},
		{
			"relation": "last",
			"description": "\"An IRI that refers to the furthest following resource in a series of resources.\"",
			"spec_title": "RFC5988",
			"spec_href": "http://tools.ietf.org/html/rfc5988"
		},
		{
			"relation": "latest-version",
			"description": "\"Points to a resource containing the latest (e.g., current) version of the context.\"",
			"spec_title": "RFC5829",
			"spec_href": "http://tools.ietf.org/html/rfc5829"
		},
		{
			"relation": "license",
			"description": "\"Refers to a license associated with this context.\"",
			"spec_title": "RFC4946",
			"spec_href": "http://tools.ietf.org/html/rfc4946"
		},
		{
			"relation": "lrdd",
			"description": "\"Refers to further information about the link's context, expressed as a LRDD (Link-based Resource Descriptor Document) resource. See [RFC6415](http://tools.ietf.org/html/rfc6415) for information about processing this relation type in host-meta documents. When used elsewhere, it refers to additional links and other metadata. Multiple instances indicate additional LRDD resources. LRDD resources MUST have an \"application/xrd+xml\" representation, and MAY have others.\"",
			"spec_title": "RFC6415",
			"spec_href": "http://tools.ietf.org/html/rfc6415"
		},
		{
			"relation": "monitor",
			"description": "\"Refers to a resource that can be used to monitor changes in an HTTP resource.\"",
			"spec_title": "RFC5989",
			"spec_href": "http://tools.ietf.org/html/rfc5989"
		},
		{
			"relation": "monitor-group",
			"description": "\"Refers to a resource that can be used to monitor changes in a specified group of HTTP resources.\"",
			"spec_title": "RFC5989",
			"spec_href": "http://tools.ietf.org/html/rfc5989"
		},
		{
			"relation": "next",
			"description": "\"Indicates that the link's context is a part of a series, and that the next in the series is the link target.\"",
			"spec_title": "HTML5links",
			"spec_href": "http://www.w3.org/TR/html5/links.html#link-type-next"
		},
		{
			"relation": "next-archive",
			"description": "\"Refers to the immediately following archive resource.\"",
			"spec_title": "RFC5005",
			"spec_href": "http://tools.ietf.org/html/rfc5005"
		},
		{
			"relation": "nofollow",
			"description": "\"Indicates that the context’s original author or publisher does not endorse the link target.\"",
			"spec_title": "HTML5links",
			"spec_href": "http://www.w3.org/TR/html5/links.html#link-type-nofollow"
		},
		{
			"relation": "noreferrer",
			"description": "\"Indicates that no referrer information is to be leaked when following the link.\"",
			"spec_title": "HTML5links",
			"spec_href": "http://www.w3.org/TR/html5/links.html#link-type-noreferrer"
		},
		{
			"relation": "payment",
			"description": "\"Indicates a resource where payment is accepted.\"",
			"spec_title": "RFC5988",
			"spec_href": "http://tools.ietf.org/html/rfc5988"
		},
		{
			"relation": "predecessor-version",
			"description": "\"Points to a resource containing the predecessor version in the version history.\"",
			"spec_title": "RFC5829",
			"spec_href": "http://tools.ietf.org/html/rfc5829"
		},
		{
			"relation": "prefetch",
			"description": "\"Indicates that the link target should be preemptively cached.\"",
			"spec_title": "HTML5links",
			"spec_href": "http://www.w3.org/TR/html5/links.html#link-type-prefetch"
		},
		{
			"relation": "prev",
			"description": "\"Indicates that the link's context is a part of a series, and that the previous in the series is the link target.\"",
			"spec_title": "HTML5links",
			"spec_href": "http://www.w3.org/TR/html5/links.html#link-type-prev"
		},
		{
			"relation": "preview",
			"description": "\"Refers to a resource that provides a preview of the link's context.\"",
			"spec_title": "RFC6903",
			"spec_href": "http://tools.ietf.org/html/rfc6903"
		},
		{
			"relation": "previous",
			"description": "\"Refers to the previous resource in an ordered series of resources. Synonym for `prev`.\"",
			"spec_title": "HTML401",
			"spec_href": "http://www.w3.org/TR/1999/REC-html401-19991224"
		},
		{
			"relation": "prev-archive",
			"description": "\"Refers to the immediately preceding archive resource.\"",
			"spec_title": "RFC5005",
			"spec_href": "http://tools.ietf.org/html/rfc5005"
		},
		{
			"relation": "privacy-policy",
			"description": "\"Refers to a privacy policy associated with the link's context.\"",
			"spec_title": "RFC6903",
			"spec_href": "http://tools.ietf.org/html/rfc6903"
		},
		{
			"relation": "profile",
			"description": "Identifying that a resource representation conforms to a certain profile, without affecting the non-profile semantics of the resource representation",
			"spec_title": "RFC6906",
			"spec_href": "http://tools.ietf.org/html/rfc6906"
		},
		{
			"relation": "related",
			"description": "\"Identifies a related resource.\"",
			"spec_title": "RFC4287",
			"spec_href": "http://tools.ietf.org/html/rfc4287"
		},
		{
			"relation": "replies",
			"description": "\"Identifies a resource that is a reply to the context of the link.\"",
			"spec_title": "RFC4685",
			"spec_href": "http://tools.ietf.org/html/rfc4685"
		},
		{
			"relation": "search",
			"description": "\"Refers to a resource that can be used to search through the link's context and related resources.\"",
			"spec_title": "OpenSearch",
			"spec_href": "http://www.opensearch.org/Specifications/OpenSearch/1.1"
		},
		{
			"relation": "section",
			"description": "\"Refers to a section in a collection of resources.\"",
			"spec_title": "HTML401",
			"spec_href": "http://www.w3.org/TR/1999/REC-html401-19991224"
		},
		{
			"relation": "self",
			"description": "\"Conveys an identifier for the link's context.\"",
			"spec_title": "RFC4287",
			"spec_href": "http://tools.ietf.org/html/rfc4287"
		},
		{
			"relation": "service",
			"description": "\"Indicates a URI that can be used to retrieve a service document.\"",
			"spec_title": "RFC5023",
			"spec_href": "http://tools.ietf.org/html/rfc5023"
		},
		{
			"relation": "start",
			"description": "\"Refers to the first resource in a collection of resources.\"",
			"spec_title": "HTML401",
			"spec_href": "http://www.w3.org/TR/1999/REC-html401-19991224"
		},
		{
			"relation": "stylesheet",
			"description": "\"Refers to a stylesheet.\"",
			"spec_title": "HTML5links",
			"spec_href": "http://www.w3.org/TR/html5/links.html#link-type-stylesheet"
		},
		{
			"relation": "subsection",
			"description": "\"Refers to a resource serving as a subsection in a collection of resources.\"",
			"spec_title": "HTML401",
			"spec_href": "http://www.w3.org/TR/1999/REC-html401-19991224"
		},
		{
			"relation": "successor-version",
			"description": "\"Points to a resource containing the successor version in the version history.\"",
			"spec_title": "RFC5829",
			"spec_href": "http://tools.ietf.org/html/rfc5829"
		},
		{
			"relation": "tag",
			"description": "\"Gives a tag (identified by the given address) that applies to the current document.\"",
			"spec_title": "HTML5links",
			"spec_href": "http://www.w3.org/TR/html5/links.html#link-type-tag"
		},
		{
			"relation": "terms-of-service",
			"description": "\"Refers to the terms of service associated with the link's context.\"",
			"spec_title": "RFC6903",
			"spec_href": "http://tools.ietf.org/html/rfc6903"
		},
		{
			"relation": "type",
			"description": "\"Refers to a resource identifying the abstract semantic type of which the link's context is considered to be an instance.\"",
			"spec_title": "RFC6903",
			"spec_href": "http://tools.ietf.org/html/rfc6903"
		},
		{
			"relation": "up",
			"description": "\"Refers to a parent document in a hierarchy of documents.\"",
			"spec_title": "RFC5988",
			"spec_href": "http://tools.ietf.org/html/rfc5988"
		},
		{
			"relation": "version-history",
			"description": "\"Points to a resource containing the version history for the context.\"",
			"spec_title": "RFC5829",
			"spec_href": "http://tools.ietf.org/html/rfc5829"
		},
		{
			"relation": "via",
			"description": "\"Identifies a resource that is the source of the information in the link's context.\"",
			"spec_title": "RFC4287",
			"spec_href": "http://tools.ietf.org/html/rfc4287"
		},
		{
			"relation": "working-copy",
			"description": "\"Points to a working copy for this resource.\"",
			"spec_title": "RFC5829",
			"spec_href": "http://tools.ietf.org/html/rfc5829"
		},
		{
			"relation": "working-copy-of",
			"description": "\"Points to the versioned resource from which this working copy was obtained.\"",
			"spec_title": "RFC5829",
			"spec_href": "http://tools.ietf.org/html/rfc5829"
		}
	];

/***/ },
/* 175 */
/***/ function(module, exports, __webpack_require__) {

	function DOMParser(options){
		this.options = options ||{locator:{}};
		
	}
	DOMParser.prototype.parseFromString = function(source,mimeType){	
		var options = this.options;
		var sax =  new XMLReader();
		var domBuilder = options.domBuilder || new DOMHandler();//contentHandler and LexicalHandler
		var errorHandler = options.errorHandler;
		var locator = options.locator;
		var defaultNSMap = options.xmlns||{};
		var entityMap = {'lt':'<','gt':'>','amp':'&','quot':'"','apos':"'"}
		if(locator){
			domBuilder.setDocumentLocator(locator)
		}
		
		sax.errorHandler = buildErrorHandler(errorHandler,domBuilder,locator);
		sax.domBuilder = options.domBuilder || domBuilder;
		if(/\/x?html?$/.test(mimeType)){
			entityMap.nbsp = '\xa0';
			entityMap.copy = '\xa9';
			defaultNSMap['']= 'http://www.w3.org/1999/xhtml';
		}
		defaultNSMap.xml = defaultNSMap.xml || 'http://www.w3.org/XML/1998/namespace';
		if(source){
			sax.parse(source,defaultNSMap,entityMap);
		}else{
			sax.errorHandler.error("invalid document source");
		}
		return domBuilder.document;
	}
	function buildErrorHandler(errorImpl,domBuilder,locator){
		if(!errorImpl){
			if(domBuilder instanceof DOMHandler){
				return domBuilder;
			}
			errorImpl = domBuilder ;
		}
		var errorHandler = {}
		var isCallback = errorImpl instanceof Function;
		locator = locator||{}
		function build(key){
			var fn = errorImpl[key];
			if(!fn && isCallback){
				fn = errorImpl.length == 2?function(msg){errorImpl(key,msg)}:errorImpl;
			}
			errorHandler[key] = fn && function(msg){
				fn('[xmldom '+key+']\t'+msg+_locator(locator));
			}||function(){};
		}
		build('warning');
		build('error');
		build('fatalError');
		return errorHandler;
	}

	//console.log('#\n\n\n\n\n\n\n####')
	/**
	 * +ContentHandler+ErrorHandler
	 * +LexicalHandler+EntityResolver2
	 * -DeclHandler-DTDHandler 
	 * 
	 * DefaultHandler:EntityResolver, DTDHandler, ContentHandler, ErrorHandler
	 * DefaultHandler2:DefaultHandler,LexicalHandler, DeclHandler, EntityResolver2
	 * @link http://www.saxproject.org/apidoc/org/xml/sax/helpers/DefaultHandler.html
	 */
	function DOMHandler() {
	    this.cdata = false;
	}
	function position(locator,node){
		node.lineNumber = locator.lineNumber;
		node.columnNumber = locator.columnNumber;
	}
	/**
	 * @see org.xml.sax.ContentHandler#startDocument
	 * @link http://www.saxproject.org/apidoc/org/xml/sax/ContentHandler.html
	 */ 
	DOMHandler.prototype = {
		startDocument : function() {
	    	this.document = new DOMImplementation().createDocument(null, null, null);
	    	if (this.locator) {
	        	this.document.documentURI = this.locator.systemId;
	    	}
		},
		startElement:function(namespaceURI, localName, qName, attrs) {
			var doc = this.document;
		    var el = doc.createElementNS(namespaceURI, qName||localName);
		    var len = attrs.length;
		    appendElement(this, el);
		    this.currentElement = el;
		    
			this.locator && position(this.locator,el)
		    for (var i = 0 ; i < len; i++) {
		        var namespaceURI = attrs.getURI(i);
		        var value = attrs.getValue(i);
		        var qName = attrs.getQName(i);
				var attr = doc.createAttributeNS(namespaceURI, qName);
				if( attr.getOffset){
					position(attr.getOffset(1),attr)
				}
				attr.value = attr.nodeValue = value;
				el.setAttributeNode(attr)
		    }
		},
		endElement:function(namespaceURI, localName, qName) {
			var current = this.currentElement
		    var tagName = current.tagName;
		    this.currentElement = current.parentNode;
		},
		startPrefixMapping:function(prefix, uri) {
		},
		endPrefixMapping:function(prefix) {
		},
		processingInstruction:function(target, data) {
		    var ins = this.document.createProcessingInstruction(target, data);
		    this.locator && position(this.locator,ins)
		    appendElement(this, ins);
		},
		ignorableWhitespace:function(ch, start, length) {
		},
		characters:function(chars, start, length) {
			chars = _toString.apply(this,arguments)
			//console.log(chars)
			if(this.currentElement && chars){
				if (this.cdata) {
					var charNode = this.document.createCDATASection(chars);
					this.currentElement.appendChild(charNode);
				} else {
					var charNode = this.document.createTextNode(chars);
					this.currentElement.appendChild(charNode);
				}
				this.locator && position(this.locator,charNode)
			}
		},
		skippedEntity:function(name) {
		},
		endDocument:function() {
			this.document.normalize();
		},
		setDocumentLocator:function (locator) {
		    if(this.locator = locator){// && !('lineNumber' in locator)){
		    	locator.lineNumber = 0;
		    }
		},
		//LexicalHandler
		comment:function(chars, start, length) {
			chars = _toString.apply(this,arguments)
		    var comm = this.document.createComment(chars);
		    this.locator && position(this.locator,comm)
		    appendElement(this, comm);
		},
		
		startCDATA:function() {
		    //used in characters() methods
		    this.cdata = true;
		},
		endCDATA:function() {
		    this.cdata = false;
		},
		
		startDTD:function(name, publicId, systemId) {
			var impl = this.document.implementation;
		    if (impl && impl.createDocumentType) {
		        var dt = impl.createDocumentType(name, publicId, systemId);
		        this.locator && position(this.locator,dt)
		        appendElement(this, dt);
		    }
		},
		/**
		 * @see org.xml.sax.ErrorHandler
		 * @link http://www.saxproject.org/apidoc/org/xml/sax/ErrorHandler.html
		 */
		warning:function(error) {
			console.warn('[xmldom warning]\t'+error,_locator(this.locator));
		},
		error:function(error) {
			console.error('[xmldom error]\t'+error,_locator(this.locator));
		},
		fatalError:function(error) {
			console.error('[xmldom fatalError]\t'+error,_locator(this.locator));
		    throw error;
		}
	}
	function _locator(l){
		if(l){
			return '\n@'+(l.systemId ||'')+'#[line:'+l.lineNumber+',col:'+l.columnNumber+']'
		}
	}
	function _toString(chars,start,length){
		if(typeof chars == 'string'){
			return chars.substr(start,length)
		}else{//java sax connect width xmldom on rhino(what about: "? && !(chars instanceof String)")
			if(chars.length >= start+length || start){
				return new java.lang.String(chars,start,length)+'';
			}
			return chars;
		}
	}

	/*
	 * @link http://www.saxproject.org/apidoc/org/xml/sax/ext/LexicalHandler.html
	 * used method of org.xml.sax.ext.LexicalHandler:
	 *  #comment(chars, start, length)
	 *  #startCDATA()
	 *  #endCDATA()
	 *  #startDTD(name, publicId, systemId)
	 *
	 *
	 * IGNORED method of org.xml.sax.ext.LexicalHandler:
	 *  #endDTD()
	 *  #startEntity(name)
	 *  #endEntity(name)
	 *
	 *
	 * @link http://www.saxproject.org/apidoc/org/xml/sax/ext/DeclHandler.html
	 * IGNORED method of org.xml.sax.ext.DeclHandler
	 * 	#attributeDecl(eName, aName, type, mode, value)
	 *  #elementDecl(name, model)
	 *  #externalEntityDecl(name, publicId, systemId)
	 *  #internalEntityDecl(name, value)
	 * @link http://www.saxproject.org/apidoc/org/xml/sax/ext/EntityResolver2.html
	 * IGNORED method of org.xml.sax.EntityResolver2
	 *  #resolveEntity(String name,String publicId,String baseURI,String systemId)
	 *  #resolveEntity(publicId, systemId)
	 *  #getExternalSubset(name, baseURI)
	 * @link http://www.saxproject.org/apidoc/org/xml/sax/DTDHandler.html
	 * IGNORED method of org.xml.sax.DTDHandler
	 *  #notationDecl(name, publicId, systemId) {};
	 *  #unparsedEntityDecl(name, publicId, systemId, notationName) {};
	 */
	"endDTD,startEntity,endEntity,attributeDecl,elementDecl,externalEntityDecl,internalEntityDecl,resolveEntity,getExternalSubset,notationDecl,unparsedEntityDecl".replace(/\w+/g,function(key){
		DOMHandler.prototype[key] = function(){return null}
	})

	/* Private static helpers treated below as private instance methods, so don't need to add these to the public API; we might use a Relator to also get rid of non-standard public properties */
	function appendElement (hander,node) {
	    if (!hander.currentElement) {
	        hander.document.appendChild(node);
	    } else {
	        hander.currentElement.appendChild(node);
	    }
	}//appendChild and setAttributeNS are preformance key

	if(true){
		var XMLReader = __webpack_require__(198).XMLReader;
		var DOMImplementation = exports.DOMImplementation = __webpack_require__(199).DOMImplementation;
		exports.XMLSerializer = __webpack_require__(199).XMLSerializer ;
		exports.DOMParser = DOMParser;
	}


/***/ },
/* 176 */
/***/ function(module, exports, __webpack_require__) {

	var JsonSchemaCompatability = (function () {

		function convert3to4Type(types, always) {
			if (!Array.isArray(types)) {
				types = [types];
			}
			var needsReplacement = !!always;
			var result = [];
			for (var i = 0; i < types.length; i++) {
				var entry = types[i];
				if (typeof entry === 'object') {
					result.push(entry);
					needsReplacement = true;
				} else {
					result.push({"type": entry});
				}
			}
			return needsReplacement && result;
		}

		function convert3to4(obj) {
			// Old-style "type"
			if (obj.type) {
				if (typeof obj.type !== 'string') {
					var anyOf = convert3to4Type(obj.type);
					if (anyOf) {
						obj.anyOf = anyOf;
						delete obj.type;
					}
				}
				else if (obj.type == 'any') {
					delete obj.type;
				}
			}
			if (obj['extends']) {
				var allOf = obj['extends'];
				if (!Array.isArray(allOf)) {
					allOf = [allOf];
				}
				obj.allOf = allOf;
				delete obj['extends'];
			}
			if (obj.disallow) {
				if (typeof obj.disallow === 'string') {
					obj.not = {"type": obj.disallow};
				} else {
					obj.not = {"anyOf": convert3to4Type(obj.disallow, true)};
				}
				delete obj.disallow;
			}

			// Object concerns
			if (obj.properties) {
				var required = Array.isArray(obj.required) ? obj.required : [];
				for (var key in obj.properties) {
					var subSchema = obj.properties[key];
					if (subSchema && typeof subSchema.required === 'boolean') {
						if (subSchema.required) {
							required.push(key);
						}
						delete subSchema.required;
					}
				}
				if (required.length) {
					obj.required = required;
				}
			}
			if (obj.dependencies) {
				for (var key in obj.dependencies) {
					if (typeof obj.dependencies[key] === 'string') {
						obj.dependencies[key] = [obj.dependencies[key]];
					}
				}
			}
			// This is safe as long as we process our children *after* we collect their "required" properties
			// - otherwise, they'd delete their "required" booleans before we got a chance to see them
			if (typeof obj.required === 'boolean') {
				delete obj.required;
			}
			
			// Numeric concerns
			if (typeof obj.divisibleBy !== 'undefined') {
				obj.multipleOf = obj.divisibleBy;
				delete obj.divisibleBy;
			}
			
			// This MUST happen at the end of the function, otherwise it'll screw up "required" collection
			for (var key in obj) {
				if (key === "properties" || key === "patternProperties" || key === "dependencies") {
					for (var subKey in obj[key]) {
						obj[key][subKey] = convert3to4(obj[key][subKey]);
					}
				} else if (key !== "enum") {
					if (Array.isArray(obj[key])) {
						for (var i = 0; i < obj[key].length; i++) {
							obj[key][i] = convert3to4(obj[key][i]);
						}
					} else if (typeof obj[key] === "object") {
						obj[key] = convert3to4(obj[key]);
					}
				}
			}
			return obj;
		}

		var api = {
			v4: convert3to4
		};
		
		if (true) {
			module.exports = api;
		}
		return api;
	})();

/***/ },
/* 177 */
/***/ function(module, exports, __webpack_require__) {

	var __WEBPACK_AMD_DEFINE_ARRAY__, __WEBPACK_AMD_DEFINE_RESULT__;//     Underscore.js 1.8.3
	//     http://underscorejs.org
	//     (c) 2009-2015 Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
	//     Underscore may be freely distributed under the MIT license.

	(function() {

	  // Baseline setup
	  // --------------

	  // Establish the root object, `window` in the browser, or `exports` on the server.
	  var root = this;

	  // Save the previous value of the `_` variable.
	  var previousUnderscore = root._;

	  // Save bytes in the minified (but not gzipped) version:
	  var ArrayProto = Array.prototype, ObjProto = Object.prototype, FuncProto = Function.prototype;

	  // Create quick reference variables for speed access to core prototypes.
	  var
	    push             = ArrayProto.push,
	    slice            = ArrayProto.slice,
	    toString         = ObjProto.toString,
	    hasOwnProperty   = ObjProto.hasOwnProperty;

	  // All **ECMAScript 5** native function implementations that we hope to use
	  // are declared here.
	  var
	    nativeIsArray      = Array.isArray,
	    nativeKeys         = Object.keys,
	    nativeBind         = FuncProto.bind,
	    nativeCreate       = Object.create;

	  // Naked function reference for surrogate-prototype-swapping.
	  var Ctor = function(){};

	  // Create a safe reference to the Underscore object for use below.
	  var _ = function(obj) {
	    if (obj instanceof _) return obj;
	    if (!(this instanceof _)) return new _(obj);
	    this._wrapped = obj;
	  };

	  // Export the Underscore object for **Node.js**, with
	  // backwards-compatibility for the old `require()` API. If we're in
	  // the browser, add `_` as a global object.
	  if (true) {
	    if (typeof module !== 'undefined' && module.exports) {
	      exports = module.exports = _;
	    }
	    exports._ = _;
	  } else {
	    root._ = _;
	  }

	  // Current version.
	  _.VERSION = '1.8.3';

	  // Internal function that returns an efficient (for current engines) version
	  // of the passed-in callback, to be repeatedly applied in other Underscore
	  // functions.
	  var optimizeCb = function(func, context, argCount) {
	    if (context === void 0) return func;
	    switch (argCount == null ? 3 : argCount) {
	      case 1: return function(value) {
	        return func.call(context, value);
	      };
	      case 2: return function(value, other) {
	        return func.call(context, value, other);
	      };
	      case 3: return function(value, index, collection) {
	        return func.call(context, value, index, collection);
	      };
	      case 4: return function(accumulator, value, index, collection) {
	        return func.call(context, accumulator, value, index, collection);
	      };
	    }
	    return function() {
	      return func.apply(context, arguments);
	    };
	  };

	  // A mostly-internal function to generate callbacks that can be applied
	  // to each element in a collection, returning the desired result — either
	  // identity, an arbitrary callback, a property matcher, or a property accessor.
	  var cb = function(value, context, argCount) {
	    if (value == null) return _.identity;
	    if (_.isFunction(value)) return optimizeCb(value, context, argCount);
	    if (_.isObject(value)) return _.matcher(value);
	    return _.property(value);
	  };
	  _.iteratee = function(value, context) {
	    return cb(value, context, Infinity);
	  };

	  // An internal function for creating assigner functions.
	  var createAssigner = function(keysFunc, undefinedOnly) {
	    return function(obj) {
	      var length = arguments.length;
	      if (length < 2 || obj == null) return obj;
	      for (var index = 1; index < length; index++) {
	        var source = arguments[index],
	            keys = keysFunc(source),
	            l = keys.length;
	        for (var i = 0; i < l; i++) {
	          var key = keys[i];
	          if (!undefinedOnly || obj[key] === void 0) obj[key] = source[key];
	        }
	      }
	      return obj;
	    };
	  };

	  // An internal function for creating a new object that inherits from another.
	  var baseCreate = function(prototype) {
	    if (!_.isObject(prototype)) return {};
	    if (nativeCreate) return nativeCreate(prototype);
	    Ctor.prototype = prototype;
	    var result = new Ctor;
	    Ctor.prototype = null;
	    return result;
	  };

	  var property = function(key) {
	    return function(obj) {
	      return obj == null ? void 0 : obj[key];
	    };
	  };

	  // Helper for collection methods to determine whether a collection
	  // should be iterated as an array or as an object
	  // Related: http://people.mozilla.org/~jorendorff/es6-draft.html#sec-tolength
	  // Avoids a very nasty iOS 8 JIT bug on ARM-64. #2094
	  var MAX_ARRAY_INDEX = Math.pow(2, 53) - 1;
	  var getLength = property('length');
	  var isArrayLike = function(collection) {
	    var length = getLength(collection);
	    return typeof length == 'number' && length >= 0 && length <= MAX_ARRAY_INDEX;
	  };

	  // Collection Functions
	  // --------------------

	  // The cornerstone, an `each` implementation, aka `forEach`.
	  // Handles raw objects in addition to array-likes. Treats all
	  // sparse array-likes as if they were dense.
	  _.each = _.forEach = function(obj, iteratee, context) {
	    iteratee = optimizeCb(iteratee, context);
	    var i, length;
	    if (isArrayLike(obj)) {
	      for (i = 0, length = obj.length; i < length; i++) {
	        iteratee(obj[i], i, obj);
	      }
	    } else {
	      var keys = _.keys(obj);
	      for (i = 0, length = keys.length; i < length; i++) {
	        iteratee(obj[keys[i]], keys[i], obj);
	      }
	    }
	    return obj;
	  };

	  // Return the results of applying the iteratee to each element.
	  _.map = _.collect = function(obj, iteratee, context) {
	    iteratee = cb(iteratee, context);
	    var keys = !isArrayLike(obj) && _.keys(obj),
	        length = (keys || obj).length,
	        results = Array(length);
	    for (var index = 0; index < length; index++) {
	      var currentKey = keys ? keys[index] : index;
	      results[index] = iteratee(obj[currentKey], currentKey, obj);
	    }
	    return results;
	  };

	  // Create a reducing function iterating left or right.
	  function createReduce(dir) {
	    // Optimized iterator function as using arguments.length
	    // in the main function will deoptimize the, see #1991.
	    function iterator(obj, iteratee, memo, keys, index, length) {
	      for (; index >= 0 && index < length; index += dir) {
	        var currentKey = keys ? keys[index] : index;
	        memo = iteratee(memo, obj[currentKey], currentKey, obj);
	      }
	      return memo;
	    }

	    return function(obj, iteratee, memo, context) {
	      iteratee = optimizeCb(iteratee, context, 4);
	      var keys = !isArrayLike(obj) && _.keys(obj),
	          length = (keys || obj).length,
	          index = dir > 0 ? 0 : length - 1;
	      // Determine the initial value if none is provided.
	      if (arguments.length < 3) {
	        memo = obj[keys ? keys[index] : index];
	        index += dir;
	      }
	      return iterator(obj, iteratee, memo, keys, index, length);
	    };
	  }

	  // **Reduce** builds up a single result from a list of values, aka `inject`,
	  // or `foldl`.
	  _.reduce = _.foldl = _.inject = createReduce(1);

	  // The right-associative version of reduce, also known as `foldr`.
	  _.reduceRight = _.foldr = createReduce(-1);

	  // Return the first value which passes a truth test. Aliased as `detect`.
	  _.find = _.detect = function(obj, predicate, context) {
	    var key;
	    if (isArrayLike(obj)) {
	      key = _.findIndex(obj, predicate, context);
	    } else {
	      key = _.findKey(obj, predicate, context);
	    }
	    if (key !== void 0 && key !== -1) return obj[key];
	  };

	  // Return all the elements that pass a truth test.
	  // Aliased as `select`.
	  _.filter = _.select = function(obj, predicate, context) {
	    var results = [];
	    predicate = cb(predicate, context);
	    _.each(obj, function(value, index, list) {
	      if (predicate(value, index, list)) results.push(value);
	    });
	    return results;
	  };

	  // Return all the elements for which a truth test fails.
	  _.reject = function(obj, predicate, context) {
	    return _.filter(obj, _.negate(cb(predicate)), context);
	  };

	  // Determine whether all of the elements match a truth test.
	  // Aliased as `all`.
	  _.every = _.all = function(obj, predicate, context) {
	    predicate = cb(predicate, context);
	    var keys = !isArrayLike(obj) && _.keys(obj),
	        length = (keys || obj).length;
	    for (var index = 0; index < length; index++) {
	      var currentKey = keys ? keys[index] : index;
	      if (!predicate(obj[currentKey], currentKey, obj)) return false;
	    }
	    return true;
	  };

	  // Determine if at least one element in the object matches a truth test.
	  // Aliased as `any`.
	  _.some = _.any = function(obj, predicate, context) {
	    predicate = cb(predicate, context);
	    var keys = !isArrayLike(obj) && _.keys(obj),
	        length = (keys || obj).length;
	    for (var index = 0; index < length; index++) {
	      var currentKey = keys ? keys[index] : index;
	      if (predicate(obj[currentKey], currentKey, obj)) return true;
	    }
	    return false;
	  };

	  // Determine if the array or object contains a given item (using `===`).
	  // Aliased as `includes` and `include`.
	  _.contains = _.includes = _.include = function(obj, item, fromIndex, guard) {
	    if (!isArrayLike(obj)) obj = _.values(obj);
	    if (typeof fromIndex != 'number' || guard) fromIndex = 0;
	    return _.indexOf(obj, item, fromIndex) >= 0;
	  };

	  // Invoke a method (with arguments) on every item in a collection.
	  _.invoke = function(obj, method) {
	    var args = slice.call(arguments, 2);
	    var isFunc = _.isFunction(method);
	    return _.map(obj, function(value) {
	      var func = isFunc ? method : value[method];
	      return func == null ? func : func.apply(value, args);
	    });
	  };

	  // Convenience version of a common use case of `map`: fetching a property.
	  _.pluck = function(obj, key) {
	    return _.map(obj, _.property(key));
	  };

	  // Convenience version of a common use case of `filter`: selecting only objects
	  // containing specific `key:value` pairs.
	  _.where = function(obj, attrs) {
	    return _.filter(obj, _.matcher(attrs));
	  };

	  // Convenience version of a common use case of `find`: getting the first object
	  // containing specific `key:value` pairs.
	  _.findWhere = function(obj, attrs) {
	    return _.find(obj, _.matcher(attrs));
	  };

	  // Return the maximum element (or element-based computation).
	  _.max = function(obj, iteratee, context) {
	    var result = -Infinity, lastComputed = -Infinity,
	        value, computed;
	    if (iteratee == null && obj != null) {
	      obj = isArrayLike(obj) ? obj : _.values(obj);
	      for (var i = 0, length = obj.length; i < length; i++) {
	        value = obj[i];
	        if (value > result) {
	          result = value;
	        }
	      }
	    } else {
	      iteratee = cb(iteratee, context);
	      _.each(obj, function(value, index, list) {
	        computed = iteratee(value, index, list);
	        if (computed > lastComputed || computed === -Infinity && result === -Infinity) {
	          result = value;
	          lastComputed = computed;
	        }
	      });
	    }
	    return result;
	  };

	  // Return the minimum element (or element-based computation).
	  _.min = function(obj, iteratee, context) {
	    var result = Infinity, lastComputed = Infinity,
	        value, computed;
	    if (iteratee == null && obj != null) {
	      obj = isArrayLike(obj) ? obj : _.values(obj);
	      for (var i = 0, length = obj.length; i < length; i++) {
	        value = obj[i];
	        if (value < result) {
	          result = value;
	        }
	      }
	    } else {
	      iteratee = cb(iteratee, context);
	      _.each(obj, function(value, index, list) {
	        computed = iteratee(value, index, list);
	        if (computed < lastComputed || computed === Infinity && result === Infinity) {
	          result = value;
	          lastComputed = computed;
	        }
	      });
	    }
	    return result;
	  };

	  // Shuffle a collection, using the modern version of the
	  // [Fisher-Yates shuffle](http://en.wikipedia.org/wiki/Fisher–Yates_shuffle).
	  _.shuffle = function(obj) {
	    var set = isArrayLike(obj) ? obj : _.values(obj);
	    var length = set.length;
	    var shuffled = Array(length);
	    for (var index = 0, rand; index < length; index++) {
	      rand = _.random(0, index);
	      if (rand !== index) shuffled[index] = shuffled[rand];
	      shuffled[rand] = set[index];
	    }
	    return shuffled;
	  };

	  // Sample **n** random values from a collection.
	  // If **n** is not specified, returns a single random element.
	  // The internal `guard` argument allows it to work with `map`.
	  _.sample = function(obj, n, guard) {
	    if (n == null || guard) {
	      if (!isArrayLike(obj)) obj = _.values(obj);
	      return obj[_.random(obj.length - 1)];
	    }
	    return _.shuffle(obj).slice(0, Math.max(0, n));
	  };

	  // Sort the object's values by a criterion produced by an iteratee.
	  _.sortBy = function(obj, iteratee, context) {
	    iteratee = cb(iteratee, context);
	    return _.pluck(_.map(obj, function(value, index, list) {
	      return {
	        value: value,
	        index: index,
	        criteria: iteratee(value, index, list)
	      };
	    }).sort(function(left, right) {
	      var a = left.criteria;
	      var b = right.criteria;
	      if (a !== b) {
	        if (a > b || a === void 0) return 1;
	        if (a < b || b === void 0) return -1;
	      }
	      return left.index - right.index;
	    }), 'value');
	  };

	  // An internal function used for aggregate "group by" operations.
	  var group = function(behavior) {
	    return function(obj, iteratee, context) {
	      var result = {};
	      iteratee = cb(iteratee, context);
	      _.each(obj, function(value, index) {
	        var key = iteratee(value, index, obj);
	        behavior(result, value, key);
	      });
	      return result;
	    };
	  };

	  // Groups the object's values by a criterion. Pass either a string attribute
	  // to group by, or a function that returns the criterion.
	  _.groupBy = group(function(result, value, key) {
	    if (_.has(result, key)) result[key].push(value); else result[key] = [value];
	  });

	  // Indexes the object's values by a criterion, similar to `groupBy`, but for
	  // when you know that your index values will be unique.
	  _.indexBy = group(function(result, value, key) {
	    result[key] = value;
	  });

	  // Counts instances of an object that group by a certain criterion. Pass
	  // either a string attribute to count by, or a function that returns the
	  // criterion.
	  _.countBy = group(function(result, value, key) {
	    if (_.has(result, key)) result[key]++; else result[key] = 1;
	  });

	  // Safely create a real, live array from anything iterable.
	  _.toArray = function(obj) {
	    if (!obj) return [];
	    if (_.isArray(obj)) return slice.call(obj);
	    if (isArrayLike(obj)) return _.map(obj, _.identity);
	    return _.values(obj);
	  };

	  // Return the number of elements in an object.
	  _.size = function(obj) {
	    if (obj == null) return 0;
	    return isArrayLike(obj) ? obj.length : _.keys(obj).length;
	  };

	  // Split a collection into two arrays: one whose elements all satisfy the given
	  // predicate, and one whose elements all do not satisfy the predicate.
	  _.partition = function(obj, predicate, context) {
	    predicate = cb(predicate, context);
	    var pass = [], fail = [];
	    _.each(obj, function(value, key, obj) {
	      (predicate(value, key, obj) ? pass : fail).push(value);
	    });
	    return [pass, fail];
	  };

	  // Array Functions
	  // ---------------

	  // Get the first element of an array. Passing **n** will return the first N
	  // values in the array. Aliased as `head` and `take`. The **guard** check
	  // allows it to work with `_.map`.
	  _.first = _.head = _.take = function(array, n, guard) {
	    if (array == null) return void 0;
	    if (n == null || guard) return array[0];
	    return _.initial(array, array.length - n);
	  };

	  // Returns everything but the last entry of the array. Especially useful on
	  // the arguments object. Passing **n** will return all the values in
	  // the array, excluding the last N.
	  _.initial = function(array, n, guard) {
	    return slice.call(array, 0, Math.max(0, array.length - (n == null || guard ? 1 : n)));
	  };

	  // Get the last element of an array. Passing **n** will return the last N
	  // values in the array.
	  _.last = function(array, n, guard) {
	    if (array == null) return void 0;
	    if (n == null || guard) return array[array.length - 1];
	    return _.rest(array, Math.max(0, array.length - n));
	  };

	  // Returns everything but the first entry of the array. Aliased as `tail` and `drop`.
	  // Especially useful on the arguments object. Passing an **n** will return
	  // the rest N values in the array.
	  _.rest = _.tail = _.drop = function(array, n, guard) {
	    return slice.call(array, n == null || guard ? 1 : n);
	  };

	  // Trim out all falsy values from an array.
	  _.compact = function(array) {
	    return _.filter(array, _.identity);
	  };

	  // Internal implementation of a recursive `flatten` function.
	  var flatten = function(input, shallow, strict, startIndex) {
	    var output = [], idx = 0;
	    for (var i = startIndex || 0, length = getLength(input); i < length; i++) {
	      var value = input[i];
	      if (isArrayLike(value) && (_.isArray(value) || _.isArguments(value))) {
	        //flatten current level of array or arguments object
	        if (!shallow) value = flatten(value, shallow, strict);
	        var j = 0, len = value.length;
	        output.length += len;
	        while (j < len) {
	          output[idx++] = value[j++];
	        }
	      } else if (!strict) {
	        output[idx++] = value;
	      }
	    }
	    return output;
	  };

	  // Flatten out an array, either recursively (by default), or just one level.
	  _.flatten = function(array, shallow) {
	    return flatten(array, shallow, false);
	  };

	  // Return a version of the array that does not contain the specified value(s).
	  _.without = function(array) {
	    return _.difference(array, slice.call(arguments, 1));
	  };

	  // Produce a duplicate-free version of the array. If the array has already
	  // been sorted, you have the option of using a faster algorithm.
	  // Aliased as `unique`.
	  _.uniq = _.unique = function(array, isSorted, iteratee, context) {
	    if (!_.isBoolean(isSorted)) {
	      context = iteratee;
	      iteratee = isSorted;
	      isSorted = false;
	    }
	    if (iteratee != null) iteratee = cb(iteratee, context);
	    var result = [];
	    var seen = [];
	    for (var i = 0, length = getLength(array); i < length; i++) {
	      var value = array[i],
	          computed = iteratee ? iteratee(value, i, array) : value;
	      if (isSorted) {
	        if (!i || seen !== computed) result.push(value);
	        seen = computed;
	      } else if (iteratee) {
	        if (!_.contains(seen, computed)) {
	          seen.push(computed);
	          result.push(value);
	        }
	      } else if (!_.contains(result, value)) {
	        result.push(value);
	      }
	    }
	    return result;
	  };

	  // Produce an array that contains the union: each distinct element from all of
	  // the passed-in arrays.
	  _.union = function() {
	    return _.uniq(flatten(arguments, true, true));
	  };

	  // Produce an array that contains every item shared between all the
	  // passed-in arrays.
	  _.intersection = function(array) {
	    var result = [];
	    var argsLength = arguments.length;
	    for (var i = 0, length = getLength(array); i < length; i++) {
	      var item = array[i];
	      if (_.contains(result, item)) continue;
	      for (var j = 1; j < argsLength; j++) {
	        if (!_.contains(arguments[j], item)) break;
	      }
	      if (j === argsLength) result.push(item);
	    }
	    return result;
	  };

	  // Take the difference between one array and a number of other arrays.
	  // Only the elements present in just the first array will remain.
	  _.difference = function(array) {
	    var rest = flatten(arguments, true, true, 1);
	    return _.filter(array, function(value){
	      return !_.contains(rest, value);
	    });
	  };

	  // Zip together multiple lists into a single array -- elements that share
	  // an index go together.
	  _.zip = function() {
	    return _.unzip(arguments);
	  };

	  // Complement of _.zip. Unzip accepts an array of arrays and groups
	  // each array's elements on shared indices
	  _.unzip = function(array) {
	    var length = array && _.max(array, getLength).length || 0;
	    var result = Array(length);

	    for (var index = 0; index < length; index++) {
	      result[index] = _.pluck(array, index);
	    }
	    return result;
	  };

	  // Converts lists into objects. Pass either a single array of `[key, value]`
	  // pairs, or two parallel arrays of the same length -- one of keys, and one of
	  // the corresponding values.
	  _.object = function(list, values) {
	    var result = {};
	    for (var i = 0, length = getLength(list); i < length; i++) {
	      if (values) {
	        result[list[i]] = values[i];
	      } else {
	        result[list[i][0]] = list[i][1];
	      }
	    }
	    return result;
	  };

	  // Generator function to create the findIndex and findLastIndex functions
	  function createPredicateIndexFinder(dir) {
	    return function(array, predicate, context) {
	      predicate = cb(predicate, context);
	      var length = getLength(array);
	      var index = dir > 0 ? 0 : length - 1;
	      for (; index >= 0 && index < length; index += dir) {
	        if (predicate(array[index], index, array)) return index;
	      }
	      return -1;
	    };
	  }

	  // Returns the first index on an array-like that passes a predicate test
	  _.findIndex = createPredicateIndexFinder(1);
	  _.findLastIndex = createPredicateIndexFinder(-1);

	  // Use a comparator function to figure out the smallest index at which
	  // an object should be inserted so as to maintain order. Uses binary search.
	  _.sortedIndex = function(array, obj, iteratee, context) {
	    iteratee = cb(iteratee, context, 1);
	    var value = iteratee(obj);
	    var low = 0, high = getLength(array);
	    while (low < high) {
	      var mid = Math.floor((low + high) / 2);
	      if (iteratee(array[mid]) < value) low = mid + 1; else high = mid;
	    }
	    return low;
	  };

	  // Generator function to create the indexOf and lastIndexOf functions
	  function createIndexFinder(dir, predicateFind, sortedIndex) {
	    return function(array, item, idx) {
	      var i = 0, length = getLength(array);
	      if (typeof idx == 'number') {
	        if (dir > 0) {
	            i = idx >= 0 ? idx : Math.max(idx + length, i);
	        } else {
	            length = idx >= 0 ? Math.min(idx + 1, length) : idx + length + 1;
	        }
	      } else if (sortedIndex && idx && length) {
	        idx = sortedIndex(array, item);
	        return array[idx] === item ? idx : -1;
	      }
	      if (item !== item) {
	        idx = predicateFind(slice.call(array, i, length), _.isNaN);
	        return idx >= 0 ? idx + i : -1;
	      }
	      for (idx = dir > 0 ? i : length - 1; idx >= 0 && idx < length; idx += dir) {
	        if (array[idx] === item) return idx;
	      }
	      return -1;
	    };
	  }

	  // Return the position of the first occurrence of an item in an array,
	  // or -1 if the item is not included in the array.
	  // If the array is large and already in sort order, pass `true`
	  // for **isSorted** to use binary search.
	  _.indexOf = createIndexFinder(1, _.findIndex, _.sortedIndex);
	  _.lastIndexOf = createIndexFinder(-1, _.findLastIndex);

	  // Generate an integer Array containing an arithmetic progression. A port of
	  // the native Python `range()` function. See
	  // [the Python documentation](http://docs.python.org/library/functions.html#range).
	  _.range = function(start, stop, step) {
	    if (stop == null) {
	      stop = start || 0;
	      start = 0;
	    }
	    step = step || 1;

	    var length = Math.max(Math.ceil((stop - start) / step), 0);
	    var range = Array(length);

	    for (var idx = 0; idx < length; idx++, start += step) {
	      range[idx] = start;
	    }

	    return range;
	  };

	  // Function (ahem) Functions
	  // ------------------

	  // Determines whether to execute a function as a constructor
	  // or a normal function with the provided arguments
	  var executeBound = function(sourceFunc, boundFunc, context, callingContext, args) {
	    if (!(callingContext instanceof boundFunc)) return sourceFunc.apply(context, args);
	    var self = baseCreate(sourceFunc.prototype);
	    var result = sourceFunc.apply(self, args);
	    if (_.isObject(result)) return result;
	    return self;
	  };

	  // Create a function bound to a given object (assigning `this`, and arguments,
	  // optionally). Delegates to **ECMAScript 5**'s native `Function.bind` if
	  // available.
	  _.bind = function(func, context) {
	    if (nativeBind && func.bind === nativeBind) return nativeBind.apply(func, slice.call(arguments, 1));
	    if (!_.isFunction(func)) throw new TypeError('Bind must be called on a function');
	    var args = slice.call(arguments, 2);
	    var bound = function() {
	      return executeBound(func, bound, context, this, args.concat(slice.call(arguments)));
	    };
	    return bound;
	  };

	  // Partially apply a function by creating a version that has had some of its
	  // arguments pre-filled, without changing its dynamic `this` context. _ acts
	  // as a placeholder, allowing any combination of arguments to be pre-filled.
	  _.partial = function(func) {
	    var boundArgs = slice.call(arguments, 1);
	    var bound = function() {
	      var position = 0, length = boundArgs.length;
	      var args = Array(length);
	      for (var i = 0; i < length; i++) {
	        args[i] = boundArgs[i] === _ ? arguments[position++] : boundArgs[i];
	      }
	      while (position < arguments.length) args.push(arguments[position++]);
	      return executeBound(func, bound, this, this, args);
	    };
	    return bound;
	  };

	  // Bind a number of an object's methods to that object. Remaining arguments
	  // are the method names to be bound. Useful for ensuring that all callbacks
	  // defined on an object belong to it.
	  _.bindAll = function(obj) {
	    var i, length = arguments.length, key;
	    if (length <= 1) throw new Error('bindAll must be passed function names');
	    for (i = 1; i < length; i++) {
	      key = arguments[i];
	      obj[key] = _.bind(obj[key], obj);
	    }
	    return obj;
	  };

	  // Memoize an expensive function by storing its results.
	  _.memoize = function(func, hasher) {
	    var memoize = function(key) {
	      var cache = memoize.cache;
	      var address = '' + (hasher ? hasher.apply(this, arguments) : key);
	      if (!_.has(cache, address)) cache[address] = func.apply(this, arguments);
	      return cache[address];
	    };
	    memoize.cache = {};
	    return memoize;
	  };

	  // Delays a function for the given number of milliseconds, and then calls
	  // it with the arguments supplied.
	  _.delay = function(func, wait) {
	    var args = slice.call(arguments, 2);
	    return setTimeout(function(){
	      return func.apply(null, args);
	    }, wait);
	  };

	  // Defers a function, scheduling it to run after the current call stack has
	  // cleared.
	  _.defer = _.partial(_.delay, _, 1);

	  // Returns a function, that, when invoked, will only be triggered at most once
	  // during a given window of time. Normally, the throttled function will run
	  // as much as it can, without ever going more than once per `wait` duration;
	  // but if you'd like to disable the execution on the leading edge, pass
	  // `{leading: false}`. To disable execution on the trailing edge, ditto.
	  _.throttle = function(func, wait, options) {
	    var context, args, result;
	    var timeout = null;
	    var previous = 0;
	    if (!options) options = {};
	    var later = function() {
	      previous = options.leading === false ? 0 : _.now();
	      timeout = null;
	      result = func.apply(context, args);
	      if (!timeout) context = args = null;
	    };
	    return function() {
	      var now = _.now();
	      if (!previous && options.leading === false) previous = now;
	      var remaining = wait - (now - previous);
	      context = this;
	      args = arguments;
	      if (remaining <= 0 || remaining > wait) {
	        if (timeout) {
	          clearTimeout(timeout);
	          timeout = null;
	        }
	        previous = now;
	        result = func.apply(context, args);
	        if (!timeout) context = args = null;
	      } else if (!timeout && options.trailing !== false) {
	        timeout = setTimeout(later, remaining);
	      }
	      return result;
	    };
	  };

	  // Returns a function, that, as long as it continues to be invoked, will not
	  // be triggered. The function will be called after it stops being called for
	  // N milliseconds. If `immediate` is passed, trigger the function on the
	  // leading edge, instead of the trailing.
	  _.debounce = function(func, wait, immediate) {
	    var timeout, args, context, timestamp, result;

	    var later = function() {
	      var last = _.now() - timestamp;

	      if (last < wait && last >= 0) {
	        timeout = setTimeout(later, wait - last);
	      } else {
	        timeout = null;
	        if (!immediate) {
	          result = func.apply(context, args);
	          if (!timeout) context = args = null;
	        }
	      }
	    };

	    return function() {
	      context = this;
	      args = arguments;
	      timestamp = _.now();
	      var callNow = immediate && !timeout;
	      if (!timeout) timeout = setTimeout(later, wait);
	      if (callNow) {
	        result = func.apply(context, args);
	        context = args = null;
	      }

	      return result;
	    };
	  };

	  // Returns the first function passed as an argument to the second,
	  // allowing you to adjust arguments, run code before and after, and
	  // conditionally execute the original function.
	  _.wrap = function(func, wrapper) {
	    return _.partial(wrapper, func);
	  };

	  // Returns a negated version of the passed-in predicate.
	  _.negate = function(predicate) {
	    return function() {
	      return !predicate.apply(this, arguments);
	    };
	  };

	  // Returns a function that is the composition of a list of functions, each
	  // consuming the return value of the function that follows.
	  _.compose = function() {
	    var args = arguments;
	    var start = args.length - 1;
	    return function() {
	      var i = start;
	      var result = args[start].apply(this, arguments);
	      while (i--) result = args[i].call(this, result);
	      return result;
	    };
	  };

	  // Returns a function that will only be executed on and after the Nth call.
	  _.after = function(times, func) {
	    return function() {
	      if (--times < 1) {
	        return func.apply(this, arguments);
	      }
	    };
	  };

	  // Returns a function that will only be executed up to (but not including) the Nth call.
	  _.before = function(times, func) {
	    var memo;
	    return function() {
	      if (--times > 0) {
	        memo = func.apply(this, arguments);
	      }
	      if (times <= 1) func = null;
	      return memo;
	    };
	  };

	  // Returns a function that will be executed at most one time, no matter how
	  // often you call it. Useful for lazy initialization.
	  _.once = _.partial(_.before, 2);

	  // Object Functions
	  // ----------------

	  // Keys in IE < 9 that won't be iterated by `for key in ...` and thus missed.
	  var hasEnumBug = !{toString: null}.propertyIsEnumerable('toString');
	  var nonEnumerableProps = ['valueOf', 'isPrototypeOf', 'toString',
	                      'propertyIsEnumerable', 'hasOwnProperty', 'toLocaleString'];

	  function collectNonEnumProps(obj, keys) {
	    var nonEnumIdx = nonEnumerableProps.length;
	    var constructor = obj.constructor;
	    var proto = (_.isFunction(constructor) && constructor.prototype) || ObjProto;

	    // Constructor is a special case.
	    var prop = 'constructor';
	    if (_.has(obj, prop) && !_.contains(keys, prop)) keys.push(prop);

	    while (nonEnumIdx--) {
	      prop = nonEnumerableProps[nonEnumIdx];
	      if (prop in obj && obj[prop] !== proto[prop] && !_.contains(keys, prop)) {
	        keys.push(prop);
	      }
	    }
	  }

	  // Retrieve the names of an object's own properties.
	  // Delegates to **ECMAScript 5**'s native `Object.keys`
	  _.keys = function(obj) {
	    if (!_.isObject(obj)) return [];
	    if (nativeKeys) return nativeKeys(obj);
	    var keys = [];
	    for (var key in obj) if (_.has(obj, key)) keys.push(key);
	    // Ahem, IE < 9.
	    if (hasEnumBug) collectNonEnumProps(obj, keys);
	    return keys;
	  };

	  // Retrieve all the property names of an object.
	  _.allKeys = function(obj) {
	    if (!_.isObject(obj)) return [];
	    var keys = [];
	    for (var key in obj) keys.push(key);
	    // Ahem, IE < 9.
	    if (hasEnumBug) collectNonEnumProps(obj, keys);
	    return keys;
	  };

	  // Retrieve the values of an object's properties.
	  _.values = function(obj) {
	    var keys = _.keys(obj);
	    var length = keys.length;
	    var values = Array(length);
	    for (var i = 0; i < length; i++) {
	      values[i] = obj[keys[i]];
	    }
	    return values;
	  };

	  // Returns the results of applying the iteratee to each element of the object
	  // In contrast to _.map it returns an object
	  _.mapObject = function(obj, iteratee, context) {
	    iteratee = cb(iteratee, context);
	    var keys =  _.keys(obj),
	          length = keys.length,
	          results = {},
	          currentKey;
	      for (var index = 0; index < length; index++) {
	        currentKey = keys[index];
	        results[currentKey] = iteratee(obj[currentKey], currentKey, obj);
	      }
	      return results;
	  };

	  // Convert an object into a list of `[key, value]` pairs.
	  _.pairs = function(obj) {
	    var keys = _.keys(obj);
	    var length = keys.length;
	    var pairs = Array(length);
	    for (var i = 0; i < length; i++) {
	      pairs[i] = [keys[i], obj[keys[i]]];
	    }
	    return pairs;
	  };

	  // Invert the keys and values of an object. The values must be serializable.
	  _.invert = function(obj) {
	    var result = {};
	    var keys = _.keys(obj);
	    for (var i = 0, length = keys.length; i < length; i++) {
	      result[obj[keys[i]]] = keys[i];
	    }
	    return result;
	  };

	  // Return a sorted list of the function names available on the object.
	  // Aliased as `methods`
	  _.functions = _.methods = function(obj) {
	    var names = [];
	    for (var key in obj) {
	      if (_.isFunction(obj[key])) names.push(key);
	    }
	    return names.sort();
	  };

	  // Extend a given object with all the properties in passed-in object(s).
	  _.extend = createAssigner(_.allKeys);

	  // Assigns a given object with all the own properties in the passed-in object(s)
	  // (https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object/assign)
	  _.extendOwn = _.assign = createAssigner(_.keys);

	  // Returns the first key on an object that passes a predicate test
	  _.findKey = function(obj, predicate, context) {
	    predicate = cb(predicate, context);
	    var keys = _.keys(obj), key;
	    for (var i = 0, length = keys.length; i < length; i++) {
	      key = keys[i];
	      if (predicate(obj[key], key, obj)) return key;
	    }
	  };

	  // Return a copy of the object only containing the whitelisted properties.
	  _.pick = function(object, oiteratee, context) {
	    var result = {}, obj = object, iteratee, keys;
	    if (obj == null) return result;
	    if (_.isFunction(oiteratee)) {
	      keys = _.allKeys(obj);
	      iteratee = optimizeCb(oiteratee, context);
	    } else {
	      keys = flatten(arguments, false, false, 1);
	      iteratee = function(value, key, obj) { return key in obj; };
	      obj = Object(obj);
	    }
	    for (var i = 0, length = keys.length; i < length; i++) {
	      var key = keys[i];
	      var value = obj[key];
	      if (iteratee(value, key, obj)) result[key] = value;
	    }
	    return result;
	  };

	   // Return a copy of the object without the blacklisted properties.
	  _.omit = function(obj, iteratee, context) {
	    if (_.isFunction(iteratee)) {
	      iteratee = _.negate(iteratee);
	    } else {
	      var keys = _.map(flatten(arguments, false, false, 1), String);
	      iteratee = function(value, key) {
	        return !_.contains(keys, key);
	      };
	    }
	    return _.pick(obj, iteratee, context);
	  };

	  // Fill in a given object with default properties.
	  _.defaults = createAssigner(_.allKeys, true);

	  // Creates an object that inherits from the given prototype object.
	  // If additional properties are provided then they will be added to the
	  // created object.
	  _.create = function(prototype, props) {
	    var result = baseCreate(prototype);
	    if (props) _.extendOwn(result, props);
	    return result;
	  };

	  // Create a (shallow-cloned) duplicate of an object.
	  _.clone = function(obj) {
	    if (!_.isObject(obj)) return obj;
	    return _.isArray(obj) ? obj.slice() : _.extend({}, obj);
	  };

	  // Invokes interceptor with the obj, and then returns obj.
	  // The primary purpose of this method is to "tap into" a method chain, in
	  // order to perform operations on intermediate results within the chain.
	  _.tap = function(obj, interceptor) {
	    interceptor(obj);
	    return obj;
	  };

	  // Returns whether an object has a given set of `key:value` pairs.
	  _.isMatch = function(object, attrs) {
	    var keys = _.keys(attrs), length = keys.length;
	    if (object == null) return !length;
	    var obj = Object(object);
	    for (var i = 0; i < length; i++) {
	      var key = keys[i];
	      if (attrs[key] !== obj[key] || !(key in obj)) return false;
	    }
	    return true;
	  };


	  // Internal recursive comparison function for `isEqual`.
	  var eq = function(a, b, aStack, bStack) {
	    // Identical objects are equal. `0 === -0`, but they aren't identical.
	    // See the [Harmony `egal` proposal](http://wiki.ecmascript.org/doku.php?id=harmony:egal).
	    if (a === b) return a !== 0 || 1 / a === 1 / b;
	    // A strict comparison is necessary because `null == undefined`.
	    if (a == null || b == null) return a === b;
	    // Unwrap any wrapped objects.
	    if (a instanceof _) a = a._wrapped;
	    if (b instanceof _) b = b._wrapped;
	    // Compare `[[Class]]` names.
	    var className = toString.call(a);
	    if (className !== toString.call(b)) return false;
	    switch (className) {
	      // Strings, numbers, regular expressions, dates, and booleans are compared by value.
	      case '[object RegExp]':
	      // RegExps are coerced to strings for comparison (Note: '' + /a/i === '/a/i')
	      case '[object String]':
	        // Primitives and their corresponding object wrappers are equivalent; thus, `"5"` is
	        // equivalent to `new String("5")`.
	        return '' + a === '' + b;
	      case '[object Number]':
	        // `NaN`s are equivalent, but non-reflexive.
	        // Object(NaN) is equivalent to NaN
	        if (+a !== +a) return +b !== +b;
	        // An `egal` comparison is performed for other numeric values.
	        return +a === 0 ? 1 / +a === 1 / b : +a === +b;
	      case '[object Date]':
	      case '[object Boolean]':
	        // Coerce dates and booleans to numeric primitive values. Dates are compared by their
	        // millisecond representations. Note that invalid dates with millisecond representations
	        // of `NaN` are not equivalent.
	        return +a === +b;
	    }

	    var areArrays = className === '[object Array]';
	    if (!areArrays) {
	      if (typeof a != 'object' || typeof b != 'object') return false;

	      // Objects with different constructors are not equivalent, but `Object`s or `Array`s
	      // from different frames are.
	      var aCtor = a.constructor, bCtor = b.constructor;
	      if (aCtor !== bCtor && !(_.isFunction(aCtor) && aCtor instanceof aCtor &&
	                               _.isFunction(bCtor) && bCtor instanceof bCtor)
	                          && ('constructor' in a && 'constructor' in b)) {
	        return false;
	      }
	    }
	    // Assume equality for cyclic structures. The algorithm for detecting cyclic
	    // structures is adapted from ES 5.1 section 15.12.3, abstract operation `JO`.

	    // Initializing stack of traversed objects.
	    // It's done here since we only need them for objects and arrays comparison.
	    aStack = aStack || [];
	    bStack = bStack || [];
	    var length = aStack.length;
	    while (length--) {
	      // Linear search. Performance is inversely proportional to the number of
	      // unique nested structures.
	      if (aStack[length] === a) return bStack[length] === b;
	    }

	    // Add the first object to the stack of traversed objects.
	    aStack.push(a);
	    bStack.push(b);

	    // Recursively compare objects and arrays.
	    if (areArrays) {
	      // Compare array lengths to determine if a deep comparison is necessary.
	      length = a.length;
	      if (length !== b.length) return false;
	      // Deep compare the contents, ignoring non-numeric properties.
	      while (length--) {
	        if (!eq(a[length], b[length], aStack, bStack)) return false;
	      }
	    } else {
	      // Deep compare objects.
	      var keys = _.keys(a), key;
	      length = keys.length;
	      // Ensure that both objects contain the same number of properties before comparing deep equality.
	      if (_.keys(b).length !== length) return false;
	      while (length--) {
	        // Deep compare each member
	        key = keys[length];
	        if (!(_.has(b, key) && eq(a[key], b[key], aStack, bStack))) return false;
	      }
	    }
	    // Remove the first object from the stack of traversed objects.
	    aStack.pop();
	    bStack.pop();
	    return true;
	  };

	  // Perform a deep comparison to check if two objects are equal.
	  _.isEqual = function(a, b) {
	    return eq(a, b);
	  };

	  // Is a given array, string, or object empty?
	  // An "empty" object has no enumerable own-properties.
	  _.isEmpty = function(obj) {
	    if (obj == null) return true;
	    if (isArrayLike(obj) && (_.isArray(obj) || _.isString(obj) || _.isArguments(obj))) return obj.length === 0;
	    return _.keys(obj).length === 0;
	  };

	  // Is a given value a DOM element?
	  _.isElement = function(obj) {
	    return !!(obj && obj.nodeType === 1);
	  };

	  // Is a given value an array?
	  // Delegates to ECMA5's native Array.isArray
	  _.isArray = nativeIsArray || function(obj) {
	    return toString.call(obj) === '[object Array]';
	  };

	  // Is a given variable an object?
	  _.isObject = function(obj) {
	    var type = typeof obj;
	    return type === 'function' || type === 'object' && !!obj;
	  };

	  // Add some isType methods: isArguments, isFunction, isString, isNumber, isDate, isRegExp, isError.
	  _.each(['Arguments', 'Function', 'String', 'Number', 'Date', 'RegExp', 'Error'], function(name) {
	    _['is' + name] = function(obj) {
	      return toString.call(obj) === '[object ' + name + ']';
	    };
	  });

	  // Define a fallback version of the method in browsers (ahem, IE < 9), where
	  // there isn't any inspectable "Arguments" type.
	  if (!_.isArguments(arguments)) {
	    _.isArguments = function(obj) {
	      return _.has(obj, 'callee');
	    };
	  }

	  // Optimize `isFunction` if appropriate. Work around some typeof bugs in old v8,
	  // IE 11 (#1621), and in Safari 8 (#1929).
	  if (typeof /./ != 'function' && typeof Int8Array != 'object') {
	    _.isFunction = function(obj) {
	      return typeof obj == 'function' || false;
	    };
	  }

	  // Is a given object a finite number?
	  _.isFinite = function(obj) {
	    return isFinite(obj) && !isNaN(parseFloat(obj));
	  };

	  // Is the given value `NaN`? (NaN is the only number which does not equal itself).
	  _.isNaN = function(obj) {
	    return _.isNumber(obj) && obj !== +obj;
	  };

	  // Is a given value a boolean?
	  _.isBoolean = function(obj) {
	    return obj === true || obj === false || toString.call(obj) === '[object Boolean]';
	  };

	  // Is a given value equal to null?
	  _.isNull = function(obj) {
	    return obj === null;
	  };

	  // Is a given variable undefined?
	  _.isUndefined = function(obj) {
	    return obj === void 0;
	  };

	  // Shortcut function for checking if an object has a given property directly
	  // on itself (in other words, not on a prototype).
	  _.has = function(obj, key) {
	    return obj != null && hasOwnProperty.call(obj, key);
	  };

	  // Utility Functions
	  // -----------------

	  // Run Underscore.js in *noConflict* mode, returning the `_` variable to its
	  // previous owner. Returns a reference to the Underscore object.
	  _.noConflict = function() {
	    root._ = previousUnderscore;
	    return this;
	  };

	  // Keep the identity function around for default iteratees.
	  _.identity = function(value) {
	    return value;
	  };

	  // Predicate-generating functions. Often useful outside of Underscore.
	  _.constant = function(value) {
	    return function() {
	      return value;
	    };
	  };

	  _.noop = function(){};

	  _.property = property;

	  // Generates a function for a given object that returns a given property.
	  _.propertyOf = function(obj) {
	    return obj == null ? function(){} : function(key) {
	      return obj[key];
	    };
	  };

	  // Returns a predicate for checking whether an object has a given set of
	  // `key:value` pairs.
	  _.matcher = _.matches = function(attrs) {
	    attrs = _.extendOwn({}, attrs);
	    return function(obj) {
	      return _.isMatch(obj, attrs);
	    };
	  };

	  // Run a function **n** times.
	  _.times = function(n, iteratee, context) {
	    var accum = Array(Math.max(0, n));
	    iteratee = optimizeCb(iteratee, context, 1);
	    for (var i = 0; i < n; i++) accum[i] = iteratee(i);
	    return accum;
	  };

	  // Return a random integer between min and max (inclusive).
	  _.random = function(min, max) {
	    if (max == null) {
	      max = min;
	      min = 0;
	    }
	    return min + Math.floor(Math.random() * (max - min + 1));
	  };

	  // A (possibly faster) way to get the current timestamp as an integer.
	  _.now = Date.now || function() {
	    return new Date().getTime();
	  };

	   // List of HTML entities for escaping.
	  var escapeMap = {
	    '&': '&amp;',
	    '<': '&lt;',
	    '>': '&gt;',
	    '"': '&quot;',
	    "'": '&#x27;',
	    '`': '&#x60;'
	  };
	  var unescapeMap = _.invert(escapeMap);

	  // Functions for escaping and unescaping strings to/from HTML interpolation.
	  var createEscaper = function(map) {
	    var escaper = function(match) {
	      return map[match];
	    };
	    // Regexes for identifying a key that needs to be escaped
	    var source = '(?:' + _.keys(map).join('|') + ')';
	    var testRegexp = RegExp(source);
	    var replaceRegexp = RegExp(source, 'g');
	    return function(string) {
	      string = string == null ? '' : '' + string;
	      return testRegexp.test(string) ? string.replace(replaceRegexp, escaper) : string;
	    };
	  };
	  _.escape = createEscaper(escapeMap);
	  _.unescape = createEscaper(unescapeMap);

	  // If the value of the named `property` is a function then invoke it with the
	  // `object` as context; otherwise, return it.
	  _.result = function(object, property, fallback) {
	    var value = object == null ? void 0 : object[property];
	    if (value === void 0) {
	      value = fallback;
	    }
	    return _.isFunction(value) ? value.call(object) : value;
	  };

	  // Generate a unique integer id (unique within the entire client session).
	  // Useful for temporary DOM ids.
	  var idCounter = 0;
	  _.uniqueId = function(prefix) {
	    var id = ++idCounter + '';
	    return prefix ? prefix + id : id;
	  };

	  // By default, Underscore uses ERB-style template delimiters, change the
	  // following template settings to use alternative delimiters.
	  _.templateSettings = {
	    evaluate    : /<%([\s\S]+?)%>/g,
	    interpolate : /<%=([\s\S]+?)%>/g,
	    escape      : /<%-([\s\S]+?)%>/g
	  };

	  // When customizing `templateSettings`, if you don't want to define an
	  // interpolation, evaluation or escaping regex, we need one that is
	  // guaranteed not to match.
	  var noMatch = /(.)^/;

	  // Certain characters need to be escaped so that they can be put into a
	  // string literal.
	  var escapes = {
	    "'":      "'",
	    '\\':     '\\',
	    '\r':     'r',
	    '\n':     'n',
	    '\u2028': 'u2028',
	    '\u2029': 'u2029'
	  };

	  var escaper = /\\|'|\r|\n|\u2028|\u2029/g;

	  var escapeChar = function(match) {
	    return '\\' + escapes[match];
	  };

	  // JavaScript micro-templating, similar to John Resig's implementation.
	  // Underscore templating handles arbitrary delimiters, preserves whitespace,
	  // and correctly escapes quotes within interpolated code.
	  // NB: `oldSettings` only exists for backwards compatibility.
	  _.template = function(text, settings, oldSettings) {
	    if (!settings && oldSettings) settings = oldSettings;
	    settings = _.defaults({}, settings, _.templateSettings);

	    // Combine delimiters into one regular expression via alternation.
	    var matcher = RegExp([
	      (settings.escape || noMatch).source,
	      (settings.interpolate || noMatch).source,
	      (settings.evaluate || noMatch).source
	    ].join('|') + '|$', 'g');

	    // Compile the template source, escaping string literals appropriately.
	    var index = 0;
	    var source = "__p+='";
	    text.replace(matcher, function(match, escape, interpolate, evaluate, offset) {
	      source += text.slice(index, offset).replace(escaper, escapeChar);
	      index = offset + match.length;

	      if (escape) {
	        source += "'+\n((__t=(" + escape + "))==null?'':_.escape(__t))+\n'";
	      } else if (interpolate) {
	        source += "'+\n((__t=(" + interpolate + "))==null?'':__t)+\n'";
	      } else if (evaluate) {
	        source += "';\n" + evaluate + "\n__p+='";
	      }

	      // Adobe VMs need the match returned to produce the correct offest.
	      return match;
	    });
	    source += "';\n";

	    // If a variable is not specified, place data values in local scope.
	    if (!settings.variable) source = 'with(obj||{}){\n' + source + '}\n';

	    source = "var __t,__p='',__j=Array.prototype.join," +
	      "print=function(){__p+=__j.call(arguments,'');};\n" +
	      source + 'return __p;\n';

	    try {
	      var render = new Function(settings.variable || 'obj', '_', source);
	    } catch (e) {
	      e.source = source;
	      throw e;
	    }

	    var template = function(data) {
	      return render.call(this, data, _);
	    };

	    // Provide the compiled source as a convenience for precompilation.
	    var argument = settings.variable || 'obj';
	    template.source = 'function(' + argument + '){\n' + source + '}';

	    return template;
	  };

	  // Add a "chain" function. Start chaining a wrapped Underscore object.
	  _.chain = function(obj) {
	    var instance = _(obj);
	    instance._chain = true;
	    return instance;
	  };

	  // OOP
	  // ---------------
	  // If Underscore is called as a function, it returns a wrapped object that
	  // can be used OO-style. This wrapper holds altered versions of all the
	  // underscore functions. Wrapped objects may be chained.

	  // Helper function to continue chaining intermediate results.
	  var result = function(instance, obj) {
	    return instance._chain ? _(obj).chain() : obj;
	  };

	  // Add your own custom functions to the Underscore object.
	  _.mixin = function(obj) {
	    _.each(_.functions(obj), function(name) {
	      var func = _[name] = obj[name];
	      _.prototype[name] = function() {
	        var args = [this._wrapped];
	        push.apply(args, arguments);
	        return result(this, func.apply(_, args));
	      };
	    });
	  };

	  // Add all of the Underscore functions to the wrapper object.
	  _.mixin(_);

	  // Add all mutator Array functions to the wrapper.
	  _.each(['pop', 'push', 'reverse', 'shift', 'sort', 'splice', 'unshift'], function(name) {
	    var method = ArrayProto[name];
	    _.prototype[name] = function() {
	      var obj = this._wrapped;
	      method.apply(obj, arguments);
	      if ((name === 'shift' || name === 'splice') && obj.length === 0) delete obj[0];
	      return result(this, obj);
	    };
	  });

	  // Add all accessor Array functions to the wrapper.
	  _.each(['concat', 'join', 'slice'], function(name) {
	    var method = ArrayProto[name];
	    _.prototype[name] = function() {
	      return result(this, method.apply(this._wrapped, arguments));
	    };
	  });

	  // Extracts the result from a wrapped and chained object.
	  _.prototype.value = function() {
	    return this._wrapped;
	  };

	  // Provide unwrapping proxy for some methods used in engine operations
	  // such as arithmetic and JSON stringification.
	  _.prototype.valueOf = _.prototype.toJSON = _.prototype.value;

	  _.prototype.toString = function() {
	    return '' + this._wrapped;
	  };

	  // AMD registration happens at the end for compatibility with AMD loaders
	  // that may not enforce next-turn semantics on modules. Even though general
	  // practice for AMD registration is to be anonymous, underscore registers
	  // as a named module because, like jQuery, it is a base library that is
	  // popular enough to be bundled in a third party lib, but not be part of
	  // an AMD load request. Those cases could generate an error when an
	  // anonymous define() is called outside of a loader request.
	  if (true) {
	    !(__WEBPACK_AMD_DEFINE_ARRAY__ = [], __WEBPACK_AMD_DEFINE_RESULT__ = function() {
	      return _;
	    }.apply(exports, __WEBPACK_AMD_DEFINE_ARRAY__), __WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
	  }
	}.call(this));


/***/ },
/* 178 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	var asap = __webpack_require__(231);

	function noop() {}

	// States:
	//
	// 0 - pending
	// 1 - fulfilled with _value
	// 2 - rejected with _value
	// 3 - adopted the state of another promise, _value
	//
	// once the state is no longer pending (0) it is immutable

	// All `_` prefixed properties will be reduced to `_{random number}`
	// at build time to obfuscate them and discourage their use.
	// We don't use symbols or Object.defineProperty to fully hide them
	// because the performance isn't good enough.


	// to avoid using try/catch inside critical functions, we
	// extract them to here.
	var LAST_ERROR = null;
	var IS_ERROR = {};
	function getThen(obj) {
	  try {
	    return obj.then;
	  } catch (ex) {
	    LAST_ERROR = ex;
	    return IS_ERROR;
	  }
	}

	function tryCallOne(fn, a) {
	  try {
	    return fn(a);
	  } catch (ex) {
	    LAST_ERROR = ex;
	    return IS_ERROR;
	  }
	}
	function tryCallTwo(fn, a, b) {
	  try {
	    fn(a, b);
	  } catch (ex) {
	    LAST_ERROR = ex;
	    return IS_ERROR;
	  }
	}

	module.exports = Promise;

	function Promise(fn) {
	  if (typeof this !== 'object') {
	    throw new TypeError('Promises must be constructed via new');
	  }
	  if (typeof fn !== 'function') {
	    throw new TypeError('not a function');
	  }
	  this._45 = 0;
	  this._81 = 0;
	  this._65 = null;
	  this._54 = null;
	  if (fn === noop) return;
	  doResolve(fn, this);
	}
	Promise._10 = null;
	Promise._97 = null;
	Promise._61 = noop;

	Promise.prototype.then = function(onFulfilled, onRejected) {
	  if (this.constructor !== Promise) {
	    return safeThen(this, onFulfilled, onRejected);
	  }
	  var res = new Promise(noop);
	  handle(this, new Handler(onFulfilled, onRejected, res));
	  return res;
	};

	function safeThen(self, onFulfilled, onRejected) {
	  return new self.constructor(function (resolve, reject) {
	    var res = new Promise(noop);
	    res.then(resolve, reject);
	    handle(self, new Handler(onFulfilled, onRejected, res));
	  });
	};
	function handle(self, deferred) {
	  while (self._81 === 3) {
	    self = self._65;
	  }
	  if (Promise._10) {
	    Promise._10(self);
	  }
	  if (self._81 === 0) {
	    if (self._45 === 0) {
	      self._45 = 1;
	      self._54 = deferred;
	      return;
	    }
	    if (self._45 === 1) {
	      self._45 = 2;
	      self._54 = [self._54, deferred];
	      return;
	    }
	    self._54.push(deferred);
	    return;
	  }
	  handleResolved(self, deferred);
	}

	function handleResolved(self, deferred) {
	  asap(function() {
	    var cb = self._81 === 1 ? deferred.onFulfilled : deferred.onRejected;
	    if (cb === null) {
	      if (self._81 === 1) {
	        resolve(deferred.promise, self._65);
	      } else {
	        reject(deferred.promise, self._65);
	      }
	      return;
	    }
	    var ret = tryCallOne(cb, self._65);
	    if (ret === IS_ERROR) {
	      reject(deferred.promise, LAST_ERROR);
	    } else {
	      resolve(deferred.promise, ret);
	    }
	  });
	}
	function resolve(self, newValue) {
	  // Promise Resolution Procedure: https://github.com/promises-aplus/promises-spec#the-promise-resolution-procedure
	  if (newValue === self) {
	    return reject(
	      self,
	      new TypeError('A promise cannot be resolved with itself.')
	    );
	  }
	  if (
	    newValue &&
	    (typeof newValue === 'object' || typeof newValue === 'function')
	  ) {
	    var then = getThen(newValue);
	    if (then === IS_ERROR) {
	      return reject(self, LAST_ERROR);
	    }
	    if (
	      then === self.then &&
	      newValue instanceof Promise
	    ) {
	      self._81 = 3;
	      self._65 = newValue;
	      finale(self);
	      return;
	    } else if (typeof then === 'function') {
	      doResolve(then.bind(newValue), self);
	      return;
	    }
	  }
	  self._81 = 1;
	  self._65 = newValue;
	  finale(self);
	}

	function reject(self, newValue) {
	  self._81 = 2;
	  self._65 = newValue;
	  if (Promise._97) {
	    Promise._97(self, newValue);
	  }
	  finale(self);
	}
	function finale(self) {
	  if (self._45 === 1) {
	    handle(self, self._54);
	    self._54 = null;
	  }
	  if (self._45 === 2) {
	    for (var i = 0; i < self._54.length; i++) {
	      handle(self, self._54[i]);
	    }
	    self._54 = null;
	  }
	}

	function Handler(onFulfilled, onRejected, promise){
	  this.onFulfilled = typeof onFulfilled === 'function' ? onFulfilled : null;
	  this.onRejected = typeof onRejected === 'function' ? onRejected : null;
	  this.promise = promise;
	}

	/**
	 * Take a potentially misbehaving resolver function and make sure
	 * onFulfilled and onRejected are only called once.
	 *
	 * Makes no guarantees about asynchrony.
	 */
	function doResolve(fn, promise) {
	  var done = false;
	  var res = tryCallTwo(fn, function (value) {
	    if (done) return;
	    done = true;
	    resolve(promise, value);
	  }, function (reason) {
	    if (done) return;
	    done = true;
	    reject(promise, reason);
	  })
	  if (!done && res === IS_ERROR) {
	    done = true;
	    reject(promise, LAST_ERROR);
	  }
	}


/***/ },
/* 179 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	var Promise = __webpack_require__(178);

	module.exports = Promise;
	Promise.prototype.done = function (onFulfilled, onRejected) {
	  var self = arguments.length ? this.then.apply(this, arguments) : this;
	  self.then(null, function (err) {
	    setTimeout(function () {
	      throw err;
	    }, 0);
	  });
	};


/***/ },
/* 180 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	var Promise = __webpack_require__(178);

	module.exports = Promise;
	Promise.prototype['finally'] = function (f) {
	  return this.then(function (value) {
	    return Promise.resolve(f()).then(function () {
	      return value;
	    });
	  }, function (err) {
	    return Promise.resolve(f()).then(function () {
	      throw err;
	    });
	  });
	};


/***/ },
/* 181 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	//This file contains the ES6 extensions to the core Promises/A+ API

	var Promise = __webpack_require__(178);

	module.exports = Promise;

	/* Static Functions */

	var TRUE = valuePromise(true);
	var FALSE = valuePromise(false);
	var NULL = valuePromise(null);
	var UNDEFINED = valuePromise(undefined);
	var ZERO = valuePromise(0);
	var EMPTYSTRING = valuePromise('');

	function valuePromise(value) {
	  var p = new Promise(Promise._61);
	  p._81 = 1;
	  p._65 = value;
	  return p;
	}
	Promise.resolve = function (value) {
	  if (value instanceof Promise) return value;

	  if (value === null) return NULL;
	  if (value === undefined) return UNDEFINED;
	  if (value === true) return TRUE;
	  if (value === false) return FALSE;
	  if (value === 0) return ZERO;
	  if (value === '') return EMPTYSTRING;

	  if (typeof value === 'object' || typeof value === 'function') {
	    try {
	      var then = value.then;
	      if (typeof then === 'function') {
	        return new Promise(then.bind(value));
	      }
	    } catch (ex) {
	      return new Promise(function (resolve, reject) {
	        reject(ex);
	      });
	    }
	  }
	  return valuePromise(value);
	};

	Promise.all = function (arr) {
	  var args = Array.prototype.slice.call(arr);

	  return new Promise(function (resolve, reject) {
	    if (args.length === 0) return resolve([]);
	    var remaining = args.length;
	    function res(i, val) {
	      if (val && (typeof val === 'object' || typeof val === 'function')) {
	        if (val instanceof Promise && val.then === Promise.prototype.then) {
	          while (val._81 === 3) {
	            val = val._65;
	          }
	          if (val._81 === 1) return res(i, val._65);
	          if (val._81 === 2) reject(val._65);
	          val.then(function (val) {
	            res(i, val);
	          }, reject);
	          return;
	        } else {
	          var then = val.then;
	          if (typeof then === 'function') {
	            var p = new Promise(then.bind(val));
	            p.then(function (val) {
	              res(i, val);
	            }, reject);
	            return;
	          }
	        }
	      }
	      args[i] = val;
	      if (--remaining === 0) {
	        resolve(args);
	      }
	    }
	    for (var i = 0; i < args.length; i++) {
	      res(i, args[i]);
	    }
	  });
	};

	Promise.reject = function (value) {
	  return new Promise(function (resolve, reject) {
	    reject(value);
	  });
	};

	Promise.race = function (values) {
	  return new Promise(function (resolve, reject) {
	    values.forEach(function(value){
	      Promise.resolve(value).then(resolve, reject);
	    });
	  });
	};

	/* Prototype Methods */

	Promise.prototype['catch'] = function (onRejected) {
	  return this.then(null, onRejected);
	};


/***/ },
/* 182 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	// This file contains then/promise specific extensions that are only useful
	// for node.js interop

	var Promise = __webpack_require__(178);
	var asap = __webpack_require__(247);

	module.exports = Promise;

	/* Static Functions */

	Promise.denodeify = function (fn, argumentCount) {
	  if (
	    typeof argumentCount === 'number' && argumentCount !== Infinity
	  ) {
	    return denodeifyWithCount(fn, argumentCount);
	  } else {
	    return denodeifyWithoutCount(fn);
	  }
	}

	var callbackFn = (
	  'function (err, res) {' +
	  'if (err) { rj(err); } else { rs(res); }' +
	  '}'
	);
	function denodeifyWithCount(fn, argumentCount) {
	  var args = [];
	  for (var i = 0; i < argumentCount; i++) {
	    args.push('a' + i);
	  }
	  var body = [
	    'return function (' + args.join(',') + ') {',
	    'var self = this;',
	    'return new Promise(function (rs, rj) {',
	    'var res = fn.call(',
	    ['self'].concat(args).concat([callbackFn]).join(','),
	    ');',
	    'if (res &&',
	    '(typeof res === "object" || typeof res === "function") &&',
	    'typeof res.then === "function"',
	    ') {rs(res);}',
	    '});',
	    '};'
	  ].join('');
	  return Function(['Promise', 'fn'], body)(Promise, fn);
	}
	function denodeifyWithoutCount(fn) {
	  var fnLength = Math.max(fn.length - 1, 3);
	  var args = [];
	  for (var i = 0; i < fnLength; i++) {
	    args.push('a' + i);
	  }
	  var body = [
	    'return function (' + args.join(',') + ') {',
	    'var self = this;',
	    'var args;',
	    'var argLength = arguments.length;',
	    'if (arguments.length > ' + fnLength + ') {',
	    'args = new Array(arguments.length + 1);',
	    'for (var i = 0; i < arguments.length; i++) {',
	    'args[i] = arguments[i];',
	    '}',
	    '}',
	    'return new Promise(function (rs, rj) {',
	    'var cb = ' + callbackFn + ';',
	    'var res;',
	    'switch (argLength) {',
	    args.concat(['extra']).map(function (_, index) {
	      return (
	        'case ' + (index) + ':' +
	        'res = fn.call(' + ['self'].concat(args.slice(0, index)).concat('cb').join(',') + ');' +
	        'break;'
	      );
	    }).join(''),
	    'default:',
	    'args[argLength] = cb;',
	    'res = fn.apply(self, args);',
	    '}',
	    
	    'if (res &&',
	    '(typeof res === "object" || typeof res === "function") &&',
	    'typeof res.then === "function"',
	    ') {rs(res);}',
	    '});',
	    '};'
	  ].join('');

	  return Function(
	    ['Promise', 'fn'],
	    body
	  )(Promise, fn);
	}

	Promise.nodeify = function (fn) {
	  return function () {
	    var args = Array.prototype.slice.call(arguments);
	    var callback =
	      typeof args[args.length - 1] === 'function' ? args.pop() : null;
	    var ctx = this;
	    try {
	      return fn.apply(this, arguments).nodeify(callback, ctx);
	    } catch (ex) {
	      if (callback === null || typeof callback == 'undefined') {
	        return new Promise(function (resolve, reject) {
	          reject(ex);
	        });
	      } else {
	        asap(function () {
	          callback.call(ctx, ex);
	        })
	      }
	    }
	  }
	}

	Promise.prototype.nodeify = function (callback, ctx) {
	  if (typeof callback != 'function') return this;

	  this.then(function (value) {
	    asap(function () {
	      callback.call(ctx, null, value);
	    });
	  }, function (err) {
	    asap(function () {
	      callback.call(ctx, err);
	    });
	  });
	}


/***/ },
/* 183 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	var Promise = __webpack_require__(178);

	module.exports = Promise;
	Promise.enableSynchronous = function () {
	  Promise.prototype.isPending = function() {
	    return this.getState() == 0;
	  };

	  Promise.prototype.isFulfilled = function() {
	    return this.getState() == 1;
	  };

	  Promise.prototype.isRejected = function() {
	    return this.getState() == 2;
	  };

	  Promise.prototype.getValue = function () {
	    if (this._81 === 3) {
	      return this._65.getValue();
	    }

	    if (!this.isFulfilled()) {
	      throw new Error('Cannot get a value of an unfulfilled promise.');
	    }

	    return this._65;
	  };

	  Promise.prototype.getReason = function () {
	    if (this._81 === 3) {
	      return this._65.getReason();
	    }

	    if (!this.isRejected()) {
	      throw new Error('Cannot get a rejection reason of a non-rejected promise.');
	    }

	    return this._65;
	  };

	  Promise.prototype.getState = function () {
	    if (this._81 === 3) {
	      return this._65.getState();
	    }
	    if (this._81 === -1 || this._81 === -2) {
	      return 0;
	    }

	    return this._81;
	  };
	};

	Promise.disableSynchronous = function() {
	  Promise.prototype.isPending = undefined;
	  Promise.prototype.isFulfilled = undefined;
	  Promise.prototype.isRejected = undefined;
	  Promise.prototype.getValue = undefined;
	  Promise.prototype.getReason = undefined;
	  Promise.prototype.getState = undefined;
	};


/***/ },
/* 184 */
/***/ function(module, exports, __webpack_require__) {

	
	var indexOf = [].indexOf;

	module.exports = function(arr, obj){
	  if (indexOf) return arr.indexOf(obj);
	  for (var i = 0; i < arr.length; ++i) {
	    if (arr[i] === obj) return i;
	  }
	  return -1;
	};

/***/ },
/* 185 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';
	var YAMLException = __webpack_require__(107);
	var TYPE_CONSTRUCTOR_OPTIONS = [
	    'kind',
	    'resolve',
	    'construct',
	    'instanceOf',
	    'predicate',
	    'represent',
	    'defaultStyle',
	    'styleAliases'
	];
	var YAML_NODE_KINDS = [
	    'scalar',
	    'sequence',
	    'mapping'
	];
	function compileStyleAliases(map) {
	    var result = {};
	    if (null !== map) {
	        Object.keys(map).forEach(function (style) {
	            map[style].forEach(function (alias) {
	                result[String(alias)] = style;
	            });
	        });
	    }
	    return result;
	}
	function Type(tag, options) {
	    options = options || {};
	    Object.keys(options).forEach(function (name) {
	        if (-1 === TYPE_CONSTRUCTOR_OPTIONS.indexOf(name)) {
	            throw new YAMLException('Unknown option "' + name + '" is met in definition of "' + tag + '" YAML type.');
	        }
	    });
	    this.tag = tag;
	    this.kind = options['kind'] || null;
	    this.resolve = options['resolve'] || function () { return true; };
	    this.construct = options['construct'] || function (data) { return data; };
	    this.instanceOf = options['instanceOf'] || null;
	    this.predicate = options['predicate'] || null;
	    this.represent = options['represent'] || null;
	    this.defaultStyle = options['defaultStyle'] || null;
	    this.styleAliases = compileStyleAliases(options['styleAliases'] || null);
	    if (-1 === YAML_NODE_KINDS.indexOf(this.kind)) {
	        throw new YAMLException('Unknown kind "' + this.kind + '" is specified for "' + tag + '" YAML type.');
	    }
	}
	module.exports = Type;
	//# sourceMappingURL=type.js.map

/***/ },
/* 186 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';
	var Schema = __webpack_require__(149);
	module.exports = new Schema({
	    include: [
	        __webpack_require__(202)
	    ],
	    implicit: [
	        __webpack_require__(203),
	        __webpack_require__(204),
	        __webpack_require__(205),
	        __webpack_require__(206)
	    ]
	});
	//# sourceMappingURL=json.js.map

/***/ },
/* 187 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(process) {"use strict";

	__webpack_require__(207);
	var get               = __webpack_require__(230);
	var Report            = __webpack_require__(208);
	var FormatValidators  = __webpack_require__(209);
	var JsonValidation    = __webpack_require__(210);
	var SchemaCache       = __webpack_require__(211);
	var SchemaCompilation = __webpack_require__(212);
	var SchemaValidation  = __webpack_require__(213);
	var Utils             = __webpack_require__(214);
	var Draft4Schema      = __webpack_require__(232);
	var Draft4HyperSchema = __webpack_require__(233);

	/*
	    default options
	*/
	var defaultOptions = {
	    // default timeout for all async tasks
	    asyncTimeout: 2000,
	    // force additionalProperties and additionalItems to be defined on "object" and "array" types
	    forceAdditional: false,
	    // assume additionalProperties and additionalItems are defined as "false" where appropriate
	    assumeAdditional: false,
	    // force items to be defined on "array" types
	    forceItems: false,
	    // force minItems to be defined on "array" types
	    forceMinItems: false,
	    // force maxItems to be defined on "array" types
	    forceMaxItems: false,
	    // force minLength to be defined on "string" types
	    forceMinLength: false,
	    // force maxLength to be defined on "string" types
	    forceMaxLength: false,
	    // force properties or patternProperties to be defined on "object" types
	    forceProperties: false,
	    // ignore references that cannot be resolved (remote schemas) // TODO: make sure this is only for remote schemas, not local ones
	    ignoreUnresolvableReferences: false,
	    // disallow usage of keywords that this validator can't handle
	    noExtraKeywords: false,
	    // disallow usage of schema's without "type" defined
	    noTypeless: false,
	    // disallow zero length strings in validated objects
	    noEmptyStrings: false,
	    // disallow zero length arrays in validated objects
	    noEmptyArrays: false,
	    // forces "uri" format to be in fully rfc3986 compliant
	    strictUris: false,
	    // turn on some of the above
	    strictMode: false,
	    // report error paths as an array of path segments to get to the offending node
	    reportPathAsArray: false,
	    // stops validation as soon as an error is found, true by default but can be turned off
	    breakOnFirstError: true,
	    // check if schema follow best practices and common sence
	    pedanticCheck: false,
	    // ignore unknown formats (do not report them as an error)
	    ignoreUnknownFormats: false,
	    // function to be called on every schema
	    customValidator: null
	};

	/*
	    constructor
	*/
	function ZSchema(options) {
	    this.cache = {};
	    this.referenceCache = [];

	    this.setRemoteReference("http://json-schema.org/draft-04/schema", Draft4Schema);
	    this.setRemoteReference("http://json-schema.org/draft-04/hyper-schema", Draft4HyperSchema);

	    // options
	    if (typeof options === "object") {
	        var keys = Object.keys(options),
	            idx = keys.length,
	            key;

	        // check that the options are correctly configured
	        while (idx--) {
	            key = keys[idx];
	            if (defaultOptions[key] === undefined) {
	                throw new Error("Unexpected option passed to constructor: " + key);
	            }
	        }

	        // copy the default options into passed options
	        keys = Object.keys(defaultOptions);
	        idx = keys.length;
	        while (idx--) {
	            key = keys[idx];
	            if (options[key] === undefined) {
	                options[key] = Utils.clone(defaultOptions[key]);
	            }
	        }

	        this.options = options;
	    } else {
	        this.options = Utils.clone(defaultOptions);
	    }

	    if (this.options.strictMode === true) {
	        this.options.forceAdditional  = true;
	        this.options.forceItems       = true;
	        this.options.forceMaxLength   = true;
	        this.options.forceProperties  = true;
	        this.options.noExtraKeywords  = true;
	        this.options.noTypeless       = true;
	        this.options.noEmptyStrings   = true;
	        this.options.noEmptyArrays    = true;
	    }

	}

	/*
	    instance methods
	*/
	ZSchema.prototype.compileSchema = function (schema) {
	    var report = new Report(this.options);

	    schema = SchemaCache.getSchema.call(this, report, schema);

	    SchemaCompilation.compileSchema.call(this, report, schema);

	    this.lastReport = report;
	    return report.isValid();
	};
	ZSchema.prototype.validateSchema = function (schema) {
	    if (Array.isArray(schema) && schema.length === 0) {
	        throw new Error(".validateSchema was called with an empty array");
	    }

	    var report = new Report(this.options);

	    schema = SchemaCache.getSchema.call(this, report, schema);

	    var compiled = SchemaCompilation.compileSchema.call(this, report, schema);
	    if (compiled) { SchemaValidation.validateSchema.call(this, report, schema); }

	    this.lastReport = report;
	    return report.isValid();
	};
	ZSchema.prototype.validate = function (json, schema, options, callback) {

	    if (Utils.whatIs(options) === "function") {
	        callback = options;
	        options = {};
	    }
	    if (!options) { options = {}; }

	    var whatIs = Utils.whatIs(schema);
	    if (whatIs !== "string" && whatIs !== "object") {
	        var e = new Error("Invalid .validate call - schema must be an string or object but " + whatIs + " was passed!");
	        if (callback) {
	            process.nextTick(function () {
	                callback(e, false);
	            });
	            return;
	        }
	        throw e;
	    }

	    var foundError = false;
	    var report = new Report(this.options);

	    if (typeof schema === "string") {
	        var schemaName = schema;
	        schema = SchemaCache.getSchema.call(this, report, schemaName);
	        if (!schema) {
	            throw new Error("Schema with id '" + schemaName + "' wasn't found in the validator cache!");
	        }
	    } else {
	        schema = SchemaCache.getSchema.call(this, report, schema);
	    }

	    var compiled = false;
	    if (!foundError) {
	        compiled = SchemaCompilation.compileSchema.call(this, report, schema);
	    }
	    if (!compiled) {
	        this.lastReport = report;
	        foundError = true;
	    }

	    var validated = false;
	    if (!foundError) {
	        validated = SchemaValidation.validateSchema.call(this, report, schema);
	    }
	    if (!validated) {
	        this.lastReport = report;
	        foundError = true;
	    }

	    if (options.schemaPath) {
	        report.rootSchema = schema;
	        schema = get(schema, options.schemaPath);
	        if (!schema) {
	            throw new Error("Schema path '" + options.schemaPath + "' wasn't found in the schema!");
	        }
	    }

	    if (!foundError) {
	        JsonValidation.validate.call(this, report, schema, json);
	    }

	    if (callback) {
	        report.processAsyncTasks(this.options.asyncTimeout, callback);
	        return;
	    } else if (report.asyncTasks.length > 0) {
	        throw new Error("This validation has async tasks and cannot be done in sync mode, please provide callback argument.");
	    }

	    // assign lastReport so errors are retrievable in sync mode
	    this.lastReport = report;
	    return report.isValid();
	};
	ZSchema.prototype.getLastError = function () {
	    if (this.lastReport.errors.length === 0) {
	        return null;
	    }
	    var e = new Error();
	    e.name = "z-schema validation error";
	    e.message = this.lastReport.commonErrorMessage;
	    e.details = this.lastReport.errors;
	    return e;
	};
	ZSchema.prototype.getLastErrors = function () {
	    return this.lastReport && this.lastReport.errors.length > 0 ? this.lastReport.errors : undefined;
	};
	ZSchema.prototype.getMissingReferences = function (arr) {
	    arr = arr || this.lastReport.errors;
	    var res = [],
	        idx = arr.length;
	    while (idx--) {
	        var error = arr[idx];
	        if (error.code === "UNRESOLVABLE_REFERENCE") {
	            var reference = error.params[0];
	            if (res.indexOf(reference) === -1) {
	                res.push(reference);
	            }
	        }
	        if (error.inner) {
	            res = res.concat(this.getMissingReferences(error.inner));
	        }
	    }
	    return res;
	};
	ZSchema.prototype.getMissingRemoteReferences = function () {
	    var missingReferences = this.getMissingReferences(),
	        missingRemoteReferences = [],
	        idx = missingReferences.length;
	    while (idx--) {
	        var remoteReference = SchemaCache.getRemotePath(missingReferences[idx]);
	        if (remoteReference && missingRemoteReferences.indexOf(remoteReference) === -1) {
	            missingRemoteReferences.push(remoteReference);
	        }
	    }
	    return missingRemoteReferences;
	};
	ZSchema.prototype.setRemoteReference = function (uri, schema) {
	    if (typeof schema === "string") {
	        schema = JSON.parse(schema);
	    } else {
	        schema = Utils.cloneDeep(schema);
	    }
	    SchemaCache.cacheSchemaByUri.call(this, uri, schema);
	};
	ZSchema.prototype.getResolvedSchema = function (schema) {
	    var report = new Report(this.options);
	    schema = SchemaCache.getSchema.call(this, report, schema);

	    // clone before making any modifications
	    schema = Utils.cloneDeep(schema);

	    var visited = [];

	    // clean-up the schema and resolve references
	    var cleanup = function (schema) {
	        var key,
	            typeOf = Utils.whatIs(schema);
	        if (typeOf !== "object" && typeOf !== "array") {
	            return;
	        }

	        if (schema.___$visited) {
	            return;
	        }

	        schema.___$visited = true;
	        visited.push(schema);

	        if (schema.$ref && schema.__$refResolved) {
	            var from = schema.__$refResolved;
	            var to = schema;
	            delete schema.$ref;
	            delete schema.__$refResolved;
	            for (key in from) {
	                if (from.hasOwnProperty(key)) {
	                    to[key] = from[key];
	                }
	            }
	        }
	        for (key in schema) {
	            if (schema.hasOwnProperty(key)) {
	                if (key.indexOf("__$") === 0) {
	                    delete schema[key];
	                } else {
	                    cleanup(schema[key]);
	                }
	            }
	        }
	    };

	    cleanup(schema);
	    visited.forEach(function (s) {
	        delete s.___$visited;
	    });

	    this.lastReport = report;
	    if (report.isValid()) {
	        return schema;
	    } else {
	        throw this.getLastError();
	    }
	};
	ZSchema.prototype.setSchemaReader = function (schemaReader) {
	    return ZSchema.setSchemaReader(schemaReader);
	};
	ZSchema.prototype.getSchemaReader = function () {
	    return ZSchema.schemaReader;
	};

	/*
	    static methods
	*/
	ZSchema.setSchemaReader = function (schemaReader) {
	    ZSchema.schemaReader = schemaReader;
	};
	ZSchema.registerFormat = function (formatName, validatorFunction) {
	    FormatValidators[formatName] = validatorFunction;
	};
	ZSchema.unregisterFormat = function (formatName) {
	    delete FormatValidators[formatName];
	};
	ZSchema.getRegisteredFormats = function () {
	    return Object.keys(FormatValidators);
	};
	ZSchema.getDefaultOptions = function () {
	    return Utils.cloneDeep(defaultOptions);
	};

	module.exports = ZSchema;
	
	/* WEBPACK VAR INJECTION */}.call(exports, __webpack_require__(56)))

/***/ },
/* 188 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	var Utils = __webpack_require__(216);

	var internals = {
	    delimiter: '&',
	    arrayPrefixGenerators: {
	        brackets: function (prefix) {
	            return prefix + '[]';
	        },
	        indices: function (prefix, key) {
	            return prefix + '[' + key + ']';
	        },
	        repeat: function (prefix) {
	            return prefix;
	        }
	    },
	    strictNullHandling: false,
	    skipNulls: false,
	    encode: true
	};

	internals.stringify = function (object, prefix, generateArrayPrefix, strictNullHandling, skipNulls, encode, filter, sort, allowDots) {
	    var obj = object;
	    if (typeof filter === 'function') {
	        obj = filter(prefix, obj);
	    } else if (Utils.isBuffer(obj)) {
	        obj = String(obj);
	    } else if (obj instanceof Date) {
	        obj = obj.toISOString();
	    } else if (obj === null) {
	        if (strictNullHandling) {
	            return encode ? Utils.encode(prefix) : prefix;
	        }

	        obj = '';
	    }

	    if (typeof obj === 'string' || typeof obj === 'number' || typeof obj === 'boolean') {
	        if (encode) {
	            return [Utils.encode(prefix) + '=' + Utils.encode(obj)];
	        }
	        return [prefix + '=' + obj];
	    }

	    var values = [];

	    if (typeof obj === 'undefined') {
	        return values;
	    }

	    var objKeys;
	    if (Array.isArray(filter)) {
	        objKeys = filter;
	    } else {
	        var keys = Object.keys(obj);
	        objKeys = sort ? keys.sort(sort) : keys;
	    }

	    for (var i = 0; i < objKeys.length; ++i) {
	        var key = objKeys[i];

	        if (skipNulls && obj[key] === null) {
	            continue;
	        }

	        if (Array.isArray(obj)) {
	            values = values.concat(internals.stringify(obj[key], generateArrayPrefix(prefix, key), generateArrayPrefix, strictNullHandling, skipNulls, encode, filter, sort, allowDots));
	        } else {
	            values = values.concat(internals.stringify(obj[key], prefix + (allowDots ? '.' + key : '[' + key + ']'), generateArrayPrefix, strictNullHandling, skipNulls, encode, filter, sort, allowDots));
	        }
	    }

	    return values;
	};

	module.exports = function (object, opts) {
	    var obj = object;
	    var options = opts || {};
	    var delimiter = typeof options.delimiter === 'undefined' ? internals.delimiter : options.delimiter;
	    var strictNullHandling = typeof options.strictNullHandling === 'boolean' ? options.strictNullHandling : internals.strictNullHandling;
	    var skipNulls = typeof options.skipNulls === 'boolean' ? options.skipNulls : internals.skipNulls;
	    var encode = typeof options.encode === 'boolean' ? options.encode : internals.encode;
	    var sort = typeof options.sort === 'function' ? options.sort : null;
	    var allowDots = typeof options.allowDots === 'undefined' ? false : options.allowDots;
	    var objKeys;
	    var filter;
	    if (typeof options.filter === 'function') {
	        filter = options.filter;
	        obj = filter('', obj);
	    } else if (Array.isArray(options.filter)) {
	        objKeys = filter = options.filter;
	    }

	    var keys = [];

	    if (typeof obj !== 'object' || obj === null) {
	        return '';
	    }

	    var arrayFormat;
	    if (options.arrayFormat in internals.arrayPrefixGenerators) {
	        arrayFormat = options.arrayFormat;
	    } else if ('indices' in options) {
	        arrayFormat = options.indices ? 'indices' : 'repeat';
	    } else {
	        arrayFormat = 'indices';
	    }

	    var generateArrayPrefix = internals.arrayPrefixGenerators[arrayFormat];

	    if (!objKeys) {
	        objKeys = Object.keys(obj);
	    }

	    if (sort) {
	        objKeys.sort(sort);
	    }

	    for (var i = 0; i < objKeys.length; ++i) {
	        var key = objKeys[i];

	        if (skipNulls && obj[key] === null) {
	            continue;
	        }

	        keys = keys.concat(internals.stringify(obj[key], key, generateArrayPrefix, strictNullHandling, skipNulls, encode, filter, sort, allowDots));
	    }

	    return keys.join(delimiter);
	};


/***/ },
/* 189 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	var Utils = __webpack_require__(216);

	var internals = {
	    delimiter: '&',
	    depth: 5,
	    arrayLimit: 20,
	    parameterLimit: 1000,
	    strictNullHandling: false,
	    plainObjects: false,
	    allowPrototypes: false,
	    allowDots: false
	};

	internals.parseValues = function (str, options) {
	    var obj = {};
	    var parts = str.split(options.delimiter, options.parameterLimit === Infinity ? undefined : options.parameterLimit);

	    for (var i = 0; i < parts.length; ++i) {
	        var part = parts[i];
	        var pos = part.indexOf(']=') === -1 ? part.indexOf('=') : part.indexOf(']=') + 1;

	        if (pos === -1) {
	            obj[Utils.decode(part)] = '';

	            if (options.strictNullHandling) {
	                obj[Utils.decode(part)] = null;
	            }
	        } else {
	            var key = Utils.decode(part.slice(0, pos));
	            var val = Utils.decode(part.slice(pos + 1));

	            if (Object.prototype.hasOwnProperty.call(obj, key)) {
	                obj[key] = [].concat(obj[key]).concat(val);
	            } else {
	                obj[key] = val;
	            }
	        }
	    }

	    return obj;
	};

	internals.parseObject = function (chain, val, options) {
	    if (!chain.length) {
	        return val;
	    }

	    var root = chain.shift();

	    var obj;
	    if (root === '[]') {
	        obj = [];
	        obj = obj.concat(internals.parseObject(chain, val, options));
	    } else {
	        obj = options.plainObjects ? Object.create(null) : {};
	        var cleanRoot = root[0] === '[' && root[root.length - 1] === ']' ? root.slice(1, root.length - 1) : root;
	        var index = parseInt(cleanRoot, 10);
	        if (
	            !isNaN(index) &&
	            root !== cleanRoot &&
	            String(index) === cleanRoot &&
	            index >= 0 &&
	            (options.parseArrays && index <= options.arrayLimit)
	        ) {
	            obj = [];
	            obj[index] = internals.parseObject(chain, val, options);
	        } else {
	            obj[cleanRoot] = internals.parseObject(chain, val, options);
	        }
	    }

	    return obj;
	};

	internals.parseKeys = function (givenKey, val, options) {
	    if (!givenKey) {
	        return;
	    }

	    // Transform dot notation to bracket notation
	    var key = options.allowDots ? givenKey.replace(/\.([^\.\[]+)/g, '[$1]') : givenKey;

	    // The regex chunks

	    var parent = /^([^\[\]]*)/;
	    var child = /(\[[^\[\]]*\])/g;

	    // Get the parent

	    var segment = parent.exec(key);

	    // Stash the parent if it exists

	    var keys = [];
	    if (segment[1]) {
	        // If we aren't using plain objects, optionally prefix keys
	        // that would overwrite object prototype properties
	        if (!options.plainObjects && Object.prototype.hasOwnProperty(segment[1])) {
	            if (!options.allowPrototypes) {
	                return;
	            }
	        }

	        keys.push(segment[1]);
	    }

	    // Loop through children appending to the array until we hit depth

	    var i = 0;
	    while ((segment = child.exec(key)) !== null && i < options.depth) {
	        i += 1;
	        if (!options.plainObjects && Object.prototype.hasOwnProperty(segment[1].replace(/\[|\]/g, ''))) {
	            if (!options.allowPrototypes) {
	                continue;
	            }
	        }
	        keys.push(segment[1]);
	    }

	    // If there's a remainder, just add whatever is left

	    if (segment) {
	        keys.push('[' + key.slice(segment.index) + ']');
	    }

	    return internals.parseObject(keys, val, options);
	};

	module.exports = function (str, opts) {
	    var options = opts || {};
	    options.delimiter = typeof options.delimiter === 'string' || Utils.isRegExp(options.delimiter) ? options.delimiter : internals.delimiter;
	    options.depth = typeof options.depth === 'number' ? options.depth : internals.depth;
	    options.arrayLimit = typeof options.arrayLimit === 'number' ? options.arrayLimit : internals.arrayLimit;
	    options.parseArrays = options.parseArrays !== false;
	    options.allowDots = typeof options.allowDots === 'boolean' ? options.allowDots : internals.allowDots;
	    options.plainObjects = typeof options.plainObjects === 'boolean' ? options.plainObjects : internals.plainObjects;
	    options.allowPrototypes = typeof options.allowPrototypes === 'boolean' ? options.allowPrototypes : internals.allowPrototypes;
	    options.parameterLimit = typeof options.parameterLimit === 'number' ? options.parameterLimit : internals.parameterLimit;
	    options.strictNullHandling = typeof options.strictNullHandling === 'boolean' ? options.strictNullHandling : internals.strictNullHandling;

	    if (
	        str === '' ||
	        str === null ||
	        typeof str === 'undefined'
	    ) {
	        return options.plainObjects ? Object.create(null) : {};
	    }

	    var tempObj = typeof str === 'string' ? internals.parseValues(str, options) : str;
	    var obj = options.plainObjects ? Object.create(null) : {};

	    // Iterate over the keys and setup the new object

	    var keys = Object.keys(tempObj);
	    for (var i = 0; i < keys.length; ++i) {
	        var key = keys[i];
	        var newObj = internals.parseKeys(key, tempObj[key], options);
	        obj = Utils.merge(obj, newObj, options);
	    }

	    return Utils.compact(obj);
	};


/***/ },
/* 190 */
/***/ function(module, exports, __webpack_require__) {

	/* (ignored) */

/***/ },
/* 191 */
/***/ function(module, exports, __webpack_require__) {

	/* (ignored) */

/***/ },
/* 192 */
/***/ function(module, exports, __webpack_require__) {

	var __WEBPACK_AMD_DEFINE_ARRAY__, __WEBPACK_AMD_DEFINE_RESULT__;/**
	 * @preserve date-and-time.js (c) KNOWLEDGECODE | MIT
	 */
	(function (global) {
	    'use strict';

	    var date = {},
	        lang = 'en',
	        locales = {
	            en: {
	                MMMM: ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'],
	                MMM: ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
	                dddd: ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday'],
	                ddd: ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'],
	                dd: ['Su', 'Mo', 'Tu', 'We', 'Th', 'Fr', 'Sa'],
	                A: ['a.m.', 'p.m.'],
	                formats: {
	                    YYYY: function (d) { return ('000' + d.getFullYear()).slice(-4); },
	                    YY: function (d) { return ('0' + d.getFullYear()).slice(-2); },
	                    Y: function (d) { return '' + d.getFullYear(); },
	                    MMMM: function (d) { return this.MMMM[d.getMonth()]; },
	                    MMM: function (d) { return this.MMM[d.getMonth()]; },
	                    MM: function (d) { return ('0' + (d.getMonth() + 1)).slice(-2); },
	                    M: function (d) { return '' + (d.getMonth() + 1); },
	                    DD: function (d) { return ('0' + d.getDate()).slice(-2); },
	                    D: function (d) { return '' + d.getDate(); },
	                    HH: function (d) { return ('0' + d.getHours()).slice(-2); },
	                    H: function (d) { return '' + d.getHours(); },
	                    A: function (d) { return this.A[d.getHours() > 11 | 0]; },
	                    hh: function (d) { return ('0' + (d.getHours() % 12 || 12)).slice(-2); },
	                    h: function (d) { return '' + (d.getHours() % 12 || 12); },
	                    mm: function (d) { return ('0' + d.getMinutes()).slice(-2); },
	                    m: function (d) { return '' + d.getMinutes(); },
	                    ss: function (d) { return ('0' + d.getSeconds()).slice(-2); },
	                    s: function (d) { return '' + d.getSeconds(); },
	                    SSS: function (d) { return ('00' + d.getMilliseconds()).slice(-3); },
	                    SS: function (d) { return ('0' + (d.getMilliseconds() / 10 | 0)).slice(-2); },
	                    S: function (d) { return '' + (d.getMilliseconds() / 100 | 0); },
	                    dddd: function (d) { return this.dddd[d.getDay()]; },
	                    ddd: function (d) { return this.ddd[d.getDay()]; },
	                    dd: function (d) { return this.dd[d.getDay()]; },
	                    Z: function (d) {
	                        var offset = d.utc ? 0 : d.getTimezoneOffset() / 0.6;
	                        return (offset > 0 ? '-' : '+') + ('000' + Math.abs(offset - offset % 100 * 0.4)).slice(-4);
	                    },
	                    post: function (str) { return str; }
	                },
	                parsers: {
	                    h: function (h, a) { return (h === 12 ? 0 : h) + a * 12; },
	                    pre: function (str) { return str; }
	                }
	            }
	        },
	        isCommonJS = function () {
	            return typeof module === 'object' && typeof module.exports === 'object';
	        },
	        forEach = function (array, fn) {
	            for (var i = 0, len = array.length; i < len; i++) {
	                if (fn(array[i], i) === 0) {
	                    break;
	                }
	            }
	        },
	        parse = function (dateString, formatString) {
	            var offset = 0, k, length, str,
	                keys = formatString.match(/YYYY|YY|MMM?M?|DD|HH|hh|mm|ss|SSS?|./g),
	                dt = { Y: 0, M: 1, D: 1, A: 0, H: 0, h: 0, m: 0, s: 0, S: 0 };

	            dateString = locales[lang].parsers.pre(dateString);
	            forEach(keys, function (key) {
	                k = key.charAt(0);
	                length = key.length;
	                str = dateString.slice(offset);
	                if (/^(MM|DD|HH|hh|mm|ss|SS?S?)$/.test(key)) {
	                    dt[k] = str.slice(0, length) | 0;
	                } else if (/^(YYYY|YY|M|D|H|h|m|s)$/.test(key)) {
	                    str = (str.match(length === 4 ? /^\d{1,4}/ : /^\d\d?/) || [''])[0];
	                    length = str.length;
	                    dt[k] = str | 0;
	                    if (k === 'Y' && dt.Y < 70) {
	                        dt.Y += 2000;
	                    }
	                } else if (/^(MMMM?|A)$/.test(key)) {
	                    forEach(locales[lang][key], function (val, i) {
	                        if (!str.indexOf(val)) {
	                            dt[k] = k === 'M' ? i + 1 : i;
	                            length = val.length;
	                            return 0;
	                        }
	                    });
	                }
	                offset += length;
	            });
	            return dt;
	        },
	        toH = function (h, a) {
	            return locales[lang].parsers.h(h, a);
	        };

	    /**
	     * formatting a date
	     * @param {Object} dateObj - target date
	     * @param {String} formatString - format string
	     * @param {Boolean} [utc] - output as UTC
	     * @returns {String} the formatted string
	     */
	    date.format = function (dateObj, formatString, utc) {
	        var d = new Date(dateObj.getTime() + (utc ? dateObj.getTimezoneOffset() * 60000 : 0)),
	            locale = locales[lang], formats = locale.formats;

	        d.utc = utc;
	        return formatString.replace(/(\[[^\[\]]*]|\[.*\][^\[]*\]|YYYY|YY|MMM?M?|DD|HH|hh|mm|ss|SSS?|ddd?d?|.)/g, function (token) {
	            var format = formats[token];
	            return format ? formats.post(format.call(locale, d)) : token.replace(/\[(.*)]/, '$1');
	        });
	    };

	    /**
	     * parsing a date string
	     * @param {String} dateString - date string
	     * @param {String} formatString - format string
	     * @param {Boolean} [utc] - input as UTC
	     * @returns {Object} the constructed date
	     */
	    date.parse = function (dateString, formatString, utc) {
	        var dt = parse(dateString, formatString),
	            dateObj = new Date(dt.Y, dt.M - 1, dt.D, dt.H || toH(dt.h, dt.A), dt.m, dt.s, dt.S);

	        return utc ? new Date(dateObj.getTime() - dateObj.getTimezoneOffset() * 60000) : dateObj;
	    };

	    /**
	     * validation
	     * @param {String} dateString - date string
	     * @param {String} formatString - format string
	     * @returns {Boolean} whether the date string is a valid date
	     */
	    date.isValid = function (dateString, formatString) {
	        var dt = parse(dateString, formatString),
	            H = dt.H || toH(dt.h, dt.A),
	            d = new Date(dt.Y, dt.M - 1, dt.D, H, dt.m, dt.s, dt.S);

	        return dt.Y === d.getFullYear() && dt.M - 1 === d.getMonth() && dt.D === d.getDate()
	            && H === d.getHours() && dt.m === d.getMinutes() && dt.s === d.getSeconds()
	            && dt.S === d.getMilliseconds();
	    };

	    /**
	     * adding years
	     * @param {Object} dateObj - the augend
	     * @param {Number} years - the addend
	     * @returns {Object} the date after addition
	     */
	    date.addYears = function (dateObj, years) {
	        var d = new Date(dateObj.getTime());

	        d.setFullYear(d.getFullYear() + years);
	        return d;
	    };

	    /**
	     * adding months
	     * @param {Object} dateObj - the augend
	     * @param {Number} months - the addend
	     * @returns {Object} the date after addition
	     */
	    date.addMonths = function (dateObj, months) {
	        var d = new Date(dateObj.getTime());

	        d.setMonth(d.getMonth() + months);
	        return d;
	    };

	    /**
	     * adding days
	     * @param {Object} dateObj - the augend
	     * @param {Number} days - the addend
	     * @returns {Object} the date after addition
	     */
	    date.addDays = function (dateObj, days) {
	        return new Date(dateObj.getTime() + days * 86400000);
	    };

	    /**
	     * adding hours
	     * @param {Object} dateObj - the augend
	     * @param {Number} hours - the addend
	     * @returns {Object} the date after addition
	     */
	    date.addHours = function (dateObj, hours) {
	        return new Date(dateObj.getTime() + hours * 3600000);
	    };

	    /**
	     * adding minutes
	     * @param {Object} dateObj - the augend
	     * @param {Number} minutes - the addend
	     * @returns {Object} the date after addition
	     */
	    date.addMinutes = function (dateObj, minutes) {
	        return new Date(dateObj.getTime() + minutes * 60000);
	    };

	    /**
	     * adding seconds
	     * @param {Object} dateObj - the augend
	     * @param {Number} seconds - the addend
	     * @returns {Object} the date after addition
	     */
	    date.addSeconds = function (dateObj, seconds) {
	        return new Date(dateObj.getTime() + seconds * 1000);
	    };

	    /**
	     * adding milliseconds
	     * @param {Object} dateObj - the augend
	     * @param {Number} milliseconds - the addend
	     * @returns {Object} the date after addition
	     */
	    date.addMilliseconds = function (dateObj, milliseconds) {
	        return new Date(dateObj.getTime() + milliseconds);
	    };

	    /**
	     * subtracting
	     * @param {Object} date1 - the minuend
	     * @param {Object} date2 - the subtrahend
	     * @returns {Object} the result object after subtraction
	     */
	    date.subtract = function (date1, date2) {
	        var delta = date1.getTime() - date2.getTime();

	        return {
	            toMilliseconds: function () {
	                return delta;
	            },
	            toSeconds: function () {
	                return delta / 1000 | 0;
	            },
	            toMinutes: function () {
	                return delta / 60000 | 0;
	            },
	            toHours: function () {
	                return delta / 3600000 | 0;
	            },
	            toDays: function () {
	                return delta / 86400000 | 0;
	            }
	        };
	    };

	    /**
	     * leap year
	     * @param {Object} dateObj - target date
	     * @returns {Boolean} whether the year is a leap year
	     */
	    date.isLeapYear = function (dateObj) {
	        var y = dateObj.getFullYear();
	        return (!(y % 4) && !!(y % 100)) || !(y % 400);
	    };

	    /**
	     * setting a locale
	     * @param {String} [code] - language code
	     * @returns {String} current language code
	     */
	    date.locale = function (code) {
	        if (code) {
	            if (code !== 'en' && isCommonJS()) {
	                __webpack_require__(222)("./" + code);
	            }
	            lang = code;
	        }
	        return lang;
	    };

	    /**
	     * getting a definition of locale
	     * @param {String} code - language code
	     * @returns {Object} definition of locale
	     */
	    date.getLocales = function (code) {
	        return locales[code || lang];
	    };

	    /**
	     * adding a new definition of locale
	     * @param {String} code - language code
	     * @param {Object} options - definition of locale
	     * @returns {void}
	     */
	    date.setLocales = function (code, options) {
	        var copy = function (src, proto) {
	                var Locale = function () {}, dst, key;

	                Locale.prototype = proto;
	                dst = new Locale();
	                for (key in src) {
	                    if (src.hasOwnProperty(key)) {
	                        dst[key] = src[key];
	                    }
	                }
	                return dst;
	            },
	            base = locales[code] || locales.en,
	            locale = copy(options, base);

	        if (options.formats) {
	            locale.formats = copy(options.formats, base.formats);
	        }
	        if (options.parsers) {
	            locale.parsers = copy(options.parsers, base.parsers);
	        }
	        locales[code] = locale;
	    };

	    if (isCommonJS()) {
	        module.exports = date;
	    } else if (true) {
	        !(__WEBPACK_AMD_DEFINE_ARRAY__ = [], __WEBPACK_AMD_DEFINE_RESULT__ = function () {
	            return date;
	        }.apply(exports, __WEBPACK_AMD_DEFINE_ARRAY__), __WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
	    } else {
	        global.date = date;
	    }

	}(this));



/***/ },
/* 193 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(process) {'use strict';

	if (!process.version ||
	    process.version.indexOf('v0.') === 0 ||
	    process.version.indexOf('v1.') === 0 && process.version.indexOf('v1.8.') !== 0) {
	  module.exports = nextTick;
	} else {
	  module.exports = process.nextTick;
	}

	function nextTick(fn) {
	  var args = new Array(arguments.length - 1);
	  var i = 0;
	  while (i < args.length) {
	    args[i++] = arguments[i];
	  }
	  process.nextTick(function afterTick() {
	    fn.apply(null, args);
	  });
	}
	
	/* WEBPACK VAR INJECTION */}.call(exports, __webpack_require__(56)))

/***/ },
/* 194 */
/***/ function(module, exports, __webpack_require__) {

	// Copyright Joyent, Inc. and other Node contributors.
	//
	// Permission is hereby granted, free of charge, to any person obtaining a
	// copy of this software and associated documentation files (the
	// "Software"), to deal in the Software without restriction, including
	// without limitation the rights to use, copy, modify, merge, publish,
	// distribute, sublicense, and/or sell copies of the Software, and to permit
	// persons to whom the Software is furnished to do so, subject to the
	// following conditions:
	//
	// The above copyright notice and this permission notice shall be included
	// in all copies or substantial portions of the Software.
	//
	// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
	// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
	// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
	// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
	// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
	// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
	// USE OR OTHER DEALINGS IN THE SOFTWARE.

	function EventEmitter() {
	  this._events = this._events || {};
	  this._maxListeners = this._maxListeners || undefined;
	}
	module.exports = EventEmitter;

	// Backwards-compat with node 0.10.x
	EventEmitter.EventEmitter = EventEmitter;

	EventEmitter.prototype._events = undefined;
	EventEmitter.prototype._maxListeners = undefined;

	// By default EventEmitters will print a warning if more than 10 listeners are
	// added to it. This is a useful default which helps finding memory leaks.
	EventEmitter.defaultMaxListeners = 10;

	// Obviously not all Emitters should be limited to 10. This function allows
	// that to be increased. Set to zero for unlimited.
	EventEmitter.prototype.setMaxListeners = function(n) {
	  if (!isNumber(n) || n < 0 || isNaN(n))
	    throw TypeError('n must be a positive number');
	  this._maxListeners = n;
	  return this;
	};

	EventEmitter.prototype.emit = function(type) {
	  var er, handler, len, args, i, listeners;

	  if (!this._events)
	    this._events = {};

	  // If there is no 'error' event listener then throw.
	  if (type === 'error') {
	    if (!this._events.error ||
	        (isObject(this._events.error) && !this._events.error.length)) {
	      er = arguments[1];
	      if (er instanceof Error) {
	        throw er; // Unhandled 'error' event
	      }
	      throw TypeError('Uncaught, unspecified "error" event.');
	    }
	  }

	  handler = this._events[type];

	  if (isUndefined(handler))
	    return false;

	  if (isFunction(handler)) {
	    switch (arguments.length) {
	      // fast cases
	      case 1:
	        handler.call(this);
	        break;
	      case 2:
	        handler.call(this, arguments[1]);
	        break;
	      case 3:
	        handler.call(this, arguments[1], arguments[2]);
	        break;
	      // slower
	      default:
	        args = Array.prototype.slice.call(arguments, 1);
	        handler.apply(this, args);
	    }
	  } else if (isObject(handler)) {
	    args = Array.prototype.slice.call(arguments, 1);
	    listeners = handler.slice();
	    len = listeners.length;
	    for (i = 0; i < len; i++)
	      listeners[i].apply(this, args);
	  }

	  return true;
	};

	EventEmitter.prototype.addListener = function(type, listener) {
	  var m;

	  if (!isFunction(listener))
	    throw TypeError('listener must be a function');

	  if (!this._events)
	    this._events = {};

	  // To avoid recursion in the case that type === "newListener"! Before
	  // adding it to the listeners, first emit "newListener".
	  if (this._events.newListener)
	    this.emit('newListener', type,
	              isFunction(listener.listener) ?
	              listener.listener : listener);

	  if (!this._events[type])
	    // Optimize the case of one listener. Don't need the extra array object.
	    this._events[type] = listener;
	  else if (isObject(this._events[type]))
	    // If we've already got an array, just append.
	    this._events[type].push(listener);
	  else
	    // Adding the second element, need to change to array.
	    this._events[type] = [this._events[type], listener];

	  // Check for listener leak
	  if (isObject(this._events[type]) && !this._events[type].warned) {
	    if (!isUndefined(this._maxListeners)) {
	      m = this._maxListeners;
	    } else {
	      m = EventEmitter.defaultMaxListeners;
	    }

	    if (m && m > 0 && this._events[type].length > m) {
	      this._events[type].warned = true;
	      console.error('(node) warning: possible EventEmitter memory ' +
	                    'leak detected. %d listeners added. ' +
	                    'Use emitter.setMaxListeners() to increase limit.',
	                    this._events[type].length);
	      if (typeof console.trace === 'function') {
	        // not supported in IE 10
	        console.trace();
	      }
	    }
	  }

	  return this;
	};

	EventEmitter.prototype.on = EventEmitter.prototype.addListener;

	EventEmitter.prototype.once = function(type, listener) {
	  if (!isFunction(listener))
	    throw TypeError('listener must be a function');

	  var fired = false;

	  function g() {
	    this.removeListener(type, g);

	    if (!fired) {
	      fired = true;
	      listener.apply(this, arguments);
	    }
	  }

	  g.listener = listener;
	  this.on(type, g);

	  return this;
	};

	// emits a 'removeListener' event iff the listener was removed
	EventEmitter.prototype.removeListener = function(type, listener) {
	  var list, position, length, i;

	  if (!isFunction(listener))
	    throw TypeError('listener must be a function');

	  if (!this._events || !this._events[type])
	    return this;

	  list = this._events[type];
	  length = list.length;
	  position = -1;

	  if (list === listener ||
	      (isFunction(list.listener) && list.listener === listener)) {
	    delete this._events[type];
	    if (this._events.removeListener)
	      this.emit('removeListener', type, listener);

	  } else if (isObject(list)) {
	    for (i = length; i-- > 0;) {
	      if (list[i] === listener ||
	          (list[i].listener && list[i].listener === listener)) {
	        position = i;
	        break;
	      }
	    }

	    if (position < 0)
	      return this;

	    if (list.length === 1) {
	      list.length = 0;
	      delete this._events[type];
	    } else {
	      list.splice(position, 1);
	    }

	    if (this._events.removeListener)
	      this.emit('removeListener', type, listener);
	  }

	  return this;
	};

	EventEmitter.prototype.removeAllListeners = function(type) {
	  var key, listeners;

	  if (!this._events)
	    return this;

	  // not listening for removeListener, no need to emit
	  if (!this._events.removeListener) {
	    if (arguments.length === 0)
	      this._events = {};
	    else if (this._events[type])
	      delete this._events[type];
	    return this;
	  }

	  // emit removeListener for all listeners on all events
	  if (arguments.length === 0) {
	    for (key in this._events) {
	      if (key === 'removeListener') continue;
	      this.removeAllListeners(key);
	    }
	    this.removeAllListeners('removeListener');
	    this._events = {};
	    return this;
	  }

	  listeners = this._events[type];

	  if (isFunction(listeners)) {
	    this.removeListener(type, listeners);
	  } else if (listeners) {
	    // LIFO order
	    while (listeners.length)
	      this.removeListener(type, listeners[listeners.length - 1]);
	  }
	  delete this._events[type];

	  return this;
	};

	EventEmitter.prototype.listeners = function(type) {
	  var ret;
	  if (!this._events || !this._events[type])
	    ret = [];
	  else if (isFunction(this._events[type]))
	    ret = [this._events[type]];
	  else
	    ret = this._events[type].slice();
	  return ret;
	};

	EventEmitter.prototype.listenerCount = function(type) {
	  if (this._events) {
	    var evlistener = this._events[type];

	    if (isFunction(evlistener))
	      return 1;
	    else if (evlistener)
	      return evlistener.length;
	  }
	  return 0;
	};

	EventEmitter.listenerCount = function(emitter, type) {
	  return emitter.listenerCount(type);
	};

	function isFunction(arg) {
	  return typeof arg === 'function';
	}

	function isNumber(arg) {
	  return typeof arg === 'number';
	}

	function isObject(arg) {
	  return typeof arg === 'object' && arg !== null;
	}

	function isUndefined(arg) {
	  return arg === void 0;
	}


/***/ },
/* 195 */
/***/ function(module, exports, __webpack_require__) {

	var toString = {}.toString;

	module.exports = Array.isArray || function (arr) {
	  return toString.call(arr) == '[object Array]';
	};


/***/ },
/* 196 */
/***/ function(module, exports, __webpack_require__) {

	// Copyright Joyent, Inc. and other Node contributors.
	//
	// Permission is hereby granted, free of charge, to any person obtaining a
	// copy of this software and associated documentation files (the
	// "Software"), to deal in the Software without restriction, including
	// without limitation the rights to use, copy, modify, merge, publish,
	// distribute, sublicense, and/or sell copies of the Software, and to permit
	// persons to whom the Software is furnished to do so, subject to the
	// following conditions:
	//
	// The above copyright notice and this permission notice shall be included
	// in all copies or substantial portions of the Software.
	//
	// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
	// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
	// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
	// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
	// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
	// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
	// USE OR OTHER DEALINGS IN THE SOFTWARE.

	var Buffer = __webpack_require__(87).Buffer;

	var isBufferEncoding = Buffer.isEncoding
	  || function(encoding) {
	       switch (encoding && encoding.toLowerCase()) {
	         case 'hex': case 'utf8': case 'utf-8': case 'ascii': case 'binary': case 'base64': case 'ucs2': case 'ucs-2': case 'utf16le': case 'utf-16le': case 'raw': return true;
	         default: return false;
	       }
	     }


	function assertEncoding(encoding) {
	  if (encoding && !isBufferEncoding(encoding)) {
	    throw new Error('Unknown encoding: ' + encoding);
	  }
	}

	// StringDecoder provides an interface for efficiently splitting a series of
	// buffers into a series of JS strings without breaking apart multi-byte
	// characters. CESU-8 is handled as part of the UTF-8 encoding.
	//
	// @TODO Handling all encodings inside a single object makes it very difficult
	// to reason about this code, so it should be split up in the future.
	// @TODO There should be a utf8-strict encoding that rejects invalid UTF-8 code
	// points as used by CESU-8.
	var StringDecoder = exports.StringDecoder = function(encoding) {
	  this.encoding = (encoding || 'utf8').toLowerCase().replace(/[-_]/, '');
	  assertEncoding(encoding);
	  switch (this.encoding) {
	    case 'utf8':
	      // CESU-8 represents each of Surrogate Pair by 3-bytes
	      this.surrogateSize = 3;
	      break;
	    case 'ucs2':
	    case 'utf16le':
	      // UTF-16 represents each of Surrogate Pair by 2-bytes
	      this.surrogateSize = 2;
	      this.detectIncompleteChar = utf16DetectIncompleteChar;
	      break;
	    case 'base64':
	      // Base-64 stores 3 bytes in 4 chars, and pads the remainder.
	      this.surrogateSize = 3;
	      this.detectIncompleteChar = base64DetectIncompleteChar;
	      break;
	    default:
	      this.write = passThroughWrite;
	      return;
	  }

	  // Enough space to store all bytes of a single character. UTF-8 needs 4
	  // bytes, but CESU-8 may require up to 6 (3 bytes per surrogate).
	  this.charBuffer = new Buffer(6);
	  // Number of bytes received for the current incomplete multi-byte character.
	  this.charReceived = 0;
	  // Number of bytes expected for the current incomplete multi-byte character.
	  this.charLength = 0;
	};


	// write decodes the given buffer and returns it as JS string that is
	// guaranteed to not contain any partial multi-byte characters. Any partial
	// character found at the end of the buffer is buffered up, and will be
	// returned when calling write again with the remaining bytes.
	//
	// Note: Converting a Buffer containing an orphan surrogate to a String
	// currently works, but converting a String to a Buffer (via `new Buffer`, or
	// Buffer#write) will replace incomplete surrogates with the unicode
	// replacement character. See https://codereview.chromium.org/121173009/ .
	StringDecoder.prototype.write = function(buffer) {
	  var charStr = '';
	  // if our last write ended with an incomplete multibyte character
	  while (this.charLength) {
	    // determine how many remaining bytes this buffer has to offer for this char
	    var available = (buffer.length >= this.charLength - this.charReceived) ?
	        this.charLength - this.charReceived :
	        buffer.length;

	    // add the new bytes to the char buffer
	    buffer.copy(this.charBuffer, this.charReceived, 0, available);
	    this.charReceived += available;

	    if (this.charReceived < this.charLength) {
	      // still not enough chars in this buffer? wait for more ...
	      return '';
	    }

	    // remove bytes belonging to the current character from the buffer
	    buffer = buffer.slice(available, buffer.length);

	    // get the character that was split
	    charStr = this.charBuffer.slice(0, this.charLength).toString(this.encoding);

	    // CESU-8: lead surrogate (D800-DBFF) is also the incomplete character
	    var charCode = charStr.charCodeAt(charStr.length - 1);
	    if (charCode >= 0xD800 && charCode <= 0xDBFF) {
	      this.charLength += this.surrogateSize;
	      charStr = '';
	      continue;
	    }
	    this.charReceived = this.charLength = 0;

	    // if there are no more bytes in this buffer, just emit our char
	    if (buffer.length === 0) {
	      return charStr;
	    }
	    break;
	  }

	  // determine and set charLength / charReceived
	  this.detectIncompleteChar(buffer);

	  var end = buffer.length;
	  if (this.charLength) {
	    // buffer the incomplete character bytes we got
	    buffer.copy(this.charBuffer, 0, buffer.length - this.charReceived, end);
	    end -= this.charReceived;
	  }

	  charStr += buffer.toString(this.encoding, 0, end);

	  var end = charStr.length - 1;
	  var charCode = charStr.charCodeAt(end);
	  // CESU-8: lead surrogate (D800-DBFF) is also the incomplete character
	  if (charCode >= 0xD800 && charCode <= 0xDBFF) {
	    var size = this.surrogateSize;
	    this.charLength += size;
	    this.charReceived += size;
	    this.charBuffer.copy(this.charBuffer, size, 0, size);
	    buffer.copy(this.charBuffer, 0, 0, size);
	    return charStr.substring(0, end);
	  }

	  // or just emit the charStr
	  return charStr;
	};

	// detectIncompleteChar determines if there is an incomplete UTF-8 character at
	// the end of the given buffer. If so, it sets this.charLength to the byte
	// length that character, and sets this.charReceived to the number of bytes
	// that are available for this character.
	StringDecoder.prototype.detectIncompleteChar = function(buffer) {
	  // determine how many bytes we have to check at the end of this buffer
	  var i = (buffer.length >= 3) ? 3 : buffer.length;

	  // Figure out if one of the last i bytes of our buffer announces an
	  // incomplete char.
	  for (; i > 0; i--) {
	    var c = buffer[buffer.length - i];

	    // See http://en.wikipedia.org/wiki/UTF-8#Description

	    // 110XXXXX
	    if (i == 1 && c >> 5 == 0x06) {
	      this.charLength = 2;
	      break;
	    }

	    // 1110XXXX
	    if (i <= 2 && c >> 4 == 0x0E) {
	      this.charLength = 3;
	      break;
	    }

	    // 11110XXX
	    if (i <= 3 && c >> 3 == 0x1E) {
	      this.charLength = 4;
	      break;
	    }
	  }
	  this.charReceived = i;
	};

	StringDecoder.prototype.end = function(buffer) {
	  var res = '';
	  if (buffer && buffer.length)
	    res = this.write(buffer);

	  if (this.charReceived) {
	    var cr = this.charReceived;
	    var buf = this.charBuffer;
	    var enc = this.encoding;
	    res += buf.slice(0, cr).toString(enc);
	  }

	  return res;
	};

	function passThroughWrite(buffer) {
	  return buffer.toString(this.encoding);
	}

	function utf16DetectIncompleteChar(buffer) {
	  this.charReceived = buffer.length % 2;
	  this.charLength = this.charReceived ? 2 : 0;
	}

	function base64DetectIncompleteChar(buffer) {
	  this.charReceived = buffer.length % 3;
	  this.charLength = this.charReceived ? 3 : 0;
	}


/***/ },
/* 197 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(Buffer) {var xmllint = {};
	var errrCount=0;
	(function() {
	    var module = undefined;
	    var process = undefined;
	    var require = undefined;

	    if(typeof window === 'undefined') {
	        var window = {};
	    }

	    xmllint.validateXML = function (options) {
	        var Module = {
	                xml: options.xml,
	                schema: options.schema
	            }
	            ;
	        

	        Module["preRun"] = (function () {
	            var i;
	            for (i = 0; i < (1 || Module["xml"].length); i++) {
	                FS.createDataFile("/", "file_" + i + ".xml", Module["intArrayFromString"](Module["xml"][i]), true, true)
	            }
	            for (i = 0; i < Module["schema"].length; i++) {
	                FS.createDataFile("/", "file_" + i + ".xsd", Module["intArrayFromString"](Module["schema"][i]), true, true)
	            }
	        });
	        Module.arguments = ["--noout"];
	        ((function () {
	            var i;
	            if ("[object Array]" !== Object.prototype.toString.call(Module["schema"])) {
	                Module["schema"] = [Module["schema"]]
	            }
	            if ("[object Array]" !== Object.prototype.toString.call(Module["xml"])) {
	                Module["xml"] = [Module["xml"]]
	            }
	            for (i = 0; i < Module["schema"].length; i++) {
	                Module.arguments.push("--schema");
	                Module.arguments.push("file_" + i + ".xsd")
	            }
	            for (i = 0; i < (1 || Module["xml"].length); i++) {
	                Module.arguments.push("file_" + i + ".xml")
	            }
	        }))();
	        Module["return"] = "";
	        Module["stdout"] = Module["stderr"] = (function (code) {
	            Module["return"] += String.fromCharCode(code)
	        });
	        var Module;
	        if (!Module)Module = (typeof Module !== "undefined" ? Module : null) || {};
	        var moduleOverrides = {};
	        for (var key in Module) {
	            if (Module.hasOwnProperty(key)) {
	                moduleOverrides[key] = Module[key]
	            }
	        }
	        
	        if (true) {
	            Module["read"] = function read(url) {
	                var xhr = new XMLHttpRequest;
	                xhr.open("GET", url, false);
	                xhr.send(null);
	                return xhr.responseText
	            };
	            if (typeof arguments != "undefined") {
	                Module["arguments"] = arguments
	            }
	            if (typeof console !== "undefined") {
	                if (!Module["print"])Module["print"] = function print(x) {
	                    console.log(x)
	                };
	                if (!Module["printErr"])Module["printErr"] = function printErr(x) {

	                        throw new Error("!_PERF_!")

	                    console.log(x)

	                }
	            } else {
	                var TRY_USE_DUMP = false;
	                if (!Module["print"])Module["print"] = TRY_USE_DUMP && typeof dump !== "undefined" ? (function (x) {
	                    dump(x)
	                }) : (function (x) {
	                })
	            }
	            window["Module"] = Module;
	        } else {
	            throw"Unknown runtime environment. Where are we?"
	        }
	        function globalEval(x) {
	            eval.call(null, x)
	        }

	        if (!Module["load"] && Module["read"]) {
	            Module["load"] = function load(f) {
	                globalEval(Module["read"](f))
	            }
	        }
	        if (!Module["print"]) {
	            Module["print"] = (function () {
	            })
	        }
	        if (!Module["printErr"]) {
	            Module["printErr"] = Module["print"]
	        }
	        if (!Module["arguments"]) {
	            Module["arguments"] = []
	        }
	        if (!Module["thisProgram"]) {
	            Module["thisProgram"] = "./this.program"
	        }
	        Module.print = Module["print"];
	        Module.printErr = Module["printErr"];
	        Module["preRun"] = [];
	        Module["postRun"] = [];
	        for (var key in moduleOverrides) {
	            if (moduleOverrides.hasOwnProperty(key)) {
	                Module[key] = moduleOverrides[key]
	            }
	        }
	        var Runtime = {
	            setTempRet0: (function (value) {
	                tempRet0 = value
	            }), getTempRet0: (function () {
	                return tempRet0
	            }), stackSave: (function () {
	                return STACKTOP
	            }), stackRestore: (function (stackTop) {
	                STACKTOP = stackTop
	            }), getNativeTypeSize: (function (type) {
	                switch (type) {
	                    case"i1":
	                    case"i8":
	                        return 1;
	                    case"i16":
	                        return 2;
	                    case"i32":
	                        return 4;
	                    case"i64":
	                        return 8;
	                    case"float":
	                        return 4;
	                    case"double":
	                        return 8;
	                    default:
	                    {
	                        if (type[type.length - 1] === "*") {
	                            return Runtime.QUANTUM_SIZE
	                        } else if (type[0] === "i") {
	                            var bits = parseInt(type.substr(1));
	                            assert(bits % 8 === 0);
	                            return bits / 8
	                        } else {
	                            return 0
	                        }
	                    }
	                }
	            }), getNativeFieldSize: (function (type) {
	                return Math.max(Runtime.getNativeTypeSize(type), Runtime.QUANTUM_SIZE)
	            }), STACK_ALIGN: 16, getAlignSize: (function (type, size, vararg) {
	                if (!vararg && (type == "i64" || type == "double"))return 8;
	                if (!type)return Math.min(size, 8);
	                return Math.min(size || (type ? Runtime.getNativeFieldSize(type) : 0), Runtime.QUANTUM_SIZE)
	            }), dynCall: (function (sig, ptr, args) {
	                if (args && args.length) {
	                    if (!args.splice)args = Array.prototype.slice.call(args);
	                    args.splice(0, 0, ptr);
	                    return Module["dynCall_" + sig].apply(null, args)
	                } else {
	                    return Module["dynCall_" + sig].call(null, ptr)
	                }
	            }), functionPointers: [], addFunction: (function (func) {
	                for (var i = 0; i < Runtime.functionPointers.length; i++) {
	                    if (!Runtime.functionPointers[i]) {
	                        Runtime.functionPointers[i] = func;
	                        return 2 * (1 + i)
	                    }
	                }
	                throw"Finished up all reserved function pointers. Use a higher value for RESERVED_FUNCTION_POINTERS."
	            }), removeFunction: (function (index) {
	                Runtime.functionPointers[(index - 2) / 2] = null
	            }), getAsmConst: (function (code, numArgs) {
	                if (!Runtime.asmConstCache)Runtime.asmConstCache = {};
	                var func = Runtime.asmConstCache[code];
	                if (func)return func;
	                var args = [];
	                for (var i = 0; i < numArgs; i++) {
	                    args.push(String.fromCharCode(36) + i)
	                }
	                var source = Pointer_stringify(code);
	                if (source[0] === '"') {
	                    if (source.indexOf('"', 1) === source.length - 1) {
	                        source = source.substr(1, source.length - 2)
	                    } else {
	                        abort("invalid EM_ASM input |" + source + "|. Please use EM_ASM(..code..) (no quotes) or EM_ASM({ ..code($0).. }, input) (to input values)")
	                    }
	                }
	                try {
	                    var evalled = eval("(function(Module, FS) { return function(" + args.join(",") + "){ " + source + " } })")(Module, typeof FS !== "undefined" ? FS : null)
	                } catch (e) {
	                    Module.printErr("error in executing inline EM_ASM code: " + e + " on: \n\n" + source + "\n\nwith args |" + args + "| (make sure to use the right one out of EM_ASM, EM_ASM_ARGS, etc.)");
	                    throw e
	                }
	                return Runtime.asmConstCache[code] = evalled
	            }), warnOnce: (function (text) {
	                if (!Runtime.warnOnce.shown)Runtime.warnOnce.shown = {};
	                if (!Runtime.warnOnce.shown[text]) {
	                    Runtime.warnOnce.shown[text] = 1;
	                    Module.printErr(text)
	                }
	            }), funcWrappers: {}, getFuncWrapper: (function (func, sig) {
	                assert(sig);
	                if (!Runtime.funcWrappers[sig]) {
	                    Runtime.funcWrappers[sig] = {}
	                }
	                var sigCache = Runtime.funcWrappers[sig];
	                if (!sigCache[func]) {
	                    sigCache[func] = function dynCall_wrapper() {
	                        return Runtime.dynCall(sig, func, arguments)
	                    }
	                }
	                return sigCache[func]
	            }), UTF8Processor: (function () {
	                var buffer = [];
	                var needed = 0;
	                this.processCChar = (function (code) {
	                    code = code & 255;
	                    if (buffer.length == 0) {
	                        if ((code & 128) == 0) {
	                            return String.fromCharCode(code)
	                        }
	                        buffer.push(code);
	                        if ((code & 224) == 192) {
	                            needed = 1
	                        } else if ((code & 240) == 224) {
	                            needed = 2
	                        } else {
	                            needed = 3
	                        }
	                        return ""
	                    }
	                    if (needed) {
	                        buffer.push(code);
	                        needed--;
	                        if (needed > 0)return ""
	                    }
	                    var c1 = buffer[0];
	                    var c2 = buffer[1];
	                    var c3 = buffer[2];
	                    var c4 = buffer[3];
	                    var ret;
	                    if (buffer.length == 2) {
	                        ret = String.fromCharCode((c1 & 31) << 6 | c2 & 63)
	                    } else if (buffer.length == 3) {
	                        ret = String.fromCharCode((c1 & 15) << 12 | (c2 & 63) << 6 | c3 & 63)
	                    } else {
	                        var codePoint = (c1 & 7) << 18 | (c2 & 63) << 12 | (c3 & 63) << 6 | c4 & 63;
	                        ret = String.fromCharCode(((codePoint - 65536) / 1024 | 0) + 55296, (codePoint - 65536) % 1024 + 56320)
	                    }
	                    buffer.length = 0;
	                    return ret
	                });
	                this.processJSString = function processJSString(string) {
	                    string = unescape(encodeURIComponent(string));
	                    var ret = [];
	                    for (var i = 0; i < string.length; i++) {
	                        ret.push(string.charCodeAt(i))
	                    }
	                    return ret
	                }
	            }), getCompilerSetting: (function (name) {
	                throw"You must build with -s RETAIN_COMPILER_SETTINGS=1 for Runtime.getCompilerSetting or emscripten_get_compiler_setting to work"
	            }), stackAlloc: (function (size) {
	                var ret = STACKTOP;
	                STACKTOP = STACKTOP + size | 0;
	                STACKTOP = STACKTOP + 15 & -16;
	                return ret
	            }), staticAlloc: (function (size) {
	                var ret = STATICTOP;
	                STATICTOP = STATICTOP + size | 0;
	                STATICTOP = STATICTOP + 15 & -16;
	                return ret
	            }), dynamicAlloc: (function (size) {
	                var ret = DYNAMICTOP;
	                DYNAMICTOP = DYNAMICTOP + size | 0;
	                DYNAMICTOP = DYNAMICTOP + 15 & -16;
	                if (DYNAMICTOP >= TOTAL_MEMORY)enlargeMemory();
	                return ret
	            }), alignMemory: (function (size, quantum) {
	                var ret = size = Math.ceil(size / (quantum ? quantum : 16)) * (quantum ? quantum : 16);
	                return ret
	            }), makeBigInt: (function (low, high, unsigned) {
	                var ret = unsigned ? +(low >>> 0) + +(high >>> 0) * +4294967296 : +(low >>> 0) + +(high | 0) * +4294967296;
	                return ret
	            }), GLOBAL_BASE: 8, QUANTUM_SIZE: 4, __dummy__: 0
	        };
	        Module["Runtime"] = Runtime;
	        var __THREW__ = 0;
	        var ABORT = false;
	        var EXITSTATUS = 0;
	        var undef = 0;
	        var tempValue, tempInt, tempBigInt, tempInt2, tempBigInt2, tempPair, tempBigIntI, tempBigIntR, tempBigIntS, tempBigIntP, tempBigIntD, tempDouble, tempFloat;
	        var tempI64, tempI64b;
	        var tempRet0, tempRet1, tempRet2, tempRet3, tempRet4, tempRet5, tempRet6, tempRet7, tempRet8, tempRet9;

	        function assert(condition, text) {
	            if (!condition) {
	                abort("Assertion failed: " + text)
	            }
	        }

	        var globalScope = this;

	        function getCFunc(ident) {
	            var func = Module["_" + ident];
	            if (!func) {
	                try {
	                    func = eval("_" + ident)
	                } catch (e) {
	                }
	            }
	            assert(func, "Cannot call unknown function " + ident + " (perhaps LLVM optimizations or closure removed it?)");
	            return func
	        }

	        var cwrap, ccall;
	        ((function () {
	            var JSfuncs = {
	                "stackSave": (function () {
	                    Runtime.stackSave()
	                }), "stackRestore": (function () {
	                    Runtime.stackRestore()
	                }), "arrayToC": (function (arr) {
	                    var ret = Runtime.stackAlloc(arr.length);
	                    writeArrayToMemory(arr, ret);
	                    return ret
	                }), "stringToC": (function (str) {
	                    var ret = 0;
	                    if (str !== null && str !== undefined && str !== 0) {
	                        ret = Runtime.stackAlloc((str.length << 2) + 1);
	                        writeStringToMemory(str, ret)
	                    }
	                    return ret
	                })
	            };
	            var toC = {"string": JSfuncs["stringToC"], "array": JSfuncs["arrayToC"]};
	            ccall = function ccallFunc(ident, returnType, argTypes, args) {
	                var func = getCFunc(ident);
	                var cArgs = [];
	                var stack = 0;
	                if (args) {
	                    for (var i = 0; i < args.length; i++) {
	                        var converter = toC[argTypes[i]];
	                        if (converter) {
	                            if (stack === 0)stack = Runtime.stackSave();
	                            cArgs[i] = converter(args[i])
	                        } else {
	                            cArgs[i] = args[i]
	                        }
	                    }
	                }
	                var ret = func.apply(null, cArgs);
	                if (returnType === "string")ret = Pointer_stringify(ret);
	                if (stack !== 0)Runtime.stackRestore(stack);
	                return ret
	            };
	            var sourceRegex = /^function\s*\(([^)]*)\)\s*{\s*([^*]*?)[\s;]*(?:return\s*(.*?)[;\s]*)?}$/;

	            function parseJSFunc(jsfunc) {
	                var parsed = jsfunc.toString().match(sourceRegex).slice(1);
	                return {arguments: parsed[0], body: parsed[1], returnValue: parsed[2]}
	            }

	            var JSsource = {};
	            for (var fun in JSfuncs) {
	                if (JSfuncs.hasOwnProperty(fun)) {
	                    JSsource[fun] = parseJSFunc(JSfuncs[fun])
	                }
	            }
	            cwrap = function cwrap(ident, returnType, argTypes) {
	                argTypes = argTypes || [];
	                var cfunc = getCFunc(ident);
	                var numericArgs = argTypes.every((function (type) {
	                    return type === "number"
	                }));
	                var numericRet = returnType !== "string";
	                if (numericRet && numericArgs) {
	                    return cfunc
	                }
	                var argNames = argTypes.map((function (x, i) {
	                    return "$" + i
	                }));
	                var funcstr = "(function(" + argNames.join(",") + ") {";
	                var nargs = argTypes.length;
	                if (!numericArgs) {
	                    funcstr += "var stack = " + JSsource["stackSave"].body + ";";
	                    for (var i = 0; i < nargs; i++) {
	                        var arg = argNames[i], type = argTypes[i];
	                        if (type === "number")continue;
	                        var convertCode = JSsource[type + "ToC"];
	                        funcstr += "var " + convertCode.arguments + " = " + arg + ";";
	                        funcstr += convertCode.body + ";";
	                        funcstr += arg + "=" + convertCode.returnValue + ";"
	                    }
	                }
	                var cfuncname = parseJSFunc((function () {
	                    return cfunc
	                })).returnValue;
	                funcstr += "var ret = " + cfuncname + "(" + argNames.join(",") + ");";
	                if (!numericRet) {
	                    var strgfy = parseJSFunc((function () {
	                        return Pointer_stringify
	                    })).returnValue;
	                    funcstr += "ret = " + strgfy + "(ret);"
	                }
	                if (!numericArgs) {
	                    funcstr += JSsource["stackRestore"].body.replace("()", "(stack)") + ";"
	                }
	                funcstr += "return ret})";
	                return eval(funcstr)
	            }
	        }))();
	        Module["cwrap"] = cwrap;
	        Module["ccall"] = ccall;
	        function setValue(ptr, value, type, noSafe) {
	            type = type || "i8";
	            if (type.charAt(type.length - 1) === "*")type = "i32";
	            switch (type) {
	                case"i1":
	                    HEAP8[ptr >> 0] = value;
	                    break;
	                case"i8":
	                    HEAP8[ptr >> 0] = value;
	                    break;
	                case"i16":
	                    HEAP16[ptr >> 1] = value;
	                    break;
	                case"i32":
	                    HEAP32[ptr >> 2] = value;
	                    break;
	                case"i64":
	                    tempI64 = [value >>> 0, (tempDouble = value, +Math_abs(tempDouble) >= +1 ? tempDouble > +0 ? (Math_min(+Math_floor(tempDouble / +4294967296), +4294967295) | 0) >>> 0 : ~~+Math_ceil((tempDouble - +(~~tempDouble >>> 0)) / +4294967296) >>> 0 : 0)], HEAP32[ptr >> 2] = tempI64[0], HEAP32[ptr + 4 >> 2] = tempI64[1];
	                    break;
	                case"float":
	                    HEAPF32[ptr >> 2] = value;
	                    break;
	                case"double":
	                    HEAPF64[ptr >> 3] = value;
	                    break;
	                default:
	                    abort("invalid type for setValue: " + type)
	            }
	        }

	        Module["setValue"] = setValue;
	        function getValue(ptr, type, noSafe) {
	            type = type || "i8";
	            if (type.charAt(type.length - 1) === "*")type = "i32";
	            switch (type) {
	                case"i1":
	                    return HEAP8[ptr >> 0];
	                case"i8":
	                    return HEAP8[ptr >> 0];
	                case"i16":
	                    return HEAP16[ptr >> 1];
	                case"i32":
	                    return HEAP32[ptr >> 2];
	                case"i64":
	                    return HEAP32[ptr >> 2];
	                case"float":
	                    return HEAPF32[ptr >> 2];
	                case"double":
	                    return HEAPF64[ptr >> 3];
	                default:
	                    abort("invalid type for setValue: " + type)
	            }
	            return null
	        }

	        Module["getValue"] = getValue;
	        var ALLOC_NORMAL = 0;
	        var ALLOC_STACK = 1;
	        var ALLOC_STATIC = 2;
	        var ALLOC_DYNAMIC = 3;
	        var ALLOC_NONE = 4;
	        Module["ALLOC_NORMAL"] = ALLOC_NORMAL;
	        Module["ALLOC_STACK"] = ALLOC_STACK;
	        Module["ALLOC_STATIC"] = ALLOC_STATIC;
	        Module["ALLOC_DYNAMIC"] = ALLOC_DYNAMIC;
	        Module["ALLOC_NONE"] = ALLOC_NONE;
	        function allocate(slab, types, allocator, ptr) {
	            var zeroinit, size;
	            if (typeof slab === "number") {
	                zeroinit = true;
	                size = slab
	            } else {
	                zeroinit = false;
	                size = slab.length
	            }
	            var singleType = typeof types === "string" ? types : null;
	            var ret;
	            if (allocator == ALLOC_NONE) {
	                ret = ptr
	            } else {
	                ret = [_malloc, Runtime.stackAlloc, Runtime.staticAlloc, Runtime.dynamicAlloc][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length))
	            }
	            if (zeroinit) {
	                var ptr = ret, stop;
	                assert((ret & 3) == 0);
	                stop = ret + (size & ~3);
	                for (; ptr < stop; ptr += 4) {
	                    HEAP32[ptr >> 2] = 0
	                }
	                stop = ret + size;
	                while (ptr < stop) {
	                    HEAP8[ptr++ >> 0] = 0
	                }
	                return ret
	            }
	            if (singleType === "i8") {
	                if (slab.subarray || slab.slice) {
	                    HEAPU8.set(slab, ret)
	                } else {
	                    HEAPU8.set(new Uint8Array(slab), ret)
	                }
	                return ret
	            }
	            var i = 0, type, typeSize, previousType;
	            while (i < size) {
	                var curr = slab[i];
	                if (typeof curr === "function") {
	                    curr = Runtime.getFunctionIndex(curr)
	                }
	                type = singleType || types[i];
	                if (type === 0) {
	                    i++;
	                    continue
	                }
	                if (type == "i64")type = "i32";
	                setValue(ret + i, curr, type);
	                if (previousType !== type) {
	                    typeSize = Runtime.getNativeTypeSize(type);
	                    previousType = type
	                }
	                i += typeSize
	            }
	            return ret
	        }

	        Module["allocate"] = allocate;
	        function Pointer_stringify(ptr, length) {
	            if (length === 0 || !ptr)return "";
	            var hasUtf = false;
	            var t;
	            var i = 0;
	            while (1) {
	                t = HEAPU8[ptr + i >> 0];
	                if (t >= 128)hasUtf = true; else if (t == 0 && !length)break;
	                i++;
	                if (length && i == length)break
	            }
	            if (!length)length = i;
	            var ret = "";
	            if (!hasUtf) {
	                var MAX_CHUNK = 1024;
	                var curr;
	                while (length > 0) {
	                    curr = String.fromCharCode.apply(String, HEAPU8.subarray(ptr, ptr + Math.min(length, MAX_CHUNK)));
	                    ret = ret ? ret + curr : curr;
	                    ptr += MAX_CHUNK;
	                    length -= MAX_CHUNK
	                }
	                return ret
	            }
	            var utf8 = new Runtime.UTF8Processor;
	            for (i = 0; i < length; i++) {
	                t = HEAPU8[ptr + i >> 0];
	                ret += utf8.processCChar(t)
	            }
	            return ret
	        }

	        Module["Pointer_stringify"] = Pointer_stringify;
	        function UTF16ToString(ptr) {
	            var i = 0;
	            var str = "";
	            while (1) {
	                var codeUnit = HEAP16[ptr + i * 2 >> 1];
	                if (codeUnit == 0)return str;
	                ++i;
	                str += String.fromCharCode(codeUnit)
	            }
	        }

	        Module["UTF16ToString"] = UTF16ToString;
	        function stringToUTF16(str, outPtr) {
	            for (var i = 0; i < str.length; ++i) {
	                var codeUnit = str.charCodeAt(i);
	                HEAP16[outPtr + i * 2 >> 1] = codeUnit
	            }
	            HEAP16[outPtr + str.length * 2 >> 1] = 0
	        }

	        Module["stringToUTF16"] = stringToUTF16;
	        function UTF32ToString(ptr) {
	            var i = 0;
	            var str = "";
	            while (1) {
	                var utf32 = HEAP32[ptr + i * 4 >> 2];
	                if (utf32 == 0)return str;
	                ++i;
	                if (utf32 >= 65536) {
	                    var ch = utf32 - 65536;
	                    str += String.fromCharCode(55296 | ch >> 10, 56320 | ch & 1023)
	                } else {
	                    str += String.fromCharCode(utf32)
	                }
	            }
	        }

	        Module["UTF32ToString"] = UTF32ToString;
	        function stringToUTF32(str, outPtr) {
	            var iChar = 0;
	            for (var iCodeUnit = 0; iCodeUnit < str.length; ++iCodeUnit) {
	                var codeUnit = str.charCodeAt(iCodeUnit);
	                if (codeUnit >= 55296 && codeUnit <= 57343) {
	                    var trailSurrogate = str.charCodeAt(++iCodeUnit);
	                    codeUnit = 65536 + ((codeUnit & 1023) << 10) | trailSurrogate & 1023
	                }
	                HEAP32[outPtr + iChar * 4 >> 2] = codeUnit;
	                ++iChar
	            }
	            HEAP32[outPtr + iChar * 4 >> 2] = 0
	        }

	        Module["stringToUTF32"] = stringToUTF32;
	        function demangle(func) {
	            var hasLibcxxabi = !!Module["___cxa_demangle"];
	            if (hasLibcxxabi) {
	                try {
	                    var buf = _malloc(func.length);
	                    writeStringToMemory(func.substr(1), buf);
	                    var status = _malloc(4);
	                    var ret = Module["___cxa_demangle"](buf, 0, 0, status);
	                    if (getValue(status, "i32") === 0 && ret) {
	                        return Pointer_stringify(ret)
	                    }
	                } catch (e) {
	                } finally {
	                    if (buf)_free(buf);
	                    if (status)_free(status);
	                    if (ret)_free(ret)
	                }
	            }
	            var i = 3;
	            var basicTypes = {
	                "v": "void",
	                "b": "bool",
	                "c": "char",
	                "s": "short",
	                "i": "int",
	                "l": "long",
	                "f": "float",
	                "d": "double",
	                "w": "wchar_t",
	                "a": "signed char",
	                "h": "unsigned char",
	                "t": "unsigned short",
	                "j": "unsigned int",
	                "m": "unsigned long",
	                "x": "long long",
	                "y": "unsigned long long",
	                "z": "..."
	            };
	            var subs = [];
	            var first = true;

	            function dump(x) {
	                if (x)Module.print(x);
	                Module.print(func);
	                var pre = "";
	                for (var a = 0; a < i; a++)pre += " ";
	                Module.print(pre + "^")
	            }

	            function parseNested() {
	                i++;
	                if (func[i] === "K")i++;
	                var parts = [];
	                while (func[i] !== "E") {
	                    if (func[i] === "S") {
	                        i++;
	                        var next = func.indexOf("_", i);
	                        var num = func.substring(i, next) || 0;
	                        parts.push(subs[num] || "?");
	                        i = next + 1;
	                        continue
	                    }
	                    if (func[i] === "C") {
	                        parts.push(parts[parts.length - 1]);
	                        i += 2;
	                        continue
	                    }
	                    var size = parseInt(func.substr(i));
	                    var pre = size.toString().length;
	                    if (!size || !pre) {
	                        i--;
	                        break
	                    }
	                    var curr = func.substr(i + pre, size);
	                    parts.push(curr);
	                    subs.push(curr);
	                    i += pre + size
	                }
	                i++;
	                return parts
	            }

	            function parse(rawList, limit, allowVoid) {
	                limit = limit || Infinity;
	                var ret = "", list = [];

	                function flushList() {
	                    return "(" + list.join(", ") + ")"
	                }

	                var name;
	                if (func[i] === "N") {
	                    name = parseNested().join("::");
	                    limit--;
	                    if (limit === 0)return rawList ? [name] : name
	                } else {
	                    if (func[i] === "K" || first && func[i] === "L")i++;
	                    var size = parseInt(func.substr(i));
	                    if (size) {
	                        var pre = size.toString().length;
	                        name = func.substr(i + pre, size);
	                        i += pre + size
	                    }
	                }
	                first = false;
	                if (func[i] === "I") {
	                    i++;
	                    var iList = parse(true);
	                    var iRet = parse(true, 1, true);
	                    ret += iRet[0] + " " + name + "<" + iList.join(", ") + ">"
	                } else {
	                    ret = name
	                }
	                paramLoop:while (i < func.length && limit-- > 0) {
	                    var c = func[i++];
	                    if (c in basicTypes) {
	                        list.push(basicTypes[c])
	                    } else {
	                        switch (c) {
	                            case"P":
	                                list.push(parse(true, 1, true)[0] + "*");
	                                break;
	                            case"R":
	                                list.push(parse(true, 1, true)[0] + "&");
	                                break;
	                            case"L":
	                            {
	                                i++;
	                                var end = func.indexOf("E", i);
	                                var size = end - i;
	                                list.push(func.substr(i, size));
	                                i += size + 2;
	                                break
	                            }
	                                ;
	                            case"A":
	                            {
	                                var size = parseInt(func.substr(i));
	                                i += size.toString().length;
	                                if (func[i] !== "_")throw"?";
	                                i++;
	                                list.push(parse(true, 1, true)[0] + " [" + size + "]");
	                                break
	                            }
	                                ;
	                            case"E":
	                                break paramLoop;
	                            default:
	                                ret += "?" + c;
	                                break paramLoop
	                        }
	                    }
	                }
	                if (!allowVoid && list.length === 1 && list[0] === "void")list = [];
	                if (rawList) {
	                    if (ret) {
	                        list.push(ret + "?")
	                    }
	                    return list
	                } else {
	                    return ret + flushList()
	                }
	            }

	            var parsed = func;
	            try {
	                if (func == "Object._main" || func == "_main") {
	                    return "main()"
	                }
	                if (typeof func === "number")func = Pointer_stringify(func);
	                if (func[0] !== "_")return func;
	                if (func[1] !== "_")return func;
	                if (func[2] !== "Z")return func;
	                switch (func[3]) {
	                    case"n":
	                        return "operator new()";
	                    case"d":
	                        return "operator delete()"
	                }
	                parsed = parse()
	            } catch (e) {
	                parsed += "?"
	            }
	            if (parsed.indexOf("?") >= 0 && !hasLibcxxabi) {
	                Runtime.warnOnce("warning: a problem occurred in builtin C++ name demangling; build with  -s DEMANGLE_SUPPORT=1  to link in libcxxabi demangling")
	            }
	            return parsed
	        }

	        function demangleAll(text) {
	            return text.replace(/__Z[\w\d_]+/g, (function (x) {
	                var y = demangle(x);
	                return x === y ? x : x + " [" + y + "]"
	            }))
	        }

	        function jsStackTrace() {
	            var err = new Error;
	            if (!err.stack) {
	                try {
	                    throw new Error(0)
	                } catch (e) {
	                    err = e
	                }
	                if (!err.stack) {
	                    return "(no stack trace available)"
	                }
	            }
	            return err.stack.toString()
	        }

	        function stackTrace() {
	            return demangleAll(jsStackTrace())
	        }

	        Module["stackTrace"] = stackTrace;
	        var PAGE_SIZE = 4096;

	        function alignMemoryPage(x) {
	            return x + 4095 & -4096
	        }

	        var HEAP;
	        var HEAP8, HEAPU8, HEAP16, HEAPU16, HEAP32, HEAPU32, HEAPF32, HEAPF64;
	        var STATIC_BASE = 0, STATICTOP = 0, staticSealed = false;
	        var STACK_BASE = 0, STACKTOP = 0, STACK_MAX = 0;
	        var DYNAMIC_BASE = 0, DYNAMICTOP = 0;

	        function enlargeMemory() {
	            abort("Cannot enlarge memory arrays. Either (1) compile with -s TOTAL_MEMORY=X with X higher than the current value " + TOTAL_MEMORY + ", (2) compile with ALLOW_MEMORY_GROWTH which adjusts the size at runtime but prevents some optimizations, or (3) set Module.TOTAL_MEMORY before the program runs.")
	        }

	        var TOTAL_STACK = Module["TOTAL_STACK"] || 5242880;
	        var TOTAL_MEMORY = Module["TOTAL_MEMORY"] || 16777216;
	        var FAST_MEMORY = Module["FAST_MEMORY"] || 2097152;
	        var totalMemory = 64 * 1024;
	        while (totalMemory < TOTAL_MEMORY || totalMemory < 2 * TOTAL_STACK) {
	            if (totalMemory < 16 * 1024 * 1024) {
	                totalMemory *= 2
	            } else {
	                totalMemory += 16 * 1024 * 1024
	            }
	        }
	        if (totalMemory !== TOTAL_MEMORY) {
	            Module.printErr("increasing TOTAL_MEMORY to " + totalMemory + " to be compliant with the asm.js spec");
	            TOTAL_MEMORY = totalMemory
	        }
	        assert(typeof Int32Array !== "undefined" && typeof Float64Array !== "undefined" && !!(new Int32Array(1))["subarray"] && !!(new Int32Array(1))["set"], "JS engine does not provide full typed array support");
	        var buffer = new ArrayBuffer(TOTAL_MEMORY);
	        HEAP8 = new Int8Array(buffer);
	        HEAP16 = new Int16Array(buffer);
	        HEAP32 = new Int32Array(buffer);
	        HEAPU8 = new Uint8Array(buffer);
	        HEAPU16 = new Uint16Array(buffer);
	        HEAPU32 = new Uint32Array(buffer);
	        HEAPF32 = new Float32Array(buffer);
	        HEAPF64 = new Float64Array(buffer);
	        HEAP32[0] = 255;
	        assert(HEAPU8[0] === 255 && HEAPU8[3] === 0, "Typed arrays 2 must be run on a little-endian system");
	        Module["HEAP"] = HEAP;
	        Module["buffer"] = buffer;
	        Module["HEAP8"] = HEAP8;
	        Module["HEAP16"] = HEAP16;
	        Module["HEAP32"] = HEAP32;
	        Module["HEAPU8"] = HEAPU8;
	        Module["HEAPU16"] = HEAPU16;
	        Module["HEAPU32"] = HEAPU32;
	        Module["HEAPF32"] = HEAPF32;
	        Module["HEAPF64"] = HEAPF64;
	        function callRuntimeCallbacks(callbacks) {
	            while (callbacks.length > 0) {
	                var callback = callbacks.shift();
	                if (typeof callback == "function") {
	                    callback();
	                    continue
	                }
	                var func = callback.func;
	                if (typeof func === "number") {
	                    if (callback.arg === undefined) {
	                        Runtime.dynCall("v", func)
	                    } else {
	                        Runtime.dynCall("vi", func, [callback.arg])
	                    }
	                } else {
	                    func(callback.arg === undefined ? null : callback.arg)
	                }
	            }
	        }

	        var __ATPRERUN__ = [];
	        var __ATINIT__ = [];
	        var __ATMAIN__ = [];
	        var __ATEXIT__ = [];
	        var __ATPOSTRUN__ = [];
	        var runtimeInitialized = false;
	        var runtimeExited = false;

	        function preRun() {
	            if (Module["preRun"]) {
	                if (typeof Module["preRun"] == "function")Module["preRun"] = [Module["preRun"]];
	                while (Module["preRun"].length) {
	                    addOnPreRun(Module["preRun"].shift())
	                }
	            }
	            callRuntimeCallbacks(__ATPRERUN__)
	        }

	        function ensureInitRuntime() {
	            if (runtimeInitialized)return;
	            runtimeInitialized = true;
	            callRuntimeCallbacks(__ATINIT__)
	        }

	        function preMain() {
	            callRuntimeCallbacks(__ATMAIN__)
	        }

	        function exitRuntime() {
	            callRuntimeCallbacks(__ATEXIT__);
	            runtimeExited = true
	        }

	        function postRun() {
	            if (Module["postRun"]) {
	                if (typeof Module["postRun"] == "function")Module["postRun"] = [Module["postRun"]];
	                while (Module["postRun"].length) {
	                    addOnPostRun(Module["postRun"].shift())
	                }
	            }
	            callRuntimeCallbacks(__ATPOSTRUN__)
	        }

	        function addOnPreRun(cb) {
	            __ATPRERUN__.unshift(cb)
	        }

	        Module["addOnPreRun"] = Module.addOnPreRun = addOnPreRun;
	        function addOnInit(cb) {
	            __ATINIT__.unshift(cb)
	        }

	        Module["addOnInit"] = Module.addOnInit = addOnInit;
	        function addOnPreMain(cb) {
	            __ATMAIN__.unshift(cb)
	        }

	        Module["addOnPreMain"] = Module.addOnPreMain = addOnPreMain;
	        function addOnExit(cb) {
	            __ATEXIT__.unshift(cb)
	        }

	        Module["addOnExit"] = Module.addOnExit = addOnExit;
	        function addOnPostRun(cb) {
	            __ATPOSTRUN__.unshift(cb)
	        }

	        Module["addOnPostRun"] = Module.addOnPostRun = addOnPostRun;
	        function intArrayFromString(stringy, dontAddNull, length) {
	            var ret = (new Runtime.UTF8Processor).processJSString(stringy);
	            if (length) {
	                ret.length = length
	            }
	            if (!dontAddNull) {
	                ret.push(0)
	            }
	            return ret
	        }

	        Module["intArrayFromString"] = intArrayFromString;
	        function intArrayToString(array) {
	            var ret = [];
	            for (var i = 0; i < array.length; i++) {
	                var chr = array[i];
	                if (chr > 255) {
	                    chr &= 255
	                }
	                ret.push(String.fromCharCode(chr))
	            }
	            return ret.join("")
	        }

	        Module["intArrayToString"] = intArrayToString;
	        function writeStringToMemory(string, buffer, dontAddNull) {
	            var array = intArrayFromString(string, dontAddNull);
	            var i = 0;
	            while (i < array.length) {
	                var chr = array[i];
	                HEAP8[buffer + i >> 0] = chr;
	                i = i + 1
	            }
	        }

	        Module["writeStringToMemory"] = writeStringToMemory;
	        function writeArrayToMemory(array, buffer) {
	            for (var i = 0; i < array.length; i++) {
	                HEAP8[buffer + i >> 0] = array[i]
	            }
	        }

	        Module["writeArrayToMemory"] = writeArrayToMemory;
	        function writeAsciiToMemory(str, buffer, dontAddNull) {
	            for (var i = 0; i < str.length; i++) {
	                HEAP8[buffer + i >> 0] = str.charCodeAt(i)
	            }
	            if (!dontAddNull)HEAP8[buffer + str.length >> 0] = 0
	        }

	        Module["writeAsciiToMemory"] = writeAsciiToMemory;
	        function unSign(value, bits, ignore) {
	            if (value >= 0) {
	                return value
	            }
	            return bits <= 32 ? 2 * Math.abs(1 << bits - 1) + value : Math.pow(2, bits) + value
	        }

	        function reSign(value, bits, ignore) {
	            if (value <= 0) {
	                return value
	            }
	            var half = bits <= 32 ? Math.abs(1 << bits - 1) : Math.pow(2, bits - 1);
	            if (value >= half && (bits <= 32 || value > half)) {
	                value = -2 * half + value
	            }
	            return value
	        }

	        if (!Math["imul"] || Math["imul"](4294967295, 5) !== -5)Math["imul"] = function imul(a, b) {
	            var ah = a >>> 16;
	            var al = a & 65535;
	            var bh = b >>> 16;
	            var bl = b & 65535;
	            return al * bl + (ah * bl + al * bh << 16) | 0
	        };
	        Math.imul = Math["imul"];
	        var Math_abs = Math.abs;
	        var Math_cos = Math.cos;
	        var Math_sin = Math.sin;
	        var Math_tan = Math.tan;
	        var Math_acos = Math.acos;
	        var Math_asin = Math.asin;
	        var Math_atan = Math.atan;
	        var Math_atan2 = Math.atan2;
	        var Math_exp = Math.exp;
	        var Math_log = Math.log;
	        var Math_sqrt = Math.sqrt;
	        var Math_ceil = Math.ceil;
	        var Math_floor = Math.floor;
	        var Math_pow = Math.pow;
	        var Math_imul = Math.imul;
	        var Math_fround = Math.fround;
	        var Math_min = Math.min;
	        var runDependencies = 0;
	        var runDependencyWatcher = null;
	        var dependenciesFulfilled = null;

	        function addRunDependency(id) {
	            runDependencies++;
	            if (Module["monitorRunDependencies"]) {
	                Module["monitorRunDependencies"](runDependencies)
	            }
	        }

	        Module["addRunDependency"] = addRunDependency;
	        function removeRunDependency(id) {
	            runDependencies--;
	            if (Module["monitorRunDependencies"]) {
	                Module["monitorRunDependencies"](runDependencies)
	            }
	            if (runDependencies == 0) {
	                if (runDependencyWatcher !== null) {
	                    clearInterval(runDependencyWatcher);
	                    runDependencyWatcher = null
	                }
	                if (dependenciesFulfilled) {
	                    var callback = dependenciesFulfilled;
	                    dependenciesFulfilled = null;
	                    callback()
	                }
	            }
	        }

	        Module["removeRunDependency"] = removeRunDependency;
	        Module["preloadedImages"] = {};
	        Module["preloadedAudios"] = {};
	        var memoryInitializer = null;
	        STATIC_BASE = 8;
	        STATICTOP = STATIC_BASE + 329776;
	        __ATINIT__.push();
	        allocate([1, 0, 0, 0, 2, 0, 0, 0, 3, 0, 0, 0, 4, 0, 0, 0, 5, 0, 0, 0, 6, 0, 0, 0, 7, 0, 0, 0, 8, 0, 0, 0, 9, 0, 0, 0, 10, 0, 0, 0, 11, 0, 0, 0, 12, 0, 0, 0, 13, 0, 0, 0, 14, 0, 0, 0, 15, 0, 0, 0, 16, 0, 0, 0, 17, 0, 0, 0, 18, 0, 0, 0, 19, 0, 0, 0, 20, 0, 0, 0, 21, 0, 0, 0, 22, 0, 0, 0, 23, 0, 0, 0, 24, 0, 0, 0, 25, 0, 0, 0, 26, 0, 0, 0, 27, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 0, 0, 0, 0, 0, 0, 0, 45, 0, 0, 0, 0, 0, 0, 0, 45, 100, 101, 98, 117, 103, 0, 0, 45, 45, 100, 101, 98, 117, 103, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 115, 104, 101, 108, 108, 0, 0, 45, 45, 115, 104, 101, 108, 108, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 99, 111, 112, 121, 0, 0, 0, 45, 45, 99, 111, 112, 121, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 114, 101, 99, 111, 118, 101, 114, 0, 0, 0, 0, 0, 0, 0, 0, 45, 45, 114, 101, 99, 111, 118, 101, 114, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 65, 0, 0, 0, 0, 0, 45, 104, 117, 103, 101, 0, 0, 0, 45, 45, 104, 117, 103, 101, 0, 0, 45, 110, 111, 101, 110, 116, 0, 0, 45, 45, 110, 111, 101, 110, 116, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 110, 111, 101, 110, 99, 0, 0, 45, 45, 110, 111, 101, 110, 99, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 110, 115, 99, 108, 101, 97, 110, 0, 0, 0, 0, 0, 0, 0, 0, 45, 45, 110, 115, 99, 108, 101, 97, 110, 0, 0, 0, 0, 0, 0, 0, 45, 110, 111, 99, 100, 97, 116, 97, 0, 0, 0, 0, 0, 0, 0, 0, 45, 45, 110, 111, 99, 100, 97, 116, 97, 0, 0, 0, 0, 0, 0, 0, 45, 110, 111, 100, 105, 99, 116, 0, 45, 45, 110, 111, 100, 105, 99, 116, 0, 0, 0, 0, 0, 0, 0, 0, 45, 118, 101, 114, 115, 105, 111, 110, 0, 0, 0, 0, 0, 0, 0, 0, 45, 45, 118, 101, 114, 115, 105, 111, 110, 0, 0, 0, 0, 0, 0, 0, 45, 110, 111, 111, 117, 116, 0, 0, 45, 45, 110, 111, 111, 117, 116, 0, 45, 111, 0, 0, 0, 0, 0, 0, 45, 111, 117, 116, 112, 117, 116, 0, 45, 45, 111, 117, 116, 112, 117, 116, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 104, 116, 109, 108, 111, 117, 116, 0, 0, 0, 0, 0, 0, 0, 0, 45, 45, 104, 116, 109, 108, 111, 117, 116, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 110, 111, 119, 114, 97, 112, 0, 45, 45, 110, 111, 119, 114, 97, 112, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 104, 116, 109, 108, 0, 0, 0, 45, 45, 104, 116, 109, 108, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 120, 109, 108, 111, 117, 116, 0, 45, 45, 120, 109, 108, 111, 117, 116, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 110, 111, 100, 101, 102, 100, 116, 100, 0, 0, 0, 0, 0, 0, 0, 45, 45, 110, 111, 100, 101, 102, 100, 116, 100, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 108, 111, 97, 100, 100, 116, 100, 0, 0, 0, 0, 0, 0, 0, 0, 45, 45, 108, 111, 97, 100, 100, 116, 100, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 100, 116, 100, 97, 116, 116, 114, 0, 0, 0, 0, 0, 0, 0, 0, 45, 45, 100, 116, 100, 97, 116, 116, 114, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 118, 97, 108, 105, 100, 0, 0, 45, 45, 118, 97, 108, 105, 100, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 112, 111, 115, 116, 118, 97, 108, 105, 100, 0, 0, 0, 0, 0, 0, 45, 45, 112, 111, 115, 116, 118, 97, 108, 105, 100, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 100, 116, 100, 118, 97, 108, 105, 100, 0, 0, 0, 0, 0, 0, 0, 45, 45, 100, 116, 100, 118, 97, 108, 105, 100, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 100, 116, 100, 118, 97, 108, 105, 100, 102, 112, 105, 0, 0, 0, 0, 45, 45, 100, 116, 100, 118, 97, 108, 105, 100, 102, 112, 105, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 100, 114, 111, 112, 100, 116, 100, 0, 0, 0, 0, 0, 0, 0, 0, 45, 45, 100, 114, 111, 112, 100, 116, 100, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 105, 110, 115, 101, 114, 116, 0, 45, 45, 105, 110, 115, 101, 114, 116, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 116, 105, 109, 105, 110, 103, 0, 45, 45, 116, 105, 109, 105, 110, 103, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 97, 117, 116, 111, 0, 0, 0, 45, 45, 97, 117, 116, 111, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 114, 101, 112, 101, 97, 116, 0, 45, 45, 114, 101, 112, 101, 97, 116, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 112, 117, 115, 104, 0, 0, 0, 45, 45, 112, 117, 115, 104, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 112, 117, 115, 104, 115, 109, 97, 108, 108, 0, 0, 0, 0, 0, 0, 45, 45, 112, 117, 115, 104, 115, 109, 97, 108, 108, 0, 0, 0, 0, 0, 0, 16, 0, 0, 0, 0, 0, 0, 45, 109, 101, 109, 111, 114, 121, 0, 45, 45, 109, 101, 109, 111, 114, 121, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 116, 101, 115, 116, 73, 79, 0, 45, 45, 116, 101, 115, 116, 73, 79, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 120, 105, 110, 99, 108, 117, 100, 101, 0, 0, 0, 0, 0, 0, 0, 45, 45, 120, 105, 110, 99, 108, 117, 100, 101, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 110, 111, 120, 105, 110, 99, 108, 117, 100, 101, 110, 111, 100, 101, 0, 45, 45, 110, 111, 120, 105, 110, 99, 108, 117, 100, 101, 110, 111, 100, 101, 0, 0, 0, 0, 0, 0, 0, 0, 45, 110, 111, 102, 105, 120, 117, 112, 45, 98, 97, 115, 101, 45, 117, 114, 105, 115, 0, 0, 0, 0, 0, 0, 45, 45, 110, 111, 102, 105, 120, 117, 112, 45, 98, 97, 115, 101, 45, 117, 114, 105, 115, 0, 0, 0, 0, 0, 45, 110, 111, 119, 97, 114, 110, 105, 110, 103, 0, 0, 0, 0, 0, 0, 45, 45, 110, 111, 119, 97, 114, 110, 105, 110, 103, 0, 0, 0, 0, 0, 45, 112, 101, 100, 97, 110, 116, 105, 99, 0, 0, 0, 0, 0, 0, 0, 45, 45, 112, 101, 100, 97, 110, 116, 105, 99, 0, 0, 0, 0, 0, 0, 45, 100, 101, 98, 117, 103, 101, 110, 116, 0, 0, 0, 0, 0, 0, 0, 45, 45, 100, 101, 98, 117, 103, 101, 110, 116, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 99, 49, 52, 110, 0, 0, 0, 45, 45, 99, 49, 52, 110, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 99, 49, 52, 110, 49, 49, 0, 45, 45, 99, 49, 52, 110, 49, 49, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 101, 120, 99, 45, 99, 49, 52, 110, 0, 0, 0, 0, 0, 0, 0, 45, 45, 101, 120, 99, 45, 99, 49, 52, 110, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 99, 97, 116, 97, 108, 111, 103, 115, 0, 0, 0, 0, 0, 0, 0, 45, 45, 99, 97, 116, 97, 108, 111, 103, 115, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 110, 111, 99, 97, 116, 97, 108, 111, 103, 115, 0, 0, 0, 0, 0, 45, 45, 110, 111, 99, 97, 116, 97, 108, 111, 103, 115, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 101, 110, 99, 111, 100, 101, 0, 45, 45, 101, 110, 99, 111, 100, 101, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 85, 84, 70, 45, 56, 0, 0, 0, 68, 86, 69, 110, 99, 0, 0, 0, 45, 110, 111, 98, 108, 97, 110, 107, 115, 0, 0, 0, 0, 0, 0, 0, 45, 45, 110, 111, 98, 108, 97, 110, 107, 115, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 109, 97, 120, 109, 101, 109, 0, 45, 45, 109, 97, 120, 109, 101, 109, 0, 0, 0, 0, 0, 0, 0, 0, 37, 100, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 102, 111, 114, 109, 97, 116, 0, 45, 45, 102, 111, 114, 109, 97, 116, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 112, 114, 101, 116, 116, 121, 0, 45, 45, 112, 114, 101, 116, 116, 121, 0, 0, 0, 0, 0, 0, 0, 0, 45, 115, 116, 114, 101, 97, 109, 0, 45, 45, 115, 116, 114, 101, 97, 109, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 119, 97, 108, 107, 101, 114, 0, 45, 45, 119, 97, 108, 107, 101, 114, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 115, 97, 120, 49, 0, 0, 0, 45, 45, 115, 97, 120, 49, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 115, 97, 120, 0, 0, 0, 0, 45, 45, 115, 97, 120, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 99, 104, 107, 114, 101, 103, 105, 115, 116, 101, 114, 0, 0, 0, 0, 45, 45, 99, 104, 107, 114, 101, 103, 105, 115, 116, 101, 114, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 114, 101, 108, 97, 120, 110, 103, 0, 0, 0, 0, 0, 0, 0, 0, 45, 45, 114, 101, 108, 97, 120, 110, 103, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 115, 99, 104, 101, 109, 97, 0, 45, 45, 115, 99, 104, 101, 109, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 115, 99, 104, 101, 109, 97, 116, 114, 111, 110, 0, 0, 0, 0, 0, 45, 45, 115, 99, 104, 101, 109, 97, 116, 114, 111, 110, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 110, 111, 110, 101, 116, 0, 0, 45, 45, 110, 111, 110, 101, 116, 0, 45, 110, 111, 99, 111, 109, 112, 97, 99, 116, 0, 0, 0, 0, 0, 0, 45, 45, 110, 111, 99, 111, 109, 112, 97, 99, 116, 0, 0, 0, 0, 0, 45, 108, 111, 97, 100, 45, 116, 114, 97, 99, 101, 0, 0, 0, 0, 0, 45, 45, 108, 111, 97, 100, 45, 116, 114, 97, 99, 101, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 112, 97, 116, 104, 0, 0, 0, 45, 45, 112, 97, 116, 104, 0, 0, 45, 112, 97, 116, 116, 101, 114, 110, 0, 0, 0, 0, 0, 0, 0, 0, 45, 45, 112, 97, 116, 116, 101, 114, 110, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 120, 112, 97, 116, 104, 0, 0, 45, 45, 120, 112, 97, 116, 104, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 111, 108, 100, 120, 109, 108, 49, 48, 0, 0, 0, 0, 0, 0, 0, 45, 45, 111, 108, 100, 120, 109, 108, 49, 48, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 85, 110, 107, 110, 111, 119, 110, 32, 111, 112, 116, 105, 111, 110, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 83, 71, 77, 76, 95, 67, 65, 84, 65, 76, 79, 71, 95, 70, 73, 76, 69, 83, 0, 0, 0, 0, 0, 0, 86, 97, 114, 105, 97, 98, 108, 101, 32, 36, 83, 71, 77, 76, 95, 67, 65, 84, 65, 76, 79, 71, 95, 70, 73, 76, 69, 83, 32, 110, 111, 116, 32, 115, 101, 116, 10, 0, 0, 0, 88, 77, 76, 76, 73, 78, 84, 95, 73, 78, 68, 69, 78, 84, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 60, 33, 68, 79, 67, 84, 89, 80, 69, 32, 72, 84, 77, 76, 32, 80, 85, 66, 76, 73, 67, 32, 34, 45, 47, 47, 87, 51, 67, 47, 47, 68, 84, 68, 32, 72, 84, 77, 76, 32, 52, 46, 48, 32, 84, 114, 97, 110, 115, 105, 116, 105, 111, 110, 97, 108, 47, 47, 69, 78, 34, 10, 0, 0, 9, 34, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 84, 82, 47, 82, 69, 67, 45, 104, 116, 109, 108, 52, 48, 47, 108, 111, 111, 115, 101, 46, 100, 116, 100, 34, 62, 10, 0, 0, 60, 104, 116, 109, 108, 62, 60, 104, 101, 97, 100, 62, 60, 116, 105, 116, 108, 101, 62, 37, 115, 32, 111, 117, 116, 112, 117, 116, 60, 47, 116, 105, 116, 108, 101, 62, 60, 47, 104, 101, 97, 100, 62, 10, 0, 0, 0, 0, 60, 98, 111, 100, 121, 32, 98, 103, 99, 111, 108, 111, 114, 61, 34, 35, 102, 102, 102, 102, 102, 102, 34, 62, 60, 104, 49, 32, 97, 108, 105, 103, 110, 61, 34, 99, 101, 110, 116, 101, 114, 34, 62, 37, 115, 32, 111, 117, 116, 112, 117, 116, 60, 47, 104, 49, 62, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 83, 99, 104, 101, 109, 97, 116, 114, 111, 110, 32, 115, 99, 104, 101, 109, 97, 32, 37, 115, 32, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 99, 111, 109, 112, 105, 108, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 67, 111, 109, 112, 105, 108, 105, 110, 103, 32, 116, 104, 101, 32, 115, 99, 104, 101, 109, 97, 115, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 82, 101, 108, 97, 120, 45, 78, 71, 32, 115, 99, 104, 101, 109, 97, 32, 37, 115, 32, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 99, 111, 109, 112, 105, 108, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 87, 88, 83, 32, 115, 99, 104, 101, 109, 97, 32, 37, 115, 32, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 99, 111, 109, 112, 105, 108, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 80, 97, 116, 116, 101, 114, 110, 32, 37, 115, 32, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 99, 111, 109, 112, 105, 108, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 82, 101, 103, 105, 115, 116, 114, 97, 116, 105, 111, 110, 32, 99, 111, 117, 110, 116, 32, 111, 102, 102, 58, 32, 37, 100, 10, 0, 0, 0, 0, 0, 37, 100, 32, 105, 116, 101, 114, 97, 116, 105, 111, 110, 115, 0, 0, 0, 60, 47, 98, 111, 100, 121, 62, 60, 47, 104, 116, 109, 108, 62, 10, 0, 49, 46, 48, 0, 0, 0, 0, 0, 105, 110, 102, 111, 0, 0, 0, 0, 97, 98, 99, 0, 0, 0, 0, 0, 114, 0, 0, 0, 0, 0, 0, 0, 109, 109, 97, 112, 32, 102, 97, 105, 108, 117, 114, 101, 32, 102, 111, 114, 32, 102, 105, 108, 101, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 80, 97, 114, 115, 105, 110, 103, 0, 88, 105, 110, 99, 108, 117, 100, 101, 32, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 0, 0, 0, 0, 0, 67, 111, 112, 121, 105, 110, 103, 0, 70, 114, 101, 101, 105, 110, 103, 32, 111, 114, 105, 103, 105, 110, 97, 108, 0, 0, 0, 0, 0, 0, 0, 0, 99, 111, 117, 108, 100, 32, 110, 111, 116, 32, 103, 101, 116, 32, 118, 97, 108, 105, 100, 32, 108, 105, 115, 116, 32, 111, 102, 32, 101, 108, 101, 109, 101, 110, 116, 115, 10, 0, 0, 0, 78, 111, 32, 101, 108, 101, 109, 101, 110, 116, 32, 99, 97, 110, 32, 98, 101, 32, 105, 110, 115, 101, 114, 116, 101, 100, 32, 117, 110, 100, 101, 114, 32, 114, 111, 111, 116, 10, 0, 0, 37, 100, 32, 101, 108, 101, 109, 101, 110, 116, 32, 116, 121, 112, 101, 115, 32, 99, 97, 110, 32, 98, 101, 32, 105, 110, 115, 101, 114, 116, 101, 100, 32, 117, 110, 100, 101, 114, 32, 114, 111, 111, 116, 58, 10, 0, 0, 0, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 119, 98, 0, 0, 0, 0, 0, 0, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 111, 112, 101, 110, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 83, 97, 118, 105, 110, 103, 0, 0, 67, 97, 110, 39, 116, 32, 119, 114, 105, 116, 101, 32, 100, 97, 116, 97, 10, 0, 0, 0, 0, 0, 0, 0, 70, 97, 105, 108, 101, 100, 32, 116, 111, 32, 99, 97, 110, 111, 110, 105, 99, 97, 108, 105, 122, 101, 10, 0, 70, 97, 105, 108, 101, 100, 32, 116, 111, 32, 115, 97, 118, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 102, 97, 105, 108, 101, 100, 32, 115, 97, 118, 101, 32, 116, 111, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 80, 97, 114, 115, 105, 110, 103, 32, 68, 84, 68, 0, 0, 0, 0, 0, 67, 111, 117, 108, 100, 32, 110, 111, 116, 32, 112, 97, 114, 115, 101, 32, 68, 84, 68, 32, 37, 115, 10, 0, 67, 111, 117, 108, 100, 110, 39, 116, 32, 97, 108, 108, 111, 99, 97, 116, 101, 32, 118, 97, 108, 105, 100, 97, 116, 105, 111, 110, 32, 99, 111, 110, 116, 101, 120, 116, 10, 0, 0, 0, 68, 111, 99, 117, 109, 101, 110, 116, 32, 37, 115, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 118, 97, 108, 105, 100, 97, 116, 101, 32, 97, 103, 97, 105, 110, 115, 116, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 86, 97, 108, 105, 100, 97, 116, 105, 110, 103, 32, 97, 103, 97, 105, 110, 115, 116, 32, 68, 84, 68, 0, 0, 68, 111, 99, 117, 109, 101, 110, 116, 32, 37, 115, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 118, 97, 108, 105, 100, 97, 116, 101, 10, 0, 0, 86, 97, 108, 105, 100, 97, 116, 105, 110, 103, 0, 0, 0, 0, 0, 0, 37, 115, 32, 118, 97, 108, 105, 100, 97, 116, 101, 115, 10, 0, 0, 0, 37, 115, 32, 102, 97, 105, 108, 115, 32, 116, 111, 32, 118, 97, 108, 105, 100, 97, 116, 101, 10, 0, 0, 0, 37, 115, 32, 118, 97, 108, 105, 100, 97, 116, 105, 111, 110, 32, 103, 101, 110, 101, 114, 97, 116, 101, 100, 32, 97, 110, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 10, 0, 0, 0, 0, 0, 0, 70, 114, 101, 101, 105, 110, 103, 0, 0, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 83, 116, 114, 101, 97, 109, 80, 117, 115, 104, 40, 41, 32, 102, 97, 105, 108, 117, 114, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 119, 97, 108, 107, 105, 110, 103, 32, 116, 104, 114, 111, 117, 103, 104, 32, 116, 104, 101, 32, 100, 111, 99, 0, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 119, 97, 108, 107, 32, 116, 104, 114, 111, 117, 103, 104, 32, 116, 104, 101, 32, 100, 111, 99, 10, 0, 70, 97, 105, 108, 101, 100, 32, 116, 111, 32, 99, 114, 97, 116, 101, 32, 97, 32, 114, 101, 97, 100, 101, 114, 32, 102, 114, 111, 109, 32, 116, 104, 101, 32, 100, 111, 99, 117, 109, 101, 110, 116, 10, 0, 0, 0, 0, 0, 45, 45, 0, 0, 0, 0, 0, 0, 37, 100, 32, 37, 100, 32, 37, 115, 32, 37, 100, 32, 37, 100, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 32, 37, 115, 10, 0, 0, 0, 0, 78, 111, 100, 101, 32, 37, 115, 32, 109, 97, 116, 99, 104, 101, 115, 32, 112, 97, 116, 116, 101, 114, 110, 32, 37, 115, 10, 0, 0, 0, 0, 0, 120, 109, 108, 80, 97, 116, 116, 101, 114, 110, 77, 97, 116, 99, 104, 32, 97, 110, 100, 32, 120, 109, 108, 83, 116, 114, 101, 97, 109, 80, 117, 115, 104, 32, 100, 105, 115, 97, 103, 114, 101, 101, 10, 0, 0, 0, 0, 0, 32, 32, 112, 97, 116, 116, 101, 114, 110, 32, 37, 115, 32, 110, 111, 100, 101, 32, 37, 115, 10, 0, 0, 0, 120, 109, 108, 83, 116, 114, 101, 97, 109, 80, 111, 112, 40, 41, 32, 102, 97, 105, 108, 117, 114, 101, 10, 0, 37, 115, 0, 0, 0, 0, 0, 0, 79, 117, 116, 32, 111, 102, 32, 109, 101, 109, 111, 114, 121, 32, 102, 111, 114, 32, 88, 80, 97, 116, 104, 10, 0, 0, 0, 0, 0, 0, 0, 0, 88, 80, 97, 116, 104, 32, 101, 118, 97, 108, 117, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 117, 114, 101, 10, 0, 0, 0, 0, 0, 0, 0, 88, 80, 97, 116, 104, 32, 115, 101, 116, 32, 105, 115, 32, 101, 109, 112, 116, 121, 10, 0, 0, 0, 0, 0, 116, 114, 117, 101, 0, 0, 0, 0, 102, 97, 108, 115, 101, 0, 0, 0, 73, 110, 102, 105, 110, 105, 116, 121, 0, 0, 0, 0, 0, 0, 0, 0, 45, 73, 110, 102, 105, 110, 105, 116, 121, 0, 0, 0, 0, 0, 0, 0, 78, 97, 78, 0, 0, 0, 0, 0, 37, 48, 103, 0, 0, 0, 0, 0, 88, 80, 97, 116, 104, 32, 79, 98, 106, 101, 99, 116, 32, 105, 115, 32, 117, 110, 105, 110, 105, 116, 105, 97, 108, 105, 122, 101, 100, 10, 0, 0, 88, 80, 97, 116, 104, 32, 111, 98, 106, 101, 99, 116, 32, 111, 102, 32, 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 116, 121, 112, 101, 10], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE);
	        allocate([60, 98, 62, 118, 97, 108, 105, 100, 105, 116, 121, 32, 119, 97, 114, 110, 105, 110, 103, 60, 47, 98, 62, 58, 32, 0, 0, 0, 0, 0, 0, 0, 60, 47, 112, 62, 10, 0, 0, 0, 60, 112, 114, 101, 62, 10, 0, 0, 37, 99, 0, 0, 0, 0, 0, 0, 32, 0, 0, 0, 0, 0, 0, 0, 94, 10, 0, 0, 0, 0, 0, 0, 60, 47, 112, 114, 101, 62, 0, 0, 60, 112, 62, 0, 0, 0, 0, 0, 37, 115, 58, 37, 100, 58, 32, 0, 69, 110, 116, 105, 116, 121, 58, 32, 108, 105, 110, 101, 32, 37, 100, 58, 32, 0, 0, 0, 0, 0, 0, 0, 60, 98, 62, 118, 97, 108, 105, 100, 105, 116, 121, 32, 101, 114, 114, 111, 114, 60, 47, 98, 62, 58, 32, 0, 60, 98, 62, 119, 97, 114, 110, 105, 110, 103, 60, 47, 98, 62, 58, 32, 0, 0, 0, 0, 0, 0, 0, 0, 60, 98, 62, 101, 114, 114, 111, 114, 60, 47, 98, 62, 58, 32, 0, 0, 117, 115, 101, 114, 95, 100, 97, 116, 97, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 24, 217, 0, 0, 0, 0, 0, 0, 112, 212, 0, 0, 0, 0, 0, 0, 83, 65, 88, 32, 103, 101, 110, 101, 114, 97, 116, 101, 100, 32, 97, 32, 100, 111, 99, 32, 33, 10, 0, 0, 1, 0, 0, 0, 2, 0, 0, 0, 3, 0, 0, 0, 4, 0, 0, 0, 5, 0, 0, 0, 6, 0, 0, 0, 7, 0, 0, 0, 8, 0, 0, 0, 9, 0, 0, 0, 10, 0, 0, 0, 11, 0, 0, 0, 12, 0, 0, 0, 13, 0, 0, 0, 14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 17, 0, 0, 0, 18, 0, 0, 0, 19, 0, 0, 0, 20, 0, 0, 0, 21, 0, 0, 0, 22, 0, 0, 0, 23, 0, 0, 0, 24, 0, 0, 0, 25, 0, 0, 0, 26, 0, 0, 0, 27, 0, 0, 0, 175, 190, 237, 222, 0, 0, 0, 0, 28, 0, 0, 0, 29, 0, 0, 0, 0, 0, 0, 0, 83, 65, 88, 46, 101, 110, 100, 69, 108, 101, 109, 101, 110, 116, 78, 115, 40, 37, 115, 0, 0, 0, 0, 0, 44, 32, 78, 85, 76, 76, 0, 0, 44, 32, 37, 115, 0, 0, 0, 0, 44, 32, 78, 85, 76, 76, 41, 10, 0, 0, 0, 0, 0, 0, 0, 0, 44, 32, 39, 37, 115, 39, 41, 10, 0, 0, 0, 0, 0, 0, 0, 0, 83, 65, 88, 46, 115, 116, 97, 114, 116, 69, 108, 101, 109, 101, 110, 116, 78, 115, 40, 37, 115, 0, 0, 0, 44, 32, 39, 37, 115, 39, 0, 0, 44, 32, 37, 100, 0, 0, 0, 0, 44, 32, 120, 109, 108, 110, 115, 0, 58, 37, 115, 0, 0, 0, 0, 0, 61, 39, 37, 115, 39, 0, 0, 0, 44, 32, 37, 100, 44, 32, 37, 100, 0, 0, 0, 0, 0, 0, 0, 0, 44, 32, 37, 115, 58, 37, 115, 61, 39, 0, 0, 0, 0, 0, 0, 0, 44, 32, 37, 115, 61, 39, 0, 0, 37, 46, 52, 115, 46, 46, 46, 39, 44, 32, 37, 100, 0, 0, 0, 0, 41, 10, 0, 0, 0, 0, 0, 0, 83, 65, 88, 46, 101, 120, 116, 101, 114, 110, 97, 108, 83, 117, 98, 115, 101, 116, 40, 37, 115, 44, 0, 0, 32, 44, 0, 0, 0, 0, 0, 0, 32, 37, 115, 44, 0, 0, 0, 0, 32, 41, 10, 0, 0, 0, 0, 0, 32, 37, 115, 41, 10, 0, 0, 0, 83, 65, 88, 46, 112, 99, 100, 97, 116, 97, 40, 37, 46, 50, 48, 115, 44, 32, 37, 100, 41, 10, 0, 0, 83, 65, 88, 46, 103, 101, 116, 80, 97, 114, 97, 109, 101, 116, 101, 114, 69, 110, 116, 105, 116, 121, 40, 37, 115, 41, 10, 0, 0, 0, 0, 0, 83, 65, 88, 46, 102, 97, 116, 97, 108, 69, 114, 114, 111, 114, 58, 32, 0, 0, 0, 0, 0, 0, 0, 0, 83, 65, 88, 46, 101, 114, 114, 111, 114, 58, 32, 0, 0, 0, 0, 0, 83, 65, 88, 46, 119, 97, 114, 110, 105, 110, 103, 58, 32, 0, 0, 0, 83, 65, 88, 46, 99, 111, 109, 109, 101, 110, 116, 40, 37, 115, 41, 10, 0, 0, 0, 0, 0, 0, 0, 0, 83, 65, 88, 46, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 73, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 40, 37, 115, 44, 32, 37, 115, 41, 10, 0, 0, 0, 0, 0, 0, 83, 65, 88, 46, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 73, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 40, 37, 115, 44, 32, 78, 85, 76, 76, 41, 10, 0, 0, 0, 0, 83, 65, 88, 46, 105, 103, 110, 111, 114, 97, 98, 108, 101, 87, 104, 105, 116, 101, 115, 112, 97, 99, 101, 40, 37, 115, 44, 32, 37, 100, 41, 10, 0, 0, 0, 0, 0, 0, 0, 0, 83, 65, 88, 46, 99, 104, 97, 114, 97, 99, 116, 101, 114, 115, 40, 37, 115, 44, 32, 37, 100, 41, 10, 0, 83, 65, 88, 46, 114, 101, 102, 101, 114, 101, 110, 99, 101, 40, 37, 115, 41, 10, 0, 0, 0, 0, 0, 0, 83, 65, 88, 46, 101, 110, 100, 68, 111, 99, 117, 109, 101, 110, 116, 40, 41, 10, 0, 0, 0, 0, 0, 0, 83, 65, 88, 46, 115, 116, 97, 114, 116, 68, 111, 99, 117, 109, 101, 110, 116, 40, 41, 10, 0, 0, 0, 0, 83, 65, 88, 46, 115, 101, 116, 68, 111, 99, 117, 109, 101, 110, 116, 76, 111, 99, 97, 116, 111, 114, 40, 41, 10, 0, 0, 0, 0, 0, 0, 0, 40, 110, 117, 108, 108, 41, 0, 0, 83, 65, 88, 46, 117, 110, 112, 97, 114, 115, 101, 100, 69, 110, 116, 105, 116, 121, 68, 101, 99, 108, 40, 37, 115, 44, 32, 37, 115, 44, 32, 37, 115, 44, 32, 37, 115, 41, 10, 0, 83, 65, 88, 46, 101, 108, 101, 109, 101, 110, 116, 68, 101, 99, 108, 40, 37, 115, 44, 32, 37, 100, 44, 32, 46, 46, 46, 41, 10, 0, 0, 0, 83, 65, 88, 46, 97, 116, 116, 114, 105, 98, 117, 116, 101, 68, 101, 99, 108, 40, 37, 115, 44, 32, 37, 115, 44, 32, 37, 100, 44, 32, 37, 100, 44, 32, 78, 85, 76, 76, 44, 32, 46, 46, 46, 41, 10, 0, 0, 0, 83, 65, 88, 46, 97, 116, 116, 114, 105, 98, 117, 116, 101, 68, 101, 99, 108, 40, 37, 115, 44, 32, 37, 115, 44, 32, 37, 100, 44, 32, 37, 100, 44, 32, 37, 115, 44, 32, 46, 46, 46, 41, 10, 0, 0, 0, 0, 0, 83, 65, 88, 46, 110, 111, 116, 97, 116, 105, 111, 110, 68, 101, 99, 108, 40, 37, 115, 44, 32, 37, 115, 44, 32, 37, 115, 41, 10, 0, 0, 0, 83, 65, 88, 46, 101, 110, 116, 105, 116, 121, 68, 101, 99, 108, 40, 37, 115, 44, 32, 37, 100, 44, 32, 37, 115, 44, 32, 37, 115, 44, 32, 37, 115, 41, 10, 0, 0, 0, 0, 0, 83, 65, 88, 46, 103, 101, 116, 69, 110, 116, 105, 116, 121, 40, 37, 115, 41, 10, 0, 0, 0, 0, 0, 0, 83, 65, 88, 46, 114, 101, 115, 111, 108, 118, 101, 69, 110, 116, 105, 116, 121, 40, 0, 0, 0, 0, 0, 0, 44, 32, 37, 115, 41, 10, 0, 0, 44, 32, 41, 10, 0, 0, 0, 0, 83, 65, 88, 46, 104, 97, 115, 69, 120, 116, 101, 114, 110, 97, 108, 83, 117, 98, 115, 101, 116, 40, 41, 10, 0, 0, 0, 0, 0, 0, 0, 0, 83, 65, 88, 46, 104, 97, 115, 73, 110, 116, 101, 114, 110, 97, 108, 83, 117, 98, 115, 101, 116, 40, 41, 10, 0, 0, 0, 0, 0, 0, 0, 0, 83, 65, 88, 46, 105, 115, 83, 116, 97, 110, 100, 97, 108, 111, 110, 101, 40, 41, 10, 0, 0, 0, 0, 0, 83, 65, 88, 46, 105, 110, 116, 101, 114, 110, 97, 108, 83, 117, 98, 115, 101, 116, 40, 37, 115, 44, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 175, 190, 237, 222, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 88, 83, 68, 32, 115, 99, 104, 101, 109, 97, 32, 37, 115, 32, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 99, 111, 109, 112, 105, 108, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 80, 97, 114, 115, 105, 110, 103, 32, 97, 110, 100, 32, 118, 97, 108, 105, 100, 97, 116, 105, 110, 103, 0, 0, 37, 115, 32, 58, 32, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 112, 97, 114, 115, 101, 10, 0, 0, 0, 85, 110, 97, 98, 108, 101, 32, 116, 111, 32, 111, 112, 101, 110, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 32, 116, 111, 111, 107, 32, 37, 108, 100, 32, 109, 115, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 76, 111, 97, 100, 101, 100, 32, 85, 82, 76, 61, 34, 37, 115, 34, 32, 73, 68, 61, 34, 37, 115, 34, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 47, 0, 0, 0, 0, 0, 0, 0, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 108, 111, 97, 100, 32, 101, 120, 116, 101, 114, 110, 97, 108, 32, 101, 110, 116, 105, 116, 121, 32, 34, 37, 115, 34, 10, 0, 0, 0, 0, 110, 111, 100, 101, 45, 62, 95, 112, 114, 105, 118, 97, 116, 101, 32, 33, 61, 32, 78, 85, 76, 76, 0, 0, 46, 46, 47, 108, 105, 98, 120, 109, 108, 50, 47, 120, 109, 108, 108, 105, 110, 116, 46, 99, 0, 0, 0, 0, 100, 101, 114, 101, 103, 105, 115, 116, 101, 114, 78, 111, 100, 101, 0, 0, 42, 40, 108, 111, 110, 103, 42, 41, 110, 111, 100, 101, 45, 62, 95, 112, 114, 105, 118, 97, 116, 101, 32, 61, 61, 32, 40, 108, 111, 110, 103, 41, 32, 48, 120, 56, 49, 55, 50, 54, 51, 53, 52, 0, 0, 0, 0, 0, 79, 117, 116, 32, 111, 102, 32, 109, 101, 109, 111, 114, 121, 32, 105, 110, 32, 120, 109, 108, 108, 105, 110, 116, 58, 114, 101, 103, 105, 115, 116, 101, 114, 78, 111, 100, 101, 40, 41, 10, 0, 0, 0, 0, 0, 0, 0, 0, 77, 65, 88, 95, 80, 65, 84, 72, 83, 32, 114, 101, 97, 99, 104, 101, 100, 58, 32, 116, 111, 111, 32, 109, 97, 110, 121, 32, 112, 97, 116, 104, 115, 10, 0, 0, 0, 0, 0, 0, 82, 97, 110, 32, 111, 117, 116, 32, 111, 102, 32, 109, 101, 109, 111, 114, 121, 32, 110, 101, 101, 100, 115, 32, 62, 32, 37, 100, 32, 98, 121, 116, 101, 115, 10, 0, 0, 0, 0, 0, 37, 115, 58, 32, 117, 115, 105, 110, 103, 32, 108, 105, 98, 120, 109, 108, 32, 118, 101, 114, 115, 105, 111, 110, 32, 37, 115, 10, 0, 0, 0, 0, 32, 32, 32, 99, 111, 109, 112, 105, 108, 101, 100, 32, 119, 105, 116, 104, 58, 32, 0, 0, 0, 0, 0, 0, 84, 104, 114, 101, 97, 100, 115, 32, 0, 0, 0, 0, 0, 0, 0, 0, 84, 114, 101, 101, 32, 0, 0, 0, 79, 117, 116, 112, 117, 116, 32, 0, 80, 117, 115, 104, 32, 0, 0, 0, 82, 101, 97, 100, 101, 114, 32, 0, 80, 97, 116, 116, 101, 114, 110, 115, 32, 0, 0, 0, 0, 0, 0, 0, 87, 114, 105, 116, 101, 114, 32, 0, 83, 65, 88, 118, 49, 32, 0, 0, 70, 84, 80, 32, 0, 0, 0, 0, 72, 84, 84, 80, 32, 0, 0, 0, 68, 84, 68, 86, 97, 108, 105, 100, 32, 0, 0, 0, 0, 0, 0, 0, 72, 84, 77, 76, 32, 0, 0, 0, 76, 101, 103, 97, 99, 121, 32, 0, 67, 49, 52, 78, 32, 0, 0, 0, 67, 97, 116, 97, 108, 111, 103, 32, 0, 0, 0, 0, 0, 0, 0, 0, 88, 80, 97, 116, 104, 32, 0, 0, 88, 80, 111, 105, 110, 116, 101, 114, 32, 0, 0, 0, 0, 0, 0, 0, 88, 73, 110, 99, 108, 117, 100, 101, 32, 0, 0, 0, 0, 0, 0, 0, 73, 99, 111, 110, 118, 32, 0, 0, 73, 83, 79, 56, 56, 53, 57, 88, 32, 0, 0, 0, 0, 0, 0, 0, 85, 110, 105, 99, 111, 100, 101, 32, 0, 0, 0, 0, 0, 0, 0, 0, 82, 101, 103, 101, 120, 112, 115, 32, 0, 0, 0, 0, 0, 0, 0, 0, 65, 117, 116, 111, 109, 97, 116, 97, 32, 0, 0, 0, 0, 0, 0, 0, 69, 120, 112, 114, 32, 0, 0, 0, 83, 99, 104, 101, 109, 97, 115, 32, 0, 0, 0, 0, 0, 0, 0, 0, 83, 99, 104, 101, 109, 97, 116, 114, 111, 110, 32, 0, 0, 0, 0, 0, 77, 111, 100, 117, 108, 101, 115, 32, 0, 0, 0, 0, 0, 0, 0, 0, 68, 101, 98, 117, 103, 32, 0, 0, 77, 101, 109, 68, 101, 98, 117, 103, 32, 0, 0, 0, 0, 0, 0, 0, 82, 117, 110, 68, 101, 98, 117, 103, 32, 0, 0, 0, 0, 0, 0, 0, 90, 108, 105, 98, 32, 0, 0, 0, 76, 122, 109, 97, 32, 0, 0, 0, 85, 115, 97, 103, 101, 32, 58, 32, 37, 115, 32, 91, 111, 112, 116, 105, 111, 110, 115, 93, 32, 88, 77, 76, 102, 105, 108, 101, 115, 32, 46, 46, 46, 10, 0, 0, 0, 0, 0, 0, 9, 80, 97, 114, 115, 101, 32, 116, 104, 101, 32, 88, 77, 76, 32, 102, 105, 108, 101, 115, 32, 97, 110, 100, 32, 111, 117, 116, 112, 117, 116, 32, 116, 104, 101, 32, 114, 101, 115, 117, 108, 116, 32, 111, 102, 32, 116, 104, 101, 32, 112, 97, 114, 115, 105, 110, 103, 10, 0, 0, 0, 0, 0, 0, 9, 45, 45, 118, 101, 114, 115, 105, 111, 110, 32, 58, 32, 100, 105, 115, 112, 108, 97, 121, 32, 116, 104, 101, 32, 118, 101, 114, 115, 105, 111, 110, 32, 111, 102, 32, 116, 104, 101, 32, 88, 77, 76, 32, 108, 105, 98, 114, 97, 114, 121, 32, 117, 115, 101, 100, 10, 0, 0, 0, 0, 0, 0, 0, 9, 45, 45, 100, 101, 98, 117, 103, 32, 58, 32, 100, 117, 109, 112, 32, 97, 32, 100, 101, 98, 117, 103, 32, 116, 114, 101, 101, 32, 111, 102, 32, 116, 104, 101, 32, 105, 110, 45, 109, 101, 109, 111, 114, 121, 32, 100, 111, 99, 117, 109, 101, 110, 116, 10, 0, 9, 45, 45, 115, 104, 101, 108, 108, 32, 58, 32, 114, 117, 110, 32, 97, 32, 110, 97, 118, 105, 103, 97, 116, 105, 110, 103, 32, 115, 104, 101, 108, 108, 10, 0, 0, 0, 0, 0, 0, 9, 45, 45, 100, 101, 98, 117, 103, 101, 110, 116, 32, 58, 32, 100, 101, 98, 117, 103, 32, 116, 104, 101, 32, 101, 110, 116, 105, 116, 105, 101, 115, 32, 100, 101, 102, 105, 110, 101, 100, 32, 105, 110, 32, 116, 104, 101, 32, 100, 111, 99, 117, 109, 101, 110, 116, 10, 0, 0, 0, 0, 0, 0, 0, 9, 45, 45, 99, 111, 112, 121, 32, 58, 32, 117, 115, 101, 100, 32, 116, 111, 32, 116, 101, 115, 116, 32, 116, 104, 101, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 99, 111, 112, 121, 32, 105, 109, 112, 108, 101, 109, 101, 110, 116, 97, 116, 105, 111, 110, 10, 0, 0, 0, 0, 0, 0, 0, 0, 9, 45, 45, 114, 101, 99, 111, 118, 101, 114, 32, 58, 32, 111, 117, 116, 112, 117, 116, 32, 119, 104, 97, 116, 32, 119, 97, 115, 32, 112, 97, 114, 115, 97, 98, 108, 101, 32, 111, 110, 32, 98, 114, 111, 107, 101, 110, 32, 88, 77, 76, 32, 100, 111, 99, 117, 109, 101, 110, 116, 115, 10, 0, 0, 9, 45, 45, 104, 117, 103, 101, 32, 58, 32, 114, 101, 109, 111, 118, 101, 32, 97, 110, 121, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 97, 114, 98, 105, 116, 114, 97, 114, 121, 32, 112, 97, 114, 115, 101, 114, 32, 108, 105, 109, 105, 116, 115, 10, 0, 0, 9, 45, 45, 110, 111, 101, 110, 116, 32, 58, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 32, 101, 110, 116, 105, 116, 121, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 115, 32, 98, 121, 32, 116, 104, 101, 105, 114, 32, 118, 97, 108, 117, 101, 10, 0, 9, 45, 45, 110, 111, 101, 110, 99, 32, 58, 32, 105, 103, 110, 111, 114, 101, 32, 97, 110, 121, 32, 101, 110, 99, 111, 100, 105, 110, 103, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 105, 110, 115, 105, 100, 101, 32, 116, 104, 101, 32, 100, 111, 99, 117, 109, 101, 110, 116, 10, 0, 0, 0, 9, 45, 45, 110, 111, 111, 117, 116, 32, 58, 32, 100, 111, 110, 39, 116, 32, 111, 117, 116, 112, 117, 116, 32, 116, 104, 101, 32, 114, 101, 115, 117, 108, 116, 32, 116, 114, 101, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 9, 45, 45, 112, 97, 116, 104, 32, 39, 112, 97, 116, 104, 115, 39, 58, 32, 112, 114, 111, 118, 105, 100, 101, 32, 97, 32, 115, 101, 116, 32, 111, 102, 32, 112, 97, 116, 104, 115, 32, 102, 111, 114, 32, 114, 101, 115, 111, 117, 114, 99, 101, 115, 10, 0, 0, 9, 45, 45, 108, 111, 97, 100, 45, 116, 114, 97, 99, 101, 32, 58, 32, 112, 114, 105, 110, 116, 32, 116, 114, 97, 99, 101, 32, 111, 102, 32, 97, 108, 108, 32, 101, 120, 116, 101, 114, 110, 97, 108, 32, 101, 110, 116, 105, 116, 105, 101, 115, 32, 108, 111, 97, 100, 101, 100, 10, 0, 0, 0, 0, 9, 45, 45, 110, 111, 110, 101, 116, 32, 58, 32, 114, 101, 102, 117, 115, 101, 32, 116, 111, 32, 102, 101, 116, 99, 104, 32, 68, 84, 68, 115, 32, 111, 114, 32, 101, 110, 116, 105, 116, 105, 101, 115, 32, 111, 118, 101, 114, 32, 110, 101, 116, 119, 111, 114, 107, 10, 0, 0, 0, 0, 0, 0, 0, 9, 45, 45, 110, 111, 99, 111, 109, 112, 97, 99, 116, 32, 58, 32, 100, 111, 32, 110, 111, 116, 32, 103, 101, 110, 101, 114, 97, 116, 101, 32, 99, 111, 109, 112, 97, 99, 116, 32, 116, 101, 120, 116, 32, 110, 111, 100, 101, 115, 10, 0, 0, 0, 0, 0, 0, 9, 45, 45, 104, 116, 109, 108, 111, 117, 116, 32, 58, 32, 111, 117, 116, 112, 117, 116, 32, 114, 101, 115, 117, 108, 116, 115, 32, 97, 115, 32, 72, 84, 77, 76, 10, 0, 0, 0, 0, 9, 45, 45, 110, 111, 119, 114, 97, 112, 32, 58, 32, 100, 111, 32, 110, 111, 116, 32, 112, 117, 116, 32, 72, 84, 77, 76, 32, 100, 111, 99, 32, 119, 114, 97, 112, 112, 101, 114, 10, 0, 0, 0, 0, 0, 0, 0, 0, 9, 45, 45, 118, 97, 108, 105, 100, 32, 58, 32, 118, 97, 108, 105, 100, 97, 116, 101, 32, 116, 104, 101, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 105, 110, 32, 97, 100, 100, 105, 116, 105, 111, 110, 32, 116, 111, 32, 115, 116, 100, 32, 119, 101, 108, 108, 45, 102, 111, 114, 109, 101, 100, 32, 99, 104, 101, 99, 107, 10, 0, 0, 9, 45, 45, 112, 111, 115, 116, 118, 97, 108, 105, 100, 32, 58, 32, 100, 111, 32, 97, 32, 112, 111, 115, 116, 101, 114, 105, 111, 114, 105, 32, 118, 97, 108, 105, 100, 97, 116, 105, 111, 110, 44, 32, 105, 46, 101, 32, 97, 102, 116, 101, 114, 32, 112, 97, 114, 115, 105, 110, 103, 10, 0, 0, 0, 9, 45, 45, 100, 116, 100, 118, 97, 108, 105, 100, 32, 85, 82, 76, 32, 58, 32, 100, 111, 32, 97, 32, 112, 111, 115, 116, 101, 114, 105, 111, 114, 105, 32, 118, 97, 108, 105, 100, 97, 116, 105, 111, 110, 32, 97, 103, 97, 105, 110, 115, 116, 32, 97, 32, 103, 105, 118, 101, 110, 32, 68, 84, 68, 10, 0, 0, 0, 0, 0, 0, 0, 9, 45, 45, 100, 116, 100, 118, 97, 108, 105, 100, 102, 112, 105, 32, 70, 80, 73, 32, 58, 32, 115, 97, 109, 101, 32, 98, 117, 116, 32, 110, 97, 109, 101, 32, 116, 104, 101, 32, 68, 84, 68, 32, 119, 105, 116, 104, 32, 97, 32, 80, 117, 98, 108, 105, 99, 32, 73, 100, 101, 110, 116, 105, 102, 105, 101, 114, 10, 0, 0, 0, 0, 9, 45, 45, 116, 105, 109, 105, 110, 103, 32, 58, 32, 112, 114, 105, 110, 116, 32, 115, 111, 109, 101, 32, 116, 105, 109, 105, 110, 103, 115, 10, 0, 9, 45, 45, 111, 117, 116, 112, 117, 116, 32, 102, 105, 108, 101, 32, 111, 114, 32, 45, 111, 32, 102, 105, 108, 101, 58, 32, 115, 97, 118, 101, 32, 116, 111, 32, 97, 32, 103, 105, 118, 101, 110, 32, 102, 105, 108, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 9, 45, 45, 114, 101, 112, 101, 97, 116, 32, 58, 32, 114, 101, 112, 101, 97, 116, 32, 49, 48, 48, 32, 116, 105, 109, 101, 115, 44, 32, 102, 111, 114, 32, 116, 105, 109, 105, 110, 103, 32, 111, 114, 32, 112, 114, 111, 102, 105, 108, 105, 110, 103, 10, 0, 0, 9, 45, 45, 105, 110, 115, 101, 114, 116, 32, 58, 32, 97, 100, 45, 104, 111, 99, 32, 116, 101, 115, 116, 32, 102, 111, 114, 32, 118, 97, 108, 105, 100, 32, 105, 110, 115, 101, 114, 116, 105, 111, 110, 115, 10, 0, 0, 0, 9, 45, 45, 104, 116, 109, 108, 32, 58, 32, 117, 115, 101, 32, 116, 104, 101, 32, 72, 84, 77, 76, 32, 112, 97, 114, 115, 101, 114, 10, 0, 0, 9, 45, 45, 120, 109, 108, 111, 117, 116, 32, 58, 32, 102, 111, 114, 99, 101, 32, 116, 111, 32, 117, 115, 101, 32, 116, 104, 101, 32, 88, 77, 76, 32, 115, 101, 114, 105, 97, 108, 105, 122, 101, 114, 32, 119, 104, 101, 110, 32, 117, 115, 105, 110, 103, 32, 45, 45, 104, 116, 109, 108, 10, 0, 0, 9, 45, 45, 110, 111, 100, 101, 102, 100, 116, 100, 32, 58, 32, 100, 111, 32, 110, 111, 116, 32, 100, 101, 102, 97, 117, 108, 116, 32, 72, 84, 77, 76, 32, 100, 111, 99, 116, 121, 112, 101, 10, 0, 0, 0, 0, 0, 0, 9, 45, 45, 112, 117, 115, 104, 32, 58, 32, 117, 115, 101, 32, 116, 104, 101, 32, 112, 117, 115, 104, 32, 109, 111, 100, 101, 32, 111, 102, 32, 116, 104, 101, 32, 112, 97, 114, 115, 101, 114, 10, 0, 0, 0, 0, 0, 0, 9, 45, 45, 112, 117, 115, 104, 115, 109, 97, 108, 108, 32, 58, 32, 117, 115, 101, 32, 116, 104, 101, 32, 112, 117, 115, 104, 32, 109, 111, 100, 101, 32, 111, 102, 32, 116, 104, 101, 32, 112, 97, 114, 115, 101, 114, 32, 117, 115, 105, 110, 103, 32, 116, 105, 110, 121, 32, 105, 110, 99, 114, 101, 109, 101, 110, 116, 115, 10, 0, 0, 0, 9, 45, 45, 109, 101, 109, 111, 114, 121, 32, 58, 32, 112, 97, 114, 115, 101, 32, 102, 114, 111, 109, 32, 109, 101, 109, 111, 114, 121, 10, 0, 0, 9, 45, 45, 109, 97, 120, 109, 101, 109, 32, 110, 98, 98, 121, 116, 101, 115, 32, 58, 32, 108, 105, 109, 105, 116, 115, 32, 109, 101, 109, 111, 114, 121, 32, 97, 108, 108, 111, 99, 97, 116, 105, 111, 110, 32, 116, 111, 32, 110, 98, 98, 121, 116, 101, 115, 32, 98, 121, 116, 101, 115, 10, 0, 0, 9, 45, 45, 110, 111, 119, 97, 114, 110, 105, 110, 103, 32, 58, 32, 100, 111, 32, 110, 111, 116, 32, 101, 109, 105, 116, 32, 119, 97, 114, 110, 105, 110, 103, 115, 32, 102, 114, 111, 109, 32, 112, 97, 114, 115, 101, 114, 47, 118, 97, 108, 105, 100, 97, 116, 111, 114, 10, 0, 0, 0, 0, 0, 0, 9, 45, 45, 110, 111, 98, 108, 97, 110, 107, 115, 32, 58, 32, 100, 114, 111, 112, 32, 40, 105, 103, 110, 111, 114, 97, 98, 108, 101, 63, 41, 32, 98, 108, 97, 110, 107, 115, 32, 115, 112, 97, 99, 101, 115, 10, 0, 0, 9, 45, 45, 110, 111, 99, 100, 97, 116, 97, 32, 58, 32, 114, 101, 112, 108, 97, 99, 101, 32, 99, 100, 97, 116, 97, 32, 115, 101, 99, 116, 105, 111, 110, 32, 119, 105, 116, 104, 32, 116, 101, 120, 116, 32, 110, 111, 100, 101, 115, 10, 0, 0, 0, 0, 0, 9, 45, 45, 102, 111, 114, 109, 97, 116, 32, 58, 32, 114, 101, 102, 111, 114, 109, 97, 116, 47, 114, 101, 105, 110, 100, 101, 110, 116, 32, 116, 104, 101, 32, 105, 110, 112, 117, 116, 10, 0, 0, 0, 0, 0, 0, 0, 0, 9, 45, 45, 101, 110, 99, 111, 100, 101, 32, 101, 110, 99, 111, 100, 105, 110, 103, 32, 58, 32, 111, 117, 116, 112, 117, 116, 32, 105, 110, 32, 116, 104, 101, 32, 103, 105, 118, 101, 110, 32, 101, 110, 99, 111, 100, 105, 110, 103, 10, 0, 0, 0, 0, 0, 0, 9, 45, 45, 100, 114, 111, 112, 100, 116, 100, 32, 58, 32, 114, 101, 109, 111, 118, 101, 32, 116, 104, 101, 32, 68, 79, 67, 84, 89, 80, 69, 32, 111, 102, 32, 116, 104, 101, 32, 105, 110, 112, 117, 116, 32, 100, 111, 99, 115, 10, 0, 0, 0, 0, 0, 0, 9, 45, 45, 112, 114, 101, 116, 116, 121, 32, 83, 84, 89, 76, 69, 32, 58, 32, 112, 114, 101, 116, 116, 121, 45, 112, 114, 105, 110, 116, 32, 105, 110, 32, 97, 32, 112, 97, 114, 116, 105, 99, 117, 108, 97, 114, 32, 115, 116, 121, 108, 101, 10, 0, 0, 0, 9, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 48, 32, 68, 111, 32, 110, 111, 116, 32, 112, 114, 101, 116, 116, 121, 32, 112, 114, 105, 110, 116, 10, 0, 0, 0, 0, 0, 0, 0, 0, 9, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 49, 32, 70, 111, 114, 109, 97, 116, 32, 116, 104, 101, 32, 88, 77, 76, 32, 99, 111, 110, 116, 101, 110, 116, 44, 32, 97, 115, 32, 45, 45, 102, 111, 114, 109, 97, 116, 10, 0, 0, 0, 0, 0, 0, 0, 0, 9, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 50, 32, 65, 100, 100, 32, 119, 104, 105, 116, 101, 115, 112, 97, 99, 101, 32, 105, 110, 115, 105, 100, 101, 32, 116, 97, 103, 115, 44, 32, 112, 114, 101, 115, 101, 114, 118, 105, 110, 103, 32, 99, 111, 110, 116, 101, 110, 116, 10, 0, 0, 0, 0, 0, 9, 45, 45, 99, 49, 52, 110, 32, 58, 32, 115, 97, 118, 101, 32, 105, 110, 32, 87, 51, 67, 32, 99, 97, 110, 111, 110, 105, 99, 97, 108, 32, 102, 111, 114, 109, 97, 116, 32, 118, 49, 46, 48, 32, 40, 119, 105, 116, 104, 32, 99, 111, 109, 109, 101, 110, 116, 115, 41, 10, 0, 0, 0, 0, 9, 45, 45, 99, 49, 52, 110, 49, 49, 32, 58, 32, 115, 97, 118, 101, 32, 105, 110, 32, 87, 51, 67, 32, 99, 97, 110, 111, 110, 105, 99, 97, 108, 32, 102, 111, 114, 109, 97, 116, 32, 118, 49, 46, 49, 32, 40, 119, 105, 116, 104, 32, 99, 111, 109, 109, 101, 110, 116, 115, 41, 10, 0, 0, 9, 45, 45, 101, 120, 99, 45, 99, 49, 52, 110, 32, 58, 32, 115, 97, 118, 101, 32, 105, 110, 32, 87, 51, 67, 32, 101, 120, 99, 108, 117, 115, 105, 118, 101, 32, 99, 97, 110, 111, 110, 105, 99, 97, 108, 32, 102, 111, 114, 109, 97, 116, 32, 40, 119, 105, 116, 104, 32, 99, 111, 109, 109, 101, 110, 116, 115, 41, 10, 0, 0, 0, 9, 45, 45, 110, 115, 99, 108, 101, 97, 110, 32, 58, 32, 114, 101, 109, 111, 118, 101, 32, 114, 101, 100, 117, 110, 100, 97, 110, 116, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 115, 10, 0, 0, 0, 9, 45, 45, 116, 101, 115, 116, 73, 79, 32, 58, 32, 116, 101, 115, 116, 32, 117, 115, 101, 114, 32, 73, 47, 79, 32, 115, 117, 112, 112, 111, 114, 116, 10, 0, 0, 0, 0, 0, 0, 9, 45, 45, 99, 97, 116, 97, 108, 111, 103, 115, 32, 58, 32, 117, 115, 101, 32, 83, 71, 77, 76, 32, 99, 97, 116, 97, 108, 111, 103, 115, 32, 102, 114, 111, 109, 32, 36, 83, 71, 77, 76, 95, 67, 65, 84, 65, 76, 79, 71, 95, 70, 73, 76, 69, 83, 10, 0, 0, 0, 0, 0, 0, 0, 9, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 111, 116, 104, 101, 114, 119, 105, 115, 101, 32, 88, 77, 76, 32, 67, 97, 116, 97, 108, 111, 103, 115, 32, 115, 116, 97, 114, 116, 105, 110, 103, 32, 102, 114, 111, 109, 32, 10, 0, 0, 0, 0, 9, 32, 32, 32, 32, 32, 32, 32, 32, 32, 37, 115, 32, 97, 114, 101, 32, 97, 99, 116, 105, 118, 97, 116, 101, 100, 32, 98, 121, 32, 100, 101, 102, 97, 117, 108, 116, 10, 0, 0, 102, 105, 108, 101, 58, 47, 47, 47, 101, 116, 99, 47, 120, 109, 108, 47, 99, 97, 116, 97, 108, 111, 103, 0, 9, 45, 45, 110, 111, 99, 97, 116, 97, 108, 111, 103, 115, 58, 32, 100, 101, 97, 99, 116, 105, 118, 97, 116, 101, 32, 97, 108, 108, 32, 99, 97, 116, 97, 108, 111, 103, 115, 10, 0, 9, 45, 45, 97, 117, 116, 111, 32, 58, 32, 103, 101, 110, 101, 114, 97, 116, 101, 32, 97, 32, 115, 109, 97, 108, 108, 32, 100, 111, 99, 32, 111, 110, 32, 116, 104, 101, 32, 102, 108, 121, 10, 0, 0, 0, 0, 0, 0, 9, 45, 45, 120, 105, 110, 99, 108, 117, 100, 101, 32, 58, 32, 100, 111, 32, 88, 73, 110, 99, 108, 117, 100, 101, 32, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 10, 0, 0, 0, 9, 45, 45, 110, 111, 120, 105, 110, 99, 108, 117, 100, 101, 110, 111, 100, 101, 32, 58, 32, 115, 97, 109, 101, 32, 98, 117, 116, 32, 100, 111, 32, 110, 111, 116, 32, 103, 101, 110, 101, 114, 97, 116, 101, 32, 88, 73, 110, 99, 108, 117, 100, 101, 32, 110, 111, 100, 101, 115, 10, 0, 0, 0, 0, 9, 45, 45, 110, 111, 102, 105, 120, 117, 112, 45, 98, 97, 115, 101, 45, 117, 114, 105, 115, 32, 58, 32, 100, 111, 32, 110, 111, 116, 32, 102, 105, 120, 117, 112, 32, 120, 109, 108, 58, 98, 97, 115, 101, 32, 117, 114, 105, 115, 10, 0, 0, 0, 0, 0, 0, 9, 45, 45, 108, 111, 97, 100, 100, 116, 100, 32, 58, 32, 102, 101, 116, 99, 104, 32, 101, 120, 116, 101, 114, 110, 97, 108, 32, 68, 84, 68, 10, 0, 0, 0, 0, 0, 0, 0, 0, 9, 45, 45, 100, 116, 100, 97, 116, 116, 114, 32, 58, 32, 108, 111, 97, 100, 100, 116, 100, 32, 43, 32, 112, 111, 112, 117, 108, 97, 116, 101, 32, 116, 104, 101, 32, 116, 114, 101, 101, 32, 119, 105, 116, 104, 32, 105, 110, 104, 101, 114, 105, 116, 101, 100, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 115, 32, 10, 0, 0, 0, 0, 9, 45, 45, 115, 116, 114, 101, 97, 109, 32, 58, 32, 117, 115, 101, 32, 116, 104, 101, 32, 115, 116, 114, 101, 97, 109, 105, 110, 103, 32, 105, 110, 116, 101, 114, 102, 97, 99, 101, 32, 116, 111, 32, 112, 114, 111, 99, 101, 115, 115, 32, 118, 101, 114, 121, 32, 108, 97, 114, 103, 101, 32, 102, 105, 108, 101, 115, 10, 0, 0, 0, 0, 9, 45, 45, 119, 97, 108, 107, 101, 114, 32, 58, 32, 99, 114, 101, 97, 116, 101, 32, 97, 32, 114, 101, 97, 100, 101, 114, 32, 97, 110, 100, 32, 119, 97, 108, 107, 32, 116, 104, 111, 117, 103, 104, 32, 116, 104, 101, 32, 114, 101, 115, 117, 108, 116, 105, 110, 103, 32, 100, 111, 99, 10, 0, 0, 9, 45, 45, 112, 97, 116, 116, 101, 114, 110, 32, 112, 97, 116, 116, 101, 114, 110, 95, 118, 97, 108, 117, 101, 32, 58, 32, 116, 101, 115, 116, 32, 116, 104, 101, 32, 112, 97, 116, 116, 101, 114, 110, 32, 115, 117, 112, 112, 111, 114, 116, 10, 0, 0, 0, 0, 9, 45, 45, 99, 104, 107, 114, 101, 103, 105, 115, 116, 101, 114, 32, 58, 32, 118, 101, 114, 105, 102, 121, 32, 116, 104, 101, 32, 110, 111, 100, 101, 32, 114, 101, 103, 105, 115, 116, 114, 97, 116, 105, 111, 110, 32, 99, 111, 100, 101, 10, 0, 0, 0, 0, 0, 9, 45, 45, 114, 101, 108, 97, 120, 110, 103, 32, 115, 99, 104, 101, 109, 97, 32, 58, 32, 100, 111, 32, 82, 101, 108, 97, 120, 78, 71, 32, 118, 97, 108, 105, 100, 97, 116, 105, 111, 110, 32, 97, 103, 97, 105, 110, 115, 116, 32, 116, 104, 101, 32, 115, 99, 104, 101, 109, 97, 10, 0, 0, 0, 9, 45, 45, 115, 99, 104, 101, 109, 97, 32, 115, 99, 104, 101, 109, 97, 32, 58, 32, 100, 111, 32, 118, 97, 108, 105, 100, 97, 116, 105, 111, 110, 32, 97, 103, 97, 105, 110, 115, 116, 32, 116, 104, 101, 32, 87, 88, 83, 32, 115, 99, 104, 101, 109, 97, 10, 0, 0, 0, 0, 0, 0, 0, 0, 9, 45, 45, 115, 99, 104, 101, 109, 97, 116, 114, 111, 110, 32, 115, 99, 104, 101, 109, 97, 32, 58, 32, 100, 111, 32, 118, 97, 108, 105, 100, 97, 116, 105, 111, 110, 32, 97, 103, 97, 105, 110, 115, 116, 32, 97, 32, 115, 99, 104, 101, 109, 97, 116, 114, 111, 110, 10, 0, 0, 0, 0, 0, 0, 9, 45, 45, 115, 97, 120, 49, 58, 32, 117, 115, 101, 32, 116, 104, 101, 32, 111, 108, 100, 32, 83, 65, 88, 49, 32, 105, 110, 116, 101, 114, 102, 97, 99, 101, 115, 32, 102, 111, 114, 32, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 10, 0, 0, 0, 0, 9, 45, 45, 115, 97, 120, 58, 32, 100, 111, 32, 110, 111, 116, 32, 98, 117, 105, 108, 100, 32, 97, 32, 116, 114, 101, 101, 32, 98, 117, 116, 32, 119, 111, 114, 107, 32, 106, 117, 115, 116, 32, 97, 116, 32, 116, 104, 101, 32, 83, 65, 88, 32, 108, 101, 118, 101, 108, 10, 0, 0, 0, 0, 0, 9, 45, 45, 111, 108, 100, 120, 109, 108, 49, 48, 58, 32, 117, 115, 101, 32, 88, 77, 76, 45, 49, 46, 48, 32, 112, 97, 114, 115, 105, 110, 103, 32, 114, 117, 108, 101, 115, 32, 98, 101, 102, 111, 114, 101, 32, 116, 104, 101, 32, 53, 116, 104, 32, 101, 100, 105, 116, 105, 111, 110, 10, 0, 0, 9, 45, 45, 120, 112, 97, 116, 104, 32, 101, 120, 112, 114, 58, 32, 101, 118, 97, 108, 117, 97, 116, 101, 32, 116, 104, 101, 32, 88, 80, 97, 116, 104, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 44, 32, 105, 109, 112, 108, 121, 32, 45, 45, 110, 111, 111, 117, 116, 10, 0, 0, 0, 0, 10, 76, 105, 98, 120, 109, 108, 32, 112, 114, 111, 106, 101, 99, 116, 32, 104, 111, 109, 101, 32, 112, 97, 103, 101, 58, 32, 104, 116, 116, 112, 58, 47, 47, 120, 109, 108, 115, 111, 102, 116, 46, 111, 114, 103, 47, 10, 0, 84, 111, 32, 114, 101, 112, 111, 114, 116, 32, 98, 117, 103, 115, 32, 111, 114, 32, 103, 101, 116, 32, 115, 111, 109, 101, 32, 104, 101, 108, 112, 32, 99, 104, 101, 99, 107, 58, 32, 104, 116, 116, 112, 58, 47, 47, 120, 109, 108, 115, 111, 102, 116, 46, 111, 114, 103, 47, 98, 117, 103, 115, 46, 104, 116, 109, 108, 10, 0, 0, 0, 0, 83, 65, 88, 46, 101, 110, 100, 69, 108, 101, 109, 101, 110, 116, 40, 37, 115, 41, 10, 0, 0, 0, 0, 0, 83, 65, 88, 46, 115, 116, 97, 114, 116, 69, 108, 101, 109, 101, 110, 116, 40, 37, 115, 0, 0, 0, 0, 0, 37, 115, 39, 0, 0, 0, 0, 0, 108, 116, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 17, 0, 0, 0, 56, 238, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 120, 242, 0, 0, 120, 242, 0, 0, 1, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 103, 116, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 17, 0, 0, 0, 144, 238, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 112, 242, 0, 0, 112, 242, 0, 0, 1, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 97, 109, 112, 0, 0, 0, 0, 0, 0, 0, 0, 0, 17, 0, 0, 0, 232, 238, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 104, 242, 0, 0, 104, 242, 0, 0, 1, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 97, 112, 111, 115, 0, 0, 0, 0, 0, 0, 0, 0, 17, 0, 0, 0, 64, 239, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 96, 242, 0, 0, 96, 242, 0, 0, 1, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 113, 117, 111, 116, 0, 0, 0, 0, 0, 0, 0, 0, 17, 0, 0, 0, 152, 239, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 64, 241, 0, 0, 64, 241, 0, 0, 1, 0, 0, 0, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 65, 100, 100, 68, 116, 100, 69, 110, 116, 105, 116, 121, 58, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 105, 115, 32, 78, 85, 76, 76, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 65, 100, 100, 68, 116, 100, 69, 110, 116, 105, 116, 121, 58, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 119, 105, 116, 104, 111, 117, 116, 32, 101, 120, 116, 101, 114, 110, 97, 108, 32, 115, 117, 98, 115, 101, 116, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 65, 100, 100, 68, 111, 99, 69, 110, 116, 105, 116, 121, 58, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 105, 115, 32, 78, 85, 76, 76, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 65, 100, 100, 68, 111, 99, 69, 110, 116, 105, 116, 121, 58, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 119, 105, 116, 104, 111, 117, 116, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 115, 117, 98, 115, 101, 116, 0, 0, 0, 0, 0, 0, 0, 60, 33, 69, 78, 84, 73, 84, 89, 32, 0, 0, 0, 0, 0, 0, 0, 32, 0, 0, 0, 0, 0, 0, 0, 62, 10, 0, 0, 0, 0, 0, 0, 32, 80, 85, 66, 76, 73, 67, 32, 0, 0, 0, 0, 0, 0, 0, 0, 32, 83, 89, 83, 84, 69, 77, 32, 0, 0, 0, 0, 0, 0, 0, 0, 32, 78, 68, 65, 84, 65, 32, 0, 60, 33, 69, 78, 84, 73, 84, 89, 32, 37, 32, 0, 0, 0, 0, 0, 120, 109, 108, 68, 117, 109, 112, 69, 110, 116, 105, 116, 105, 101, 115, 68, 101, 99, 108, 58, 32, 105, 110, 116, 101, 114, 110, 97, 108, 58, 32, 117, 110, 107, 110, 111, 119, 110, 32, 116, 121, 112, 101, 32, 101, 110, 116, 105, 116, 121, 32, 116, 121, 112, 101, 0, 34, 0, 0, 0, 0, 0, 0, 0, 38, 113, 117, 111, 116, 59, 0, 0, 38, 35, 120, 50, 53, 59, 0, 0, 120, 109, 108, 67, 111, 112, 121, 69, 110, 116, 105, 116, 121, 58, 58, 32, 109, 97, 108, 108, 111, 99, 32, 102, 97, 105, 108, 101, 100, 0, 0, 0, 120, 109, 108, 69, 110, 99, 111, 100, 101, 69, 110, 116, 105, 116, 105, 101, 115, 58, 32, 109, 97, 108, 108, 111, 99, 32, 102, 97, 105, 108, 101, 100, 0, 0, 0, 0, 0, 0, 0, 0, 45, 45, 62, 0, 0, 0, 0, 0, 120, 109, 108, 69, 110, 99, 111, 100, 101, 69, 110, 116, 105, 116, 105, 101, 115, 58, 32, 105, 110, 112, 117, 116, 32, 110, 111, 116, 32, 85, 84, 70, 45, 56, 0, 0, 0, 0, 0, 0, 73, 83, 79, 45, 56, 56, 53, 57, 45, 49, 0, 0, 0, 0, 0, 0, 38, 35, 37, 100, 59, 0, 0, 0, 120, 109, 108, 69, 110, 99, 111, 100, 101, 69, 110, 116, 105, 116, 105, 101, 115, 58, 32, 99, 104, 97, 114, 32, 111, 117, 116, 32, 111, 102, 32, 114, 97, 110, 103, 101, 10, 0, 0, 0, 38, 35, 120, 37, 88, 59, 0, 0, 120, 109, 108, 69, 110, 99, 111, 100, 101, 69, 110, 116, 105, 116, 105, 101, 115, 58, 32, 114, 101, 97, 108, 108, 111, 99, 32, 102, 97, 105, 108, 101, 100, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 67, 114, 101, 97, 116, 101, 69, 110, 116, 105, 116, 121, 58, 32, 109, 97, 108, 108, 111, 99, 32, 102, 97, 105, 108, 101, 100, 0, 0, 39, 0, 0, 0, 0, 0, 0, 0, 38, 0, 0, 0, 0, 0, 0, 0, 62, 0, 0, 0, 0, 0, 0, 0, 60, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 85, 84, 70, 45, 56, 0, 0, 0, 85, 84, 70, 56, 0, 0, 0, 0, 85, 84, 70, 45, 49, 54, 0, 0, 85, 84, 70, 49, 54, 0, 0, 0, 73, 83, 79, 45, 49, 48, 54, 52, 54, 45, 85, 67, 83, 45, 50, 0, 85, 67, 83, 45, 50, 0, 0, 0, 85, 67, 83, 50, 0, 0, 0, 0, 73, 83, 79, 45, 49, 48, 54, 52, 54, 45, 85, 67, 83, 45, 52, 0, 85, 67, 83, 45, 52, 0, 0, 0, 85, 67, 83, 52, 0, 0, 0, 0, 73, 83, 79, 45, 56, 56, 53, 57, 45, 49, 0, 0, 0, 0, 0, 0, 73, 83, 79, 45, 76, 65, 84, 73, 78, 45, 49, 0, 0, 0, 0, 0, 73, 83, 79, 32, 76, 65, 84, 73, 78, 32, 49, 0, 0, 0, 0, 0, 73, 83, 79, 45, 56, 56, 53, 57, 45, 50, 0, 0, 0, 0, 0, 0, 73, 83, 79, 45, 76, 65, 84, 73, 78, 45, 50, 0, 0, 0, 0, 0, 73, 83, 79, 32, 76, 65, 84, 73, 78, 32, 50, 0, 0, 0, 0, 0, 73, 83, 79, 45, 56, 56, 53, 57, 45, 51, 0, 0, 0, 0, 0, 0, 73, 83, 79, 45, 56, 56, 53, 57, 45, 52, 0, 0, 0, 0, 0, 0, 73, 83, 79, 45, 56, 56, 53, 57, 45, 53, 0, 0, 0, 0, 0, 0, 73, 83, 79, 45, 56, 56, 53, 57, 45, 54, 0, 0, 0, 0, 0, 0, 73, 83, 79, 45, 56, 56, 53, 57, 45, 55, 0, 0, 0, 0, 0, 0, 73, 83, 79, 45, 56, 56, 53, 57, 45, 56, 0, 0, 0, 0, 0, 0, 73, 83, 79, 45, 56, 56, 53, 57, 45, 57, 0, 0, 0, 0, 0, 0, 73, 83, 79, 45, 50, 48, 50, 50, 45, 74, 80, 0, 0, 0, 0, 0, 83, 72, 73, 70, 84, 95, 74, 73, 83, 0, 0, 0, 0, 0, 0, 0, 69, 85, 67, 45, 74, 80, 0, 0, 69, 66, 67, 68, 73, 67, 0, 0, 83, 104, 105, 102, 116, 45, 74, 73, 83, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 78, 101, 119, 67, 104, 97, 114, 69, 110, 99, 111, 100, 105, 110, 103, 72, 97, 110, 100, 108, 101, 114, 32, 58, 32, 110, 111, 32, 110, 97, 109, 101, 32, 33, 10, 0, 0, 120, 109, 108, 78, 101, 119, 67, 104, 97, 114, 69, 110, 99, 111, 100, 105, 110, 103, 72, 97, 110, 100, 108, 101, 114, 32, 58, 32, 111, 117, 116, 32, 111, 102, 32, 109, 101, 109, 111, 114, 121, 32, 33, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 79, 100, 100, 32, 112, 114, 111, 98, 108, 101, 109, 32, 97, 116, 32, 101, 110, 100, 105, 97, 110, 110, 101, 115, 115, 32, 100, 101, 116, 101, 99, 116, 105, 111, 110, 10, 0, 0, 0, 0, 120, 109, 108, 73, 110, 105, 116, 67, 104, 97, 114, 69, 110, 99, 111, 100, 105, 110, 103, 72, 97, 110, 100, 108, 101, 114, 115, 32, 58, 32, 111, 117, 116, 32, 111, 102, 32, 109, 101, 109, 111, 114, 121, 32, 33, 10, 0, 0, 85, 84, 70, 45, 49, 54, 76, 69, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 85, 84, 70, 45, 49, 54, 66, 69, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 65, 83, 67, 73, 73, 0, 0, 0, 85, 83, 45, 65, 83, 67, 73, 73, 0, 0, 0, 0, 0, 0, 0, 0, 72, 84, 77, 76, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 82, 101, 103, 105, 115, 116, 101, 114, 67, 104, 97, 114, 69, 110, 99, 111, 100, 105, 110, 103, 72, 97, 110, 100, 108, 101, 114, 58, 32, 78, 85, 76, 76, 32, 104, 97, 110, 100, 108, 101, 114, 32, 33, 10, 0, 120, 109, 108, 82, 101, 103, 105, 115, 116, 101, 114, 67, 104, 97, 114, 69, 110, 99, 111, 100, 105, 110, 103, 72, 97, 110, 100, 108, 101, 114, 58, 32, 84, 111, 111, 32, 109, 97, 110, 121, 32, 104, 97, 110, 100, 108, 101, 114, 32, 114, 101, 103, 105, 115, 116, 101, 114, 101, 100, 44, 32, 115, 101, 101, 32, 37, 115, 10, 0, 0, 0, 0, 77, 65, 88, 95, 69, 78, 67, 79, 68, 73, 78, 71, 95, 72, 65, 78, 68, 76, 69, 82, 83, 0, 0, 0, 101, 98, 99, 100, 105, 99, 0, 0, 69, 66, 67, 68, 73, 67, 45, 85, 83, 0, 0, 0, 0, 0, 0, 0, 73, 66, 77, 45, 48, 51, 55, 0, 83, 72, 73, 70, 84, 45, 74, 73, 83, 0, 0, 0, 0, 0, 0, 0, 83, 104, 105, 102, 116, 95, 74, 73, 83, 0, 0, 0, 0, 0, 0, 0, 105, 99, 111, 110, 118, 32, 58, 32, 112, 114, 111, 98, 108, 101, 109, 115, 32, 119, 105, 116, 104, 32, 102, 105, 108, 116, 101, 114, 115, 32, 102, 111, 114, 32, 39, 37, 115, 39, 10, 0, 48, 120, 37, 48, 50, 88, 32, 48, 120, 37, 48, 50, 88, 32, 48, 120, 37, 48, 50, 88, 32, 48, 120, 37, 48, 50, 88, 0, 0, 0, 0, 0, 105, 110, 112, 117, 116, 32, 99, 111, 110, 118, 101, 114, 115, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 32, 100, 117, 101, 32, 116, 111, 32, 105, 110, 112, 117, 116, 32, 101, 114, 114, 111, 114, 44, 32, 98, 121, 116, 101, 115, 32, 37, 115, 10, 0, 0, 0, 120, 109, 108, 67, 104, 97, 114, 69, 110, 99, 79, 117, 116, 70, 117, 110, 99, 58, 32, 110, 111, 32, 111, 117, 116, 112, 117, 116, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 33, 10, 0, 0, 0, 0, 0, 0, 0, 0, 38, 35, 37, 100, 59, 0, 0, 0, 111, 117, 116, 112, 117, 116, 32, 99, 111, 110, 118, 101, 114, 115, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 32, 100, 117, 101, 32, 116, 111, 32, 99, 111, 110, 118, 32, 101, 114, 114, 111, 114, 44, 32, 98, 121, 116, 101, 115, 32, 37, 115, 10, 0, 0, 0, 37, 115, 58, 37, 100, 58, 32, 0, 69, 110, 116, 105, 116, 121, 58, 32, 108, 105, 110, 101, 32, 37, 100, 58, 32, 0, 0, 0, 0, 0, 0, 0, 78, 111, 32, 101, 114, 114, 111, 114, 32, 109, 101, 115, 115, 97, 103, 101, 32, 112, 114, 111, 118, 105, 100, 101, 100, 0, 0, 0, 0, 0, 0, 0, 104, 114, 101, 102, 0, 0, 0, 0, 37, 115, 0, 0, 0, 0, 0, 0, 77, 101, 109, 111, 114, 121, 32, 97, 108, 108, 111, 99, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 32, 58, 32, 37, 115, 10, 0, 0, 77, 101, 109, 111, 114, 121, 32, 97, 108, 108, 111, 99, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 10, 0, 0, 0, 0, 0, 0, 0, 101, 114, 114, 111, 114, 58, 32, 0, 10, 0, 0, 0, 0, 0, 0, 0, 119, 97, 114, 110, 105, 110, 103, 58, 32, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 118, 97, 108, 105, 100, 105, 116, 121, 32, 101, 114, 114, 111, 114, 58, 32, 0, 0, 0, 0, 0, 0, 0, 0, 118, 97, 108, 105, 100, 105, 116, 121, 32, 119, 97, 114, 110, 105, 110, 103, 58, 32, 0, 0, 0, 0, 0, 0, 101, 108, 101, 109, 101, 110, 116, 32, 37, 115, 58, 32, 0, 0, 0, 0, 112, 97, 114, 115, 101, 114, 32, 0, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 0, 0, 0, 0, 0, 0, 118, 97, 108, 105, 100, 105, 116, 121, 32, 0, 0, 0, 0, 0, 0, 0, 72, 84, 77, 76, 32, 112, 97, 114, 115, 101, 114, 32, 0, 0, 0, 0, 109, 101, 109, 111, 114, 121, 32, 0, 111, 117, 116, 112, 117, 116, 32, 0, 73, 47, 79, 32, 0, 0, 0, 0, 88, 73, 110, 99, 108, 117, 100, 101, 32, 0, 0, 0, 0, 0, 0, 0, 88, 80, 97, 116, 104, 32, 0, 0, 114, 101, 103, 101, 120, 112, 32, 0, 109, 111, 100, 117, 108, 101, 32, 0, 83, 99, 104, 101, 109, 97, 115, 32, 118, 97, 108, 105, 100, 105, 116, 121, 32, 0, 0, 0, 0, 0, 0, 0, 83, 99, 104, 101, 109, 97, 115, 32, 112, 97, 114, 115, 101, 114, 32, 0, 82, 101, 108, 97, 120, 45, 78, 71, 32, 112, 97, 114, 115, 101, 114, 32, 0, 0, 0, 0, 0, 0, 0, 0, 82, 101, 108, 97, 120, 45, 78, 71, 32, 118, 97, 108, 105, 100, 105, 116, 121, 32, 0, 0, 0, 0, 0, 0, 67, 97, 116, 97, 108, 111, 103, 32, 0, 0, 0, 0, 0, 0, 0, 0, 67, 49, 52, 78, 32, 0, 0, 0, 88, 83, 76, 84, 32, 0, 0, 0, 101, 110, 99, 111, 100, 105, 110, 103, 32, 0, 0, 0, 0, 0, 0, 0, 115, 99, 104, 101, 109, 97, 116, 114, 111, 110, 32, 0, 0, 0, 0, 0, 105, 110, 116, 101, 114, 110, 97, 108, 32, 98, 117, 102, 102, 101, 114, 32, 0, 0, 0, 0, 0, 0, 0, 0, 85, 82, 73, 32, 0, 0, 0, 0, 58, 32, 0, 0, 0, 0, 0, 0, 119, 97, 114, 110, 105, 110, 103, 32, 58, 32, 0, 0, 0, 0, 0, 0, 101, 114, 114, 111, 114, 32, 58, 32, 0, 0, 0, 0, 0, 0, 0, 0, 37, 115, 10, 0, 0, 0, 0, 0, 111, 117, 116, 32, 111, 102, 32, 109, 101, 109, 111, 114, 121, 32, 101, 114, 114, 111, 114, 0, 0, 0, 0, 0, 37, 115, 58, 37, 100, 58, 32, 10, 0, 0, 0, 0, 0, 0, 0, 0, 69, 110, 116, 105, 116, 121, 58, 32, 108, 105, 110, 101, 32, 37, 100, 58, 32, 10, 0, 0, 0, 0, 0, 0, 70, 97, 116, 97, 108, 58, 32, 112, 114, 111, 103, 114, 97, 109, 32, 99, 111, 109, 112, 105, 108, 101, 100, 32, 97, 103, 97, 105, 110, 115, 116, 32, 108, 105, 98, 120, 109, 108, 32, 37, 100, 32, 117, 115, 105, 110, 103, 32, 108, 105, 98, 120, 109, 108, 32, 37, 100, 10, 0, 0, 0, 0, 0, 0, 87, 97, 114, 110, 105, 110, 103, 58, 32, 112, 114, 111, 103, 114, 97, 109, 32, 99, 111, 109, 112, 105, 108, 101, 100, 32, 97, 103, 97, 105, 110, 115, 116, 32, 108, 105, 98, 120, 109, 108, 32, 37, 100, 32, 117, 115, 105, 110, 103, 32, 111, 108, 100, 101, 114, 32, 37, 100, 10, 0, 0, 0, 0, 0, 77, 101, 109, 111, 114, 121, 32, 97, 108, 108, 111, 99, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 32, 58, 32, 37, 115, 10, 0, 0, 77, 101, 109, 111, 114, 121, 32, 97, 108, 108, 111, 99, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 10, 0, 0, 0, 0, 0, 0, 0, 67, 104, 97, 114, 32, 48, 120, 37, 88, 32, 111, 117, 116, 32, 111, 102, 32, 97, 108, 108, 111, 119, 101, 100, 32, 114, 97, 110, 103, 101, 10, 0, 73, 110, 112, 117, 116, 32, 105, 115, 32, 110, 111, 116, 32, 112, 114, 111, 112, 101, 114, 32, 85, 84, 70, 45, 56, 44, 32, 105, 110, 100, 105, 99, 97, 116, 101, 32, 101, 110, 99, 111, 100, 105, 110, 103, 32, 33, 10, 0, 66, 121, 116, 101, 115, 58, 32, 48, 120, 37, 48, 50, 88, 32, 48, 120, 37, 48, 50, 88, 32, 48, 120, 37, 48, 50, 88, 32, 48, 120, 37, 48, 50, 88, 10, 0, 0, 0, 0, 0, 73, 110, 112, 117, 116, 32, 105, 115, 32, 110, 111, 116, 32, 112, 114, 111, 112, 101, 114, 32, 85, 84, 70, 45, 56, 44, 32, 105, 110, 100, 105, 99, 97, 116, 101, 32, 101, 110, 99, 111, 100, 105, 110, 103, 32, 33, 10, 37, 115, 0, 0, 0, 0, 0, 0, 0, 67, 104, 97, 114, 32, 48, 120, 48, 32, 111, 117, 116, 32, 111, 102, 32, 97, 108, 108, 111, 119, 101, 100, 32, 114, 97, 110, 103, 101, 10, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 44, 32, 120, 109, 108, 67, 111, 112, 121, 67, 104, 97, 114, 77, 117, 108, 116, 105, 66, 121, 116, 101, 32, 48, 120, 37, 88, 32, 111, 117, 116, 32, 111, 102, 32, 98, 111, 117, 110, 100, 10, 0, 101, 110, 99, 111, 100, 105, 110, 103, 32, 117, 110, 107, 110, 111, 119, 110, 10, 0, 0, 0, 0, 0, 0, 0, 101, 110, 99, 111, 100, 105, 110, 103, 32, 110, 111, 116, 32, 115, 117, 112], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 54128);
	        allocate([112, 111, 114, 116, 101, 100, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 85, 83, 67, 52, 32, 108, 105, 116, 116, 108, 101, 32, 101, 110, 100, 105, 97, 110, 0, 0, 0, 0, 0, 0, 85, 83, 67, 52, 32, 98, 105, 103, 32, 101, 110, 100, 105, 97, 110, 0, 69, 66, 67, 68, 73, 67, 0, 0, 85, 67, 83, 52, 32, 50, 49, 52, 51, 0, 0, 0, 0, 0, 0, 0, 85, 67, 83, 52, 32, 51, 52, 49, 50, 0, 0, 0, 0, 0, 0, 0, 85, 67, 83, 50, 0, 0, 0, 0, 73, 83, 79, 45, 50, 48, 50, 50, 45, 74, 80, 0, 0, 0, 0, 0, 83, 104, 105, 102, 116, 95, 74, 73, 83, 0, 0, 0, 0, 0, 0, 0, 69, 85, 67, 45, 74, 80, 0, 0, 99, 111, 117, 108, 100, 110, 39, 116, 32, 97, 108, 108, 111, 99, 97, 116, 101, 32, 97, 32, 110, 101, 119, 32, 105, 110, 112, 117, 116, 32, 115, 116, 114, 101, 97, 109, 10, 0, 0, 0, 110, 101, 119, 32, 105, 110, 112, 117, 116, 32, 102, 114, 111, 109, 32, 73, 47, 79, 10, 0, 0, 0, 0, 0, 120, 109, 108, 78, 101, 119, 69, 110, 116, 105, 116, 121, 73, 110, 112, 117, 116, 83, 116, 114, 101, 97, 109, 32, 101, 110, 116, 105, 116, 121, 32, 61, 32, 78, 85, 76, 76, 10, 0, 0, 110, 101, 119, 32, 105, 110, 112, 117, 116, 32, 102, 114, 111, 109, 32, 101, 110, 116, 105, 116, 121, 58, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 67, 97, 110, 110, 111, 116, 32, 112, 97, 114, 115, 101, 32, 101, 110, 116, 105, 116, 121, 32, 37, 115, 10, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 110, 116, 105, 116, 121, 32, 37, 115, 32, 119, 105, 116, 104, 111, 117, 116, 32, 99, 111, 110, 116, 101, 110, 116, 32, 33, 10, 0, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 32, 101, 110, 116, 105, 116, 121, 32, 37, 115, 32, 119, 105, 116, 104, 111, 117, 116, 32, 99, 111, 110, 116, 101, 110, 116, 32, 33, 10, 0, 80, 114, 101, 100, 101, 102, 105, 110, 101, 100, 32, 101, 110, 116, 105, 116, 121, 32, 37, 115, 32, 119, 105, 116, 104, 111, 117, 116, 32, 99, 111, 110, 116, 101, 110, 116, 32, 33, 10, 0, 110, 101, 119, 32, 105, 110, 112, 117, 116, 32, 102, 114, 111, 109, 32, 102, 105, 108, 101, 58, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 0, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 108, 111, 97, 100, 32, 101, 120, 116, 101, 114, 110, 97, 108, 32, 101, 110, 116, 105, 116, 121, 58, 32, 78, 85, 76, 76, 32, 102, 105, 108, 101, 110, 97, 109, 101, 32, 10, 0, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 108, 111, 97, 100, 32, 101, 120, 116, 101, 114, 110, 97, 108, 32, 101, 110, 116, 105, 116, 121, 32, 34, 37, 115, 34, 10, 0, 0, 0, 0, 71, 111, 116, 32, 78, 85, 76, 76, 32, 112, 97, 114, 115, 101, 114, 32, 99, 111, 110, 116, 101, 120, 116, 10, 0, 0, 0, 0, 0, 0, 0, 0, 99, 97, 110, 110, 111, 116, 32, 105, 110, 105, 116, 105, 97, 108, 105, 122, 101, 32, 112, 97, 114, 115, 101, 114, 32, 99, 111, 110, 116, 101, 120, 116, 10, 0, 0, 0, 0, 0, 0, 0, 99, 97, 110, 110, 111, 116, 32, 97, 108, 108, 111, 99, 97, 116, 101, 32, 112, 97, 114, 115, 101, 114, 32, 99, 111, 110, 116, 101, 120, 116, 10, 0, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 97, 108, 108, 111, 99, 97, 116, 101, 32, 98, 117, 102, 102, 101, 114, 10, 0, 0, 0, 0, 0, 0, 120, 109, 108, 83, 119, 105, 116, 99, 104, 84, 111, 69, 110, 99, 111, 100, 105, 110, 103, 32, 58, 32, 110, 111, 32, 105, 110, 112, 117, 116, 10, 0, 85, 84, 70, 45, 49, 54, 76, 69, 0, 0, 0, 0, 0, 0, 0, 0, 85, 84, 70, 45, 49, 54, 0, 0, 85, 84, 70, 45, 49, 54, 66, 69, 0, 0, 0, 0, 0, 0, 0, 0, 85, 84, 70, 45, 56, 0, 0, 0, 115, 119, 105, 116, 99, 104, 105, 110, 103, 32, 101, 110, 99, 111, 100, 105, 110, 103, 58, 32, 101, 110, 99, 111, 100, 101, 114, 32, 101, 114, 114, 111, 114, 10, 0, 0, 0, 0, 0, 0, 115, 119, 105, 116, 99, 104, 105, 110, 103, 32, 101, 110, 99, 111, 100, 105, 110, 103, 32, 58, 32, 110, 111, 32, 105, 110, 112, 117, 116, 10, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 69, 120, 99, 101, 115, 115, 105, 118, 101, 32, 100, 101, 112, 116, 104, 32, 105, 110, 32, 100, 111, 99, 117, 109, 101, 110, 116, 58, 32, 37, 100, 32, 117, 115, 101, 32, 88, 77, 76, 95, 80, 65, 82, 83, 69, 95, 72, 85, 71, 69, 32, 111, 112, 116, 105, 111, 110, 10, 0, 0, 0, 0, 0, 0, 80, 111, 112, 112, 105, 110, 103, 32, 105, 110, 112, 117, 116, 32, 37, 100, 10, 0, 0, 0, 0, 0, 0, 0, 37, 115, 40, 37, 100, 41, 58, 32, 0, 0, 0, 0, 0, 0, 0, 0, 80, 117, 115, 104, 105, 110, 103, 32, 105, 110, 112, 117, 116, 32, 37, 100, 32, 58, 32, 37, 46, 51, 48, 115, 10, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 80, 97, 114, 115, 101, 67, 104, 97, 114, 82, 101, 102, 58, 32, 105, 110, 118, 97, 108, 105, 100, 32, 120, 109, 108, 67, 104, 97, 114, 32, 118, 97, 108, 117, 101, 32, 37, 100, 10, 0, 0, 0, 0, 0, 0, 80, 69, 82, 101, 102, 101, 114, 101, 110, 99, 101, 58, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 0, 80, 69, 82, 101, 102, 101, 114, 101, 110, 99, 101, 58, 32, 37, 37, 37, 115, 59, 32, 110, 111, 116, 32, 102, 111, 117, 110, 100, 10, 0, 0, 0, 80, 69, 82, 101, 102, 101, 114, 101, 110, 99, 101, 58, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 32, 101, 110, 116, 105, 116, 121, 10, 0, 0, 0, 0, 0, 0, 83, 116, 114, 105, 110, 103, 32, 100, 101, 99, 111, 100, 105, 110, 103, 32, 69, 110, 116, 105, 116, 121, 32, 82, 101, 102, 101, 114, 101, 110, 99, 101, 58, 32, 37, 46, 51, 48, 115, 10, 0, 0, 0, 0, 0, 0, 0, 0, 112, 114, 101, 100, 101, 102, 105, 110, 101, 100, 32, 101, 110, 116, 105, 116, 121, 32, 104, 97, 115, 32, 110, 111, 32, 99, 111, 110, 116, 101, 110, 116, 10, 0, 0, 0, 0, 0, 0, 0, 83, 116, 114, 105, 110, 103, 32, 100, 101, 99, 111, 100, 105, 110, 103, 32, 80, 69, 32, 82, 101, 102, 101, 114, 101, 110, 99, 101, 58, 32, 37, 46, 51, 48, 115, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 78, 97, 109, 101, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 88, 77, 76, 32, 78, 97, 109, 101, 115, 112, 97, 99, 101, 32, 99, 111, 109, 112, 108, 105, 97, 110, 116, 10, 0, 78, 97, 109, 101, 0, 0, 0, 0, 78, 109, 84, 111, 107, 101, 110, 0, 69, 110, 116, 105, 116, 121, 86, 97, 108, 117, 101, 58, 32, 39, 37, 99, 39, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 101, 120, 99, 101, 112, 116, 32, 102, 111, 114, 32, 101, 110, 116, 105, 116, 105, 101, 115, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 115, 10, 0, 0, 0, 0, 0, 83, 121, 115, 116, 101, 109, 76, 105, 116, 101, 114, 97, 108, 0, 0, 0, 80, 117, 98, 108, 105, 99, 32, 73, 68, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 32, 33, 34, 35, 36, 37, 0, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 0, 61, 62, 63, 64, 65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 91, 92, 0, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 83, 112, 97, 99, 101, 32, 114, 101, 113, 117, 105, 114, 101, 100, 32, 97, 102, 116, 101, 114, 32, 39, 83, 89, 83, 84, 69, 77, 39, 10, 0, 0, 83, 112, 97, 99, 101, 32, 114, 101, 113, 117, 105, 114, 101, 100, 32, 97, 102, 116, 101, 114, 32, 39, 80, 85, 66, 76, 73, 67, 39, 10, 0, 0, 83, 112, 97, 99, 101, 32, 114, 101, 113, 117, 105, 114, 101, 100, 32, 97, 102, 116, 101, 114, 32, 116, 104, 101, 32, 80, 117, 98, 108, 105, 99, 32, 73, 100, 101, 110, 116, 105, 102, 105, 101, 114, 10, 0, 0, 0, 0, 0, 67, 111, 109, 109, 101, 110, 116, 32, 116, 111, 111, 32, 98, 105, 103, 32, 102, 111, 117, 110, 100, 0, 0, 0, 99, 111, 109, 109, 101, 110, 116, 32, 100, 111, 101, 115, 110, 39, 116, 32, 115, 116, 97, 114, 116, 32, 97, 110, 100, 32, 115, 116, 111, 112, 32, 105, 110, 32, 116, 104, 101, 32, 115, 97, 109, 101, 32, 101, 110, 116, 105, 116, 121, 10, 0, 0, 0, 0, 0, 0, 68, 111, 117, 98, 108, 101, 32, 104, 121, 112, 104, 101, 110, 32, 119, 105, 116, 104, 105, 110, 32, 99, 111, 109, 109, 101, 110, 116, 58, 32, 60, 33, 45, 45, 37, 46, 53, 48, 115, 10, 0, 0, 0, 0, 0, 0, 0, 0, 68, 111, 117, 98, 108, 101, 32, 104, 121, 112, 104, 101, 110, 32, 119, 105, 116, 104, 105, 110, 32, 99, 111, 109, 109, 101, 110, 116, 10, 0, 0, 0, 88, 77, 76, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 97, 108, 108, 111, 119, 101, 100, 32, 111, 110, 108, 121, 32, 97, 116, 32, 116, 104, 101, 32, 115, 116, 97, 114, 116, 32, 111, 102, 32, 116, 104, 101, 32, 100, 111, 99, 117, 109, 101, 110, 116, 10, 0, 0, 0, 0, 0, 0, 168, 27, 1, 0, 184, 27, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 80, 97, 114, 115, 101, 80, 73, 84, 97, 114, 103, 101, 116, 58, 32, 105, 110, 118, 97, 108, 105, 100, 32, 110, 97, 109, 101, 32, 112, 114, 101, 102, 105, 120, 32, 39, 120, 109, 108, 39, 10, 0, 0, 0, 0, 99, 111, 108, 111, 110, 115, 32, 97, 114, 101, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 102, 114, 111, 109, 32, 80, 73, 32, 110, 97, 109, 101, 115, 32, 39, 37, 115, 39, 10, 0, 0, 0, 0, 0, 0, 0, 0, 80, 73, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 100, 111, 101, 115, 110, 39, 116, 32, 115, 116, 97, 114, 116, 32, 97, 110, 100, 32, 115, 116, 111, 112, 32, 105, 110, 32, 116, 104, 101, 32, 115, 97, 109, 101, 32, 101, 110, 116, 105, 116, 121, 10, 0, 0, 0, 0, 0, 0, 0, 80, 97, 114, 115, 101, 80, 73, 58, 32, 80, 73, 32, 37, 115, 32, 115, 112, 97, 99, 101, 32, 101, 120, 112, 101, 99, 116, 101, 100, 10, 0, 0, 80, 73, 32, 37, 115, 32, 116, 111, 111, 32, 98, 105, 103, 32, 102, 111, 117, 110, 100, 0, 0, 0, 0, 0, 80, 97, 114, 115, 101, 80, 73, 58, 32, 80, 73, 32, 37, 115, 32, 110, 101, 118, 101, 114, 32, 101, 110, 100, 32, 46, 46, 46, 10, 0, 0, 0, 111, 97, 115, 105, 115, 45, 120, 109, 108, 45, 99, 97, 116, 97, 108, 111, 103, 0, 0, 0, 0, 0, 0, 0, 83, 112, 97, 99, 101, 32, 114, 101, 113, 117, 105, 114, 101, 100, 32, 97, 102, 116, 101, 114, 32, 39, 60, 33, 78, 79, 84, 65, 84, 73, 79, 78, 39, 10, 0, 0, 0, 0, 0, 0, 83, 112, 97, 99, 101, 32, 114, 101, 113, 117, 105, 114, 101, 100, 32, 97, 102, 116, 101, 114, 32, 116, 104, 101, 32, 78, 79, 84, 65, 84, 73, 79, 78, 32, 110, 97, 109, 101, 39, 10, 0, 0, 0, 0, 0, 0, 0, 0, 99, 111, 108, 111, 110, 115, 32, 97, 114, 101, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 102, 114, 111, 109, 32, 110, 111, 116, 97, 116, 105, 111, 110, 32, 110, 97, 109, 101, 115, 32, 39, 37, 115, 39, 10, 0, 0, 78, 111, 116, 97, 116, 105, 111, 110, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 100, 111, 101, 115, 110, 39, 116, 32, 115, 116, 97, 114, 116, 32, 97, 110, 100, 32, 115, 116, 111, 112, 32, 105, 110, 32, 116, 104, 101, 32, 115, 97, 109, 101, 32, 101, 110, 116, 105, 116, 121, 10, 0, 83, 112, 97, 99, 101, 32, 114, 101, 113, 117, 105, 114, 101, 100, 32, 97, 102, 116, 101, 114, 32, 39, 60, 33, 69, 78, 84, 73, 84, 89, 39, 10, 0, 0, 0, 0, 0, 0, 0, 0, 83, 112, 97, 99, 101, 32, 114, 101, 113, 117, 105, 114, 101, 100, 32, 97, 102, 116, 101, 114, 32, 39, 37, 39, 10, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 80, 97, 114, 115, 101, 69, 110, 116, 105, 116, 121, 68, 101, 99, 108, 58, 32, 110, 111, 32, 110, 97, 109, 101, 10, 0, 0, 0, 0, 99, 111, 108, 111, 110, 115, 32, 97, 114, 101, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 102, 114, 111, 109, 32, 101, 110, 116, 105, 116, 105, 101, 115, 32, 110, 97, 109, 101, 115, 32, 39, 37, 115, 39, 10, 0, 0, 83, 112, 97, 99, 101, 32, 114, 101, 113, 117, 105, 114, 101, 100, 32, 97, 102, 116, 101, 114, 32, 116, 104, 101, 32, 101, 110, 116, 105, 116, 121, 32, 110, 97, 109, 101, 10, 0, 0, 0, 73, 110, 118, 97, 108, 105, 100, 32, 85, 82, 73, 58, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 0, 83, 65, 88, 32, 99, 111, 109, 112, 97, 116, 105, 98, 105, 108, 105, 116, 121, 32, 109, 111, 100, 101, 32, 100, 111, 99, 117, 109, 101, 110, 116, 0, 78, 101, 119, 32, 68, 111, 99, 32, 102, 97, 105, 108, 101, 100, 0, 0, 102, 97, 107, 101, 0, 0, 0, 0, 83, 112, 97, 99, 101, 32, 114, 101, 113, 117, 105, 114, 101, 100, 32, 98, 101, 102, 111, 114, 101, 32, 39, 78, 68, 65, 84, 65, 39, 10, 0, 0, 83, 112, 97, 99, 101, 32, 114, 101, 113, 117, 105, 114, 101, 100, 32, 97, 102, 116, 101, 114, 32, 39, 78, 68, 65, 84, 65, 39, 10, 0, 0, 0, 120, 109, 108, 80, 97, 114, 115, 101, 69, 110, 116, 105, 116, 121, 68, 101, 99, 108, 58, 32, 101, 110, 116, 105, 116, 121, 32, 37, 115, 32, 110, 111, 116, 32, 116, 101, 114, 109, 105, 110, 97, 116, 101, 100, 10, 0, 0, 0, 69, 110, 116, 105, 116, 121, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 100, 111, 101, 115, 110, 39, 116, 32, 115, 116, 97, 114, 116, 32, 97, 110, 100, 32, 115, 116, 111, 112, 32, 105, 110, 32, 116, 104, 101, 32, 115, 97, 109, 101, 32, 101, 110, 116, 105, 116, 121, 10, 0, 0, 0, 83, 112, 97, 99, 101, 32, 114, 101, 113, 117, 105, 114, 101, 100, 32, 97, 102, 116, 101, 114, 32, 39, 35, 70, 73, 88, 69, 68, 39, 10, 0, 0, 65, 116, 116, 114, 105, 98, 117, 116, 101, 32, 100, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 101, 114, 114, 111, 114, 10, 0, 0, 0, 0, 0, 0, 78, 97, 109, 101, 32, 101, 120, 112, 101, 99, 116, 101, 100, 32, 105, 110, 32, 78, 79, 84, 65, 84, 73, 79, 78, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 10, 0, 0, 115, 116, 97, 110, 100, 97, 108, 111, 110, 101, 58, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 110, 111, 116, 97, 116, 105, 111, 110, 32, 118, 97, 108, 117, 101, 32, 116, 111, 107, 101, 110, 32, 37, 115, 32, 100, 117, 112, 108, 105, 99, 97, 116, 101, 100, 10, 0, 0, 0, 0, 0, 0, 0, 115, 116, 97, 110, 100, 97, 108, 111, 110, 101, 58, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 101, 110, 117, 109, 101, 114, 97, 116, 105, 111, 110, 32, 118, 97, 108, 117, 101, 32, 116, 111, 107, 101, 110, 32, 37, 115, 32, 100, 117, 112, 108, 105, 99, 97, 116, 101, 100, 10, 0, 0, 0, 0, 83, 112, 97, 99, 101, 32, 114, 101, 113, 117, 105, 114, 101, 100, 32, 97, 102, 116, 101, 114, 32, 39, 78, 79, 84, 65, 84, 73, 79, 78, 39, 10, 0, 0, 0, 0, 0, 0, 0, 0, 83, 112, 97, 99, 101, 32, 114, 101, 113, 117, 105, 114, 101, 100, 32, 97, 102, 116, 101, 114, 32, 39, 60, 33, 65, 84, 84, 76, 73, 83, 84, 39, 10, 0, 0, 0, 0, 0, 0, 0, 65, 84, 84, 76, 73, 83, 84, 58, 32, 110, 111, 32, 110, 97, 109, 101, 32, 102, 111, 114, 32, 69, 108, 101, 109, 101, 110, 116, 10, 0, 0, 0, 65, 84, 84, 76, 73, 83, 84, 58, 32, 110, 111, 32, 110, 97, 109, 101, 32, 102, 111, 114, 32, 65, 116, 116, 114, 105, 98, 117, 116, 101, 10, 0, 83, 112, 97, 99, 101, 32, 114, 101, 113, 117, 105, 114, 101, 100, 32, 97, 102, 116, 101, 114, 32, 116, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 110, 97, 109, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 83, 112, 97, 99, 101, 32, 114, 101, 113, 117, 105, 114, 101, 100, 32, 97, 102, 116, 101, 114, 32, 116, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 116, 121, 112, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 83, 112, 97, 99, 101, 32, 114, 101, 113, 117, 105, 114, 101, 100, 32, 97, 102, 116, 101, 114, 32, 116, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 100, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 10, 0, 0, 0, 0, 0, 0, 0, 105, 110, 32, 120, 109, 108, 80, 97, 114, 115, 101, 65, 116, 116, 114, 105, 98, 117, 116, 101, 76, 105, 115, 116, 68, 101, 99, 108, 10, 0, 0, 0, 65, 116, 116, 114, 105, 98, 117, 116, 101, 32, 108, 105, 115, 116, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 100, 111, 101, 115, 110, 39, 116, 32, 115, 116, 97, 114, 116, 32, 97, 110, 100, 32, 115, 116, 111, 112, 32, 105, 110, 32, 116, 104, 101, 32, 115, 97, 109, 101, 32, 101, 110, 116, 105, 116, 121, 10, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 99, 111, 110, 116, 101, 110, 116, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 100, 111, 101, 115, 110, 39, 116, 32, 115, 116, 97, 114, 116, 32, 97, 110, 100, 32, 115, 116, 111, 112, 32, 105, 110, 32, 116, 104, 101, 32, 115, 97, 109, 101, 32, 101, 110, 116, 105, 116, 121, 10, 0, 0, 120, 109, 108, 80, 97, 114, 115, 101, 69, 108, 101, 109, 101, 110, 116, 77, 105, 120, 101, 100, 67, 111, 110, 116, 101, 110, 116, 68, 101, 99, 108, 32, 58, 32, 78, 97, 109, 101, 32, 101, 120, 112, 101, 99, 116, 101, 100, 10, 0, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 80, 97, 114, 115, 101, 69, 108, 101, 109, 101, 110, 116, 67, 111, 110, 116, 101, 110, 116, 68, 101, 99, 108, 32, 58, 32, 37, 115, 32, 39, 40, 39, 32, 101, 120, 112, 101, 99, 116, 101, 100, 10, 0, 0, 0, 83, 112, 97, 99, 101, 32, 114, 101, 113, 117, 105, 114, 101, 100, 32, 97, 102, 116, 101, 114, 32, 39, 69, 76, 69, 77, 69, 78, 84, 39, 10, 0, 120, 109, 108, 80, 97, 114, 115, 101, 69, 108, 101, 109, 101, 110, 116, 68, 101, 99, 108, 58, 32, 110, 111, 32, 110, 97, 109, 101, 32, 102, 111, 114, 32, 69, 108, 101, 109, 101, 110, 116, 10, 0, 0, 0, 0, 0, 0, 0, 83, 112, 97, 99, 101, 32, 114, 101, 113, 117, 105, 114, 101, 100, 32, 97, 102, 116, 101, 114, 32, 116, 104, 101, 32, 101, 108, 101, 109, 101, 110, 116, 32, 110, 97, 109, 101, 10, 0, 0, 80, 69, 82, 101, 102, 101, 114, 101, 110, 99, 101, 58, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 119, 105, 116, 104, 105, 110, 32, 109, 97, 114, 107, 117, 112, 32, 100, 101, 99, 108, 32, 105, 110, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 115, 117, 98, 115, 101, 116, 10, 0, 0, 0, 120, 109, 108, 80, 97, 114, 115, 101, 69, 108, 101, 109, 101, 110, 116, 68, 101, 99, 108, 58, 32, 39, 69, 77, 80, 84, 89, 39, 44, 32, 39, 65, 78, 89, 39, 32, 111, 114, 32, 39, 40, 39, 32, 101, 120, 112, 101, 99, 116, 101, 100, 10, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 100, 111, 101, 115, 110, 39, 116, 32, 115, 116, 97, 114, 116, 32, 97, 110, 100, 32, 115, 116, 111, 112, 32, 105, 110, 32, 116, 104, 101, 32, 115, 97, 109, 101, 32, 101, 110, 116, 105, 116, 121, 10, 0, 0, 83, 112, 97, 99, 101, 32, 110, 101, 101, 100, 101, 100, 32, 97, 102, 116, 101, 114, 32, 39, 60, 63, 120, 109, 108, 39, 10, 0, 0, 0, 0, 0, 49, 46, 48, 0, 0, 0, 0, 0, 83, 112, 97, 99, 101, 32, 110, 101, 101, 100, 101, 100, 32, 104, 101, 114, 101, 10, 0, 0, 0, 0, 0, 0, 77, 105, 115, 115, 105, 110, 103, 32, 101, 110, 99, 111, 100, 105, 110, 103, 32, 105, 110, 32, 116, 101, 120, 116, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 10, 0, 0, 0, 35, 120, 37, 88, 0, 0, 0, 0, 35, 37, 100, 0, 0, 0, 0, 0, 105, 110, 118, 97, 108, 105, 100, 32, 101, 110, 116, 105, 116, 121, 32, 116, 121, 112, 101, 32, 102, 111, 117, 110, 100, 10, 0, 0, 0, 0, 0, 0, 69, 110, 116, 105, 116, 121, 32, 39, 37, 115, 39, 32, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 112, 97, 114, 115, 101, 10, 0, 0, 0, 0, 110, 98, 107, 116, 101, 120, 116, 0, 120, 109, 108, 80, 97, 114, 115, 101, 69, 110, 116, 105, 116, 121, 82, 101, 102, 58, 32, 110, 111, 32, 110, 97, 109, 101, 10, 0, 0, 0, 0, 0, 69, 110, 116, 105, 116, 121, 32, 39, 37, 115, 39, 32, 110, 111, 116, 32, 100, 101, 102, 105, 110, 101, 100, 10, 0, 0, 0, 0, 0, 0, 0, 0, 69, 110, 116, 105, 116, 121, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 116, 111, 32, 117, 110, 112, 97, 114, 115, 101, 100, 32, 101, 110, 116, 105, 116, 121, 32, 37, 115, 10, 0, 65, 116, 116, 114, 105, 98, 117, 116, 101, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 115, 32, 101, 120, 116, 101, 114, 110, 97, 108, 32, 101, 110, 116, 105, 116, 121, 32, 39, 37, 115, 39, 10, 0, 0, 0, 0, 0, 0, 39, 60, 39, 32, 105, 110, 32, 101, 110, 116, 105, 116, 121, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 101, 100, 32, 105, 110, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 115, 32, 118, 97, 108, 117, 101, 115, 10, 0, 65, 116, 116, 101, 109, 112, 116, 32, 116, 111, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 116, 104, 101, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 32, 101, 110, 116, 105, 116, 121, 32, 39, 37, 115, 39, 10, 0, 120, 109, 108, 80, 97, 114, 115, 101, 80, 69, 82, 101, 102, 101, 114, 101, 110, 99, 101, 58, 32, 110, 111, 32, 110, 97, 109, 101, 10, 0, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 58, 32, 37, 37, 37, 115, 59, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 32, 101, 110, 116, 105, 116, 121, 10, 0, 0, 0, 0, 0, 0, 120, 109, 108, 80, 97, 114, 115, 101, 68, 111, 99, 84, 121, 112, 101, 68, 101, 99, 108, 32, 58, 32, 110, 111, 32, 68, 79, 67, 84, 89, 80, 69, 32, 110, 97, 109, 101, 32, 33, 10, 0, 0, 0, 0, 0, 0, 0, 0, 101, 114, 114, 111, 114, 32, 112, 97, 114, 115, 105, 110, 103, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 110, 97, 109, 101, 10, 0, 0, 0, 83, 112, 101, 99, 105, 102, 105, 99, 97, 116, 105, 111, 110, 32, 109, 97, 110, 100, 97, 116, 101, 32, 118, 97, 108, 117, 101, 32, 102, 111, 114, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 10, 0, 0, 0, 120, 109, 108, 58, 108, 97, 110, 103, 0, 0, 0, 0, 0, 0, 0, 0, 77, 97, 108, 102, 111, 114, 109, 101, 100, 32, 118, 97, 108, 117, 101, 32, 102, 111, 114, 32, 120, 109, 108, 58, 108, 97, 110, 103, 32, 58, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 120, 109, 108, 58, 115, 112, 97, 99, 101, 0, 0, 0, 0, 0, 0, 0, 100, 101, 102, 97, 117, 108, 116, 0, 112, 114, 101, 115, 101, 114, 118, 101, 0, 0, 0, 0, 0, 0, 0, 0, 73, 110, 118, 97, 108, 105, 100, 32, 118, 97, 108, 117, 101, 32, 34, 37, 115, 34, 32, 102, 111, 114, 32, 120, 109, 108, 58, 115, 112, 97, 99, 101, 32, 58, 32, 34, 100, 101, 102, 97, 117, 108, 116, 34, 32, 111, 114, 32, 34, 112, 114, 101, 115, 101, 114, 118, 101, 34, 32, 101, 120, 112, 101, 99, 116, 101, 100, 10, 0, 0, 0, 0, 120, 109, 108, 80, 97, 114, 115, 101, 83, 116, 97, 114, 116, 84, 97, 103, 58, 32, 105, 110, 118, 97, 108, 105, 100, 32, 101, 108, 101, 109, 101, 110, 116, 32, 110, 97, 109, 101, 10, 0, 97, 116, 116, 114, 105, 98, 117, 116, 101, 115, 32, 99, 111, 110, 115, 116, 114, 117, 99, 116, 32, 101, 114, 114, 111, 114, 10, 0, 0, 0, 0, 0, 120, 109, 108, 80, 97, 114, 115, 101, 83, 116, 97, 114, 116, 84, 97, 103, 58, 32, 112, 114, 111, 98, 108, 101, 109, 32, 112, 97, 114, 115, 105, 110, 103, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 115, 10, 0, 0, 0, 67, 68, 97, 116, 97, 32, 115, 101, 99, 116, 105, 111, 110, 32, 116, 111, 111, 32, 98, 105, 103, 32, 102, 111, 117, 110, 100, 0, 0, 0, 0, 0, 67, 68, 97, 116, 97, 32, 115, 101, 99, 116, 105, 111, 110, 32, 110, 111, 116, 32, 102, 105, 110, 105, 115, 104, 101, 100, 10, 37, 46, 53, 48, 115, 10, 0, 0, 0, 0, 0, 0, 0, 100, 101, 116, 101, 99, 116, 101, 100, 32, 97, 110, 32, 101, 114, 114, 111, 114, 32, 105, 110, 32, 101, 108, 101, 109, 101, 110, 116, 32, 99, 111, 110, 116, 101, 110, 116, 10, 0, 0, 0, 67, 111, 117, 108, 100, 110, 39, 116, 32, 102, 105, 110, 100, 32, 101, 110, 100, 32, 111, 102, 32, 83, 116, 97, 114, 116, 32, 84, 97, 103, 32, 37, 115, 32, 108, 105, 110, 101, 32, 37, 100, 10, 0, 0, 0, 0, 0, 0, 80, 114, 101, 109, 97, 116, 117, 114, 101, 32, 101, 110, 100, 32, 111, 102, 32, 100, 97, 116, 97, 32, 105, 110, 32, 116, 97, 103, 32, 37, 115, 32, 108, 105, 110, 101, 32, 37, 100, 10, 0, 0, 0, 0, 0, 0, 0, 0, 85, 84, 70, 45, 49, 54, 0, 0, 85, 84, 70, 49, 54, 0, 0, 0, 68, 111, 99, 117, 109, 101, 110, 116, 32, 108, 97, 98, 101, 108, 108, 101, 100, 32, 85, 84, 70, 45, 49, 54, 32, 98, 117, 116, 32, 104, 97, 115, 32, 85, 84, 70, 45, 56, 32, 99, 111, 110, 116, 101, 110, 116, 10, 0, 85, 84, 70, 45, 56, 0, 0, 0, 85, 84, 70, 56, 0, 0, 0, 0, 85, 110, 115, 117, 112, 112, 111, 114, 116, 101, 100, 32, 101, 110, 99, 111, 100, 105, 110, 103, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 0, 66, 108, 97, 110, 107, 32, 110, 101, 101, 100, 101, 100, 32, 97, 102, 116, 101, 114, 32, 39, 60, 63, 120, 109, 108, 39, 10, 0, 0, 0, 0, 0, 85, 110, 115, 117, 112, 112, 111, 114, 116, 101, 100, 32, 118, 101, 114, 115, 105, 111, 110, 32, 39, 37, 115, 39, 10, 0, 0, 0, 0, 0, 0, 0, 66, 108, 97, 110, 107, 32, 110, 101, 101, 100, 101, 100, 32, 104, 101, 114, 101, 10, 0, 0, 0, 0, 0, 0, 83, 116, 97, 114, 116, 32, 116, 97, 103, 32, 101, 120, 112, 101, 99, 116, 101, 100, 44, 32, 39, 60, 39, 32, 110, 111, 116, 32, 102, 111, 117, 110, 100, 10, 0, 0, 0, 0, 0, 0, 85, 67, 83, 45, 52, 0, 0, 0, 85, 67, 83, 52, 0, 0, 0, 0, 120, 109, 108, 80, 97, 114, 115, 101, 67, 104, 117, 110, 107, 58, 32, 101, 110, 99, 111, 100, 101, 114, 32, 101, 114, 114, 111, 114, 10, 0, 0, 0, 72, 117, 103, 101, 32, 105, 110, 112, 117, 116, 32, 108, 111, 111, 107, 117, 112, 0, 0, 0, 0, 0, 0, 0, 13, 0, 0, 0, 0, 0, 0, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 112, 97, 114, 115, 101, 114, 58, 32, 111, 117, 116, 32, 111, 102, 32, 109, 101, 109, 111, 114, 121, 10, 0, 110, 111, 110, 101, 0, 0, 0, 0, 112, 115, 101, 117, 100, 111, 114, 111, 111, 116, 0, 0, 0, 0, 0, 0, 86, 101, 114, 115, 105, 111, 110, 32, 109, 105, 115, 109, 97, 116, 99, 104, 32, 98, 101, 116, 119, 101, 101, 110, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 97, 110, 100, 32, 101, 110, 116, 105, 116, 121, 10, 0, 0, 0, 120, 109, 108, 0, 0, 0, 0, 0, 120, 109, 108, 110, 115, 0, 0, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 88, 77, 76, 47, 49, 57, 57, 56, 47, 110, 97, 109, 101, 115, 112, 97, 99, 101, 0, 0, 0, 0, 99, 97, 110, 110, 111, 116, 32, 97, 108, 108, 111, 99, 97, 116, 101, 32, 112, 97, 114, 115, 101, 114, 32, 99, 111, 110, 116, 101, 120, 116, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 67, 111, 117, 108, 100, 110, 39, 116, 32, 102, 105, 110, 100, 32, 101, 110, 100, 32, 111, 102, 32, 83, 116, 97, 114, 116, 32, 84, 97, 103, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 60, 33, 91, 67, 68, 65, 84, 65, 91, 0, 0, 0, 0, 0, 0, 0, 80, 80, 58, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 44, 32, 115, 116, 97, 116, 101, 32, 61, 61, 32, 67, 79, 77, 77, 69, 78, 84, 10, 0, 0, 0, 80, 80, 58, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 44, 32, 115, 116, 97, 116, 101, 32, 61, 61, 32, 73, 71, 78, 79, 82, 69, 0, 0, 0, 0, 0, 80, 80, 58, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 44, 32, 115, 116, 97, 116, 101, 32, 61, 61, 32, 80, 73, 10, 0, 0, 0, 0, 0, 0, 0, 0, 80, 80, 58, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 44, 32, 115, 116, 97, 116, 101, 32, 61, 61, 32, 69, 78, 84, 73, 84, 89, 95, 68, 69, 67, 76, 10, 0, 0, 0, 0, 0, 0, 0, 80, 80, 58, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 44, 32, 115, 116, 97, 116, 101, 32, 61, 61, 32, 69, 78, 84, 73, 84, 89, 95, 86, 65, 76, 85, 69, 10, 0, 0, 0, 0, 0, 0, 80, 80, 58, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 44, 32, 115, 116, 97, 116, 101, 32, 61, 61, 32, 65, 84, 84, 82, 73, 66, 85, 84, 69, 95, 86, 65, 76, 85, 69, 10, 0, 0, 0, 80, 80, 58, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 44, 32, 115, 116, 97, 116, 101, 32, 61, 61, 32, 83, 89, 83, 84, 69, 77, 95, 76, 73, 84, 69, 82, 65, 76, 10, 0, 0, 0, 0, 80, 80, 58, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 44, 32, 115, 116, 97, 116, 101, 32, 61, 61, 32, 80, 85, 66, 76, 73, 67, 95, 76, 73, 84, 69, 82, 65, 76, 10, 0, 0, 0, 0, 66, 121, 116, 101, 115, 58, 32, 48, 120, 37, 48, 50, 88, 32, 48, 120, 37, 48, 50, 88, 32, 48, 120, 37, 48, 50, 88, 32, 48, 120, 37, 48, 50, 88, 10, 0, 0, 0, 0, 0, 73, 110, 112, 117, 116, 32, 105, 115, 32, 110, 111, 116, 32, 112, 114, 111, 112, 101, 114, 32, 85, 84, 70, 45, 56, 44, 32, 105, 110, 100, 105, 99, 97, 116, 101, 32, 101, 110, 99, 111, 100, 105, 110, 103, 32, 33, 10, 37, 115, 0, 0, 0, 0, 0, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 58, 32, 120, 109, 108, 80, 97, 114, 115, 101, 71, 101, 116, 76, 97, 115, 116, 115, 10, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 80, 97, 114, 115, 101, 73, 110, 116, 101, 114, 110, 97, 108, 83, 117, 98, 115, 101, 116, 58, 32, 101, 114, 114, 111, 114, 32, 100, 101, 116, 101, 99, 116, 101, 100, 32, 105, 110, 32, 77, 97, 114, 107, 117, 112, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 10, 0, 0, 0, 117, 110, 112, 97, 114, 115, 101, 97, 98, 108, 101, 0, 0, 0, 0, 0, 79, 112, 101, 110, 105, 110, 103, 32, 97, 110, 100, 32, 101, 110, 100, 105, 110, 103, 32, 116, 97, 103, 32, 109, 105, 115, 109, 97, 116, 99, 104, 58, 32, 37, 115, 32, 108, 105, 110, 101, 32, 37, 100, 32, 97, 110, 100, 32, 37, 115, 10, 0, 0, 0, 0, 0, 70, 97, 105, 108, 101, 100, 32, 116, 111, 32, 112, 97, 114, 115, 101, 32, 81, 78, 97, 109, 101, 32, 39, 37, 115, 39, 10, 0, 0, 0, 0, 0, 70, 97, 105, 108, 101, 100, 32, 116, 111, 32, 112, 97, 114, 115, 101, 32, 81, 78, 97, 109, 101, 32, 39, 37, 115, 58, 39, 10, 0, 0, 0, 0, 70, 97, 105, 108, 101, 100, 32, 116, 111, 32, 112, 97, 114, 115, 101, 32, 81, 78, 97, 109, 101, 32, 39, 37, 115, 58, 37, 115, 58, 39, 10, 0, 78, 67, 78, 97, 109, 101, 0, 0, 80, 98, 109, 32, 112, 111, 112, 112, 105, 110, 103, 32, 37, 100, 32, 78, 83, 10, 0, 0, 0, 0, 0, 0, 83, 116, 97, 114, 116, 84, 97, 103, 58, 32, 105, 110, 118, 97, 108, 105, 100, 32, 101, 108, 101, 109, 101, 110, 116, 32, 110, 97, 109, 101, 10, 0, 100, 105, 99, 116, 105, 111, 110, 97, 114, 121, 32, 97, 108, 108, 111, 99, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 117, 114, 101, 0, 0, 0, 120, 109, 108, 110, 115, 58, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 118, 97, 108, 105, 100, 32, 85, 82, 73, 10, 0, 120, 109, 108, 110, 115, 58, 32, 85, 82, 73, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 97, 98, 115, 111, 108, 117, 116, 101, 10, 0, 0, 120, 109, 108, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 85, 82, 73, 32, 99, 97, 110, 110, 111, 116, 32, 98, 101, 32, 116, 104, 101, 32, 100, 101, 102, 97, 117, 108, 116, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 10, 0, 0, 0, 0, 0, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 50, 48, 48, 48, 47, 120, 109, 108, 110, 115, 47, 0, 0, 0, 114, 101, 117, 115, 101, 32, 111, 102, 32, 116, 104, 101, 32, 120, 109, 108, 110, 115, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 110, 97, 109, 101, 32, 105, 115, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 10, 0, 120, 109, 108, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 112, 114, 101, 102, 105, 120, 32, 109, 97, 112, 112, 101, 100, 32, 116, 111, 32, 119, 114, 111, 110, 103, 32, 85, 82, 73, 10, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 85, 82, 73, 32, 109, 97, 112, 112, 101, 100, 32, 116, 111, 32, 119, 114, 111, 110, 103, 32, 112, 114, 101, 102, 105, 120, 10, 0, 0, 0, 0, 0, 0, 0, 114, 101, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 111, 102, 32, 116, 104, 101, 32, 120, 109, 108, 110, 115, 32, 112, 114, 101, 102, 105, 120, 32, 105, 115, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 10, 0, 0, 120, 109, 108, 110, 115, 58, 37, 115, 58, 32, 69, 109, 112, 116, 121, 32, 88, 77, 76, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 105, 115, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 101, 100, 10, 0, 0, 0, 120, 109, 108, 110, 115, 58, 37, 115, 58, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 118, 97, 108, 105, 100, 32, 85, 82, 73, 10, 0, 0, 0, 0, 0, 0, 120, 109, 108, 110, 115, 58, 37, 115, 58, 32, 85, 82, 73, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 97, 98, 115, 111, 108, 117, 116, 101, 10, 0, 0, 0, 0, 0, 0, 0, 115, 116, 97, 110, 100, 97, 108, 111, 110, 101, 58, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 111, 110, 32, 37, 115, 32, 100, 101, 102, 97, 117, 108, 116, 101, 100, 32, 102, 114, 111, 109, 32, 101, 120, 116, 101, 114, 110, 97, 108, 32, 115, 117, 98, 115, 101, 116, 10, 0, 0, 78, 97, 109, 101, 115, 112, 97, 99, 101, 32, 112, 114, 101, 102, 105, 120, 32, 37, 115, 32, 102, 111, 114, 32, 37, 115, 32, 111, 110, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 100, 101, 102, 105, 110, 101, 100, 10, 0, 0, 0, 0, 0, 0, 0, 0, 78, 97, 109, 101, 115, 112, 97, 99, 101, 100, 32, 65, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 105, 110, 32, 39, 37, 115, 39, 32, 114, 101, 100, 101, 102, 105, 110, 101, 100, 10, 0, 0, 0, 0, 0, 0, 78, 97, 109, 101, 115, 112, 97, 99, 101, 32, 112, 114, 101, 102, 105, 120, 32, 37, 115, 32, 111, 110, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 100, 101, 102, 105, 110, 101, 100, 10, 0, 0, 0, 0, 0, 0, 0, 108, 97, 110, 103, 0, 0, 0, 0, 115, 112, 97, 99, 101, 0, 0, 0, 65, 116, 116, 86, 97, 108, 117, 101, 32, 108, 101, 110, 103, 116, 104, 32, 116, 111, 111, 32, 108, 111, 110, 103, 10, 0, 0, 0, 0, 0, 0, 0, 105, 110, 118, 97, 108, 105, 100, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 105, 110, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 118, 97, 108, 117, 101, 10, 0, 0, 0, 65, 116, 116, 86, 97, 108, 117, 101, 58, 32, 39, 32, 101, 120, 112, 101, 99, 116, 101, 100, 10, 0, 0, 0, 120, 109, 108, 80, 97, 114, 115, 101, 69, 110, 100, 84, 97, 103, 58, 32, 39, 60, 47, 39, 32, 110, 111, 116, 32, 102, 111, 117, 110, 100, 10, 0, 65, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 114, 101, 100, 101, 102, 105, 110, 101, 100, 10, 0, 65, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 58, 37, 115, 32, 114, 101, 100, 101, 102, 105, 110, 101, 100, 10, 0, 0, 0, 0, 0, 0, 120, 109, 108, 80, 97, 114, 115, 101, 83, 116, 114, 105, 110, 103, 80, 69, 82, 101, 102, 101, 114, 101, 110, 99, 101, 58, 32, 110, 111, 32, 110, 97, 109, 101, 10, 0, 0, 0, 0, 0, 37, 37, 37, 115, 59, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 32, 101, 110, 116, 105, 116, 121, 10, 0, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 76, 111, 97, 100, 69, 110, 116, 105, 116, 121, 67, 111, 110, 116, 101, 110, 116, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 32, 101, 114, 114, 111, 114, 0, 0, 0, 0, 82, 101, 97, 100, 105, 110, 103, 32, 37, 115, 32, 101, 110, 116, 105, 116, 121, 32, 99, 111, 110, 116, 101, 110, 116, 32, 105, 110, 112, 117, 116, 10, 0, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 76, 111, 97, 100, 69, 110, 116, 105, 116, 121, 67, 111, 110, 116, 101, 110, 116, 32, 105, 110, 112, 117, 116, 32, 101, 114, 114, 111, 114, 0, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 76, 111, 97, 100, 69, 110, 116, 105, 116, 121, 67, 111, 110, 116, 101, 110, 116, 58, 32, 105, 110, 118, 97, 108, 105, 100, 32, 99, 104, 97, 114, 32, 118, 97, 108, 117, 101, 32, 37, 100, 10, 0, 0, 0, 0, 120, 109, 108, 80, 97, 114, 115, 101, 83, 116, 114, 105, 110, 103, 69, 110, 116, 105, 116, 121, 82, 101, 102, 58, 32, 110, 111, 32, 110, 97, 109, 101, 10, 0, 0, 0, 0, 0, 0, 0, 65, 108, 108, 32, 109, 97, 114, 107, 117, 112, 32, 111, 102, 32, 116, 104, 101, 32, 99, 111, 110, 100, 105, 116, 105, 111, 110, 97, 108, 32, 115, 101, 99, 116, 105, 111, 110, 32, 105, 115, 32, 110, 111, 116, 32, 105, 110, 32, 116, 104, 101, 32, 115, 97, 109, 101, 32, 101, 110, 116, 105, 116, 121, 10, 0, 0, 0, 0, 0, 0, 0, 0, 69, 110, 116, 101, 114, 105, 110, 103, 32, 73, 78, 67, 76, 85, 68, 69, 32, 67, 111, 110, 100, 105, 116, 105, 111, 110, 97, 108, 32, 83, 101, 99, 116, 105, 111, 110, 10, 0, 0, 0, 76, 101, 97, 118, 105, 110, 103, 32, 73, 78, 67, 76, 85, 68, 69, 32, 67, 111, 110, 100, 105, 116, 105, 111, 110, 97, 108, 32, 83, 101, 99, 116, 105, 111, 110, 10, 0, 0, 0, 0, 69, 110, 116, 101, 114, 105, 110, 103, 32, 73, 71, 78, 79, 82, 69, 32, 67, 111, 110, 100, 105, 116, 105, 111, 110, 97, 108, 32, 83, 101, 99, 116, 105, 111, 110, 10, 0, 0, 0, 0, 76, 101, 97, 118, 105, 110, 103, 32, 73, 71, 78, 79, 82, 69, 32, 67, 111, 110, 100, 105, 116, 105, 111, 110, 97, 108, 32, 83, 101, 99, 116, 105, 111, 110, 10, 0, 0, 0, 0, 0, 120, 109, 108, 80, 97, 114, 115, 101, 69, 108, 101, 109, 101, 110, 116, 67, 104, 105, 108, 100, 114, 101, 110, 67, 111, 110, 116, 101, 110, 116, 68, 101, 99, 108, 32, 58, 32, 100, 101, 112, 116, 104, 32, 37, 100, 32, 116, 111, 111, 32, 100, 101, 101, 112, 44, 32, 117, 115, 101, 32, 88, 77, 76, 95, 80, 65, 82, 83, 69, 95, 72, 85, 71, 69, 10, 0, 0, 0, 0, 0, 120, 109, 108, 80, 97, 114, 115, 101, 69, 108, 101, 109, 101, 110, 116, 67, 104, 105, 108, 100, 114, 101, 110, 67, 111, 110, 116, 101, 110, 116, 68, 101, 99, 108, 32, 58, 32, 39, 37, 99, 39, 32, 101, 120, 112, 101, 99, 116, 101, 100, 10, 0, 0, 0, 0, 0, 101, 120, 116, 101, 114, 110, 97, 108, 0, 0, 0, 0, 0, 0, 0, 0, 99, 97, 116, 97, 108, 111, 103, 0, 67, 97, 116, 97, 108, 111, 103, 32, 80, 73, 32, 115, 121, 110, 116, 97, 120, 32, 101, 114, 114, 111, 114, 58, 32, 37, 115, 10, 0, 0, 0, 0, 120, 109, 108, 45, 115, 116, 121, 108, 101, 115, 104, 101, 101, 116, 0, 0, 120, 109, 108, 45, 109, 111, 100, 101, 108, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 80, 97, 114, 115, 101, 67, 111, 109, 109, 101, 110, 116, 58, 32, 105, 110, 118, 97, 108, 105, 100, 32, 120, 109, 108, 67, 104, 97, 114, 32, 118, 97, 108, 117, 101, 32, 37, 100, 10, 0, 0, 0, 0, 0, 0, 67, 111, 109, 109, 101, 110, 116, 32, 110, 111, 116, 32, 116, 101, 114, 109, 105, 110, 97, 116, 101, 100, 32, 10, 60, 33, 45, 45, 37, 46, 53, 48, 115, 10, 0, 0, 0, 0, 0, 0, 67, 111, 109, 109, 101, 110, 116, 32, 100, 111, 101, 115, 110, 39, 116, 32, 115, 116, 97, 114, 116, 32, 97, 110, 100, 32, 115, 116, 111, 112, 32, 105, 110, 32, 116, 104, 101, 32, 115, 97, 109, 101, 32, 101, 110, 116, 105, 116, 121, 10, 0, 0, 0, 0, 0, 0, 67, 111, 109, 109, 101, 110, 116, 32, 110, 111, 116, 32, 116, 101, 114, 109, 105, 110, 97, 116, 101, 100, 10, 0, 80, 67, 68, 65, 84, 65, 32, 105, 110, 118, 97, 108, 105, 100, 32, 67, 104, 97, 114, 32, 118, 97, 108, 117, 101, 32, 37, 100, 10, 0, 0, 0, 37, 115, 0, 0, 0, 0, 0, 0, 120, 109, 108, 80, 97, 114, 115, 101, 83, 116, 114, 105, 110, 103, 67, 104, 97, 114, 82, 101, 102, 58, 32, 105, 110, 118, 97, 108, 105, 100, 32, 120, 109, 108, 67, 104, 97, 114, 32, 118, 97, 108, 117, 101, 32, 37, 100, 10, 0, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 78, 101, 119, 66, 108, 97, 110, 107, 115, 87, 114, 97, 112, 112, 101, 114, 73, 110, 112, 117, 116, 83, 116, 114, 101, 97, 109, 32, 101, 110, 116, 105, 116, 121, 10, 0, 0, 110, 101, 119, 32, 98, 108, 97, 110, 107, 115, 32, 119, 114, 97, 112, 112, 101, 114, 32, 102, 111, 114, 32, 101, 110, 116, 105, 116, 121, 58, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 67, 104, 97, 114, 82, 101, 102, 58, 32, 105, 110, 118, 97, 108, 105, 100, 32, 104, 101, 120, 97, 100, 101, 99, 105, 109, 97, 108, 32, 118, 97, 108, 117, 101, 0, 0, 0, 0, 0, 0, 67, 104, 97, 114, 82, 101, 102, 58, 32, 105, 110, 118, 97, 108, 105, 100, 32, 100, 101, 99, 105, 109, 97, 108, 32, 118, 97, 108, 117, 101, 0, 0, 67, 104, 97, 114, 82, 101, 102, 58, 32, 105, 110, 118, 97, 108, 105, 100, 32, 118, 97, 108, 117, 101, 0, 0, 105, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 0, 0, 80, 69, 82, 101, 102, 101, 114, 101, 110, 99, 101, 32, 97, 116, 32, 101, 110, 100, 32, 111, 102, 32, 100, 111, 99, 117, 109, 101, 110, 116, 0, 0, 80, 69, 82, 101, 102, 101, 114, 101, 110, 99, 101, 32, 105, 110, 32, 112, 114, 111, 108, 111, 103, 0, 0, 0, 80, 69, 82, 101, 102, 101, 114, 101, 110, 99, 101, 32, 105, 110, 32, 101, 112, 105, 108, 111, 103, 0, 0, 0, 80, 69, 82, 101, 102, 101, 114, 101, 110, 99, 101, 58, 32, 110, 111, 32, 110, 97, 109, 101, 0, 0, 0, 0, 80, 69, 82, 101, 102, 101, 114, 101, 110, 99, 101, 58, 32, 101, 120, 112, 101, 99, 116, 105, 110, 103, 32, 39, 59, 39, 0, 0, 0, 0, 0, 0, 68, 101, 116, 101, 99, 116, 101, 100, 32, 97, 110, 32, 101, 110, 116, 105, 116, 121, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 108, 111, 111, 112, 0, 0, 0, 0, 0, 0, 0, 69, 110, 116, 105, 116, 121, 86, 97, 108, 117, 101, 58, 32, 34, 32, 111, 114, 32, 39, 32, 101, 120, 112, 101, 99, 116, 101, 100, 0, 0, 0, 0, 80, 69, 82, 101, 102, 101, 114, 101, 110, 99, 101, 115, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 105, 110, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 115, 117, 98, 115, 101, 116, 0, 0, 0, 0, 0, 0, 0, 65, 116, 116, 86, 97, 108, 117, 101, 58, 32, 34, 32, 111, 114, 32, 39, 32, 101, 120, 112, 101, 99, 116, 101, 100, 0, 0, 0, 0, 0, 0, 0, 85, 110, 101, 115, 99, 97, 112, 101, 100, 32, 39, 60, 39, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 101, 100, 32, 105, 110, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 115, 32, 118, 97, 108, 117, 101, 115, 0, 0, 83, 121, 115, 116, 101, 109, 76, 105, 116, 101, 114, 97, 108, 32, 34, 32, 111, 114, 32, 39, 32, 101, 120, 112, 101, 99, 116, 101, 100, 0, 0, 0, 85, 110, 102, 105, 110, 105, 115, 104, 101, 100, 32, 83, 121, 115, 116, 101, 109, 32, 111, 114, 32, 80, 117, 98, 108, 105, 99, 32, 73, 68, 32, 34, 32, 111, 114, 32, 39, 32, 101, 120, 112, 101, 99, 116, 101, 100, 0, 0, 83, 101, 113, 117, 101, 110, 99, 101, 32, 39, 93, 93, 62, 39, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 101, 100, 32, 105, 110, 32, 99, 111, 110, 116, 101, 110, 116, 0, 0, 0, 83, 89, 83, 84, 69, 77, 32, 111, 114, 32, 80, 85, 66, 76, 73, 67, 44, 32, 116, 104, 101, 32, 85, 82, 73, 32, 105, 115, 32, 109, 105, 115, 115, 105, 110, 103, 0, 0, 0, 0, 80, 85, 66, 76, 73, 67, 44, 32, 116, 104, 101, 32, 80, 117, 98, 108, 105, 99, 32, 73, 100, 101, 110, 116, 105, 102, 105, 101, 114, 32, 105, 115, 32, 109, 105, 115, 115, 105, 110, 103, 0, 0, 0, 0, 0, 0, 0, 0, 67, 111, 109, 109, 101, 110, 116, 32, 109, 117, 115, 116, 32, 110, 111, 116, 32, 99, 111, 110, 116, 97, 105, 110, 32, 39, 45, 45, 39, 32, 40, 100, 111, 117, 98, 108, 101, 45, 104, 121, 112, 104, 101, 110, 41, 0, 0, 0, 120, 109, 108, 80, 97, 114, 115, 101, 80, 73, 32, 58, 32, 110, 111, 32, 116, 97, 114, 103, 101, 116, 32, 110, 97, 109, 101, 0, 0, 0, 0, 0, 73, 110, 118, 97, 108, 105, 100, 32, 80, 73, 32, 110, 97, 109, 101, 0, 78, 79, 84, 65, 84, 73, 79, 78, 58, 32, 78, 97, 109, 101, 32, 101, 120, 112, 101, 99, 116, 101, 100, 32, 104, 101, 114, 101, 0, 0, 0, 0, 39, 62, 39, 32, 114, 101, 113, 117, 105, 114, 101, 100, 32, 116, 111, 32, 99, 108, 111, 115, 101, 32, 78, 79, 84, 65, 84, 73, 79, 78, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 0, 0, 0, 0, 0, 0, 69, 110, 116, 105, 116, 121, 32, 118, 97, 108, 117, 101, 32, 114, 101, 113, 117, 105, 114, 101, 100, 0, 0, 0, 70, 114, 97, 103, 109, 101, 110, 116, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 101, 100, 0, 0, 0, 0, 39, 40, 39, 32, 114, 101, 113, 117, 105, 114, 101, 100, 32, 116, 111, 32, 115, 116, 97, 114, 116, 32, 65, 84, 84, 76, 73, 83, 84, 32, 101, 110, 117, 109, 101, 114, 97, 116, 105, 111, 110, 0, 0, 0, 0, 0, 0, 0, 78, 109, 84, 111, 107, 101, 110, 32, 101, 120, 112, 101, 99, 116, 101, 100, 32, 105, 110, 32, 65, 84, 84, 76, 73, 83, 84, 32, 101, 110, 117, 109, 101, 114, 97, 116, 105, 111, 110, 0, 39, 41, 39, 32, 114, 101, 113, 117, 105, 114, 101, 100, 32, 116, 111, 32, 102, 105, 110, 105, 115, 104, 32, 65, 84, 84, 76, 73, 83, 84, 32, 101, 110, 117, 109, 101, 114, 97, 116, 105, 111, 110, 0, 0, 0, 0, 0, 0, 77, 105, 120, 101, 100, 67, 111, 110, 116, 101, 110, 116, 68, 101, 99, 108, 32, 58, 32, 39, 124, 39, 32, 111, 114, 32, 39, 41, 42, 39, 32, 101, 120, 112, 101, 99, 116, 101, 100, 0, 77, 105, 120, 101, 100, 67, 111, 110, 116, 101, 110, 116, 68, 101, 99, 108, 32, 58, 32, 39, 35, 80, 67, 68, 65, 84, 65, 39, 32, 101, 120, 112, 101, 99, 116, 101, 100, 0, 0, 0, 67, 111, 110, 116, 101, 110, 116, 68, 101, 99, 108, 32, 58, 32, 78, 97, 109, 101, 32, 111, 114, 32, 39, 40, 39, 32, 101, 120, 112, 101, 99, 116, 101, 100, 0, 0, 0, 0, 0, 0, 67, 111, 110, 116, 101, 110, 116, 68, 101, 99, 108, 32, 58, 32, 39, 44, 39, 32, 39, 124, 39, 32, 111, 114, 32, 39, 41, 39, 32, 101, 120, 112, 101, 99, 116, 101, 100, 0, 0, 0, 80, 69, 82, 101, 102, 101, 114, 101, 110, 99, 101, 58, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 119, 105, 116, 104, 105, 110, 32, 109, 97, 114, 107, 117, 112, 32, 100, 101, 99, 108, 32, 105, 110, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 115, 117, 98, 115, 101, 116, 0, 0, 0, 0, 101, 120, 112, 101, 99, 116, 101, 100, 32, 39, 62, 39, 0, 0, 0, 0, 88, 77, 76, 32, 99, 111, 110, 100, 105, 116, 105, 111, 110, 97, 108, 32, 115, 101, 99, 116, 105, 111, 110, 32, 39, 91, 39, 32, 101, 120, 112, 101, 99, 116, 101, 100, 0, 0, 0, 0, 67, 111, 110, 116, 101, 110, 116, 32, 101, 114, 114, 111, 114, 32, 105, 110, 32, 116, 104, 101, 32, 101, 120, 116, 101, 114, 110, 97, 108, 32, 115, 117, 98, 115, 101, 116, 0, 0, 0, 0, 99, 111, 110, 100, 105, 116, 105, 111, 110, 97, 108, 32, 115, 101, 99, 116, 105, 111, 110, 32, 73, 78, 67, 76, 85, 68, 69, 32, 111, 114, 32, 73, 71, 78, 79, 82, 69, 32, 107, 101, 121, 119, 111, 114, 100, 32, 101, 120, 112, 101, 99, 116, 101, 100, 0, 0, 88, 77, 76, 32, 99, 111, 110, 100, 105, 116, 105, 111, 110, 97, 108, 32, 115, 101, 99, 116, 105, 111, 110, 32, 110, 111, 116, 32, 99, 108, 111, 115, 101, 100, 0, 0, 0, 0, 0, 0, 84, 101, 120, 116, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 39, 60, 63, 120, 109, 108, 39, 32, 114, 101, 113, 117, 105, 114, 101, 100, 0, 0, 0, 0, 0, 0, 0, 112, 97, 114, 115, 105, 110, 103, 32, 88, 77, 76, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 58, 32, 39, 63, 62, 39, 32, 101, 120, 112, 101, 99, 116, 101, 100, 0, 0, 101, 120, 116, 101, 114, 110, 97, 108, 32, 112, 97, 114, 115, 101, 100, 32, 101, 110, 116, 105, 116, 105, 101, 115, 32, 99, 97, 110, 110, 111, 116, 32, 98, 101, 32, 115, 116, 97, 110, 100, 97, 108, 111, 110, 101, 0, 0, 0, 69, 110, 116, 105, 116, 121, 82, 101, 102, 58, 32, 101, 120, 112, 101, 99, 116, 105, 110, 103, 32, 39, 59, 39, 0, 0, 0, 0, 0, 0, 0, 0, 68, 79, 67, 84, 89, 80, 69, 32, 105, 109, 112, 114, 111, 112, 101, 114, 108, 121, 32, 116, 101, 114, 109, 105, 110, 97, 116, 101, 100], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 64368);
	        allocate([69, 110, 100, 84, 97, 103, 58, 32, 39, 60, 47, 39, 32, 110, 111, 116, 32, 102, 111, 117, 110, 100, 0, 0, 101, 120, 112, 101, 99, 116, 101, 100, 32, 39, 61, 39, 0, 0, 0, 0, 83, 116, 114, 105, 110, 103, 32, 110, 111, 116, 32, 99, 108, 111, 115, 101, 100, 32, 101, 120, 112, 101, 99, 116, 105, 110, 103, 32, 34, 32, 111, 114, 32, 39, 0, 0, 0, 0, 0, 0, 83, 116, 114, 105, 110, 103, 32, 110, 111, 116, 32, 115, 116, 97, 114, 116, 101, 100, 32, 101, 120, 112, 101, 99, 116, 105, 110, 103, 32, 39, 32, 111, 114, 32, 34, 0, 0, 0, 0, 0, 73, 110, 118, 97, 108, 105, 100, 32, 88, 77, 76, 32, 101, 110, 99, 111, 100, 105, 110, 103, 32, 110, 97, 109, 101, 0, 0, 0, 0, 0, 0, 0, 115, 116, 97, 110, 100, 97, 108, 111, 110, 101, 32, 97, 99, 99, 101, 112, 116, 115, 32, 111, 110, 108, 121, 32, 39, 121, 101, 115, 39, 32, 111, 114, 32, 39, 110, 111, 39, 0, 0, 0, 68, 111, 99, 117, 109, 101, 110, 116, 32, 105, 115, 32, 101, 109, 112, 116, 121, 0, 0, 0, 0, 0, 0, 0, 69, 120, 116, 114, 97, 32, 99, 111, 110, 116, 101, 110, 116, 32, 97, 116, 32, 116, 104, 101, 32, 101, 110, 100, 32, 111, 102, 32, 116, 104, 101, 32, 100, 111, 99, 117, 109, 101, 110, 116, 0, 0, 0, 0, 0, 0, 0, 0, 99, 104, 117, 110, 107, 32, 105, 115, 32, 110, 111, 116, 32, 119, 101, 108, 108, 32, 98, 97, 108, 97, 110, 99, 101, 100, 0, 0, 0, 0, 0, 0, 101, 120, 116, 114, 97, 32, 99, 111, 110, 116, 101, 110, 116, 32, 97, 116, 32, 116, 104, 101, 32, 101, 110, 100, 32, 111, 102, 32, 119, 101, 108, 108, 32, 98, 97, 108, 97, 110, 99, 101, 100, 32, 99, 104, 117, 110, 107, 0, 77, 97, 108, 102, 111, 114, 109, 101, 100, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 101, 120, 112, 101, 99, 116, 105, 110, 103, 32, 118, 101, 114, 115, 105, 111, 110, 0, 78, 97, 109, 101, 32, 116, 111, 111, 32, 108, 111, 110, 103, 32, 117, 115, 101, 32, 88, 77, 76, 95, 80, 65, 82, 83, 69, 95, 72, 85, 71, 69, 32, 111, 112, 116, 105, 111, 110, 0, 85, 110, 114, 101, 103, 105, 115, 116, 101, 114, 101, 100, 32, 101, 114, 114, 111, 114, 32, 109, 101, 115, 115, 97, 103, 101, 0, 0, 0, 0, 0, 0, 37, 115, 10, 0, 0, 0, 0, 0, 37, 115, 58, 32, 37, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 116, 101, 120, 116, 0, 0, 0, 0, 116, 101, 120, 116, 110, 111, 101, 110, 99, 0, 0, 0, 0, 0, 0, 0, 99, 111, 109, 109, 101, 110, 116, 0, 98, 117, 105, 108, 100, 105, 110, 103, 32, 81, 78, 97, 109, 101, 0, 0, 81, 78, 97, 109, 101, 32, 115, 112, 108, 105, 116, 0, 0, 0, 0, 0, 120, 109, 108, 0, 0, 0, 0, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 88, 77, 76, 47, 49, 57, 57, 56, 47, 110, 97, 109, 101, 115, 112, 97, 99, 101, 0, 0, 0, 0, 98, 117, 105, 108, 100, 105, 110, 103, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 0, 0, 0, 0, 0, 0, 98, 117, 105, 108, 100, 105, 110, 103, 32, 68, 84, 68, 0, 0, 0, 0, 98, 117, 105, 108, 100, 105, 110, 103, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 115, 117, 98, 115, 101, 116, 0, 0, 0, 0, 0, 0, 0, 0, 49, 46, 48, 0, 0, 0, 0, 0, 98, 117, 105, 108, 100, 105, 110, 103, 32, 100, 111, 99, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 98, 117, 105, 108, 100, 105, 110, 103, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 0, 0, 0, 0, 0, 0, 98, 117, 105, 108, 100, 105, 110, 103, 32, 80, 73, 0, 0, 0, 0, 0, 98, 117, 105, 108, 100, 105, 110, 103, 32, 110, 111, 100, 101, 0, 0, 0, 98, 117, 105, 108, 100, 105, 110, 103, 32, 116, 101, 120, 116, 0, 0, 0, 98, 117, 105, 108, 100, 105, 110, 103, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 0, 0, 0, 0, 98, 117, 105, 108, 100, 105, 110, 103, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 0, 0, 0, 0, 0, 0, 98, 117, 105, 108, 100, 105, 110, 103, 32, 99, 111, 109, 109, 101, 110, 116, 0, 0, 0, 0, 0, 0, 0, 0, 98, 117, 105, 108, 100, 105, 110, 103, 32, 67, 68, 65, 84, 65, 0, 0, 103, 101, 116, 116, 105, 110, 103, 32, 110, 111, 100, 101, 32, 112, 97, 116, 104, 0, 0, 0, 0, 0, 0, 0, 63, 0, 0, 0, 0, 0, 0, 0, 47, 0, 0, 0, 0, 0, 0, 0, 37, 115, 58, 37, 115, 0, 0, 0, 42, 0, 0, 0, 0, 0, 0, 0, 99, 111, 109, 109, 101, 110, 116, 40, 41, 0, 0, 0, 0, 0, 0, 0, 116, 101, 120, 116, 40, 41, 0, 0, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 45, 105, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 40, 39, 37, 115, 39, 41, 0, 0, 0, 0, 47, 64, 0, 0, 0, 0, 0, 0, 37, 115, 0, 0, 0, 0, 0, 0, 37, 115, 37, 115, 37, 115, 0, 0, 37, 115, 37, 115, 91, 37, 100, 93, 37, 115, 0, 0, 0, 0, 0, 0, 108, 97, 110, 103, 0, 0, 0, 0, 115, 112, 97, 99, 101, 0, 0, 0, 100, 101, 102, 97, 117, 108, 116, 0, 112, 114, 101, 115, 101, 114, 118, 101, 0, 0, 0, 0, 0, 0, 0, 0, 98, 97, 115, 101, 0, 0, 0, 0, 104, 116, 109, 108, 0, 0, 0, 0, 104, 101, 97, 100, 0, 0, 0, 0, 104, 114, 101, 102, 0, 0, 0, 0, 104, 116, 116, 112, 58, 47, 47, 0, 102, 116, 112, 58, 47, 47, 0, 0, 117, 114, 110, 58, 0, 0, 0, 0, 103, 101, 116, 116, 105, 110, 103, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 108, 105, 115, 116, 0, 0, 115, 101, 97, 114, 99, 104, 105, 110, 103, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 73, 83, 79, 45, 56, 56, 53, 57, 45, 49, 0, 0, 0, 0, 0, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 98, 117, 102, 102, 101, 114, 0, 103, 114, 111, 119, 105, 110, 103, 32, 98, 117, 102, 102, 101, 114, 0, 0, 34, 0, 0, 0, 0, 0, 0, 0, 38, 113, 117, 111, 116, 59, 0, 0, 39, 0, 0, 0, 0, 0, 0, 0, 58, 0, 0, 0, 0, 0, 0, 0, 37, 46, 50, 48, 115, 0, 0, 0, 100, 101, 102, 97, 117, 108, 116, 37, 100, 0, 0, 0, 0, 0, 0, 0, 37, 46, 50, 48, 115, 37, 100, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 116, 104, 101, 32, 88, 77, 76, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 0, 0, 0, 0, 99, 111, 112, 121, 105, 110, 103, 32, 110, 111, 100, 101, 0, 0, 0, 0, 105, 110, 118, 97, 108, 105, 100, 32, 104, 101, 120, 97, 100, 101, 99, 105, 109, 97, 108, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 118, 97, 108, 117, 101, 10, 0, 0, 0, 0, 105, 110, 118, 97, 108, 105, 100, 32, 100, 101, 99, 105, 109, 97, 108, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 118, 97, 108, 117, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 117, 110, 116, 101, 114, 109, 105, 110, 97, 116, 101, 100, 32, 101, 110, 116, 105, 116, 121, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 37, 49, 53, 115, 10, 0, 0, 0, 0, 0, 115, 116, 114, 105, 110, 103, 32, 105, 115, 32, 110, 111, 116, 32, 105, 110, 32, 85, 84, 70, 45, 56, 10, 0, 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 101, 114, 114, 111, 114, 32, 110, 117, 109, 98, 101, 114, 10, 0, 0, 0, 0, 0, 0, 0, 0, 152, 45, 1, 0, 176, 45, 1, 0, 200, 45, 1, 0, 240, 45, 1, 0, 8, 46, 1, 0, 24, 46, 1, 0, 40, 46, 1, 0, 64, 46, 1, 0, 88, 46, 1, 0, 120, 46, 1, 0, 136, 46, 1, 0, 152, 46, 1, 0, 168, 46, 1, 0, 184, 46, 1, 0, 208, 46, 1, 0, 240, 46, 1, 0, 8, 47, 1, 0, 32, 47, 1, 0, 48, 47, 1, 0, 72, 47, 1, 0, 88, 47, 1, 0, 128, 47, 1, 0, 152, 47, 1, 0, 184, 47, 1, 0, 200, 47, 1, 0, 232, 47, 1, 0, 0, 48, 1, 0, 24, 48, 1, 0, 48, 48, 1, 0, 72, 48, 1, 0, 104, 48, 1, 0, 120, 48, 1, 0, 144, 48, 1, 0, 160, 48, 1, 0, 200, 48, 1, 0, 232, 48, 1, 0, 0, 49, 1, 0, 16, 49, 1, 0, 40, 49, 1, 0, 64, 49, 1, 0, 80, 49, 1, 0, 96, 49, 1, 0, 120, 49, 1, 0, 136, 49, 1, 0, 176, 49, 1, 0, 192, 49, 1, 0, 208, 49, 1, 0, 224, 49, 1, 0, 240, 49, 1, 0, 0, 50, 1, 0, 16, 50, 1, 0, 32, 50, 1, 0, 56, 50, 1, 0, 80, 50, 1, 0, 104, 50, 1, 0, 120, 50, 1, 0, 136, 50, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 102, 114, 101, 97, 100, 40, 41, 0, 102, 102, 108, 117, 115, 104, 40, 41, 0, 0, 0, 0, 0, 0, 0, 0, 102, 99, 108, 111, 115, 101, 40, 41, 0, 0, 0, 0, 0, 0, 0, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 105, 110, 112, 117, 116, 32, 98, 117, 102, 102, 101, 114, 0, 0, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 111, 117, 116, 112, 117, 116, 32, 98, 117, 102, 102, 101, 114, 0, 0, 102, 105, 108, 101, 0, 0, 0, 0, 103, 114, 111, 119, 105, 110, 103, 32, 105, 110, 112, 117, 116, 32, 98, 117, 102, 102, 101, 114, 0, 0, 0, 0, 30, 0, 0, 0, 0, 0, 0, 0, 98, 117, 105, 108, 100, 105, 110, 103, 32, 99, 97, 110, 111, 110, 105, 99, 97, 108, 32, 112, 97, 116, 104, 10, 0, 0, 0, 0, 0, 0, 0, 0, 102, 116, 112, 58, 47, 47, 0, 0, 104, 116, 116, 112, 58, 47, 47, 0, 78, 85, 76, 76, 0, 0, 0, 0, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 108, 111, 97, 100, 32, 101, 120, 116, 101, 114, 110, 97, 108, 32, 101, 110, 116, 105, 116, 121, 32, 34, 37, 115, 34, 10, 0, 0, 0, 0, 102, 105, 108, 101, 58, 47, 47, 108, 111, 99, 97, 108, 104, 111, 115, 116, 47, 0, 0, 0, 0, 0, 0, 0, 102, 105, 108, 101, 58, 47, 47, 47, 0, 0, 0, 0, 0, 0, 0, 0, 119, 114, 105, 116, 101, 40, 41, 0, 99, 108, 111, 115, 101, 40, 41, 0, 114, 101, 97, 100, 40, 41, 0, 0, 102, 119, 114, 105, 116, 101, 40, 41, 0, 0, 0, 0, 0, 0, 0, 0, 45, 0, 0, 0, 0, 0, 0, 0, 119, 98, 0, 0, 0, 0, 0, 0, 102, 105, 108, 101, 58, 47, 0, 0, 114, 0, 0, 0, 0, 0, 0, 0, 85, 110, 107, 110, 111, 119, 110, 32, 73, 79, 32, 101, 114, 114, 111, 114, 0, 0, 0, 0, 0, 0, 0, 0, 80, 101, 114, 109, 105, 115, 115, 105, 111, 110, 32, 100, 101, 110, 105, 101, 100, 0, 0, 0, 0, 0, 0, 0, 82, 101, 115, 111, 117, 114, 99, 101, 32, 116, 101, 109, 112, 111, 114, 97, 114, 105, 108, 121, 32, 117, 110, 97, 118, 97, 105, 108, 97, 98, 108, 101, 0, 0, 0, 0, 0, 0, 0, 0, 66, 97, 100, 32, 102, 105, 108, 101, 32, 100, 101, 115, 99, 114, 105, 112, 116, 111, 114, 0, 0, 0, 0, 0, 66, 97, 100, 32, 109, 101, 115, 115, 97, 103, 101, 0, 0, 0, 0, 0, 82, 101, 115, 111, 117, 114, 99, 101, 32, 98, 117, 115, 121, 0, 0, 0, 79, 112, 101, 114, 97, 116, 105, 111, 110, 32, 99, 97, 110, 99, 101, 108, 101, 100, 0, 0, 0, 0, 0, 0, 78, 111, 32, 99, 104, 105, 108, 100, 32, 112, 114, 111, 99, 101, 115, 115, 101, 115, 0, 0, 0, 0, 0, 0, 82, 101, 115, 111, 117, 114, 99, 101, 32, 100, 101, 97, 100, 108, 111, 99, 107, 32, 97, 118, 111, 105, 100, 101, 100, 0, 0, 0, 0, 0, 0, 0, 68, 111, 109, 97, 105, 110, 32, 101, 114, 114, 111, 114, 0, 0, 0, 0, 70, 105, 108, 101, 32, 101, 120, 105, 115, 116, 115, 0, 0, 0, 0, 0, 66, 97, 100, 32, 97, 100, 100, 114, 101, 115, 115, 0, 0, 0, 0, 0, 70, 105, 108, 101, 32, 116, 111, 111, 32, 108, 97, 114, 103, 101, 0, 0, 79, 112, 101, 114, 97, 116, 105, 111, 110, 32, 105, 110, 32, 112, 114, 111, 103, 114, 101, 115, 115, 0, 0, 0, 73, 110, 116, 101, 114, 114, 117, 112, 116, 101, 100, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 99, 97, 108, 108, 0, 0, 0, 0, 0, 0, 0, 73, 110, 118, 97, 108, 105, 100, 32, 97, 114, 103, 117, 109, 101, 110, 116, 0, 0, 0, 0, 0, 0, 0, 0, 73, 110, 112, 117, 116, 47, 111, 117, 116, 112, 117, 116, 32, 101, 114, 114, 111, 114, 0, 0, 0, 0, 0, 0, 73, 115, 32, 97, 32, 100, 105, 114, 101, 99, 116, 111, 114, 121, 0, 0, 84, 111, 111, 32, 109, 97, 110, 121, 32, 111, 112, 101, 110, 32, 102, 105, 108, 101, 115, 0, 0, 0, 0, 0, 84, 111, 111, 32, 109, 97, 110, 121, 32, 108, 105, 110, 107, 115, 0, 0, 73, 110, 97, 112, 112, 114, 111, 112, 114, 105, 97, 116, 101, 32, 109, 101, 115, 115, 97, 103, 101, 32, 98, 117, 102, 102, 101, 114, 32, 108, 101, 110, 103, 116, 104, 0, 0, 0, 0, 0, 70, 105, 108, 101, 110, 97, 109, 101, 32, 116, 111, 111, 32, 108, 111, 110, 103, 0, 0, 0, 0, 0, 0, 0, 84, 111, 111, 32, 109, 97, 110, 121, 32, 111, 112, 101, 110, 32, 102, 105, 108, 101, 115, 32, 105, 110, 32, 115, 121, 115, 116, 101, 109, 0, 0, 0, 78, 111, 32, 115, 117, 99, 104, 32, 100, 101, 118, 105, 99, 101, 0, 0, 78, 111, 32, 115, 117, 99, 104, 32, 102, 105, 108, 101, 32, 111, 114, 32, 100, 105, 114, 101, 99, 116, 111, 114, 121, 0, 0, 0, 0, 0, 0, 0, 69, 120, 101, 99, 32, 102, 111, 114, 109, 97, 116, 32, 101, 114, 114, 111, 114, 0, 0, 0, 0, 0, 0, 0, 78, 111, 32, 108, 111, 99, 107, 115, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 0, 0, 0, 0, 0, 0, 78, 111, 116, 32, 101, 110, 111, 117, 103, 104, 32, 115, 112, 97, 99, 101, 0, 0, 0, 0, 0, 0, 0, 0, 78, 111, 32, 115, 112, 97, 99, 101, 32, 108, 101, 102, 116, 32, 111, 110, 32, 100, 101, 118, 105, 99, 101, 0, 70, 117, 110, 99, 116, 105, 111, 110, 32, 110, 111, 116, 32, 105, 109, 112, 108, 101, 109, 101, 110, 116, 101, 100, 0, 0, 0, 0, 0, 0, 0, 0, 78, 111, 116, 32, 97, 32, 100, 105, 114, 101, 99, 116, 111, 114, 121, 0, 68, 105, 114, 101, 99, 116, 111, 114, 121, 32, 110, 111, 116, 32, 101, 109, 112, 116, 121, 0, 0, 0, 0, 0, 78, 111, 116, 32, 115, 117, 112, 112, 111, 114, 116, 101, 100, 0, 0, 0, 73, 110, 97, 112, 112, 114, 111, 112, 114, 105, 97, 116, 101, 32, 73, 47, 79, 32, 99, 111, 110, 116, 114, 111, 108, 32, 111, 112, 101, 114, 97, 116, 105, 111, 110, 0, 0, 0, 0, 0, 78, 111, 32, 115, 117, 99, 104, 32, 100, 101, 118, 105, 99, 101, 32, 111, 114, 32, 97, 100, 100, 114, 101, 115, 115, 0, 0, 0, 0, 0, 0, 0, 79, 112, 101, 114, 97, 116, 105, 111, 110, 32, 110, 111, 116, 32, 112, 101, 114, 109, 105, 116, 116, 101, 100, 0, 66, 114, 111, 107, 101, 110, 32, 112, 105, 112, 101, 0, 0, 0, 0, 0, 82, 101, 115, 117, 108, 116, 32, 116, 111, 111, 32, 108, 97, 114, 103, 101, 0, 0, 0, 0, 0, 0, 0, 0, 82, 101, 97, 100, 45, 111, 110, 108, 121, 32, 102, 105, 108, 101, 32, 115, 121, 115, 116, 101, 109, 0, 0, 0, 73, 110, 118, 97, 108, 105, 100, 32, 115, 101, 101, 107, 0, 0, 0, 0, 78, 111, 32, 115, 117, 99, 104, 32, 112, 114, 111, 99, 101, 115, 115, 0, 79, 112, 101, 114, 97, 116, 105, 111, 110, 32, 116, 105, 109, 101, 100, 32, 111, 117, 116, 0, 0, 0, 0, 0, 73, 109, 112, 114, 111, 112, 101, 114, 32, 108, 105, 110, 107, 0, 0, 0, 65, 116, 116, 101, 109, 112, 116, 32, 116, 111, 32, 108, 111, 97, 100, 32, 110, 101, 116, 119, 111, 114, 107, 32, 101, 110, 116, 105, 116, 121, 32, 37, 115, 0, 0, 0, 0, 0, 0, 0, 101, 110, 99, 111, 100, 101, 114, 32, 101, 114, 114, 111, 114, 0, 0, 0, 102, 108, 117, 115, 104, 32, 101, 114, 114, 111, 114, 0, 0, 0, 0, 0, 119, 114, 105, 116, 101, 32, 101, 114, 114, 111, 114, 0, 0, 0, 0, 0, 110, 111, 32, 105, 110, 112, 117, 116, 0, 0, 0, 0, 0, 0, 0, 0, 98, 117, 102, 102, 101, 114, 32, 102, 117, 108, 108, 0, 0, 0, 0, 0, 108, 111, 97, 100, 105, 110, 103, 32, 101, 114, 114, 111, 114, 0, 0, 0, 110, 111, 116, 32, 97, 32, 115, 111, 99, 107, 101, 116, 0, 0, 0, 0, 97, 108, 114, 101, 97, 100, 121, 32, 99, 111, 110, 110, 101, 99, 116, 101, 100, 0, 0, 0, 0, 0, 0, 0, 99, 111, 110, 110, 101, 99, 116, 105, 111, 110, 32, 114, 101, 102, 117, 115, 101, 100, 0, 0, 0, 0, 0, 0, 117, 110, 114, 101, 97, 99, 104, 97, 98, 108, 101, 32, 110, 101, 116, 119, 111, 114, 107, 0, 0, 0, 0, 0, 97, 100, 100, 100, 114, 101, 115, 115, 32, 105, 110, 32, 117, 115, 101, 0, 97, 108, 114, 101, 97, 100, 121, 32, 105, 110, 32, 117, 115, 101, 0, 0, 117, 110, 107, 110, 111, 119, 110, 32, 97, 100, 100, 114, 101, 115, 115, 32, 102, 97, 109, 105, 108, 108, 121, 0, 120, 109, 108, 77, 97, 108, 108, 111, 99, 66, 114, 101, 97, 107, 112, 111, 105, 110, 116, 32, 114, 101, 97, 99, 104, 101, 100, 32, 111, 110, 32, 98, 108, 111, 99, 107, 32, 37, 100, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 77, 97, 108, 108, 111, 99, 76, 111, 99, 32, 58, 32, 79, 117, 116, 32, 111, 102, 32, 102, 114, 101, 101, 32, 115, 112, 97, 99, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 37, 112, 32, 58, 32, 77, 97, 108, 108, 111, 99, 40, 37, 108, 117, 41, 32, 79, 107, 10, 0, 0, 0, 0, 110, 111, 110, 101, 0, 0, 0, 0, 37, 112, 32, 58, 32, 82, 101, 97, 108, 108, 111, 99, 101, 100, 40, 37, 108, 117, 32, 45, 62, 32, 37, 108, 117, 41, 32, 79, 107, 10, 0, 0, 116, 114, 121, 105, 110, 103, 32, 116, 111, 32, 102, 114, 101, 101, 32, 112, 111, 105, 110, 116, 101, 114, 32, 102, 114, 111, 109, 32, 102, 114, 101, 101, 100, 32, 97, 114, 101, 97, 10, 0, 37, 112, 32, 58, 32, 70, 114, 101, 101, 100, 40, 41, 10, 0, 0, 0, 120, 109, 108, 77, 101, 109, 70, 114, 101, 101, 40, 37, 108, 88, 41, 32, 101, 114, 114, 111, 114, 10, 0, 0, 37, 112, 32, 58, 32, 83, 116, 114, 100, 117, 112, 40, 41, 32, 79, 107, 10, 0, 0, 0, 0, 0, 0, 0, 32, 32, 32, 32, 32, 32, 77, 69, 77, 79, 82, 89, 32, 65, 76, 76, 79, 67, 65, 84, 69, 68, 32, 58, 32, 37, 108, 117, 44, 32, 77, 65, 88, 32, 119, 97, 115, 32, 37, 108, 117, 10, 0, 0, 0, 0, 0, 0, 88, 77, 76, 95, 77, 69, 77, 95, 66, 82, 69, 65, 75, 80, 79, 73, 78, 84, 0, 0, 0, 0, 0, 0, 37, 117, 100, 0, 0, 0, 0, 0, 88, 77, 76, 95, 77, 69, 77, 95, 84, 82, 65, 67, 69, 0, 0, 0, 37, 112, 0, 0, 0, 0, 0, 0, 77, 101, 109, 111, 114, 121, 32, 116, 97, 103, 32, 101, 114, 114, 111, 114, 32, 111, 99, 99, 117, 114, 115, 32, 58, 37, 112, 32, 10, 9, 32, 98, 121, 101, 10, 0, 0, 0, 0, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 85, 82, 73, 32, 115, 116, 114, 117, 99, 116, 117, 114, 101, 10, 0, 115, 97, 118, 105, 110, 103, 32, 85, 82, 73, 10, 0, 0, 0, 0, 0, 58, 37, 100, 0, 0, 0, 0, 0, 102, 105, 108, 101, 0, 0, 0, 0, 117, 110, 101, 115, 99, 97, 112, 105, 110, 103, 32, 85, 82, 73, 32, 118, 97, 108, 117, 101, 10, 0, 0, 0, 101, 115, 99, 97, 112, 105, 110, 103, 32, 85, 82, 73, 32, 118, 97, 108, 117, 101, 10, 0, 0, 0, 0, 0, 43, 45, 46, 0, 0, 0, 0, 0, 58, 0, 0, 0, 0, 0, 0, 0, 47, 63, 59, 58, 64, 0, 0, 0, 47, 47, 0, 0, 0, 0, 0, 0, 59, 58, 38, 61, 43, 36, 44, 0, 64, 0, 0, 0, 0, 0, 0, 0, 37, 100, 0, 0, 0, 0, 0, 0, 58, 64, 38, 61, 43, 36, 44, 47, 63, 59, 0, 0, 0, 0, 0, 0, 63, 0, 0, 0, 0, 0, 0, 0, 59, 47, 63, 58, 64, 38, 61, 43, 44, 36, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 35, 0, 0, 0, 0, 0, 0, 0, 114, 101, 115, 111, 108, 118, 105, 110, 103, 32, 85, 82, 73, 32, 97, 103, 97, 105, 110, 115, 116, 32, 98, 97, 115, 101, 10, 0, 0, 0, 0, 0, 47, 0, 0, 0, 0, 0, 0, 0, 47, 59, 38, 61, 43, 36, 44, 0, 98, 117, 105, 108, 100, 105, 110, 103, 32, 114, 101, 108, 97, 116, 105, 118, 101, 32, 85, 82, 73, 10, 0, 0, 58, 47, 47, 0, 0, 0, 0, 0, 58, 47, 63, 95, 46, 35, 38, 59, 61, 0, 0, 0, 0, 0, 0, 0, 114, 101, 97, 99, 104, 105, 110, 103, 32, 97, 114, 98, 105, 116, 114, 97, 114, 121, 32, 77, 65, 88, 95, 85, 82, 73, 95, 76, 69, 78, 71, 84, 72, 32, 108, 105, 109, 105, 116, 10, 0, 0, 0, 0, 0, 0, 0, 0, 77, 101, 109, 111, 114, 121, 32, 97, 108, 108, 111, 99, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 32, 58, 32, 37, 115, 10, 0, 0, 77, 101, 109, 111, 114, 121, 32, 97, 108, 108, 111, 99, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 10, 0, 0, 0, 0, 0, 0, 0, 67, 97, 110, 110, 111, 116, 32, 99, 114, 101, 97, 116, 101, 32, 97, 117, 116, 111, 109, 97, 116, 97, 32, 102, 111, 114, 32, 101, 108, 101, 109, 101, 110, 116, 32, 37, 115, 10, 0, 0, 67, 111, 110, 116, 101, 110, 116, 32, 109, 111, 100, 101, 108, 32, 111, 102, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 100, 101, 116, 101, 114, 109, 105, 110, 105, 115, 116, 58, 32, 37, 115, 10, 0, 0, 0, 0, 0, 109, 97, 108, 108, 111, 99, 32, 102, 97, 105, 108, 101, 100, 0, 0, 0, 120, 109, 108, 78, 101, 119, 69, 108, 101, 109, 101, 110, 116, 67, 111, 110, 116, 101, 110, 116, 32, 58, 32, 110, 97, 109, 101, 32, 61, 61, 32, 78, 85, 76, 76, 32, 33, 10, 0, 0, 120, 109, 108, 78, 101, 119, 69, 108, 101, 109, 101, 110, 116, 67, 111, 110, 116, 101, 110, 116, 32, 58, 32, 110, 97, 109, 101, 32, 33, 61, 32, 78, 85, 76, 76, 32, 33, 10, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 58, 32, 69, 76, 69, 77, 69, 78, 84, 32, 99, 111, 110, 116, 101, 110, 116, 32, 99, 111, 114, 114, 117, 112, 116, 101, 100, 32, 105, 110, 118, 97, 108, 105, 100, 32, 116, 121, 112, 101, 10, 0, 0, 0, 0, 0, 0, 0, 32, 46, 46, 46, 0, 0, 0, 0, 40, 0, 0, 0, 0, 0, 0, 0, 35, 80, 67, 68, 65, 84, 65, 0, 58, 0, 0, 0, 0, 0, 0, 0, 32, 44, 32, 0, 0, 0, 0, 0, 32, 124, 32, 0, 0, 0, 0, 0, 41, 0, 0, 0, 0, 0, 0, 0, 63, 0, 0, 0, 0, 0, 0, 0, 42, 0, 0, 0, 0, 0, 0, 0, 43, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 65, 100, 100, 69, 108, 101, 109, 101, 110, 116, 68, 101, 99, 108, 58, 32, 99, 111, 110, 116, 101, 110, 116, 32, 33, 61, 32, 78, 85, 76, 76, 32, 102, 111, 114, 32, 69, 77, 80, 84, 89, 10, 0, 0, 0, 120, 109, 108, 65, 100, 100, 69, 108, 101, 109, 101, 110, 116, 68, 101, 99, 108, 58, 32, 99, 111, 110, 116, 101, 110, 116, 32, 33, 61, 32, 78, 85, 76, 76, 32, 102, 111, 114, 32, 65, 78, 89, 10, 0, 0, 0, 0, 0, 120, 109, 108, 65, 100, 100, 69, 108, 101, 109, 101, 110, 116, 68, 101, 99, 108, 58, 32, 99, 111, 110, 116, 101, 110, 116, 32, 61, 61, 32, 78, 85, 76, 76, 32, 102, 111, 114, 32, 77, 73, 88, 69, 68, 10, 0, 0, 0, 120, 109, 108, 65, 100, 100, 69, 108, 101, 109, 101, 110, 116, 68, 101, 99, 108, 58, 32, 99, 111, 110, 116, 101, 110, 116, 32, 61, 61, 32, 78, 85, 76, 76, 32, 102, 111, 114, 32, 69, 76, 69, 77, 69, 78, 84, 10, 0, 73, 110, 116, 101, 114, 110, 97, 108, 58, 32, 69, 76, 69, 77, 69, 78, 84, 32, 100, 101, 99, 108, 32, 99, 111, 114, 114, 117, 112, 116, 101, 100, 32, 105, 110, 118, 97, 108, 105, 100, 32, 116, 121, 112, 101, 10, 0, 0, 120, 109, 108, 65, 100, 100, 69, 108, 101, 109, 101, 110, 116, 68, 101, 99, 108, 58, 32, 84, 97, 98, 108, 101, 32, 99, 114, 101, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 33, 10, 0, 0, 0, 0, 0, 0, 82, 101, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 111, 102, 32, 101, 108, 101, 109, 101, 110, 116, 32, 37, 115, 10, 0, 0, 0, 0, 0, 60, 33, 69, 76, 69, 77, 69, 78, 84, 32, 0, 0, 0, 0, 0, 0, 32, 69, 77, 80, 84, 89, 62, 10, 0, 0, 0, 0, 0, 0, 0, 0, 32, 65, 78, 89, 62, 10, 0, 0, 32, 0, 0, 0, 0, 0, 0, 0, 62, 10, 0, 0, 0, 0, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 58, 32, 69, 76, 69, 77, 69, 78, 84, 32, 115, 116, 114, 117, 99, 116, 32, 99, 111, 114, 114, 117, 112, 116, 101, 100, 32, 105, 110, 118, 97, 108, 105, 100, 32, 116, 121, 112, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 58, 32, 65, 84, 84, 82, 73, 66, 85, 84, 69, 32, 115, 116, 114, 117, 99, 116, 32, 99, 111, 114, 114, 117, 112, 116, 101, 100, 32, 105, 110, 118, 97, 108, 105, 100, 32, 116, 121, 112, 101, 10, 0, 0, 0, 0, 0, 0, 65, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 111, 102, 32, 37, 115, 58, 32, 105, 110, 118, 97, 108, 105, 100, 32, 100, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 10, 0, 0, 0, 0, 0, 0, 120, 109, 108, 65, 100, 100, 65, 116, 116, 114, 105, 98, 117, 116, 101, 68, 101, 99, 108, 58, 32, 84, 97, 98, 108, 101, 32, 99, 114, 101, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 33, 10, 0, 0, 0, 0, 65, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 111, 102, 32, 101, 108, 101, 109, 101, 110, 116, 32, 37, 115, 58, 32, 97, 108, 114, 101, 97, 100, 121, 32, 100, 101, 102, 105, 110, 101, 100, 10, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 104, 97, 115, 32, 116, 111, 111, 32, 109, 97, 121, 32, 73, 68, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 115, 32, 100, 101, 102, 105, 110, 101, 100, 32, 58, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 120, 109, 108, 110, 115, 0, 0, 0, 60, 33, 65, 84, 84, 76, 73, 83, 84, 32, 0, 0, 0, 0, 0, 0, 32, 67, 68, 65, 84, 65, 0, 0, 32, 73, 68, 0, 0, 0, 0, 0, 32, 73, 68, 82, 69, 70, 0, 0, 32, 73, 68, 82, 69, 70, 83, 0, 32, 69, 78, 84, 73, 84, 89, 0, 32, 69, 78, 84, 73, 84, 73, 69, 83, 0, 0, 0, 0, 0, 0, 0, 32, 78, 77, 84, 79, 75, 69, 78, 0, 0, 0, 0, 0, 0, 0, 0, 32, 78, 77, 84, 79, 75, 69, 78, 83, 0, 0, 0, 0, 0, 0, 0, 32, 40, 0, 0, 0, 0, 0, 0, 32, 78, 79, 84, 65, 84, 73, 79, 78, 32, 40, 0, 0, 0, 0, 0, 32, 35, 82, 69, 81, 85, 73, 82, 69, 68, 0, 0, 0, 0, 0, 0, 32, 35, 73, 77, 80, 76, 73, 69, 68, 0, 0, 0, 0, 0, 0, 0, 32, 35, 70, 73, 88, 69, 68, 0, 73, 110, 116, 101, 114, 110, 97, 108, 58, 32, 65, 84, 84, 82, 73, 66, 85, 84, 69, 32, 115, 116, 114, 117, 99, 116, 32, 99, 111, 114, 114, 117, 112, 116, 101, 100, 32, 105, 110, 118, 97, 108, 105, 100, 32, 100, 101, 102, 10, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 65, 100, 100, 78, 111, 116, 97, 116, 105, 111, 110, 68, 101, 99, 108, 58, 32, 84, 97, 98, 108, 101, 32, 99, 114, 101, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 33, 10, 0, 0, 0, 0, 0, 120, 109, 108, 65, 100, 100, 78, 111, 116, 97, 116, 105, 111, 110, 68, 101, 99, 108, 58, 32, 37, 115, 32, 97, 108, 114, 101, 97, 100, 121, 32, 100, 101, 102, 105, 110, 101, 100, 10, 0, 60, 33, 78, 79, 84, 65, 84, 73, 79, 78, 32, 0, 0, 0, 0, 0, 32, 80, 85, 66, 76, 73, 67, 32, 0, 0, 0, 0, 0, 0, 0, 0, 32, 83, 89, 83, 84, 69, 77, 32, 0, 0, 0, 0, 0, 0, 0, 0, 32, 62, 10, 0, 0, 0, 0, 0, 120, 109, 108, 65, 100, 100, 73, 68, 58, 32, 84, 97, 98, 108, 101, 32, 99, 114, 101, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 33, 10, 0, 0, 0, 0, 0, 0, 0, 73, 68, 32, 37, 115, 32, 97, 108, 114, 101, 97, 100, 121, 32, 100, 101, 102, 105, 110, 101, 100, 10, 0, 0, 105, 100, 0, 0, 0, 0, 0, 0, 120, 109, 108, 0, 0, 0, 0, 0, 110, 97, 109, 101, 0, 0, 0, 0, 97, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 65, 100, 100, 82, 101, 102, 58, 32, 84, 97, 98, 108, 101, 32, 99, 114, 101, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 33, 10, 0, 0, 0, 0, 0, 0, 120, 109, 108, 65, 100, 100, 82, 101, 102, 58, 32, 82, 101, 102, 101, 114, 101, 110, 99, 101, 32, 108, 105, 115, 116, 32, 99, 114, 101, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 33, 10, 0, 0, 0, 0, 0, 120, 109, 108, 65, 100, 100, 82, 101, 102, 58, 32, 82, 101, 102, 101, 114, 101, 110, 99, 101, 32, 108, 105, 115, 116, 32, 105, 110, 115, 101, 114, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 33, 10, 0, 0, 0, 0, 78, 79, 84, 65, 84, 73, 79, 78, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 100, 101, 99, 108, 97, 114, 101, 100, 10, 0, 0, 0, 0, 115, 116, 97, 110, 100, 97, 108, 111, 110, 101, 58, 32, 37, 115, 32, 111, 110, 32, 37, 115, 32, 118, 97, 108, 117, 101, 32, 104, 97, 100, 32, 116, 111, 32, 98, 101, 32, 110, 111, 114, 109, 97, 108, 105, 122, 101, 100, 32, 98, 97, 115, 101, 100, 32, 111, 110, 32, 101, 120, 116, 101, 114, 110, 97, 108, 32, 115, 117, 98, 115, 101, 116, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 10, 0, 0, 0, 83, 121, 110, 116, 97, 120, 32, 111, 102, 32, 100, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 32, 102, 111, 114, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 111, 102, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 118, 97, 108, 105, 100, 10, 0, 0, 0, 0, 73, 68, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 111, 102, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 118, 97, 108, 105, 100, 32, 109, 117, 115, 116, 32, 98, 101, 32, 35, 73, 77, 80, 76, 73, 69, 68, 32, 111, 114, 32, 35, 82, 69, 81, 85, 73, 82, 69, 68, 10, 0, 0, 0, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 104, 97, 115, 32, 37, 100, 32, 73, 68, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 100, 101, 102, 105, 110, 101, 100, 32, 105, 110, 32, 116, 104, 101, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 115, 117, 98, 115, 101, 116, 32, 58, 32, 37, 115, 10, 0, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 104, 97, 115, 32, 37, 100, 32, 73, 68, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 100, 101, 102, 105, 110, 101, 100, 32, 105, 110, 32, 116, 104, 101, 32, 101, 120, 116, 101, 114, 110, 97, 108, 32, 115, 117, 98, 115, 101, 116, 32, 58, 32, 37, 115, 10, 0, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 104, 97, 115, 32, 73, 68, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 115, 32, 100, 101, 102, 105, 110, 101, 100, 32, 105, 110, 32, 116, 104, 101, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 97, 110, 100, 32, 101, 120, 116, 101, 114, 110, 97, 108, 32, 115, 117, 98, 115, 101, 116, 32, 58, 32, 37, 115, 10, 0, 0, 68, 101, 102, 97, 117, 108, 116, 32, 118, 97, 108, 117, 101, 32, 34, 37, 115, 34, 32, 102, 111, 114, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 111, 102, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 97, 109, 111, 110, 103, 32, 116, 104, 101, 32, 101, 110, 117, 109, 101, 114, 97, 116, 101, 100, 32, 115, 101, 116, 10, 0, 0, 0, 0, 0, 0, 68, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 111, 102, 32, 37, 115, 32, 104, 97, 115, 32, 100, 117, 112, 108, 105, 99, 97, 116, 101, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 115, 32, 111, 102, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 0, 68, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 111, 102, 32, 37, 115, 32, 104, 97, 115, 32, 100, 117, 112, 108, 105, 99, 97, 116, 101, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 115, 32, 111, 102, 32, 37, 115, 58, 37, 115, 10, 0, 0, 0, 0, 0, 68, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 111, 102, 32, 37, 115, 32, 104, 97, 115, 32, 100, 117, 112, 108, 105, 99, 97, 116, 101, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 115, 32, 116, 111, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 0, 68, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 111, 102, 32, 37, 115, 32, 104, 97, 115, 32, 100, 117, 112, 108, 105, 99, 97, 116, 101, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 115, 32, 116, 111, 32, 37, 115, 58, 37, 115, 10, 0, 0, 0, 0, 0, 78, 111, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 102, 111, 114, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 111, 102, 32, 101, 108, 101, 109, 101, 110, 116, 32, 37, 115, 10, 0, 0, 83, 121, 110, 116, 97, 120, 32, 111, 102, 32, 118, 97, 108, 117, 101, 32, 102, 111, 114, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 111, 102, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 118, 97, 108, 105, 100, 10, 0, 0, 0, 0, 86, 97, 108, 117, 101, 32, 102, 111, 114, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 111, 102, 32, 37, 115, 32, 105, 115, 32, 100, 105, 102, 102, 101, 114, 101, 110, 116, 32, 102, 114, 111, 109, 32, 100, 101, 102, 97, 117, 108, 116, 32, 34, 37, 115, 34, 10, 0, 0, 0, 0, 86, 97, 108, 117, 101, 32, 34, 37, 115, 34, 32, 102, 111, 114, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 111, 102, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 100, 101, 99, 108, 97, 114, 101, 100, 32, 78, 111, 116, 97, 116, 105, 111, 110, 10, 0, 0, 0, 86, 97, 108, 117, 101, 32, 34, 37, 115, 34, 32, 102, 111, 114, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 111, 102, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 97, 109, 111, 110, 103, 32, 116, 104, 101, 32, 101, 110, 117, 109, 101, 114, 97, 116, 101, 100, 32, 110, 111, 116, 97, 116, 105, 111, 110, 115, 10, 0, 0, 0, 0, 0, 0, 0, 0, 86, 97, 108, 117, 101, 32, 34, 37, 115, 34, 32, 102, 111, 114, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 111, 102, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 97, 109, 111, 110, 103, 32, 116, 104, 101, 32, 101, 110, 117, 109, 101, 114, 97, 116, 101, 100, 32, 115, 101, 116, 10, 0, 0, 0, 0, 0, 0, 86, 97, 108, 117, 101, 32, 102, 111, 114, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 111, 102, 32, 37, 115, 32, 109, 117, 115, 116, 32, 98, 101, 32, 34, 37, 115, 34, 10, 0, 0, 0, 0, 0, 0, 86, 97, 108, 105, 100, 97, 116, 105, 110, 103, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 0, 0, 0, 0, 78, 111, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 102, 111, 114, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 120, 109, 108, 110, 115, 58, 37, 115, 32, 111, 102, 32, 101, 108, 101, 109, 101, 110, 116, 32, 37, 115, 10, 0, 0, 0, 0, 78, 111, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 102, 111, 114, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 120, 109, 108, 110, 115, 32, 111, 102, 32, 101, 108, 101, 109, 101, 110, 116, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 83, 121, 110, 116, 97, 120, 32, 111, 102, 32, 118, 97, 108, 117, 101, 32, 102, 111, 114, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 120, 109, 108, 110, 115, 58, 37, 115, 32, 111, 102, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 118, 97, 108, 105, 100, 10, 0, 0, 0, 0, 0, 0, 83, 121, 110, 116, 97, 120, 32, 111, 102, 32, 118, 97, 108, 117, 101, 32, 102, 111, 114, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 120, 109, 108, 110, 115, 32, 111, 102, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 118, 97, 108, 105, 100, 10, 0, 86, 97, 108, 117, 101, 32, 102, 111, 114, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 120, 109, 108, 110, 115, 58, 37, 115, 32, 111, 102, 32, 37, 115, 32, 105, 115, 32, 100, 105, 102, 102, 101, 114, 101, 110, 116, 32, 102, 114, 111, 109, 32, 100, 101, 102, 97, 117, 108, 116, 32, 34, 37, 115, 34, 10, 0, 0, 0, 0, 0, 0, 86, 97, 108, 117, 101, 32, 102, 111, 114, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 120, 109, 108, 110, 115, 32, 111, 102, 32, 37, 115, 32, 105, 115, 32, 100, 105, 102, 102, 101, 114, 101, 110, 116, 32, 102, 114, 111, 109, 32, 100, 101, 102, 97, 117, 108, 116, 32, 34, 37, 115, 34, 10, 0, 86, 97, 108, 117, 101, 32, 34, 37, 115, 34, 32, 102, 111, 114, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 120, 109, 108, 110, 115, 58, 37, 115, 32, 111, 102, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 100, 101, 99, 108, 97, 114, 101, 100, 32, 78, 111, 116, 97, 116, 105, 111, 110, 10, 0, 0, 0, 0, 0, 86, 97, 108, 117, 101, 32, 34, 37, 115, 34, 32, 102, 111, 114, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 120, 109, 108, 110, 115, 32, 111, 102, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 100, 101, 99, 108, 97, 114, 101, 100, 32, 78, 111, 116, 97, 116, 105, 111, 110, 10, 0, 0, 0, 0, 0, 0, 0, 0, 86, 97, 108, 117, 101, 32, 34, 37, 115, 34, 32, 102, 111, 114, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 120, 109, 108, 110, 115, 58, 37, 115, 32, 111, 102, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 97, 109, 111, 110, 103, 32, 116, 104, 101, 32, 101, 110, 117, 109, 101, 114, 97, 116, 101, 100, 32, 110, 111, 116, 97, 116, 105, 111, 110, 115, 10, 0, 0, 86, 97, 108, 117, 101, 32, 34, 37, 115, 34, 32, 102, 111, 114, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 120, 109, 108, 110, 115, 32, 111, 102, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 97, 109, 111, 110, 103, 32, 116, 104, 101, 32, 101, 110, 117, 109, 101, 114, 97, 116, 101, 100, 32, 110, 111, 116, 97, 116, 105, 111, 110, 115, 10, 0, 0, 0, 0, 0, 86, 97, 108, 117, 101, 32, 34, 37, 115, 34, 32, 102, 111, 114, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 120, 109, 108, 110, 115, 58, 37, 115, 32, 111, 102, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 97, 109, 111, 110, 103, 32, 116, 104, 101, 32, 101, 110, 117, 109, 101, 114, 97, 116, 101, 100, 32, 115, 101, 116, 10, 0, 0, 0, 0, 0, 0, 0, 0, 86, 97, 108, 117, 101, 32, 34, 37, 115, 34, 32, 102, 111, 114, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 120, 109, 108, 110, 115, 32, 111, 102, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 97, 109, 111, 110, 103, 32, 116, 104, 101, 32, 101, 110, 117, 109, 101, 114, 97, 116, 101, 100, 32, 115, 101, 116, 10, 0, 0, 0, 86, 97, 108, 117, 101, 32, 102, 111, 114, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 120, 109, 108, 110, 115, 58, 37, 115, 32, 111, 102, 32, 37, 115, 32, 109, 117, 115, 116, 32, 98, 101, 32, 34, 37, 115, 34, 10, 0, 0, 0, 0, 0, 0, 0, 0, 86, 97, 108, 117, 101, 32, 102, 111, 114, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 120, 109, 108, 110, 115, 32, 111, 102, 32, 37, 115, 32, 109, 117, 115, 116, 32, 98, 101, 32, 34, 37, 115, 34, 10, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 119, 97, 115, 32, 100, 101, 99, 108, 97, 114, 101, 100, 32, 69, 77, 80, 84, 89, 32, 116, 104, 105, 115, 32, 111, 110, 101, 32, 104, 97, 115, 32, 99, 111, 110, 116, 101, 110, 116, 10, 0, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 119, 97, 115, 32, 100, 101, 99, 108, 97, 114, 101, 100, 32, 35, 80, 67, 68, 65, 84, 65, 32, 98, 117, 116, 32, 99, 111, 110, 116, 97, 105, 110, 115, 32, 110, 111, 110, 32, 116, 101, 120, 116, 32, 110, 111, 100, 101, 115, 10, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 100, 101, 99, 108, 97, 114, 101, 100, 32, 105, 110, 32, 37, 115, 32, 108, 105, 115, 116, 32, 111, 102, 32, 112, 111, 115, 115, 105, 98, 108, 101, 32, 99, 104, 105, 108, 100, 114, 101, 110, 10, 0, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 99, 111, 110, 116, 101, 110, 116, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 102, 111, 108, 108, 111, 119, 32, 116, 104, 101, 32, 68, 84, 68, 44, 32, 77, 105, 115, 112, 108, 97, 99, 101, 100, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 99, 111, 110, 116, 101, 110, 116, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 102, 111, 108, 108, 111, 119, 32, 116, 104, 101, 32, 68, 84, 68, 44, 32, 84, 101, 120, 116, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 101, 100, 10, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 99, 111, 110, 116, 101, 110, 116, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 102, 111, 108, 108, 111, 119, 32, 116, 104, 101, 32, 68, 84, 68, 44, 32, 69, 120, 112, 101, 99, 116, 105, 110, 103, 32, 109, 111, 114, 101, 32, 99, 104, 105, 108, 100, 10, 0, 0, 0, 0, 0, 0, 0, 65, 116, 116, 114, 105, 98, 117, 116, 101, 32, 101, 108, 101, 109, 101, 110, 116, 32, 110, 111, 116, 32, 101, 120, 112, 101, 99, 116, 101, 100, 10, 0, 84, 101, 120, 116, 32, 101, 108, 101, 109, 101, 110, 116, 32, 104, 97, 115, 32, 99, 104, 105, 108, 100, 114, 101, 110, 32, 33, 10, 0, 0, 0, 0, 84, 101, 120, 116, 32, 101, 108, 101, 109, 101, 110, 116, 32, 104, 97, 115, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 33, 10, 0, 0, 0, 84, 101, 120, 116, 32, 101, 108, 101, 109, 101, 110, 116, 32, 104, 97, 115, 32, 110, 111, 32, 99, 111, 110, 116, 101, 110, 116, 32, 33, 10, 0, 0, 69, 110, 116, 105, 116, 121, 32, 101, 108, 101, 109, 101, 110, 116, 32, 110, 111, 116, 32, 101, 120, 112, 101, 99, 116, 101, 100, 10, 0, 0, 0, 0, 78, 111, 116, 97, 116, 105, 111, 110, 32, 101, 108, 101, 109, 101, 110, 116, 32, 110, 111, 116, 32, 101, 120, 112, 101, 99, 116, 101, 100, 10, 0, 0, 68, 111, 99, 117, 109, 101, 110, 116, 32, 101, 108, 101, 109, 101, 110, 116, 32, 110, 111, 116, 32, 101, 120, 112, 101, 99, 116, 101, 100, 10, 0, 0, 72, 84, 77, 76, 32, 68, 111, 99, 117, 109, 101, 110, 116, 32, 110, 111, 116, 32, 101, 120, 112, 101, 99, 116, 101, 100, 10, 0, 0, 0, 0, 0, 117, 110, 107, 110, 111, 119, 110, 32, 101, 108, 101, 109, 101, 110, 116, 32, 116, 121, 112, 101, 10, 0, 0, 0, 78, 111, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 102, 111, 114, 32, 101, 108, 101, 109, 101, 110, 116, 32, 37, 115, 10, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 58, 32, 77, 73, 88, 69, 68, 32, 115, 116, 114, 117, 99, 116, 32, 99, 111, 114, 114, 117, 112, 116, 101, 100, 10, 0, 0, 0, 0, 0, 0, 0, 115, 116, 97, 110, 100, 97, 108, 111, 110, 101, 58, 32, 37, 115, 32, 100, 101, 99, 108, 97, 114, 101, 100, 32, 105, 110, 32, 116, 104, 101, 32, 101, 120, 116, 101, 114, 110, 97, 108, 32, 115, 117, 98, 115, 101, 116, 32, 99, 111, 110, 116, 97, 105, 110, 115, 32, 119, 104, 105, 116, 101, 32, 115, 112, 97, 99, 101, 115, 32, 110, 111, 100, 101, 115, 10, 0, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 99, 97, 114, 114, 121, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 10, 0, 69, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 99, 97, 114, 114, 121, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 58, 37, 115, 10, 0, 0, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 114, 101, 113, 117, 105, 114, 101, 100, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 58, 37, 115, 32, 104, 97, 115, 32, 110, 111, 32, 112, 114, 101, 102, 105, 120, 10, 0, 0, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 114, 101, 113, 117, 105, 114, 101, 100, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 58, 37, 115, 32, 104, 97, 115, 32, 100, 105, 102, 102, 101, 114, 101, 110, 116, 32, 112, 114, 101, 102, 105, 120, 10, 0, 0, 0, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 110, 97, 109, 101, 32, 102, 111, 114, 32, 100, 101, 102, 97, 117, 108, 116, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 109, 97, 116, 99, 104, 32, 116, 104, 101, 32, 68, 84, 68, 10, 0, 69, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 110, 97, 109, 101, 32, 102, 111, 114, 32, 37, 115, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 109, 97, 116, 99, 104, 32, 116, 104, 101, 32, 68, 84, 68, 10, 0, 0, 0, 0, 0, 0, 0, 0, 110, 111, 32, 114, 111, 111, 116, 32, 101, 108, 101, 109, 101, 110, 116, 10, 0, 0, 0, 0, 0, 0, 0, 0, 72, 84, 77, 76, 0, 0, 0, 0, 104, 116, 109, 108, 0, 0, 0, 0, 114, 111, 111, 116, 32, 97, 110, 100, 32, 68, 84, 68, 32, 110, 97, 109, 101, 32, 100, 111, 32, 110, 111, 116, 32, 109, 97, 116, 99, 104, 32, 39, 37, 115, 39, 32, 97, 110, 100, 32, 39, 37, 115, 39, 10, 0, 0, 0, 120, 109, 108, 86, 97, 108, 105, 100, 97, 116, 101, 68, 111, 99, 117, 109, 101, 110, 116, 70, 105, 110, 97, 108, 58, 32, 100, 111, 99, 32, 61, 61, 32, 78, 85, 76, 76, 10, 0, 0, 110, 111, 32, 68, 84, 68, 32, 102, 111, 117, 110, 100, 33, 10, 0, 0, 67, 111, 117, 108, 100, 32, 110, 111, 116, 32, 98, 117, 105, 108, 100, 32, 85, 82, 73, 32, 102, 111, 114, 32, 101, 120, 116, 101, 114, 110, 97, 108, 32, 115, 117, 98, 115, 101, 116, 32, 34, 37, 115, 34, 10, 0, 0, 0, 67, 111, 117, 108, 100, 32, 110, 111, 116, 32, 108, 111, 97, 100, 32, 116, 104, 101, 32, 101, 120, 116, 101, 114, 110, 97, 108, 32, 115, 117, 98, 115, 101, 116, 32, 34, 37, 115, 34, 10, 0, 0, 0, 0, 0, 0, 0, 0, 60, 33, 100, 117, 109, 109, 121, 63, 62, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 86, 97, 108, 105, 100, 97, 116, 101, 65, 116, 116, 114, 105, 98, 117, 116, 101, 67, 97, 108, 108, 98, 97, 99, 107, 40, 37, 115, 41, 58, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 10, 0, 0, 0, 0, 0, 0, 0, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 58, 32, 99, 111, 117, 108, 100, 32, 110, 111, 116, 32, 102, 105, 110, 100, 32, 100, 101, 99, 108, 32, 102, 111, 114, 32, 101, 108, 101, 109, 101, 110, 116, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 78, 79, 84, 65, 84, 73, 79, 78, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 100, 101, 99, 108, 97, 114, 101, 100, 32, 102, 111, 114, 32, 69, 77, 80, 84, 89, 32, 101, 108, 101, 109, 101, 110, 116, 32, 37, 115, 10, 0, 0, 0, 0, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 108, 105, 110, 101, 32, 37, 100, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 115, 32, 97, 110, 32, 117, 110, 107, 110, 111, 119, 110, 32, 73, 68, 32, 34, 37, 115, 34, 10, 0, 0, 0, 0, 0, 73, 68, 82, 69, 70, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 115, 32, 97, 110, 32, 117, 110, 107, 110, 111, 119, 110, 32, 73, 68, 32, 34, 37, 115, 34], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 74608);
	        allocate([10, 0, 0, 0, 0, 0, 0, 0, 73, 68, 82, 69, 70, 83, 32, 115, 112, 108, 105, 116, 0, 0, 0, 0, 73, 68, 82, 69, 70, 83, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 115, 32, 97, 110, 32, 117, 110, 107, 110, 111, 119, 110, 32, 73, 68, 32, 34, 37, 115, 34, 10, 0, 0, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 99, 111, 110, 116, 101, 110, 116, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 102, 111, 108, 108, 111, 119, 32, 116, 104, 101, 32, 68, 84, 68, 44, 32, 101, 120, 112, 101, 99, 116, 105, 110, 103, 32, 37, 115, 44, 32, 103, 111, 116, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 99, 111, 110, 116, 101, 110, 116, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 102, 111, 108, 108, 111, 119, 32, 116, 104, 101, 32, 68, 84, 68, 44, 32, 101, 120, 112, 101, 99, 116, 105, 110, 103, 32, 37, 115, 44, 32, 103, 111, 116, 32, 37, 115, 10, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 99, 111, 110, 116, 101, 110, 116, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 102, 111, 108, 108, 111, 119, 32, 116, 104, 101, 32, 68, 84, 68, 10, 0, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 99, 111, 110, 116, 101, 110, 116, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 102, 111, 108, 108, 111, 119, 32, 116, 104, 101, 32, 68, 84, 68, 10, 0, 0, 0, 0, 0, 0, 0, 0, 67, 68, 65, 84, 65, 0, 0, 0, 63, 63, 63, 0, 0, 0, 0, 0, 114, 101, 97, 108, 108, 111, 99, 32, 102, 97, 105, 108, 101, 100, 0, 0, 70, 97, 105, 108, 101, 100, 32, 116, 111, 32, 98, 117, 105, 108, 100, 32, 99, 111, 110, 116, 101, 110, 116, 32, 109, 111, 100, 101, 108, 32, 114, 101, 103, 101, 120, 112, 32, 102, 111, 114, 32, 37, 115, 10, 0, 0, 0, 0, 69, 78, 84, 73, 84, 89, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 97, 110, 32, 117, 110, 107, 110, 111, 119, 110, 32, 101, 110, 116, 105, 116, 121, 32, 34, 37, 115, 34, 10, 0, 0, 0, 69, 78, 84, 73, 84, 89, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 97, 110, 32, 101, 110, 116, 105, 116, 121, 32, 34, 37, 115, 34, 32, 111, 102, 32, 119, 114, 111, 110, 103, 32, 116, 121, 112, 101, 10, 0, 0, 0, 0, 0, 69, 78, 84, 73, 84, 73, 69, 83, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 97, 110, 32, 117, 110, 107, 110, 111, 119, 110, 32, 101, 110, 116, 105, 116, 121, 32, 34, 37, 115, 34, 10, 0, 69, 78, 84, 73, 84, 73, 69, 83, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 97, 110, 32, 101, 110, 116, 105, 116, 121, 32, 34, 37, 115, 34, 32, 111, 102, 32, 119, 114, 111, 110, 103, 32, 116, 121, 112, 101, 10, 0, 0, 0, 78, 79, 84, 65, 84, 73, 79, 78, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 97, 110, 32, 117, 110, 107, 110, 111, 119, 110, 32, 110, 111, 116, 97, 116, 105, 111, 110, 32, 34, 37, 115, 34, 10, 0, 0, 0, 0, 0, 0, 0, 101, 108, 101, 109, 101, 110, 116, 32, 116, 97, 98, 108, 101, 32, 97, 108, 108, 111, 99, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 0, 69, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 104, 97, 115, 32, 116, 111, 111, 32, 109, 97, 110, 121, 32, 73, 68, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 115, 32, 100, 101, 102, 105, 110, 101, 100, 32, 58, 32, 37, 115, 10, 0, 0, 0, 0, 0, 37, 115, 0, 0, 0, 0, 0, 0, 77, 101, 109, 111, 114, 121, 32, 97, 108, 108, 111, 99, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 32, 58, 32, 37, 115, 10, 0, 0, 77, 101, 109, 111, 114, 121, 32, 97, 108, 108, 111, 99, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 10, 0, 0, 0, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 78, 85, 76, 76, 32, 99, 111, 110, 116, 101, 110, 116, 32, 105, 110, 32, 99, 111, 110, 116, 101, 110, 116, 32, 109, 111, 100, 101, 108, 32, 111, 102, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 80, 67, 68, 65, 84, 65, 32, 105, 110, 32, 99, 111, 110, 116, 101, 110, 116, 32, 109, 111, 100, 101, 108, 32, 111, 102, 32, 37, 115, 10, 0, 0, 0, 0, 66, 117, 105, 108, 100, 105, 110, 103, 32, 99, 111, 110, 116, 101, 110, 116, 32, 109, 111, 100, 101, 108, 0, 0, 67, 111, 110, 116, 101, 110, 116, 77, 111, 100, 101, 108, 32, 98, 114, 111, 107, 101, 110, 32, 102, 111, 114, 32, 101, 108, 101, 109, 101, 110, 116, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 200, 121, 1, 0, 200, 121, 1, 0, 176, 119, 1, 0, 136, 197, 1, 0, 208, 121, 1, 0, 216, 121, 1, 0, 224, 121, 1, 0, 232, 121, 1, 0, 240, 121, 1, 0, 248, 121, 1, 0, 208, 192, 1, 0, 24, 212, 1, 0, 112, 205, 1, 0, 240, 201, 1, 0, 216, 191, 1, 0, 56, 121, 1, 0, 80, 122, 1, 0, 40, 216, 1, 0, 48, 216, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 168, 117, 1, 0, 176, 119, 1, 0, 0, 0, 0, 0, 216, 119, 1, 0, 176, 119, 1, 0, 0, 0, 0, 0, 160, 117, 1, 0, 168, 117, 1, 0, 24, 115, 1, 0, 208, 119, 1, 0, 216, 119, 1, 0, 176, 119, 1, 0, 0, 0, 0, 0, 0, 120, 1, 0, 168, 117, 1, 0, 24, 115, 1, 0, 208, 119, 1, 0, 216, 119, 1, 0, 176, 119, 1, 0, 0, 0, 0, 0, 48, 122, 1, 0, 176, 119, 1, 0, 208, 121, 1, 0, 216, 121, 1, 0, 224, 121, 1, 0, 232, 121, 1, 0, 240, 121, 1, 0, 248, 121, 1, 0, 208, 192, 1, 0, 56, 121, 1, 0, 80, 122, 1, 0, 40, 216, 1, 0, 48, 216, 1, 0, 168, 117, 1, 0, 48, 122, 1, 0, 0, 0, 0, 0, 136, 197, 1, 0, 176, 119, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 208, 121, 1, 0, 176, 119, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 216, 121, 1, 0, 176, 119, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 224, 121, 1, 0, 176, 119, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 232, 121, 1, 0, 176, 119, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 240, 121, 1, 0, 176, 119, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 248, 121, 1, 0, 176, 119, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 216, 191, 1, 0, 176, 119, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 56, 121, 1, 0, 176, 119, 1, 0, 168, 117, 1, 0, 24, 212, 1, 0, 0, 0, 0, 0, 80, 122, 1, 0, 176, 119, 1, 0, 168, 117, 1, 0, 24, 212, 1, 0, 0, 0, 0, 0, 40, 216, 1, 0, 176, 119, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 48, 216, 1, 0, 176, 119, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 96, 121, 1, 0, 176, 119, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 208, 192, 1, 0, 176, 119, 1, 0, 176, 121, 1, 0, 240, 201, 1, 0, 216, 191, 1, 0, 56, 121, 1, 0, 80, 122, 1, 0, 40, 216, 1, 0, 48, 216, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 176, 121, 1, 0, 176, 119, 1, 0, 240, 201, 1, 0, 216, 191, 1, 0, 56, 121, 1, 0, 80, 122, 1, 0, 40, 216, 1, 0, 48, 216, 1, 0, 168, 117, 1, 0, 152, 121, 1, 0, 0, 0, 0, 0, 152, 121, 1, 0, 176, 119, 1, 0, 240, 201, 1, 0, 216, 191, 1, 0, 56, 121, 1, 0, 80, 122, 1, 0, 40, 216, 1, 0, 48, 216, 1, 0, 168, 117, 1, 0, 176, 121, 1, 0, 0, 0, 0, 0, 24, 212, 1, 0, 176, 119, 1, 0, 168, 117, 1, 0, 112, 205, 1, 0, 240, 201, 1, 0, 216, 191, 1, 0, 56, 121, 1, 0, 80, 122, 1, 0, 40, 216, 1, 0, 48, 216, 1, 0, 0, 0, 0, 0, 112, 205, 1, 0, 176, 119, 1, 0, 168, 117, 1, 0, 24, 212, 1, 0, 0, 0, 0, 0, 240, 201, 1, 0, 176, 119, 1, 0, 168, 117, 1, 0, 24, 212, 1, 0, 0, 0, 0, 0, 176, 119, 1, 0, 176, 119, 1, 0, 168, 117, 1, 0, 208, 121, 1, 0, 216, 121, 1, 0, 224, 121, 1, 0, 232, 121, 1, 0, 240, 121, 1, 0, 248, 121, 1, 0, 144, 122, 1, 0, 0, 122, 1, 0, 72, 121, 1, 0, 152, 122, 1, 0, 96, 122, 1, 0, 128, 122, 1, 0, 88, 121, 1, 0, 112, 122, 1, 0, 0, 0, 0, 0, 96, 118, 1, 0, 176, 119, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 56, 122, 1, 0, 176, 119, 1, 0, 0, 0, 0, 0, 128, 121, 1, 0, 192, 121, 1, 0, 72, 121, 1, 0, 0, 122, 1, 0, 176, 119, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 32, 121, 1, 0, 32, 121, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 120, 121, 1, 0, 176, 119, 1, 0, 0, 0, 0, 0, 32, 191, 1, 0, 120, 121, 1, 0, 32, 191, 1, 0, 176, 190, 1, 0, 176, 119, 1, 0, 0, 0, 0, 0, 176, 190, 1, 0, 120, 121, 1, 0, 176, 190, 1, 0, 176, 119, 1, 0, 0, 0, 0, 0, 152, 118, 1, 0, 176, 119, 1, 0, 168, 117, 1, 0, 208, 121, 1, 0, 216, 121, 1, 0, 224, 121, 1, 0, 232, 121, 1, 0, 240, 121, 1, 0, 248, 121, 1, 0, 80, 122, 1, 0, 40, 216, 1, 0, 48, 216, 1, 0, 32, 121, 1, 0, 0, 0, 0, 0, 112, 118, 1, 0, 112, 118, 1, 0, 104, 118, 1, 0, 176, 119, 1, 0, 120, 122, 1, 0, 192, 121, 1, 0, 32, 121, 1, 0, 72, 121, 1, 0, 0, 122, 1, 0, 152, 122, 1, 0, 0, 0, 0, 0, 104, 118, 1, 0, 112, 118, 1, 0, 104, 118, 1, 0, 176, 119, 1, 0, 120, 122, 1, 0, 192, 121, 1, 0, 32, 121, 1, 0, 72, 121, 1, 0, 0, 122, 1, 0, 152, 122, 1, 0, 0, 0, 0, 0, 120, 118, 1, 0, 112, 118, 1, 0, 104, 118, 1, 0, 120, 118, 1, 0, 120, 121, 1, 0, 176, 190, 1, 0, 32, 191, 1, 0, 176, 119, 1, 0, 0, 0, 0, 0, 128, 118, 1, 0, 120, 121, 1, 0, 176, 190, 1, 0, 32, 191, 1, 0, 0, 0, 0, 0, 144, 118, 1, 0, 112, 118, 1, 0, 104, 118, 1, 0, 120, 118, 1, 0, 120, 121, 1, 0, 176, 190, 1, 0, 32, 191, 1, 0, 128, 118, 1, 0, 136, 118, 1, 0, 176, 119, 1, 0, 0, 0, 0, 0, 136, 118, 1, 0, 112, 118, 1, 0, 104, 118, 1, 0, 120, 118, 1, 0, 120, 121, 1, 0, 176, 190, 1, 0, 32, 191, 1, 0, 128, 118, 1, 0, 144, 118, 1, 0, 136, 118, 1, 0, 176, 119, 1, 0, 0, 0, 0, 0, 160, 205, 1, 0, 200, 205, 1, 0, 0, 0, 0, 0, 200, 205, 1, 0, 200, 205, 1, 0, 0, 0, 0, 0, 184, 193, 1, 0, 40, 122, 1, 0, 176, 119, 1, 0, 168, 117, 1, 0, 208, 121, 1, 0, 216, 121, 1, 0, 224, 121, 1, 0, 232, 121, 1, 0, 240, 121, 1, 0, 248, 121, 1, 0, 80, 122, 1, 0, 40, 216, 1, 0, 48, 216, 1, 0, 32, 121, 1, 0, 0, 0, 0, 0, 144, 122, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 0, 122, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 72, 121, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 152, 122, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 96, 122, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 128, 122, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 88, 121, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 112, 122, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 184, 121, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 136, 122, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 168, 121, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 144, 121, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 104, 122, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 24, 122, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 160, 122, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 136, 121, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 40, 121, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 48, 121, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 112, 198, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 192, 121, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 168, 189, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 96, 201, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 88, 122, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 104, 177, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 144, 177, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 120, 122, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 80, 121, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 8, 122, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 32, 121, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 32, 182, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 200, 182, 1, 0, 64, 183, 1, 0, 0, 0, 0, 0, 40, 121, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 72, 183, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 48, 121, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 160, 183, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 56, 121, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 168, 183, 1, 0, 192, 183, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 64, 121, 1, 0, 0, 0, 0, 0, 1, 1, 2, 0, 104, 184, 1, 0, 120, 184, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 128, 185, 1, 0, 0, 0, 0, 0, 184, 185, 1, 0, 0, 2, 2, 1, 0, 0, 0, 0, 192, 185, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 224, 185, 1, 0, 64, 183, 1, 0, 8, 186, 1, 0, 72, 121, 1, 0, 0, 3, 0, 0, 0, 0, 1, 0, 16, 186, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 224, 119, 1, 0, 0, 2, 2, 1, 0, 0, 0, 0, 32, 186, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 64, 183, 1, 0, 56, 186, 1, 0, 64, 186, 1, 0, 0, 2, 2, 1, 1, 1, 1, 0, 80, 186, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 96, 186, 1, 0, 0, 0, 0, 0, 80, 121, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 120, 186, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 144, 186, 1, 0, 0, 0, 0, 0, 176, 186, 1, 0, 88, 121, 1, 0, 0, 3, 0, 0, 0, 0, 1, 0, 184, 186, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 96, 121, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 208, 186, 1, 0, 224, 186, 1, 0, 0, 0, 0, 0, 224, 187, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 160, 117, 1, 0, 1, 1, 0, 0, 0, 0, 0, 0, 40, 188, 1, 0, 56, 188, 1, 0, 96, 118, 1, 0, 64, 189, 1, 0, 136, 189, 1, 0, 0, 0, 0, 0, 168, 189, 1, 0, 0, 2, 2, 1, 0, 0, 1, 0, 176, 189, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 200, 189, 1, 0, 224, 189, 1, 0, 0, 0, 0, 0, 112, 121, 1, 0, 0, 0, 0, 0, 0, 0, 2, 0, 232, 189, 1, 0, 224, 186, 1, 0, 0, 0, 0, 0, 248, 189, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 120, 121, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 88, 190, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 128, 121, 1, 0, 0, 3, 0, 0, 1, 1, 0, 0, 104, 190, 1, 0, 224, 186, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 96, 183, 1, 0, 0, 0, 0, 0, 136, 121, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 136, 190, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 144, 121, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 152, 190, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 176, 190, 1, 0, 0, 2, 2, 1, 0, 0, 0, 0, 184, 190, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 200, 190, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 32, 191, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 48, 191, 1, 0, 72, 191, 1, 0, 176, 190, 1, 0, 200, 190, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 152, 121, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 80, 191, 1, 0, 224, 186, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 160, 121, 1, 0, 0, 0, 0, 0, 0, 0, 2, 0, 104, 191, 1, 0, 224, 186, 1, 0, 0, 0, 0, 0, 120, 191, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 168, 121, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 192, 191, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 216, 191, 1, 0, 0, 0, 0, 0, 1, 1, 0, 0, 224, 191, 1, 0, 240, 191, 1, 0, 48, 122, 1, 0, 0, 0, 0, 0, 88, 192, 1, 0, 0, 0, 0, 0, 96, 118, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 160, 192, 1, 0, 224, 186, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 200, 192, 1, 0, 0, 0, 0, 0, 208, 192, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 216, 192, 1, 0, 240, 192, 1, 0, 152, 121, 1, 0, 96, 183, 1, 0, 0, 193, 1, 0, 0, 0, 0, 0, 176, 121, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 8, 193, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 184, 121, 1, 0, 0, 3, 0, 0, 0, 0, 1, 0, 32, 193, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 48, 193, 1, 0, 0, 1, 0, 0, 1, 1, 1, 0, 56, 193, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 88, 193, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 184, 193, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 200, 193, 1, 0, 224, 193, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 192, 121, 1, 0, 0, 3, 0, 0, 1, 1, 1, 0, 224, 194, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 248, 194, 1, 0, 0, 0, 0, 0, 200, 121, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 32, 195, 1, 0, 56, 195, 1, 0, 184, 193, 1, 0, 48, 196, 1, 0, 64, 183, 1, 0, 144, 196, 1, 0, 248, 119, 1, 0, 0, 2, 2, 1, 0, 2, 0, 0, 152, 196, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 168, 196, 1, 0, 0, 0, 0, 0, 0, 120, 1, 0, 0, 0, 0, 0, 0, 2, 0, 0, 224, 196, 1, 0, 248, 196, 1, 0, 232, 119, 1, 0, 0, 0, 0, 0, 8, 197, 1, 0, 0, 0, 0, 0, 208, 121, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 48, 197, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 200, 192, 1, 0, 0, 0, 0, 0, 216, 121, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 48, 197, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 200, 192, 1, 0, 0, 0, 0, 0, 224, 121, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 48, 197, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 200, 192, 1, 0, 0, 0, 0, 0, 232, 121, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 48, 197, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 200, 192, 1, 0, 0, 0, 0, 0, 240, 121, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 48, 197, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 200, 192, 1, 0, 0, 0, 0, 0, 248, 121, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 48, 197, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 200, 192, 1, 0, 0, 0, 0, 0, 168, 117, 1, 0, 1, 1, 0, 0, 0, 0, 0, 0, 64, 197, 1, 0, 80, 197, 1, 0, 0, 0, 0, 0, 120, 197, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 136, 197, 1, 0, 0, 2, 2, 1, 0, 0, 0, 0, 144, 197, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 96, 183, 1, 0, 168, 197, 1, 0, 0, 0, 0, 0, 32, 112, 1, 0, 1, 1, 0, 0, 0, 0, 0, 0, 192, 197, 1, 0, 216, 197, 1, 0, 0, 0, 0, 0, 232, 197, 1, 0, 248, 197, 1, 0, 0, 0, 0, 0, 0, 122, 1, 0, 0, 3, 0, 0, 0, 0, 1, 0, 0, 198, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 122, 1, 0, 0, 0, 0, 0, 0, 1, 2, 0, 24, 198, 1, 0, 224, 186, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 48, 198, 1, 0, 0, 0, 0, 0, 112, 198, 1, 0, 0, 2, 2, 1, 0, 0, 1, 0, 120, 198, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 136, 198, 1, 0, 200, 192, 1, 0, 224, 198, 1, 0, 240, 198, 1, 0, 0, 2, 2, 1, 0, 0, 1, 0, 248, 198, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 199, 1, 0, 200, 192, 1, 0, 0, 0, 0, 0, 16, 122, 1, 0, 0, 0, 0, 0, 0, 0, 2, 0, 152, 199, 1, 0, 224, 186, 1, 0, 0, 0, 0, 0, 120, 191, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 168, 199, 1, 0, 0, 2, 2, 1, 1, 1, 0, 0, 176, 199, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 200, 199, 1, 0, 0, 0, 0, 0, 24, 122, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 232, 199, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 32, 122, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 8, 200, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 32, 200, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 40, 122, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 112, 200, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 136, 200, 1, 0, 200, 192, 1, 0, 0, 0, 0, 0, 48, 122, 1, 0, 0, 1, 1, 0, 0, 0, 0, 0, 208, 200, 1, 0, 224, 186, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 208, 119, 1, 0, 0, 2, 2, 1, 0, 0, 0, 0, 224, 200, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 201, 1, 0, 64, 183, 1, 0, 0, 0, 0, 0, 96, 201, 1, 0, 0, 0, 0, 0, 0, 0, 2, 0, 104, 201, 1, 0, 128, 201, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 0, 0, 0, 0, 232, 201, 1, 0, 240, 201, 1, 0, 0, 0, 0, 0, 1, 1, 0, 0, 248, 201, 1, 0, 240, 191, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 88, 192, 1, 0, 0, 0, 0, 0, 200, 119, 1, 0, 0, 2, 2, 1, 0, 0, 0, 0, 8, 202, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 40, 202, 1, 0, 0, 0, 0, 0, 72, 202, 1, 0, 232, 119, 1, 0, 0, 0, 0, 0, 0, 2, 0, 0, 80, 202, 1, 0, 144, 202, 1, 0, 160, 117, 1, 0, 96, 183, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 56, 122, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 152, 203, 1, 0, 224, 186, 1, 0, 96, 118, 1, 0, 96, 183, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 72, 122, 1, 0, 0, 0, 0, 0, 0, 0, 2, 0, 56, 193, 1, 0, 216, 203, 1, 0, 96, 118, 1, 0, 224, 204, 1, 0, 88, 205, 1, 0, 0, 0, 0, 0, 112, 205, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 120, 205, 1, 0, 136, 205, 1, 0, 48, 122, 1, 0, 96, 183, 1, 0, 144, 205, 1, 0, 0, 0, 0, 0, 160, 205, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 176, 205, 1, 0, 192, 205, 1, 0, 200, 205, 1, 0, 208, 205, 1, 0, 0, 0, 0, 0, 24, 206, 1, 0, 200, 205, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 32, 206, 1, 0, 56, 206, 1, 0, 0, 0, 0, 0, 64, 206, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 176, 119, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 144, 206, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 200, 192, 1, 0, 0, 0, 0, 0, 160, 206, 1, 0, 0, 2, 2, 1, 0, 0, 0, 0, 168, 206, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 192, 206, 1, 0, 0, 0, 0, 0, 232, 201, 1, 0, 80, 122, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 216, 206, 1, 0, 240, 206, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 88, 207, 1, 0, 0, 0, 0, 0, 88, 122, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 96, 207, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 224, 187, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 96, 122, 1, 0, 0, 3, 0, 0, 1, 1, 1, 0, 120, 207, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 96, 183, 1, 0, 0, 0, 0, 0, 104, 122, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 152, 207, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 16, 115, 1, 0, 0, 0, 0, 0, 0, 0, 2, 0, 192, 207, 1, 0, 56, 206, 1, 0, 0, 0, 0, 0, 216, 207, 1, 0, 240, 207, 1, 0, 248, 207, 1, 0, 0, 208, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 8, 208, 1, 0, 32, 208, 1, 0, 0, 0, 0, 0, 48, 208, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 112, 122, 1, 0, 0, 3, 0, 0, 0, 0, 1, 0, 144, 208, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 120, 122, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 168, 208, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 128, 122, 1, 0, 0, 3, 0, 0, 1, 1, 1, 0, 208, 208, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 96, 183, 1, 0, 0, 0, 0, 0, 136, 122, 1, 0, 0, 3, 0, 0, 0, 0, 1, 0, 232, 208, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 24, 115, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 248, 208, 1, 0, 56, 206, 1, 0, 0, 0, 0, 0, 8, 209, 1, 0, 0, 0, 0, 0, 248, 207, 1, 0, 104, 177, 1, 0, 0, 3, 0, 0, 0, 0, 1, 0, 32, 209, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 144, 177, 1, 0, 0, 3, 0, 0, 0, 0, 1, 0, 48, 209, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 152, 118, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 160, 183, 1, 0, 64, 209, 1, 0, 120, 118, 1, 0, 96, 209, 1, 0, 192, 209, 1, 0, 0, 0, 0, 0, 136, 118, 1, 0, 1, 0, 0, 0, 0, 0, 0, 0, 208, 209, 1, 0, 224, 209, 1, 0, 120, 118, 1, 0, 232, 209, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 104, 118, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 56, 210, 1, 0, 224, 186, 1, 0, 0, 0, 0, 0, 72, 210, 1, 0, 176, 210, 1, 0, 0, 0, 0, 0, 200, 210, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 216, 210, 1, 0, 56, 206, 1, 0, 0, 0, 0, 0, 240, 210, 1, 0, 0, 0, 0, 0, 88, 211, 1, 0, 144, 118, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 104, 211, 1, 0, 224, 209, 1, 0, 120, 118, 1, 0, 232, 209, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 112, 118, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 120, 211, 1, 0, 224, 186, 1, 0, 0, 0, 0, 0, 72, 210, 1, 0, 176, 210, 1, 0, 0, 0, 0, 0, 128, 118, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 144, 211, 1, 0, 224, 209, 1, 0, 120, 118, 1, 0, 232, 209, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 216, 119, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 160, 211, 1, 0, 56, 206, 1, 0, 0, 0, 0, 0, 232, 197, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 120, 118, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 176, 211, 1, 0, 192, 211, 1, 0, 104, 118, 1, 0, 232, 209, 1, 0, 208, 211, 1, 0, 0, 0, 0, 0, 144, 122, 1, 0, 0, 3, 0, 0, 0, 0, 1, 0, 216, 211, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 152, 122, 1, 0, 0, 3, 0, 0, 1, 1, 1, 0, 0, 212, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 96, 183, 1, 0, 0, 0, 0, 0, 24, 212, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 32, 212, 1, 0, 136, 205, 1, 0, 48, 122, 1, 0, 96, 183, 1, 0, 48, 212, 1, 0, 0, 0, 0, 0, 160, 122, 1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 64, 212, 1, 0, 40, 182, 1, 0, 0, 0, 0, 0, 96, 183, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 34, 0, 0, 0, 56, 127, 1, 0, 64, 127, 1, 0, 38, 0, 0, 0, 112, 127, 1, 0, 120, 127, 1, 0, 39, 0, 0, 0, 152, 127, 1, 0, 160, 127, 1, 0, 60, 0, 0, 0, 176, 127, 1, 0, 184, 127, 1, 0, 62, 0, 0, 0, 216, 127, 1, 0, 224, 127, 1, 0, 160, 0, 0, 0, 8, 128, 1, 0, 16, 128, 1, 0, 161, 0, 0, 0, 72, 128, 1, 0, 80, 128, 1, 0, 162, 0, 0, 0, 128, 128, 1, 0, 136, 128, 1, 0, 163, 0, 0, 0, 168, 128, 1, 0, 176, 128, 1, 0, 164, 0, 0, 0, 208, 128, 1, 0, 216, 128, 1, 0, 165, 0, 0, 0, 248, 128, 1, 0, 0, 129, 1, 0, 166, 0, 0, 0, 40, 129, 1, 0, 48, 129, 1, 0, 167, 0, 0, 0, 96, 129, 1, 0, 104, 129, 1, 0, 168, 0, 0, 0, 136, 129, 1, 0, 144, 129, 1, 0, 169, 0, 0, 0, 192, 129, 1, 0, 200, 129, 1, 0, 170, 0, 0, 0, 232, 129, 1, 0, 240, 129, 1, 0, 171, 0, 0, 0, 32, 130, 1, 0, 40, 130, 1, 0, 172, 0, 0, 0, 128, 130, 1, 0, 136, 130, 1, 0, 173, 0, 0, 0, 160, 130, 1, 0, 168, 130, 1, 0, 174, 0, 0, 0, 224, 130, 1, 0, 232, 130, 1, 0, 175, 0, 0, 0, 40, 131, 1, 0, 48, 131, 1, 0, 176, 0, 0, 0, 112, 131, 1, 0, 120, 131, 1, 0, 177, 0, 0, 0, 152, 131, 1, 0, 160, 131, 1, 0, 178, 0, 0, 0, 216, 131, 1, 0, 224, 131, 1, 0, 179, 0, 0, 0, 40, 132, 1, 0, 48, 132, 1, 0, 180, 0, 0, 0, 120, 132, 1, 0, 128, 132, 1, 0, 181, 0, 0, 0, 176, 132, 1, 0, 184, 132, 1, 0, 182, 0, 0, 0, 216, 132, 1, 0, 224, 132, 1, 0, 183, 0, 0, 0, 16, 133, 1, 0, 24, 133, 1, 0, 184, 0, 0, 0, 88, 133, 1, 0, 96, 133, 1, 0, 185, 0, 0, 0, 144, 133, 1, 0, 152, 133, 1, 0, 186, 0, 0, 0, 208, 133, 1, 0, 216, 133, 1, 0, 187, 0, 0, 0, 8, 134, 1, 0, 16, 134, 1, 0, 188, 0, 0, 0, 104, 134, 1, 0, 112, 134, 1, 0, 189, 0, 0, 0, 184, 134, 1, 0, 192, 134, 1, 0, 190, 0, 0, 0, 0, 135, 1, 0, 8, 135, 1, 0, 191, 0, 0, 0, 80, 135, 1, 0, 88, 135, 1, 0, 192, 0, 0, 0, 152, 135, 1, 0, 160, 135, 1, 0, 193, 0, 0, 0, 248, 135, 1, 0, 0, 136, 1, 0, 194, 0, 0, 0, 56, 136, 1, 0, 64, 136, 1, 0, 195, 0, 0, 0, 120, 136, 1, 0, 128, 136, 1, 0, 196, 0, 0, 0, 184, 136, 1, 0, 192, 136, 1, 0, 197, 0, 0, 0, 248, 136, 1, 0, 0, 137, 1, 0, 198, 0, 0, 0, 88, 137, 1, 0, 96, 137, 1, 0, 199, 0, 0, 0, 168, 137, 1, 0, 176, 137, 1, 0, 200, 0, 0, 0, 232, 137, 1, 0, 240, 137, 1, 0, 201, 0, 0, 0, 40, 138, 1, 0, 48, 138, 1, 0, 202, 0, 0, 0, 104, 138, 1, 0, 112, 138, 1, 0, 203, 0, 0, 0, 168, 138, 1, 0, 176, 138, 1, 0, 204, 0, 0, 0, 232, 138, 1, 0, 240, 138, 1, 0, 205, 0, 0, 0, 40, 139, 1, 0, 48, 139, 1, 0, 206, 0, 0, 0, 104, 139, 1, 0, 112, 139, 1, 0, 207, 0, 0, 0, 168, 139, 1, 0, 176, 139, 1, 0, 208, 0, 0, 0, 232, 139, 1, 0, 240, 139, 1, 0, 209, 0, 0, 0, 32, 140, 1, 0, 40, 140, 1, 0, 210, 0, 0, 0, 96, 140, 1, 0, 104, 140, 1, 0, 211, 0, 0, 0, 160, 140, 1, 0, 168, 140, 1, 0, 212, 0, 0, 0, 224, 140, 1, 0, 232, 140, 1, 0, 213, 0, 0, 0, 32, 141, 1, 0, 40, 141, 1, 0, 214, 0, 0, 0, 96, 141, 1, 0, 104, 141, 1, 0, 215, 0, 0, 0, 160, 141, 1, 0, 168, 141, 1, 0, 216, 0, 0, 0, 208, 141, 1, 0, 216, 141, 1, 0, 217, 0, 0, 0, 40, 142, 1, 0, 48, 142, 1, 0, 218, 0, 0, 0, 104, 142, 1, 0, 112, 142, 1, 0, 219, 0, 0, 0, 168, 142, 1, 0, 176, 142, 1, 0, 220, 0, 0, 0, 232, 142, 1, 0, 240, 142, 1, 0, 221, 0, 0, 0, 40, 143, 1, 0, 48, 143, 1, 0, 222, 0, 0, 0, 104, 143, 1, 0, 112, 143, 1, 0, 223, 0, 0, 0, 160, 143, 1, 0, 168, 143, 1, 0, 224, 0, 0, 0, 224, 143, 1, 0, 232, 143, 1, 0, 225, 0, 0, 0, 56, 144, 1, 0, 64, 144, 1, 0, 226, 0, 0, 0, 112, 144, 1, 0, 120, 144, 1, 0, 227, 0, 0, 0, 176, 144, 1, 0, 184, 144, 1, 0, 228, 0, 0, 0, 232, 144, 1, 0, 240, 144, 1, 0, 229, 0, 0, 0, 40, 145, 1, 0, 48, 145, 1, 0, 230, 0, 0, 0, 136, 145, 1, 0, 144, 145, 1, 0, 231, 0, 0, 0, 208, 145, 1, 0, 216, 145, 1, 0, 232, 0, 0, 0, 16, 146, 1, 0, 24, 146, 1, 0, 233, 0, 0, 0, 72, 146, 1, 0, 80, 146, 1, 0, 234, 0, 0, 0, 128, 146, 1, 0, 136, 146, 1, 0, 235, 0, 0, 0, 192, 146, 1, 0, 200, 146, 1, 0, 236, 0, 0, 0, 0, 147, 1, 0, 8, 147, 1, 0, 237, 0, 0, 0, 56, 147, 1, 0, 64, 147, 1, 0, 238, 0, 0, 0, 112, 147, 1, 0, 120, 147, 1, 0, 239, 0, 0, 0, 176, 147, 1, 0, 184, 147, 1, 0, 240, 0, 0, 0, 240, 147, 1, 0, 248, 147, 1, 0, 241, 0, 0, 0, 32, 148, 1, 0, 40, 148, 1, 0, 242, 0, 0, 0, 88, 148, 1, 0, 96, 148, 1, 0, 243, 0, 0, 0, 144, 148, 1, 0, 152, 148, 1, 0, 244, 0, 0, 0, 200, 148, 1, 0, 208, 148, 1, 0, 245, 0, 0, 0, 8, 149, 1, 0, 16, 149, 1, 0, 246, 0, 0, 0, 64, 149, 1, 0, 72, 149, 1, 0, 247, 0, 0, 0, 128, 149, 1, 0, 136, 149, 1, 0, 248, 0, 0, 0, 168, 149, 1, 0, 176, 149, 1, 0, 249, 0, 0, 0, 0, 150, 1, 0, 8, 150, 1, 0, 250, 0, 0, 0, 56, 150, 1, 0, 64, 150, 1, 0, 251, 0, 0, 0, 112, 150, 1, 0, 120, 150, 1, 0, 252, 0, 0, 0, 176, 150, 1, 0, 184, 150, 1, 0, 253, 0, 0, 0, 240, 150, 1, 0, 248, 150, 1, 0, 254, 0, 0, 0, 40, 151, 1, 0, 48, 151, 1, 0, 255, 0, 0, 0, 96, 151, 1, 0, 104, 151, 1, 0, 82, 1, 0, 0, 160, 151, 1, 0, 168, 151, 1, 0, 83, 1, 0, 0, 216, 151, 1, 0, 224, 151, 1, 0, 96, 1, 0, 0, 8, 152, 1, 0, 16, 152, 1, 0, 97, 1, 0, 0, 72, 152, 1, 0, 80, 152, 1, 0, 120, 1, 0, 0, 128, 152, 1, 0, 136, 152, 1, 0, 146, 1, 0, 0, 192, 152, 1, 0, 200, 152, 1, 0, 198, 2, 0, 0, 8, 153, 1, 0, 16, 153, 1, 0, 220, 2, 0, 0, 72, 153, 1, 0, 80, 153, 1, 0, 145, 3, 0, 0, 112, 153, 1, 0, 120, 153, 1, 0, 146, 3, 0, 0, 160, 153, 1, 0, 168, 153, 1, 0, 147, 3, 0, 0, 208, 153, 1, 0, 216, 153, 1, 0, 148, 3, 0, 0, 8, 154, 1, 0, 16, 154, 1, 0, 149, 3, 0, 0, 64, 154, 1, 0, 72, 154, 1, 0, 150, 3, 0, 0, 112, 154, 1, 0, 120, 154, 1, 0, 151, 3, 0, 0, 160, 154, 1, 0, 168, 154, 1, 0, 152, 3, 0, 0, 208, 154, 1, 0, 216, 154, 1, 0, 153, 3, 0, 0, 8, 155, 1, 0, 16, 155, 1, 0, 154, 3, 0, 0, 56, 155, 1, 0, 64, 155, 1, 0, 155, 3, 0, 0, 104, 155, 1, 0, 112, 155, 1, 0, 156, 3, 0, 0, 160, 155, 1, 0, 168, 155, 1, 0, 157, 3, 0, 0, 200, 155, 1, 0, 208, 155, 1, 0, 158, 3, 0, 0, 240, 155, 1, 0, 248, 155, 1, 0, 159, 3, 0, 0, 32, 156, 1, 0, 40, 156, 1, 0, 160, 3, 0, 0, 80, 156, 1, 0, 88, 156, 1, 0, 161, 3, 0, 0, 128, 156, 1, 0, 136, 156, 1, 0, 163, 3, 0, 0, 176, 156, 1, 0, 184, 156, 1, 0, 164, 3, 0, 0, 232, 156, 1, 0, 240, 156, 1, 0, 165, 3, 0, 0, 24, 157, 1, 0, 32, 157, 1, 0, 166, 3, 0, 0, 80, 157, 1, 0, 88, 157, 1, 0, 167, 3, 0, 0, 136, 157, 1, 0, 144, 157, 1, 0, 168, 3, 0, 0, 184, 157, 1, 0, 192, 157, 1, 0, 169, 3, 0, 0, 240, 157, 1, 0, 248, 157, 1, 0, 177, 3, 0, 0, 40, 158, 1, 0, 48, 158, 1, 0, 178, 3, 0, 0, 96, 158, 1, 0, 104, 158, 1, 0, 179, 3, 0, 0, 144, 158, 1, 0, 152, 158, 1, 0, 180, 3, 0, 0, 200, 158, 1, 0, 208, 158, 1, 0, 181, 3, 0, 0, 0, 159, 1, 0, 8, 159, 1, 0, 182, 3, 0, 0, 56, 159, 1, 0, 64, 159, 1, 0, 183, 3, 0, 0, 104, 159, 1, 0, 112, 159, 1, 0, 184, 3, 0, 0, 152, 159, 1, 0, 160, 159, 1, 0, 185, 3, 0, 0, 208, 159, 1, 0, 216, 159, 1, 0, 186, 3, 0, 0, 0, 160, 1, 0, 8, 160, 1, 0, 187, 3, 0, 0, 56, 160, 1, 0, 64, 160, 1, 0, 188, 3, 0, 0, 112, 160, 1, 0, 120, 160, 1, 0, 189, 3, 0, 0, 160, 160, 1, 0, 168, 160, 1, 0, 190, 3, 0, 0, 208, 160, 1, 0, 216, 160, 1, 0, 191, 3, 0, 0, 0, 161, 1, 0, 8, 161, 1, 0, 192, 3, 0, 0, 48, 161, 1, 0, 56, 161, 1, 0, 193, 3, 0, 0, 96, 161, 1, 0, 104, 161, 1, 0, 194, 3, 0, 0, 144, 161, 1, 0, 152, 161, 1, 0, 195, 3, 0, 0, 200, 161, 1, 0, 208, 161, 1, 0, 196, 3, 0, 0, 0, 162, 1, 0, 8, 162, 1, 0, 197, 3, 0, 0, 48, 162, 1, 0, 56, 162, 1, 0, 198, 3, 0, 0, 104, 162, 1, 0, 112, 162, 1, 0, 199, 3, 0, 0, 152, 162, 1, 0, 160, 162, 1, 0, 200, 3, 0, 0, 200, 162, 1, 0, 208, 162, 1, 0, 201, 3, 0, 0, 248, 162, 1, 0, 0, 163, 1, 0, 209, 3, 0, 0, 48, 163, 1, 0, 64, 163, 1, 0, 210, 3, 0, 0, 112, 163, 1, 0, 120, 163, 1, 0, 214, 3, 0, 0, 168, 163, 1, 0, 176, 163, 1, 0, 2, 32, 0, 0, 208, 163, 1, 0, 216, 163, 1, 0, 3, 32, 0, 0, 240, 163, 1, 0, 248, 163, 1, 0, 9, 32, 0, 0, 16, 164, 1, 0, 24, 164, 1, 0, 12, 32, 0, 0, 56, 164, 1, 0, 64, 164, 1, 0, 13, 32, 0, 0, 112, 164, 1, 0, 120, 164, 1, 0, 14, 32, 0, 0, 160, 164, 1, 0, 168, 164, 1, 0, 15, 32, 0, 0, 208, 164, 1, 0, 216, 164, 1, 0, 19, 32, 0, 0, 0, 165, 1, 0, 8, 165, 1, 0, 20, 32, 0, 0, 32, 165, 1, 0, 40, 165, 1, 0, 24, 32, 0, 0, 64, 165, 1, 0, 72, 165, 1, 0, 25, 32, 0, 0, 120, 165, 1, 0, 128, 165, 1, 0, 26, 32, 0, 0, 176, 165, 1, 0, 184, 165, 1, 0, 28, 32, 0, 0, 224, 165, 1, 0, 232, 165, 1, 0, 29, 32, 0, 0, 24, 166, 1, 0, 32, 166, 1, 0, 30, 32, 0, 0, 80, 166, 1, 0, 88, 166, 1, 0, 32, 32, 0, 0, 128, 166, 1, 0, 136, 166, 1, 0, 33, 32, 0, 0, 160, 166, 1, 0, 168, 166, 1, 0, 34, 32, 0, 0, 200, 166, 1, 0, 208, 166, 1, 0, 38, 32, 0, 0, 0, 167, 1, 0, 8, 167, 1, 0, 48, 32, 0, 0, 64, 167, 1, 0, 72, 167, 1, 0, 50, 32, 0, 0, 104, 167, 1, 0, 112, 167, 1, 0, 51, 32, 0, 0, 152, 167, 1, 0, 160, 167, 1, 0, 57, 32, 0, 0, 208, 167, 1, 0, 216, 167, 1, 0, 58, 32, 0, 0, 24, 168, 1, 0, 32, 168, 1, 0, 62, 32, 0, 0, 96, 168, 1, 0, 104, 168, 1, 0, 68, 32, 0, 0, 152, 168, 1, 0, 160, 168, 1, 0, 172, 32, 0, 0, 192, 168, 1, 0, 200, 168, 1, 0, 17, 33, 0, 0, 224, 168, 1, 0, 232, 168, 1, 0, 24, 33, 0, 0, 32, 169, 1, 0, 40, 169, 1, 0, 28, 33, 0, 0, 104, 169, 1, 0, 112, 169, 1, 0, 34, 33, 0, 0, 176, 169, 1, 0, 184, 169, 1, 0, 53, 33, 0, 0, 216, 169, 1, 0, 224, 169, 1, 0, 144, 33, 0, 0, 24, 170, 1, 0, 32, 170, 1, 0, 145, 33, 0, 0, 64, 170, 1, 0, 72, 170, 1, 0, 146, 33, 0, 0, 104, 170, 1, 0, 112, 170, 1, 0, 147, 33, 0, 0, 144, 170, 1, 0, 152, 170, 1, 0, 148, 33, 0, 0, 184, 170, 1, 0, 192, 170, 1, 0, 181, 33, 0, 0, 232, 170, 1, 0, 240, 170, 1, 0, 208, 33, 0, 0, 56, 171, 1, 0, 64, 171, 1, 0, 209, 33, 0, 0, 104, 171, 1, 0, 112, 171, 1, 0, 210, 33, 0, 0, 152, 171, 1, 0, 160, 171, 1, 0, 211, 33, 0, 0, 200, 171, 1, 0, 208, 171, 1, 0, 212, 33, 0, 0, 248, 171, 1, 0, 0, 172, 1, 0, 0, 34, 0, 0, 40, 172, 1, 0, 48, 172, 1, 0, 2, 34, 0, 0, 72, 172, 1, 0, 80, 172, 1, 0, 3, 34, 0, 0, 120, 172, 1, 0, 128, 172, 1, 0, 5, 34, 0, 0, 160, 172, 1, 0, 168, 172, 1, 0, 7, 34, 0, 0, 216, 172, 1, 0, 224, 172, 1, 0, 8, 34, 0, 0, 16, 173, 1, 0, 24, 173, 1, 0, 9, 34, 0, 0, 56, 173, 1, 0, 64, 173, 1, 0, 11, 34, 0, 0, 104, 173, 1, 0, 112, 173, 1, 0, 15, 34, 0, 0, 152, 173, 1, 0, 160, 173, 1, 0, 17, 34, 0, 0, 208, 173, 1, 0, 216, 173, 1, 0, 18, 34, 0, 0, 248, 173, 1, 0, 0, 174, 1, 0, 23, 34, 0, 0, 32, 174, 1, 0, 40, 174, 1, 0, 26, 34, 0, 0, 80, 174, 1, 0, 88, 174, 1, 0, 29, 34, 0, 0, 136, 174, 1, 0, 144, 174, 1, 0, 30, 34, 0, 0, 176, 174, 1, 0, 184, 174, 1, 0, 32, 34, 0, 0, 216, 174, 1, 0, 224, 174, 1, 0, 39, 34, 0, 0, 248, 174, 1, 0, 0, 175, 1, 0, 40, 34, 0, 0, 40, 175, 1, 0, 48, 175, 1, 0, 41, 34, 0, 0, 88, 175, 1, 0, 96, 175, 1, 0, 42, 34, 0, 0, 136, 175, 1, 0, 144, 175, 1, 0, 43, 34, 0, 0, 176, 175, 1, 0, 184, 175, 1, 0, 52, 34, 0, 0, 216, 175, 1, 0, 224, 175, 1, 0, 60, 34, 0, 0, 0, 176, 1, 0, 8, 176, 1, 0, 69, 34, 0, 0, 72, 176, 1, 0, 80, 176, 1, 0, 72, 34, 0, 0, 120, 176, 1, 0, 128, 176, 1, 0, 96, 34, 0, 0, 176, 176, 1, 0, 184, 176, 1, 0, 97, 34, 0, 0, 216, 176, 1, 0, 224, 176, 1, 0, 100, 34, 0, 0, 0, 177, 1, 0, 8, 177, 1, 0, 101, 34, 0, 0, 48, 177, 1, 0, 56, 177, 1, 0, 130, 34, 0, 0, 104, 177, 1, 0, 112, 177, 1, 0, 131, 34, 0, 0, 144, 177, 1, 0, 152, 177, 1, 0, 132, 34, 0, 0, 184, 177, 1, 0, 192, 177, 1, 0, 134, 34, 0, 0, 224, 177, 1, 0, 232, 177, 1, 0, 135, 34, 0, 0, 16, 178, 1, 0, 24, 178, 1, 0, 149, 34, 0, 0, 64, 178, 1, 0, 72, 178, 1, 0, 151, 34, 0, 0, 120, 178, 1, 0, 128, 178, 1, 0, 165, 34, 0, 0, 176, 178, 1, 0, 184, 178, 1, 0, 197, 34, 0, 0, 240, 178, 1, 0, 248, 178, 1, 0, 8, 35, 0, 0, 24, 179, 1, 0, 32, 179, 1, 0, 9, 35, 0, 0, 80, 179, 1, 0, 88, 179, 1, 0, 10, 35, 0, 0, 120, 179, 1, 0, 128, 179, 1, 0, 11, 35, 0, 0, 176, 179, 1, 0, 184, 179, 1, 0, 41, 35, 0, 0, 216, 179, 1, 0, 224, 179, 1, 0, 42, 35, 0, 0, 24, 180, 1, 0, 32, 180, 1, 0, 202, 37, 0, 0, 88, 180, 1, 0, 96, 180, 1, 0, 96, 38, 0, 0, 120, 180, 1, 0, 128, 180, 1, 0, 99, 38, 0, 0, 160, 180, 1, 0, 168, 180, 1, 0, 101, 38, 0, 0, 216, 180, 1, 0, 224, 180, 1, 0, 102, 38, 0, 0, 16, 181, 1, 0, 24, 181, 1, 0, 0, 0, 0, 0, 35, 37, 117, 0, 0, 0, 0, 0, 72, 84, 77, 76, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 99, 114, 101, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 10, 0, 0, 104, 116, 109, 108, 0, 0, 0, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 84, 82, 47, 82, 69, 67, 45, 104, 116, 109, 108, 52, 48, 47, 108, 111, 111, 115, 101, 46, 100, 116, 100, 0, 0, 0, 0, 0, 0, 0, 45, 47, 47, 87, 51, 67, 47, 47, 68, 84, 68, 32, 72, 84, 77, 76, 32, 52, 46, 48, 32, 84, 114, 97, 110, 115, 105, 116, 105, 111, 110, 97, 108, 47, 47, 69, 78, 0, 0, 0, 104, 116, 109, 108, 80, 97, 114, 115, 101, 69, 110, 116, 105, 116, 121, 82, 101, 102, 58, 32, 110, 111, 32, 110, 97, 109, 101, 10, 0, 0, 0, 0, 104, 116, 109, 108, 80, 97, 114, 115, 101, 69, 110, 116, 105, 116, 121, 82, 101, 102, 58, 32, 101, 120, 112, 101, 99, 116, 105, 110, 103, 32, 39, 59, 39, 10, 0, 0, 0, 0, 0, 0, 104, 116, 109, 108, 80, 97, 114, 115, 101, 67, 104, 97, 114, 82, 101, 102, 58, 32, 99, 111, 110, 116, 101, 120, 116, 32, 101, 114, 114, 111, 114, 10, 0, 0, 0, 0, 0, 0, 0, 0, 104, 116, 109, 108, 80, 97, 114, 115, 101, 67, 104, 97, 114, 82, 101, 102, 58, 32, 109, 105, 115, 115, 105, 110, 103, 32, 115, 101, 109, 105, 99, 111, 108, 111, 110, 10, 0, 0, 0, 0, 104, 116, 109, 108, 80, 97, 114, 115, 101, 67, 104, 97, 114, 82, 101, 102, 58, 32, 105, 110, 118, 97, 108, 105, 100, 32, 118, 97, 108, 117, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 104, 116, 109, 108, 80, 97, 114, 115, 101, 67, 104, 97, 114, 82, 101, 102, 58, 32, 105, 110, 118, 97, 108, 105, 100, 32, 120, 109, 108, 67, 104, 97, 114, 32, 118, 97, 108, 117, 101, 32, 37, 100, 10, 0, 0, 0, 0, 0, 84, 97, 103, 32, 37, 115, 32, 105, 110, 118, 97, 108, 105, 100, 10, 0, 67, 111, 117, 108, 100, 110, 39, 116, 32, 102, 105, 110, 100, 32, 101, 110, 100, 32, 111, 102, 32, 83, 116, 97, 114, 116, 32, 84, 97, 103, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 104, 116, 109, 108, 80, 97, 114, 115, 101, 68, 111, 99, 117, 109, 101, 110, 116, 58, 32, 99, 111, 110, 116, 101, 120, 116, 32, 101, 114, 114, 111, 114, 10, 0, 0, 0, 0, 0, 0, 0, 68, 111, 99, 117, 109, 101, 110, 116, 32, 105, 115, 32, 101, 109, 112, 116, 121, 10, 0, 0, 0, 0, 0, 0, 78, 101, 119, 80, 97, 114, 115, 101, 114, 67, 116, 120, 116, 58, 32, 111, 117, 116, 32, 111, 102, 32, 109, 101, 109, 111, 114, 121, 10, 0, 0, 0, 104, 116, 109, 108, 80, 97, 114, 115, 101, 67, 104, 117, 110, 107, 58, 32, 99, 111, 110, 116, 101, 120, 116, 32, 101, 114, 114, 111, 114, 10, 0, 0, 101, 110, 99, 111, 100, 101, 114, 32, 101, 114, 114, 111, 114, 10, 0, 0, 99, 104, 97, 114, 115, 101, 116, 61, 0, 0, 0, 0, 0, 0, 0, 0, 111, 117, 116, 32, 111, 102, 32, 109, 101, 109, 111, 114, 121, 10, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 99, 104, 97, 114, 115, 101, 116, 0, 61, 0, 0, 0, 0, 0, 0, 0, 104, 116, 109, 108, 67, 104, 101, 99, 107, 69, 110, 99, 111, 100, 105, 110, 103, 58, 32, 119, 114, 111, 110, 103, 32, 101, 110, 99, 111, 100, 105, 110, 103, 32, 109, 101, 116, 97, 10, 0, 104, 116, 109, 108, 67, 104, 101, 99, 107, 69, 110, 99, 111, 100, 105, 110, 103, 58, 32, 117, 110, 107, 110, 111, 119, 110, 32, 101, 110, 99, 111, 100, 105, 110, 103, 32, 37, 115, 10, 0, 104, 116, 109, 108, 67, 104, 101, 99, 107, 69, 110, 99, 111, 100, 105, 110, 103, 58, 32, 101, 110, 99, 111, 100, 101, 114, 32, 101, 114, 114, 111, 114, 10, 0, 0, 0, 0, 0, 0, 0, 99, 111, 117, 108, 100, 110, 39, 116, 32, 97, 108, 108, 111, 99, 97, 116, 101, 32, 97, 32, 110, 101, 119, 32, 105, 110, 112, 117, 116, 32, 115, 116, 114, 101, 97, 109, 10, 0, 0, 0, 115, 99, 114, 105, 112, 116, 0, 0, 115, 116, 121, 108, 101, 0, 0, 0, 77, 105, 115, 112, 108, 97, 99, 101, 100, 32, 68, 79, 67, 84, 89, 80, 69, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 10, 0, 0, 68, 79, 67, 84, 89, 80, 69, 0, 59, 32, 62, 47, 0, 0, 0, 0, 60, 38, 0, 0, 0, 0, 0, 0, 100, 101, 116, 101, 99, 116, 101, 100, 32, 97, 110, 32, 101, 114, 114, 111, 114, 32, 105, 110, 32, 101, 108, 101, 109, 101, 110, 116, 32, 99, 111, 110], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 84848);
	        allocate([116, 101, 110, 116, 10, 0, 0, 0, 72, 80, 80, 58, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 44, 32, 115, 116, 97, 116, 101, 32, 61, 61, 32, 67, 68, 65, 84, 65, 10, 0, 0, 0, 0, 72, 80, 80, 58, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 44, 32, 115, 116, 97, 116, 101, 32, 61, 61, 32, 68, 84, 68, 10, 0, 0, 0, 0, 0, 0, 72, 80, 80, 58, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 44, 32, 115, 116, 97, 116, 101, 32, 61, 61, 32, 67, 79, 77, 77, 69, 78, 84, 10, 0, 0, 72, 80, 80, 58, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 44, 32, 115, 116, 97, 116, 101, 32, 61, 61, 32, 80, 73, 10, 0, 0, 0, 0, 0, 0, 0, 72, 80, 80, 58, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 44, 32, 115, 116, 97, 116, 101, 32, 61, 61, 32, 69, 78, 84, 73, 84, 89, 95, 68, 69, 67, 76, 10, 0, 0, 0, 0, 0, 0, 72, 80, 80, 58, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 44, 32, 115, 116, 97, 116, 101, 32, 61, 61, 32, 69, 78, 84, 73, 84, 89, 95, 86, 65, 76, 85, 69, 10, 0, 0, 0, 0, 0, 72, 80, 80, 58, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 44, 32, 115, 116, 97, 116, 101, 32, 61, 61, 32, 65, 84, 84, 82, 73, 66, 85, 84, 69, 95, 86, 65, 76, 85, 69, 10, 0, 0, 72, 80, 80, 58, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 44, 32, 115, 116, 97, 116, 101, 32, 61, 61, 32, 88, 77, 76, 95, 80, 65, 82, 83, 69, 82, 95, 83, 89, 83, 84, 69, 77, 95, 76, 73, 84, 69, 82, 65, 76, 10, 0, 0, 0, 0, 0, 0, 0, 0, 72, 80, 80, 58, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 44, 32, 115, 116, 97, 116, 101, 32, 61, 61, 32, 88, 77, 76, 95, 80, 65, 82, 83, 69, 82, 95, 73, 71, 78, 79, 82, 69, 10, 0, 0, 0, 0, 0, 0, 0, 0, 72, 80, 80, 58, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 44, 32, 115, 116, 97, 116, 101, 32, 61, 61, 32, 88, 77, 76, 95, 80, 65, 82, 83, 69, 82, 95, 76, 73, 84, 69, 82, 65, 76, 10, 0, 0, 0, 0, 0, 0, 0, 104, 116, 109, 108, 80, 97, 114, 115, 101, 69, 110, 100, 84, 97, 103, 58, 32, 39, 60, 47, 39, 32, 110, 111, 116, 32, 102, 111, 117, 110, 100, 10, 0, 0, 0, 0, 0, 0, 0, 0, 69, 110, 100, 32, 116, 97, 103, 32, 58, 32, 101, 120, 112, 101, 99, 116, 101, 100, 32, 39, 62, 39, 10, 0, 98, 111, 100, 121, 0, 0, 0, 0, 104, 101, 97, 100, 0, 0, 0, 0, 85, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 101, 110, 100, 32, 116, 97, 103, 32, 58, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 0, 79, 112, 101, 110, 105, 110, 103, 32, 97, 110, 100, 32, 101, 110, 100, 105, 110, 103, 32, 116, 97, 103, 32, 109, 105, 115, 109, 97, 116, 99, 104, 58, 32, 37, 115, 32, 97, 110, 100, 32, 37, 115, 10, 0, 0, 0, 0, 0, 96, 118, 1, 0, 150, 0, 0, 0, 104, 118, 1, 0, 160, 0, 0, 0, 112, 118, 1, 0, 160, 0, 0, 0, 120, 118, 1, 0, 170, 0, 0, 0, 128, 118, 1, 0, 180, 0, 0, 0, 136, 118, 1, 0, 180, 0, 0, 0, 144, 118, 1, 0, 180, 0, 0, 0, 152, 118, 1, 0, 190, 0, 0, 0, 168, 117, 1, 0, 200, 0, 0, 0, 160, 117, 1, 0, 200, 0, 0, 0, 32, 112, 1, 0, 220, 0, 0, 0, 0, 0, 0, 0, 100, 0, 0, 0, 100, 105, 118, 0, 0, 0, 0, 0, 116, 100, 0, 0, 0, 0, 0, 0, 116, 104, 0, 0, 0, 0, 0, 0, 116, 114, 0, 0, 0, 0, 0, 0, 116, 104, 101, 97, 100, 0, 0, 0, 116, 98, 111, 100, 121, 0, 0, 0, 116, 102, 111, 111, 116, 0, 0, 0, 116, 97, 98, 108, 101, 0, 0, 0, 38, 0, 0, 0, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 101, 109, 98, 101, 100, 115, 32, 99, 108, 111, 115, 101, 32, 116, 97, 103, 10, 0, 0, 0, 0, 73, 110, 118, 97, 108, 105, 100, 32, 99, 104, 97, 114, 32, 105, 110, 32, 67, 68, 65, 84, 65, 32, 48, 120, 37, 88, 10, 0, 0, 0, 0, 0, 67, 104, 97, 114, 32, 48, 120, 37, 88, 32, 111, 117, 116, 32, 111, 102, 32, 97, 108, 108, 111, 119, 101, 100, 32, 114, 97, 110, 103, 101, 10, 0, 85, 110, 115, 117, 112, 112, 111, 114, 116, 101, 100, 32, 101, 110, 99, 111, 100, 105, 110, 103, 32, 37, 115, 0, 66, 121, 116, 101, 115, 58, 32, 48, 120, 37, 48, 50, 88, 32, 48, 120, 37, 48, 50, 88, 32, 48, 120, 37, 48, 50, 88, 32, 48, 120, 37, 48, 50, 88, 10, 0, 0, 0, 0, 0, 66, 121, 116, 101, 115, 58, 32, 48, 120, 37, 48, 50, 88, 10, 0, 0, 73, 110, 112, 117, 116, 32, 105, 115, 32, 110, 111, 116, 32, 112, 114, 111, 112, 101, 114, 32, 85, 84, 70, 45, 56, 44, 32, 105, 110, 100, 105, 99, 97, 116, 101, 32, 101, 110, 99, 111, 100, 105, 110, 103, 32, 33, 10, 0, 72, 84, 84, 80, 45, 69, 81, 85, 73, 86, 0, 0, 0, 0, 0, 0, 67, 79, 78, 84, 69, 78, 84, 0, 67, 72, 65, 82, 83, 69, 84, 61, 0, 0, 0, 0, 0, 0, 0, 0, 112, 0, 0, 0, 0, 0, 0, 0, 32, 112, 1, 0, 168, 117, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 109, 101, 116, 97, 0, 0, 0, 0, 108, 105, 110, 107, 0, 0, 0, 0, 116, 105, 116, 108, 101, 0, 0, 0, 98, 97, 115, 101, 0, 0, 0, 0, 110, 111, 102, 114, 97, 109, 101, 115, 0, 0, 0, 0, 0, 0, 0, 0, 102, 114, 97, 109, 101, 0, 0, 0, 102, 114, 97, 109, 101, 115, 101, 116, 0, 0, 0, 0, 0, 0, 0, 0, 45, 47, 47, 87, 51, 67, 47, 47, 68, 84, 68, 32, 72, 84, 77, 76, 32, 52, 46, 48, 49, 47, 47, 69, 78, 0, 0, 0, 0, 0, 0, 0, 45, 47, 47, 87, 51, 67, 47, 47, 68, 84, 68, 32, 72, 84, 77, 76, 32, 52, 47, 47, 69, 78, 0, 0, 32, 121, 1, 0, 40, 121, 1, 0, 48, 121, 1, 0, 56, 121, 1, 0, 64, 121, 1, 0, 72, 121, 1, 0, 80, 121, 1, 0, 88, 121, 1, 0, 96, 121, 1, 0, 160, 117, 1, 0, 112, 121, 1, 0, 120, 121, 1, 0, 128, 121, 1, 0, 136, 121, 1, 0, 144, 121, 1, 0, 152, 121, 1, 0, 160, 121, 1, 0, 168, 121, 1, 0, 96, 118, 1, 0, 176, 121, 1, 0, 184, 121, 1, 0, 192, 121, 1, 0, 200, 121, 1, 0, 208, 121, 1, 0, 216, 121, 1, 0, 224, 121, 1, 0, 232, 121, 1, 0, 240, 121, 1, 0, 248, 121, 1, 0, 0, 122, 1, 0, 8, 122, 1, 0, 16, 122, 1, 0, 24, 122, 1, 0, 32, 122, 1, 0, 40, 122, 1, 0, 48, 122, 1, 0, 232, 119, 1, 0, 56, 122, 1, 0, 72, 122, 1, 0, 176, 119, 1, 0, 80, 122, 1, 0, 88, 122, 1, 0, 96, 122, 1, 0, 104, 122, 1, 0, 112, 122, 1, 0, 120, 122, 1, 0, 128, 122, 1, 0, 136, 122, 1, 0, 104, 118, 1, 0, 112, 118, 1, 0, 144, 122, 1, 0, 152, 122, 1, 0, 160, 122, 1, 0, 0, 0, 0, 0, 97, 0, 0, 0, 0, 0, 0, 0, 97, 98, 98, 114, 0, 0, 0, 0, 97, 99, 114, 111, 110, 121, 109, 0, 97, 100, 100, 114, 101, 115, 115, 0, 97, 112, 112, 108, 101, 116, 0, 0, 98, 0, 0, 0, 0, 0, 0, 0, 98, 100, 111, 0, 0, 0, 0, 0, 98, 105, 103, 0, 0, 0, 0, 0, 98, 108, 111, 99, 107, 113, 117, 111, 116, 101, 0, 0, 0, 0, 0, 0, 98, 117, 116, 116, 111, 110, 0, 0, 99, 97, 112, 116, 105, 111, 110, 0, 99, 101, 110, 116, 101, 114, 0, 0, 99, 105, 116, 101, 0, 0, 0, 0, 99, 111, 100, 101, 0, 0, 0, 0, 100, 100, 0, 0, 0, 0, 0, 0, 100, 101, 108, 0, 0, 0, 0, 0, 100, 102, 110, 0, 0, 0, 0, 0, 100, 116, 0, 0, 0, 0, 0, 0, 101, 109, 0, 0, 0, 0, 0, 0, 102, 111, 110, 116, 0, 0, 0, 0, 102, 111, 114, 109, 0, 0, 0, 0, 104, 49, 0, 0, 0, 0, 0, 0, 104, 50, 0, 0, 0, 0, 0, 0, 104, 51, 0, 0, 0, 0, 0, 0, 104, 52, 0, 0, 0, 0, 0, 0, 104, 53, 0, 0, 0, 0, 0, 0, 104, 54, 0, 0, 0, 0, 0, 0, 105, 0, 0, 0, 0, 0, 0, 0, 105, 102, 114, 97, 109, 101, 0, 0, 105, 110, 115, 0, 0, 0, 0, 0, 107, 98, 100, 0, 0, 0, 0, 0, 108, 97, 98, 101, 108, 0, 0, 0, 108, 101, 103, 101, 110, 100, 0, 0, 108, 105, 0, 0, 0, 0, 0, 0, 110, 111, 115, 99, 114, 105, 112, 116, 0, 0, 0, 0, 0, 0, 0, 0, 111, 98, 106, 101, 99, 116, 0, 0, 112, 114, 101, 0, 0, 0, 0, 0, 113, 0, 0, 0, 0, 0, 0, 0, 115, 0, 0, 0, 0, 0, 0, 0, 115, 97, 109, 112, 0, 0, 0, 0, 115, 109, 97, 108, 108, 0, 0, 0, 115, 112, 97, 110, 0, 0, 0, 0, 115, 116, 114, 105, 107, 101, 0, 0, 115, 116, 114, 111, 110, 103, 0, 0, 116, 116, 0, 0, 0, 0, 0, 0, 117, 0, 0, 0, 0, 0, 0, 0, 118, 97, 114, 0, 0, 0, 0, 0, 104, 116, 109, 108, 73, 110, 105, 116, 80, 97, 114, 115, 101, 114, 67, 116, 120, 116, 58, 32, 111, 117, 116, 32, 111, 102, 32, 109, 101, 109, 111, 114, 121, 10, 0, 0, 0, 0, 0, 0, 104, 116, 109, 108, 80, 97, 114, 115, 101, 68, 111, 99, 84, 121, 112, 101, 68, 101, 99, 108, 32, 58, 32, 110, 111, 32, 68, 79, 67, 84, 89, 80, 69, 32, 110, 97, 109, 101, 32, 33, 10, 0, 0, 0, 0, 0, 0, 0, 68, 79, 67, 84, 89, 80, 69, 32, 105, 109, 112, 114, 111, 112, 101, 114, 108, 121, 32, 116, 101, 114, 109, 105, 110, 97, 116, 101, 100, 10, 0, 0, 83, 112, 97, 99, 101, 32, 114, 101, 113, 117, 105, 114, 101, 100, 32, 97, 102, 116, 101, 114, 32, 39, 83, 89, 83, 84, 69, 77, 39, 10, 0, 0, 104, 116, 109, 108, 80, 97, 114, 115, 101, 69, 120, 116, 101, 114, 110, 97, 108, 73, 68, 58, 32, 83, 89, 83, 84, 69, 77, 44, 32, 110, 111, 32, 85, 82, 73, 10, 0, 0, 0, 0, 83, 112, 97, 99, 101, 32, 114, 101, 113, 117, 105, 114, 101, 100, 32, 97, 102, 116, 101, 114, 32, 39, 80, 85, 66, 76, 73, 67, 39, 10, 0, 0, 104, 116, 109, 108, 80, 97, 114, 115, 101, 69, 120, 116, 101, 114, 110, 97, 108, 73, 68, 58, 32, 80, 85, 66, 76, 73, 67, 44, 32, 110, 111, 32, 80, 117, 98, 108, 105, 99, 32, 73, 100, 101, 110, 116, 105, 102, 105, 101, 114, 10, 0, 0, 0, 0, 0, 0, 85, 110, 102, 105, 110, 105, 115, 104, 101, 100, 32, 80, 117, 98, 105, 100, 76, 105, 116, 101, 114, 97, 108, 10, 0, 0, 0, 0, 0, 0, 0, 0, 80, 117, 98, 105, 100, 76, 105, 116, 101, 114, 97, 108, 32, 34, 32, 111, 114, 32, 39, 32, 101, 120, 112, 101, 99, 116, 101, 100, 10, 0, 0, 0, 85, 110, 102, 105, 110, 105, 115, 104, 101, 100, 32, 83, 121, 115, 116, 101, 109, 76, 105, 116, 101, 114, 97, 108, 10, 0, 0, 0, 0, 0, 0, 0, 32, 111, 114, 32, 39, 32, 101, 120, 112, 101, 99, 116, 101, 100, 10, 0, 80, 97, 114, 115, 101, 80, 73, 58, 32, 80, 73, 32, 37, 115, 32, 115, 112, 97, 99, 101, 32, 101, 120, 112, 101, 99, 116, 101, 100, 10, 0, 0, 80, 97, 114, 115, 101, 80, 73, 58, 32, 80, 73, 32, 37, 115, 32, 110, 101, 118, 101, 114, 32, 101, 110, 100, 32, 46, 46, 46, 10, 0, 0, 0, 80, 73, 32, 105, 115, 32, 110, 111, 116, 32, 115, 116, 97, 114, 116, 101, 100, 32, 99, 111, 114, 114, 101, 99, 116, 108, 121, 0, 0, 0, 0, 0, 98, 117, 102, 102, 101, 114, 32, 97, 108, 108, 111, 99, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 10, 0, 0, 0, 0, 0, 0, 0, 103, 114, 111, 119, 105, 110, 103, 32, 98, 117, 102, 102, 101, 114, 32, 102, 97, 105, 108, 101, 100, 10, 0, 0, 67, 111, 109, 109, 101, 110, 116, 32, 110, 111, 116, 32, 116, 101, 114, 109, 105, 110, 97, 116, 101, 100, 32, 10, 60, 33, 45, 45, 37, 46, 53, 48, 115, 10, 0, 0, 0, 0, 0, 0, 104, 116, 109, 108, 80, 97, 114, 115, 101, 83, 116, 97, 114, 116, 84, 97, 103, 58, 32, 105, 110, 118, 97, 108, 105, 100, 32, 101, 108, 101, 109, 101, 110, 116, 32, 110, 97, 109, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 104, 116, 109, 108, 80, 97, 114, 115, 101, 69, 108, 101, 109, 101, 110, 116, 73, 110, 116, 101, 114, 110, 97, 108, 58, 32, 99, 111, 110, 116, 101, 120, 116, 32, 101, 114, 114, 111, 114, 10, 0, 0, 0, 0, 0, 0, 0, 0, 104, 116, 109, 108, 80, 97, 114, 115, 101, 83, 116, 97, 114, 116, 84, 97, 103, 58, 32, 99, 111, 110, 116, 101, 120, 116, 32, 101, 114, 114, 111, 114, 10, 0, 0, 0, 0, 0, 0, 0, 104, 116, 109, 108, 80, 97, 114, 115, 101, 83, 116, 97, 114, 116, 84, 97, 103, 58, 32, 109, 105, 115, 112, 108, 97, 99, 101, 100, 32, 60, 104, 116, 109, 108, 62, 32, 116, 97, 103, 10, 0, 0, 0, 0, 0, 0, 0, 0, 104, 116, 109, 108, 80, 97, 114, 115, 101, 83, 116, 97, 114, 116, 84, 97, 103, 58, 32, 109, 105, 115, 112, 108, 97, 99, 101, 100, 32, 60, 104, 101, 97, 100, 62, 32, 116, 97, 103, 10, 0, 0, 0, 0, 0, 0, 0, 0, 104, 116, 109, 108, 80, 97, 114, 115, 101, 83, 116, 97, 114, 116, 84, 97, 103, 58, 32, 109, 105, 115, 112, 108, 97, 99, 101, 100, 32, 60, 98, 111, 100, 121, 62, 32, 116, 97, 103, 10, 0, 0, 0, 0, 0, 0, 0, 0, 65, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 114, 101, 100, 101, 102, 105, 110, 101, 100, 10, 0, 104, 116, 109, 108, 80, 97, 114, 115, 101, 83, 116, 97, 114, 116, 84, 97, 103, 58, 32, 112, 114, 111, 98, 108, 101, 109, 32, 112, 97, 114, 115, 105, 110, 103, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 115, 10, 0, 0, 104, 116, 116, 112, 45, 101, 113, 117, 105, 118, 0, 0, 0, 0, 0, 0, 67, 111, 110, 116, 101, 110, 116, 45, 84, 121, 112, 101, 0, 0, 0, 0, 99, 111, 110, 116, 101, 110, 116, 0, 101, 114, 114, 111, 114, 32, 112, 97, 114, 115, 105, 110, 103, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 110, 97, 109, 101, 10, 0, 0, 0, 65, 116, 116, 86, 97, 108, 117, 101, 58, 32, 34, 32, 101, 120, 112, 101, 99, 116, 101, 100, 10, 0, 0, 0, 65, 116, 116, 86, 97, 108, 117, 101, 58, 32, 39, 32, 101, 120, 112, 101, 99, 116, 101, 100, 10, 0, 0, 0, 65, 116, 116, 86, 97, 108, 117, 101, 58, 32, 110, 111, 32, 118, 97, 108, 117, 101, 32, 102, 111, 117, 110, 100, 10, 0, 0, 0, 0, 0, 0, 0, 103, 114, 111, 119, 105, 110, 103, 32, 98, 117, 102, 102, 101, 114, 10, 0, 77, 101, 109, 111, 114, 121, 32, 97, 108, 108, 111, 99, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 32, 58, 32, 37, 115, 10, 0, 0, 77, 101, 109, 111, 114, 121, 32, 97, 108, 108, 111, 99, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 10, 0, 0, 0, 0, 0, 0, 0, 113, 117, 111, 116, 0, 0, 0, 0, 113, 117, 111, 116, 97, 116, 105, 111, 110, 32, 109, 97, 114, 107, 32, 61, 32, 65, 80, 76, 32, 113, 117, 111, 116, 101, 44, 32, 85, 43, 48, 48, 50, 50, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 0, 0, 0, 97, 109, 112, 0, 0, 0, 0, 0, 97, 109, 112, 101, 114, 115, 97, 110, 100, 44, 32, 85, 43, 48, 48, 50, 54, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 0, 0, 0, 0, 97, 112, 111, 115, 0, 0, 0, 0, 115, 105, 110, 103, 108, 101, 32, 113, 117, 111, 116, 101, 0, 0, 0, 0, 108, 116, 0, 0, 0, 0, 0, 0, 108, 101, 115, 115, 45, 116, 104, 97, 110, 32, 115, 105, 103, 110, 44, 32, 85, 43, 48, 48, 51, 67, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 103, 116, 0, 0, 0, 0, 0, 0, 103, 114, 101, 97, 116, 101, 114, 45, 116, 104, 97, 110, 32, 115, 105, 103, 110, 44, 32, 85, 43, 48, 48, 51, 69, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 0, 0, 0, 0, 110, 98, 115, 112, 0, 0, 0, 0, 110, 111, 45, 98, 114, 101, 97, 107, 32, 115, 112, 97, 99, 101, 32, 61, 32, 110, 111, 110, 45, 98, 114, 101, 97, 107, 105, 110, 103, 32, 115, 112, 97, 99, 101, 44, 32, 85, 43, 48, 48, 65, 48, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 0, 0, 105, 101, 120, 99, 108, 0, 0, 0, 105, 110, 118, 101, 114, 116, 101, 100, 32, 101, 120, 99, 108, 97, 109, 97, 116, 105, 111, 110, 32, 109, 97, 114, 107, 44, 32, 85, 43, 48, 48, 65, 49, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 0, 0, 0, 0, 99, 101, 110, 116, 0, 0, 0, 0, 99, 101, 110, 116, 32, 115, 105, 103, 110, 44, 32, 85, 43, 48, 48, 65, 50, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 0, 0, 0, 0, 112, 111, 117, 110, 100, 0, 0, 0, 112, 111, 117, 110, 100, 32, 115, 105, 103, 110, 44, 32, 85, 43, 48, 48, 65, 51, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 0, 0, 0, 99, 117, 114, 114, 101, 110, 0, 0, 99, 117, 114, 114, 101, 110, 99, 121, 32, 115, 105, 103, 110, 44, 32, 85, 43, 48, 48, 65, 52, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 121, 101, 110, 0, 0, 0, 0, 0, 121, 101, 110, 32, 115, 105, 103, 110, 32, 61, 32, 121, 117, 97, 110, 32, 115, 105, 103, 110, 44, 32, 85, 43, 48, 48, 65, 53, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 0, 98, 114, 118, 98, 97, 114, 0, 0, 98, 114, 111, 107, 101, 110, 32, 98, 97, 114, 32, 61, 32, 98, 114, 111, 107, 101, 110, 32, 118, 101, 114, 116, 105, 99, 97, 108, 32, 98, 97, 114, 44, 32, 85, 43, 48, 48, 65, 54, 32, 73, 83, 79, 110, 117, 109, 0, 115, 101, 99, 116, 0, 0, 0, 0, 115, 101, 99, 116, 105, 111, 110, 32, 115, 105, 103, 110, 44, 32, 85, 43, 48, 48, 65, 55, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 0, 117, 109, 108, 0, 0, 0, 0, 0, 100, 105, 97, 101, 114, 101, 115, 105, 115, 32, 61, 32, 115, 112, 97, 99, 105, 110, 103, 32, 100, 105, 97, 101, 114, 101, 115, 105, 115, 44, 32, 85, 43, 48, 48, 65, 56, 32, 73, 83, 79, 100, 105, 97, 0, 0, 0, 0, 99, 111, 112, 121, 0, 0, 0, 0, 99, 111, 112, 121, 114, 105, 103, 104, 116, 32, 115, 105, 103, 110, 44, 32, 85, 43, 48, 48, 65, 57, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 111, 114, 100, 102, 0, 0, 0, 0, 102, 101, 109, 105, 110, 105, 110, 101, 32, 111, 114, 100, 105, 110, 97, 108, 32, 105, 110, 100, 105, 99, 97, 116, 111, 114, 44, 32, 85, 43, 48, 48, 65, 65, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 0, 0, 0, 108, 97, 113, 117, 111, 0, 0, 0, 108, 101, 102, 116, 45, 112, 111, 105, 110, 116, 105, 110, 103, 32, 100, 111, 117, 98, 108, 101, 32, 97, 110, 103, 108, 101, 32, 113, 117, 111, 116, 97, 116, 105, 111, 110, 32, 109, 97, 114, 107, 32, 61, 32, 108, 101, 102, 116, 32, 112, 111, 105, 110, 116, 105, 110, 103, 32, 103, 117, 105, 108, 108, 101, 109, 101, 116, 44, 32, 85, 43, 48, 48, 65, 66, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 0, 0, 110, 111, 116, 0, 0, 0, 0, 0, 110, 111, 116, 32, 115, 105, 103, 110, 44, 32, 85, 43, 48, 48, 65, 67, 32, 73, 83, 79, 110, 117, 109, 0, 115, 104, 121, 0, 0, 0, 0, 0, 115, 111, 102, 116, 32, 104, 121, 112, 104, 101, 110, 32, 61, 32, 100, 105, 115, 99, 114, 101, 116, 105, 111, 110, 97, 114, 121, 32, 104, 121, 112, 104, 101, 110, 44, 32, 85, 43, 48, 48, 65, 68, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 0, 0, 0, 114, 101, 103, 0, 0, 0, 0, 0, 114, 101, 103, 105, 115, 116, 101, 114, 101, 100, 32, 115, 105, 103, 110, 32, 61, 32, 114, 101, 103, 105, 115, 116, 101, 114, 101, 100, 32, 116, 114, 97, 100, 101, 32, 109, 97, 114, 107, 32, 115, 105, 103, 110, 44, 32, 85, 43, 48, 48, 65, 69, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 0, 109, 97, 99, 114, 0, 0, 0, 0, 109, 97, 99, 114, 111, 110, 32, 61, 32, 115, 112, 97, 99, 105, 110, 103, 32, 109, 97, 99, 114, 111, 110, 32, 61, 32, 111, 118, 101, 114, 108, 105, 110, 101, 32, 61, 32, 65, 80, 76, 32, 111, 118, 101, 114, 98, 97, 114, 44, 32, 85, 43, 48, 48, 65, 70, 32, 73, 83, 79, 100, 105, 97, 0, 100, 101, 103, 0, 0, 0, 0, 0, 100, 101, 103, 114, 101, 101, 32, 115, 105, 103, 110, 44, 32, 85, 43, 48, 48, 66, 48, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 0, 0, 112, 108, 117, 115, 109, 110, 0, 0, 112, 108, 117, 115, 45, 109, 105, 110, 117, 115, 32, 115, 105, 103, 110, 32, 61, 32, 112, 108, 117, 115, 45, 111, 114, 45, 109, 105, 110, 117, 115, 32, 115, 105, 103, 110, 44, 32, 85, 43, 48, 48, 66, 49, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 0, 115, 117, 112, 50, 0, 0, 0, 0, 115, 117, 112, 101, 114, 115, 99, 114, 105, 112, 116, 32, 116, 119, 111, 32, 61, 32, 115, 117, 112, 101, 114, 115, 99, 114, 105, 112, 116, 32, 100, 105, 103, 105, 116, 32, 116, 119, 111, 32, 61, 32, 115, 113, 117, 97, 114, 101, 100, 44, 32, 85, 43, 48, 48, 66, 50, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 0, 0, 0, 0, 115, 117, 112, 51, 0, 0, 0, 0, 115, 117, 112, 101, 114, 115, 99, 114, 105, 112, 116, 32, 116, 104, 114, 101, 101, 32, 61, 32, 115, 117, 112, 101, 114, 115, 99, 114, 105, 112, 116, 32, 100, 105, 103, 105, 116, 32, 116, 104, 114, 101, 101, 32, 61, 32, 99, 117, 98, 101, 100, 44, 32, 85, 43, 48, 48, 66, 51, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 0, 0, 97, 99, 117, 116, 101, 0, 0, 0, 97, 99, 117, 116, 101, 32, 97, 99, 99, 101, 110, 116, 32, 61, 32, 115, 112, 97, 99, 105, 110, 103, 32, 97, 99, 117, 116, 101, 44, 32, 85, 43, 48, 48, 66, 52, 32, 73, 83, 79, 100, 105, 97, 0, 0, 0, 0, 0, 109, 105, 99, 114, 111, 0, 0, 0, 109, 105, 99, 114, 111, 32, 115, 105, 103, 110, 44, 32, 85, 43, 48, 48, 66, 53, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 0, 0, 0, 112, 97, 114, 97, 0, 0, 0, 0, 112, 105, 108, 99, 114, 111, 119, 32, 115, 105, 103, 110, 32, 61, 32, 112, 97, 114, 97, 103, 114, 97, 112, 104, 32, 115, 105, 103, 110, 44, 32, 85, 43, 48, 48, 66, 54, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 109, 105, 100, 100, 111, 116, 0, 0, 109, 105, 100, 100, 108, 101, 32, 100, 111, 116, 32, 61, 32, 71, 101, 111, 114, 103, 105, 97, 110, 32, 99, 111, 109, 109, 97, 32, 71, 114, 101, 101, 107, 32, 109, 105, 100, 100, 108, 101, 32, 100, 111, 116, 44, 32, 85, 43, 48, 48, 66, 55, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 0, 99, 101, 100, 105, 108, 0, 0, 0, 99, 101, 100, 105, 108, 108, 97, 32, 61, 32, 115, 112, 97, 99, 105, 110, 103, 32, 99, 101, 100, 105, 108, 108, 97, 44, 32, 85, 43, 48, 48, 66, 56, 32, 73, 83, 79, 100, 105, 97, 0, 0, 0, 0, 0, 0, 0, 0, 115, 117, 112, 49, 0, 0, 0, 0, 115, 117, 112, 101, 114, 115, 99, 114, 105, 112, 116, 32, 111, 110, 101, 32, 61, 32, 115, 117, 112, 101, 114, 115, 99, 114, 105, 112, 116, 32, 100, 105, 103, 105, 116, 32, 111, 110, 101, 44, 32, 85, 43, 48, 48, 66, 57, 32, 73, 83, 79, 110, 117, 109, 0, 0, 111, 114, 100, 109, 0, 0, 0, 0, 109, 97, 115, 99, 117, 108, 105, 110, 101, 32, 111, 114, 100, 105, 110, 97, 108, 32, 105, 110, 100, 105, 99, 97, 116, 111, 114, 44, 32, 85, 43, 48, 48, 66, 65, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 0, 0, 114, 97, 113, 117, 111, 0, 0, 0, 114, 105, 103, 104, 116, 45, 112, 111, 105, 110, 116, 105, 110, 103, 32, 100, 111, 117, 98, 108, 101, 32, 97, 110, 103, 108, 101, 32, 113, 117, 111, 116, 97, 116, 105, 111, 110, 32, 109, 97, 114, 107, 32, 114, 105, 103, 104, 116, 32, 112, 111, 105, 110, 116, 105, 110, 103, 32, 103, 117, 105, 108, 108, 101, 109, 101, 116, 44, 32, 85, 43, 48, 48, 66, 66, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 0, 0, 102, 114, 97, 99, 49, 52, 0, 0, 118, 117, 108, 103, 97, 114, 32, 102, 114, 97, 99, 116, 105, 111, 110, 32, 111, 110, 101, 32, 113, 117, 97, 114, 116, 101, 114, 32, 61, 32, 102, 114, 97, 99, 116, 105, 111, 110, 32, 111, 110, 101, 32, 113, 117, 97, 114, 116, 101, 114, 44, 32, 85, 43, 48, 48, 66, 67, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 0, 0, 0, 102, 114, 97, 99, 49, 50, 0, 0, 118, 117, 108, 103, 97, 114, 32, 102, 114, 97, 99, 116, 105, 111, 110, 32, 111, 110, 101, 32, 104, 97, 108, 102, 32, 61, 32, 102, 114, 97, 99, 116, 105, 111, 110, 32, 111, 110, 101, 32, 104, 97, 108, 102, 44, 32, 85, 43, 48, 48, 66, 68, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 0, 102, 114, 97, 99, 51, 52, 0, 0, 118, 117, 108, 103, 97, 114, 32, 102, 114, 97, 99, 116, 105, 111, 110, 32, 116, 104, 114, 101, 101, 32, 113, 117, 97, 114, 116, 101, 114, 115, 32, 61, 32, 102, 114, 97, 99, 116, 105, 111, 110, 32, 116, 104, 114, 101, 101, 32, 113, 117, 97, 114, 116, 101, 114, 115, 44, 32, 85, 43, 48, 48, 66, 69, 32, 73, 83, 79, 110, 117, 109, 0, 105, 113, 117, 101, 115, 116, 0, 0, 105, 110, 118, 101, 114, 116, 101, 100, 32, 113, 117, 101, 115, 116, 105, 111, 110, 32, 109, 97, 114, 107, 32, 61, 32, 116, 117, 114, 110, 101, 100, 32, 113, 117, 101, 115, 116, 105, 111, 110, 32, 109, 97, 114, 107, 44, 32, 85, 43, 48, 48, 66, 70, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 65, 103, 114, 97, 118, 101, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 65, 32, 119, 105, 116, 104, 32, 103, 114, 97, 118, 101, 32, 61, 32, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 65, 32, 103, 114, 97, 118, 101, 44, 32, 85, 43, 48, 48, 67, 48, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 0, 0, 0, 0, 65, 97, 99, 117, 116, 101, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 65, 32, 119, 105, 116, 104, 32, 97, 99, 117, 116, 101, 44, 32, 85, 43, 48, 48, 67, 49, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 0, 0, 0, 65, 99, 105, 114, 99, 0, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 65, 32, 119, 105, 116, 104, 32, 99, 105, 114, 99, 117, 109, 102, 108, 101, 120, 44, 32, 85, 43, 48, 48, 67, 50, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 65, 116, 105, 108, 100, 101, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 65, 32, 119, 105, 116, 104, 32, 116, 105, 108, 100, 101, 44, 32, 85, 43, 48, 48, 67, 51, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 0, 0, 0, 65, 117, 109, 108, 0, 0, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 65, 32, 119, 105, 116, 104, 32, 100, 105, 97, 101, 114, 101, 115, 105, 115, 44, 32, 85, 43, 48, 48, 67, 52, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 65, 114, 105, 110, 103, 0, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 65, 32, 119, 105, 116, 104, 32, 114, 105, 110, 103, 32, 97, 98, 111, 118, 101, 32, 61, 32, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 65, 32, 114, 105, 110, 103, 44, 32, 85, 43, 48, 48, 67, 53, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 65, 69, 108, 105, 103, 0, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 65, 69, 32, 61, 32, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 105, 103, 97, 116, 117, 114, 101, 32, 65, 69, 44, 32, 85, 43, 48, 48, 67, 54, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 0, 67, 99, 101, 100, 105, 108, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 67, 32, 119, 105, 116, 104, 32, 99, 101, 100, 105, 108, 108, 97, 44, 32, 85, 43, 48, 48, 67, 55, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 0, 69, 103, 114, 97, 118, 101, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 69, 32, 119, 105, 116, 104, 32, 103, 114, 97, 118, 101, 44, 32, 85, 43, 48, 48, 67, 56, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 0, 0, 0, 69, 97, 99, 117, 116, 101, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 69, 32, 119, 105, 116, 104, 32, 97, 99, 117, 116, 101, 44, 32, 85, 43, 48, 48, 67, 57, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 0, 0, 0, 69, 99, 105, 114, 99, 0, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 69, 32, 119, 105, 116, 104, 32, 99, 105, 114, 99, 117, 109, 102, 108, 101, 120, 44, 32, 85, 43, 48, 48, 67, 65, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 69, 117, 109, 108, 0, 0, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 69, 32, 119, 105, 116, 104, 32, 100, 105, 97, 101, 114, 101, 115, 105, 115, 44, 32, 85, 43, 48, 48, 67, 66, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 73, 103, 114, 97, 118, 101, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 73, 32, 119, 105, 116, 104, 32, 103, 114, 97, 118, 101, 44, 32, 85, 43, 48, 48, 67, 67, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 0, 0, 0, 73, 97, 99, 117, 116, 101, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 73, 32, 119, 105, 116, 104, 32, 97, 99, 117, 116, 101, 44, 32, 85, 43, 48, 48, 67, 68, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 0, 0, 0, 73, 99, 105, 114, 99, 0, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 73, 32, 119, 105, 116, 104, 32, 99, 105, 114, 99, 117, 109, 102, 108, 101, 120, 44, 32, 85, 43, 48, 48, 67, 69, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 73, 117, 109, 108, 0, 0, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 73, 32, 119, 105, 116, 104, 32, 100, 105, 97, 101, 114, 101, 115, 105, 115, 44, 32, 85, 43, 48, 48, 67, 70, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 69, 84, 72, 0, 0, 0, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 69, 84, 72, 44, 32, 85, 43, 48, 48, 68, 48, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 0, 0, 0, 0, 78, 116, 105, 108, 100, 101, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 78, 32, 119, 105, 116, 104, 32, 116, 105, 108, 100, 101, 44, 32, 85, 43, 48, 48, 68, 49, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 0, 0, 0, 79, 103, 114, 97, 118, 101, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 79, 32, 119, 105, 116, 104, 32, 103, 114, 97, 118, 101, 44, 32, 85, 43, 48, 48, 68, 50, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 0, 0, 0, 79, 97, 99, 117, 116, 101, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 79, 32, 119, 105, 116, 104, 32, 97, 99, 117, 116, 101, 44, 32, 85, 43, 48, 48, 68, 51, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 0, 0, 0, 79, 99, 105, 114, 99, 0, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 79, 32, 119, 105, 116, 104, 32, 99, 105, 114, 99, 117, 109, 102, 108, 101, 120, 44, 32, 85, 43, 48, 48, 68, 52, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 79, 116, 105, 108, 100, 101, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 79, 32, 119, 105, 116, 104, 32, 116, 105, 108, 100, 101, 44, 32, 85, 43, 48, 48, 68, 53, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 0, 0, 0, 79, 117, 109, 108, 0, 0, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 79, 32, 119, 105, 116, 104, 32, 100, 105, 97, 101, 114, 101, 115, 105, 115, 44, 32, 85, 43, 48, 48, 68, 54, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 116, 105, 109, 101, 115, 0, 0, 0, 109, 117, 108, 116, 105, 112, 108, 105, 99, 97, 116, 105, 111, 110, 32, 115, 105, 103, 110, 44, 32, 85, 43, 48, 48, 68, 55, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 0, 0, 79, 115, 108, 97, 115, 104, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 79, 32, 119, 105, 116, 104, 32, 115, 116, 114, 111, 107, 101, 32, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 79, 32, 115, 108, 97, 115, 104, 44, 32, 85, 43, 48, 48, 68, 56, 32, 73, 83, 79, 108, 97, 116, 49, 0, 85, 103, 114, 97, 118, 101, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 85, 32, 119, 105, 116, 104, 32, 103, 114, 97, 118, 101, 44, 32, 85, 43, 48, 48, 68, 57, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 0, 0, 0, 85, 97, 99, 117, 116, 101, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 85, 32, 119, 105, 116, 104, 32, 97, 99, 117, 116, 101, 44, 32, 85, 43, 48, 48, 68, 65, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 0, 0, 0, 85, 99, 105, 114, 99, 0, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 85, 32, 119, 105, 116, 104, 32, 99, 105, 114, 99, 117, 109, 102, 108, 101, 120, 44, 32, 85, 43, 48, 48, 68, 66, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 85, 117, 109, 108, 0, 0, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 85, 32, 119, 105, 116, 104, 32, 100, 105, 97, 101, 114, 101, 115, 105, 115, 44, 32, 85, 43, 48, 48, 68, 67, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 89, 97, 99, 117, 116, 101, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 89, 32, 119, 105, 116, 104, 32, 97, 99, 117, 116, 101, 44, 32, 85, 43, 48, 48, 68, 68, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 0, 0, 0, 84, 72, 79, 82, 78, 0, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 84, 72, 79, 82, 78, 44, 32, 85, 43, 48, 48, 68, 69, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 0, 0, 115, 122, 108, 105, 103, 0, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 115, 104, 97, 114, 112, 32, 115, 32, 61, 32, 101, 115, 115, 45, 122, 101, 100, 44, 32, 85, 43, 48, 48, 68, 70, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 97, 103, 114, 97, 118, 101, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 97, 32, 119, 105, 116, 104, 32, 103, 114, 97, 118, 101, 32, 61, 32, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 97, 32, 103, 114, 97, 118, 101, 44, 32, 85, 43, 48, 48, 69, 48, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 97, 97, 99, 117, 116, 101, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 97, 32, 119, 105, 116, 104, 32, 97, 99, 117, 116, 101, 44, 32, 85, 43, 48, 48, 69, 49, 32, 73, 83, 79, 108, 97, 116, 49, 0, 97, 99, 105, 114, 99, 0, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 97, 32, 119, 105, 116, 104, 32, 99, 105, 114, 99, 117, 109, 102, 108, 101, 120, 44, 32, 85, 43, 48, 48, 69, 50, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 97, 116, 105, 108, 100, 101, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 97, 32, 119, 105, 116, 104, 32, 116, 105, 108, 100, 101, 44, 32, 85, 43, 48, 48, 69, 51, 32, 73, 83, 79, 108, 97, 116, 49, 0, 97, 117, 109, 108, 0, 0, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 97, 32, 119, 105, 116, 104, 32, 100, 105, 97, 101, 114, 101, 115, 105, 115, 44, 32, 85, 43, 48, 48, 69, 52, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 0, 97, 114, 105, 110, 103, 0, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 97, 32, 119, 105, 116, 104, 32, 114, 105, 110, 103, 32, 97, 98, 111, 118, 101, 32, 61, 32, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 97, 32, 114, 105, 110, 103, 44, 32, 85, 43, 48, 48, 69, 53, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 0, 0, 0, 0, 97, 101, 108, 105, 103, 0, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 97, 101, 32, 61, 32, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 105, 103, 97, 116, 117, 114, 101, 32, 97, 101, 44, 32, 85, 43, 48, 48, 69, 54, 32, 73, 83, 79, 108, 97, 116, 49, 0, 99, 99, 101, 100, 105, 108, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 99, 32, 119, 105, 116, 104, 32, 99, 101, 100, 105, 108, 108, 97, 44, 32, 85, 43, 48, 48, 69, 55, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 0, 0, 0, 101, 103, 114, 97, 118, 101, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 101, 32, 119, 105, 116, 104, 32, 103, 114, 97, 118, 101, 44, 32, 85, 43, 48, 48, 69, 56, 32, 73, 83, 79, 108, 97, 116, 49, 0, 101, 97, 99, 117, 116, 101, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 101, 32, 119, 105, 116, 104, 32, 97, 99, 117, 116, 101, 44, 32, 85, 43, 48, 48, 69, 57, 32, 73, 83, 79, 108, 97, 116, 49, 0, 101, 99, 105, 114, 99, 0, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 101, 32, 119, 105, 116, 104, 32, 99, 105, 114, 99, 117, 109, 102, 108, 101, 120, 44, 32, 85, 43, 48, 48, 69, 65, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 101, 117, 109, 108, 0, 0, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 101, 32, 119, 105, 116, 104, 32, 100, 105, 97, 101, 114, 101, 115, 105, 115, 44, 32, 85, 43, 48, 48, 69, 66, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 0, 105, 103, 114, 97, 118, 101, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 105, 32, 119, 105, 116, 104, 32, 103, 114, 97, 118, 101, 44, 32, 85, 43, 48, 48, 69, 67, 32, 73, 83, 79, 108, 97, 116, 49, 0, 105, 97, 99, 117, 116, 101, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 105, 32, 119, 105, 116, 104, 32, 97, 99, 117, 116, 101, 44, 32, 85, 43, 48, 48, 69, 68, 32, 73, 83, 79, 108, 97, 116, 49, 0, 105, 99, 105, 114, 99, 0, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 105, 32, 119, 105, 116, 104, 32, 99, 105, 114, 99, 117, 109, 102, 108, 101, 120, 44, 32, 85, 43, 48, 48, 69, 69, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 105, 117, 109, 108, 0, 0, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 105, 32, 119, 105, 116, 104, 32, 100, 105, 97, 101, 114, 101, 115, 105, 115, 44, 32, 85, 43, 48, 48, 69, 70, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 0, 101, 116, 104, 0, 0, 0, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 101, 116, 104, 44, 32, 85, 43, 48, 48, 70, 48, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 110, 116, 105, 108, 100, 101, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 110, 32, 119, 105, 116, 104, 32, 116, 105, 108, 100, 101, 44, 32, 85, 43, 48, 48, 70, 49, 32, 73, 83, 79, 108, 97, 116, 49, 0, 111, 103, 114, 97, 118, 101, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 111, 32, 119, 105, 116, 104, 32, 103, 114, 97, 118, 101, 44, 32, 85, 43, 48, 48, 70, 50, 32, 73, 83, 79, 108, 97, 116, 49, 0, 111, 97, 99, 117, 116, 101, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 111, 32, 119, 105, 116, 104, 32, 97, 99, 117, 116, 101, 44, 32, 85, 43, 48, 48, 70, 51, 32, 73, 83, 79, 108, 97, 116, 49, 0, 111, 99, 105, 114, 99, 0, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 111, 32, 119, 105, 116, 104, 32, 99, 105, 114, 99, 117, 109, 102, 108, 101, 120, 44, 32, 85, 43, 48, 48, 70, 52, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 111, 116, 105, 108, 100, 101, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 111, 32, 119, 105, 116, 104, 32, 116, 105, 108, 100, 101, 44, 32, 85, 43, 48, 48, 70, 53, 32, 73, 83, 79, 108, 97, 116, 49, 0, 111, 117, 109, 108, 0, 0, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 111, 32, 119, 105, 116, 104, 32, 100, 105, 97, 101, 114, 101, 115, 105, 115, 44, 32, 85, 43, 48, 48, 70, 54, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 0, 100, 105, 118, 105, 100, 101, 0, 0, 100, 105, 118, 105, 115, 105, 111, 110, 32, 115, 105, 103, 110, 44, 32, 85, 43, 48, 48, 70, 55, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 111, 115, 108, 97, 115, 104, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 111, 32, 119, 105, 116, 104, 32, 115, 116, 114, 111, 107, 101, 44, 32, 61, 32, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 111, 32, 115, 108, 97, 115, 104, 44, 32, 85, 43, 48, 48, 70, 56, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 117, 103, 114, 97, 118, 101, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 117, 32, 119, 105, 116, 104, 32, 103, 114, 97, 118, 101, 44, 32, 85, 43, 48, 48, 70, 57, 32, 73, 83, 79, 108, 97, 116, 49, 0, 117, 97, 99, 117, 116, 101, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 117, 32, 119, 105, 116, 104, 32, 97, 99, 117, 116, 101, 44, 32, 85, 43, 48, 48, 70, 65, 32, 73, 83, 79, 108, 97, 116, 49, 0, 117, 99, 105, 114, 99, 0, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 117, 32, 119, 105, 116, 104, 32, 99, 105, 114, 99, 117, 109, 102, 108, 101, 120, 44, 32, 85, 43, 48, 48, 70, 66, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 117, 117, 109, 108, 0, 0, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 117, 32, 119, 105, 116, 104, 32, 100, 105, 97, 101, 114, 101, 115, 105, 115, 44, 32, 85, 43, 48, 48, 70, 67, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 0, 121, 97, 99, 117, 116, 101, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 121, 32, 119, 105, 116, 104, 32, 97, 99, 117, 116, 101, 44, 32, 85, 43, 48, 48, 70, 68, 32, 73, 83, 79, 108, 97, 116, 49, 0, 116, 104, 111, 114, 110, 0, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 116, 104, 111, 114, 110, 32, 119, 105, 116, 104, 44, 32, 85, 43, 48, 48, 70, 69, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 121, 117, 109, 108, 0, 0, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 121, 32, 119, 105, 116, 104, 32, 100, 105, 97, 101, 114, 101, 115, 105, 115, 44, 32, 85, 43, 48, 48, 70, 70, 32, 73, 83, 79, 108, 97, 116, 49, 0, 0, 0, 0, 0, 79, 69, 108, 105, 103, 0, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 105, 103, 97, 116, 117, 114, 101, 32, 79, 69, 44, 32, 85, 43, 48, 49, 53, 50, 32, 73, 83, 79, 108, 97, 116, 50, 0, 0, 0, 0, 0, 0, 0, 111, 101, 108, 105, 103, 0, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 105, 103, 97, 116, 117, 114, 101, 32, 111, 101, 44, 32, 85, 43, 48, 49, 53, 51, 32, 73, 83, 79, 108, 97, 116, 50, 0, 83, 99, 97, 114, 111, 110, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 83, 32, 119, 105, 116, 104, 32, 99, 97, 114, 111, 110, 44, 32, 85, 43, 48, 49, 54, 48, 32, 73, 83, 79, 108, 97, 116, 50, 0, 0, 0, 0, 0, 0, 0, 115, 99, 97, 114, 111, 110, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 115, 32, 119, 105, 116, 104, 32, 99, 97, 114, 111, 110, 44, 32, 85, 43, 48, 49, 54, 49, 32, 73, 83, 79, 108, 97, 116, 50, 0, 89, 117, 109, 108, 0, 0, 0, 0, 108, 97, 116, 105, 110, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 89, 32, 119, 105, 116, 104, 32, 100, 105, 97, 101, 114, 101, 115, 105, 115, 44, 32, 85, 43, 48, 49, 55, 56, 32, 73, 83, 79, 108, 97, 116, 50, 0, 0, 0, 102, 110, 111, 102, 0, 0, 0, 0, 108, 97, 116, 105, 110, 32, 115, 109, 97, 108, 108, 32, 102, 32, 119, 105, 116, 104, 32, 104, 111, 111, 107, 32, 61, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 61, 32, 102, 108, 111, 114, 105, 110, 44, 32, 85, 43, 48, 49, 57, 50, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 0, 0, 0, 99, 105, 114, 99, 0, 0, 0, 0, 109, 111, 100, 105, 102, 105, 101, 114, 32, 108, 101, 116, 116, 101, 114, 32, 99, 105, 114, 99, 117, 109, 102, 108, 101, 120, 32, 97, 99, 99, 101, 110, 116, 44, 32, 85, 43, 48, 50, 67, 54, 32, 73, 83, 79, 112, 117, 98, 0, 0, 0, 0, 0, 0, 0, 0, 116, 105, 108, 100, 101, 0, 0, 0, 115, 109, 97, 108, 108, 32, 116, 105, 108, 100, 101, 44, 32, 85, 43, 48, 50, 68, 67, 32, 73, 83, 79, 100, 105, 97, 0, 0, 0, 0, 0, 0, 65, 108, 112, 104, 97, 0, 0, 0, 103, 114, 101, 101, 107, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 97, 108, 112, 104, 97, 44, 32, 85, 43, 48, 51, 57, 49, 0, 0, 0, 0, 0, 0, 66, 101, 116, 97, 0, 0, 0, 0, 103, 114, 101, 101, 107, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 98, 101, 116, 97, 44, 32, 85, 43, 48, 51, 57, 50, 0, 0, 0, 0, 0, 0, 0, 71, 97, 109, 109, 97, 0, 0, 0, 103, 114, 101, 101, 107, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 103, 97, 109, 109, 97, 44, 32, 85, 43, 48, 51, 57, 51, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 0, 0, 0, 0, 68, 101, 108, 116, 97, 0, 0, 0, 103, 114, 101, 101, 107, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 100, 101, 108, 116, 97, 44, 32, 85, 43, 48, 51, 57, 52, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 0, 0, 0, 0, 69, 112, 115, 105, 108, 111, 110, 0, 103, 114, 101, 101, 107, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 101, 112, 115, 105, 108, 111, 110, 44, 32, 85, 43, 48, 51, 57, 53, 0, 0, 0, 0, 90, 101, 116, 97, 0, 0, 0, 0, 103, 114, 101, 101, 107, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 122, 101, 116, 97, 44, 32, 85, 43, 48, 51, 57, 54, 0, 0, 0, 0, 0, 0, 0, 69, 116, 97, 0, 0, 0, 0, 0, 103, 114, 101, 101, 107, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 101, 116, 97, 44, 32, 85, 43, 48, 51, 57, 55, 0, 0, 0, 0, 0, 0, 0, 0, 84, 104, 101, 116, 97, 0, 0, 0, 103, 114, 101, 101, 107, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 116, 104, 101, 116, 97, 44, 32, 85, 43, 48, 51, 57, 56, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 0, 0, 0, 0, 73, 111, 116, 97, 0, 0, 0, 0, 103, 114, 101, 101, 107, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 105, 111, 116, 97, 44, 32, 85, 43, 48, 51, 57, 57, 0, 0, 0, 0, 0, 0, 0, 75, 97, 112, 112, 97, 0, 0, 0, 103, 114, 101, 101, 107, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 107, 97, 112, 112, 97, 44, 32, 85, 43, 48, 51, 57, 65, 0, 0, 0, 0, 0, 0, 76, 97, 109, 98, 100, 97, 0, 0, 103, 114, 101, 101, 107, 32, 99, 97], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 95088);
	        allocate([112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 108, 97, 109, 98, 100, 97, 44, 32, 85, 43, 48, 51, 57, 66, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 0, 0, 0, 77, 117, 0, 0, 0, 0, 0, 0, 103, 114, 101, 101, 107, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 109, 117, 44, 32, 85, 43, 48, 51, 57, 67, 0, 78, 117, 0, 0, 0, 0, 0, 0, 103, 114, 101, 101, 107, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 110, 117, 44, 32, 85, 43, 48, 51, 57, 68, 0, 88, 105, 0, 0, 0, 0, 0, 0, 103, 114, 101, 101, 107, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 120, 105, 44, 32, 85, 43, 48, 51, 57, 69, 32, 73, 83, 79, 103, 114, 107, 51, 0, 79, 109, 105, 99, 114, 111, 110, 0, 103, 114, 101, 101, 107, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 111, 109, 105, 99, 114, 111, 110, 44, 32, 85, 43, 48, 51, 57, 70, 0, 0, 0, 0, 80, 105, 0, 0, 0, 0, 0, 0, 103, 114, 101, 101, 107, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 112, 105, 44, 32, 85, 43, 48, 51, 65, 48, 32, 73, 83, 79, 103, 114, 107, 51, 0, 82, 104, 111, 0, 0, 0, 0, 0, 103, 114, 101, 101, 107, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 114, 104, 111, 44, 32, 85, 43, 48, 51, 65, 49, 0, 0, 0, 0, 0, 0, 0, 0, 83, 105, 103, 109, 97, 0, 0, 0, 103, 114, 101, 101, 107, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 115, 105, 103, 109, 97, 44, 32, 85, 43, 48, 51, 65, 51, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 0, 0, 0, 0, 84, 97, 117, 0, 0, 0, 0, 0, 103, 114, 101, 101, 107, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 116, 97, 117, 44, 32, 85, 43, 48, 51, 65, 52, 0, 0, 0, 0, 0, 0, 0, 0, 85, 112, 115, 105, 108, 111, 110, 0, 103, 114, 101, 101, 107, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 117, 112, 115, 105, 108, 111, 110, 44, 32, 85, 43, 48, 51, 65, 53, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 0, 0, 80, 104, 105, 0, 0, 0, 0, 0, 103, 114, 101, 101, 107, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 112, 104, 105, 44, 32, 85, 43, 48, 51, 65, 54, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 0, 0, 0, 0, 0, 0, 67, 104, 105, 0, 0, 0, 0, 0, 103, 114, 101, 101, 107, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 99, 104, 105, 44, 32, 85, 43, 48, 51, 65, 55, 0, 0, 0, 0, 0, 0, 0, 0, 80, 115, 105, 0, 0, 0, 0, 0, 103, 114, 101, 101, 107, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 112, 115, 105, 44, 32, 85, 43, 48, 51, 65, 56, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 0, 0, 0, 0, 0, 0, 79, 109, 101, 103, 97, 0, 0, 0, 103, 114, 101, 101, 107, 32, 99, 97, 112, 105, 116, 97, 108, 32, 108, 101, 116, 116, 101, 114, 32, 111, 109, 101, 103, 97, 44, 32, 85, 43, 48, 51, 65, 57, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 0, 0, 0, 0, 97, 108, 112, 104, 97, 0, 0, 0, 103, 114, 101, 101, 107, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 97, 108, 112, 104, 97, 44, 32, 85, 43, 48, 51, 66, 49, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 0, 0, 0, 0, 0, 0, 98, 101, 116, 97, 0, 0, 0, 0, 103, 114, 101, 101, 107, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 98, 101, 116, 97, 44, 32, 85, 43, 48, 51, 66, 50, 32, 73, 83, 79, 103, 114, 107, 51, 0, 103, 97, 109, 109, 97, 0, 0, 0, 103, 114, 101, 101, 107, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 103, 97, 109, 109, 97, 44, 32, 85, 43, 48, 51, 66, 51, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 0, 0, 0, 0, 0, 0, 100, 101, 108, 116, 97, 0, 0, 0, 103, 114, 101, 101, 107, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 100, 101, 108, 116, 97, 44, 32, 85, 43, 48, 51, 66, 52, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 0, 0, 0, 0, 0, 0, 101, 112, 115, 105, 108, 111, 110, 0, 103, 114, 101, 101, 107, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 101, 112, 115, 105, 108, 111, 110, 44, 32, 85, 43, 48, 51, 66, 53, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 0, 0, 0, 0, 122, 101, 116, 97, 0, 0, 0, 0, 103, 114, 101, 101, 107, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 122, 101, 116, 97, 44, 32, 85, 43, 48, 51, 66, 54, 32, 73, 83, 79, 103, 114, 107, 51, 0, 101, 116, 97, 0, 0, 0, 0, 0, 103, 114, 101, 101, 107, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 101, 116, 97, 44, 32, 85, 43, 48, 51, 66, 55, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 116, 104, 101, 116, 97, 0, 0, 0, 103, 114, 101, 101, 107, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 116, 104, 101, 116, 97, 44, 32, 85, 43, 48, 51, 66, 56, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 0, 0, 0, 0, 0, 0, 105, 111, 116, 97, 0, 0, 0, 0, 103, 114, 101, 101, 107, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 105, 111, 116, 97, 44, 32, 85, 43, 48, 51, 66, 57, 32, 73, 83, 79, 103, 114, 107, 51, 0, 107, 97, 112, 112, 97, 0, 0, 0, 103, 114, 101, 101, 107, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 107, 97, 112, 112, 97, 44, 32, 85, 43, 48, 51, 66, 65, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 0, 0, 0, 0, 0, 0, 108, 97, 109, 98, 100, 97, 0, 0, 103, 114, 101, 101, 107, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 108, 97, 109, 98, 100, 97, 44, 32, 85, 43, 48, 51, 66, 66, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 0, 0, 0, 0, 0, 109, 117, 0, 0, 0, 0, 0, 0, 103, 114, 101, 101, 107, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 109, 117, 44, 32, 85, 43, 48, 51, 66, 67, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 0, 110, 117, 0, 0, 0, 0, 0, 0, 103, 114, 101, 101, 107, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 110, 117, 44, 32, 85, 43, 48, 51, 66, 68, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 0, 120, 105, 0, 0, 0, 0, 0, 0, 103, 114, 101, 101, 107, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 120, 105, 44, 32, 85, 43, 48, 51, 66, 69, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 0, 111, 109, 105, 99, 114, 111, 110, 0, 103, 114, 101, 101, 107, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 111, 109, 105, 99, 114, 111, 110, 44, 32, 85, 43, 48, 51, 66, 70, 32, 78, 69, 87, 0, 0, 112, 105, 0, 0, 0, 0, 0, 0, 103, 114, 101, 101, 107, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 112, 105, 44, 32, 85, 43, 48, 51, 67, 48, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 0, 114, 104, 111, 0, 0, 0, 0, 0, 103, 114, 101, 101, 107, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 114, 104, 111, 44, 32, 85, 43, 48, 51, 67, 49, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 115, 105, 103, 109, 97, 102, 0, 0, 103, 114, 101, 101, 107, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 102, 105, 110, 97, 108, 32, 115, 105, 103, 109, 97, 44, 32, 85, 43, 48, 51, 67, 50, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 115, 105, 103, 109, 97, 0, 0, 0, 103, 114, 101, 101, 107, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 115, 105, 103, 109, 97, 44, 32, 85, 43, 48, 51, 67, 51, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 0, 0, 0, 0, 0, 0, 116, 97, 117, 0, 0, 0, 0, 0, 103, 114, 101, 101, 107, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 116, 97, 117, 44, 32, 85, 43, 48, 51, 67, 52, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 117, 112, 115, 105, 108, 111, 110, 0, 103, 114, 101, 101, 107, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 117, 112, 115, 105, 108, 111, 110, 44, 32, 85, 43, 48, 51, 67, 53, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 0, 0, 0, 0, 112, 104, 105, 0, 0, 0, 0, 0, 103, 114, 101, 101, 107, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 112, 104, 105, 44, 32, 85, 43, 48, 51, 67, 54, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 99, 104, 105, 0, 0, 0, 0, 0, 103, 114, 101, 101, 107, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 99, 104, 105, 44, 32, 85, 43, 48, 51, 67, 55, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 112, 115, 105, 0, 0, 0, 0, 0, 103, 114, 101, 101, 107, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 112, 115, 105, 44, 32, 85, 43, 48, 51, 67, 56, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 111, 109, 101, 103, 97, 0, 0, 0, 103, 114, 101, 101, 107, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 111, 109, 101, 103, 97, 44, 32, 85, 43, 48, 51, 67, 57, 32, 73, 83, 79, 103, 114, 107, 51, 0, 0, 0, 0, 0, 0, 0, 0, 116, 104, 101, 116, 97, 115, 121, 109, 0, 0, 0, 0, 0, 0, 0, 0, 103, 114, 101, 101, 107, 32, 115, 109, 97, 108, 108, 32, 108, 101, 116, 116, 101, 114, 32, 116, 104, 101, 116, 97, 32, 115, 121, 109, 98, 111, 108, 44, 32, 85, 43, 48, 51, 68, 49, 32, 78, 69, 87, 0, 0, 0, 0, 0, 117, 112, 115, 105, 104, 0, 0, 0, 103, 114, 101, 101, 107, 32, 117, 112, 115, 105, 108, 111, 110, 32, 119, 105, 116, 104, 32, 104, 111, 111, 107, 32, 115, 121, 109, 98, 111, 108, 44, 32, 85, 43, 48, 51, 68, 50, 32, 78, 69, 87, 0, 0, 0, 0, 0, 0, 112, 105, 118, 0, 0, 0, 0, 0, 103, 114, 101, 101, 107, 32, 112, 105, 32, 115, 121, 109, 98, 111, 108, 44, 32, 85, 43, 48, 51, 68, 54, 32, 73, 83, 79, 103, 114, 107, 51, 0, 101, 110, 115, 112, 0, 0, 0, 0, 101, 110, 32, 115, 112, 97, 99, 101, 44, 32, 85, 43, 50, 48, 48, 50, 32, 73, 83, 79, 112, 117, 98, 0, 101, 109, 115, 112, 0, 0, 0, 0, 101, 109, 32, 115, 112, 97, 99, 101, 44, 32, 85, 43, 50, 48, 48, 51, 32, 73, 83, 79, 112, 117, 98, 0, 116, 104, 105, 110, 115, 112, 0, 0, 116, 104, 105, 110, 32, 115, 112, 97, 99, 101, 44, 32, 85, 43, 50, 48, 48, 57, 32, 73, 83, 79, 112, 117, 98, 0, 0, 0, 0, 0, 0, 0, 122, 119, 110, 106, 0, 0, 0, 0, 122, 101, 114, 111, 32, 119, 105, 100, 116, 104, 32, 110, 111, 110, 45, 106, 111, 105, 110, 101, 114, 44, 32, 85, 43, 50, 48, 48, 67, 32, 78, 69, 87, 32, 82, 70, 67, 32, 50, 48, 55, 48, 0, 0, 0, 0, 0, 0, 122, 119, 106, 0, 0, 0, 0, 0, 122, 101, 114, 111, 32, 119, 105, 100, 116, 104, 32, 106, 111, 105, 110, 101, 114, 44, 32, 85, 43, 50, 48, 48, 68, 32, 78, 69, 87, 32, 82, 70, 67, 32, 50, 48, 55, 48, 0, 0, 108, 114, 109, 0, 0, 0, 0, 0, 108, 101, 102, 116, 45, 116, 111, 45, 114, 105, 103, 104, 116, 32, 109, 97, 114, 107, 44, 32, 85, 43, 50, 48, 48, 69, 32, 78, 69, 87, 32, 82, 70, 67, 32, 50, 48, 55, 48, 0, 114, 108, 109, 0, 0, 0, 0, 0, 114, 105, 103, 104, 116, 45, 116, 111, 45, 108, 101, 102, 116, 32, 109, 97, 114, 107, 44, 32, 85, 43, 50, 48, 48, 70, 32, 78, 69, 87, 32, 82, 70, 67, 32, 50, 48, 55, 48, 0, 110, 100, 97, 115, 104, 0, 0, 0, 101, 110, 32, 100, 97, 115, 104, 44, 32, 85, 43, 50, 48, 49, 51, 32, 73, 83, 79, 112, 117, 98, 0, 0, 109, 100, 97, 115, 104, 0, 0, 0, 101, 109, 32, 100, 97, 115, 104, 44, 32, 85, 43, 50, 48, 49, 52, 32, 73, 83, 79, 112, 117, 98, 0, 0, 108, 115, 113, 117, 111, 0, 0, 0, 108, 101, 102, 116, 32, 115, 105, 110, 103, 108, 101, 32, 113, 117, 111, 116, 97, 116, 105, 111, 110, 32, 109, 97, 114, 107, 44, 32, 85, 43, 50, 48, 49, 56, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 0, 0, 0, 114, 115, 113, 117, 111, 0, 0, 0, 114, 105, 103, 104, 116, 32, 115, 105, 110, 103, 108, 101, 32, 113, 117, 111, 116, 97, 116, 105, 111, 110, 32, 109, 97, 114, 107, 44, 32, 85, 43, 50, 48, 49, 57, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 0, 0, 115, 98, 113, 117, 111, 0, 0, 0, 115, 105, 110, 103, 108, 101, 32, 108, 111, 119, 45, 57, 32, 113, 117, 111, 116, 97, 116, 105, 111, 110, 32, 109, 97, 114, 107, 44, 32, 85, 43, 50, 48, 49, 65, 32, 78, 69, 87, 0, 108, 100, 113, 117, 111, 0, 0, 0, 108, 101, 102, 116, 32, 100, 111, 117, 98, 108, 101, 32, 113, 117, 111, 116, 97, 116, 105, 111, 110, 32, 109, 97, 114, 107, 44, 32, 85, 43, 50, 48, 49, 67, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 0, 0, 0, 114, 100, 113, 117, 111, 0, 0, 0, 114, 105, 103, 104, 116, 32, 100, 111, 117, 98, 108, 101, 32, 113, 117, 111, 116, 97, 116, 105, 111, 110, 32, 109, 97, 114, 107, 44, 32, 85, 43, 50, 48, 49, 68, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 0, 0, 98, 100, 113, 117, 111, 0, 0, 0, 100, 111, 117, 98, 108, 101, 32, 108, 111, 119, 45, 57, 32, 113, 117, 111, 116, 97, 116, 105, 111, 110, 32, 109, 97, 114, 107, 44, 32, 85, 43, 50, 48, 49, 69, 32, 78, 69, 87, 0, 100, 97, 103, 103, 101, 114, 0, 0, 100, 97, 103, 103, 101, 114, 44, 32, 85, 43, 50, 48, 50, 48, 32, 73, 83, 79, 112, 117, 98, 0, 0, 0, 68, 97, 103, 103, 101, 114, 0, 0, 100, 111, 117, 98, 108, 101, 32, 100, 97, 103, 103, 101, 114, 44, 32, 85, 43, 50, 48, 50, 49, 32, 73, 83, 79, 112, 117, 98, 0, 0, 0, 0, 98, 117, 108, 108, 0, 0, 0, 0, 98, 117, 108, 108, 101, 116, 32, 61, 32, 98, 108, 97, 99, 107, 32, 115, 109, 97, 108, 108, 32, 99, 105, 114, 99, 108, 101, 44, 32, 85, 43, 50, 48, 50, 50, 32, 73, 83, 79, 112, 117, 98, 0, 0, 0, 0, 0, 0, 104, 101, 108, 108, 105, 112, 0, 0, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 32, 101, 108, 108, 105, 112, 115, 105, 115, 32, 61, 32, 116, 104, 114, 101, 101, 32, 100, 111, 116, 32, 108, 101, 97, 100, 101, 114, 44, 32, 85, 43, 50, 48, 50, 54, 32, 73, 83, 79, 112, 117, 98, 0, 0, 0, 112, 101, 114, 109, 105, 108, 0, 0, 112, 101, 114, 32, 109, 105, 108, 108, 101, 32, 115, 105, 103, 110, 44, 32, 85, 43, 50, 48, 51, 48, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 112, 114, 105, 109, 101, 0, 0, 0, 112, 114, 105, 109, 101, 32, 61, 32, 109, 105, 110, 117, 116, 101, 115, 32, 61, 32, 102, 101, 101, 116, 44, 32, 85, 43, 50, 48, 51, 50, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 80, 114, 105, 109, 101, 0, 0, 0, 100, 111, 117, 98, 108, 101, 32, 112, 114, 105, 109, 101, 32, 61, 32, 115, 101, 99, 111, 110, 100, 115, 32, 61, 32, 105, 110, 99, 104, 101, 115, 44, 32, 85, 43, 50, 48, 51, 51, 32, 73, 83, 79, 116, 101, 99, 104, 0, 108, 115, 97, 113, 117, 111, 0, 0, 115, 105, 110, 103, 108, 101, 32, 108, 101, 102, 116, 45, 112, 111, 105, 110, 116, 105, 110, 103, 32, 97, 110, 103, 108, 101, 32, 113, 117, 111, 116, 97, 116, 105, 111, 110, 32, 109, 97, 114, 107, 44, 32, 85, 43, 50, 48, 51, 57, 32, 73, 83, 79, 32, 112, 114, 111, 112, 111, 115, 101, 100, 0, 0, 114, 115, 97, 113, 117, 111, 0, 0, 115, 105, 110, 103, 108, 101, 32, 114, 105, 103, 104, 116, 45, 112, 111, 105, 110, 116, 105, 110, 103, 32, 97, 110, 103, 108, 101, 32, 113, 117, 111, 116, 97, 116, 105, 111, 110, 32, 109, 97, 114, 107, 44, 32, 85, 43, 50, 48, 51, 65, 32, 73, 83, 79, 32, 112, 114, 111, 112, 111, 115, 101, 100, 0, 111, 108, 105, 110, 101, 0, 0, 0, 111, 118, 101, 114, 108, 105, 110, 101, 32, 61, 32, 115, 112, 97, 99, 105, 110, 103, 32, 111, 118, 101, 114, 115, 99, 111, 114, 101, 44, 32, 85, 43, 50, 48, 51, 69, 32, 78, 69, 87, 0, 0, 0, 0, 0, 0, 0, 0, 102, 114, 97, 115, 108, 0, 0, 0, 102, 114, 97, 99, 116, 105, 111, 110, 32, 115, 108, 97, 115, 104, 44, 32, 85, 43, 50, 48, 52, 52, 32, 78, 69, 87, 0, 0, 0, 0, 0, 0, 101, 117, 114, 111, 0, 0, 0, 0, 101, 117, 114, 111, 32, 115, 105, 103, 110, 44, 32, 85, 43, 50, 48, 65, 67, 32, 78, 69, 87, 0, 0, 0, 105, 109, 97, 103, 101, 0, 0, 0, 98, 108, 97, 99, 107, 108, 101, 116, 116, 101, 114, 32, 99, 97, 112, 105, 116, 97, 108, 32, 73, 32, 61, 32, 105, 109, 97, 103, 105, 110, 97, 114, 121, 32, 112, 97, 114, 116, 44, 32, 85, 43, 50, 49, 49, 49, 32, 73, 83, 79, 97, 109, 115, 111, 0, 0, 119, 101, 105, 101, 114, 112, 0, 0, 115, 99, 114, 105, 112, 116, 32, 99, 97, 112, 105, 116, 97, 108, 32, 80, 32, 61, 32, 112, 111, 119, 101, 114, 32, 115, 101, 116, 32, 61, 32, 87, 101, 105, 101, 114, 115, 116, 114, 97, 115, 115, 32, 112, 44, 32, 85, 43, 50, 49, 49, 56, 32, 73, 83, 79, 97, 109, 115, 111, 0, 0, 0, 0, 114, 101, 97, 108, 0, 0, 0, 0, 98, 108, 97, 99, 107, 108, 101, 116, 116, 101, 114, 32, 99, 97, 112, 105, 116, 97, 108, 32, 82, 32, 61, 32, 114, 101, 97, 108, 32, 112, 97, 114, 116, 32, 115, 121, 109, 98, 111, 108, 44, 32, 85, 43, 50, 49, 49, 67, 32, 73, 83, 79, 97, 109, 115, 111, 0, 0, 0, 0, 0, 0, 0, 0, 116, 114, 97, 100, 101, 0, 0, 0, 116, 114, 97, 100, 101, 32, 109, 97, 114, 107, 32, 115, 105, 103, 110, 44, 32, 85, 43, 50, 49, 50, 50, 32, 73, 83, 79, 110, 117, 109, 0, 0, 97, 108, 101, 102, 115, 121, 109, 0, 97, 108, 101, 102, 32, 115, 121, 109, 98, 111, 108, 32, 61, 32, 102, 105, 114, 115, 116, 32, 116, 114, 97, 110, 115, 102, 105, 110, 105, 116, 101, 32, 99, 97, 114, 100, 105, 110, 97, 108, 44, 32, 85, 43, 50, 49, 51, 53, 32, 78, 69, 87, 0, 0, 0, 0, 108, 97, 114, 114, 0, 0, 0, 0, 108, 101, 102, 116, 119, 97, 114, 100, 115, 32, 97, 114, 114, 111, 119, 44, 32, 85, 43, 50, 49, 57, 48, 32, 73, 83, 79, 110, 117, 109, 0, 0, 117, 97, 114, 114, 0, 0, 0, 0, 117, 112, 119, 97, 114, 100, 115, 32, 97, 114, 114, 111, 119, 44, 32, 85, 43, 50, 49, 57, 49, 32, 73, 83, 79, 110, 117, 109, 0, 0, 0, 0, 114, 97, 114, 114, 0, 0, 0, 0, 114, 105, 103, 104, 116, 119, 97, 114, 100, 115, 32, 97, 114, 114, 111, 119, 44, 32, 85, 43, 50, 49, 57, 50, 32, 73, 83, 79, 110, 117, 109, 0, 100, 97, 114, 114, 0, 0, 0, 0, 100, 111, 119, 110, 119, 97, 114, 100, 115, 32, 97, 114, 114, 111, 119, 44, 32, 85, 43, 50, 49, 57, 51, 32, 73, 83, 79, 110, 117, 109, 0, 0, 104, 97, 114, 114, 0, 0, 0, 0, 108, 101, 102, 116, 32, 114, 105, 103, 104, 116, 32, 97, 114, 114, 111, 119, 44, 32, 85, 43, 50, 49, 57, 52, 32, 73, 83, 79, 97, 109, 115, 97, 0, 0, 0, 0, 0, 0, 0, 0, 99, 114, 97, 114, 114, 0, 0, 0, 100, 111, 119, 110, 119, 97, 114, 100, 115, 32, 97, 114, 114, 111, 119, 32, 119, 105, 116, 104, 32, 99, 111, 114, 110, 101, 114, 32, 108, 101, 102, 116, 119, 97, 114, 100, 115, 32, 61, 32, 99, 97, 114, 114, 105, 97, 103, 101, 32, 114, 101, 116, 117, 114, 110, 44, 32, 85, 43, 50, 49, 66, 53, 32, 78, 69, 87, 0, 0, 0, 0, 0, 108, 65, 114, 114, 0, 0, 0, 0, 108, 101, 102, 116, 119, 97, 114, 100, 115, 32, 100, 111, 117, 98, 108, 101, 32, 97, 114, 114, 111, 119, 44, 32, 85, 43, 50, 49, 68, 48, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 117, 65, 114, 114, 0, 0, 0, 0, 117, 112, 119, 97, 114, 100, 115, 32, 100, 111, 117, 98, 108, 101, 32, 97, 114, 114, 111, 119, 44, 32, 85, 43, 50, 49, 68, 49, 32, 73, 83, 79, 97, 109, 115, 97, 0, 0, 0, 0, 114, 65, 114, 114, 0, 0, 0, 0, 114, 105, 103, 104, 116, 119, 97, 114, 100, 115, 32, 100, 111, 117, 98, 108, 101, 32, 97, 114, 114, 111, 119, 44, 32, 85, 43, 50, 49, 68, 50, 32, 73, 83, 79, 116, 101, 99, 104, 0, 100, 65, 114, 114, 0, 0, 0, 0, 100, 111, 119, 110, 119, 97, 114, 100, 115, 32, 100, 111, 117, 98, 108, 101, 32, 97, 114, 114, 111, 119, 44, 32, 85, 43, 50, 49, 68, 51, 32, 73, 83, 79, 97, 109, 115, 97, 0, 0, 104, 65, 114, 114, 0, 0, 0, 0, 108, 101, 102, 116, 32, 114, 105, 103, 104, 116, 32, 100, 111, 117, 98, 108, 101, 32, 97, 114, 114, 111, 119, 44, 32, 85, 43, 50, 49, 68, 52, 32, 73, 83, 79, 97, 109, 115, 97, 0, 102, 111, 114, 97, 108, 108, 0, 0, 102, 111, 114, 32, 97, 108, 108, 44, 32, 85, 43, 50, 50, 48, 48, 32, 73, 83, 79, 116, 101, 99, 104, 0, 112, 97, 114, 116, 0, 0, 0, 0, 112, 97, 114, 116, 105, 97, 108, 32, 100, 105, 102, 102, 101, 114, 101, 110, 116, 105, 97, 108, 44, 32, 85, 43, 50, 50, 48, 50, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 0, 0, 101, 120, 105, 115, 116, 0, 0, 0, 116, 104, 101, 114, 101, 32, 101, 120, 105, 115, 116, 115, 44, 32, 85, 43, 50, 50, 48, 51, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 0, 0, 101, 109, 112, 116, 121, 0, 0, 0, 101, 109, 112, 116, 121, 32, 115, 101, 116, 32, 61, 32, 110, 117, 108, 108, 32, 115, 101, 116, 32, 61, 32, 100, 105, 97, 109, 101, 116, 101, 114, 44, 32, 85, 43, 50, 50, 48, 53, 32, 73, 83, 79, 97, 109, 115, 111, 0, 110, 97, 98, 108, 97, 0, 0, 0, 110, 97, 98, 108, 97, 32, 61, 32, 98, 97, 99, 107, 119, 97, 114, 100, 32, 100, 105, 102, 102, 101, 114, 101, 110, 99, 101, 44, 32, 85, 43, 50, 50, 48, 55, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 0, 0, 0, 105, 115, 105, 110, 0, 0, 0, 0, 101, 108, 101, 109, 101, 110, 116, 32, 111, 102, 44, 32, 85, 43, 50, 50, 48, 56, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 0, 0, 0, 0, 110, 111, 116, 105, 110, 0, 0, 0, 110, 111, 116, 32, 97, 110, 32, 101, 108, 101, 109, 101, 110, 116, 32, 111, 102, 44, 32, 85, 43, 50, 50, 48, 57, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 0, 0, 0, 0, 0, 110, 105, 0, 0, 0, 0, 0, 0, 99, 111, 110, 116, 97, 105, 110, 115, 32, 97, 115, 32, 109, 101, 109, 98, 101, 114, 44, 32, 85, 43, 50, 50, 48, 66, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 0, 0, 0, 0, 112, 114, 111, 100, 0, 0, 0, 0, 110, 45, 97, 114, 121, 32, 112, 114, 111, 100, 117, 99, 116, 32, 61, 32, 112, 114, 111, 100, 117, 99, 116, 32, 115, 105, 103, 110, 44, 32, 85, 43, 50, 50, 48, 70, 32, 73, 83, 79, 97, 109, 115, 98, 0, 0, 0, 0, 115, 117, 109, 0, 0, 0, 0, 0, 110, 45, 97, 114, 121, 32, 115, 117, 109, 109, 97, 116, 105, 111, 110, 44, 32, 85, 43, 50, 50, 49, 49, 32, 73, 83, 79, 97, 109, 115, 98, 0, 109, 105, 110, 117, 115, 0, 0, 0, 109, 105, 110, 117, 115, 32, 115, 105, 103, 110, 44, 32, 85, 43, 50, 50, 49, 50, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 0, 0, 0, 0, 108, 111, 119, 97, 115, 116, 0, 0, 97, 115, 116, 101, 114, 105, 115, 107, 32, 111, 112, 101, 114, 97, 116, 111, 114, 44, 32, 85, 43, 50, 50, 49, 55, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 0, 0, 0, 0, 0, 114, 97, 100, 105, 99, 0, 0, 0, 115, 113, 117, 97, 114, 101, 32, 114, 111, 111, 116, 32, 61, 32, 114, 97, 100, 105, 99, 97, 108, 32, 115, 105, 103, 110, 44, 32, 85, 43, 50, 50, 49, 65, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 0, 0, 0, 0, 112, 114, 111, 112, 0, 0, 0, 0, 112, 114, 111, 112, 111, 114, 116, 105, 111, 110, 97, 108, 32, 116, 111, 44, 32, 85, 43, 50, 50, 49, 68, 32, 73, 83, 79, 116, 101, 99, 104, 0, 105, 110, 102, 105, 110, 0, 0, 0, 105, 110, 102, 105, 110, 105, 116, 121, 44, 32, 85, 43, 50, 50, 49, 69, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 0, 0, 0, 0, 0, 0, 97, 110, 103, 0, 0, 0, 0, 0, 97, 110, 103, 108, 101, 44, 32, 85, 43, 50, 50, 50, 48, 32, 73, 83, 79, 97, 109, 115, 111, 0, 0, 0, 97, 110, 100, 0, 0, 0, 0, 0, 108, 111, 103, 105, 99, 97, 108, 32, 97, 110, 100, 32, 61, 32, 119, 101, 100, 103, 101, 44, 32, 85, 43, 50, 50, 50, 55, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 0, 0, 0, 111, 114, 0, 0, 0, 0, 0, 0, 108, 111, 103, 105, 99, 97, 108, 32, 111, 114, 32, 61, 32, 118, 101, 101, 44, 32, 85, 43, 50, 50, 50, 56, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 0, 0, 0, 0, 0, 0, 99, 97, 112, 0, 0, 0, 0, 0, 105, 110, 116, 101, 114, 115, 101, 99, 116, 105, 111, 110, 32, 61, 32, 99, 97, 112, 44, 32, 85, 43, 50, 50, 50, 57, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 0, 0, 0, 0, 99, 117, 112, 0, 0, 0, 0, 0, 117, 110, 105, 111, 110, 32, 61, 32, 99, 117, 112, 44, 32, 85, 43, 50, 50, 50, 65, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 0, 0, 0, 105, 110, 116, 0, 0, 0, 0, 0, 105, 110, 116, 101, 103, 114, 97, 108, 44, 32, 85, 43, 50, 50, 50, 66, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 0, 0, 0, 0, 0, 0, 116, 104, 101, 114, 101, 52, 0, 0, 116, 104, 101, 114, 101, 102, 111, 114, 101, 44, 32, 85, 43, 50, 50, 51, 52, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 0, 0, 0, 0, 0, 115, 105, 109, 0, 0, 0, 0, 0, 116, 105, 108, 100, 101, 32, 111, 112, 101, 114, 97, 116, 111, 114, 32, 61, 32, 118, 97, 114, 105, 101, 115, 32, 119, 105, 116, 104, 32, 61, 32, 115, 105, 109, 105, 108, 97, 114, 32, 116, 111, 44, 32, 85, 43, 50, 50, 51, 67, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 0, 0, 0, 0, 0, 99, 111, 110, 103, 0, 0, 0, 0, 97, 112, 112, 114, 111, 120, 105, 109, 97, 116, 101, 108, 121, 32, 101, 113, 117, 97, 108, 32, 116, 111, 44, 32, 85, 43, 50, 50, 52, 53, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 97, 115, 121, 109, 112, 0, 0, 0, 97, 108, 109, 111, 115, 116, 32, 101, 113, 117, 97, 108, 32, 116, 111, 32, 61, 32, 97, 115, 121, 109, 112, 116, 111, 116, 105, 99, 32, 116, 111, 44, 32, 85, 43, 50, 50, 52, 56, 32, 73, 83, 79, 97, 109, 115, 114, 0, 110, 101, 0, 0, 0, 0, 0, 0, 110, 111, 116, 32, 101, 113, 117, 97, 108, 32, 116, 111, 44, 32, 85, 43, 50, 50, 54, 48, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 0, 0, 101, 113, 117, 105, 118, 0, 0, 0, 105, 100, 101, 110, 116, 105, 99, 97, 108, 32, 116, 111, 44, 32, 85, 43, 50, 50, 54, 49, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 0, 0, 108, 101, 0, 0, 0, 0, 0, 0, 108, 101, 115, 115, 45, 116, 104, 97, 110, 32, 111, 114, 32, 101, 113, 117, 97, 108, 32, 116, 111, 44, 32, 85, 43, 50, 50, 54, 52, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 0, 103, 101, 0, 0, 0, 0, 0, 0, 103, 114, 101, 97, 116, 101, 114, 45, 116, 104, 97, 110, 32, 111, 114, 32, 101, 113, 117, 97, 108, 32, 116, 111, 44, 32, 85, 43, 50, 50, 54, 53, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 0, 0, 0, 0, 0, 0, 115, 117, 98, 0, 0, 0, 0, 0, 115, 117, 98, 115, 101, 116, 32, 111, 102, 44, 32, 85, 43, 50, 50, 56, 50, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 0, 0, 0, 0, 0, 115, 117, 112, 0, 0, 0, 0, 0, 115, 117, 112, 101, 114, 115, 101, 116, 32, 111, 102, 44, 32, 85, 43, 50, 50, 56, 51, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 0, 0, 0, 110, 115, 117, 98, 0, 0, 0, 0, 110, 111, 116, 32, 97, 32, 115, 117, 98, 115, 101, 116, 32, 111, 102, 44, 32, 85, 43, 50, 50, 56, 52, 32, 73, 83, 79, 97, 109, 115, 110, 0, 115, 117, 98, 101, 0, 0, 0, 0, 115, 117, 98, 115, 101, 116, 32, 111, 102, 32, 111, 114, 32, 101, 113, 117, 97, 108, 32, 116, 111, 44, 32, 85, 43, 50, 50, 56, 54, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 0, 115, 117, 112, 101, 0, 0, 0, 0, 115, 117, 112, 101, 114, 115, 101, 116, 32, 111, 102, 32, 111, 114, 32, 101, 113, 117, 97, 108, 32, 116, 111, 44, 32, 85, 43, 50, 50, 56, 55, 32, 73, 83, 79, 116, 101, 99, 104, 0, 111, 112, 108, 117, 115, 0, 0, 0, 99, 105, 114, 99, 108, 101, 100, 32, 112, 108, 117, 115, 32, 61, 32, 100, 105, 114, 101, 99, 116, 32, 115, 117, 109, 44, 32, 85, 43, 50, 50, 57, 53, 32, 73, 83, 79, 97, 109, 115, 98, 0, 0, 0, 0, 0, 0, 0, 111, 116, 105, 109, 101, 115, 0, 0, 99, 105, 114, 99, 108, 101, 100, 32, 116, 105, 109, 101, 115, 32, 61, 32, 118, 101, 99, 116, 111, 114, 32, 112, 114, 111, 100, 117, 99, 116, 44, 32, 85, 43, 50, 50, 57, 55, 32, 73, 83, 79, 97, 109, 115, 98, 0, 0, 112, 101, 114, 112, 0, 0, 0, 0, 117, 112, 32, 116, 97, 99, 107, 32, 61, 32, 111, 114, 116, 104, 111, 103, 111, 110, 97, 108, 32, 116, 111, 32, 61, 32, 112, 101, 114, 112, 101, 110, 100, 105, 99, 117, 108, 97, 114, 44, 32, 85, 43, 50, 50, 65, 53, 32, 73, 83, 79, 116, 101, 99, 104, 0, 115, 100, 111, 116, 0, 0, 0, 0, 100, 111, 116, 32, 111, 112, 101, 114, 97, 116, 111, 114, 44, 32, 85, 43, 50, 50, 67, 53, 32, 73, 83, 79, 97, 109, 115, 98, 0, 0, 0, 0, 108, 99, 101, 105, 108, 0, 0, 0, 108, 101, 102, 116, 32, 99, 101, 105, 108, 105, 110, 103, 32, 61, 32, 97, 112, 108, 32, 117, 112, 115, 116, 105, 108, 101, 44, 32, 85, 43, 50, 51, 48, 56, 32, 73, 83, 79, 97, 109, 115, 99, 0, 0, 0, 0, 0, 0, 114, 99, 101, 105, 108, 0, 0, 0, 114, 105, 103, 104, 116, 32, 99, 101, 105, 108, 105, 110, 103, 44, 32, 85, 43, 50, 51, 48, 57, 32, 73, 83, 79, 97, 109, 115, 99, 0, 0, 0, 108, 102, 108, 111, 111, 114, 0, 0, 108, 101, 102, 116, 32, 102, 108, 111, 111, 114, 32, 61, 32, 97, 112, 108, 32, 100, 111, 119, 110, 115, 116, 105, 108, 101, 44, 32, 85, 43, 50, 51, 48, 65, 32, 73, 83, 79, 97, 109, 115, 99, 0, 0, 0, 0, 0, 0, 114, 102, 108, 111, 111, 114, 0, 0, 114, 105, 103, 104, 116, 32, 102, 108, 111, 111, 114, 44, 32, 85, 43, 50, 51, 48, 66, 32, 73, 83, 79, 97, 109, 115, 99, 0, 0, 0, 0, 0, 108, 97, 110, 103, 0, 0, 0, 0, 108, 101, 102, 116, 45, 112, 111, 105, 110, 116, 105, 110, 103, 32, 97, 110, 103, 108, 101, 32, 98, 114, 97, 99, 107, 101, 116, 32, 61, 32, 98, 114, 97, 44, 32, 85, 43, 50, 51, 50, 57, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 0, 0, 0, 0, 0, 114, 97, 110, 103, 0, 0, 0, 0, 114, 105, 103, 104, 116, 45, 112, 111, 105, 110, 116, 105, 110, 103, 32, 97, 110, 103, 108, 101, 32, 98, 114, 97, 99, 107, 101, 116, 32, 61, 32, 107, 101, 116, 44, 32, 85, 43, 50, 51, 50, 65, 32, 73, 83, 79, 116, 101, 99, 104, 0, 0, 0, 0, 0, 0, 108, 111, 122, 0, 0, 0, 0, 0, 108, 111, 122, 101, 110, 103, 101, 44, 32, 85, 43, 50, 53, 67, 65, 32, 73, 83, 79, 112, 117, 98, 0, 0, 115, 112, 97, 100, 101, 115, 0, 0, 98, 108, 97, 99, 107, 32, 115, 112, 97, 100, 101, 32, 115, 117, 105, 116, 44, 32, 85, 43, 50, 54, 54, 48, 32, 73, 83, 79, 112, 117, 98, 0, 99, 108, 117, 98, 115, 0, 0, 0, 98, 108, 97, 99, 107, 32, 99, 108, 117, 98, 32, 115, 117, 105, 116, 32, 61, 32, 115, 104, 97, 109, 114, 111, 99, 107, 44, 32, 85, 43, 50, 54, 54, 51, 32, 73, 83, 79, 112, 117, 98, 0, 0, 0, 0, 0, 0, 0, 104, 101, 97, 114, 116, 115, 0, 0, 98, 108, 97, 99, 107, 32, 104, 101, 97, 114, 116, 32, 115, 117, 105, 116, 32, 61, 32, 118, 97, 108, 101, 110, 116, 105, 110, 101, 44, 32, 85, 43, 50, 54, 54, 53, 32, 73, 83, 79, 112, 117, 98, 0, 0, 0, 0, 0, 100, 105, 97, 109, 115, 0, 0, 0, 98, 108, 97, 99, 107, 32, 100, 105, 97, 109, 111, 110, 100, 32, 115, 117, 105, 116, 44, 32, 85, 43, 50, 54, 54, 54, 32, 73, 83, 79, 112, 117, 98, 0, 0, 0, 0, 0, 0, 0, 111, 110, 99, 108, 105, 99, 107, 0, 111, 110, 100, 98, 108, 99, 108, 105, 99, 107, 0, 0, 0, 0, 0, 0, 111, 110, 109, 111, 117, 115, 101, 100, 111, 119, 110, 0, 0, 0, 0, 0, 111, 110, 109, 111, 117, 115, 101, 117, 112, 0, 0, 0, 0, 0, 0, 0, 111, 110, 109, 111, 117, 115, 101, 111, 118, 101, 114, 0, 0, 0, 0, 0, 111, 110, 109, 111, 117, 115, 101, 111, 117, 116, 0, 0, 0, 0, 0, 0, 111, 110, 107, 101, 121, 112, 114, 101, 115, 115, 0, 0, 0, 0, 0, 0, 111, 110, 107, 101, 121, 100, 111, 119, 110, 0, 0, 0, 0, 0, 0, 0, 111, 110, 107, 101, 121, 117, 112, 0, 111, 110, 108, 111, 97, 100, 0, 0, 111, 110, 117, 110, 108, 111, 97, 100, 0, 0, 0, 0, 0, 0, 0, 0, 111, 110, 102, 111, 99, 117, 115, 0, 111, 110, 98, 108, 117, 114, 0, 0, 111, 110, 115, 117, 98, 109, 105, 116, 0, 0, 0, 0, 0, 0, 0, 0, 111, 110, 114, 101, 115, 101, 116, 0, 111, 110, 99, 104, 97, 110, 103, 101, 0, 0, 0, 0, 0, 0, 0, 0, 111, 110, 115, 101, 108, 101, 99, 116, 0, 0, 0, 0, 0, 0, 0, 0, 97, 110, 99, 104, 111, 114, 32, 0, 144, 122, 1, 0, 0, 122, 1, 0, 72, 121, 1, 0, 152, 122, 1, 0, 96, 122, 1, 0, 128, 122, 1, 0, 88, 121, 1, 0, 112, 122, 1, 0, 184, 121, 1, 0, 136, 122, 1, 0, 168, 121, 1, 0, 144, 121, 1, 0, 104, 122, 1, 0, 24, 122, 1, 0, 160, 122, 1, 0, 136, 121, 1, 0, 40, 121, 1, 0, 48, 121, 1, 0, 32, 121, 1, 0, 112, 198, 1, 0, 64, 121, 1, 0, 48, 193, 1, 0, 72, 122, 1, 0, 192, 121, 1, 0, 64, 186, 1, 0, 168, 189, 1, 0, 16, 115, 1, 0, 96, 201, 1, 0, 88, 122, 1, 0, 104, 177, 1, 0, 144, 177, 1, 0, 120, 122, 1, 0, 80, 121, 1, 0, 8, 122, 1, 0, 240, 198, 1, 0, 0, 208, 1, 0, 200, 210, 1, 0, 32, 122, 1, 0, 112, 121, 1, 0, 0, 0, 0, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 216, 179, 1, 0, 216, 191, 1, 0, 64, 181, 1, 0, 72, 181, 1, 0, 88, 181, 1, 0, 104, 181, 1, 0, 120, 181, 1, 0, 136, 181, 1, 0, 152, 181, 1, 0, 168, 181, 1, 0, 184, 181, 1, 0, 96, 114, 1, 0, 112, 212, 1, 0, 168, 212, 1, 0, 128, 214, 1, 0, 136, 214, 1, 0, 152, 214, 1, 0, 160, 214, 1, 0, 224, 212, 1, 0, 8, 216, 1, 0, 16, 216, 1, 0, 208, 212, 1, 0, 216, 181, 1, 0, 224, 181, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 32, 216, 1, 0, 0, 0, 0, 0, 97, 98, 98, 114, 101, 118, 105, 97, 116, 101, 100, 32, 102, 111, 114, 109, 0, 0, 0, 0, 0, 0, 0, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 216, 179, 1, 0, 216, 191, 1, 0, 64, 181, 1, 0, 72, 181, 1, 0, 88, 181, 1, 0, 104, 181, 1, 0, 120, 181, 1, 0, 136, 181, 1, 0, 152, 181, 1, 0, 168, 181, 1, 0, 184, 181, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 105, 110, 102, 111, 114, 109, 97, 116, 105, 111, 110, 32, 111, 110, 32, 97, 117, 116, 104, 111, 114, 32, 0, 0, 144, 122, 1, 0, 0, 122, 1, 0, 72, 121, 1, 0, 152, 122, 1, 0, 96, 122, 1, 0, 128, 122, 1, 0, 88, 121, 1, 0, 112, 122, 1, 0, 184, 121, 1, 0, 136, 122, 1, 0, 168, 121, 1, 0, 144, 121, 1, 0, 104, 122, 1, 0, 24, 122, 1, 0, 160, 122, 1, 0, 136, 121, 1, 0, 40, 121, 1, 0, 48, 121, 1, 0, 32, 121, 1, 0, 112, 198, 1, 0, 64, 121, 1, 0, 48, 193, 1, 0, 72, 122, 1, 0, 192, 121, 1, 0, 64, 186, 1, 0, 168, 189, 1, 0, 16, 115, 1, 0, 96, 201, 1, 0, 88, 122, 1, 0, 104, 177, 1, 0, 144, 177, 1, 0, 120, 122, 1, 0, 80, 121, 1, 0, 8, 122, 1, 0, 240, 198, 1, 0, 0, 208, 1, 0, 200, 210, 1, 0, 32, 122, 1, 0, 112, 121, 1, 0, 176, 119, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 106, 97, 118, 97, 32, 97, 112, 112, 108, 101, 116, 32, 0, 0, 0, 0, 208, 121, 1, 0, 216, 121, 1, 0, 224, 121, 1, 0, 232, 121, 1, 0, 240, 121, 1, 0, 248, 121, 1, 0, 24, 212, 1, 0, 112, 205, 1, 0, 216, 191, 1, 0, 240, 201, 1, 0, 80, 122, 1, 0, 176, 119, 1, 0, 208, 192, 1, 0, 96, 118, 1, 0, 128, 121, 1, 0, 56, 122, 1, 0, 232, 119, 1, 0, 96, 121, 1, 0, 200, 121, 1, 0, 168, 199, 1, 0, 136, 197, 1, 0, 152, 118, 1, 0, 184, 193, 1, 0, 56, 121, 1, 0, 144, 122, 1, 0, 0, 122, 1, 0, 72, 121, 1, 0, 152, 122, 1, 0, 96, 122, 1, 0, 128, 122, 1, 0, 88, 121, 1, 0, 112, 122, 1, 0, 184, 121, 1, 0, 136, 122, 1, 0, 168, 121, 1, 0, 144, 121, 1, 0, 104, 122, 1, 0, 24, 122, 1, 0, 160, 122, 1, 0, 136, 121, 1, 0, 40, 121, 1, 0, 48, 121, 1, 0, 32, 121, 1, 0, 112, 198, 1, 0, 64, 121, 1, 0, 48, 193, 1, 0, 72, 122, 1, 0, 192, 121, 1, 0, 64, 186, 1, 0, 168, 189, 1, 0, 16, 115, 1, 0, 96, 201, 1, 0, 88, 122, 1, 0, 104, 177, 1, 0, 144, 177, 1, 0, 120, 122, 1, 0, 80, 121, 1, 0, 8, 122, 1, 0, 240, 198, 1, 0, 0, 208, 1, 0, 200, 210, 1, 0, 32, 122, 1, 0, 112, 121, 1, 0, 160, 206, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 56, 214, 1, 0, 96, 214, 1, 0, 200, 214, 1, 0, 168, 212, 1, 0, 0, 213, 1, 0, 248, 212, 1, 0, 48, 213, 1, 0, 24, 214, 1, 0, 32, 214, 1, 0, 0, 0, 0, 0, 97, 114, 101, 97, 0, 0, 0, 0, 99, 108, 105, 101, 110, 116, 45, 115, 105, 100, 101, 32, 105, 109, 97, 103, 101, 32, 109, 97, 112, 32, 97, 114, 101, 97, 32, 0, 0, 0, 0, 0, 8, 216, 1, 0, 16, 216, 1, 0, 128, 214, 1, 0, 24, 216, 1, 0, 208, 212, 1, 0, 224, 212, 1, 0, 216, 181, 1, 0, 224, 181, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 200, 214, 1, 0, 0, 0, 0, 0, 98, 111, 108, 100, 32, 116, 101, 120, 116, 32, 115, 116, 121, 108, 101, 0, 100, 111, 99, 117, 109, 101, 110, 116, 32, 98, 97, 115, 101, 32, 117, 114, 105, 32, 0, 0, 0, 0, 0, 0, 128, 214, 1, 0, 0, 0, 0, 0, 98, 97, 115, 101, 102, 111, 110, 116, 0, 0, 0, 0, 0, 0, 0, 0, 98, 97, 115, 101, 32, 102, 111, 110, 116, 32, 115, 105, 122, 101, 32, 0, 152, 212, 1, 0, 160, 213, 1, 0, 128, 215, 1, 0, 136, 215, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 105, 49, 56, 110, 32, 98, 105, 100, 105, 32, 111, 118, 101, 114, 45, 114, 105, 100, 101, 32, 0, 0, 0, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 216, 179, 1, 0, 216, 191, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 216, 191, 1, 0, 0, 0, 0, 0, 108, 97, 114, 103, 101, 32, 116, 101, 120, 116, 32, 115, 116, 121, 108, 101, 0, 0, 0, 0, 0, 0, 0, 0, 108, 111, 110, 103, 32, 113, 117, 111, 116, 97, 116, 105, 111, 110, 32, 0, 208, 121, 1, 0, 216, 121, 1, 0, 224, 121, 1, 0, 232, 121, 1, 0, 240, 121, 1, 0, 248, 121, 1, 0, 24, 212, 1, 0, 112, 205, 1, 0, 216, 191, 1, 0, 240, 201, 1, 0, 80, 122, 1, 0, 176, 119, 1, 0, 208, 192, 1, 0, 96, 118, 1, 0, 128, 121, 1, 0, 56, 122, 1, 0, 232, 119, 1, 0, 96, 121, 1, 0, 200, 121, 1, 0, 168, 199, 1, 0, 136, 197, 1, 0, 152, 118, 1, 0, 184, 193, 1, 0, 56, 121, 1, 0, 144, 122, 1, 0, 0, 122, 1, 0, 72, 121, 1, 0, 152, 122, 1, 0, 96, 122, 1, 0, 128, 122, 1, 0, 88, 121, 1, 0, 112, 122, 1, 0, 184, 121, 1, 0, 136, 122, 1, 0, 168, 121, 1, 0, 144, 121, 1, 0, 104, 122, 1, 0, 24, 122, 1, 0, 160, 122, 1, 0, 136, 121, 1, 0, 40, 121, 1, 0, 48, 121, 1, 0, 32, 121, 1, 0, 112, 198, 1, 0, 64, 121, 1, 0, 48, 193, 1, 0, 72, 122, 1, 0, 192, 121, 1, 0, 64, 186, 1, 0, 168, 189, 1, 0, 16, 115, 1, 0, 96, 201, 1, 0, 88, 122, 1, 0, 104, 177, 1, 0, 144, 177, 1, 0, 120, 122, 1, 0, 80, 121, 1, 0, 8, 122, 1, 0, 240, 198, 1, 0, 0, 208, 1, 0, 200, 210, 1, 0, 32, 122, 1, 0, 112, 121, 1, 0, 0, 0, 0, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 216, 179, 1, 0, 216, 191, 1, 0, 64, 181, 1, 0, 72, 181, 1, 0, 88, 181, 1, 0, 104, 181, 1, 0, 120, 181, 1, 0, 136, 181, 1, 0, 152, 181, 1, 0, 168, 181, 1, 0, 184, 181, 1, 0, 136, 121, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 100, 111, 99, 117, 109, 101, 110, 116, 32, 98, 111, 100, 121, 32, 0, 0, 208, 121, 1, 0, 216, 121, 1, 0, 224, 121, 1, 0, 232, 121, 1, 0, 240, 121, 1, 0, 248, 121, 1, 0, 24, 212, 1, 0, 112, 205, 1, 0, 216, 191, 1, 0, 240, 201, 1, 0, 80, 122, 1, 0, 176, 119, 1, 0, 208, 192, 1, 0, 96, 118, 1, 0, 128, 121, 1, 0, 56, 122, 1, 0, 232, 119, 1, 0, 96, 121, 1, 0, 200, 121, 1, 0, 168, 199, 1, 0, 136, 197, 1, 0, 152, 118, 1, 0, 184, 193, 1, 0, 56, 121, 1, 0, 144, 122, 1, 0, 0, 122, 1, 0, 72, 121, 1, 0, 152, 122, 1, 0, 96, 122, 1, 0, 128, 122, 1, 0, 88, 121, 1, 0, 112, 122, 1, 0, 184, 121, 1, 0, 136, 122, 1, 0, 168, 121, 1, 0, 144, 121, 1, 0, 104, 122, 1, 0, 24, 122, 1, 0, 160, 122, 1, 0, 136, 121, 1, 0, 40, 121, 1, 0, 48, 121, 1, 0, 32, 121, 1, 0, 112, 198, 1, 0, 64, 121, 1, 0, 48, 193, 1, 0, 72, 122, 1, 0, 192, 121, 1, 0, 64, 186, 1, 0, 168, 189, 1, 0, 16, 115, 1, 0, 96, 201, 1, 0, 88, 122, 1, 0, 104, 177, 1, 0, 144, 177, 1, 0, 120, 122, 1, 0, 80, 121, 1, 0, 8, 122, 1, 0, 240, 198, 1, 0, 0, 208, 1, 0, 200, 210, 1, 0, 32, 122, 1, 0, 112, 121, 1, 0, 16, 122, 1, 0, 160, 121, 1, 0, 0, 0, 0, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 216, 179, 1, 0, 216, 191, 1, 0, 64, 181, 1, 0, 72, 181, 1, 0, 88, 181, 1, 0, 104, 181, 1, 0, 120, 181, 1, 0, 136, 181, 1, 0, 152, 181, 1, 0, 168, 181, 1, 0, 184, 181, 1, 0, 192, 181, 1, 0, 200, 181, 1, 0, 0, 0, 0, 0, 224, 215, 1, 0, 128, 212, 1, 0, 240, 215, 1, 0, 208, 119, 1, 0, 248, 215, 1, 0, 0, 216, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 98, 114, 0, 0, 0, 0, 0, 0, 102, 111, 114, 99, 101, 100, 32, 108, 105, 110, 101, 32, 98, 114, 101, 97, 107, 32, 0, 0, 0, 0, 0, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 216, 215, 1, 0, 0, 0, 0, 0, 112, 117, 115, 104, 32, 98, 117, 116, 116, 111, 110, 32, 0, 0, 0, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 216, 179, 1, 0, 216, 191, 1, 0, 64, 181, 1, 0, 72, 181, 1, 0, 88, 181, 1, 0, 104, 181, 1, 0, 120, 181, 1, 0, 136, 181, 1, 0, 152, 181, 1, 0, 168, 181, 1, 0, 184, 181, 1, 0, 168, 212, 1, 0, 232, 213, 1, 0, 112, 212, 1, 0, 176, 212, 1, 0, 208, 212, 1, 0, 224, 212, 1, 0, 216, 181, 1, 0, 224, 181, 1, 0, 0, 0, 0, 0, 116, 97, 98, 108, 101, 32, 99, 97, 112, 116, 105, 111, 110, 32, 0, 0, 115, 104, 111, 114, 116, 104, 97, 110, 100, 32, 102, 111, 114, 32, 100, 105, 118, 32, 97, 108, 105, 103, 110, 61, 99, 101, 110, 116, 101, 114, 32, 0, 99, 105, 116, 97, 116, 105, 111, 110, 0, 0, 0, 0, 0, 0, 0, 0, 99, 111, 109, 112, 117, 116, 101, 114, 32, 99, 111, 100, 101, 32, 102, 114, 97, 103, 109, 101, 110, 116, 0, 0, 99, 111, 108, 0, 0, 0, 0, 0, 116, 97, 98, 108, 101, 32, 99, 111, 108, 117, 109, 110, 32, 0, 0, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 216, 179, 1, 0, 216, 191, 1, 0, 64, 181, 1, 0, 72, 181, 1, 0, 88, 181, 1, 0, 104, 181, 1, 0, 120, 181, 1, 0, 136, 181, 1, 0, 152, 181, 1, 0, 168, 181, 1, 0, 184, 181, 1, 0, 120, 122, 1, 0, 248, 212, 1, 0, 48, 213, 1, 0, 56, 213, 1, 0, 64, 213, 1, 0, 72, 213, 1, 0, 0, 0, 0, 0, 99, 111, 108, 103, 114, 111, 117, 112, 0, 0, 0, 0, 0, 0, 0, 0, 116, 97, 98, 108, 101, 32, 99, 111, 108, 117, 109, 110, 32, 103, 114, 111, 117, 112, 32, 0, 0, 0, 0, 0, 176, 190, 1, 0, 0, 0, 0, 0, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 100, 101, 115, 99, 114, 105, 112, 116, 105, 111, 110, 32, 0, 100, 101, 108, 101, 116, 101, 100, 32, 116, 101, 120, 116, 32, 0, 0, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 216, 179, 1, 0, 216, 191, 1, 0, 64, 181, 1, 0, 72, 181, 1, 0, 88, 181, 1, 0, 104, 181, 1, 0, 120, 181, 1, 0, 136, 181, 1, 0, 152, 181, 1, 0, 168, 181, 1, 0, 184, 181, 1, 0, 200, 215, 1, 0, 136, 121, 1, 0, 0, 0, 0, 0, 105, 110, 115, 116, 97, 110, 99, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 0, 0, 0, 0, 0, 100, 105, 114, 0, 0, 0, 0, 0, 100, 105, 114, 101, 99, 116, 111, 114, 121, 32, 108, 105, 115, 116, 0, 0, 208, 121, 1, 0, 216, 121, 1, 0, 224, 121, 1, 0, 232, 121, 1, 0, 240, 121, 1, 0, 248, 121, 1, 0, 24, 212, 1, 0, 112, 205, 1, 0, 216, 191, 1, 0, 240, 201, 1, 0, 80, 122, 1, 0, 176, 119, 1, 0, 208, 192, 1, 0, 96, 118, 1, 0, 128, 121, 1, 0, 56, 122, 1, 0, 232, 119, 1, 0, 96, 121, 1, 0, 200, 121, 1, 0, 168, 199, 1, 0, 136, 197, 1, 0, 152, 118, 1, 0, 184, 193, 1, 0, 56, 121, 1, 0, 48, 122, 1, 0, 0, 0, 0, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 216, 179, 1, 0, 216, 191, 1, 0, 64, 181, 1, 0, 72, 181, 1, 0, 88, 181, 1, 0, 104, 181, 1, 0, 120, 181, 1, 0, 136, 181, 1, 0, 152, 181, 1, 0, 168, 181, 1, 0, 184, 181, 1, 0, 120, 212, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 103, 101, 110, 101, 114, 105, 99, 32, 108, 97, 110, 103, 117, 97, 103, 101, 47, 115, 116, 121, 108, 101, 32, 99, 111, 110, 116, 97, 105, 110, 101, 114, 0, 0, 0, 0, 0, 0, 0, 0, 48, 213, 1, 0, 0, 0, 0, 0, 100, 108, 0, 0, 0, 0, 0, 0, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 108, 105, 115, 116, 32, 0, 0, 0, 0, 0, 0, 0, 0, 176, 121, 1, 0, 152, 121, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 120, 212, 1, 0, 0, 0, 0, 0, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 116, 101, 114, 109, 32, 0, 0, 0, 0, 0, 0, 0, 0, 101, 109, 112, 104, 97, 115, 105, 115, 0, 0, 0, 0, 0, 0, 0, 0, 101, 109, 98, 101, 100, 0, 0, 0, 103, 101, 110, 101, 114, 105, 99, 32, 101, 109, 98, 101, 100, 100, 101, 100, 32, 111, 98, 106, 101, 99, 116, 32, 0, 0, 0, 0, 0, 0, 0, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 48, 213, 1, 0, 200, 214, 1, 0, 88, 213, 1, 0, 144, 121, 1, 0, 56, 214, 1, 0, 240, 214, 1, 0, 0, 213, 1, 0, 144, 215, 1, 0, 24, 214, 1, 0, 168, 212, 1, 0, 152, 215, 1, 0, 160, 215, 1, 0, 176, 215, 1, 0, 200, 213, 1, 0, 112, 212, 1, 0, 192, 215, 1, 0, 32, 214, 1, 0, 248, 212, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 102, 105, 101, 108, 100, 115, 101, 116, 0, 0, 0, 0, 0, 0, 0, 0, 102, 111, 114, 109, 32, 99, 111, 110, 116, 114, 111, 108, 32, 103, 114, 111, 117, 112, 32, 0, 0, 0, 0, 0, 208, 121, 1, 0, 216, 121, 1, 0, 224, 121, 1, 0, 232, 121, 1, 0, 240, 121, 1, 0, 248, 121, 1, 0, 24, 212, 1, 0, 112, 205, 1, 0, 216, 191, 1, 0, 240, 201, 1, 0, 80, 122, 1, 0, 176, 119, 1, 0, 208, 192, 1, 0, 96, 118, 1, 0, 128, 121, 1, 0, 56, 122, 1, 0, 232, 119, 1, 0, 96, 121, 1, 0, 200, 121, 1, 0, 168, 199, 1, 0, 136, 197, 1, 0, 152, 118, 1, 0, 184, 193, 1, 0, 56, 121, 1, 0, 144, 122, 1, 0, 0, 122, 1, 0, 72, 121, 1, 0, 152, 122, 1, 0, 96, 122, 1, 0, 128, 122, 1, 0, 88, 121, 1, 0, 112, 122, 1, 0, 184, 121, 1, 0, 136, 122, 1, 0, 168, 121, 1, 0, 144, 121, 1, 0, 104, 122, 1, 0, 24, 122, 1, 0, 160, 122, 1, 0, 136, 121, 1, 0, 40, 121, 1, 0, 48, 121, 1, 0, 32, 121, 1, 0, 112, 198, 1, 0, 64, 121, 1, 0, 48, 193, 1, 0, 72, 122, 1, 0, 192, 121, 1, 0, 64, 186, 1, 0, 168, 189, 1, 0, 16, 115, 1, 0, 96, 201, 1, 0, 88, 122, 1, 0, 104, 177, 1, 0, 144, 177, 1, 0, 120, 122, 1, 0, 80, 121, 1, 0, 8, 122, 1, 0, 240, 198, 1, 0, 0, 208, 1, 0, 200, 210, 1, 0, 32, 122, 1, 0, 112, 121, 1, 0, 40, 122, 1, 0, 108, 111, 99, 97, 108, 32, 99, 104, 97, 110, 103, 101, 32, 116, 111, 32, 102, 111, 110, 116, 32, 0, 0, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 216, 179, 1, 0, 216, 191, 1, 0, 160, 213, 1, 0, 128, 215, 1, 0, 136, 215, 1, 0, 0, 0, 0, 0, 105, 110, 116, 101, 114, 97, 99, 116, 105, 118, 101, 32, 102, 111, 114, 109, 32, 0, 0, 0, 0, 0, 0, 0, 208, 121, 1, 0, 216, 121, 1, 0, 224, 121, 1, 0, 232, 121, 1, 0, 240, 121, 1, 0, 248, 121, 1, 0, 24, 212, 1, 0, 112, 205, 1, 0, 216, 191, 1, 0, 240, 201, 1, 0, 144, 122, 1, 0, 0, 122, 1, 0, 72, 121, 1, 0, 152, 122, 1, 0, 96, 122, 1, 0, 128, 122, 1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 105328);
	        allocate([88, 121, 1, 0, 112, 122, 1, 0, 184, 121, 1, 0, 136, 122, 1, 0, 168, 121, 1, 0, 144, 121, 1, 0, 104, 122, 1, 0, 24, 122, 1, 0, 160, 122, 1, 0, 136, 121, 1, 0, 40, 121, 1, 0, 48, 121, 1, 0, 32, 121, 1, 0, 112, 198, 1, 0, 64, 121, 1, 0, 48, 193, 1, 0, 72, 122, 1, 0, 192, 121, 1, 0, 64, 186, 1, 0, 168, 189, 1, 0, 16, 115, 1, 0, 96, 201, 1, 0, 88, 122, 1, 0, 104, 177, 1, 0, 144, 177, 1, 0, 120, 122, 1, 0, 80, 121, 1, 0, 8, 122, 1, 0, 240, 198, 1, 0, 0, 208, 1, 0, 200, 210, 1, 0, 32, 122, 1, 0, 112, 121, 1, 0, 80, 122, 1, 0, 176, 119, 1, 0, 96, 118, 1, 0, 128, 121, 1, 0, 56, 122, 1, 0, 232, 119, 1, 0, 96, 121, 1, 0, 168, 199, 1, 0, 136, 197, 1, 0, 152, 118, 1, 0, 184, 193, 1, 0, 56, 121, 1, 0, 0, 0, 0, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 216, 179, 1, 0, 216, 191, 1, 0, 64, 181, 1, 0, 72, 181, 1, 0, 88, 181, 1, 0, 104, 181, 1, 0, 120, 181, 1, 0, 136, 181, 1, 0, 152, 181, 1, 0, 168, 181, 1, 0, 184, 181, 1, 0, 96, 215, 1, 0, 104, 215, 1, 0, 216, 214, 1, 0, 168, 212, 1, 0, 232, 181, 1, 0, 248, 181, 1, 0, 112, 215, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 88, 215, 1, 0, 0, 0, 0, 0, 115, 117, 98, 119, 105, 110, 100, 111, 119, 32, 0, 0, 0, 0, 0, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 224, 214, 1, 0, 168, 212, 1, 0, 200, 213, 1, 0, 240, 214, 1, 0, 0, 215, 1, 0, 16, 215, 1, 0, 72, 215, 1, 0, 32, 215, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 119, 105, 110, 100, 111, 119, 32, 115, 117, 98, 100, 105, 118, 105, 115, 105, 111, 110, 0, 0, 0, 0, 0, 0, 0, 120, 1, 0, 248, 119, 1, 0, 232, 119, 1, 0, 0, 0, 0, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 136, 212, 1, 0, 144, 212, 1, 0, 192, 181, 1, 0, 200, 181, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 104, 101, 97, 100, 105, 110, 103, 32, 0, 0, 0, 0, 0, 0, 0, 0, 100, 111, 99, 117, 109, 101, 110, 116, 32, 104, 101, 97, 100, 32, 0, 0, 216, 119, 1, 0, 168, 199, 1, 0, 224, 119, 1, 0, 16, 115, 1, 0, 24, 115, 1, 0, 200, 119, 1, 0, 208, 119, 1, 0, 72, 122, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 216, 179, 1, 0, 216, 191, 1, 0, 64, 215, 1, 0, 0, 0, 0, 0, 104, 114, 0, 0, 0, 0, 0, 0, 104, 111, 114, 105, 122, 111, 110, 116, 97, 108, 32, 114, 117, 108, 101, 32, 0, 0, 0, 0, 0, 0, 0, 0, 48, 213, 1, 0, 56, 215, 1, 0, 160, 213, 1, 0, 248, 212, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 100, 111, 99, 117, 109, 101, 110, 116, 32, 114, 111, 111, 116, 32, 101, 108, 101, 109, 101, 110, 116, 32, 0, 0, 168, 117, 1, 0, 160, 117, 1, 0, 0, 120, 1, 0, 0, 0, 0, 0, 216, 179, 1, 0, 216, 191, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 48, 215, 1, 0, 0, 0, 0, 0, 105, 116, 97, 108, 105, 99, 32, 116, 101, 120, 116, 32, 115, 116, 121, 108, 101, 0, 0, 0, 0, 0, 0, 0, 105, 110, 108, 105, 110, 101, 32, 115, 117, 98, 119, 105, 110, 100, 111, 119, 32, 0, 0, 0, 0, 0, 0, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 224, 214, 1, 0, 168, 212, 1, 0, 200, 213, 1, 0, 240, 214, 1, 0, 0, 215, 1, 0, 16, 215, 1, 0, 32, 215, 1, 0, 48, 213, 1, 0, 0, 213, 1, 0, 248, 212, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 105, 109, 103, 0, 0, 0, 0, 0, 101, 109, 98, 101, 100, 100, 101, 100, 32, 105, 109, 97, 103, 101, 32, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 216, 179, 1, 0, 216, 191, 1, 0, 64, 181, 1, 0, 72, 181, 1, 0, 88, 181, 1, 0, 104, 181, 1, 0, 120, 181, 1, 0, 136, 181, 1, 0, 152, 181, 1, 0, 168, 181, 1, 0, 184, 181, 1, 0, 224, 214, 1, 0, 168, 212, 1, 0, 0, 213, 1, 0, 248, 212, 1, 0, 112, 214, 1, 0, 208, 214, 1, 0, 0, 0, 0, 0, 200, 213, 1, 0, 200, 214, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 105, 110, 112, 117, 116, 0, 0, 0, 102, 111, 114, 109, 32, 99, 111, 110, 116, 114, 111, 108, 32, 0, 0, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 216, 179, 1, 0, 216, 191, 1, 0, 64, 181, 1, 0, 72, 181, 1, 0, 88, 181, 1, 0, 104, 181, 1, 0, 120, 181, 1, 0, 136, 181, 1, 0, 152, 181, 1, 0, 168, 181, 1, 0, 184, 181, 1, 0, 112, 212, 1, 0, 168, 212, 1, 0, 232, 213, 1, 0, 176, 214, 1, 0, 176, 212, 1, 0, 192, 212, 1, 0, 160, 213, 1, 0, 184, 214, 1, 0, 200, 213, 1, 0, 200, 214, 1, 0, 112, 214, 1, 0, 208, 214, 1, 0, 208, 212, 1, 0, 224, 212, 1, 0, 216, 181, 1, 0, 224, 181, 1, 0, 16, 182, 1, 0, 0, 182, 1, 0, 216, 214, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 105, 110, 115, 101, 114, 116, 101, 100, 32, 116, 101, 120, 116, 0, 0, 0, 105, 115, 105, 110, 100, 101, 120, 0, 115, 105, 110, 103, 108, 101, 32, 108, 105, 110, 101, 32, 112, 114, 111, 109, 112, 116, 32, 0, 0, 0, 0, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 216, 179, 1, 0, 216, 191, 1, 0, 168, 214, 1, 0, 0, 0, 0, 0, 116, 101, 120, 116, 32, 116, 111, 32, 98, 101, 32, 101, 110, 116, 101, 114, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32, 117, 115, 101, 114, 0, 0, 102, 111, 114, 109, 32, 102, 105, 101, 108, 100, 32, 108, 97, 98, 101, 108, 32, 116, 101, 120, 116, 32, 0, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 216, 179, 1, 0, 216, 191, 1, 0, 64, 181, 1, 0, 72, 181, 1, 0, 88, 181, 1, 0, 104, 181, 1, 0, 120, 181, 1, 0, 136, 181, 1, 0, 152, 181, 1, 0, 168, 181, 1, 0, 184, 181, 1, 0, 224, 213, 1, 0, 224, 212, 1, 0, 216, 181, 1, 0, 224, 181, 1, 0, 0, 0, 0, 0, 102, 105, 101, 108, 100, 115, 101, 116, 32, 108, 101, 103, 101, 110, 100, 32, 0, 0, 0, 0, 0, 0, 0, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 216, 179, 1, 0, 216, 191, 1, 0, 64, 181, 1, 0, 72, 181, 1, 0, 88, 181, 1, 0, 104, 181, 1, 0, 120, 181, 1, 0, 136, 181, 1, 0, 152, 181, 1, 0, 168, 181, 1, 0, 184, 181, 1, 0, 224, 212, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 108, 105, 115, 116, 32, 105, 116, 101, 109, 32, 0, 0, 0, 0, 0, 0, 97, 32, 109, 101, 100, 105, 97, 45, 105, 110, 100, 101, 112, 101, 110, 100, 101, 110, 116, 32, 108, 105, 110, 107, 32, 0, 0, 0, 0, 0, 0, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 216, 179, 1, 0, 216, 191, 1, 0, 64, 181, 1, 0, 72, 181, 1, 0, 88, 181, 1, 0, 104, 181, 1, 0, 120, 181, 1, 0, 136, 181, 1, 0, 152, 181, 1, 0, 168, 181, 1, 0, 184, 181, 1, 0, 96, 114, 1, 0, 128, 214, 1, 0, 136, 214, 1, 0, 112, 212, 1, 0, 152, 214, 1, 0, 160, 214, 1, 0, 152, 213, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 109, 97, 112, 0, 0, 0, 0, 0, 99, 108, 105, 101, 110, 116, 45, 115, 105, 100, 101, 32, 105, 109, 97, 103, 101, 32, 109, 97, 112, 32, 0, 0, 208, 121, 1, 0, 216, 121, 1, 0, 224, 121, 1, 0, 232, 121, 1, 0, 240, 121, 1, 0, 248, 121, 1, 0, 24, 212, 1, 0, 112, 205, 1, 0, 216, 191, 1, 0, 240, 201, 1, 0, 80, 122, 1, 0, 176, 119, 1, 0, 208, 192, 1, 0, 96, 118, 1, 0, 128, 121, 1, 0, 56, 122, 1, 0, 232, 119, 1, 0, 96, 121, 1, 0, 200, 121, 1, 0, 168, 199, 1, 0, 136, 197, 1, 0, 152, 118, 1, 0, 184, 193, 1, 0, 56, 121, 1, 0, 184, 185, 1, 0, 0, 0, 0, 0, 168, 212, 1, 0, 0, 0, 0, 0, 109, 101, 110, 117, 0, 0, 0, 0, 109, 101, 110, 117, 32, 108, 105, 115, 116, 32, 0, 0, 0, 0, 0, 0, 103, 101, 110, 101, 114, 105, 99, 32, 109, 101, 116, 97, 105, 110, 102, 111, 114, 109, 97, 116, 105, 111, 110, 32, 0, 0, 0, 0, 0, 0, 0, 0, 216, 179, 1, 0, 216, 191, 1, 0, 80, 126, 1, 0, 168, 212, 1, 0, 120, 214, 1, 0, 96, 114, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 112, 126, 1, 0, 0, 0, 0, 0, 97, 108, 116, 101, 114, 110, 97, 116, 101, 32, 99, 111, 110, 116, 101, 110, 116, 32, 99, 111, 110, 116, 97, 105, 110, 101, 114, 32, 102, 111, 114, 32, 110, 111, 110, 32, 102, 114, 97, 109, 101, 45, 98, 97, 115, 101, 100, 32, 114, 101, 110, 100, 101, 114, 105, 110, 103, 32, 0, 0, 0, 0, 0, 0, 160, 117, 1, 0, 208, 121, 1, 0, 216, 121, 1, 0, 224, 121, 1, 0, 232, 121, 1, 0, 240, 121, 1, 0, 248, 121, 1, 0, 24, 212, 1, 0, 112, 205, 1, 0, 216, 191, 1, 0, 240, 201, 1, 0, 80, 122, 1, 0, 176, 119, 1, 0, 208, 192, 1, 0, 96, 118, 1, 0, 128, 121, 1, 0, 56, 122, 1, 0, 232, 119, 1, 0, 96, 121, 1, 0, 200, 121, 1, 0, 168, 199, 1, 0, 136, 197, 1, 0, 152, 118, 1, 0, 184, 193, 1, 0, 56, 121, 1, 0, 144, 122, 1, 0, 0, 122, 1, 0, 72, 121, 1, 0, 152, 122, 1, 0, 96, 122, 1, 0, 128, 122, 1, 0, 88, 121, 1, 0, 112, 122, 1, 0, 184, 121, 1, 0, 136, 122, 1, 0, 168, 121, 1, 0, 144, 121, 1, 0, 104, 122, 1, 0, 24, 122, 1, 0, 160, 122, 1, 0, 136, 121, 1, 0, 40, 121, 1, 0, 48, 121, 1, 0, 32, 121, 1, 0, 112, 198, 1, 0, 64, 121, 1, 0, 48, 193, 1, 0, 72, 122, 1, 0, 192, 121, 1, 0, 64, 186, 1, 0, 168, 189, 1, 0, 16, 115, 1, 0, 96, 201, 1, 0, 88, 122, 1, 0, 104, 177, 1, 0, 144, 177, 1, 0, 120, 122, 1, 0, 80, 121, 1, 0, 8, 122, 1, 0, 240, 198, 1, 0, 0, 208, 1, 0, 200, 210, 1, 0, 32, 122, 1, 0, 112, 121, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 108, 116, 101, 114, 110, 97, 116, 101, 32, 99, 111, 110, 116, 101, 110, 116, 32, 99, 111, 110, 116, 97, 105, 110, 101, 114, 32, 102, 111, 114, 32, 110, 111, 110, 32, 115, 99, 114, 105, 112, 116, 45, 98, 97, 115, 101, 100, 32, 114, 101, 110, 100, 101, 114, 105, 110, 103, 32, 0, 0, 0, 0, 0, 208, 121, 1, 0, 216, 121, 1, 0, 224, 121, 1, 0, 232, 121, 1, 0, 240, 121, 1, 0, 248, 121, 1, 0, 24, 212, 1, 0, 112, 205, 1, 0, 216, 191, 1, 0, 240, 201, 1, 0, 80, 122, 1, 0, 176, 119, 1, 0, 208, 192, 1, 0, 96, 118, 1, 0, 128, 121, 1, 0, 56, 122, 1, 0, 232, 119, 1, 0, 96, 121, 1, 0, 200, 121, 1, 0, 168, 199, 1, 0, 136, 197, 1, 0, 152, 118, 1, 0, 184, 193, 1, 0, 56, 121, 1, 0, 144, 122, 1, 0, 0, 122, 1, 0, 72, 121, 1, 0, 152, 122, 1, 0, 96, 122, 1, 0, 128, 122, 1, 0, 88, 121, 1, 0, 112, 122, 1, 0, 184, 121, 1, 0, 136, 122, 1, 0, 168, 121, 1, 0, 144, 121, 1, 0, 104, 122, 1, 0, 24, 122, 1, 0, 160, 122, 1, 0, 136, 121, 1, 0, 40, 121, 1, 0, 48, 121, 1, 0, 32, 121, 1, 0, 112, 198, 1, 0, 64, 121, 1, 0, 48, 193, 1, 0, 72, 122, 1, 0, 192, 121, 1, 0, 64, 186, 1, 0, 168, 189, 1, 0, 16, 115, 1, 0, 96, 201, 1, 0, 88, 122, 1, 0, 104, 177, 1, 0, 144, 177, 1, 0, 120, 122, 1, 0, 80, 121, 1, 0, 8, 122, 1, 0, 240, 198, 1, 0, 0, 208, 1, 0, 200, 210, 1, 0, 32, 122, 1, 0, 112, 121, 1, 0, 160, 206, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 216, 179, 1, 0, 216, 191, 1, 0, 64, 181, 1, 0, 72, 181, 1, 0, 88, 181, 1, 0, 104, 181, 1, 0, 120, 181, 1, 0, 136, 181, 1, 0, 152, 181, 1, 0, 168, 181, 1, 0, 184, 181, 1, 0, 40, 214, 1, 0, 48, 214, 1, 0, 56, 214, 1, 0, 72, 214, 1, 0, 112, 212, 1, 0, 80, 214, 1, 0, 96, 214, 1, 0, 104, 214, 1, 0, 0, 213, 1, 0, 248, 212, 1, 0, 112, 214, 1, 0, 168, 212, 1, 0, 208, 212, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 48, 213, 1, 0, 88, 213, 1, 0, 24, 214, 1, 0, 32, 214, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 111, 108, 0, 0, 0, 0, 0, 0, 111, 114, 100, 101, 114, 101, 100, 32, 108, 105, 115, 116, 32, 0, 0, 0, 48, 122, 1, 0, 0, 0, 0, 0, 112, 212, 1, 0, 120, 212, 1, 0, 16, 214, 1, 0, 0, 0, 0, 0, 111, 112, 116, 103, 114, 111, 117, 112, 0, 0, 0, 0, 0, 0, 0, 0, 111, 112, 116, 105, 111, 110, 32, 103, 114, 111, 117, 112, 32, 0, 0, 0, 200, 205, 1, 0, 0, 0, 0, 0, 111, 112, 116, 105, 111, 110, 0, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 216, 179, 1, 0, 216, 191, 1, 0, 64, 181, 1, 0, 72, 181, 1, 0, 88, 181, 1, 0, 104, 181, 1, 0, 120, 181, 1, 0, 136, 181, 1, 0, 152, 181, 1, 0, 168, 181, 1, 0, 184, 181, 1, 0, 176, 212, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 32, 122, 1, 0, 0, 0, 0, 0, 115, 101, 108, 101, 99, 116, 97, 98, 108, 101, 32, 99, 104, 111, 105, 99, 101, 32, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 216, 179, 1, 0, 216, 191, 1, 0, 64, 181, 1, 0, 72, 181, 1, 0, 88, 181, 1, 0, 104, 181, 1, 0, 120, 181, 1, 0, 136, 181, 1, 0, 152, 181, 1, 0, 168, 181, 1, 0, 184, 181, 1, 0, 176, 212, 1, 0, 32, 122, 1, 0, 0, 214, 1, 0, 232, 213, 1, 0, 0, 0, 0, 0, 112, 97, 114, 97, 103, 114, 97, 112, 104, 32, 0, 0, 0, 0, 0, 0, 112, 97, 114, 97, 109, 0, 0, 0, 110, 97, 109, 101, 100, 32, 112, 114, 111, 112, 101, 114, 116, 121, 32, 118, 97, 108, 117, 101, 32, 0, 0, 0, 152, 212, 1, 0, 232, 213, 1, 0, 240, 213, 1, 0, 112, 212, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 112, 114, 101, 102, 111, 114, 109, 97, 116, 116, 101, 100, 32, 116, 101, 120, 116, 32, 0, 0, 0, 0, 0, 0, 184, 121, 1, 0, 136, 122, 1, 0, 168, 121, 1, 0, 144, 121, 1, 0, 104, 122, 1, 0, 24, 122, 1, 0, 160, 122, 1, 0, 136, 121, 1, 0, 40, 121, 1, 0, 48, 121, 1, 0, 144, 122, 1, 0, 0, 122, 1, 0, 72, 121, 1, 0, 152, 122, 1, 0, 96, 122, 1, 0, 128, 122, 1, 0, 32, 121, 1, 0, 168, 189, 1, 0, 16, 115, 1, 0, 96, 201, 1, 0, 88, 122, 1, 0, 120, 122, 1, 0, 80, 121, 1, 0, 8, 122, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 248, 212, 1, 0, 0, 0, 0, 0, 115, 104, 111, 114, 116, 32, 105, 110, 108, 105, 110, 101, 32, 113, 117, 111, 116, 97, 116, 105, 111, 110, 32, 0, 115, 116, 114, 105, 107, 101, 45, 116, 104, 114, 111, 117, 103, 104, 32, 116, 101, 120, 116, 32, 115, 116, 121, 108, 101, 0, 0, 0, 0, 0, 0, 0, 115, 97, 109, 112, 108, 101, 32, 112, 114, 111, 103, 114, 97, 109, 32, 111, 117, 116, 112, 117, 116, 44, 32, 115, 99, 114, 105, 112, 116, 115, 44, 32, 101, 116, 99, 46, 0, 0, 0, 0, 115, 99, 114, 105, 112, 116, 32, 115, 116, 97, 116, 101, 109, 101, 110, 116, 115, 32, 0, 0, 0, 0, 0, 0, 96, 114, 1, 0, 200, 213, 1, 0, 208, 213, 1, 0, 216, 213, 1, 0, 224, 213, 1, 0, 0, 0, 0, 0, 184, 213, 1, 0, 0, 0, 0, 0, 112, 212, 1, 0, 0, 0, 0, 0, 115, 101, 108, 101, 99, 116, 0, 0, 111, 112, 116, 105, 111, 110, 32, 115, 101, 108, 101, 99, 116, 111, 114, 32, 0, 0, 0, 0, 0, 0, 0, 0, 160, 205, 1, 0, 200, 205, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 216, 179, 1, 0, 216, 191, 1, 0, 64, 181, 1, 0, 72, 181, 1, 0, 88, 181, 1, 0, 104, 181, 1, 0, 120, 181, 1, 0, 136, 181, 1, 0, 152, 181, 1, 0, 168, 181, 1, 0, 184, 181, 1, 0, 168, 212, 1, 0, 160, 213, 1, 0, 168, 213, 1, 0, 176, 212, 1, 0, 208, 212, 1, 0, 216, 181, 1, 0, 224, 181, 1, 0, 0, 182, 1, 0, 0, 0, 0, 0, 115, 109, 97, 108, 108, 32, 116, 101, 120, 116, 32, 115, 116, 121, 108, 101, 0, 0, 0, 0, 0, 0, 0, 0, 103, 101, 110, 101, 114, 105, 99, 32, 108, 97, 110, 103, 117, 97, 103, 101, 47, 115, 116, 121, 108, 101, 32, 99, 111, 110, 116, 97, 105, 110, 101, 114, 32, 0, 0, 0, 0, 0, 0, 0, 115, 116, 114, 105, 107, 101, 45, 116, 104, 114, 111, 117, 103, 104, 32, 116, 101, 120, 116, 0, 0, 0, 0, 0, 115, 116, 114, 111, 110, 103, 32, 101, 109, 112, 104, 97, 115, 105, 115, 0, 115, 116, 121, 108, 101, 32, 105, 110, 102, 111, 32, 0, 0, 0, 0, 0, 216, 179, 1, 0, 216, 191, 1, 0, 152, 213, 1, 0, 216, 119, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 115, 117, 98, 115, 99, 114, 105, 112, 116, 0, 0, 0, 0, 0, 0, 0, 115, 117, 112, 101, 114, 115, 99, 114, 105, 112, 116, 32, 0, 0, 0, 0, 120, 121, 1, 0, 176, 190, 1, 0, 32, 191, 1, 0, 128, 118, 1, 0, 144, 118, 1, 0, 136, 118, 1, 0, 120, 118, 1, 0, 0, 0, 0, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 216, 179, 1, 0, 216, 191, 1, 0, 64, 181, 1, 0, 72, 181, 1, 0, 88, 181, 1, 0, 104, 181, 1, 0, 120, 181, 1, 0, 136, 181, 1, 0, 152, 181, 1, 0, 168, 181, 1, 0, 184, 181, 1, 0, 80, 213, 1, 0, 248, 212, 1, 0, 88, 213, 1, 0, 248, 119, 1, 0, 96, 213, 1, 0, 104, 213, 1, 0, 120, 213, 1, 0, 136, 213, 1, 0, 0, 0, 0, 0, 48, 213, 1, 0, 128, 212, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 116, 97, 98, 108, 101, 32, 98, 111, 100, 121, 32, 0, 0, 0, 0, 0, 120, 118, 1, 0, 0, 0, 0, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 216, 179, 1, 0, 216, 191, 1, 0, 64, 181, 1, 0, 72, 181, 1, 0, 88, 181, 1, 0, 104, 181, 1, 0, 120, 181, 1, 0, 136, 181, 1, 0, 152, 181, 1, 0, 168, 181, 1, 0, 184, 181, 1, 0, 48, 213, 1, 0, 56, 213, 1, 0, 64, 213, 1, 0, 72, 213, 1, 0, 0, 0, 0, 0, 116, 97, 98, 108, 101, 32, 100, 97, 116, 97, 32, 99, 101, 108, 108, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 216, 179, 1, 0, 216, 191, 1, 0, 64, 181, 1, 0, 72, 181, 1, 0, 88, 181, 1, 0, 104, 181, 1, 0, 120, 181, 1, 0, 136, 181, 1, 0, 152, 181, 1, 0, 168, 181, 1, 0, 184, 181, 1, 0, 40, 121, 1, 0, 8, 213, 1, 0, 16, 213, 1, 0, 24, 213, 1, 0, 32, 213, 1, 0, 40, 213, 1, 0, 48, 213, 1, 0, 56, 213, 1, 0, 64, 213, 1, 0, 72, 213, 1, 0, 0, 0, 0, 0, 240, 212, 1, 0, 128, 212, 1, 0, 248, 212, 1, 0, 0, 213, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 116, 101, 120, 116, 97, 114, 101, 97, 0, 0, 0, 0, 0, 0, 0, 0, 109, 117, 108, 116, 105, 45, 108, 105, 110, 101, 32, 116, 101, 120, 116, 32, 102, 105, 101, 108, 100, 32, 0, 0, 152, 212, 1, 0, 160, 212, 1, 0, 24, 115, 1, 0, 216, 119, 1, 0, 216, 179, 1, 0, 216, 191, 1, 0, 64, 181, 1, 0, 72, 181, 1, 0, 88, 181, 1, 0, 104, 181, 1, 0, 120, 181, 1, 0, 136, 181, 1, 0, 152, 181, 1, 0, 168, 181, 1, 0, 184, 181, 1, 0, 168, 212, 1, 0, 176, 212, 1, 0, 192, 212, 1, 0, 208, 212, 1, 0, 224, 212, 1, 0, 216, 181, 1, 0, 224, 181, 1, 0, 16, 182, 1, 0, 0, 182, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 136, 212, 1, 0, 144, 212, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 116, 97, 98, 108, 101, 32, 102, 111, 111, 116, 101, 114, 32, 0, 0, 0, 116, 97, 98, 108, 101, 32, 104, 101, 97, 100, 101, 114, 32, 99, 101, 108, 108, 0, 0, 0, 0, 0, 0, 0, 116, 97, 98, 108, 101, 32, 104, 101, 97, 100, 101, 114, 32, 0, 0, 0, 100, 111, 99, 117, 109, 101, 110, 116, 32, 116, 105, 116, 108, 101, 32, 0, 116, 97, 98, 108, 101, 32, 114, 111, 119, 32, 0, 0, 0, 0, 0, 0, 112, 118, 1, 0, 104, 118, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 128, 212, 1, 0, 0, 0, 0, 0, 116, 101, 108, 101, 116, 121, 112, 101, 32, 111, 114, 32, 109, 111, 110, 111, 115, 112, 97, 99, 101, 100, 32, 116, 101, 120, 116, 32, 115, 116, 121, 108, 101, 0, 0, 0, 0, 0, 0, 0, 117, 110, 100, 101, 114, 108, 105, 110, 101, 100, 32, 116, 101, 120, 116, 32, 115, 116, 121, 108, 101, 0, 0, 0, 117, 108, 0, 0, 0, 0, 0, 0, 117, 110, 111, 114, 100, 101, 114, 101, 100, 32, 108, 105, 115, 116, 32, 0, 112, 212, 1, 0, 120, 212, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 105, 110, 115, 116, 97, 110, 99, 101, 32, 111, 102, 32, 97, 32, 118, 97, 114, 105, 97, 98, 108, 101, 32, 111, 114, 32, 112, 114, 111, 103, 114, 97, 109, 32, 97, 114, 103, 117, 109, 101, 110, 116, 0, 0, 0, 0, 0, 0, 116, 121, 112, 101, 0, 0, 0, 0, 99, 111, 109, 112, 97, 99, 116, 0, 98, 103, 99, 111, 108, 111, 114, 0, 114, 111, 119, 115, 0, 0, 0, 0, 99, 111, 108, 115, 0, 0, 0, 0, 105, 100, 0, 0, 0, 0, 0, 0, 99, 108, 97, 115, 115, 0, 0, 0, 110, 97, 109, 101, 0, 0, 0, 0, 100, 105, 115, 97, 98, 108, 101, 100, 0, 0, 0, 0, 0, 0, 0, 0, 114, 101, 97, 100, 111, 110, 108, 121, 0, 0, 0, 0, 0, 0, 0, 0, 116, 97, 98, 105, 110, 100, 101, 120, 0, 0, 0, 0, 0, 0, 0, 0, 97, 99, 99, 101, 115, 115, 107, 101, 121, 0, 0, 0, 0, 0, 0, 0, 110, 111, 119, 114, 97, 112, 0, 0, 119, 105, 100, 116, 104, 0, 0, 0, 104, 101, 105, 103, 104, 116, 0, 0, 97, 120, 105, 115, 0, 0, 0, 0, 104, 101, 97, 100, 101, 114, 115, 0, 115, 99, 111, 112, 101, 0, 0, 0, 114, 111, 119, 115, 112, 97, 110, 0, 99, 111, 108, 115, 112, 97, 110, 0, 97, 108, 105, 103, 110, 0, 0, 0, 99, 104, 97, 114, 0, 0, 0, 0, 99, 104, 97, 114, 111, 102, 102, 0, 118, 97, 108, 105, 103, 110, 0, 0, 115, 117, 109, 109, 97, 114, 121, 0, 98, 111, 114, 100, 101, 114, 0, 0, 114, 117, 108, 101, 115, 0, 0, 0, 99, 101, 108, 108, 115, 112, 97, 99, 105, 110, 103, 0, 0, 0, 0, 0, 99, 101, 108, 108, 112, 97, 100, 100, 105, 110, 103, 0, 0, 0, 0, 0, 100, 97, 116, 97, 112, 97, 103, 101, 115, 105, 122, 101, 0, 0, 0, 0, 109, 101, 100, 105, 97, 0, 0, 0, 115, 105, 122, 101, 0, 0, 0, 0, 109, 117, 108, 116, 105, 112, 108, 101, 0, 0, 0, 0, 0, 0, 0, 0, 108, 97, 110, 103, 117, 97, 103, 101, 0, 0, 0, 0, 0, 0, 0, 0, 115, 114, 99, 0, 0, 0, 0, 0, 100, 101, 102, 101, 114, 0, 0, 0, 101, 118, 101, 110, 116, 0, 0, 0, 102, 111, 114, 0, 0, 0, 0, 0, 118, 97, 108, 117, 101, 0, 0, 0, 118, 97, 108, 117, 101, 116, 121, 112, 101, 0, 0, 0, 0, 0, 0, 0, 115, 101, 108, 101, 99, 116, 101, 100, 0, 0, 0, 0, 0, 0, 0, 0, 115, 116, 97, 114, 116, 0, 0, 0, 104, 115, 112, 97, 99, 101, 0, 0, 118, 115, 112, 97, 99, 101, 0, 0, 100, 101, 99, 108, 97, 114, 101, 0, 99, 108, 97, 115, 115, 105, 100, 0, 99, 111, 100, 101, 98, 97, 115, 101, 0, 0, 0, 0, 0, 0, 0, 0, 100, 97, 116, 97, 0, 0, 0, 0, 99, 111, 100, 101, 116, 121, 112, 101, 0, 0, 0, 0, 0, 0, 0, 0, 97, 114, 99, 104, 105, 118, 101, 0, 115, 116, 97, 110, 100, 98, 121, 0, 117, 115, 101, 109, 97, 112, 0, 0, 115, 99, 104, 101, 109, 101, 0, 0, 104, 114, 101, 102, 0, 0, 0, 0, 104, 114, 101, 102, 108, 97, 110, 103, 0, 0, 0, 0, 0, 0, 0, 0, 114, 101, 108, 0, 0, 0, 0, 0, 114, 101, 118, 0, 0, 0, 0, 0, 112, 114, 111, 109, 112, 116, 0, 0, 99, 104, 101, 99, 107, 101, 100, 0, 109, 97, 120, 108, 101, 110, 103, 116, 104, 0, 0, 0, 0, 0, 0, 0, 97, 108, 116, 0, 0, 0, 0, 0, 105, 115, 109, 97, 112, 0, 0, 0, 97, 99, 99, 101, 112, 116, 0, 0, 108, 111, 110, 103, 100, 101, 115, 99, 0, 0, 0, 0, 0, 0, 0, 0, 102, 114, 97, 109, 101, 98, 111, 114, 100, 101, 114, 0, 0, 0, 0, 0, 109, 97, 114, 103, 105, 110, 119, 105, 100, 116, 104, 0, 0, 0, 0, 0, 109, 97, 114, 103, 105, 110, 104, 101, 105, 103, 104, 116, 0, 0, 0, 0, 115, 99, 114, 111, 108, 108, 105, 110, 103, 0, 0, 0, 0, 0, 0, 0, 118, 101, 114, 115, 105, 111, 110, 0, 110, 111, 115, 104, 97, 100, 101, 0, 112, 114, 111, 102, 105, 108, 101, 0, 110, 111, 114, 101, 115, 105, 122, 101, 0, 0, 0, 0, 0, 0, 0, 0, 97, 99, 116, 105, 111, 110, 0, 0, 109, 101, 116, 104, 111, 100, 0, 0, 101, 110, 99, 116, 121, 112, 101, 0, 97, 99, 99, 101, 112, 116, 45, 99, 104, 97, 114, 115, 101, 116, 0, 0, 99, 111, 108, 111, 114, 0, 0, 0, 102, 97, 99, 101, 0, 0, 0, 0, 104, 105, 100, 100, 101, 110, 0, 0, 112, 97, 108, 101, 116, 116, 101, 0, 112, 108, 117, 103, 105, 110, 115, 112, 97, 99, 101, 0, 0, 0, 0, 0, 112, 108, 117, 103, 105, 110, 117, 114, 108, 0, 0, 0, 0, 0, 0, 0, 117, 110, 105, 116, 115, 0, 0, 0, 100, 97, 116, 101, 116, 105, 109, 101, 0, 0, 0, 0, 0, 0, 0, 0, 99, 108, 101, 97, 114, 0, 0, 0, 98, 97, 99, 107, 103, 114, 111, 117, 110, 100, 0, 0, 0, 0, 0, 0, 116, 101, 120, 116, 0, 0, 0, 0, 118, 108, 105, 110, 107, 0, 0, 0, 97, 108, 105, 110, 107, 0, 0, 0, 115, 104, 97, 112, 101, 0, 0, 0, 99, 111, 111, 114, 100, 115, 0, 0, 110, 111, 104, 114, 101, 102, 0, 0, 116, 97, 114, 103, 101, 116, 0, 0, 108, 105, 115, 116, 105, 110, 103, 0, 120, 109, 112, 0, 0, 0, 0, 0, 104, 116, 109, 108, 0, 0, 0, 0, 104, 101, 97, 100, 0, 0, 0, 0, 109, 101, 116, 97, 0, 0, 0, 0, 104, 116, 116, 112, 45, 101, 113, 117, 105, 118, 0, 0, 0, 0, 0, 0, 67, 111, 110, 116, 101, 110, 116, 45, 84, 121, 112, 101, 0, 0, 0, 0, 99, 111, 110, 116, 101, 110, 116, 0, 99, 104, 97, 114, 115, 101, 116, 61, 0, 0, 0, 0, 0, 0, 0, 0, 67, 104, 97, 114, 115, 101, 116, 61, 0, 0, 0, 0, 0, 0, 0, 0, 67, 72, 65, 82, 83, 69, 84, 61, 0, 0, 0, 0, 0, 0, 0, 0, 99, 104, 97, 114, 115, 101, 116, 32, 61, 0, 0, 0, 0, 0, 0, 0, 67, 104, 97, 114, 115, 101, 116, 32, 61, 0, 0, 0, 0, 0, 0, 0, 67, 72, 65, 82, 83, 69, 84, 32, 61, 0, 0, 0, 0, 0, 0, 0, 116, 101, 120, 116, 47, 104, 116, 109, 108, 59, 32, 99, 104, 97, 114, 115, 101, 116, 61, 37, 115, 0, 0, 0, 200, 218, 1, 0, 208, 218, 1, 0, 216, 218, 1, 0, 224, 218, 1, 0, 232, 218, 1, 0, 248, 218, 1, 0, 0, 219, 1, 0, 16, 219, 1, 0, 24, 219, 1, 0, 40, 219, 1, 0, 48, 219, 1, 0, 56, 219, 1, 0, 72, 219, 1, 0, 0, 0, 0, 0, 72, 84, 77, 76, 0, 0, 0, 0, 97, 115, 99, 105, 105, 0, 0, 0, 115, 99, 114, 105, 112, 116, 0, 0, 115, 116, 121, 108, 101, 0, 0, 0, 60, 33, 45, 45, 0, 0, 0, 0, 45, 45, 62, 0, 0, 0, 0, 0, 60, 63, 0, 0, 0, 0, 0, 0, 32, 0, 0, 0, 0, 0, 0, 0, 62, 0, 0, 0, 0, 0, 0, 0, 38, 0, 0, 0, 0, 0, 0, 0, 59, 0, 0, 0, 0, 0, 0, 0, 60, 0, 0, 0, 0, 0, 0, 0, 58, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 98, 111, 100, 121, 0, 0, 0, 0, 62, 60, 47, 0, 0, 0, 0, 0, 60, 47, 0, 0, 0, 0, 0, 0, 85, 84, 70, 45, 56, 0, 0, 0, 60, 33, 68, 79, 67, 84, 89, 80, 69, 32, 0, 0, 0, 0, 0, 0, 32, 80, 85, 66, 76, 73, 67, 32, 0, 0, 0, 0, 0, 0, 0, 0, 32, 83, 89, 83, 84, 69, 77, 32, 0, 0, 0, 0, 0, 0, 0, 0, 62, 10, 0, 0, 0, 0, 0, 0, 61, 0, 0, 0, 0, 0, 0, 0, 104, 114, 101, 102, 0, 0, 0, 0, 97, 99, 116, 105, 111, 110, 0, 0, 115, 114, 99, 0, 0, 0, 0, 0, 110, 97, 109, 101, 0, 0, 0, 0, 97, 0, 0, 0, 0, 0, 0, 0, 34, 0, 0, 0, 0, 0, 0, 0, 64, 47, 58, 61, 63, 59, 35, 37, 38, 44, 43, 0, 0, 0, 0, 0, 61, 34, 34, 0, 0, 0, 0, 0, 115, 116, 114, 105, 110, 103, 32, 105, 115, 32, 110, 111, 116, 32, 105, 110, 32, 85, 84, 70, 45, 56, 10, 0, 105, 110, 118, 97, 108, 105, 100, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 118, 97, 108, 117, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 117, 110, 107, 110, 111, 119, 110, 32, 101, 110, 99, 111, 100, 105, 110, 103, 32, 37, 115, 10, 0, 0, 0, 0, 72, 84, 77, 76, 32, 104, 97, 115, 32, 110, 111, 32, 68, 79, 67, 84, 89, 80, 69, 10, 0, 0, 0, 0, 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 101, 114, 114, 111, 114, 32, 110, 117, 109, 98, 101, 114, 10, 0, 0, 0, 0, 0, 0, 0, 0, 99, 104, 101, 99, 107, 101, 100, 0, 99, 111, 109, 112, 97, 99, 116, 0, 100, 101, 99, 108, 97, 114, 101, 0, 100, 101, 102, 101, 114, 0, 0, 0, 100, 105, 115, 97, 98, 108, 101, 100, 0, 0, 0, 0, 0, 0, 0, 0, 105, 115, 109, 97, 112, 0, 0, 0, 109, 117, 108, 116, 105, 112, 108, 101, 0, 0, 0, 0, 0, 0, 0, 0, 110, 111, 104, 114, 101, 102, 0, 0, 110, 111, 114, 101, 115, 105, 122, 101, 0, 0, 0, 0, 0, 0, 0, 0, 110, 111, 115, 104, 97, 100, 101, 0, 110, 111, 119, 114, 97, 112, 0, 0, 114, 101, 97, 100, 111, 110, 108, 121, 0, 0, 0, 0, 0, 0, 0, 0, 115, 101, 108, 101, 99, 116, 101, 100, 0, 0, 0, 0, 0, 0, 0, 0, 40, 78, 85, 76, 76, 41, 0, 0, 35, 37, 88, 0, 0, 0, 0, 0, 46, 46, 46, 0, 0, 0, 0, 0, 78, 85, 76, 76, 10, 0, 0, 0, 45, 0, 0, 0, 0, 0, 0, 0, 97, 0, 0, 0, 0, 0, 0, 0, 116, 0, 0, 0, 0, 0, 0, 0, 67, 0, 0, 0, 0, 0, 0, 0, 101, 0, 0, 0, 0, 0, 0, 0, 69, 0, 0, 0, 0, 0, 0, 0, 112, 0, 0, 0, 0, 0, 0, 0, 99, 0, 0, 0, 0, 0, 0, 0, 100, 0, 0, 0, 0, 0, 0, 0, 104, 0, 0, 0, 0, 0, 0, 0, 84, 0, 0, 0, 0, 0, 0, 0, 70, 0, 0, 0, 0, 0, 0, 0, 78, 0, 0, 0, 0, 0, 0, 0, 110, 0, 0, 0, 0, 0, 0, 0, 63, 0, 0, 0, 0, 0, 0, 0, 32, 37, 56, 100, 32, 0, 0, 0, 37, 115, 58, 0, 0, 0, 0, 0, 37, 115, 0, 0, 0, 0, 0, 0, 100, 101, 102, 97, 117, 108, 116, 32, 45, 62, 32, 37, 115, 0, 0, 0, 37, 115, 32, 45, 62, 32, 37, 115, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 37, 115, 58, 32, 110, 111, 32, 115, 117, 99, 104, 32, 110, 111, 100, 101, 10, 0, 0, 0, 0, 0, 0, 0, 37, 115, 32, 105, 115, 32, 97, 32, 66, 111, 111, 108, 101, 97, 110, 10, 0, 0, 0, 0, 0, 0, 0, 0, 37, 115, 32, 105, 115, 32, 97, 32, 110, 117, 109, 98, 101, 114, 10, 0, 37, 115, 32, 105, 115, 32, 97, 32, 115, 116, 114, 105, 110, 103, 10, 0, 37, 115, 32, 105, 115, 32, 97, 32, 112, 111, 105, 110, 116, 10, 0, 0, 37, 115, 32, 105, 115, 32, 97, 32, 114, 97, 110, 103, 101, 10, 0, 0, 37, 115, 32, 105, 115, 32, 117, 115, 101, 114, 45, 100, 101, 102, 105, 110, 101, 100, 10, 0, 0, 0, 0, 0, 37, 115, 32, 105, 115, 32, 97, 110, 32, 88, 83, 76, 84, 32, 118, 97, 108, 117, 101, 32, 116, 114, 101, 101, 10, 0, 0, 0, 0, 0, 0, 0, 32, 78, 111, 32, 98, 97, 115, 101, 32, 102, 111, 117, 110, 100, 32, 33, 33, 33, 10, 0, 0, 0, 0, 0, 37, 115, 10, 0, 0, 0, 0, 0, 70, 97, 105, 108, 101, 100, 32, 116, 111, 32, 119, 114, 105, 116, 101, 32, 116, 111, 32, 37, 115, 10, 0, 0, 119, 0, 0, 0, 0, 0, 0, 0, 70, 97, 105, 108, 101, 100, 32, 116, 111, 32, 115, 97, 118, 101, 32, 116, 111, 32, 37, 115, 10, 0, 0, 0, 84, 111, 32, 115, 97, 118, 101, 32, 116, 111, 32, 115, 117, 98, 112, 97, 114, 116, 115, 32, 111, 102, 32, 97, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 117, 115, 101, 32, 116, 104, 101, 32, 39, 119, 114, 105, 116, 101, 39, 32, 99, 111, 109, 109, 97, 110, 100, 10, 0, 0, 0, 0, 0, 0, 47, 10, 0, 0, 0, 0, 0, 0, 32, 32, 0, 0, 0, 0, 0, 0, 37, 115, 32, 62, 32, 0, 0, 0, 47, 0, 0, 0, 0, 0, 0, 0, 37, 115, 58, 37, 115, 32, 62, 32, 0, 0, 0, 0, 0, 0, 0, 0, 63, 32, 62, 32, 0, 0, 0, 0, 101, 120, 105, 116, 0, 0, 0, 0, 113, 117, 105, 116, 0, 0, 0, 0, 98, 121, 101, 0, 0, 0, 0, 0, 104, 101, 108, 112, 0, 0, 0, 0, 9, 98, 97, 115, 101, 32, 32, 32, 32, 32, 32, 32, 32, 32, 100, 105, 115, 112, 108, 97, 121, 32, 88, 77, 76, 32, 98, 97, 115, 101, 32, 111, 102, 32, 116, 104, 101, 32, 110, 111, 100, 101, 10, 0, 0, 0, 0, 0, 9, 115, 101, 116, 98, 97, 115, 101, 32, 85, 82, 73, 32, 32, 99, 104, 97, 110, 103, 101, 32, 116, 104, 101, 32, 88, 77, 76, 32, 98, 97, 115, 101, 32, 111, 102, 32, 116, 104, 101, 32, 110, 111, 100, 101, 10, 0, 0, 9, 98, 121, 101, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 108, 101, 97, 118, 101, 32, 115, 104, 101, 108, 108, 10, 0, 0, 0, 0, 0, 0, 9, 99, 97, 116, 32, 91, 110, 111, 100, 101, 93, 32, 32, 32, 100, 105, 115, 112, 108, 97, 121, 32, 110, 111, 100, 101, 32, 111, 114, 32, 99, 117, 114, 114, 101, 110, 116, 32, 110, 111, 100, 101, 10, 0, 0, 0, 0, 0, 9, 99, 100, 32, 91, 112, 97, 116, 104, 93, 32, 32, 32, 32, 99, 104, 97, 110, 103, 101, 32, 100, 105, 114, 101, 99, 116, 111, 114, 121, 32, 116, 111, 32, 112, 97, 116, 104, 32, 111, 114, 32, 116, 111, 32, 114, 111, 111, 116, 10, 0, 0, 0, 0, 0, 0, 9, 100, 105, 114, 32, 91, 112, 97, 116, 104, 93, 32, 32, 32, 100, 117, 109, 112, 115, 32, 105, 110, 102, 111, 114, 109, 97, 116, 105, 111, 110, 115, 32, 97, 98, 111, 117, 116, 32, 116, 104, 101, 32, 110, 111, 100, 101, 32, 40, 110, 97, 109, 101, 115, 112, 97, 99, 101, 44, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 115, 44, 32, 99, 111, 110, 116, 101, 110, 116, 41, 10, 0, 0, 0, 0, 0, 0, 0, 9, 100, 117, 32, 91, 112, 97, 116, 104, 93, 32, 32, 32, 32, 115, 104, 111, 119, 32, 116, 104, 101, 32, 115, 116, 114, 117, 99, 116, 117, 114, 101, 32, 111, 102, 32, 116, 104, 101, 32, 115, 117, 98, 116, 114, 101, 101, 32, 117, 110, 100, 101, 114, 32, 112, 97, 116, 104, 32, 111, 114, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101, 110, 116, 32, 110, 111, 100, 101, 10, 0, 9, 101, 120, 105, 116, 32, 32, 32, 32, 32, 32, 32, 32, 32, 108, 101, 97, 118, 101, 32, 115, 104, 101, 108, 108, 10, 0, 0, 0, 0, 0, 0, 9, 104, 101, 108, 112, 32, 32, 32, 32, 32, 32, 32, 32, 32, 100, 105, 115, 112, 108, 97, 121, 32, 116, 104, 105, 115, 32, 104, 101, 108, 112, 10, 0, 0, 0, 0, 0, 0, 0, 0, 9, 102, 114, 101, 101, 32, 32, 32, 32, 32, 32, 32, 32, 32, 100, 105, 115, 112, 108, 97, 121, 32, 109, 101, 109, 111, 114, 121, 32, 117, 115, 97, 103, 101, 10, 0, 0, 0, 0, 0, 9, 108, 111, 97, 100, 32, 91, 110, 97, 109, 101, 93, 32, 32, 108, 111, 97, 100, 32, 97, 32, 110, 101, 119, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 119, 105, 116, 104, 32, 110, 97, 109, 101, 10, 0, 0, 0, 0, 9, 108, 115, 32, 91, 112, 97, 116, 104, 93, 32, 32, 32, 32, 108, 105, 115, 116, 32, 99, 111, 110, 116, 101, 110, 116, 115, 32, 111, 102, 32, 112, 97, 116, 104, 32, 111, 114, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101, 110, 116, 32, 100, 105, 114, 101, 99, 116, 111, 114, 121, 10, 0, 0, 0, 9, 115, 101, 116, 32, 120, 109, 108, 95, 102, 114, 97, 103, 109, 101, 110, 116, 32, 114, 101, 112, 108, 97, 99, 101, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101, 110, 116, 32, 110, 111, 100, 101, 32, 99, 111, 110, 116, 101, 110, 116, 32, 119, 105, 116, 104, 32, 116, 104, 101, 32, 102, 114, 97, 103, 109, 101, 110, 116, 32, 112, 97, 114, 115, 101, 100, 32, 105, 110, 32, 99, 111, 110, 116, 101, 120, 116, 10, 0, 9, 120, 112, 97, 116, 104, 32, 101, 120, 112, 114, 32, 32, 32, 101, 118, 97, 108, 117, 97, 116, 101, 32, 116, 104, 101, 32, 88, 80, 97, 116, 104, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 105, 110, 32, 116, 104, 97, 116, 32, 99, 111, 110, 116, 101, 120, 116, 32, 97, 110, 100, 32, 112, 114, 105, 110, 116, 32, 116, 104, 101, 32, 114, 101, 115, 117, 108, 116, 10, 0, 0, 0, 0, 0, 0, 0, 9, 115, 101, 116, 110, 115, 32, 110, 115, 114, 101, 103, 32, 32, 114, 101, 103, 105, 115, 116, 101, 114, 32, 97, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 116, 111, 32, 97, 32, 112, 114, 101, 102, 105, 120, 32, 105, 110, 32, 116, 104, 101, 32, 88, 80, 97, 116, 104, 32, 101, 118, 97, 108, 117, 97, 116, 105, 111, 110, 32, 99, 111, 110, 116, 101, 120, 116, 10, 0, 9, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 102, 111, 114, 109, 97, 116, 32, 102, 111, 114, 32, 110, 115, 114, 101, 103, 32, 105, 115, 58, 32, 112, 114, 101, 102, 105, 120, 61, 91, 110, 115, 117, 114, 105, 93, 32, 40, 105, 46, 101, 46, 32, 112, 114, 101, 102, 105, 120, 61, 32, 117, 110, 115, 101, 116, 115, 32, 97, 32, 112, 114, 101, 102, 105, 120, 41, 10, 0, 0, 0, 0, 0, 0, 0, 9, 115, 101, 116, 114, 111, 111, 116, 110, 115, 32, 32, 32, 32, 114, 101, 103, 105, 115, 116, 101, 114, 32, 97, 108, 108, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 102, 111, 117, 110, 100, 32, 111, 110, 32, 116, 104, 101, 32, 114, 111, 111, 116, 32, 101, 108, 101, 109, 101, 110, 116, 10, 0, 9, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 116, 104, 101, 32, 100, 101, 102, 97, 117, 108, 116, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 105, 102, 32, 97, 110, 121, 32, 117, 115, 101, 115, 32, 39, 100, 101, 102, 97, 117, 108, 116, 110, 115, 39, 32, 112, 114, 101, 102, 105, 120, 10, 0, 0, 0, 0, 0, 9, 112, 119, 100, 32, 32, 32, 32, 32, 32, 32, 32, 32, 32, 100, 105, 115, 112, 108, 97, 121, 32, 99, 117, 114, 114, 101, 110, 116, 32, 119, 111, 114, 107, 105, 110, 103, 32, 100, 105, 114, 101, 99, 116, 111, 114, 121, 10, 0, 0, 0, 0, 0, 0, 0, 0, 9, 119, 104, 101, 114, 101, 105, 115, 32, 32, 32, 32, 32, 32, 100, 105, 115, 112, 108, 97, 121, 32, 97, 98, 115, 111, 108, 117, 116, 101, 32, 112, 97, 116, 104, 32, 111, 102, 32, 91, 112, 97, 116, 104, 93, 32, 111, 114, 32, 99, 117, 114, 114, 101, 110, 116, 32, 119, 111, 114, 107, 105, 110, 103, 32, 100, 105, 114, 101, 99, 116, 111, 114, 121, 10, 0, 0, 0, 0, 0, 9, 113, 117, 105, 116, 32, 32, 32, 32, 32, 32, 32, 32, 32, 108, 101, 97, 118, 101, 32, 115, 104, 101, 108, 108, 10, 0, 0, 0, 0, 0, 0, 9, 115, 97, 118, 101, 32, 91, 110, 97, 109, 101, 93, 32, 32, 115, 97, 118, 101, 32, 116, 104, 105, 115, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 116, 111, 32, 110, 97, 109, 101, 32, 111, 114, 32, 116, 104, 101, 32, 111, 114, 105, 103, 105, 110, 97, 108, 32, 110, 97, 109, 101, 10, 0, 0, 9, 119, 114, 105, 116, 101, 32, 91, 110, 97, 109, 101, 93, 32, 119, 114, 105, 116, 101, 32, 116, 104, 101, 32, 99, 117, 114, 114, 101, 110, 116, 32, 110, 111, 100, 101, 32, 116, 111, 32, 116, 104, 101, 32, 102, 105, 108, 101, 110, 97, 109, 101, 10, 0, 0, 0, 9, 118, 97, 108, 105, 100, 97, 116, 101, 32, 32, 32, 32, 32, 99, 104, 101, 99, 107, 32, 116, 104, 101, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 102, 111, 114, 32, 101, 114, 114, 111, 114, 115, 10, 0, 0, 0, 0, 9, 114, 101, 108, 97, 120, 110, 103, 32, 114, 110, 103, 32, 32, 118, 97, 108, 105, 100, 97, 116, 101, 32, 116, 104, 101, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 97, 103, 97, 105, 115, 110, 116, 32, 116, 104, 101, 32, 82, 101, 108, 97, 120, 45, 78, 71, 32, 115, 99, 104, 101, 109, 97, 115, 10, 0, 0, 0, 0, 0, 0, 0, 9, 103, 114, 101, 112, 32, 115, 116, 114, 105, 110, 103, 32, 32, 115, 101, 97, 114, 99, 104, 32, 102, 111, 114, 32, 97, 32, 115, 116, 114, 105, 110, 103, 32, 105, 110, 32, 116, 104, 101, 32, 115, 117, 98, 116, 114, 101, 101, 10, 0, 0, 0, 0, 0, 0, 0, 118, 97, 108, 105, 100, 97, 116, 101, 0, 0, 0, 0, 0, 0, 0, 0, 108, 111, 97, 100, 0, 0, 0, 0, 114, 101, 108, 97, 120, 110, 103, 0, 115, 97, 118, 101, 0, 0, 0, 0, 119, 114, 105, 116, 101, 0, 0, 0, 87, 114, 105, 116, 101, 32, 99, 111, 109, 109, 97, 110, 100, 32, 114, 101, 113, 117, 105, 114, 101, 115, 32, 97, 32, 102, 105, 108, 101, 110, 97, 109, 101, 32, 97, 114, 103, 117, 109, 101, 110, 116, 10, 0, 0, 0, 0, 0, 103, 114, 101, 112, 0, 0, 0, 0, 102, 114, 101, 101, 0, 0, 0, 0, 37, 100, 0, 0, 0, 0, 0, 0, 112, 119, 100, 0, 0, 0, 0, 0, 100, 117, 0, 0, 0, 0, 0, 0, 98, 97, 115, 101, 0, 0, 0, 0, 115, 101, 116, 0, 0, 0, 0, 0, 115, 101, 116, 110, 115, 0, 0, 0, 115, 101, 116, 110, 115, 58, 32, 112, 114, 101, 102, 105, 120, 61, 91, 110, 115, 117, 114, 105, 93, 32, 114, 101, 113, 117, 105, 114, 101, 100, 10, 0, 115, 101, 116, 114, 111, 111, 116, 110, 115, 0, 0, 0, 0, 0, 0, 0, 120, 112, 97, 116, 104, 0, 0, 0, 120, 112, 97, 116, 104, 58, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 114, 101, 113, 117, 105, 114, 101, 100, 10, 0, 0, 0, 0, 0, 115, 101, 116, 98, 97, 115, 101, 0, 108, 115, 0, 0, 0, 0, 0, 0, 100, 105, 114, 0, 0, 0, 0, 0, 119, 104, 101, 114, 101, 105, 115, 0, 99, 100, 0, 0, 0, 0, 0, 0, 99, 97, 110, 110, 111, 116, 32, 99, 100, 32, 116, 111, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 10, 0, 37, 115, 32, 105, 115, 32, 97, 32, 37, 100, 32, 78, 111, 100, 101, 32, 83, 101, 116, 10, 0, 0, 0, 0, 37, 115, 32, 105, 115, 32, 97, 110, 32, 101, 109, 112, 116, 121, 32, 78, 111, 100, 101, 32, 83, 101, 116, 10, 0, 0, 0, 0, 0, 0, 0, 0, 99, 97, 116, 0, 0, 0, 0, 0, 32, 45, 45, 45, 45, 45, 45, 45, 10, 0, 0, 0, 0, 0, 0, 0, 85, 110, 107, 110, 111, 119, 110, 32, 99, 111, 109, 109, 97, 110, 100, 32, 37, 115, 10, 0, 0, 0, 0, 0, 100, 101, 102, 97, 117, 108, 116, 110, 115, 0, 0, 0, 0, 0, 0, 0, 69, 114, 114, 111, 114, 58, 32, 117, 110, 97, 98, 108, 101, 32, 116, 111, 32, 114, 101, 103, 105, 115, 116, 101, 114, 32, 78, 83, 32, 119, 105, 116, 104, 32, 112, 114, 101, 102, 105, 120, 61, 34, 37, 115, 34, 32, 97, 110, 100, 32, 104, 114, 101, 102, 61, 34, 37, 115, 34, 10, 0, 0, 0, 0, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 112, 97, 114, 115, 101, 32, 99, 111, 110, 116, 101, 110, 116, 10, 0, 0, 0, 0, 0, 0, 0, 0, 37, 115, 32, 58, 32, 0, 0, 0, 82, 101, 108, 97, 120, 45, 78, 71, 32, 115, 99, 104, 101, 109, 97, 32, 37, 115, 32, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 99, 111, 109, 112, 105, 108, 101, 10, 0, 0, 0, 37, 115, 32, 118, 97, 108, 105, 100, 97, 116, 101, 115, 10, 0, 0, 0, 37, 115, 32, 102, 97, 105, 108, 115, 32, 116, 111, 32, 118, 97, 108, 105, 100, 97, 116, 101, 10, 0, 0, 0, 37, 115, 32, 118, 97, 108, 105, 100, 97, 116, 105, 111, 110, 32, 103, 101, 110, 101, 114, 97, 116, 101, 100, 32, 97, 110, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 10, 0, 0, 0, 0, 0, 0, 68, 84, 68, 32, 110, 111, 100, 101, 32, 105, 115, 32, 78, 85, 76, 76, 10, 0, 0, 0, 0, 0, 0, 0, 78, 111, 100, 101, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 68, 84, 68, 0, 0, 0, 0, 0, 0, 0, 68, 84, 68, 40, 37, 115, 41, 0, 68, 84, 68, 0, 0, 0, 0, 0, 44, 32, 80, 85, 66, 76, 73, 67, 32, 37, 115, 0, 0, 0, 0, 0, 44, 32, 83, 89, 83, 84, 69, 77, 32, 37, 115, 0, 0, 0, 0, 0, 78, 111, 100, 101, 32, 104, 97, 115, 32, 110, 111, 32, 112, 97, 114, 101, 110, 116, 10, 0, 0, 0, 0, 0, 78, 111, 100, 101, 32, 104, 97, 115, 32, 110, 111, 32, 100, 111, 99, 10, 0, 0, 0, 0, 0, 0, 0, 0, 112, 115, 101, 117, 100, 111, 114, 111, 111, 116, 0, 0, 0, 0, 0, 0, 78, 111, 100, 101, 32, 100, 111, 99, 32, 100, 105, 102, 102, 101, 114, 115, 32, 102, 114, 111, 109, 32, 112, 97, 114, 101, 110, 116, 39, 115, 32, 111, 110, 101, 10, 0, 0, 0, 0, 0, 65, 116, 116, 114, 32, 104, 97, 115, 32, 110, 111, 32, 112, 114, 101, 118, 32, 97, 110, 100, 32, 110, 111, 116, 32, 102, 105, 114, 115, 116, 32, 111, 102, 32, 97, 116, 116, 114, 32, 108, 105, 115, 116, 10, 0, 0, 0, 0, 78, 111, 100, 101, 32, 104, 97, 115, 32, 110, 111, 32, 112, 114, 101, 118, 32, 97, 110, 100, 32, 110, 111, 116, 32, 102, 105, 114, 115, 116, 32, 111, 102, 32, 112, 97, 114, 101, 110, 116, 32, 108, 105, 115, 116, 10, 0, 0, 78, 111, 100, 101, 32, 112, 114, 101, 118, 45, 62, 110, 101, 120, 116, 32, 58, 32, 98, 97, 99, 107, 32, 108, 105, 110, 107, 32, 119, 114, 111, 110, 103, 10, 0, 0, 0, 0, 0, 0, 78, 111, 100, 101, 32, 104, 97, 115, 32, 110, 111, 32, 110, 101, 120, 116, 32, 97, 110, 100, 32, 110, 111, 116, 32, 108, 97, 115, 116, 32, 111, 102, 32, 112, 97, 114, 101, 110, 116, 32, 108, 105, 115, 116, 10, 0, 0, 0, 78, 111, 100, 101, 32, 110, 101, 120, 116, 45, 62, 112, 114, 101, 118, 32, 58, 32, 102, 111, 114, 119, 97, 114, 100, 32, 108, 105, 110, 107, 32, 119, 114, 111, 110, 103, 10, 0, 0, 0, 110, 98, 107, 116, 101, 120, 116, 0, 84, 101, 120, 116, 32, 110, 111, 100, 101, 32, 104, 97, 115, 32, 119, 114, 111, 110, 103, 32, 110, 97, 109, 101, 32, 39, 37, 115, 39, 0, 0, 0, 67, 111, 109, 109, 101, 110, 116, 32, 110, 111, 100, 101, 32, 104, 97, 115, 32, 119, 114, 111, 110, 103, 32, 110, 97, 109, 101, 32, 39, 37, 115, 39, 0, 0, 0, 0, 0, 0, 0, 0, 67, 68, 97, 116, 97, 32, 115, 101, 99, 116, 105, 111, 110, 32, 104, 97, 115, 32, 110, 111, 110, 32, 78, 85, 76, 76, 32, 110, 97, 109, 101, 32, 39, 37, 115, 39, 0, 0, 0, 0, 78, 97, 109, 101, 32, 105, 115, 32, 78, 85, 76, 76, 0, 0, 0, 0, 78, 97, 109, 101, 32, 105, 115, 32, 110, 111, 116, 32, 97, 110, 32, 78, 67, 78, 97, 109, 101, 32, 39, 37, 115, 39, 0, 0, 0, 0, 0, 0, 78, 97, 109, 101, 32, 105, 115, 32, 110, 111, 116, 32, 102, 114, 111, 109, 32, 116, 104, 101, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 100, 105, 99, 116, 105, 111, 110, 110, 97, 114, 121, 32, 39, 37, 115, 39, 0, 0, 83, 116, 114, 105, 110, 103, 32, 105, 115, 32, 110, 111, 116, 32, 85, 84, 70, 45, 56, 32, 37, 115, 0, 0, 82, 101, 102, 101, 114, 101, 110, 99, 101, 32, 116, 111, 32, 100, 101, 102, 97, 117, 108, 116, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 110, 111, 116, 32, 105, 110, 32, 115, 99, 111, 112, 101, 10, 0, 0, 0, 0, 82, 101, 102, 101, 114, 101, 110, 99, 101, 32, 116, 111, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 39, 37, 115, 39, 32, 110, 111, 116, 32, 105, 110, 32, 115, 99, 111, 112, 101, 10, 0, 0, 0, 0, 0, 0, 0, 82, 101, 102, 101, 114, 101, 110, 99, 101, 32, 116, 111, 32, 100, 101, 102, 97, 117, 108, 116, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 110, 111, 116, 32, 111, 110, 32, 97, 110, 99, 101, 115, 116, 111, 114, 10, 0, 82, 101, 102, 101, 114, 101, 110, 99, 101, 32, 116, 111, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 39, 37, 115, 39, 32, 110, 111, 116, 32, 111, 110, 32, 97, 110, 99, 101, 115, 116, 111, 114, 10, 0, 0, 0, 0, 68, 79, 67, 85, 77, 69, 78, 84, 32, 61, 61, 32, 78, 85, 76, 76, 32, 33, 10, 0, 0, 0, 0, 0, 110, 97, 109, 101, 61, 0, 0, 0, 118, 101, 114, 115, 105, 111, 110, 61, 0, 0, 0, 0, 0, 0, 0, 0, 101, 110, 99, 111, 100, 105, 110, 103, 61, 0, 0, 0, 0, 0, 0, 0, 85, 82, 76, 61, 0, 0, 0, 0, 115, 116, 97, 110, 100, 97, 108, 111, 110, 101, 61, 116, 114, 117, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 110, 111, 100, 101, 32, 105, 115, 32, 78, 85, 76, 76, 10, 0, 78, 111, 100, 101, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 0, 0, 0, 0, 0, 73, 110, 99, 111, 109, 112, 108, 101, 116, 101, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 37, 115, 32, 104, 114, 101, 102, 61, 78, 85, 76, 76, 10, 0, 0, 0, 0, 0, 0, 73, 110, 99, 111, 109, 112, 108, 101, 116, 101, 32, 100, 101, 102, 97, 117, 108, 116, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 104, 114, 101, 102, 61, 78, 85, 76, 76, 10, 0, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 37, 115, 32, 104, 114, 101, 102, 61, 0, 0, 0, 0, 0, 0, 100, 101, 102, 97, 117, 108, 116, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 104, 114, 101, 102, 61, 0, 77, 105, 115, 112, 108, 97, 99, 101, 100, 32, 69, 76, 69, 77, 69, 78, 84, 32, 110, 111, 100, 101, 10, 0, 77, 105, 115, 112, 108, 97, 99, 101, 100, 32, 65, 84, 84, 82, 73, 66, 85, 84, 69, 32, 110, 111, 100, 101, 10, 0, 0, 0, 0, 0, 0, 0, 77, 105, 115, 112, 108, 97, 99, 101, 100, 32, 84, 69, 88, 84, 32, 110, 111, 100, 101, 10, 0, 0, 0, 0, 77, 105, 115, 112, 108, 97, 99, 101, 100, 32, 67, 68, 65, 84, 65, 32, 110, 111, 100, 101, 10, 0, 0, 0, 77, 105, 115, 112, 108, 97, 99, 101, 100, 32, 69, 78, 84, 73, 84, 89, 82, 69, 70, 32, 110, 111, 100, 101], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 115568);
	        allocate([10, 0, 0, 0, 0, 0, 0, 0, 77, 105, 115, 112, 108, 97, 99, 101, 100, 32, 69, 78, 84, 73, 84, 89, 32, 110, 111, 100, 101, 10, 0, 0, 77, 105, 115, 112, 108, 97, 99, 101, 100, 32, 80, 73, 32, 110, 111, 100, 101, 10, 0, 0, 0, 0, 0, 0, 77, 105, 115, 112, 108, 97, 99, 101, 100, 32, 67, 79, 77, 77, 69, 78, 84, 32, 110, 111, 100, 101, 10, 0, 68, 79, 67, 85, 77, 69, 78, 84, 10, 0, 0, 0, 0, 0, 0, 0, 72, 84, 77, 76, 32, 68, 79, 67, 85, 77, 69, 78, 84, 10, 0, 0, 77, 105, 115, 112, 108, 97, 99, 101, 100, 32, 68, 79, 67, 84, 89, 80, 69, 32, 110, 111, 100, 101, 10, 0, 77, 105, 115, 112, 108, 97, 99, 101, 100, 32, 70, 82, 65, 71, 77, 69, 78, 84, 32, 110, 111, 100, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 77, 105, 115, 112, 108, 97, 99, 101, 100, 32, 78, 79, 84, 65, 84, 73, 79, 78, 32, 110, 111, 100, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 85, 110, 107, 110, 111, 119, 110, 32, 110, 111, 100, 101, 32, 116, 121, 112, 101, 32, 37, 100, 10, 0, 0, 0, 110, 111, 100, 101, 32, 105, 115, 32, 78, 85, 76, 76, 10, 0, 0, 0, 69, 76, 69, 77, 69, 78, 84, 32, 0, 0, 0, 0, 0, 0, 0, 0, 58, 0, 0, 0, 0, 0, 0, 0, 69, 114, 114, 111, 114, 44, 32, 65, 84, 84, 82, 73, 66, 85, 84, 69, 32, 102, 111, 117, 110, 100, 32, 104, 101, 114, 101, 10, 0, 0, 0, 0, 84, 69, 88, 84, 32, 110, 111, 32, 101, 110, 99, 0, 0, 0, 0, 0, 84, 69, 88, 84, 0, 0, 0, 0, 32, 99, 111, 109, 112, 97, 99, 116, 10, 0, 0, 0, 0, 0, 0, 0, 32, 105, 110, 116, 101, 114, 110, 101, 100, 10, 0, 0, 0, 0, 0, 0, 67, 68, 65, 84, 65, 95, 83, 69, 67, 84, 73, 79, 78, 10, 0, 0, 69, 78, 84, 73, 84, 89, 95, 82, 69, 70, 40, 37, 115, 41, 10, 0, 69, 78, 84, 73, 84, 89, 10, 0, 80, 73, 32, 37, 115, 10, 0, 0, 67, 79, 77, 77, 69, 78, 84, 10, 0, 0, 0, 0, 0, 0, 0, 0, 69, 114, 114, 111, 114, 44, 32, 68, 79, 67, 85, 77, 69, 78, 84, 32, 102, 111, 117, 110, 100, 32, 104, 101, 114, 101, 10, 0, 0, 0, 0, 0, 68, 79, 67, 85, 77, 69, 78, 84, 95, 84, 89, 80, 69, 10, 0, 0, 68, 79, 67, 85, 77, 69, 78, 84, 95, 70, 82, 65, 71, 10, 0, 0, 78, 79, 84, 65, 84, 73, 79, 78, 10, 0, 0, 0, 0, 0, 0, 0, 73, 78, 67, 76, 85, 68, 69, 32, 83, 84, 65, 82, 84, 10, 0, 0, 73, 78, 67, 76, 85, 68, 69, 32, 69, 78, 68, 10, 0, 0, 0, 0, 80, 66, 77, 58, 32, 100, 111, 99, 32, 61, 61, 32, 78, 85, 76, 76, 32, 33, 33, 33, 10, 0, 0, 0, 99, 111, 110, 116, 101, 110, 116, 61, 0, 0, 0, 0, 0, 0, 0, 0, 69, 110, 116, 105, 116, 121, 32, 105, 115, 32, 78, 85, 76, 76, 10, 0, 73, 78, 84, 69, 82, 78, 65, 76, 95, 71, 69, 78, 69, 82, 65, 76, 95, 69, 78, 84, 73, 84, 89, 32, 0, 0, 0, 0, 0, 0, 0, 0, 69, 88, 84, 69, 82, 78, 65, 76, 95, 71, 69, 78, 69, 82, 65, 76, 95, 80, 65, 82, 83, 69, 68, 95, 69, 78, 84, 73, 84, 89, 32, 0, 69, 88, 84, 69, 82, 78, 65, 76, 95, 71, 69, 78, 69, 82, 65, 76, 95, 85, 78, 80, 65, 82, 83, 69, 68, 95, 69, 78, 84, 73, 84, 89, 32, 0, 0, 0, 0, 0, 0, 0, 73, 78, 84, 69, 82, 78, 65, 76, 95, 80, 65, 82, 65, 77, 69, 84, 69, 82, 95, 69, 78, 84, 73, 84, 89, 32, 0, 0, 0, 0, 0, 0, 69, 88, 84, 69, 82, 78, 65, 76, 95, 80, 65, 82, 65, 77, 69, 84, 69, 82, 95, 69, 78, 84, 73, 84, 89, 32, 0, 0, 0, 0, 0, 0, 69, 78, 84, 73, 84, 89, 95, 37, 100, 32, 33, 32, 0, 0, 0, 0, 69, 120, 116, 101, 114, 110, 97, 108, 73, 68, 61, 37, 115, 10, 0, 0, 83, 121, 115, 116, 101, 109, 73, 68, 61, 37, 115, 10, 0, 0, 0, 0, 85, 82, 73, 61, 37, 115, 10, 0, 69, 110, 116, 105, 116, 121, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 105, 115, 32, 78, 85, 76, 76, 10, 0, 0, 0, 0, 0, 78, 111, 100, 101, 32, 105, 115, 32, 110, 111, 116, 32, 97, 110, 32, 101, 110, 116, 105, 116, 121, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 0, 0, 0, 0, 0, 0, 0, 69, 78, 84, 73, 84, 89, 68, 69, 67, 76, 40, 0, 0, 0, 0, 0, 41, 0, 0, 0, 0, 0, 0, 0, 69, 110, 116, 105, 116, 121, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 104, 97, 115, 32, 110, 111, 32, 110, 97, 109, 101, 0, 0, 44, 32, 105, 110, 116, 101, 114, 110, 97, 108, 10, 0, 0, 0, 0, 0, 44, 32, 101, 120, 116, 101, 114, 110, 97, 108, 32, 112, 97, 114, 115, 101, 100, 10, 0, 0, 0, 0, 0, 0, 44, 32, 117, 110, 112, 97, 114, 115, 101, 100, 10, 0, 0, 0, 0, 0, 44, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 10, 0, 0, 0, 0, 44, 32, 101, 120, 116, 101, 114, 110, 97, 108, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 10, 0, 0, 0, 44, 32, 112, 114, 101, 100, 101, 102, 105, 110, 101, 100, 10, 0, 0, 0, 32, 69, 120, 116, 101, 114, 110, 97, 108, 73, 68, 61, 37, 115, 10, 0, 32, 83, 121, 115, 116, 101, 109, 73, 68, 61, 37, 115, 10, 0, 0, 0, 32, 85, 82, 73, 61, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 0, 32, 99, 111, 110, 116, 101, 110, 116, 61, 0, 0, 0, 0, 0, 0, 0, 65, 116, 116, 114, 105, 98, 117, 116, 101, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 105, 115, 32, 78, 85, 76, 76, 10, 0, 0, 78, 111, 100, 101, 32, 105, 115, 32, 110, 111, 116, 32, 97, 110, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 0, 0, 0, 0, 65, 84, 84, 82, 68, 69, 67, 76, 40, 37, 115, 41, 0, 0, 0, 0, 78, 111, 100, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 104, 97, 115, 32, 110, 111, 32, 110, 97, 109, 101, 0, 0, 32, 102, 111, 114, 32, 37, 115, 0, 78, 111, 100, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 104, 97, 115, 32, 110, 111, 32, 101, 108, 101, 109, 101, 110, 116, 32, 110, 97, 109, 101, 0, 0, 32, 67, 68, 65, 84, 65, 0, 0, 32, 73, 68, 0, 0, 0, 0, 0, 32, 73, 68, 82, 69, 70, 0, 0, 32, 73, 68, 82, 69, 70, 83, 0, 32, 69, 78, 84, 73, 84, 89, 0, 32, 69, 78, 84, 73, 84, 73, 69, 83, 0, 0, 0, 0, 0, 0, 0, 32, 78, 77, 84, 79, 75, 69, 78, 0, 0, 0, 0, 0, 0, 0, 0, 32, 78, 77, 84, 79, 75, 69, 78, 83, 0, 0, 0, 0, 0, 0, 0, 32, 69, 78, 85, 77, 69, 82, 65, 84, 73, 79, 78, 0, 0, 0, 0, 32, 78, 79, 84, 65, 84, 73, 79, 78, 32, 0, 0, 0, 0, 0, 0, 124, 37, 115, 0, 0, 0, 0, 0, 32, 40, 37, 115, 0, 0, 0, 0, 46, 46, 46, 41, 0, 0, 0, 0, 32, 82, 69, 81, 85, 73, 82, 69, 68, 0, 0, 0, 0, 0, 0, 0, 32, 73, 77, 80, 76, 73, 69, 68, 0, 0, 0, 0, 0, 0, 0, 0, 32, 70, 73, 88, 69, 68, 0, 0, 34, 0, 0, 0, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 105, 115, 32, 78, 85, 76, 76, 10, 0, 0, 0, 0, 78, 111, 100, 101, 32, 105, 115, 32, 110, 111, 116, 32, 97, 110, 32, 101, 108, 101, 109, 101, 110, 116, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 0, 0, 0, 0, 0, 0, 69, 76, 69, 77, 68, 69, 67, 76, 40, 0, 0, 0, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 104, 97, 115, 32, 110, 111, 32, 110, 97, 109, 101, 0, 44, 32, 85, 78, 68, 69, 70, 73, 78, 69, 68, 0, 0, 0, 0, 0, 44, 32, 69, 77, 80, 84, 89, 0, 44, 32, 65, 78, 89, 0, 0, 0, 44, 32, 77, 73, 88, 69, 68, 32, 0, 0, 0, 0, 0, 0, 0, 0, 69, 110, 116, 105, 116, 105, 101, 115, 32, 105, 110, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 115, 117, 98, 115, 101, 116, 10, 0, 0, 0, 0, 78, 111, 32, 101, 110, 116, 105, 116, 105, 101, 115, 32, 105, 110, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 115, 117, 98, 115, 101, 116, 10, 0, 69, 110, 116, 105, 116, 105, 101, 115, 32, 105, 110, 32, 101, 120, 116, 101, 114, 110, 97, 108, 32, 115, 117, 98, 115, 101, 116, 10, 0, 0, 0, 0, 78, 111, 32, 101, 110, 116, 105, 116, 105, 101, 115, 32, 105, 110, 32, 101, 120, 116, 101, 114, 110, 97, 108, 32, 115, 117, 98, 115, 101, 116, 10, 0, 69, 110, 116, 105, 116, 121, 32, 105, 115, 32, 78, 85, 76, 76, 0, 0, 73, 78, 84, 69, 82, 78, 65, 76, 32, 71, 69, 78, 69, 82, 65, 76, 44, 32, 0, 0, 0, 0, 0, 0, 69, 88, 84, 69, 82, 78, 65, 76, 32, 80, 65, 82, 83, 69, 68, 44, 32, 0, 0, 0, 0, 0, 0, 0, 69, 88, 84, 69, 82, 78, 65, 76, 32, 85, 78, 80, 65, 82, 83, 69, 68, 44, 32, 0, 0, 0, 0, 0, 73, 78, 84, 69, 82, 78, 65, 76, 32, 80, 65, 82, 65, 77, 69, 84, 69, 82, 44, 32, 0, 0, 0, 0, 69, 88, 84, 69, 82, 78, 65, 76, 32, 80, 65, 82, 65, 77, 69, 84, 69, 82, 44, 32, 0, 0, 0, 0, 85, 110, 107, 110, 111, 119, 110, 32, 101, 110, 116, 105, 116, 121, 32, 116, 121, 112, 101, 32, 37, 100, 10, 0, 73, 68, 32, 34, 37, 115, 34, 0, 83, 89, 83, 84, 69, 77, 32, 34, 37, 115, 34, 0, 0, 0, 0, 0, 10, 32, 111, 114, 105, 103, 32, 34, 37, 115, 34, 0, 0, 0, 0, 0, 10, 32, 99, 111, 110, 116, 101, 110, 116, 32, 34, 37, 115, 34, 0, 0, 65, 116, 116, 114, 32, 105, 115, 32, 78, 85, 76, 76, 0, 0, 0, 0, 65, 84, 84, 82, 73, 66, 85, 84, 69, 32, 0, 0, 0, 0, 0, 0, 65, 116, 116, 114, 105, 98, 117, 116, 101, 32, 104, 97, 115, 32, 110, 111, 32, 110, 97, 109, 101, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 240, 63, 0, 0, 0, 0, 0, 0, 240, 191, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 37, 115, 0, 0, 0, 0, 0, 0, 96, 0, 2, 0, 104, 0, 2, 0, 128, 0, 2, 0, 152, 0, 2, 0, 176, 0, 2, 0, 216, 0, 2, 0, 240, 0, 2, 0, 8, 1, 2, 0, 32, 1, 2, 0, 64, 1, 2, 0, 88, 1, 2, 0, 112, 1, 2, 0, 128, 1, 2, 0, 160, 1, 2, 0, 184, 1, 2, 0, 216, 1, 2, 0, 248, 1, 2, 0, 8, 2, 2, 0, 24, 2, 2, 0, 48, 2, 2, 0, 80, 2, 2, 0, 96, 2, 2, 0, 120, 2, 2, 0, 152, 2, 2, 0, 176, 2, 2, 0, 200, 2, 2, 0, 79, 98, 106, 101, 99, 116, 32, 105, 115, 32, 101, 109, 112, 116, 121, 32, 40, 78, 85, 76, 76, 41, 10, 0, 79, 98, 106, 101, 99, 116, 32, 105, 115, 32, 117, 110, 105, 110, 105, 116, 105, 97, 108, 105, 122, 101, 100, 10, 0, 0, 0, 0, 0, 0, 0, 0, 79, 98, 106, 101, 99, 116, 32, 105, 115, 32, 97, 32, 78, 111, 100, 101, 32, 83, 101, 116, 32, 58, 10, 0, 79, 98, 106, 101, 99, 116, 32, 105, 115, 32, 97, 110, 32, 88, 83, 76, 84, 32, 118, 97, 108, 117, 101, 32, 116, 114, 101, 101, 32, 58, 10, 0, 79, 98, 106, 101, 99, 116, 32, 105, 115, 32, 97, 32, 66, 111, 111, 108, 101, 97, 110, 32, 58, 32, 0, 0, 116, 114, 117, 101, 10, 0, 0, 0, 102, 97, 108, 115, 101, 10, 0, 0, 79, 98, 106, 101, 99, 116, 32, 105, 115, 32, 97, 32, 110, 117, 109, 98, 101, 114, 32, 58, 32, 73, 110, 102, 105, 110, 105, 116, 121, 10, 0, 0, 79, 98, 106, 101, 99, 116, 32, 105, 115, 32, 97, 32, 110, 117, 109, 98, 101, 114, 32, 58, 32, 45, 73, 110, 102, 105, 110, 105, 116, 121, 10, 0, 79, 98, 106, 101, 99, 116, 32, 105, 115, 32, 97, 32, 110, 117, 109, 98, 101, 114, 32, 58, 32, 78, 97, 78, 10, 0, 0, 0, 0, 0, 0, 0, 79, 98, 106, 101, 99, 116, 32, 105, 115, 32, 97, 32, 110, 117, 109, 98, 101, 114, 32, 58, 32, 48, 10, 0, 79, 98, 106, 101, 99, 116, 32, 105, 115, 32, 97, 32, 110, 117, 109, 98, 101, 114, 32, 58, 32, 37, 48, 103, 10, 0, 0, 0, 0, 0, 0, 0, 79, 98, 106, 101, 99, 116, 32, 105, 115, 32, 97, 32, 115, 116, 114, 105, 110, 103, 32, 58, 32, 0, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 79, 98, 106, 101, 99, 116, 32, 105, 115, 32, 97, 32, 112, 111, 105, 110, 116, 32, 58, 32, 105, 110, 100, 101, 120, 32, 37, 100, 32, 105, 110, 32, 110, 111, 100, 101, 0, 0, 0, 0, 79, 98, 106, 101, 99, 116, 32, 105, 115, 32, 97, 32, 99, 111, 108, 108, 97, 112, 115, 101, 100, 32, 114, 97, 110, 103, 101, 32, 58, 10, 0, 0, 105, 110, 100, 101, 120, 32, 37, 100, 32, 105, 110, 32, 0, 0, 0, 0, 110, 111, 100, 101, 10, 0, 0, 0, 79, 98, 106, 101, 99, 116, 32, 105, 115, 32, 97, 32, 114, 97, 110, 103, 101, 32, 58, 10, 0, 0, 0, 0, 70, 114, 111, 109, 32, 0, 0, 0, 84, 111, 32, 0, 0, 0, 0, 0, 79, 98, 106, 101, 99, 116, 32, 105, 115, 32, 97, 32, 76, 111, 99, 97, 116, 105, 111, 110, 32, 83, 101, 116, 58, 10, 0, 0, 0, 0, 0, 0, 79, 98, 106, 101, 99, 116, 32, 105, 115, 32, 117, 115, 101, 114, 32, 100, 101, 102, 105, 110, 101, 100, 10, 0, 46, 46, 47, 108, 105, 98, 120, 109, 108, 50, 47, 120, 112, 97, 116, 104, 46, 99, 0, 0, 0, 0, 0, 0, 88, 80, 97, 116, 104, 32, 115, 116, 97, 99, 107, 32, 100, 101, 112, 116, 104, 32, 108, 105, 109, 105, 116, 32, 114, 101, 97, 99, 104, 101, 100, 10, 0, 0, 0, 0, 0, 0, 0, 0, 112, 117, 115, 104, 105, 110, 103, 32, 118, 97, 108, 117, 101, 10, 0, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 110, 111, 100, 101, 115, 101, 116, 10, 0, 0, 0, 0, 0, 0, 0, 103, 114, 111, 119, 105, 110, 103, 32, 110, 111, 100, 101, 115, 101, 116, 10, 0, 0, 0, 0, 0, 0, 0, 0, 103, 114, 111, 119, 105, 110, 103, 32, 110, 111, 100, 101, 115, 101, 116, 32, 104, 105, 116, 32, 108, 105, 109, 105, 116, 10, 0, 0, 0, 0, 0, 0, 109, 101, 114, 103, 105, 110, 103, 32, 110, 111, 100, 101, 115, 101, 116, 10, 0, 0, 0, 0, 0, 0, 0, 0, 109, 101, 114, 103, 105, 110, 103, 32, 110, 111, 100, 101, 115, 101, 116, 32, 104, 105, 116, 32, 108, 105, 109, 105, 116, 10, 0, 0, 0, 0, 0, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 110, 111, 100, 101, 32, 115, 101, 116, 32, 111, 98, 106, 101, 99, 116, 10, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 0, 0, 0, 0, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 88, 77, 76, 47, 49, 57, 57, 56, 47, 110, 97, 109, 101, 115, 112, 97, 99, 101, 0, 0, 0, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 102, 108, 111, 97, 116, 32, 111, 98, 106, 101, 99, 116, 10, 0, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 98, 111, 111, 108, 101, 97, 110, 32, 111, 98, 106, 101, 99, 116, 10, 0, 0, 0, 0, 0, 0, 0, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 115, 116, 114, 105, 110, 103, 32, 111, 98, 106, 101, 99, 116, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 99, 111, 112, 121, 105, 110, 103, 32, 111, 98, 106, 101, 99, 116, 10, 0, 120, 109, 108, 88, 80, 97, 116, 104, 79, 98, 106, 101, 99, 116, 67, 111, 112, 121, 58, 32, 117, 110, 115, 117, 112, 112, 111, 114, 116, 101, 100, 32, 116, 121, 112, 101, 32, 37, 100, 10, 0, 0, 0, 0, 0, 0, 0, 0, 116, 114, 117, 101, 0, 0, 0, 0, 102, 97, 108, 115, 101, 0, 0, 0, 73, 110, 102, 105, 110, 105, 116, 121, 0, 0, 0, 0, 0, 0, 0, 0, 45, 73, 110, 102, 105, 110, 105, 116, 121, 0, 0, 0, 0, 0, 0, 0, 78, 97, 78, 0, 0, 0, 0, 0, 48, 0, 0, 0, 0, 0, 0, 0, 85, 110, 105, 109, 112, 108, 101, 109, 101, 110, 116, 101, 100, 32, 98, 108, 111, 99, 107, 32, 97, 116, 32, 37, 115, 58, 37, 100, 10, 0, 0, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 99, 111, 110, 116, 101, 120, 116, 10, 0, 0, 0, 0, 0, 0, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 112, 97, 114, 115, 101, 114, 32, 99, 111, 110, 116, 101, 120, 116, 10, 0, 0, 0, 0, 0, 0, 0, 0, 102, 97, 107, 101, 32, 110, 111, 100, 101, 32, 108, 105, 98, 120, 115, 108, 116, 0, 0, 0, 0, 0, 0, 0, 184, 254, 1, 0, 0, 0, 0, 0, 120, 109, 108, 88, 80, 97, 116, 104, 84, 114, 97, 110, 115, 108, 97, 116, 101, 70, 117, 110, 99, 116, 105, 111, 110, 58, 32, 73, 110, 118, 97, 108, 105, 100, 32, 85, 84, 70, 56, 32, 115, 116, 114, 105, 110, 103, 10, 0, 0, 0, 0, 0, 0, 0, 240, 63, 0, 0, 0, 0, 0, 0, 36, 64, 0, 0, 0, 0, 0, 0, 89, 64, 0, 0, 0, 0, 0, 64, 143, 64, 0, 0, 0, 0, 0, 136, 195, 64, 0, 0, 0, 0, 0, 106, 248, 64, 0, 0, 0, 0, 128, 132, 46, 65, 0, 0, 0, 0, 208, 18, 99, 65, 0, 0, 0, 0, 132, 215, 151, 65, 0, 0, 0, 0, 101, 205, 205, 65, 0, 0, 0, 32, 95, 160, 2, 66, 0, 0, 0, 232, 118, 72, 55, 66, 0, 0, 0, 162, 148, 26, 109, 66, 0, 0, 64, 229, 156, 48, 162, 66, 0, 0, 144, 30, 196, 188, 214, 66, 0, 0, 52, 38, 245, 107, 12, 67, 0, 128, 224, 55, 121, 195, 65, 67, 0, 160, 216, 133, 87, 52, 118, 67, 0, 200, 78, 103, 109, 193, 171, 67, 0, 61, 145, 96, 228, 88, 225, 67, 64, 140, 181, 120, 29, 175, 21, 68, 110, 111, 100, 101, 0, 0, 0, 0, 116, 101, 120, 116, 0, 0, 0, 0, 99, 111, 109, 109, 101, 110, 116, 0, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 45, 105, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 32, 97, 116, 32, 37, 115, 58, 37, 100, 10, 0, 0, 0, 0, 0, 0, 0, 0, 78, 85, 76, 76, 32, 99, 111, 110, 116, 101, 120, 116, 32, 112, 111, 105, 110, 116, 101, 114, 10, 0, 0, 0, 120, 109, 108, 88, 80, 97, 116, 104, 69, 118, 97, 108, 58, 32, 101, 118, 97, 108, 117, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 10, 0, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 88, 80, 97, 116, 104, 69, 118, 97, 108, 58, 32, 37, 100, 32, 111, 98, 106, 101, 99, 116, 32, 108, 101, 102, 116, 32, 111, 110, 32, 116, 104, 101, 32, 115, 116, 97, 99, 107, 10, 0, 0, 0, 0, 0, 0, 98, 111, 111, 108, 101, 97, 110, 0, 99, 101, 105, 108, 105, 110, 103, 0, 99, 111, 117, 110, 116, 0, 0, 0, 99, 111, 110, 99, 97, 116, 0, 0, 99, 111, 110, 116, 97, 105, 110, 115, 0, 0, 0, 0, 0, 0, 0, 0, 105, 100, 0, 0, 0, 0, 0, 0, 102, 108, 111, 111, 114, 0, 0, 0, 108, 97, 115, 116, 0, 0, 0, 0, 108, 97, 110, 103, 0, 0, 0, 0, 108, 111, 99, 97, 108, 45, 110, 97, 109, 101, 0, 0, 0, 0, 0, 0, 110, 111, 116, 0, 0, 0, 0, 0, 110, 97, 109, 101, 0, 0, 0, 0, 110, 97, 109, 101, 115, 112, 97, 99, 101, 45, 117, 114, 105, 0, 0, 0, 110, 111, 114, 109, 97, 108, 105, 122, 101, 45, 115, 112, 97, 99, 101, 0, 110, 117, 109, 98, 101, 114, 0, 0, 112, 111, 115, 105, 116, 105, 111, 110, 0, 0, 0, 0, 0, 0, 0, 0, 114, 111, 117, 110, 100, 0, 0, 0, 115, 116, 114, 105, 110, 103, 0, 0, 115, 116, 114, 105, 110, 103, 45, 108, 101, 110, 103, 116, 104, 0, 0, 0, 115, 116, 97, 114, 116, 115, 45, 119, 105, 116, 104, 0, 0, 0, 0, 0, 115, 117, 98, 115, 116, 114, 105, 110, 103, 0, 0, 0, 0, 0, 0, 0, 115, 117, 98, 115, 116, 114, 105, 110, 103, 45, 98, 101, 102, 111, 114, 101, 0, 0, 0, 0, 0, 0, 0, 0, 115, 117, 98, 115, 116, 114, 105, 110, 103, 45, 97, 102, 116, 101, 114, 0, 115, 117, 109, 0, 0, 0, 0, 0, 116, 114, 97, 110, 115, 108, 97, 116, 101, 0, 0, 0, 0, 0, 0, 0, 101, 115, 99, 97, 112, 101, 45, 117, 114, 105, 0, 0, 0, 0, 0, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 50, 48, 48, 50, 47, 48, 56, 47, 120, 113, 117, 101, 114, 121, 45, 102, 117, 110, 99, 116, 105, 111, 110, 115, 0, 0, 0, 0, 0, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 101, 118, 97, 108, 117, 97, 116, 105, 111, 110, 32, 99, 111, 110, 116, 101, 120, 116, 10, 0, 0, 0, 0, 120, 109, 108, 88, 80, 97, 116, 104, 82, 117, 110, 69, 118, 97, 108, 58, 32, 108, 97, 115, 116, 32, 105, 115, 32, 108, 101, 115, 115, 32, 116, 104, 97, 110, 32, 122, 101, 114, 111, 10, 0, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 88, 80, 97, 116, 104, 67, 111, 109, 112, 79, 112, 69, 118, 97, 108, 58, 32, 118, 97, 114, 105, 97, 98, 108, 101, 32, 37, 115, 32, 98, 111, 117, 110, 100, 32, 116, 111, 32, 117, 110, 100, 101, 102, 105, 110, 101, 100, 32, 112, 114, 101, 102, 105, 120, 32, 37, 115, 10, 0, 0, 0, 120, 109, 108, 88, 80, 97, 116, 104, 67, 111, 109, 112, 79, 112, 69, 118, 97, 108, 58, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 32, 101, 114, 114, 111, 114, 10, 0, 0, 0, 0, 120, 109, 108, 88, 80, 97, 116, 104, 67, 111, 109, 112, 79, 112, 69, 118, 97, 108, 58, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 37, 115, 32, 98, 111, 117, 110, 100, 32, 116, 111, 32, 117, 110, 100, 101, 102, 105, 110, 101, 100, 32, 112, 114, 101, 102, 105, 120, 32, 37, 115, 10, 0, 0, 0, 120, 109, 108, 88, 80, 97, 116, 104, 67, 111, 109, 112, 79, 112, 69, 118, 97, 108, 58, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 37, 115, 32, 110, 111, 116, 32, 102, 111, 117, 110, 100, 10, 0, 0, 0, 0, 0, 0, 88, 80, 97, 116, 104, 58, 32, 117, 110, 107, 110, 111, 119, 110, 32, 112, 114, 101, 99, 111, 109, 112, 105, 108, 101, 100, 32, 111, 112, 101, 114, 97, 116, 105, 111, 110, 32, 37, 100, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 88, 80, 97, 116, 104, 67, 111, 109, 112, 105, 108, 101, 100, 69, 118, 97, 108, 58, 32, 101, 118, 97, 108, 117, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 10, 0, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 88, 80, 97, 116, 104, 67, 111, 109, 112, 105, 108, 101, 100, 69, 118, 97, 108, 58, 32, 37, 100, 32, 111, 98, 106, 101, 99, 116, 115, 32, 108, 101, 102, 116, 32, 111, 110, 32, 116, 104, 101, 32, 115, 116, 97, 99, 107, 46, 10, 0, 0, 0, 0, 97, 100, 100, 105, 110, 103, 32, 115, 116, 101, 112, 10, 0, 0, 0, 0, 58, 58, 0, 0, 0, 0, 0, 0, 114, 97, 110, 103, 101, 45, 116, 111, 0, 0, 0, 0, 0, 0, 0, 0, 97, 110, 99, 101, 115, 116, 111, 114, 0, 0, 0, 0, 0, 0, 0, 0, 97, 110, 99, 101, 115, 116, 111, 114, 45, 111, 114, 45, 115, 101, 108, 102, 0, 0, 0, 0, 0, 0, 0, 0, 97, 116, 116, 114, 105, 98, 117, 116, 101, 0, 0, 0, 0, 0, 0, 0, 99, 104, 105, 108, 100, 0, 0, 0, 100, 101, 115, 99, 101, 110, 100, 97, 110, 116, 0, 0, 0, 0, 0, 0, 100, 101, 115, 99, 101, 110, 100, 97, 110, 116, 45, 111, 114, 45, 115, 101, 108, 102, 0, 0, 0, 0, 0, 0, 102, 111, 108, 108, 111, 119, 105, 110, 103, 0, 0, 0, 0, 0, 0, 0, 102, 111, 108, 108, 111, 119, 105, 110, 103, 45, 115, 105, 98, 108, 105, 110, 103, 0, 0, 0, 0, 0, 0, 0, 110, 97, 109, 101, 115, 112, 97, 99, 101, 0, 0, 0, 0, 0, 0, 0, 112, 97, 114, 101, 110, 116, 0, 0, 112, 114, 101, 99, 101, 100, 105, 110, 103, 0, 0, 0, 0, 0, 0, 0, 112, 114, 101, 99, 101, 100, 105, 110, 103, 45, 115, 105, 98, 108, 105, 110, 103, 0, 0, 0, 0, 0, 0, 0, 115, 101, 108, 102, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 115, 32, 97, 114, 114, 97, 121, 10, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 115, 116, 114, 101, 97, 109, 97, 98, 108, 101, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 18, 0, 0, 0, 40, 247, 1, 0, 32, 247, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 99, 111, 109, 112, 97, 114, 105, 110, 103, 32, 110, 111, 100, 101, 115, 101, 116, 115, 10, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 99, 111, 109, 112, 111, 110, 101, 110, 116, 10, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 115, 116, 101, 112, 115, 10, 0, 0, 0, 0, 0, 0, 0, 37, 100, 0, 0, 0, 0, 0, 0, 37, 42, 46, 42, 101, 0, 0, 0, 37, 48, 46, 42, 102, 0, 0, 0, 120, 109, 108, 80, 111, 105, 110, 116, 101, 114, 76, 105, 115, 116, 67, 114, 101, 97, 116, 101, 58, 32, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 105, 116, 101, 109, 10, 0, 0, 120, 109, 108, 80, 111, 105, 110, 116, 101, 114, 76, 105, 115, 116, 65, 100, 100, 83, 105, 122, 101, 58, 32, 114, 101, 45, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 105, 116, 101, 109, 10, 0, 0, 0, 0, 0, 0, 100, 117, 112, 108, 105, 99, 97, 116, 105, 110, 103, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 10, 0, 0, 77, 101, 109, 111, 114, 121, 32, 97, 108, 108, 111, 99, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 32, 58, 32, 37, 115, 10, 0, 0, 77, 101, 109, 111, 114, 121, 32, 97, 108, 108, 111, 99, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 10, 0, 0, 0, 0, 0, 0, 0, 76, 111, 99, 97, 116, 105, 111, 110, 83, 101, 116, 32, 105, 115, 32, 78, 85, 76, 76, 32, 33, 10, 0, 0, 37, 100, 32, 58, 32, 0, 0, 0, 78, 111, 100, 101, 32, 105, 115, 32, 78, 85, 76, 76, 32, 33, 10, 0, 32, 47, 10, 0, 0, 0, 0, 0, 86, 97, 108, 117, 101, 32, 84, 114, 101, 101, 32, 105, 115, 32, 78, 85, 76, 76, 32, 33, 10, 0, 0, 0, 78, 111, 100, 101, 83, 101, 116, 32, 105, 115, 32, 78, 85, 76, 76, 32, 33, 10, 0, 0, 0, 0, 0, 0, 83, 101, 116, 32, 99, 111, 110, 116, 97, 105, 110, 115, 32, 37, 100, 32, 110, 111, 100, 101, 115, 58, 10, 0, 79, 107, 10, 0, 0, 0, 0, 0, 78, 117, 109, 98, 101, 114, 32, 101, 110, 99, 111, 100, 105, 110, 103, 10, 0, 0, 0, 0, 0, 0, 0, 0, 85, 110, 102, 105, 110, 105, 115, 104, 101, 100, 32, 108, 105, 116, 101, 114, 97, 108, 10, 0, 0, 0, 0, 0, 83, 116, 97, 114, 116, 32, 111, 102, 32, 108, 105, 116, 101, 114, 97, 108, 10, 0, 0, 0, 0, 0, 0, 0, 69, 120, 112, 101, 99, 116, 101, 100, 32, 36, 32, 102, 111, 114, 32, 118, 97, 114, 105, 97, 98, 108, 101, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 10, 0, 0, 0, 0, 0, 0, 85, 110, 100, 101, 102, 105, 110, 101, 100, 32, 118, 97, 114, 105, 97, 98, 108, 101, 10, 0, 0, 0, 0, 0, 73, 110, 118, 97, 108, 105, 100, 32, 112, 114, 101, 100, 105, 99, 97, 116, 101, 10, 0, 0, 0, 0, 0, 0, 73, 110, 118, 97, 108, 105, 100, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 10, 0, 0, 0, 0, 0, 77, 105, 115, 115, 105, 110, 103, 32, 99, 108, 111, 115, 105, 110, 103, 32, 99, 117, 114, 108, 121, 32, 98, 114, 97, 99, 101, 10, 0, 0, 0, 0, 85, 110, 114, 101, 103, 105, 115, 116, 101, 114, 101, 100, 32, 102, 117, 110, 99, 116, 105, 111, 110, 10, 0, 0, 73, 110, 118, 97, 108, 105, 100, 32, 111, 112, 101, 114, 97, 110, 100, 10, 0, 0, 0, 0, 0, 0, 0, 0, 73, 110, 118, 97, 108, 105, 100, 32, 116, 121, 112, 101, 10, 0, 0, 0, 73, 110, 118, 97, 108, 105, 100, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 10, 0, 0, 0, 0, 73, 110, 118, 97, 108, 105, 100, 32, 99, 111, 110, 116, 101, 120, 116, 32, 115, 105, 122, 101, 10, 0, 0, 0, 73, 110, 118, 97, 108, 105, 100, 32, 99, 111, 110, 116, 101, 120, 116, 32, 112, 111, 115, 105, 116, 105, 111, 110, 10, 0, 0, 0, 0, 0, 0, 0, 77, 101, 109, 111, 114, 121, 32, 97, 108, 108, 111, 99, 97, 116, 105, 111, 110, 32, 101, 114, 114, 111, 114, 10, 0, 0, 0, 0, 0, 0, 0, 0, 83, 121, 110, 116, 97, 120, 32, 101, 114, 114, 111, 114, 10, 0, 0, 0, 82, 101, 115, 111, 117, 114, 99, 101, 32, 101, 114, 114, 111, 114, 10, 0, 83, 117, 98, 32, 114, 101, 115, 111, 117, 114, 99, 101, 32, 101, 114, 114, 111, 114, 10, 0, 0, 0, 0, 0, 85, 110, 100, 101, 102, 105, 110, 101, 100, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 112, 114, 101, 102, 105, 120, 10, 0, 0, 0, 0, 0, 69, 110, 99, 111, 100, 105, 110, 103, 32, 101, 114, 114, 111, 114, 10, 0, 67, 104, 97, 114, 32, 111, 117, 116, 32, 111, 102, 32, 88, 77, 76, 32, 114, 97, 110, 103, 101, 10, 0, 0, 73, 110, 118, 97, 108, 105, 100, 32, 111, 114, 32, 105, 110, 99, 111, 109, 112, 108, 101, 116, 101, 32, 99, 111, 110, 116, 101, 120, 116, 10, 0, 0, 83, 116, 97, 99, 107, 32, 117, 115, 97, 103, 101, 32, 101, 114, 114, 111, 114, 10, 0, 0, 0, 0, 0, 0, 70, 111, 114, 98, 105, 100, 100, 101, 110, 32, 118, 97, 114, 105, 97, 98, 108, 101, 10, 0, 0, 0, 0, 0, 63, 63, 32, 85, 110, 107, 110, 111, 119, 110, 32, 101, 114, 114, 111, 114, 32, 63, 63, 10, 0, 0, 0, 0, 128, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 3, 4, 5, 6, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 127, 240, 0, 0, 0, 0, 0, 0, 69, 114, 114, 111, 114, 32, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 116, 101, 109, 112, 111, 114, 97, 114, 121, 32, 115, 116, 111, 114, 97, 103, 101, 32, 102, 111, 114, 32, 116, 105, 109, 32, 115, 111, 114, 116, 58, 32, 110, 101, 101, 100, 32, 37, 108, 117, 32, 98, 121, 116, 101, 115, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 114, 97, 110, 103, 101, 0, 0, 0, 0, 0, 0, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 32, 97, 116, 32, 37, 115, 58, 37, 100, 10, 0, 0, 0, 0, 0, 0, 0, 0, 46, 46, 47, 108, 105, 98, 120, 109, 108, 50, 47, 120, 112, 111, 105, 110, 116, 101, 114, 46, 99, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 108, 111, 99, 97, 116, 105, 111, 110, 115, 101, 116, 0, 0, 97, 100, 100, 105, 110, 103, 32, 108, 111, 99, 97, 116, 105, 111, 110, 32, 116, 111, 32, 115, 101, 116, 0, 0, 114, 97, 110, 103, 101, 45, 116, 111, 0, 0, 0, 0, 0, 0, 0, 0, 114, 97, 110, 103, 101, 0, 0, 0, 114, 97, 110, 103, 101, 45, 105, 110, 115, 105, 100, 101, 0, 0, 0, 0, 115, 116, 114, 105, 110, 103, 45, 114, 97, 110, 103, 101, 0, 0, 0, 0, 115, 116, 97, 114, 116, 45, 112, 111, 105, 110, 116, 0, 0, 0, 0, 0, 101, 110, 100, 45, 112, 111, 105, 110, 116, 0, 0, 0, 0, 0, 0, 0, 104, 101, 114, 101, 0, 0, 0, 0, 32, 111, 114, 105, 103, 105, 110, 0, 120, 109, 108, 88, 80, 116, 114, 69, 118, 97, 108, 58, 32, 101, 118, 97, 108, 117, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 114, 101, 116, 117, 114, 110, 32, 97, 32, 110, 111, 100, 101, 32, 115, 101, 116, 10, 0, 0, 0, 0, 120, 109, 108, 88, 80, 116, 114, 69, 118, 97, 108, 58, 32, 111, 98, 106, 101, 99, 116, 40, 115, 41, 32, 108, 101, 102, 116, 32, 111, 110, 32, 116, 104, 101, 32, 101, 118, 97, 108, 32, 115, 116, 97, 99, 107, 10, 0, 0, 85, 110, 105, 109, 112, 108, 101, 109, 101, 110, 116, 101, 100, 32, 98, 108, 111, 99, 107, 32, 97, 116, 32, 37, 115, 58, 37, 100, 10, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 112, 111, 105, 110, 116, 0, 0, 0, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 101, 118, 97, 108, 117, 97, 116, 105, 111, 110, 32, 99, 111, 110, 116, 101, 120, 116, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 98, 117, 102, 102, 101, 114, 0, 0, 0, 0, 0, 0, 0, 120, 112, 111, 105, 110, 116, 101, 114, 0, 0, 0, 0, 0, 0, 0, 0, 101, 108, 101, 109, 101, 110, 116, 0, 120, 109, 108, 110, 115, 0, 0, 0, 117, 110, 115, 117, 112, 112, 111, 114, 116, 101, 100, 32, 115, 99, 104, 101, 109, 101, 32, 39, 37, 115, 39, 10, 0, 0, 0, 0, 0, 0, 0, 0, 119, 97, 114, 110, 105, 110, 103, 58, 32, 67, 104, 105, 108, 100, 83, 101, 113, 32, 110, 111, 116, 32, 115, 116, 97, 114, 116, 105, 110, 103, 32, 98, 121, 32, 47, 49, 10, 0, 0, 0, 77, 101, 109, 111, 114, 121, 32, 97, 108, 108, 111, 99, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 32, 58, 32, 37, 115, 10, 0, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 88, 73, 110, 99, 108, 117, 100, 101, 32, 99, 111, 110, 116, 101, 120, 116, 0, 0, 0, 0, 0, 0, 0, 88, 73, 110, 99, 108, 117, 100, 101, 32, 101, 114, 114, 111, 114, 58, 32, 119, 111, 117, 108, 100, 32, 114, 101, 115, 117, 108, 116, 32, 105, 110, 32, 109, 117, 108, 116, 105, 112, 108, 101, 32, 114, 111, 111, 116, 32, 110, 111, 100, 101, 115, 10, 0, 0, 0, 0, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 98, 117, 105, 108, 100, 32, 110, 111, 100, 101, 10, 0, 0, 0, 104, 114, 101, 102, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 112, 97, 114, 115, 101, 0, 0, 0, 120, 109, 108, 0, 0, 0, 0, 0, 116, 101, 120, 116, 0, 0, 0, 0, 105, 110, 118, 97, 108, 105, 100, 32, 118, 97, 108, 117, 101, 32, 37, 115, 32, 102, 111, 114, 32, 39, 112, 97, 114, 115, 101, 39, 10, 0, 0, 0, 102, 97, 105, 108, 101, 100, 32, 98, 117, 105, 108, 100, 32, 85, 82, 76, 10, 0, 0, 0, 0, 0, 0, 0, 102, 97, 108, 108, 98, 97, 99, 107, 0, 0, 0, 0, 0, 0, 0, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 50, 48, 48, 51, 47, 88, 73, 110, 99, 108, 117, 100, 101, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 50, 48, 48, 49, 47, 88, 73, 110, 99, 108, 117, 100, 101, 0, 99, 111, 117, 108, 100, 32, 110, 111, 116, 32, 108, 111, 97, 100, 32, 37, 115, 44, 32, 97, 110, 100, 32, 110, 111, 32, 102, 97, 108, 108, 98, 97, 99, 107, 32, 119, 97, 115, 32, 102, 111, 117, 110, 100, 10, 0, 0, 0, 105, 110, 118, 97, 108, 105, 100, 32, 118, 97, 108, 117, 101, 32, 85, 82, 73, 32, 37, 115, 10, 0, 0, 0, 102, 114, 97, 103, 109, 101, 110, 116, 32, 105, 100, 101, 110, 116, 105, 102, 105, 101, 114, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 102, 111, 114, 32, 116, 101, 120, 116, 58, 32, 37, 115, 10, 0, 0, 0, 0, 0, 116, 101, 120, 116, 32, 115, 101, 114, 105, 97, 108, 105, 122, 97, 116, 105, 111, 110, 32, 111, 102, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 110, 111, 116, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 10, 0, 0, 0, 101, 110, 99, 111, 100, 105, 110, 103, 0, 0, 0, 0, 0, 0, 0, 0, 101, 110, 99, 111, 100, 105, 110, 103, 32, 37, 115, 32, 110, 111, 116, 32, 115, 117, 112, 112, 111, 114, 116, 101, 100, 10, 0, 0, 0, 0, 0, 0, 37, 115, 32, 99, 111, 110, 116, 97, 105, 110, 115, 32, 105, 110, 118, 97, 108, 105, 100, 32, 99, 104, 97, 114, 10, 0, 0, 0, 0, 0, 0, 0, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 116, 101, 120, 116, 0, 99, 111, 117, 108, 100, 32, 110, 111, 116, 32, 99, 114, 101, 97, 116, 101, 32, 88, 80, 111, 105, 110, 116, 101, 114, 32, 99, 111, 110, 116, 101, 120, 116, 10, 0, 0, 0, 0, 0, 0, 88, 80, 111, 105, 110, 116, 101, 114, 32, 101, 118, 97, 108, 117, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 58, 32, 35, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 0, 88, 80, 111, 105, 110, 116, 101, 114, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 114, 97, 110, 103, 101, 58, 32, 35, 37, 115, 10, 0, 0, 0, 88, 80, 111, 105, 110, 116, 101, 114, 32, 115, 101, 108, 101, 99, 116, 115, 32, 97, 110, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 58, 32, 35, 37, 115, 10, 0, 0, 0, 0, 0, 88, 80, 111, 105, 110, 116, 101, 114, 32, 115, 101, 108, 101, 99, 116, 115, 32, 97, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 58, 32, 35, 37, 115, 10, 0, 0, 0, 0, 0, 0, 88, 80, 111, 105, 110, 116, 101, 114, 32, 115, 101, 108, 101, 99, 116, 115, 32, 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 110, 111, 100, 101, 115, 58, 32, 35, 37, 115, 10, 0, 98, 97, 115, 101, 0, 0, 0, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 88, 77, 76, 47, 49, 57, 57, 56, 47, 110, 97, 109, 101, 115, 112, 97, 99, 101, 0, 0, 0, 0, 116, 114, 121, 105, 110, 103, 32, 116, 111, 32, 98, 117, 105, 108, 100, 32, 114, 101, 108, 97, 116, 105, 118, 101, 32, 85, 82, 73, 32, 102, 114, 111, 109, 32, 37, 115, 10, 0, 0, 0, 116, 114, 121, 105, 110, 103, 32, 116, 111, 32, 114, 101, 98, 117, 105, 108, 100, 32, 98, 97, 115, 101, 32, 102, 114, 111, 109, 32, 37, 115, 10, 0, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 100, 111, 99, 0, 0, 109, 105, 115, 109, 97, 116, 99, 104, 32, 105, 110, 32, 114, 101, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 111, 102, 32, 101, 110, 116, 105, 116, 121, 32, 37, 115, 10, 0, 0, 99, 97, 110, 110, 111, 116, 32, 97, 108, 108, 111, 99, 97, 116, 101, 32, 112, 97, 114, 115, 101, 114, 32, 99, 111, 110, 116, 101, 120, 116, 0, 0, 120, 112, 111, 105, 110, 116, 101, 114, 0, 0, 0, 0, 0, 0, 0, 0, 73, 110, 118, 97, 108, 105, 100, 32, 102, 114, 97, 103, 109, 101, 110, 116, 32, 105, 100, 101, 110, 116, 105, 102, 105, 101, 114, 32, 105, 110, 32, 85, 82, 73, 32, 37, 115, 32, 117, 115, 101, 32, 116, 104, 101, 32, 120, 112, 111, 105, 110, 116, 101, 114, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 10, 0, 0, 0, 0, 0, 0, 0, 100, 101, 116, 101, 99, 116, 101, 100, 32, 97, 32, 108, 111, 99, 97, 108, 32, 114, 101, 99, 117, 114, 115, 105, 111, 110, 32, 119, 105, 116, 104, 32, 110, 111, 32, 120, 112, 111, 105, 110, 116, 101, 114, 32, 105, 110, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 100, 101, 116, 101, 99, 116, 101, 100, 32, 97, 32, 114, 101, 99, 117, 114, 115, 105, 111, 110, 32, 105, 110, 32, 37, 115, 10, 0, 0, 0, 0, 0, 103, 114, 111, 119, 105, 110, 103, 32, 88, 73, 110, 99, 108, 117, 100, 101, 32, 99, 111, 110, 116, 101, 120, 116, 0, 0, 0, 0, 0, 0, 0, 0, 105, 110, 99, 108, 117, 100, 101, 0, 37, 115, 32, 104, 97, 115, 32, 97, 110, 32, 39, 105, 110, 99, 108, 117, 100, 101, 39, 32, 99, 104, 105, 108, 100, 10, 0, 0, 0, 0, 0, 0, 37, 115, 32, 104, 97, 115, 32, 109, 117, 108, 116, 105, 112, 108, 101, 32, 102, 97, 108, 108, 98, 97, 99, 107, 32, 99, 104, 105, 108, 100, 114, 101, 110, 10, 0, 0, 0, 0, 0, 0, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 116, 104, 101, 32, 99, 104, 105, 108, 100, 32, 111, 102, 32, 97, 110, 32, 39, 105, 110, 99, 108, 117, 100, 101, 39, 10, 0, 0, 0, 0, 97, 100, 100, 105, 110, 103, 32, 85, 82, 76, 0, 0, 0, 0, 0, 0, 77, 101, 109, 111, 114, 121, 32, 97, 108, 108, 111, 99, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 32, 58, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 111, 117, 116, 32, 111, 102, 32, 109, 101, 109, 111, 114, 121, 10, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 82, 101, 115, 111, 108, 118, 101, 58, 32, 112, 117, 98, 73, 68, 32, 37, 115, 32, 115, 121, 115, 73, 68, 32, 37, 115, 10, 0, 0, 0, 0, 0, 82, 101, 115, 111, 108, 118, 101, 58, 32, 112, 117, 98, 73, 68, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 82, 101, 115, 111, 108, 118, 101, 58, 32, 115, 121, 115, 73, 68, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 82, 101, 115, 111, 108, 118, 101, 32, 85, 82, 73, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 88, 77, 76, 95, 68, 69, 66, 85, 71, 95, 67, 65, 84, 65, 76, 79, 71, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 88, 77, 76, 95, 67, 65, 84, 65, 76, 79, 71, 95, 70, 73, 76, 69, 83, 0, 0, 0, 0, 0, 0, 0, 102, 105, 108, 101, 58, 47, 47, 47, 101, 116, 99, 47, 120, 109, 108, 47, 99, 97, 116, 97, 108, 111, 103, 0, 67, 97, 116, 97, 108, 111, 103, 115, 32, 99, 108, 101, 97, 110, 117, 112, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 99, 97, 116, 97, 108, 111, 103, 0, 3, 0, 0, 0, 0, 0, 0, 0, 65, 100, 100, 105, 110, 103, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 99, 97, 116, 97, 108, 111, 103, 32, 37, 115, 10, 0, 0, 0, 0, 0, 76, 111, 99, 97, 108, 32, 82, 101, 115, 111, 108, 118, 101, 58, 32, 112, 117, 98, 73, 68, 32, 37, 115, 32, 115, 121, 115, 73, 68, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 76, 111, 99, 97, 108, 32, 82, 101, 115, 111, 108, 118, 101, 58, 32, 112, 117, 98, 73, 68, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 0, 76, 111, 99, 97, 108, 32, 82, 101, 115, 111, 108, 118, 101, 58, 32, 115, 121, 115, 73, 68, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 37, 115, 32, 105, 110, 32, 102, 105, 108, 101, 32, 104, 97, 115, 104, 10, 0, 0, 37, 115, 32, 110, 111, 116, 32, 102, 111, 117, 110, 100, 32, 105, 110, 32, 102, 105, 108, 101, 32, 104, 97, 115, 104, 10, 0, 0, 0, 0, 0, 0, 37, 115, 32, 97, 100, 100, 101, 100, 32, 116, 111, 32, 102, 105, 108, 101, 32, 104, 97, 115, 104, 10, 0, 0, 70, 97, 105, 108, 101, 100, 32, 116, 111, 32, 112, 97, 114, 115, 101, 32, 99, 97, 116, 97, 108, 111, 103, 32, 37, 115, 10, 0, 0, 0, 0, 0, 37, 100, 32, 80, 97, 114, 115, 105, 110, 103, 32, 99, 97, 116, 97, 108, 111, 103, 32, 37, 115, 10, 0, 0, 117, 114, 110, 58, 111, 97, 115, 105, 115, 58, 110, 97, 109, 101, 115, 58, 116, 99, 58, 101, 110, 116, 105, 116, 121, 58, 120, 109, 108, 110, 115, 58, 120, 109, 108, 58, 99, 97, 116, 97, 108, 111, 103, 0, 0, 0, 0, 0, 112, 114, 101, 102, 101, 114, 0, 0, 115, 121, 115, 116, 101, 109, 0, 0, 112, 117, 98, 108, 105, 99, 0, 0, 73, 110, 118, 97, 108, 105, 100, 32, 118, 97, 108, 117, 101, 32, 102, 111, 114, 32, 112, 114, 101, 102, 101, 114, 58, 32, 39, 37, 115, 39, 10, 0, 70, 105, 108, 101, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 97, 110, 32, 88, 77, 76, 32, 67, 97, 116, 97, 108, 111, 103, 10, 0, 0, 103, 114, 111, 117, 112, 0, 0, 0, 105, 100, 0, 0, 0, 0, 0, 0, 98, 97, 115, 101, 0, 0, 0, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 88, 77, 76, 47, 49, 57, 57, 56, 47, 110, 97, 109, 101, 115, 112, 97, 99, 101, 0, 0, 0, 0, 112, 117, 98, 108, 105, 99, 73, 100, 0, 0, 0, 0, 0, 0, 0, 0, 117, 114, 105, 0, 0, 0, 0, 0, 115, 121, 115, 116, 101, 109, 73, 100, 0, 0, 0, 0, 0, 0, 0, 0, 114, 101, 119, 114, 105, 116, 101, 83, 121, 115, 116, 101, 109, 0, 0, 0, 115, 121, 115, 116, 101, 109, 73, 100, 83, 116, 97, 114, 116, 83, 116, 114, 105, 110, 103, 0, 0, 0, 0, 0, 114, 101, 119, 114, 105, 116, 101, 80, 114, 101, 102, 105, 120, 0, 0, 0, 100, 101, 108, 101, 103, 97, 116, 101, 80, 117, 98, 108, 105, 99, 0, 0, 112, 117, 98, 108, 105, 99, 73, 100, 83, 116, 97, 114, 116, 83, 116, 114, 105, 110, 103, 0, 0, 0, 0, 0, 100, 101, 108, 101, 103, 97, 116, 101, 83, 121, 115, 116, 101, 109, 0, 0, 110, 97, 109, 101, 0, 0, 0, 0, 114, 101, 119, 114, 105, 116, 101, 85, 82, 73, 0, 0, 0, 0, 0, 0, 117, 114, 105, 83, 116, 97, 114, 116, 83, 116, 114, 105, 110, 103, 0, 0, 100, 101, 108, 101, 103, 97, 116, 101, 85, 82, 73, 0, 0, 0, 0, 0, 110, 101, 120, 116, 67, 97, 116, 97, 108, 111, 103, 0, 0, 0, 0, 0, 37, 115, 32, 101, 110, 116, 114, 121, 32, 108, 97, 99, 107, 115, 32, 39, 37, 115, 39, 10, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 37, 115, 58, 32, 39, 37, 115, 39, 32, 39, 37, 115, 39, 10, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 37, 115, 58, 32, 39, 37, 115, 39, 10, 0, 37, 115, 32, 101, 110, 116, 114, 121, 32, 39, 37, 115, 39, 32, 98, 114, 111, 107, 101, 110, 32, 63, 58, 32, 37, 115, 10, 0, 0, 0, 0, 0, 83, 89, 83, 84, 69, 77, 0, 0, 80, 85, 66, 76, 73, 67, 0, 0, 68, 69, 76, 69, 71, 65, 84, 69, 0, 0, 0, 0, 0, 0, 0, 0, 69, 78, 84, 73, 84, 89, 0, 0, 68, 79, 67, 84, 89, 80, 69, 0, 76, 73, 78, 75, 84, 89, 80, 69, 0, 0, 0, 0, 0, 0, 0, 0, 78, 79, 84, 65, 84, 73, 79, 78, 0, 0, 0, 0, 0, 0, 0, 0, 83, 71, 77, 76, 68, 69, 67, 76, 0, 0, 0, 0, 0, 0, 0, 0, 68, 79, 67, 85, 77, 69, 78, 84, 0, 0, 0, 0, 0, 0, 0, 0, 67, 65, 84, 65, 76, 79, 71, 0, 66, 65, 83, 69, 0, 0, 0, 0, 117, 114, 110, 58, 112, 117, 98, 108, 105, 99, 105, 100, 58, 0, 0, 0, 85, 82, 78, 32, 73, 68, 32, 37, 115, 32, 101, 120, 112, 97, 110, 100, 101, 100, 32, 116, 111, 32, 78, 85, 76, 76, 10, 0, 0, 0, 0, 0, 85, 82, 78, 32, 73, 68, 32, 101, 120, 112, 97, 110, 100, 101, 100, 32, 116, 111, 32, 37, 115, 10, 0, 0, 68, 101, 116, 101, 99, 116, 101, 100, 32, 114, 101, 99, 117, 114, 115, 105, 111, 110, 32, 105, 110, 32, 99, 97, 116, 97, 108, 111, 103, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 85, 82, 73, 32, 109, 97, 116, 99, 104, 32, 37, 115, 10, 0, 0, 0, 0, 0, 85, 115, 105, 110, 103, 32, 114, 101, 119, 114, 105, 116, 105, 110, 103, 32, 114, 117, 108, 101, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 0, 84, 114, 121, 105, 110, 103, 32, 85, 82, 73, 32, 100, 101, 108, 101, 103, 97, 116, 101, 32, 37, 115, 10, 0, 80, 117, 98, 108, 105, 99, 32, 85, 82, 78, 32, 73, 68, 32, 37, 115, 32, 101, 120, 112, 97, 110, 100, 101, 100, 32, 116, 111, 32, 78, 85, 76, 76, 10, 0, 0, 0, 0, 0, 0, 80, 117, 98, 108, 105, 99, 32, 85, 82, 78, 32, 73, 68, 32, 101, 120, 112, 97, 110, 100, 101, 100, 32, 116, 111, 32, 37, 115, 10, 0, 0, 0, 83, 121, 115, 116, 101, 109, 32, 85, 82, 78, 32, 73, 68, 32, 37, 115, 32, 101, 120, 112, 97, 110, 100, 101, 100, 32, 116, 111, 32, 78, 85, 76, 76, 10, 0, 0, 0, 0, 0, 0, 83, 121, 115, 116, 101, 109, 32, 85, 82, 78, 32, 73, 68, 32, 101, 120, 112, 97, 110, 100, 101, 100, 32, 116, 111, 32, 37, 115, 10, 0, 0, 0, 70, 111, 117, 110, 100, 32, 115, 121, 115, 116, 101, 109, 32, 109, 97, 116, 99, 104, 32, 37, 115, 44, 32, 117, 115, 105, 110, 103, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 0, 84, 114, 121, 105, 110, 103, 32, 115, 121, 115, 116, 101, 109, 32, 100, 101, 108, 101, 103, 97, 116, 101, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 112, 117, 98, 108, 105, 99, 32, 109, 97, 116, 99, 104, 32, 37, 115, 10, 0, 0, 84, 114, 121, 105, 110, 103, 32, 112, 117, 98, 108, 105, 99, 32, 100, 101, 108, 101, 103, 97, 116, 101, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 99, 97, 116, 97, 108, 111, 103, 32, 101, 110, 116, 114, 121, 0, 0, 0, 0, 0, 0, 0, 0, 77, 101, 109, 111, 114, 121, 32, 97, 108, 108, 111, 99, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 32, 58, 32, 37, 115, 10, 0, 0, 79, 86, 69, 82, 82, 73, 68, 69, 0, 0, 0, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 112, 117, 98, 108, 105, 99, 32, 73, 68, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 99, 97, 116, 97, 108, 111, 103, 0, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 99, 97, 116, 97, 108, 111, 103, 32, 100, 97, 116, 97, 0, 70, 114, 101, 101, 32, 99, 97, 116, 97, 108, 111, 103, 32, 101, 110, 116, 114, 121, 32, 37, 115, 10, 0, 0, 70, 114, 101, 101, 32, 99, 97, 116, 97, 108, 111, 103, 32, 101, 110, 116, 114, 121, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 31, 0, 0, 0, 0, 0, 0, 0, 32, 0, 0, 0, 0, 0, 0, 0, 32, 0, 0, 0, 0, 0, 0, 0, 33, 0, 0, 0, 0, 0, 0, 0, 34, 0, 0, 0, 0, 0, 0, 0, 50, 48, 57, 48, 50, 0, 0, 0, 96, 18, 2, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 16, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 35, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 32, 32, 0, 0, 0, 0, 0, 0, 8, 19, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 36, 0, 0, 0, 37, 0, 0, 0, 38, 0, 0, 0, 39, 0, 0, 0, 40, 0, 0, 0, 41, 0, 0, 0, 42, 0, 0, 0, 43, 0, 0, 0, 44, 0, 0, 0, 45, 0, 0, 0, 46, 0, 0, 0, 47, 0, 0, 0, 48, 0, 0, 0, 49, 0, 0, 0, 50, 0, 0, 0, 51, 0, 0, 0, 52, 0, 0, 0, 53, 0, 0, 0, 53, 0, 0, 0, 54, 0, 0, 0, 55, 0, 0, 0, 56], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 125808);
	        allocate([57, 0, 0, 0, 57, 0, 0, 0, 58, 0, 0, 0, 59, 0, 0, 0, 60, 0, 0, 0, 0, 0, 0, 0, 61, 0, 0, 0, 62, 0, 0, 0, 63, 0, 0, 0, 64, 0, 0, 0, 36, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 41, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 47, 0, 0, 0, 48, 0, 0, 0, 49, 0, 0, 0, 50, 0, 0, 0, 51, 0, 0, 0, 0, 0, 0, 0, 53, 0, 0, 0, 65, 0, 0, 0, 54, 0, 0, 0, 55, 0, 0, 0, 56, 0, 0, 0, 57, 0, 0, 0, 57, 0, 0, 0, 58, 0, 0, 0, 59, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 101, 120, 101, 99, 117, 116, 105, 110, 103, 32, 99, 49, 52, 110, 0, 0, 105, 110, 118, 97, 108, 105, 100, 32, 109, 111, 100, 101, 32, 102, 111, 114, 32, 101, 120, 101, 99, 117, 116, 105, 110, 103, 32, 99, 49, 52, 110, 0, 120, 109, 108, 67, 49, 52, 78, 69, 120, 101, 99, 117, 116, 101, 58, 32, 111, 117, 116, 112, 117, 116, 32, 98, 117, 102, 102, 101, 114, 32, 101, 110, 99, 111, 100, 101, 114, 32, 33, 61, 32, 78, 85, 76, 76, 32, 98, 117, 116, 32, 67, 49, 52, 78, 32, 114, 101, 113, 117, 105, 114, 101, 115, 32, 85, 84, 70, 56, 32, 111, 117, 116, 112, 117, 116, 10, 0, 0, 0, 0, 120, 109, 108, 67, 49, 52, 78, 69, 120, 101, 99, 117, 116, 101, 58, 32, 117, 110, 97, 98, 108, 101, 32, 116, 111, 32, 99, 114, 101, 97, 116, 101, 32, 67, 49, 52, 78, 32, 99, 111, 110, 116, 101, 120, 116, 10, 0, 0, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 100, 111, 99, 115, 32, 99, 104, 105, 108, 100, 114, 101, 110, 32, 108, 105, 115, 116, 0, 0, 0, 102, 108, 117, 115, 104, 105, 110, 103, 32, 111, 117, 116, 112, 117, 116, 32, 98, 117, 102, 102, 101, 114, 0, 0, 100, 117, 109, 112, 105, 110, 103, 32, 100, 111, 99, 32, 116, 111, 32, 109, 101, 109, 111, 114, 121, 0, 0, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 111, 117, 116, 112, 117, 116, 32, 98, 117, 102, 102, 101, 114, 0, 0, 115, 97, 118, 105, 110, 103, 32, 100, 111, 99, 32, 116, 111, 32, 111, 117, 116, 112, 117, 116, 32, 98, 117, 102, 102, 101, 114, 0, 0, 0, 0, 0, 99, 111, 112, 105, 110, 103, 32, 99, 97, 110, 111, 110, 105, 99, 97, 110, 105, 122, 101, 100, 32, 100, 111, 99, 117, 109, 101, 110, 116, 0, 0, 0, 77, 101, 109, 111, 114, 121, 32, 97, 108, 108, 111, 99, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 32, 58, 32, 37, 115, 10, 0, 0, 102, 114, 101, 101, 105, 110, 103, 32, 99, 111, 110, 116, 101, 120, 116, 0, 100, 101, 115, 116, 114, 111, 121, 105, 110, 103, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 115, 32, 115, 116, 97, 99, 107, 0, 0, 0, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 32, 58, 32, 37, 115, 10, 0, 0, 0, 0, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 110, 111, 100, 101, 32, 108, 105, 115, 116, 0, 0, 0, 0, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 110, 111, 100, 101, 0, 110, 111, 114, 109, 97, 108, 105, 122, 105, 110, 103, 32, 116, 101, 120, 116, 32, 110, 111, 100, 101, 0, 0, 0, 10, 60, 63, 0, 0, 0, 0, 0, 60, 63, 0, 0, 0, 0, 0, 0, 32, 0, 0, 0, 0, 0, 0, 0, 110, 111, 114, 109, 97, 108, 105, 122, 105, 110, 103, 32, 112, 105, 32, 110, 111, 100, 101, 0, 0, 0, 0, 0, 63, 62, 10, 0, 0, 0, 0, 0, 63, 62, 0, 0, 0, 0, 0, 0, 10, 60, 33, 45, 45, 0, 0, 0, 60, 33, 45, 45, 0, 0, 0, 0, 110, 111, 114, 109, 97, 108, 105, 122, 105, 110, 103, 32, 99, 111, 109, 109, 101, 110, 116, 32, 110, 111, 100, 101, 0, 0, 0, 0, 0, 0, 0, 0, 45, 45, 62, 10, 0, 0, 0, 0, 45, 45, 62, 0, 0, 0, 0, 0, 88, 77, 76, 95, 65, 84, 84, 82, 73, 66, 85, 84, 69, 95, 78, 79, 68, 69, 0, 0, 0, 0, 0, 0, 88, 77, 76, 95, 78, 65, 77, 69, 83, 80, 65, 67, 69, 95, 68, 69, 67, 76, 0, 0, 0, 0, 0, 0, 88, 77, 76, 95, 69, 78, 84, 73, 84, 89, 95, 82, 69, 70, 95, 78, 79, 68, 69, 0, 0, 0, 0, 0, 88, 77, 76, 95, 69, 78, 84, 73, 84, 89, 95, 78, 79, 68, 69, 0, 85, 110, 107, 110, 111, 119, 110, 32, 110, 111, 100, 101, 32, 116, 121, 112, 101, 32, 37, 100, 32, 102, 111, 117, 110, 100, 32, 58, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 0, 78, 111, 100, 101, 32, 37, 115, 32, 105, 115, 32, 105, 110, 118, 97, 108, 105, 100, 32, 104, 101, 114, 101, 32, 58, 32, 37, 115, 10, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 98, 117, 102, 102, 101, 114, 0, 0, 0, 0, 0, 0, 0, 103, 114, 111, 119, 105, 110, 103, 32, 98, 117, 102, 102, 101, 114, 0, 0, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 101, 108, 101, 109, 101, 110, 116, 32, 110, 111, 100, 101, 0, 99, 104, 101, 99, 107, 105, 110, 103, 32, 102, 111, 114, 32, 114, 101, 108, 97, 116, 105, 118, 101, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 115, 0, 0, 0, 0, 0, 0, 0, 0, 60, 0, 0, 0, 0, 0, 0, 0, 58, 0, 0, 0, 0, 0, 0, 0, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 115, 32, 97, 120, 105, 115, 0, 0, 0, 0, 0, 0, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 115, 32, 97, 120, 105, 115, 0, 0, 0, 0, 0, 0, 62, 0, 0, 0, 0, 0, 0, 0, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 99, 104, 105, 108, 100, 114, 101, 110, 115, 32, 108, 105, 115, 116, 0, 0, 0, 0, 0, 0, 0, 60, 47, 0, 0, 0, 0, 0, 0, 114, 101, 115, 116, 111, 114, 105, 110, 103, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 115, 32, 115, 116, 97, 99, 107, 0, 0, 0, 0, 0, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 115, 32, 108, 105, 115, 116, 0, 0, 0, 0, 0, 0, 0, 0, 108, 97, 110, 103, 0, 0, 0, 0, 115, 112, 97, 99, 101, 0, 0, 0, 98, 97, 115, 101, 0, 0, 0, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 88, 77, 76, 47, 49, 57, 57, 56, 47, 110, 97, 109, 101, 115, 112, 97, 99, 101, 0, 0, 0, 0, 119, 114, 105, 116, 105, 110, 103, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 115, 0, 0, 0, 0, 0, 0, 61, 34, 0, 0, 0, 0, 0, 0, 110, 111, 114, 109, 97, 108, 105, 122, 105, 110, 103, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 115, 32, 97, 120, 105, 115, 0, 0, 0, 0, 0, 34, 0, 0, 0, 0, 0, 0, 0, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 120, 109, 108, 58, 98, 97, 115, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 0, 0, 0, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 120, 109, 108, 58, 98, 97, 115, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 45, 32, 99, 97, 110, 39, 116, 32, 103, 101, 116, 32, 97, 116, 116, 114, 32, 118, 97, 108, 117, 101, 0, 0, 0, 0, 47, 0, 0, 0, 0, 0, 0, 0, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 120, 109, 108, 58, 98, 97, 115, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 45, 32, 99, 97, 110, 39, 116, 32, 109, 111, 100, 105, 102, 121, 32, 117, 114, 105, 0, 0, 0, 0, 0, 0, 0, 0, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 120, 109, 108, 58, 98, 97, 115, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 45, 32, 99, 97, 110, 39, 116, 32, 99, 111, 110, 115, 116, 114, 117, 99, 116, 32, 117, 114, 105, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 120, 109, 108, 58, 98, 97, 115, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 45, 32, 99, 97, 110, 39, 116, 32, 99, 111, 110, 115, 116, 114, 117, 99, 116, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 0, 0, 0, 0, 0, 115, 104, 105, 102, 116, 105, 110, 103, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 115, 32, 115, 116, 97, 99, 107, 0, 0, 0, 0, 0, 0, 0, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 115, 32, 97, 120, 105, 115, 32, 40, 101, 120, 99, 32, 99, 49, 52, 110, 41, 0, 0, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 115, 32, 108, 105, 115, 116, 32, 40, 101, 120, 99, 32, 99, 49, 52, 110, 41, 0, 0, 0, 0, 0, 35, 100, 101, 102, 97, 117, 108, 116, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 119, 114, 105, 116, 105, 110, 103, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 115, 0, 0, 0, 0, 0, 0, 32, 120, 109, 108, 110, 115, 58, 0, 61, 0, 0, 0, 0, 0, 0, 0, 32, 120, 109, 108, 110, 115, 61, 0, 34, 34, 0, 0, 0, 0, 0, 0, 115, 101, 97, 114, 99, 104, 105, 110, 103, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 115, 32, 115, 116, 97, 99, 107, 32, 40, 101, 120, 99, 32, 99, 49, 52, 110, 41, 0, 0, 0, 97, 100, 100, 105, 110, 103, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 116, 111, 32, 115, 116, 97, 99, 107, 0, 0, 0, 0, 0, 0, 0, 97, 100, 100, 105, 110, 103, 32, 110, 111, 100, 101, 32, 116, 111, 32, 115, 116, 97, 99, 107, 0, 0, 0, 0, 115, 101, 97, 114, 99, 104, 105, 110, 103, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 115, 32, 115, 116, 97, 99, 107, 32, 40, 99, 49, 52, 110, 41, 0, 0, 0, 0, 0, 0, 0, 112, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 115, 32, 97, 120, 105, 115, 32, 40, 99, 49, 52, 110, 41, 0, 0, 0, 0, 0, 0, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 115, 32, 108, 105, 115, 116, 32, 40, 99, 49, 52, 110, 41, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 115, 97, 118, 105, 110, 103, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 115, 32, 115, 116, 97, 99, 107, 0, 112, 97, 114, 115, 105, 110, 103, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 117, 114, 105, 0, 0, 0, 117, 114, 110, 0, 0, 0, 0, 0, 100, 97, 118, 0, 0, 0, 0, 0, 82, 101, 108, 97, 116, 105, 118, 101, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 85, 82, 32, 105, 115, 32, 105, 110, 118, 97, 108, 105, 100, 32, 104, 101, 114, 101, 32, 58, 32, 37, 115, 10, 0, 0, 0, 0, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 110, 101, 119, 32, 99, 111, 110, 116, 101, 120, 116, 0, 0, 0, 0, 120, 109, 108, 67, 49, 52, 78, 78, 101, 119, 67, 116, 120, 58, 32, 111, 117, 116, 112, 117, 116, 32, 98, 117, 102, 102, 101, 114, 32, 101, 110, 99, 111, 100, 101, 114, 32, 33, 61, 32, 78, 85, 76, 76, 32, 98, 117, 116, 32, 67, 49, 52, 78, 32, 114, 101, 113, 117, 105, 114, 101, 115, 32, 85, 84, 70, 56, 32, 111, 117, 116, 112, 117, 116, 10, 0, 0, 0, 0, 0, 120, 109, 108, 67, 49, 52, 78, 78, 101, 119, 67, 116, 120, 58, 32, 115, 111, 117, 114, 99, 101, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 110, 111, 116, 32, 105, 110, 32, 85, 84, 70, 56, 10, 0, 0, 0, 0, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 99, 111, 110, 116, 101, 120, 116, 0, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 67, 49, 52, 78, 78, 101, 119, 67, 116, 120, 58, 32, 120, 109, 108, 67, 49, 52, 78, 86, 105, 115, 105, 98, 108, 101, 78, 115, 83, 116, 97, 99, 107, 67, 114, 101, 97, 116, 101, 32, 102, 97, 105, 108, 101, 100, 10, 0, 0, 0, 0, 0, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 115, 32, 115, 116, 97, 99, 107, 0, 0, 0, 0, 0, 0, 0, 37, 115, 0, 0, 0, 0, 0, 0, 73, 110, 118, 97, 108, 105, 100, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 32, 58, 32, 37, 115, 10, 0, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, 62, 63, 64, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 92, 93, 94, 95, 96, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 123, 124, 125, 126, 127, 128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143, 144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159, 160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175, 176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191, 192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 204, 205, 206, 207, 208, 209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223, 224, 225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 237, 238, 239, 240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 255, 109, 97, 108, 108, 111, 99, 32, 111, 102, 32, 37, 108, 100, 32, 98, 121, 116, 101, 32, 102, 97, 105, 108, 101, 100, 10, 0, 0, 0, 0, 0, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 98, 117, 102, 102, 101, 114, 0, 0, 0, 0, 0, 0, 0, 0, 0, 103, 114, 111, 119, 105, 110, 103, 32, 98, 117, 102, 102, 101, 114, 0, 0, 34, 0, 0, 0, 0, 0, 0, 0, 38, 113, 117, 111, 116, 59, 0, 0, 39, 0, 0, 0, 0, 0, 0, 0, 73, 110, 112, 117, 116, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 111, 117, 116, 115, 105, 100, 101, 32, 111, 102, 32, 116, 104, 101, 32, 98, 117, 102, 102, 101, 114, 0, 0, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 101, 120, 101, 99, 117, 116, 105, 111, 110, 32, 99, 111, 110, 116, 101, 120, 116, 0, 0, 0, 0, 0, 0, 120, 109, 108, 70, 65, 80, 97, 114, 115, 101, 82, 101, 103, 69, 120, 112, 58, 32, 101, 120, 116, 114, 97, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 115, 0, 0, 0, 0, 0, 0, 110, 111, 116, 32, 37, 115, 0, 0, 97, 116, 111, 109, 32, 112, 117, 115, 104, 58, 32, 97, 116, 111, 109, 32, 105, 115, 32, 78, 85, 76, 76, 0, 112, 117, 115, 104, 105, 110, 103, 32, 97, 116, 111, 109, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 99, 111, 117, 110, 116, 101, 114, 0, 0, 0, 0, 0, 0, 97, 100, 100, 32, 115, 116, 97, 116, 101, 58, 32, 115, 116, 97, 116, 101, 32, 105, 115, 32, 78, 85, 76, 76, 0, 0, 0, 0, 0, 0, 0, 0, 97, 100, 100, 32, 115, 116, 97, 116, 101, 58, 32, 116, 97, 114, 103, 101, 116, 32, 105, 115, 32, 78, 85, 76, 76, 0, 0, 0, 0, 0, 0, 0, 97, 100, 100, 105, 110, 103, 32, 116, 114, 97, 110, 115, 105, 116, 105, 111, 110, 0, 0, 0, 0, 0, 0, 0, 103, 101, 110, 114, 97, 116, 101, 32, 116, 114, 97, 110, 115, 105, 116, 105, 111, 110, 58, 32, 97, 116, 111, 109, 32, 61, 61, 32, 78, 85, 76, 76, 0, 0, 0, 0, 0, 0, 0, 0, 99, 111, 112, 121, 105, 110, 103, 32, 97, 116, 111, 109, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 114, 97, 110, 103, 101, 0, 0, 0, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 97, 116, 111, 109, 0, 84, 79, 68, 79, 58, 32, 88, 77, 76, 95, 82, 69, 71, 69, 88, 80, 95, 83, 84, 82, 73, 78, 71, 10, 0, 0, 0, 0, 0, 0, 0, 0, 114, 117, 110, 110, 105, 110, 103, 32, 114, 101, 103, 101, 120, 112, 0, 0, 101, 112, 115, 105, 108, 111, 110, 32, 116, 114, 97, 110, 115, 105, 116, 105, 111, 110, 32, 108, 101, 102, 116, 32, 97, 116, 32, 114, 117, 110, 116, 105, 109, 101, 10, 0, 0, 0, 0, 0, 101, 120, 101, 99, 32, 115, 97, 118, 101, 58, 32, 97, 108, 108, 111, 99, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 0, 0, 0, 0, 115, 97, 118, 105, 110, 103, 32, 114, 101, 103, 101, 120, 112, 0, 0, 0, 99, 111, 109, 112, 105, 108, 105, 110, 103, 32, 114, 101, 103, 101, 120, 112, 0, 0, 0, 0, 0, 0, 0, 0, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 99, 111, 109, 112, 105, 108, 101, 58, 32, 37, 115, 10, 0, 0, 101, 120, 112, 101, 99, 116, 105, 110, 103, 32, 97, 32, 98, 114, 97, 110, 99, 104, 32, 97, 102, 116, 101, 114, 32, 124, 0, 0, 0, 0, 0, 0, 105, 110, 116, 101, 114, 110, 97, 108, 58, 32, 110, 111, 32, 97, 116, 111, 109, 32, 103, 101, 110, 101, 114, 97, 116, 101, 100, 0, 0, 0, 0, 0, 73, 109, 112, 114, 111, 112, 101, 114, 32, 113, 117, 97, 110, 116, 105, 102, 105, 101, 114, 0, 0, 0, 0, 0, 85, 110, 116, 101, 114, 109, 105, 110, 97, 116, 101, 100, 32, 113, 117, 97, 110, 116, 105, 102, 105, 101, 114, 0, 120, 109, 108, 70, 65, 80, 97, 114, 115, 101, 65, 116, 111, 109, 58, 32, 101, 120, 112, 101, 99, 116, 105, 110, 103, 32, 39, 41, 39, 0, 0, 0, 120, 109, 108, 70, 65, 80, 97, 114, 115, 101, 67, 104, 97, 114, 67, 108, 97, 115, 115, 58, 32, 39, 93, 39, 32, 101, 120, 112, 101, 99, 116, 101, 100, 0, 0, 0, 0, 0, 0, 0, 69, 115, 99, 97, 112, 101, 100, 32, 115, 101, 113, 117, 101, 110, 99, 101, 58, 32, 101, 120, 112, 101, 99, 116, 105, 110, 103, 32, 92, 0, 0, 0, 69, 120, 112, 101, 99, 116, 105, 110, 103, 32, 39, 123, 39, 0, 0, 0, 69, 120, 112, 101, 99, 116, 105, 110, 103, 32, 39, 125, 39, 0, 0, 0, 87, 114, 111, 110, 103, 32, 101, 115, 99, 97, 112, 101, 32, 115, 101, 113, 117, 101, 110, 99, 101, 44, 32, 109, 105, 115, 117, 115, 101, 32, 111, 102, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 39, 92, 39, 0, 0, 73, 115, 88, 88, 88, 88, 32, 101, 120, 112, 101, 99, 116, 101, 100, 0, 85, 110, 107, 110, 111, 119, 110, 32, 99, 104, 97, 114, 32, 112, 114, 111, 112, 101, 114, 116, 121, 0, 0, 0, 97, 100, 100, 32, 114, 97, 110, 103, 101, 58, 32, 97, 116, 111, 109, 32, 105, 115, 32, 78, 85, 76, 76, 0, 97, 100, 100, 32, 114, 97, 110, 103, 101, 58, 32, 97, 116, 111, 109, 32, 105, 115, 32, 110, 111, 116, 32, 114, 97, 110, 103, 101, 115, 0, 0, 0, 97, 100, 100, 105, 110, 103, 32, 114, 97, 110, 103, 101, 115, 0, 0, 0, 99, 104, 97, 114, 67, 108, 97, 115, 115, 69, 120, 112, 114, 58, 32, 39, 93, 39, 32, 101, 120, 112, 101, 99, 116, 101, 100, 0, 0, 0, 0, 0, 69, 120, 112, 101, 99, 116, 105, 110, 103, 32, 39, 93, 39, 0, 0, 0, 73, 110, 118, 97, 108, 105, 100, 32, 101, 115, 99, 97, 112, 101, 32, 118, 97, 108, 117, 101, 0, 0, 0, 0, 69, 120, 112, 101, 99, 116, 105, 110, 103, 32, 97, 32, 99, 104, 97, 114, 32, 114, 97, 110, 103, 101, 0, 0, 69, 120, 112, 101, 99, 116, 105, 110, 103, 32, 116, 104, 101, 32, 101, 110, 100, 32, 111, 102, 32, 97, 32, 99, 104, 97, 114, 32, 114, 97, 110, 103, 101, 0, 0, 0, 0, 0, 0, 0, 69, 110, 100, 32, 111, 102, 32, 114, 97, 110, 103, 101, 32, 105, 115, 32, 98, 101, 102, 111, 114, 101, 32, 115, 116, 97, 114, 116, 32, 111, 102, 32, 114, 97, 110, 103, 101, 0, 0, 0, 97, 100, 100, 105, 110, 103, 32, 115, 116, 97, 116, 101, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 115, 116, 97, 116, 101, 0, 0, 0, 0, 0, 0, 0, 0, 85, 110, 105, 109, 112, 108, 101, 109, 101, 110, 116, 101, 100, 32, 98, 108, 111, 99, 107, 32, 97, 116, 32, 37, 115, 58, 37, 100, 10, 0, 0, 0, 46, 46, 47, 108, 105, 98, 120, 109, 108, 50, 47, 120, 109, 108, 114, 101, 103, 101, 120, 112, 46, 99, 0, 0, 112, 117, 115, 104, 105, 110, 103, 32, 105, 110, 112, 117, 116, 32, 115, 116, 114, 105, 110, 103, 0, 0, 0, 0, 77, 101, 109, 111, 114, 121, 32, 97, 108, 108, 111, 99, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 32, 58, 32, 37, 115, 10, 0, 0, 85, 110, 105, 109, 112, 108, 101, 109, 101, 110, 116, 101, 100, 32, 98, 108, 111, 99, 107, 32, 97, 116, 32, 37, 115, 58, 37, 100, 10, 0, 0, 0, 46, 46, 47, 108, 105, 98, 120, 109, 108, 50, 47, 120, 109, 108, 115, 99, 104, 101, 109, 97, 115, 46, 99, 0, 10, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 67, 104, 101, 99, 107, 70, 97, 99, 101, 116, 0, 0, 0, 0, 0, 97, 32, 116, 121, 112, 101, 32, 117, 115, 101, 114, 32, 100, 101, 114, 105, 118, 101, 100, 32, 116, 121, 112, 101, 32, 104, 97, 115, 32, 110, 111, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 0, 0, 0, 0, 0, 0, 0, 42, 0, 0, 0, 0, 0, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 58, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 67, 104, 101, 99, 107, 70, 97, 99, 101, 116, 44, 32, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 118, 97, 108, 105, 100, 97, 116, 101, 32, 116, 104, 101, 32, 118, 97, 108, 117, 101, 32, 39, 37, 115, 39, 32, 111, 102, 32, 116, 104, 101, 32, 102, 97, 99, 101, 116, 32, 39, 37, 115, 39, 32, 97, 103, 97, 105, 110, 115, 116, 32, 116, 104, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 0, 0, 84, 104, 101, 32, 118, 97, 108, 117, 101, 32, 39, 37, 115, 39, 32, 111, 102, 32, 116, 104, 101, 32, 102, 97, 99, 101, 116, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 118, 97, 108, 105, 100, 97, 116, 101, 32, 97, 103, 97, 105, 110, 115, 116, 32, 116, 104, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 0, 0, 0, 0, 0, 0, 0, 0, 118, 97, 108, 117, 101, 32, 119, 97, 115, 32, 110, 111, 116, 32, 99, 111, 109, 112, 117, 116, 101, 100, 0, 0, 84, 104, 101, 32, 118, 97, 108, 117, 101, 32, 39, 37, 115, 39, 32, 111, 102, 32, 116, 104, 101, 32, 102, 97, 99, 101, 116, 32, 39, 112, 97, 116, 116, 101, 114, 110, 39, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 118, 97, 108, 105, 100, 32, 114, 101, 103, 117, 108, 97, 114, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 0, 118, 97, 108, 105, 100, 97, 116, 105, 110, 103, 32, 102, 97, 99, 101, 116, 32, 118, 97, 108, 117, 101, 0, 0, 84, 104, 101, 32, 118, 97, 108, 117, 101, 32, 39, 37, 115, 39, 32, 111, 102, 32, 116, 104, 101, 32, 102, 97, 99, 101, 116, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 118, 97, 108, 105, 100, 32, 39, 37, 115, 39, 0, 0, 0, 0, 110, 111, 110, 78, 101, 103, 97, 116, 105, 118, 101, 73, 110, 116, 101, 103, 101, 114, 0, 0, 0, 0, 0, 0, 112, 111, 115, 105, 116, 105, 118, 101, 73, 110, 116, 101, 103, 101, 114, 0, 112, 114, 101, 115, 101, 114, 118, 101, 0, 0, 0, 0, 0, 0, 0, 0, 114, 101, 112, 108, 97, 99, 101, 0, 99, 111, 108, 108, 97, 112, 115, 101, 0, 0, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 118, 97, 108, 117, 101, 32, 39, 37, 115, 39, 32, 111, 102, 32, 116, 104, 101, 32, 102, 97, 99, 101, 116, 32, 39, 119, 104, 105, 116, 101, 115, 112, 97, 99, 101, 39, 32, 105, 115, 32, 110, 111, 116, 32, 118, 97, 108, 105, 100, 0, 0, 0, 70, 97, 105, 108, 101, 100, 32, 116, 111, 32, 108, 111, 99, 97, 116, 101, 32, 116, 104, 101, 32, 109, 97, 105, 110, 32, 115, 99, 104, 101, 109, 97, 32, 114, 101, 115, 111, 117, 114, 99, 101, 32, 97, 116, 32, 39, 37, 115, 39, 0, 0, 0, 0, 0, 0, 0, 70, 97, 105, 108, 101, 100, 32, 116, 111, 32, 108, 111, 99, 97, 116, 101, 32, 116, 104, 101, 32, 109, 97, 105, 110, 32, 115, 99, 104, 101, 109, 97, 32, 114, 101, 115, 111, 117, 114, 99, 101, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 80, 97, 114, 115, 101, 0, 0, 65, 110, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 32, 111, 99, 99, 117, 114, 101, 100, 0, 0, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 118, 97, 108, 105, 100, 97, 116, 105, 111, 110, 32, 99, 111, 110, 116, 101, 120, 116, 0, 0, 0, 84, 104, 101, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 104, 97, 115, 32, 110, 111, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 101, 108, 101, 109, 101, 110, 116, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 65, 117, 103, 109, 101, 110, 116, 73, 68, 67, 58, 32, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 97, 110, 32, 97, 117, 103, 109, 101, 110, 116, 101, 100, 32, 73, 68, 67, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 67, 114, 101, 97, 116, 101, 80, 67, 116, 120, 116, 79, 110, 86, 67, 116, 120, 116, 0, 0, 0, 0, 0, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 99, 114, 101, 97, 116, 101, 32, 97, 32, 116, 101, 109, 112, 46, 32, 112, 97, 114, 115, 101, 114, 32, 99, 111, 110, 116, 101, 120, 116, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 83, 65, 88, 72, 97, 110, 100, 108, 101, 67, 68, 97, 116, 97, 83, 101, 99, 116, 105, 111, 110, 0, 0, 99, 97, 108, 108, 105, 110, 103, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 86, 80, 117, 115, 104, 84, 101, 120, 116, 40, 41, 0, 0, 0, 0, 78, 101, 105, 116, 104, 101, 114, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 110, 111, 114, 32, 101, 108, 101, 109, 101, 110, 116, 32, 99, 111, 110, 116, 101, 110, 116, 32, 105, 115, 32, 97, 108, 108, 111, 119, 101, 100, 32, 98, 101, 99, 97, 117, 115, 101, 32, 116, 104, 101, 32, 101, 108, 101, 109, 101, 110, 116, 32, 105, 115, 32, 39, 110, 105, 108, 108, 101, 100, 39, 0, 0, 0, 0, 0, 0, 0, 0, 67, 104, 97, 114, 97, 99, 116, 101, 114, 32, 99, 111, 110, 116, 101, 110, 116, 32, 105, 115, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 101, 100, 44, 32, 98, 101, 99, 97, 117, 115, 101, 32, 116, 104, 101, 32, 99, 111, 110, 116, 101, 110, 116, 32, 116, 121, 112, 101, 32, 105, 115, 32, 101, 109, 112, 116, 121, 0, 0, 0, 0, 0, 67, 104, 97, 114, 97, 99, 116, 101, 114, 32, 99, 111, 110, 116, 101, 110, 116, 32, 111, 116, 104, 101, 114, 32, 116, 104, 97, 110, 32, 119, 104, 105, 116, 101, 115, 112, 97, 99, 101, 32, 105, 115, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 101, 100, 32, 98, 101, 99, 97, 117, 115, 101, 32, 116, 104, 101, 32, 99, 111, 110, 116, 101, 110, 116, 32, 116, 121, 112, 101, 32, 105, 115, 32, 39, 101, 108, 101, 109, 101, 110, 116, 45, 111, 110, 108, 121, 39, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 83, 65, 88, 72, 97, 110, 100, 108, 101, 69, 110, 100, 69, 108, 101, 109, 101, 110, 116, 78, 115, 0, 0, 101, 108, 101, 109, 32, 112, 111, 112, 32, 109, 105, 115, 109, 97, 116, 99, 104, 0, 0, 0, 0, 0, 0, 0, 99, 97, 108, 108, 105, 110, 103, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 86, 97, 108, 105, 100, 97, 116, 111, 114, 80, 111, 112, 69, 108, 101, 109, 40, 41, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 86, 97, 108, 105, 100, 97, 116, 111, 114, 80, 111, 112, 69, 108, 101, 109, 0, 0, 0, 0, 0, 0, 0, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 99, 114, 101, 97, 116, 101, 32, 97, 32, 114, 101, 103, 101, 120, 32, 99, 111, 110, 116, 101, 120, 116, 0, 0, 0, 0, 0, 0, 0, 0, 77, 105, 115, 115, 105, 110, 103, 32, 99, 104, 105, 108, 100, 32, 101, 108, 101, 109, 101, 110, 116, 40, 115, 41, 0, 0, 0, 0, 0, 0, 0, 0, 99, 97, 108, 108, 105, 110, 103, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 86, 67, 104, 101, 99, 107, 67, 86, 67, 83, 105, 109, 112, 108, 101, 84, 121, 112, 101, 40, 41, 0, 0, 99, 97, 108, 108, 105, 110, 103, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 67, 104, 101, 99, 107, 67, 79, 83, 86, 97, 108, 105, 100, 68, 101, 102, 97, 117, 108, 116, 40, 41, 0, 99, 97, 108, 108, 105, 110, 103, 32, 120, 109, 108, 78, 101, 119, 84, 101, 120, 116, 40, 41, 0, 0, 0, 0, 84, 104, 101, 32, 99, 111, 110, 116, 101, 110, 116, 32, 109, 117, 115, 116, 32, 110, 111, 116, 32, 99, 111, 110, 116, 97, 105, 110, 116, 32, 101, 108, 101, 109, 101, 110, 116, 32, 110, 111, 100, 101, 115, 32, 115, 105, 110, 99, 101, 32, 116, 104, 101, 114, 101, 32, 105, 115, 32, 97, 32, 102, 105, 120, 101, 100, 32, 118, 97, 108, 117, 101, 32, 99, 111, 110, 115, 116, 114, 97, 105, 110, 116, 0, 0, 0, 0, 0, 84, 104, 101, 32, 105, 110, 105, 116, 105, 97, 108, 32, 118, 97, 108, 117, 101, 32, 39, 37, 115, 39, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 109, 97, 116, 99, 104, 32, 116, 104, 101, 32, 102, 105, 120, 101, 100, 32, 118, 97, 108, 117, 101, 32, 99, 111, 110, 115, 116, 114, 97, 105, 110, 116, 32, 39, 37, 115, 39, 0, 0, 0, 84, 104, 101, 32, 97, 99, 116, 117, 97, 108, 32, 118, 97, 108, 117, 101, 32, 39, 37, 115, 39, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 109, 97, 116, 99, 104, 32, 116, 104, 101, 32, 102, 105, 120, 101, 100, 32, 118, 97, 108, 117, 101, 32, 99, 111, 110, 115, 116, 114, 97, 105, 110, 116, 32, 39, 37, 115, 39, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 73, 68, 67, 32, 108, 105, 115, 116, 32, 111, 102, 32, 110, 111, 100, 101, 45, 116, 97, 98, 108, 101, 32, 105, 116, 101, 109, 115, 0, 114, 101, 45, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 73, 68, 67, 32, 108, 105, 115, 116, 32, 111, 102, 32, 110, 111, 100, 101, 45, 116, 97, 98, 108, 101, 32, 105, 116, 101, 109, 115, 0, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 97, 110, 32, 97, 114, 114, 97, 121, 32, 111, 102, 32, 73, 68, 67, 32, 110, 111, 100, 101, 45, 116, 97, 98, 108, 101, 32, 105, 116, 101, 109, 115, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 97, 32, 80, 83, 86, 73, 32, 73, 68, 67, 32, 98, 105, 110, 100, 105, 110, 103, 32, 105, 116, 101, 109, 0, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 110, 101, 119, 32, 105, 116, 101, 109, 32, 108, 105, 115, 116, 0, 0, 0, 0, 0, 0, 0, 0, 103, 114, 111, 119, 105, 110, 103, 32, 105, 116, 101, 109, 32, 108, 105, 115, 116, 0, 0, 0, 0, 0, 0, 0, 77, 111, 114, 101, 32, 116, 104, 97, 110, 32, 111, 110, 101, 32, 109, 97, 116, 99, 104, 32, 102, 111, 117, 110, 100, 32, 102, 111, 114, 32, 107, 101, 121, 45, 115, 101, 113, 117, 101, 110, 99, 101, 32, 37, 115, 32, 111, 102, 32, 107, 101, 121, 114, 101, 102, 32, 39, 37, 115, 39, 0, 0, 0, 0, 78, 111, 32, 109, 97, 116, 99, 104, 32, 102, 111, 117, 110, 100, 32, 102, 111, 114, 32, 107, 101, 121, 45, 115, 101, 113, 117, 101, 110, 99, 101, 32, 37, 115, 32, 111, 102, 32, 107, 101, 121, 114, 101, 102, 32, 39, 37, 115, 39, 0, 0, 0, 0, 0, 0, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 50, 48, 48, 49, 47, 88, 77, 76, 83, 99, 104, 101, 109, 97, 0, 0, 0, 0, 0, 0, 0, 0, 91, 0, 0, 0, 0, 0, 0, 0, 39, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 70, 111, 114, 109, 97, 116, 73, 68, 67, 75, 101, 121, 83, 101, 113, 117, 101, 110, 99, 101, 0, 0, 0, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 99, 111, 109, 112, 117, 116, 101, 32, 97, 32, 99, 97, 110, 111, 110, 105, 99, 97, 108, 32, 118, 97, 108, 117, 101, 0, 0, 0, 0, 0, 63, 63, 63, 0, 0, 0, 0, 0, 39, 44, 32, 0, 0, 0, 0, 0, 93, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 32, 0, 0, 0, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 39, 37, 115, 39, 58, 32, 0, 0, 46, 10, 0, 0, 0, 0, 0, 0, 114, 101, 45, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 97, 110, 32, 97, 114, 114, 97, 121, 32, 111, 102, 32, 73, 68, 67, 32, 110, 111, 100, 101, 45, 116, 97, 98, 108, 101, 32, 105, 116, 101, 109, 115, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 88, 80, 97, 116, 104, 80, 114, 111, 99, 101, 115, 115, 72, 105, 115, 116, 111, 114, 121, 0, 0, 0, 0, 99, 97, 108, 108, 105, 110, 103, 32, 120, 109, 108, 83, 116, 114, 101, 97, 109, 80, 111, 112, 40, 41, 0, 0, 102, 105, 101, 108, 100, 32, 114, 101, 115, 111, 108, 118, 101, 115, 32, 116, 111, 32, 97, 32, 67, 84, 32, 119, 105, 116, 104, 32, 115, 105, 109, 112, 108, 101, 32, 99, 111, 110, 116, 101, 110, 116, 32, 98, 117, 116, 32, 116, 104, 101, 32, 67, 84, 32, 105, 115, 32, 109, 105, 115, 115, 105, 110, 103, 32, 116, 104, 101, 32, 83, 84, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 88, 80, 97, 116, 104, 32, 39, 37, 115, 39, 32, 111, 102, 32, 97, 32, 102, 105, 101, 108, 100, 32, 111, 102, 32, 37, 115, 32, 100, 111, 101, 115, 32, 101, 118, 97, 108, 117, 97, 116, 101, 32, 116, 111, 32, 97, 32, 110, 111, 100, 101, 32, 111, 102, 32, 110, 111, 110, 45, 115, 105, 109, 112, 108, 101, 32, 116, 121, 112, 101, 0, 0, 0, 0, 0, 0, 87, 97, 114, 110, 105, 110, 103, 58, 32, 78, 111, 32, 112, 114, 101, 99, 111, 109, 112, 117, 116, 101, 100, 32, 118, 97, 108, 117, 101, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 44, 32, 116, 104, 101, 32, 118, 97, 108, 117, 101, 32, 119, 97, 115, 32, 101, 105, 116, 104, 101, 114, 32, 105, 110, 118, 97, 108, 105, 100, 32, 111, 114, 32, 115, 111, 109, 101, 116, 104, 105, 110, 103, 32, 115, 116, 114, 97, 110, 103, 101, 32, 104, 97, 112, 112, 101, 110, 100, 0, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 97, 110, 32, 97, 114, 114, 97, 121, 32, 111, 102, 32, 107, 101, 121, 45, 115, 101, 113, 117, 101, 110, 99, 101, 115, 0, 0, 0, 0, 114, 101, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 97, 110, 32, 97, 114, 114, 97, 121, 32, 111, 102, 32, 107, 101, 121, 45, 115, 101, 113, 117, 101, 110, 99, 101, 115, 0, 0, 84, 104, 101, 32, 88, 80, 97, 116, 104, 32, 39, 37, 115, 39, 32, 111, 102, 32, 97, 32, 102, 105, 101, 108, 100, 32, 111, 102, 32, 37, 115, 32, 101, 118, 97, 108, 117, 97, 116, 101, 115, 32, 116, 111, 32, 97, 32, 110, 111, 100, 101, 45, 115, 101, 116, 32, 119, 105, 116, 104, 32, 109, 111, 114, 101, 32, 116, 104, 97, 110, 32, 111, 110, 101, 32, 109, 101, 109, 98, 101, 114, 0, 0, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 97, 110, 32, 73, 68, 67, 32, 107, 101, 121, 45, 115, 101, 113, 117, 101, 110, 99, 101, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 97, 32, 73, 68, 67, 32, 107, 101, 121, 0, 0, 0, 0, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 107, 101, 121, 45, 115, 101, 113, 117, 101, 110, 99, 101, 32, 37, 115, 32, 105, 110, 32, 37, 115, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 97, 110, 32, 73, 68, 67, 32, 110, 111, 100, 101, 45, 116, 97, 98, 108, 101, 32, 105, 116, 101, 109, 0, 0, 0, 0, 0, 0, 0, 78, 111, 116, 32, 97, 108, 108, 32, 102, 105, 101, 108, 100, 115, 32, 111, 102, 32, 37, 115, 32, 101, 118, 97, 108, 117, 97, 116, 101, 32, 116, 111, 32, 97, 32, 110, 111, 100, 101, 0, 84, 104, 101, 32, 115, 116, 97, 116, 101, 32, 111, 98, 106, 101, 99, 116, 32, 116, 111, 32, 98, 101, 32, 114, 101, 109, 111, 118, 101, 100, 32, 105, 115, 32, 110, 111, 116, 32, 116, 104, 101, 32, 102, 105, 114, 115, 116, 32, 105, 110, 32, 116, 104, 101, 32, 108, 105, 115, 116, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 116, 104, 101, 32, 73, 68, 67, 32, 110, 111, 100, 101, 32, 116, 97, 98, 108, 101, 32, 105, 116, 101, 109, 32, 108, 105, 115, 116, 0, 114, 101, 45, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 116, 104, 101, 32, 73, 68, 67, 32, 110, 111, 100, 101, 32, 116, 97, 98, 108, 101, 32, 105, 116, 101, 109, 32, 108, 105, 115, 116, 0, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 116, 104, 101, 32, 73, 68, 67, 32, 107, 101, 121, 32, 115, 116, 111, 114, 97, 103, 101, 32, 108, 105, 115, 116, 0, 0, 0, 0, 0, 114, 101, 45, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 116, 104, 101, 32, 73, 68, 67, 32, 107, 101, 121, 32, 115, 116, 111, 114, 97, 103, 101, 32, 108, 105, 115, 116, 0, 0, 32, 39, 0, 0, 0, 0, 0, 0, 99, 111, 109, 112, 108, 101, 120, 32, 116, 121, 112, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 0, 115, 105, 109, 112, 108, 101, 32, 116, 121, 112, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 0, 0, 101, 108, 101, 109, 101, 110, 116, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 0, 0, 0, 0, 0, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 117, 115, 101, 0, 0, 0, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 0, 0, 0, 109, 111, 100, 101, 108, 32, 103, 114, 111, 117, 112, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 0, 0, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 103, 114, 111, 117, 112, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 0, 0, 0, 0, 0, 0, 110, 111, 116, 97, 116, 105, 111, 110, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 0, 0, 0, 0, 109, 111, 100, 101, 108, 32, 103, 114, 111, 117, 112, 32, 40, 115, 101, 113, 117, 101, 110, 99, 101, 41, 0, 0, 109, 111, 100, 101, 108, 32, 103, 114, 111, 117, 112, 32, 40, 99, 104, 111, 105, 99, 101, 41, 0, 0, 0, 0, 109, 111, 100, 101, 108, 32, 103, 114, 111, 117, 112, 32, 40, 97, 108, 108, 41, 0, 0, 0, 0, 0, 0, 0, 112, 97, 114, 116, 105, 99, 108, 101, 0, 0, 0, 0, 0, 0, 0, 0, 117, 110, 105, 113, 117, 101, 32, 105, 100, 101, 110, 116, 105, 116, 121, 45, 99, 111, 110, 115, 116, 114, 97, 105, 110, 116, 0, 0, 0, 0, 0, 0, 107, 101, 121, 32, 105, 100, 101, 110, 116, 105, 116, 121, 45, 99, 111, 110, 115, 116, 114, 97, 105, 110, 116, 0, 107, 101, 121, 114, 101, 102, 32, 105, 100, 101, 110, 116, 105, 116, 121, 45, 99, 111, 110, 115, 116, 114, 97, 105, 110, 116, 0, 0, 0, 0, 0, 0, 119, 105, 108, 100, 99, 97, 114, 100, 32, 40, 97, 110, 121, 41, 0, 0, 91, 104, 101, 108, 112, 101, 114, 32, 99, 111, 109, 112, 111, 110, 101, 110, 116, 93, 32, 81, 78, 97, 109, 101, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 0, 0, 0, 0, 0, 0, 91, 104, 101, 108, 112, 101, 114, 32, 99, 111, 109, 112, 111, 110, 101, 110, 116, 93, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 117, 115, 101, 32, 112, 114, 111, 104, 105, 98, 105, 116, 105, 111, 110, 0, 0, 0, 0, 78, 111, 116, 32, 97, 32, 115, 99, 104, 101, 109, 97, 32, 99, 111, 109, 112, 111, 110, 101, 110, 116, 0, 0, 70, 111, 114, 32, 97, 32, 115, 116, 114, 105, 110, 103, 32, 116, 111, 32, 98, 101, 32, 97, 32, 118, 97, 108, 105, 100, 32, 100, 101, 102, 97, 117, 108, 116, 44, 32, 116, 104, 101, 32, 116, 121, 112, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 109, 117, 115, 116, 32, 98, 101, 32, 97, 32, 115, 105, 109, 112, 108, 101, 32, 116, 121, 112, 101, 32, 111, 114, 32, 97, 32, 99, 111, 109, 112, 108, 101, 120, 32, 116, 121, 112, 101, 32, 119, 105, 116, 104, 32, 115, 105, 109, 112, 108, 101, 32, 99, 111, 110, 116, 101, 110, 116, 32, 111, 114, 32, 109, 105, 120, 101, 100, 32, 99, 111, 110, 116, 101, 110, 116, 32, 97, 110, 100, 32, 97, 32, 112, 97, 114, 116, 105, 99, 108, 101, 32, 101, 109, 112, 116, 105, 97, 98, 108, 101, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 67, 104, 101, 99, 107, 67, 79, 83, 86, 97, 108, 105, 100, 68, 101, 102, 97, 117, 108, 116, 0, 0, 0, 46, 0, 0, 0, 0, 0, 0, 0, 32, 69, 120, 112, 101, 99, 116, 101, 100, 32, 105, 115, 32, 111, 110, 101, 32, 111, 102, 32, 40, 32, 0, 0, 32, 69, 120, 112, 101, 99, 116, 101, 100, 32, 105, 115, 32, 40, 32, 0, 35, 35, 111, 116, 104, 101, 114, 0, 123, 42, 125, 0, 0, 0, 0, 0, 123, 35, 35, 111, 116, 104, 101, 114, 58, 0, 0, 0, 0, 0, 0, 0, 123, 0, 0, 0, 0, 0, 0, 0, 125, 0, 0, 0, 0, 0, 0, 0, 44, 32, 0, 0, 0, 0, 0, 0, 32, 41, 46, 10, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 39, 0, 0, 0, 0, 0, 0, 0, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 39, 0, 0, 0, 0, 0, 39, 58, 32, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 83, 65, 88, 72, 97, 110, 100, 108, 101, 83, 116, 97, 114, 116, 69, 108, 101, 109, 101, 110, 116, 78, 115, 0, 0, 0, 0, 0, 0, 0, 0, 99, 97, 108, 108, 105, 110, 103, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 86, 97, 108, 105, 100, 97, 116, 111, 114, 80, 117, 115, 104, 69, 108, 101, 109, 40, 41, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 98, 105, 110, 100, 105, 110, 103, 115, 32, 102, 111, 114, 32, 83, 65, 88, 32, 118, 97, 108, 105, 100, 97, 116, 105, 111, 110, 0, 0, 0, 0, 0, 0, 0, 0, 114, 101, 45, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 98, 105, 110, 100, 105, 110, 103, 115, 32, 102, 111, 114, 32, 83, 65, 88, 32, 118, 97, 108, 105, 100, 97, 116, 105, 111, 110, 0, 0, 0, 0, 0, 99, 97, 108, 108, 105, 110, 103, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 86, 97, 108, 105, 100, 97, 116, 111, 114, 80, 117, 115, 104, 65, 116, 116, 114, 105, 98, 117, 116, 101, 40, 41, 0, 0, 0, 0, 0, 0, 0, 99, 97, 108, 108, 105, 110, 103, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 86, 97, 108, 105, 100, 97, 116, 101, 69, 108, 101, 109, 40, 41, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 86, 97, 108, 105, 100, 97, 116, 101, 69, 108, 101, 109, 0, 0, 0, 105, 110, 32, 115, 107, 105, 112, 45, 115, 116, 97, 116, 101, 0, 0, 0, 99, 97, 108, 108, 105, 110, 103, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 83, 116, 114, 101, 97, 109, 86, 97, 108, 105, 100, 97, 116, 101, 67, 104, 105, 108, 100, 69, 108, 101, 109, 101, 110, 116, 40, 41, 0, 0, 0, 116, 104, 101, 32, 99, 104, 105, 108, 100, 32, 101, 108, 101, 109, 101, 110, 116, 32, 119, 97, 115, 32, 118, 97, 108, 105, 100, 32, 98, 117, 116, 32, 110, 101, 105, 116, 104, 101, 114, 32, 116, 104, 101, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 110, 111, 114, 32, 116, 104, 101, 32, 116, 121, 112, 101, 32, 119, 97, 115, 32, 115, 101, 116, 0, 0, 0, 0, 78, 111, 32, 109, 97, 116, 99, 104, 105, 110, 103, 32, 103, 108, 111, 98, 97, 108, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 32, 102, 111, 114, 32, 116, 104, 101, 32, 118, 97, 108, 105, 100, 97, 116, 105, 111, 110, 32, 114, 111, 111, 116, 0, 0, 0, 0, 0, 0, 0, 0, 99, 97, 108, 108, 105, 110, 103, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 86, 97, 108, 105, 100, 97, 116, 101, 69, 108, 101, 109, 87, 105, 108, 100, 99, 97, 114, 100, 40, 41, 0, 99, 97, 108, 108, 105, 110, 103, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 86, 97, 108, 105, 100, 97, 116, 101, 69, 108, 101, 109, 68, 101, 99, 108, 40, 41, 0, 0, 0, 0, 0, 84, 104, 101, 32, 116, 121, 112, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 105, 115, 32, 97, 98, 115, 101, 110, 116, 0, 0, 0, 84, 104, 101, 32, 116, 121, 112, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 105, 115, 32, 97, 98, 115, 116, 114, 97, 99, 116, 0, 99, 97, 108, 108, 105, 110, 103, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 88, 80, 97, 116, 104, 69, 118, 97, 108, 117, 97, 116, 101, 40, 41, 0, 0, 0, 0, 0, 0, 0, 0, 99, 97, 108, 108, 105, 110, 103, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 115, 32, 118, 97, 108, 105, 100, 97, 116, 105, 111, 110, 0, 0, 0, 84, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 101, 100, 46, 10, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 86, 65, 116, 116, 114, 105, 98, 117, 116, 101, 115, 67, 111, 109, 112, 108, 101, 120, 0, 0, 0, 0, 0, 99, 97, 108, 108, 105, 110, 103, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 71, 101, 116, 70, 114, 101, 115, 104, 65, 116, 116, 114, 73, 110, 102, 111, 40, 41, 0, 0, 0, 0, 0, 100, 101, 102, 97, 117, 108, 116, 47, 102, 105, 120, 101, 100, 32, 118, 97, 108, 117, 101, 32, 111, 110, 32, 97, 110, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 117, 115, 101, 32, 119, 97, 115, 32, 110, 111, 116, 32, 112, 114, 101, 99, 111, 109, 112, 117, 116, 101, 100, 0, 0, 0, 0, 0, 99, 97, 108, 108, 105, 110, 103, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 67, 111, 112, 121, 86, 97, 108, 117, 101, 40, 41, 0, 0, 0, 0, 99, 97, 108, 108, 108, 105, 110, 103, 32, 120, 109, 108, 78, 101, 119, 80, 114, 111, 112, 40, 41, 0, 0, 0, 112, 37, 100, 0, 0, 0, 0, 0, 99, 111, 117, 108, 100, 32, 110, 111, 116, 32, 99, 111, 109, 112, 117, 116, 101, 32, 97, 32, 110, 115, 32, 112, 114, 101, 102, 105, 120, 32, 102, 111, 114, 32, 97, 32, 100, 101, 102, 97, 117, 108, 116, 47, 102, 105, 120, 101, 100, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 0, 0, 0, 0, 0, 99, 97, 108, 108, 105, 110, 103, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 83, 116, 114, 101, 97, 109, 86, 97, 108, 105, 100, 97, 116, 101, 83, 105, 109, 112, 108, 101, 84, 121, 112, 101, 86, 97, 108, 117, 101, 40, 41, 0, 0, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 114, 101, 113, 117, 105, 114, 101, 100, 32, 98, 117, 116, 32, 109, 105, 115, 115, 105, 110, 103, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 118, 97, 108, 117, 101, 32, 39, 37, 115, 39, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 109, 97, 116, 99, 104, 32, 116, 104, 101, 32, 102, 105, 120, 101, 100, 32, 118, 97, 108, 117, 101, 32, 99, 111, 110, 115, 116, 114, 97, 105, 110, 116, 32, 39, 37, 115, 39, 0, 0, 0, 78, 111, 32, 109, 97, 116, 99, 104, 105, 110, 103, 32, 103, 108, 111, 98, 97, 108, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 44, 32, 98, 117, 116, 32, 100, 101, 109, 97, 110, 100, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32, 115, 116, 114, 105, 99, 116, 32, 119, 105, 108, 100, 99, 97, 114, 100, 0, 35, 35, 0, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 105, 110, 102, 111, 32, 108, 105, 115, 116, 0, 0, 114, 101, 45, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 105, 110, 102, 111, 32, 108, 105, 115, 116, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 71, 101, 116, 70, 114, 101, 115, 104, 65, 116, 116, 114, 73, 110, 102, 111, 0, 0, 0, 0, 0, 0, 0, 97, 116, 116, 114, 32, 105, 110, 102, 111, 32, 110, 111, 116, 32, 99, 108, 101, 97, 114, 101, 100, 0, 0, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 110, 101, 119, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 105, 110, 102, 111, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 88, 80, 97, 116, 104, 69, 118, 97, 108, 117, 97, 116, 101, 0, 0, 99, 97, 108, 108, 105, 110, 103, 32, 120, 109, 108, 83, 116, 114, 101, 97, 109, 80, 117, 115, 104, 40, 41, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 116, 104, 101, 32, 115, 116, 97, 116, 101, 32, 111, 98, 106, 101, 99, 116, 32, 104, 105, 115, 116, 111, 114, 121, 0, 0, 0, 0, 0, 114, 101, 45, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 116, 104, 101, 32, 115, 116, 97, 116, 101, 32, 111, 98, 106, 101, 99, 116, 32, 104, 105, 115, 116, 111, 114, 121, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 97, 110, 32, 73, 68, 67, 32, 115, 116, 97, 116, 101, 32, 111, 98, 106, 101, 99, 116, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 73, 68, 67, 65, 100, 100, 83, 116, 97, 116, 101, 79, 98, 106, 101, 99, 116, 0, 0, 0, 0, 0, 0, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 99, 114, 101, 97, 116, 101, 32, 97, 110, 32, 88, 80, 97, 116, 104, 32, 118, 97, 108, 105, 100, 97, 116, 105, 111, 110, 32, 99, 111, 110, 116, 101, 120, 116, 0, 0, 0, 0, 78, 111, 32, 109, 97, 116, 99, 104, 105, 110, 103, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 0, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 101, 108, 101, 109, 101, 110, 116, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 105, 115, 32, 97, 98, 115, 116, 114, 97, 99, 116, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 86, 97, 108, 105, 100, 97, 116], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 136048);
	        allocate([101, 69, 108, 101, 109, 68, 101, 99, 108, 0, 0, 0, 0, 0, 0, 0, 99, 97, 108, 108, 105, 110, 103, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 86, 67, 104, 101, 99, 107, 67, 86, 67, 83, 105, 109, 112, 108, 101, 84, 121, 112, 101, 40, 41, 32, 116, 111, 32, 118, 97, 108, 105, 100, 97, 116, 101, 32, 116, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 39, 120, 115, 105, 58, 110, 105, 108, 39, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 101, 108, 101, 109, 101, 110, 116, 32, 105, 115, 32, 110, 111, 116, 32, 39, 110, 105, 108, 108, 97, 98, 108, 101, 39, 0, 0, 0, 84, 104, 101, 32, 101, 108, 101, 109, 101, 110, 116, 32, 99, 97, 110, 110, 111, 116, 32, 98, 101, 32, 39, 110, 105, 108, 108, 101, 100, 39, 32, 98, 101, 99, 97, 117, 115, 101, 32, 116, 104, 101, 114, 101, 32, 105, 115, 32, 97, 32, 102, 105, 120, 101, 100, 32, 118, 97, 108, 117, 101, 32, 99, 111, 110, 115, 116, 114, 97, 105, 110, 116, 32, 100, 101, 102, 105, 110, 101, 100, 32, 102, 111, 114, 32, 105, 116, 0, 99, 97, 108, 108, 105, 110, 103, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 80, 114, 111, 99, 101, 115, 115, 88, 83, 73, 84, 121, 112, 101, 40, 41, 32, 116, 111, 32, 112, 114, 111, 99, 101, 115, 115, 32, 116, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 39, 120, 115, 105, 58, 116, 121, 112, 101, 39, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 73, 68, 67, 82, 101, 103, 105, 115, 116, 101, 114, 77, 97, 116, 99, 104, 101, 114, 115, 0, 0, 0, 0, 84, 104, 101, 32, 99, 104, 97, 105, 110, 32, 111, 102, 32, 73, 68, 67, 32, 109, 97, 116, 99, 104, 101, 114, 115, 32, 105, 115, 32, 101, 120, 112, 101, 99, 116, 101, 100, 32, 116, 111, 32, 98, 101, 32, 101, 109, 112, 116, 121, 0, 0, 0, 0, 0, 0, 0, 67, 111, 117, 108, 100, 32, 110, 111, 116, 32, 102, 105, 110, 100, 32, 97, 110, 32, 97, 117, 103, 109, 101, 110, 116, 101, 100, 32, 73, 68, 67, 32, 105, 116, 101, 109, 32, 102, 111, 114, 32, 97, 110, 32, 73, 68, 67, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 0, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 97, 110, 32, 73, 68, 67, 32, 109, 97, 116, 99, 104, 101, 114, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 86, 97, 108, 105, 100, 97, 116, 101, 69, 108, 101, 109, 101, 110, 116, 66, 121, 68, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 0, 0, 0, 99, 97, 108, 108, 105, 110, 103, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 81, 78, 97, 109, 101, 69, 120, 112, 97, 110, 100, 40, 41, 32, 116, 111, 32, 118, 97, 108, 105, 100, 97, 116, 101, 32, 116, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 39, 120, 115, 105, 58, 116, 121, 112, 101, 39, 0, 0, 0, 0, 0, 84, 104, 101, 32, 81, 78, 97, 109, 101, 32, 118, 97, 108, 117, 101, 32, 39, 37, 115, 39, 32, 111, 102, 32, 116, 104, 101, 32, 120, 115, 105, 58, 116, 121, 112, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 114, 101, 115, 111, 108, 118, 101, 32, 116, 111, 32, 97, 32, 116, 121, 112, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 0, 0, 0, 0, 84, 104, 101, 32, 116, 121, 112, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 39, 37, 115, 39, 44, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 98, 121, 32, 120, 115, 105, 58, 116, 121, 112, 101, 44, 32, 105, 115, 32, 98, 108, 111, 99, 107, 101, 100, 32, 111, 114, 32, 110, 111, 116, 32, 118, 97, 108, 105, 100, 108, 121, 32, 100, 101, 114, 105, 118, 101, 100, 32, 102, 114, 111, 109, 32, 116, 104, 101, 32, 116, 121, 112, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 111, 102, 32, 116, 104, 101, 32, 101, 108, 101, 109, 101, 110, 116, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 84, 121, 112, 101, 70, 105, 120, 117, 112, 0, 0, 0, 0, 0, 0, 116, 104, 105, 115, 32, 102, 117, 110, 99, 116, 105, 111, 110, 32, 110, 101, 101, 100, 115, 32, 97, 32, 112, 97, 114, 115, 101, 114, 32, 99, 111, 110, 116, 101, 120, 116, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 70, 105, 120, 117, 112, 83, 105, 109, 112, 108, 101, 84, 121, 112, 101, 83, 116, 97, 103, 101, 84, 119, 111, 0, 0, 0, 0, 0, 0, 0, 0, 109, 105, 115, 115, 105, 110, 103, 32, 98, 97, 115, 101, 84, 121, 112, 101, 0, 0, 0, 0, 0, 0, 0, 0, 73, 116, 32, 105, 115, 32, 97, 110, 32, 101, 114, 114, 111, 114, 32, 102, 111, 114, 32, 98, 111, 116, 104, 32, 39, 108, 101, 110, 103, 116, 104, 39, 32, 97, 110, 100, 32, 101, 105, 116, 104, 101, 114, 32, 111, 102, 32, 39, 109, 105, 110, 76, 101, 110, 103, 116, 104, 39, 32, 111, 114, 32, 39, 109, 97, 120, 76, 101, 110, 103, 116, 104, 39, 32, 116, 111, 32, 98, 101, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 111, 110, 32, 116, 104, 101, 32, 115, 97, 109, 101, 32, 116, 121, 112, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 0, 0, 0, 73, 116, 32, 105, 115, 32, 97, 110, 32, 101, 114, 114, 111, 114, 32, 102, 111, 114, 32, 98, 111, 116, 104, 32, 39, 37, 115, 39, 32, 97, 110, 100, 32, 39, 37, 115, 39, 32, 116, 111, 32, 98, 101, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 32, 111, 110, 32, 116, 104, 101, 32, 115, 97, 109, 101, 32, 116, 121, 112, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 0, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 39, 115, 32, 102, 97, 99, 101, 116, 32, 105, 115, 32, 39, 102, 105, 120, 101, 100, 39, 44, 32, 116, 104, 117, 115, 32, 116, 104, 101, 32, 118, 97, 108, 117, 101, 32, 109, 117, 115, 116, 32, 110, 111, 116, 32, 100, 105, 102, 102, 101, 114, 0, 0, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 39, 119, 104, 105, 116, 101, 115, 112, 97, 99, 101, 39, 32, 118, 97, 108, 117, 101, 32, 104, 97, 115, 32, 116, 111, 32, 98, 101, 32, 101, 113, 117, 97, 108, 32, 116, 111, 32, 111, 114, 32, 115, 116, 114, 111, 110, 103, 101, 114, 32, 116, 104, 97, 110, 32, 116, 104, 101, 32, 39, 119, 104, 105, 116, 101, 115, 112, 97, 99, 101, 39, 32, 118, 97, 108, 117, 101, 32, 111, 102, 32, 116, 104, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 0, 0, 0, 0, 0, 0, 100, 101, 114, 105, 118, 105, 110, 103, 32, 102, 97, 99, 101, 116, 115, 44, 32, 99, 114, 101, 97, 116, 105, 110, 103, 32, 97, 32, 102, 97, 99, 101, 116, 32, 108, 105, 110, 107, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 68, 101, 114, 105, 118, 101, 65, 110, 100, 86, 97, 108, 105, 100, 97, 116, 101, 70, 97, 99, 101, 116, 115, 0, 0, 0, 0, 0, 0, 0, 0, 97, 110, 32, 101, 114, 114, 111, 114, 32, 111, 99, 99, 117, 114, 101, 100, 0, 0, 0, 0, 0, 0, 0, 0, 39, 32, 104, 97, 115, 32, 116, 111, 32, 98, 101, 0, 0, 0, 0, 0, 32, 101, 113, 117, 97, 108, 32, 116, 111, 0, 0, 0, 0, 0, 0, 0, 32, 103, 114, 101, 97, 116, 101, 114, 32, 116, 104, 97, 110, 0, 0, 0, 32, 108, 101, 115, 115, 32, 116, 104, 97, 110, 0, 0, 0, 0, 0, 0, 32, 111, 114, 32, 101, 113, 117, 97, 108, 32, 116, 111, 0, 0, 0, 0, 39, 32, 111, 102, 32, 116, 104, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 0, 0, 0, 0, 0, 0, 37, 115, 58, 32, 0, 0, 0, 0, 97, 116, 111, 109, 105, 99, 32, 116, 121, 112, 101, 32, 39, 120, 115, 58, 0, 0, 0, 0, 0, 0, 0, 0, 108, 105, 115, 116, 32, 116, 121, 112, 101, 32, 39, 120, 115, 58, 0, 0, 117, 110, 105, 111, 110, 32, 116, 121, 112, 101, 32, 39, 120, 115, 58, 0, 115, 105, 109, 112, 108, 101, 32, 116, 121, 112, 101, 32, 39, 120, 115, 58, 0, 0, 0, 0, 0, 0, 0, 0, 108, 111, 99, 97, 108, 32, 0, 0, 97, 116, 111, 109, 105, 99, 32, 116, 121, 112, 101, 0, 0, 0, 0, 0, 108, 105, 115, 116, 32, 116, 121, 112, 101, 0, 0, 0, 0, 0, 0, 0, 117, 110, 105, 111, 110, 32, 116, 121, 112, 101, 0, 0, 0, 0, 0, 0, 115, 105, 109, 112, 108, 101, 32, 116, 121, 112, 101, 0, 0, 0, 0, 0, 99, 111, 109, 112, 108, 101, 120, 32, 116, 121, 112, 101, 0, 0, 0, 0, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 117, 115, 101, 32, 0, 0, 40, 117, 110, 107, 110, 111, 119, 110, 41, 0, 0, 0, 0, 0, 0, 0, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 100, 101, 99, 108, 46, 0, 101, 108, 101, 109, 101, 110, 116, 32, 100, 101, 99, 108, 46, 0, 0, 0, 117, 110, 105, 113, 117, 101, 32, 39, 0, 0, 0, 0, 0, 0, 0, 0, 107, 101, 121, 32, 39, 0, 0, 0, 107, 101, 121, 82, 101, 102, 32, 39, 0, 0, 0, 0, 0, 0, 0, 0, 32, 119, 105, 108, 100, 99, 97, 114, 100, 0, 0, 0, 0, 0, 0, 0, 102, 97, 99, 101, 116, 32, 39, 0, 109, 111, 100, 101, 108, 32, 103, 114, 111, 117, 112, 32, 100, 101, 102, 46, 0, 0, 0, 0, 0, 0, 0, 0, 44, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 39, 0, 0, 0, 115, 107, 105, 112, 0, 0, 0, 0, 108, 97, 120, 0, 0, 0, 0, 0, 115, 116, 114, 105, 99, 116, 0, 0, 105, 110, 118, 97, 108, 105, 100, 32, 112, 114, 111, 99, 101, 115, 115, 32, 99, 111, 110, 116, 101, 110, 116, 115, 0, 0, 0, 0, 0, 0, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 58, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 67, 114, 101, 97, 116, 101, 86, 67, 116, 120, 116, 79, 110, 80, 67, 116, 120, 116, 44, 32, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 99, 114, 101, 97, 116, 101, 32, 97, 32, 116, 101, 109, 112, 46, 32, 118, 97, 108, 105, 100, 97, 116, 105, 111, 110, 32, 99, 111, 110, 116, 101, 120, 116, 46, 10, 0, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 67, 104, 101, 99, 107, 67, 79, 83, 83, 84, 82, 101, 115, 116, 114, 105, 99, 116, 115, 0, 0, 0, 0, 103, 105, 118, 101, 110, 32, 116, 121, 112, 101, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 117, 115, 101, 114, 45, 100, 101, 114, 105, 118, 101, 100, 32, 115, 105, 109, 112, 108, 101, 84, 121, 112, 101, 0, 0, 0, 0, 0, 84, 104, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 97, 110, 32, 97, 116, 111, 109, 105, 99, 32, 115, 105, 109, 112, 108, 101, 32, 116, 121, 112, 101, 0, 84, 104, 101, 32, 102, 105, 110, 97, 108, 32, 111, 102, 32, 105, 116, 115, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 32, 109, 117, 115, 116, 32, 110, 111, 116, 32, 99, 111, 110, 116, 97, 105, 110, 32, 39, 114, 101, 115, 116, 114, 105, 99, 116, 105, 111, 110, 39, 0, 0, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 103, 101, 116, 32, 112, 114, 105, 109, 105, 116, 105, 118, 101, 32, 116, 121, 112, 101, 0, 0, 0, 0, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 101, 118, 97, 108, 117, 97, 116, 101, 32, 116, 104, 101, 32, 105, 116, 101, 109, 32, 116, 121, 112, 101, 0, 0, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 105, 116, 101, 109, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 104, 97, 118, 101, 32, 97, 32, 118, 97, 114, 105, 101, 116, 121, 32, 111, 102, 32, 97, 116, 111, 109, 105, 99, 32, 111, 114, 32, 117, 110, 105, 111, 110, 0, 0, 0, 84, 104, 101, 32, 105, 116, 101, 109, 32, 116, 121, 112, 101, 32, 105, 115, 32, 97, 32, 117, 110, 105, 111, 110, 32, 116, 121, 112, 101, 44, 32, 98, 117, 116, 32, 116, 104, 101, 32, 109, 101, 109, 98, 101, 114, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 32, 111, 102, 32, 116, 104, 105, 115, 32, 105, 116, 101, 109, 32, 116, 121, 112, 101, 32, 105, 115, 32, 110, 111, 116, 32, 97, 116, 111, 109, 105, 99, 0, 84, 104, 101, 32, 102, 105, 110, 97, 108, 32, 111, 102, 32, 105, 116, 115, 32, 105, 116, 101, 109, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 32, 109, 117, 115, 116, 32, 110, 111, 116, 32, 99, 111, 110, 116, 97, 105, 110, 32, 39, 108, 105, 115, 116, 39, 0, 84, 104, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 32, 109, 117, 115, 116, 32, 98, 101, 32, 97, 32, 108, 105, 115, 116, 32, 116, 121, 112, 101, 0, 0, 84, 104, 101, 32, 39, 102, 105, 110, 97, 108, 39, 32, 111, 102, 32, 116, 104, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 32, 109, 117, 115, 116, 32, 110, 111, 116, 32, 99, 111, 110, 116, 97, 105, 110, 32, 39, 114, 101, 115, 116, 114, 105, 99, 116, 105, 111, 110, 39, 0, 0, 0, 0, 0, 0, 0, 0, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 101, 118, 97, 108, 32, 116, 104, 101, 32, 105, 116, 101, 109, 32, 116, 121, 112, 101, 32, 111, 102, 32, 97, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 0, 0, 0, 0, 0, 84, 104, 101, 32, 105, 116, 101, 109, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 118, 97, 108, 105, 100, 108, 121, 32, 100, 101, 114, 105, 118, 101, 100, 32, 102, 114, 111, 109, 32, 116, 104, 101, 32, 105, 116, 101, 109, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 32, 111, 102, 32, 116, 104, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 0, 84, 104, 101, 32, 109, 101, 109, 98, 101, 114, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 101, 105, 116, 104, 101, 114, 32, 97, 110, 32, 97, 116, 111, 109, 105, 99, 44, 32, 110, 111, 114, 32, 97, 32, 108, 105, 115, 116, 32, 116, 121, 112, 101, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 39, 102, 105, 110, 97, 108, 39, 32, 111, 102, 32, 109, 101, 109, 98, 101, 114, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 32, 99, 111, 110, 116, 97, 105, 110, 115, 32, 39, 117, 110, 105, 111, 110, 39, 0, 0, 0, 0, 0, 0, 0, 0, 78, 111, 32, 102, 97, 99, 101, 116, 115, 32, 97, 108, 108, 111, 119, 101, 100, 0, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 117, 110, 105, 111, 110, 32, 116, 121, 112, 101, 0, 0, 84, 104, 101, 32, 39, 102, 105, 110, 97, 108, 39, 32, 111, 102, 32, 105, 116, 115, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 32, 109, 117, 115, 116, 32, 110, 111, 116, 32, 99, 111, 110, 116, 97, 105, 110, 32, 39, 114, 101, 115, 116, 114, 105, 99, 116, 105, 111, 110, 39, 0, 0, 0, 0, 0, 0, 0, 0, 100, 105, 102, 102, 101, 114, 101, 110, 116, 32, 110, 117, 109, 98, 101, 114, 32, 111, 102, 32, 109, 101, 109, 98, 101, 114, 32, 116, 121, 112, 101, 115, 32, 105, 110, 32, 98, 97, 115, 101, 0, 0, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 109, 101, 109, 98, 101, 114, 32, 116, 121, 112, 101, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 118, 97, 108, 105, 100, 108, 121, 32, 100, 101, 114, 105, 118, 101, 100, 32, 102, 114, 111, 109, 32, 105, 116, 115, 32, 99, 111, 114, 114, 101, 115, 112, 111, 110, 100, 105, 110, 103, 32, 109, 101, 109, 98, 101, 114, 32, 116, 121, 112, 101, 32, 37, 115, 32, 111, 102, 32, 116, 104, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 32, 37, 115, 0, 0, 0, 0, 0, 37, 115, 58, 32, 84, 104, 101, 32, 102, 97, 99, 101, 116, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 101, 100, 46, 10, 0, 0, 0, 0, 0, 37, 115, 58, 32, 84, 104, 101, 32, 102, 97, 99, 101, 116, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 101, 100, 32, 111, 110, 32, 116, 121, 112, 101, 115, 32, 100, 101, 114, 105, 118, 101, 100, 32, 102, 114, 111, 109, 32, 116, 104, 101, 32, 116, 121, 112, 101, 32, 37, 115, 46, 10, 0, 0, 0, 78, 111, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 32, 101, 120, 105, 115, 116, 101, 110, 116, 0, 0, 0, 84, 104, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 115, 105, 109, 112, 108, 101, 32, 116, 121, 112, 101, 0, 65, 32, 116, 121, 112, 101, 44, 32, 100, 101, 114, 105, 118, 101, 100, 32, 98, 121, 32, 108, 105, 115, 116, 32, 111, 114, 32, 117, 110, 105, 111, 110, 44, 32, 109, 117, 115, 116, 32, 104, 97, 118, 101, 32, 116, 104, 101, 32, 115, 105, 109, 112, 108, 101, 32, 117, 114, 45, 116, 121, 112, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 97, 115, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 44, 32, 110, 111, 116, 32, 39, 37, 115, 39, 0, 0, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 118, 97, 114, 105, 101, 116, 121, 32, 105, 115, 32, 97, 98, 115, 101, 110, 116, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 97, 32, 116, 121, 112, 101, 32, 108, 105, 110, 107, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 70, 105, 120, 117, 112, 67, 111, 109, 112, 108, 101, 120, 84, 121, 112, 101, 0, 0, 0, 0, 0, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 58, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 84, 121, 112, 101, 70, 105, 120, 117, 112, 44, 32, 99, 111, 109, 112, 108, 101, 120, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 58, 32, 116, 104, 101, 32, 60, 115, 105, 109, 112, 108, 101, 67, 111, 110, 116, 101, 110, 116, 62, 60, 114, 101, 115, 116, 114, 105, 99, 116, 105, 111, 110, 62, 32, 105, 115, 32, 109, 105, 115, 115, 105, 110, 103, 32, 97, 32, 60, 115, 105, 109, 112, 108, 101, 84, 121, 112, 101, 62, 32, 99, 104, 105, 108, 100, 44, 32, 98, 117, 116, 32, 119, 97, 115, 32, 110, 111, 116, 32, 99, 97, 116, 99, 104, 101, 100, 32, 98, 121, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 67, 104, 101, 99, 107, 83, 82, 67, 67, 84, 40, 41, 0, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 58, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 84, 121, 112, 101, 70, 105, 120, 117, 112, 44, 32, 99, 111, 109, 112, 108, 101, 120, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 58, 32, 116, 104, 101, 32, 60, 101, 120, 116, 101, 110, 115, 105, 111, 110, 62, 101, 100, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 32, 105, 115, 32, 97, 32, 99, 111, 109, 112, 108, 101, 120, 32, 116, 121, 112, 101, 32, 119, 105, 116, 104, 32, 110, 111, 32, 115, 105, 109, 112, 108, 101, 32, 99, 111, 110, 116, 101, 110, 116, 32, 116, 121, 112, 101, 0, 0, 0, 0, 0, 0, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 58, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 84, 121, 112, 101, 70, 105, 120, 117, 112, 44, 32, 99, 111, 109, 112, 108, 101, 120, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 32, 119, 105, 116, 104, 32, 60, 115, 105, 109, 112, 108, 101, 67, 111, 110, 116, 101, 110, 116, 62, 58, 32, 117, 110, 104, 97, 110, 100, 108, 101, 100, 32, 100, 101, 114, 105, 118, 97, 116, 105, 111, 110, 32, 99, 97, 115, 101, 0, 0, 0, 84, 104, 101, 32, 116, 121, 112, 101, 32, 104, 97, 115, 32, 97, 110, 32, 39, 97, 108, 108, 39, 32, 109, 111, 100, 101, 108, 32, 103, 114, 111, 117, 112, 32, 105, 110, 32, 105, 116, 115, 32, 123, 99, 111, 110, 116, 101, 110, 116, 32, 116, 121, 112, 101, 125, 32, 97, 110, 100, 32, 116, 104, 117, 115, 32, 99, 97, 110, 110, 111, 116, 32, 98, 101, 32, 100, 101, 114, 105, 118, 101, 100, 32, 102, 114, 111, 109, 32, 97, 32, 110, 111, 110, 45, 101, 109, 112, 116, 121, 32, 116, 121, 112, 101, 44, 32, 115, 105, 110, 99, 101, 32, 116, 104, 105, 115, 32, 119, 111, 117, 108, 100, 32, 112, 114, 111, 100, 117, 99, 101, 32, 97, 32, 39, 115, 101, 113, 117, 101, 110, 99, 101, 39, 32, 109, 111, 100, 101, 108, 32, 103, 114, 111, 117, 112, 32, 99, 111, 110, 116, 97, 105, 110, 105, 110, 103, 32, 116, 104, 101, 32, 39, 97, 108, 108, 39, 32, 109, 111, 100, 101, 108, 32, 103, 114, 111, 117, 112, 59, 32, 39, 97, 108, 108, 39, 32, 109, 111, 100, 101, 108, 32, 103, 114, 111, 117, 112, 115, 32, 97, 114, 101, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 101, 100, 32, 116, 111, 32, 97, 112, 112, 101, 97, 114, 32, 105, 110, 115, 105, 100, 101, 32, 111, 116, 104, 101, 114, 32, 109, 111, 100, 101, 108, 32, 103, 114, 111, 117, 112, 115, 0, 0, 0, 0, 65, 32, 116, 121, 112, 101, 32, 99, 97, 110, 110, 111, 116, 32, 98, 101, 32, 100, 101, 114, 105, 118, 101, 100, 32, 98, 121, 32, 101, 120, 116, 101, 110, 115, 105, 111, 110, 32, 102, 114, 111, 109, 32, 97, 32, 116, 121, 112, 101, 32, 119, 104, 105, 99, 104, 32, 104, 97, 115, 32, 97, 110, 32, 39, 97, 108, 108, 39, 32, 109, 111, 100, 101, 108, 32, 103, 114, 111, 117, 112, 32, 105, 110, 32, 105, 116, 115, 32, 123, 99, 111, 110, 116, 101, 110, 116, 32, 116, 121, 112, 101, 125, 44, 32, 115, 105, 110, 99, 101, 32, 116, 104, 105, 115, 32, 119, 111, 117, 108, 100, 32, 112, 114, 111, 100, 117, 99, 101, 32, 97, 32, 39, 115, 101, 113, 117, 101, 110, 99, 101, 39, 32, 109, 111, 100, 101, 108, 32, 103, 114, 111, 117, 112, 32, 99, 111, 110, 116, 97, 105, 110, 105, 110, 103, 32, 116, 104, 101, 32, 39, 97, 108, 108, 39, 32, 109, 111, 100, 101, 108, 32, 103, 114, 111, 117, 112, 59, 32, 39, 97, 108, 108, 39, 32, 109, 111, 100, 101, 108, 32, 103, 114, 111, 117, 112, 115, 32, 97, 114, 101, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 101, 100, 32, 116, 111, 32, 97, 112, 112, 101, 97, 114, 32, 105, 110, 115, 105, 100, 101, 32, 111, 116, 104, 101, 114, 32, 109, 111, 100, 101, 108, 32, 103, 114, 111, 117, 112, 115, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 32, 109, 117, 115, 116, 32, 98, 101, 32, 97, 32, 99, 111, 109, 112, 108, 101, 120, 32, 116, 121, 112, 101, 0, 0, 0, 0, 84, 104, 101, 32, 39, 102, 105, 110, 97, 108, 39, 32, 111, 102, 32, 116, 104, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 99, 111, 110, 116, 97, 105, 110, 115, 32, 39, 114, 101, 115, 116, 114, 105, 99, 116, 105, 111, 110, 39, 0, 0, 84, 104, 101, 32, 123, 99, 111, 110, 116, 101, 110, 116, 32, 116, 121, 112, 101, 125, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 118, 97, 108, 105, 100, 108, 121, 32, 100, 101, 114, 105, 118, 101, 100, 32, 102, 114, 111, 109, 32, 116, 104, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 39, 115, 32, 123, 99, 111, 110, 116, 101, 110, 116, 32, 116, 121, 112, 101, 125, 32, 37, 115, 0, 0, 0, 0, 0, 84, 104, 101, 32, 99, 111, 110, 116, 101, 110, 116, 32, 116, 121, 112, 101, 32, 111, 102, 32, 116, 104, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 32, 109, 117, 115, 116, 32, 98, 101, 32, 101, 105, 116, 104, 101, 114, 32, 97, 32, 115, 105, 109, 112, 108, 101, 32, 116, 121, 112, 101, 32, 111, 114, 32, 39, 109, 105, 120, 101, 100, 39, 32, 97, 110, 100, 32, 97, 110, 32, 101, 109, 112, 116, 105, 97, 98, 108, 101, 32, 112, 97, 114, 116, 105, 99, 108, 101, 0, 0, 0, 0, 0, 84, 104, 101, 32, 99, 111, 110, 116, 101, 110, 116, 32, 116, 121, 112, 101, 32, 111, 102, 32, 116, 104, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 32, 109, 117, 115, 116, 32, 98, 101, 32, 101, 105, 116, 104, 101, 114, 32, 101, 109, 112, 116, 121, 32, 111, 114, 32, 39, 109, 105, 120, 101, 100, 39, 32, 40, 111, 114, 32, 39, 101, 108, 101, 109, 101, 110, 116, 115, 45, 111, 110, 108, 121, 39, 41, 32, 97, 110, 100, 32, 97, 110, 32, 101, 109, 112, 116, 105, 97, 98, 108, 101, 32, 112, 97, 114, 116, 105, 99, 108, 101, 0, 0, 0, 0, 0, 0, 0, 0, 73, 102, 32, 116, 104, 101, 32, 99, 111, 110, 116, 101, 110, 116, 32, 116, 121, 112, 101, 32, 105, 115, 32, 39, 109, 105, 120, 101, 100, 39, 44, 32, 116, 104, 101, 110, 32, 116, 104, 101, 32, 99, 111, 110, 116, 101, 110, 116, 32, 116, 121, 112, 101, 32, 111, 102, 32, 116, 104, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 32, 109, 117, 115, 116, 32, 97, 108, 115, 111, 32, 98, 101, 32, 39, 109, 105, 120, 101, 100, 39, 0, 0, 0, 0, 0, 84, 104, 101, 32, 116, 121, 112, 101, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 118, 97, 108, 105, 100, 32, 114, 101, 115, 116, 114, 105, 99, 116, 105, 111, 110, 32, 111, 102, 32, 105, 116, 115, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 0, 0, 0, 0, 84, 104, 101, 32, 39, 111, 112, 116, 105, 111, 110, 97, 108, 39, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 117, 115, 101, 32, 105, 115, 32, 105, 110, 99, 111, 110, 115, 105, 115, 116, 101, 110, 116, 32, 119, 105, 116, 104, 32, 116, 104, 101, 32, 99, 111, 114, 114, 101, 115, 112, 111, 110, 100, 105, 110, 103, 32, 39, 114, 101, 113, 117, 105, 114, 101, 100, 39, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 117, 115, 101, 32, 111, 102, 32, 116, 104, 101, 32, 37, 115, 32, 37, 115, 0, 0, 0, 0, 0, 0, 0, 98, 97, 115, 101, 0, 0, 0, 0, 114, 101, 100, 101, 102, 105, 110, 101, 100, 0, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 39, 115, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 118, 97, 108, 105, 100, 108, 121, 32, 100, 101, 114, 105, 118, 101, 100, 32, 102, 114, 111, 109, 32, 116, 104, 101, 32, 99, 111, 114, 114, 101, 115, 112, 111, 110, 100, 105, 110, 103, 32, 37, 115, 32, 111, 102, 32, 116, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 105, 110, 32, 116, 104, 101, 32, 37, 115, 32, 37, 115, 0, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 101, 102, 102, 101, 99, 116, 105, 118, 101, 32, 118, 97, 108, 117, 101, 32, 99, 111, 110, 115, 116, 114, 97, 105, 110, 116, 32, 111, 102, 32, 116, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 117, 115, 101, 32, 105, 115, 32, 105, 110, 99, 111, 110, 115, 105, 115, 116, 101, 110, 116, 32, 119, 105, 116, 104, 32, 105, 116, 115, 32, 99, 111, 114, 114, 101, 115, 112, 111, 110, 100, 101, 110, 116, 32, 105, 110, 32, 116, 104, 101, 32, 37, 115, 32, 37, 115, 0, 78, 101, 105, 116, 104, 101, 114, 32, 97, 32, 109, 97, 116, 99, 104, 105, 110, 103, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 117, 115, 101, 44, 32, 110, 111, 114, 32, 97, 32, 109, 97, 116, 99, 104, 105, 110, 103, 32, 119, 105, 108, 100, 99, 97, 114, 100, 32, 101, 120, 105, 115, 116, 115, 32, 105, 110, 32, 116, 104, 101, 32, 37, 115, 32, 37, 115, 0, 0, 0, 65, 32, 109, 97, 116, 99, 104, 105, 110, 103, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 117, 115, 101, 32, 102, 111, 114, 32, 116, 104, 101, 32, 39, 114, 101, 113, 117, 105, 114, 101, 100, 39, 32, 37, 115, 32, 111, 102, 32, 116, 104, 101, 32, 37, 115, 32, 37, 115, 32, 105, 115, 32, 109, 105, 115, 115, 105, 110, 103, 0, 0, 84, 104, 101, 32, 37, 115, 32, 104, 97, 115, 32, 97, 110, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 119, 105, 108, 100, 99, 97, 114, 100, 44, 32, 98, 117, 116, 32, 116, 104, 101, 32, 37, 115, 32, 37, 115, 32, 39, 37, 115, 39, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 104, 97, 118, 101, 32, 111, 110, 101, 0, 0, 84, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 119, 105, 108, 100, 99, 97, 114, 100, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 118, 97, 108, 105, 100, 32, 115, 117, 98, 115, 101, 116, 32, 111, 102, 32, 116, 104, 101, 32, 119, 105, 108, 100, 99, 97, 114, 100, 32, 105, 110, 32, 116, 104, 101, 32, 37, 115, 32, 37, 115, 32, 39, 37, 115, 39, 0, 0, 84, 104, 101, 32, 123, 112, 114, 111, 99, 101, 115, 115, 32, 99, 111, 110, 116, 101, 110, 116, 115, 125, 32, 111, 102, 32, 116, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 119, 105, 108, 100, 99, 97, 114, 100, 32, 105, 115, 32, 119, 101, 97, 107, 101, 114, 32, 116, 104, 97, 110, 32, 116, 104, 101, 32, 111, 110, 101, 32, 105, 110, 32, 116, 104, 101, 32, 37, 115, 32, 37, 115, 32, 39, 37, 115, 39, 0, 0, 0, 0, 0, 0, 0, 58, 32, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 39, 102, 105, 110, 97, 108, 39, 32, 111, 102, 32, 116, 104, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 99, 111, 110, 116, 97, 105, 110, 115, 32, 39, 101, 120, 116, 101, 110, 115, 105, 111, 110, 39, 0, 0, 0, 0, 84, 104, 101, 32, 99, 111, 110, 116, 101, 110, 116, 32, 116, 121, 112, 101, 32, 109, 117, 115, 116, 32, 115, 112, 101, 99, 105, 102, 121, 32, 97, 32, 112, 97, 114, 116, 105, 99, 108, 101, 0, 0, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 99, 111, 110, 116, 101, 110, 116, 32, 116, 121, 112, 101, 32, 111, 102, 32, 98, 111, 116, 104, 44, 32, 116, 104, 101, 32, 116, 121, 112, 101, 32, 97, 110, 100, 32, 105, 116, 115, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 44, 32, 109, 117, 115, 116, 32, 101, 105, 116, 104, 101, 114, 32, 39, 109, 105, 120, 101, 100, 39, 32, 111, 114, 32, 39, 101, 108, 101, 109, 101, 110, 116, 45, 111, 110, 108, 121, 39, 0, 0, 0, 0, 0, 84, 104, 101, 32, 99, 111, 110, 116, 101, 110, 116, 32, 116, 121, 112, 101, 32, 109, 117, 115, 116, 32, 98, 101, 32, 116, 104, 101, 32, 115, 105, 109, 112, 108, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 0, 0, 0, 73, 102, 32, 116, 104, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 32, 105, 115, 32, 97, 32, 115, 105, 109, 112, 108, 101, 32, 116, 121, 112, 101, 44, 32, 116, 104, 101, 32, 100, 101, 114, 105, 118, 97, 116, 105, 111, 110, 32, 109, 101, 116, 104, 111, 100, 32, 109, 117, 115, 116, 32, 98, 101, 32, 39, 101, 120, 116, 101, 110, 115, 105, 111, 110, 39, 0, 0, 0, 0, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 37, 115, 0, 0, 0, 0, 84, 104, 101, 114, 101, 32, 109, 117, 115, 116, 32, 110, 111, 116, 32, 101, 120, 105, 115, 116, 32, 109, 111, 114, 101, 32, 116, 104, 97, 110, 32, 111, 110, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 111, 102, 32, 116, 121, 112, 101, 32, 39, 120, 115, 58, 73, 68, 39, 32, 40, 111, 114, 32, 100, 101, 114, 105, 118, 101, 100, 32, 102, 114, 111, 109, 32, 39, 120, 115, 58, 73, 68, 39, 41, 46, 32, 84, 104, 101, 32, 37, 115, 32, 118, 105, 111, 108, 97, 116, 101, 115, 32, 116, 104, 105, 115, 32, 99, 111, 110, 115, 116, 114, 97, 105, 110, 116, 0, 0, 0, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 58, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 73, 116, 101, 109, 76, 105, 115, 116, 82, 101, 109, 111, 118, 101, 44, 32, 105, 110, 100, 101, 120, 32, 101, 114, 114, 111, 114, 46, 10, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 70, 105, 120, 117, 112, 84, 121, 112, 101, 65, 116, 116, 114, 105, 98, 117, 116, 101, 85, 115, 101, 115, 0, 110, 111, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 0, 0, 0, 0, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 101, 120, 112, 97, 110, 100, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 115, 0, 0, 0, 0, 0, 84, 104, 101, 32, 117, 110, 105, 111, 110, 32, 111, 102, 32, 116, 104, 101, 32, 119, 105, 108, 99, 97, 114, 100, 32, 105, 115, 32, 110, 111, 116, 32, 101, 120, 112, 114, 101, 115, 115, 105, 98, 108, 101, 46, 10, 0, 0, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 119, 105, 108, 100, 99, 97, 114, 100, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 99, 111, 110, 115, 116, 114, 97, 105, 110, 116, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 69, 120, 112, 97, 110, 100, 65, 116, 116, 114, 105, 98, 117, 116, 101, 71, 114, 111, 117, 112, 82, 101, 102, 115, 0, 0, 0, 0, 0, 0, 0, 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 97, 116, 116, 114, 32, 112, 114, 111, 104, 105, 98, 105, 116, 105, 111, 110, 32, 102, 111, 117, 110, 100, 0, 0, 0, 0, 0, 0, 0, 83, 107, 105, 112, 112, 105, 110, 103, 32, 112, 111, 105, 110, 116, 108, 101, 115, 115, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 117, 115, 101, 32, 112, 114, 111, 104, 105, 98, 105, 116, 105, 111, 110, 32, 39, 37, 115, 39, 44, 32, 115, 105, 110, 99, 101, 32, 97, 32, 99, 111, 114, 114, 101, 115, 112, 111, 110, 100, 105, 110, 103, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 117, 115, 101, 32, 101, 120, 105, 115, 116, 115, 32, 97, 108, 114, 101, 97, 100, 121, 32, 105, 110, 32, 116, 104, 101, 32, 116, 121, 112, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 0, 0, 0, 0, 84, 104, 101, 32, 105, 110, 116, 101, 114, 115, 101, 99, 116, 105, 111, 110, 32, 111, 102, 32, 116, 104, 101, 32, 119, 105, 108, 99, 97, 114, 100, 32, 105, 115, 32, 110, 111, 116, 32, 101, 120, 112, 114, 101, 115, 115, 105, 98, 108, 101, 46, 10, 0, 0, 0, 0, 97, 100, 100, 105, 110, 103, 32, 119, 105, 108, 100, 99, 97, 114, 100, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 109, 111, 100, 101, 108, 32, 103, 114, 111, 117, 112, 32, 99, 111, 109, 112, 111, 110, 101, 110, 116, 0, 0, 0, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 112, 97, 114, 116, 105, 99, 108, 101, 32, 99, 111, 109, 112, 111, 110, 101, 110, 116, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 70, 105, 120, 117, 112, 83, 105, 109, 112, 108, 101, 84, 121, 112, 101, 83, 116, 97, 103, 101, 79, 110, 101, 0, 0, 0, 0, 0, 0, 0, 0, 108, 105, 115, 116, 32, 116, 121, 112, 101, 32, 104, 97, 115, 32, 110, 111, 32, 105, 116, 101, 109, 45, 116, 121, 112, 101, 32, 97, 115, 115, 105, 103, 110, 101, 100, 0, 0, 0, 0, 0, 117, 110, 105, 111, 110, 32, 116, 121, 112, 101, 32, 104, 97, 115, 32, 110, 111, 32, 109, 101, 109, 98, 101, 114, 45, 116, 121, 112, 101, 115, 32, 97, 115, 115, 105, 103, 110, 101, 100, 0, 116, 121, 112, 101, 32, 104, 97, 115, 32, 110, 111, 32, 98, 97, 115, 101, 45, 116, 121, 112, 101, 32, 97, 115, 115, 105, 103, 110, 101, 100, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 116, 121, 112, 101, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 114, 101, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 105, 110, 102, 111, 0, 0, 0, 0, 73, 102, 32, 117, 115, 105, 110, 103, 32, 60, 99, 111, 109, 112, 108, 101, 120, 67, 111, 110, 116, 101, 110, 116, 62, 44, 32, 116, 104, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 32, 105, 115, 32, 101, 120, 112, 101, 99, 116, 101, 100, 32, 116, 111, 32, 98, 101, 32, 97, 32, 99, 111, 109, 112, 108, 101, 120, 32, 116, 121, 112, 101, 46, 32, 84, 104, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 97, 32, 115, 105, 109, 112, 108, 101, 32, 116, 121, 112, 101, 0, 0, 73, 102, 32, 117, 115, 105, 110, 103, 32, 60, 115, 105, 109, 112, 108, 101, 67, 111, 110, 116, 101, 110, 116, 62, 32, 97, 110, 100, 32, 60, 114, 101, 115, 116, 114, 105, 99, 116, 105, 111, 110, 62, 44, 32, 116, 104, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 32, 109, 117, 115, 116, 32, 98, 101, 32, 97, 32, 99, 111, 109, 112, 108, 101, 120, 32, 116, 121, 112, 101, 46, 32, 84, 104, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 97, 32, 115, 105, 109, 112, 108, 101, 32, 116, 121, 112, 101, 0, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 58, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 67, 104, 101, 99, 107, 83, 82, 67, 67, 84, 44, 32, 39, 37, 115, 39, 44, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 32, 104, 97, 115, 32, 110, 111, 32, 99, 111, 110, 116, 101, 110, 116, 32, 116, 121, 112, 101, 0, 0, 0, 0, 0, 0, 0, 0, 65, 32, 60, 115, 105, 109, 112, 108, 101, 84, 121, 112, 101, 62, 32, 105, 115, 32, 101, 120, 112, 101, 99, 116, 101, 100, 32, 97, 109, 111, 110, 103, 32, 116, 104, 101, 32, 99, 104, 105, 108, 100, 114, 101, 110, 32, 111, 102, 32, 60, 114, 101, 115, 116, 114, 105, 99, 116, 105, 111, 110, 62, 44, 32, 105, 102, 32, 60, 115, 105, 109, 112, 108, 101, 67, 111, 110, 116, 101, 110, 116, 62, 32, 105, 115, 32, 117, 115, 101, 100, 32, 97, 110, 100, 32, 116, 104, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 97, 32, 99, 111, 109, 112, 108, 101, 120, 32, 116, 121, 112, 101, 0, 0, 0, 0, 0, 73, 102, 32, 60, 115, 105, 109, 112, 108, 101, 67, 111, 110, 116, 101, 110, 116, 62, 32, 97, 110, 100, 32, 60, 114, 101, 115, 116, 114, 105, 99, 116, 105, 111, 110, 62, 32, 105, 115, 32, 117, 115, 101, 100, 44, 32, 116, 104, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 32, 109, 117, 115, 116, 32, 98, 101, 32, 97, 32, 115, 105, 109, 112, 108, 101, 32, 116, 121, 112, 101, 32, 111, 114, 32, 97, 32, 99, 111, 109, 112, 108, 101, 120, 32, 116, 121, 112, 101, 32, 119, 105, 116, 104, 32, 109, 105, 120, 101, 100, 32, 99, 111, 110, 116, 101, 110, 116, 32, 97, 110, 100, 32, 112, 97, 114, 116, 105, 99, 108, 101, 32, 101, 109, 112, 116, 105, 97, 98, 108, 101, 46, 32, 84, 104, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 110, 101, 32, 111, 102, 32, 116, 104, 111, 115, 101, 0, 0, 0, 0, 0, 0, 73, 102, 32, 60, 115, 105, 109, 112, 108, 101, 67, 111, 110, 116, 101, 110, 116, 62, 32, 97, 110, 100, 32, 60, 101, 120, 116, 101, 110, 115, 105, 111, 110, 62, 32, 105, 115, 32, 117, 115, 101, 100, 44, 32, 116, 104, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 32, 109, 117, 115, 116, 32, 98, 101, 32, 97, 32, 115, 105, 109, 112, 108, 101, 32, 116, 121, 112, 101, 46, 32, 84, 104, 101, 32, 98, 97, 115, 101, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 97, 32, 99, 111, 109, 112, 108, 101, 120, 32, 116, 121, 112, 101, 0, 0, 0, 184, 44, 2, 0, 0, 0, 0, 0, 84, 104, 101, 32, 81, 78, 97, 109, 101, 32, 118, 97, 108, 117, 101, 32, 39, 37, 115, 39, 32, 104, 97, 115, 32, 110, 111, 32, 99, 111, 114, 114, 101, 115, 112, 111, 110, 100, 105, 110, 103, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 105, 110, 32, 115, 99, 111, 112, 101, 0, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 76, 111, 111, 107, 117, 112, 78, 97, 109, 101, 115, 112, 97, 99, 101, 0, 0, 0, 0, 0, 0, 0, 0, 110, 111, 32, 110, 111, 100, 101, 32, 111, 114, 32, 110, 111, 100, 101, 39, 115, 32, 100, 111, 99, 32, 97, 118, 97, 108, 105, 97, 98, 108, 101, 0, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 118, 97, 108, 105, 100, 32, 118, 97, 108, 117, 101, 32, 111, 102, 32, 0, 0, 0, 84, 104, 101, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 99, 111, 110, 116, 101, 110, 116, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 118, 97, 108, 105, 100, 32, 118, 97, 108, 117, 101, 32, 111, 102, 32, 0, 0, 116, 104, 101, 32, 108, 111, 99, 97, 108, 32, 0, 0, 0, 0, 0, 0, 116, 104, 101, 32, 0, 0, 0, 0, 120, 115, 58, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 86, 97, 108, 105, 100, 97, 116, 101, 69, 108, 101, 109, 87, 105, 108, 100, 99, 97, 114, 100, 0, 0, 0, 98, 97, 100, 32, 97, 114, 103, 117, 109, 101, 110, 116, 115, 0, 0, 0, 78, 111, 32, 109, 97, 116, 99, 104, 105, 110, 103, 32, 103, 108, 111, 98, 97, 108, 32, 101, 108, 101, 109, 101, 110, 116, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 44, 32, 98, 117, 116, 32, 100, 101, 109, 97, 110, 100, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32, 115, 116, 114, 105, 99, 116, 32, 119, 105, 108, 100, 99, 97, 114, 100, 0, 0, 0, 99, 97, 108, 108, 105, 110, 103, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 80, 114, 111, 99, 101, 115, 115, 88, 83, 73, 84, 121, 112, 101, 40, 41, 32, 116, 111, 32, 112, 114, 111, 99, 101, 115, 115, 32, 116, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 39, 120, 115, 105, 58, 110, 105, 108, 39, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 86, 97, 108, 105, 100, 97, 116, 101, 67, 104, 105, 108, 100, 69, 108, 101, 109, 0, 0, 0, 0, 0, 0, 110, 111, 116, 32, 105, 110, 116, 101, 110, 100, 101, 100, 32, 102, 111, 114, 32, 116, 104, 101, 32, 118, 97, 108, 105, 100, 97, 116, 105, 111, 110, 32, 114, 111, 111, 116, 0, 0, 0, 0, 78, 101, 105, 116, 104, 101, 114, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 110, 111, 114, 32, 101, 108, 101, 109, 101, 110, 116, 32, 99, 111, 110, 116, 101, 110, 116, 32, 105, 115, 32, 97, 108, 108, 111, 119, 101, 100, 44, 32, 98, 101, 99, 97, 117, 115, 101, 32, 116, 104, 101, 32, 101, 108, 101, 109, 101, 110, 116, 32, 119, 97, 115, 32, 39, 110, 105, 108, 108, 101, 100, 39, 0, 0, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 99, 111, 110, 116, 101, 110, 116, 32, 105, 115, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 101, 100, 44, 32, 98, 101, 99, 97, 117, 115, 101, 32, 116, 104, 101, 32, 99, 111, 110, 116, 101, 110, 116, 32, 116, 121, 112, 101, 32, 105, 115, 32, 101, 109, 112, 116, 121, 0, 0, 0, 0, 0, 0, 0, 116, 121, 112, 101, 32, 104, 97, 115, 32, 101, 108, 101, 109, 32, 99, 111, 110, 116, 101, 110, 116, 32, 98, 117, 116, 32, 110, 111, 32, 99, 111, 110, 116, 101, 110, 116, 32, 109, 111, 100, 101, 108, 0, 0, 0, 0, 0, 0, 118, 97, 108, 105, 100, 97, 116, 105, 110, 103, 32, 101, 108, 101, 109, 44, 32, 98, 117, 116, 32, 101, 108, 101, 109, 32, 99, 111, 110, 116, 101, 110, 116, 32, 105, 115, 32, 97, 108, 114, 101, 97, 100, 121, 32, 105, 110, 118, 97, 108, 105, 100, 0, 0, 0, 0, 99, 97, 108, 108, 105, 110, 103, 32, 120, 109, 108, 82, 101, 103, 69, 120, 101, 99, 80, 117, 115, 104, 83, 116, 114, 105, 110, 103, 50, 40, 41, 0, 84, 104, 105, 115, 32, 101, 108, 101, 109, 101, 110, 116, 32, 105, 115, 32, 110, 111, 116, 32, 101, 120, 112, 101, 99, 116, 101, 100, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 99, 111, 110, 116, 101, 110, 116, 32, 105, 115, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 101, 100, 44, 32, 98, 101, 99, 97, 117, 115, 101, 32, 116, 104, 101, 32, 99, 111, 110, 116, 101, 110, 116, 32, 116, 121, 112, 101, 32, 105, 115, 32, 97, 32, 115, 105, 109, 112, 108, 101, 32, 116, 121, 112, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 99, 111, 110, 116, 101, 110, 116, 32, 105, 115, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 101, 100, 44, 32, 98, 101, 99, 97, 117, 115, 101, 32, 116, 104, 101, 32, 116, 121, 112, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 105, 115, 32, 115, 105, 109, 112, 108, 101, 0, 0, 0, 84, 104, 101, 32, 118, 97, 108, 117, 101, 32, 109, 117, 115, 116, 32, 99, 111, 110, 115, 105, 115, 116, 32, 111, 102, 32, 116, 117, 112, 108, 101, 115, 58, 32, 116, 104, 101, 32, 116, 97, 114, 103, 101, 116, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 110, 97, 109, 101, 32, 97, 110, 100, 32, 116, 104, 101, 32, 100, 111, 99, 117, 109, 101, 110, 116, 39, 115, 32, 85, 82, 73, 0, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 65, 115, 115, 101, 109, 98, 108, 101, 66, 121, 88, 83, 73, 0, 0, 97, 115, 115, 101, 109, 98, 108, 105, 110, 103, 32, 115, 99, 104, 101, 109, 97, 116, 97, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 65, 115, 115, 101, 109, 98, 108, 101, 66, 121, 76, 111, 99, 97, 116, 105, 111, 110, 0, 0, 0, 0, 0, 110, 111, 32, 112, 97, 114, 115, 101, 114, 32, 99, 111, 110, 116, 101, 120, 116, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 0, 0, 0, 0, 0, 110, 111, 32, 99, 111, 110, 115, 116, 114, 117, 99, 116, 111, 114, 0, 0, 84, 104, 101, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 97, 116, 32, 108, 111, 99, 97, 116, 105, 111, 110, 32, 39, 37, 115, 39, 32, 99, 111, 117, 108, 100, 32, 110, 111, 116, 32, 98, 101, 32, 97, 99, 113, 117, 105, 114, 101, 100, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 80, 117, 115, 104, 65, 116, 116, 114, 105, 98, 117, 116, 101, 0, 0, 110, 105, 108, 0, 0, 0, 0, 0, 152, 95, 2, 0, 0, 0, 0, 0, 116, 121, 112, 101, 0, 0, 0, 0, 115, 99, 104, 101, 109, 97, 76, 111, 99, 97, 116, 105, 111, 110, 0, 0, 110, 111, 78, 97, 109, 101, 115, 112, 97, 99, 101, 83, 99, 104, 101, 109, 97, 76, 111, 99, 97, 116, 105, 111, 110, 0, 0, 0, 0, 0, 0, 0, 120, 95, 2, 0, 0, 0, 0, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 50, 48, 48, 48, 47, 120, 109, 108, 110, 115, 47, 0, 0, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 50, 48, 48, 49, 47, 88, 77, 76, 83, 99, 104, 101, 109, 97, 45, 105, 110, 115, 116, 97, 110, 99, 101, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 86, 97, 108, 105, 100, 97, 116, 111, 114, 80, 117, 115, 104, 69, 108, 101, 109, 0, 0, 0, 0, 0, 0, 99, 97, 108, 108, 105, 110, 103, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 71, 101, 116, 70, 114, 101, 115, 104, 69, 108, 101, 109, 73, 110, 102, 111, 40, 41, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 71, 101, 116, 70, 114, 101, 115, 104, 69, 108, 101, 109, 73, 110, 102, 111, 0, 0, 0, 0, 0, 0, 0, 105, 110, 99, 111, 110, 115, 105, 115, 116, 101, 110, 116, 32, 100, 101, 112, 116, 104, 32, 101, 110, 99, 111, 117, 110, 116, 101, 114, 101, 100, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 116, 104, 101, 32, 101, 108, 101, 109, 101, 110, 116, 32, 105, 110, 102, 111, 32, 97, 114, 114, 97, 121, 0, 0, 0, 0, 0, 0, 0, 114, 101, 45, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 116, 104, 101, 32, 101, 108, 101, 109, 101, 110, 116, 32, 105, 110, 102, 111, 32, 97, 114, 114, 97, 121, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 97, 110, 32, 101, 108, 101, 109, 101, 110, 116, 32, 105, 110, 102, 111, 0, 0, 0, 0, 0, 0, 101, 108, 101, 109, 32, 105, 110, 102, 111, 32, 104, 97, 115, 32, 110, 111, 116, 32, 98, 101, 101, 110, 32, 99, 108, 101, 97, 114, 101, 100, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 86, 83, 116, 97, 114, 116, 0, 110, 111, 32, 105, 110, 115, 116, 97, 110, 99, 101, 32, 116, 111, 32, 118, 97, 108, 105, 100, 97, 116, 101, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 68, 111, 99, 87, 97, 108, 107, 0, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 86, 68, 111, 99, 87, 97, 108, 107, 0, 0, 0, 0, 0, 0, 0, 116, 104, 101, 114, 101, 32, 105, 115, 32, 97, 116, 32, 108, 101, 97, 115, 116, 32, 111, 110, 101, 32, 101, 110, 116, 105, 116, 121, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 105, 110, 32, 116, 104, 101, 32, 110, 111, 100, 101, 45, 116, 114, 101, 101, 32, 99, 117, 114, 114, 101, 110, 116, 108, 121, 32, 98, 101, 105, 110, 103, 32, 118, 97, 108, 105, 100, 97, 116, 101, 100, 46, 32, 80, 114, 111, 99, 101, 115, 115, 105, 110, 103, 32, 111, 102, 32, 101, 110, 116, 105, 116, 105, 101, 115, 32, 119, 105, 116, 104, 32, 116, 104, 105, 115, 32, 88, 77, 76, 32, 83, 99, 104, 101, 109, 97, 32, 112, 114, 111, 99, 101, 115, 115, 111, 114, 32, 105, 115, 32, 110, 111, 116, 32, 115, 117, 112, 112, 111, 114, 116, 101, 100, 32, 40, 121, 101, 116, 41, 46, 32, 80, 108, 101, 97, 115, 101, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 101, 32, 101, 110, 116, 105, 116, 105, 101, 115, 32, 98, 101, 102, 111, 114, 101, 32, 118, 97, 108, 105, 100, 97, 116, 105, 111, 110, 46, 0, 0, 101, 108, 101, 109, 101, 110, 116, 32, 112, 111, 115, 105, 116, 105, 111, 110, 32, 109, 105, 115, 109, 97, 116, 99, 104, 0, 0, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 97, 110, 32, 105, 116, 101, 109, 32, 108, 105, 115, 116, 32, 115, 116, 114, 117, 99, 116, 117, 114, 101, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 86, 67, 104, 101, 99, 107, 67, 86, 67, 83, 105, 109, 112, 108, 101, 84, 121, 112, 101, 0, 0, 0, 0, 99, 111, 117, 108, 100, 32, 110, 111, 116, 32, 103, 101, 116, 32, 116, 104, 101, 32, 98, 117, 105, 108, 116, 45, 105, 110, 32, 116, 121, 112, 101, 0, 118, 97, 108, 105, 100, 97, 116, 105, 110, 103, 32, 97, 103, 97, 105, 110, 115, 116, 32, 97, 32, 98, 117, 105, 108, 116, 45, 105, 110, 32, 116, 121, 112, 101, 0, 0, 0, 0, 0, 0, 118, 97, 108, 105, 100, 97, 116, 105, 110, 103, 32, 102, 97, 99, 101, 116, 115, 32, 111, 102, 32, 97, 116, 111, 109, 105, 99, 32, 115, 105, 109, 112, 108, 101, 32, 116, 121, 112, 101, 0, 118, 97, 108, 105, 100, 97, 116, 105, 110, 103, 32, 97, 110, 32, 105, 116, 101, 109, 32, 111, 102, 32, 108, 105, 115, 116, 32, 115, 105, 109, 112, 108, 101, 32, 116, 121, 112, 101, 0, 0, 118, 97, 108, 105, 100, 97, 116, 105, 110, 103, 32, 102, 97, 99, 101, 116, 115, 32, 111, 102, 32, 108, 105, 115, 116, 32, 115, 105, 109, 112, 108, 101, 32, 116, 121, 112, 101, 0, 0, 0, 117, 110, 105, 111, 110, 32, 115, 105, 109, 112, 108, 101, 32, 116, 121, 112, 101, 32, 104, 97, 115, 32, 110, 111, 32, 109, 101, 109, 98, 101, 114, 32, 116, 121, 112, 101, 115, 0, 0, 0, 118, 97, 108, 105, 100, 97, 116, 105, 110, 103, 32, 109, 101, 109, 98, 101, 114, 115, 32, 111, 102, 32, 117, 110, 105, 111, 110, 32, 115, 105, 109, 112], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 146288);
	        allocate([108, 101, 32, 116, 121, 112, 101, 0, 118, 97, 108, 105, 100, 97, 116, 105, 110, 103, 32, 102, 97, 99, 101, 116, 115, 32, 111, 102, 32, 117, 110, 105, 111, 110, 32, 115, 105, 109, 112, 108, 101, 32, 116, 121, 112, 101, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 86, 97, 108, 105, 100, 97, 116, 101, 70, 97, 99, 101, 116, 115, 0, 118, 97, 108, 105, 100, 97, 116, 105, 110, 103, 32, 97, 103, 97, 105, 110, 115, 116, 32, 97, 32, 97, 116, 111, 109, 105, 99, 32, 116, 121, 112, 101, 32, 102, 97, 99, 101, 116, 0, 0, 118, 97, 108, 105, 100, 97, 116, 105, 110, 103, 32, 97, 103, 97, 105, 110, 115, 116, 32, 97, 32, 108, 105, 115, 116, 32, 116, 121, 112, 101, 32, 102, 97, 99, 101, 116, 0, 0, 0, 0, 118, 97, 108, 105, 100, 97, 116, 105, 110, 103, 32, 97, 103, 97, 105, 110, 115, 116, 32, 97, 110, 32, 101, 110, 117, 109, 101, 114, 97, 116, 105, 111, 110, 32, 102, 97, 99, 101, 116, 0, 118, 97, 108, 105, 100, 97, 116, 105, 110, 103, 32, 97, 103, 97, 105, 110, 115, 116, 32, 97, 32, 112, 97, 116, 116, 101, 114, 110, 32, 102, 97, 99, 101, 116, 0, 0, 0, 0, 0, 0, 39, 93, 32, 0, 0, 0, 0, 0, 84, 104, 101, 32, 118, 97, 108, 117, 101, 32, 39, 37, 115, 39, 32, 104, 97, 115, 32, 97, 32, 108, 101, 110, 103, 116, 104, 32, 111, 102, 32, 39, 37, 115, 39, 59, 32, 0, 0, 0, 84, 104, 101, 32, 118, 97, 108, 117, 101, 32, 104, 97, 115, 32, 97, 32, 108, 101, 110, 103, 116, 104, 32, 111, 102, 32, 39, 37, 115, 39, 59, 32, 0, 0, 0, 0, 0, 0, 0, 0, 37, 108, 117, 0, 0, 0, 0, 0, 116, 104, 105, 115, 32, 100, 105, 102, 102, 101, 114, 115, 32, 102, 114, 111, 109, 32, 116, 104, 101, 32, 97, 108, 108, 111, 119, 101, 100, 32, 108, 101, 110, 103, 116, 104, 32, 111, 102, 32, 39, 37, 115, 39, 46, 10, 0, 0, 116, 104, 105, 115, 32, 101, 120, 99, 101, 101, 100, 115, 32, 116, 104, 101, 32, 97, 108, 108, 111, 119, 101, 100, 32, 109, 97, 120, 105, 109, 117, 109, 32, 108, 101, 110, 103, 116, 104, 32, 111, 102, 32, 39, 37, 115, 39, 46, 10, 0, 0, 0, 0, 0, 0, 0, 116, 104, 105, 115, 32, 117, 110, 100, 101, 114, 114, 117, 110, 115, 32, 116, 104, 101, 32, 97, 108, 108, 111, 119, 101, 100, 32, 109, 105, 110, 105, 109, 117, 109, 32, 108, 101, 110, 103, 116, 104, 32, 111, 102, 32, 39, 37, 115, 39, 46, 10, 0, 0, 0, 0, 0, 84, 104, 101, 32, 118, 97, 108, 117, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 97, 110, 32, 101, 108, 101, 109, 101, 110, 116, 32, 111, 102, 32, 116, 104, 101, 32, 115, 101, 116, 32, 123, 37, 115, 125, 46, 10, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 118, 97, 108, 117, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 97, 99, 99, 101, 112, 116, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32, 112, 97, 116, 116, 101, 114, 110, 32, 39, 37, 115, 39, 46, 10, 0, 0, 0, 0, 84, 104, 101, 32, 118, 97, 108, 117, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 108, 101, 115, 115, 32, 116, 104, 97, 110, 32, 116, 104, 101, 32, 109, 105, 110, 105, 109, 117, 109, 32, 118, 97, 108, 117, 101, 32, 97, 108, 108, 111, 119, 101, 100, 32, 40, 39, 37, 115, 39, 41, 46, 10, 0, 0, 84, 104, 101, 32, 118, 97, 108, 117, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 103, 114, 101, 97, 116, 101, 114, 32, 116, 104, 97, 110, 32, 116, 104, 101, 32, 109, 97, 120, 105, 109, 117, 109, 32, 118, 97, 108, 117, 101, 32, 97, 108, 108, 111, 119, 101, 100, 32, 40, 39, 37, 115, 39, 41, 46, 10, 0, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 118, 97, 108, 117, 101, 32, 39, 37, 115, 39, 32, 109, 117, 115, 116, 32, 98, 101, 32, 103, 114, 101, 97, 116, 101, 114, 32, 116, 104, 97, 110, 32, 39, 37, 115, 39, 46, 10, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 118, 97, 108, 117, 101, 32, 39, 37, 115, 39, 32, 109, 117, 115, 116, 32, 98, 101, 32, 108, 101, 115, 115, 32, 116, 104, 97, 110, 32, 39, 37, 115, 39, 46, 10, 0, 84, 104, 101, 32, 118, 97, 108, 117, 101, 32, 39, 37, 115, 39, 32, 104, 97, 115, 32, 109, 111, 114, 101, 32, 100, 105, 103, 105, 116, 115, 32, 116, 104, 97, 110, 32, 97, 114, 101, 32, 97, 108, 108, 111, 119, 101, 100, 32, 40, 39, 37, 115, 39, 41, 46, 10, 0, 0, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 118, 97, 108, 117, 101, 32, 39, 37, 115, 39, 32, 104, 97, 115, 32, 109, 111, 114, 101, 32, 102, 114, 97, 99, 116, 105, 111, 110, 97, 108, 32, 100, 105, 103, 105, 116, 115, 32, 116, 104, 97, 110, 32, 97, 114, 101, 32, 97, 108, 108, 111, 119, 101, 100, 32, 40, 39, 37, 115, 39, 41, 46, 10, 0, 0, 0, 0, 0, 84, 104, 101, 32, 118, 97, 108, 117, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 102, 97, 99, 101, 116, 45, 118, 97, 108, 105, 100, 46, 10, 0, 0, 0, 0, 0, 84, 104, 101, 32, 118, 97, 108, 117, 101, 32, 105, 115, 32, 110, 111, 116, 32, 102, 97, 99, 101, 116, 45, 118, 97, 108, 105, 100, 46, 10, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 70, 111, 114, 109, 97, 116, 70, 97, 99, 101, 116, 69, 110, 117, 109, 83, 101, 116, 0, 0, 0, 0, 0, 99, 111, 109, 112, 117, 116, 101, 32, 116, 104, 101, 32, 99, 97, 110, 111, 110, 105, 99, 97, 108, 32, 108, 101, 120, 105, 99, 97, 108, 32, 114, 101, 112, 114, 101, 115, 101, 110, 116, 97, 116, 105, 111, 110, 0, 0, 0, 0, 44, 32, 39, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 86, 97, 108, 105, 100, 97, 116, 101, 81, 78, 97, 109, 101, 0, 0, 99, 97, 108, 108, 105, 110, 103, 32, 120, 109, 108, 86, 97, 108, 105, 100, 97, 116, 101, 81, 78, 97, 109, 101, 40, 41, 0, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 86, 97, 108, 105, 100, 97, 116, 101, 78, 111, 116, 97, 116, 105, 111, 110, 0, 0, 0, 0, 0, 0, 0, 97, 32, 115, 99, 104, 101, 109, 97, 32, 105, 115, 32, 110, 101, 101, 100, 101, 100, 32, 111, 110, 32, 116, 104, 101, 32, 118, 97, 108, 105, 100, 97, 116, 105, 111, 110, 32, 99, 111, 110, 116, 101, 120, 116, 0, 0, 0, 0, 112, 97, 116, 116, 101, 114, 110, 0, 109, 97, 120, 69, 120, 99, 108, 117, 115, 105, 118, 101, 0, 0, 0, 0, 109, 97, 120, 73, 110, 99, 108, 117, 115, 105, 118, 101, 0, 0, 0, 0, 109, 105, 110, 69, 120, 99, 108, 117, 115, 105, 118, 101, 0, 0, 0, 0, 109, 105, 110, 73, 110, 99, 108, 117, 115, 105, 118, 101, 0, 0, 0, 0, 119, 104, 105, 116, 101, 83, 112, 97, 99, 101, 0, 0, 0, 0, 0, 0, 101, 110, 117, 109, 101, 114, 97, 116, 105, 111, 110, 0, 0, 0, 0, 0, 108, 101, 110, 103, 116, 104, 0, 0, 109, 97, 120, 76, 101, 110, 103, 116, 104, 0, 0, 0, 0, 0, 0, 0, 109, 105, 110, 76, 101, 110, 103, 116, 104, 0, 0, 0, 0, 0, 0, 0, 116, 111, 116, 97, 108, 68, 105, 103, 105, 116, 115, 0, 0, 0, 0, 0, 102, 114, 97, 99, 116, 105, 111, 110, 68, 105, 103, 105, 116, 115, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 69, 114, 114, 111, 114, 0, 0, 67, 97, 110, 110, 111, 116, 32, 99, 114, 101, 97, 116, 101, 32, 97, 117, 116, 111, 109, 97, 116, 97, 32, 102, 111, 114, 32, 99, 111, 109, 112, 108, 101, 120, 32, 116, 121, 112, 101, 32, 37, 115, 10, 0, 0, 0, 0, 0, 70, 97, 105, 108, 101, 100, 32, 116, 111, 32, 99, 111, 109, 112, 105, 108, 101, 32, 116, 104, 101, 32, 99, 111, 110, 116, 101, 110, 116, 32, 109, 111, 100, 101, 108, 0, 0, 0, 0, 0, 84, 104, 101, 32, 99, 111, 110, 116, 101, 110, 116, 32, 109, 111, 100, 101, 108, 32, 105, 115, 32, 110, 111, 116, 32, 100, 101, 116, 101, 114, 109, 105, 110, 105, 115, 116, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 66, 117, 105, 108, 100, 65, 67, 111, 110, 116, 101, 110, 116, 77, 111, 100, 101, 108, 0, 0, 0, 0, 0, 112, 97, 114, 116, 105, 99, 108, 101, 32, 105, 115, 32, 78, 85, 76, 76, 0, 0, 0, 0, 0, 0, 0, 0, 60, 101, 108, 101, 109, 101, 110, 116, 62, 32, 112, 97, 114, 116, 105, 99, 108, 101, 32, 104, 97, 115, 32, 110, 111, 32, 116, 101, 114, 109, 0, 0, 102, 111, 117, 110, 100, 32, 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 116, 101, 114, 109, 32, 111, 102, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 32, 105, 110, 32, 99, 111, 110, 116, 101, 110, 116, 32, 109, 111, 100, 101, 108, 0, 0, 0, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 58, 32, 0, 0, 0, 0, 0, 0, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 58, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 66, 117, 105, 108, 100, 67, 111, 110, 116, 101, 110, 116, 77, 111, 100, 101, 108, 70, 111, 114, 83, 117, 98, 115, 116, 71, 114, 111, 117, 112, 44, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 105, 115, 32, 109, 97, 114, 107, 101, 100, 32, 104, 97, 118, 105, 110, 103, 32, 97, 32, 115, 117, 98, 115, 116, 46, 32, 103, 114, 111, 117, 112, 32, 98, 117, 116, 32, 110, 111, 110, 101, 32, 97, 118, 97, 105, 108, 97, 98, 108, 101, 46, 10, 0, 0, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 97, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 105, 111, 110, 32, 103, 114, 111, 117, 112, 32, 99, 111, 110, 116, 97, 105, 110, 101, 114, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 83, 117, 98, 115, 116, 71, 114, 111, 117, 112, 65, 100, 100, 0, 0, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 97, 100, 100, 32, 97, 32, 110, 101, 119, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 105, 111, 110, 32, 99, 111, 110, 116, 97, 105, 110, 101, 114, 0, 0, 0, 0, 0, 0, 79, 110, 108, 121, 32, 103, 108, 111, 98, 97, 108, 32, 101, 108, 101, 109, 101, 110, 116, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 115, 32, 99, 97, 110, 32, 104, 97, 118, 101, 32, 97, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 105, 111, 110, 32, 103, 114, 111, 117, 112, 32, 97, 102, 102, 105, 108, 105, 97, 116, 105, 111, 110, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 101, 108, 101, 109, 101, 110, 116, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 39, 37, 115, 39, 32, 100, 101, 102, 105, 110, 101, 115, 32, 97, 32, 99, 105, 114, 99, 117, 108, 97, 114, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 105, 111, 110, 32, 103, 114, 111, 117, 112, 32, 116, 111, 32, 101, 108, 101, 109, 101, 110, 116, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 39, 37, 115, 39, 0, 0, 84, 104, 101, 32, 116, 121, 112, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 39, 37, 115, 39, 32, 119, 97, 115, 32, 101, 105, 116, 104, 101, 114, 32, 114, 101, 106, 101, 99, 116, 101, 100, 32, 98, 121, 32, 116, 104, 101, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 105, 111, 110, 32, 103, 114, 111, 117, 112, 32, 97, 102, 102, 105, 108, 105, 97, 116, 105, 111, 110, 32, 39, 37, 115, 39, 44, 32, 111, 114, 32, 110, 111, 116, 32, 118, 97, 108, 105, 100, 108, 121, 32, 100, 101, 114, 105, 118, 101, 100, 32, 102, 114, 111, 109, 32, 105, 116, 115, 32, 116, 121, 112, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 39, 37, 115, 39, 0, 0, 0, 84, 104, 101, 32, 116, 121, 112, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 40, 111, 114, 32, 116, 121, 112, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 39, 115, 32, 99, 111, 110, 116, 101, 110, 116, 32, 116, 121, 112, 101, 41, 32, 105, 115, 32, 111, 114, 32, 105, 115, 32, 100, 101, 114, 105, 118, 101, 100, 32, 102, 114, 111, 109, 32, 73, 68, 59, 32, 118, 97, 108, 117, 101, 32, 99, 111, 110, 115, 116, 114, 97, 105, 110, 116, 115, 32, 97, 114, 101, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 101, 100, 32, 105, 110, 32, 99, 111, 110, 106, 117, 110, 99, 116, 105, 111, 110, 32, 119, 105, 116, 104, 32, 115, 117, 99, 104, 32, 97, 32, 116, 121, 112, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 58, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 67, 104, 101, 99, 107, 69, 108, 101, 109, 80, 114, 111, 112, 115, 67, 111, 114, 114, 101, 99, 116, 44, 32, 116, 121, 112, 101, 32, 105, 115, 32, 109, 105, 115, 115, 105, 110, 103, 46, 46, 46, 32, 115, 107, 105, 112, 112, 105, 110, 103, 32, 118, 97, 108, 105, 100, 97, 116, 105, 111, 110, 32, 111, 102, 32, 116, 104, 101, 32, 118, 97, 108, 117, 101, 32, 99, 111, 110, 115, 116, 114, 97, 105, 110, 116, 0, 0, 102, 105, 120, 101, 100, 0, 0, 0, 100, 101, 102, 97, 117, 108, 116, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 69, 108, 101, 109, 67, 104, 101, 99, 107, 86, 97, 108, 67, 111, 110, 115, 116, 114, 0, 0, 0, 0, 0, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 118, 97, 108, 105, 100, 97, 116, 101, 32, 116, 104, 101, 32, 118, 97, 108, 117, 101, 32, 99, 111, 110, 115, 116, 114, 97, 105, 110, 116, 32, 111, 102, 32, 97, 110, 32, 101, 108, 101, 109, 101, 110, 116, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 0, 0, 0, 0, 0, 0, 0, 70, 111, 114, 32, 97, 32, 115, 116, 114, 105, 110, 103, 32, 116, 111, 32, 98, 101, 32, 97, 32, 118, 97, 108, 105, 100, 32, 100, 101, 102, 97, 117, 108, 116, 44, 32, 116, 104, 101, 32, 116, 121, 112, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 109, 117, 115, 116, 32, 98, 101, 32, 97, 32, 115, 105, 109, 112, 108, 101, 32, 116, 121, 112, 101, 32, 111, 114, 32, 97, 32, 99, 111, 109, 112, 108, 101, 120, 32, 116, 121, 112, 101, 32, 119, 105, 116, 104, 32, 109, 105, 120, 101, 100, 32, 99, 111, 110, 116, 101, 110, 116, 32, 97, 110, 100, 32, 97, 32, 112, 97, 114, 116, 105, 99, 108, 101, 32, 101, 109, 112, 116, 105, 97, 98, 108, 101, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 80, 97, 114, 115, 101, 67, 104, 101, 99, 107, 67, 79, 83, 86, 97, 108, 105, 100, 68, 101, 102, 97, 117, 108, 116, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 104, 97, 115, 32, 97, 32, 39, 102, 105, 120, 101, 100, 39, 32, 118, 97, 108, 117, 101, 32, 99, 111, 110, 115, 116, 114, 97, 105, 110, 116, 32, 44, 32, 116, 104, 117, 115, 32, 116, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 117, 115, 101, 32, 109, 117, 115, 116, 32, 97, 108, 115, 111, 32, 104, 97, 118, 101, 32, 97, 32, 39, 102, 105, 120, 101, 100, 39, 32, 118, 97, 108, 117, 101, 32, 99, 111, 110, 115, 116, 114, 97, 105, 110, 116, 0, 0, 0, 0, 0, 86, 97, 108, 117, 101, 32, 99, 111, 110, 115, 116, 114, 97, 105, 110, 116, 115, 32, 97, 114, 101, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 101, 100, 32, 105, 102, 32, 116, 104, 101, 32, 116, 121, 112, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 105, 115, 32, 111, 114, 32, 105, 115, 32, 100, 101, 114, 105, 118, 101, 100, 32, 102, 114, 111, 109, 32, 120, 115, 58, 73, 68, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 67, 104, 101, 99, 107, 65, 116, 116, 114, 85, 115, 101, 80, 114, 111, 112, 115, 67, 111, 114, 114, 101, 99, 116, 0, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 118, 97, 108, 117, 101, 32, 111, 102, 32, 116, 104, 101, 32, 118, 97, 108, 117, 101, 32, 99, 111, 110, 115, 116, 114, 97, 105, 110, 116, 32, 105, 115, 32, 110, 111, 116, 32, 118, 97, 108, 105, 100, 0, 0, 84, 104, 101, 32, 39, 102, 105, 120, 101, 100, 39, 32, 118, 97, 108, 117, 101, 32, 99, 111, 110, 115, 116, 114, 97, 105, 110, 116, 32, 111, 102, 32, 116, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 117, 115, 101, 32, 109, 117, 115, 116, 32, 109, 97, 116, 99, 104, 32, 116, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 39, 115, 32, 118, 97, 108, 117, 101, 32, 99, 111, 110, 115, 116, 114, 97, 105, 110, 116, 32, 39, 37, 115, 39, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 67, 104, 101, 99, 107, 65, 116, 116, 114, 80, 114, 111, 112, 115, 67, 111, 114, 114, 101, 99, 116, 0, 0, 84, 104, 101, 32, 117, 110, 105, 111, 110, 32, 116, 121, 112, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 105, 115, 32, 99, 105, 114, 99, 117, 108, 97, 114, 0, 0, 0, 67, 105, 114, 99, 117, 108, 97, 114, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 116, 111, 32, 116, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 103, 114, 111, 117, 112, 32, 39, 37, 115, 39, 32, 100, 101, 102, 105, 110, 101, 100, 0, 0, 67, 105, 114, 99, 117, 108, 97, 114, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 116, 111, 32, 116, 104, 101, 32, 109, 111, 100, 101, 108, 32, 103, 114, 111, 117, 112, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 39, 37, 115, 39, 32, 100, 101, 102, 105, 110, 101, 100, 0, 0, 0, 84, 104, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 105, 115, 32, 99, 105, 114, 99, 117, 108, 97, 114, 0, 0, 0, 0, 0, 0, 114, 101, 102, 0, 0, 0, 0, 0, 37, 115, 44, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 39, 37, 115, 39, 58, 32, 84, 104, 101, 32, 81, 78, 97, 109, 101, 32, 118, 97, 108, 117, 101, 32, 39, 37, 115, 39, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 114, 101, 115, 111, 108, 118, 101, 32, 116, 111, 32, 97, 40, 110, 41, 32, 37, 115, 46, 10, 0, 0, 114, 101, 102, 101, 114, 0, 0, 0, 84, 104, 101, 32, 107, 101, 121, 114, 101, 102, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 115, 32, 97, 32, 107, 101, 121, 114, 101, 102, 0, 0, 84, 104, 101, 32, 99, 97, 114, 100, 105, 110, 97, 108, 105, 116, 121, 32, 111, 102, 32, 116, 104, 101, 32, 107, 101, 121, 114, 101, 102, 32, 100, 105, 102, 102, 101, 114, 115, 32, 102, 114, 111, 109, 32, 116, 104, 101, 32, 99, 97, 114, 100, 105, 110, 97, 108, 105, 116, 121, 32, 111, 102, 32, 116, 104, 101, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 100, 32, 107, 101, 121, 47, 117, 110, 105, 113, 117, 101, 32, 39, 37, 115, 39, 0, 0, 0, 0, 65, 32, 109, 111, 100, 101, 108, 32, 103, 114, 111, 117, 112, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 105, 115, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 100, 44, 32, 98, 117, 116, 32, 105, 116, 32, 99, 111, 110, 116, 97, 105, 110, 115, 32, 97, 110, 32, 39, 97, 108, 108, 39, 32, 109, 111, 100, 101, 108, 32, 103, 114, 111, 117, 112, 44, 32, 119, 104, 105, 99, 104, 32, 99, 97, 110, 110, 111, 116, 32, 98, 101, 32, 99, 111, 110, 116, 97, 105, 110, 101, 100, 32, 98, 121, 32, 109, 111, 100, 101, 108, 32, 103, 114, 111, 117, 112, 115, 0, 105, 116, 101, 109, 84, 121, 112, 101, 0, 0, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 112, 97, 114, 116, 105, 99, 108, 101, 39, 115, 32, 123, 109, 97, 120, 32, 111, 99, 99, 117, 114, 115, 125, 32, 109, 117, 115, 116, 32, 98, 101, 32, 49, 44, 32, 115, 105, 110, 99, 101, 32, 116, 104, 101, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 114, 101, 115, 111, 108, 118, 101, 115, 32, 116, 111, 32, 97, 110, 32, 39, 97, 108, 108, 39, 32, 109, 111, 100, 101, 108, 32, 103, 114, 111, 117, 112, 0, 0, 0, 0, 0, 109, 101, 109, 98, 101, 114, 84, 121, 112, 101, 115, 0, 0, 0, 0, 0, 116, 121, 112, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 0, 115, 117, 98, 115, 116, 105, 116, 117, 116, 105, 111, 110, 71, 114, 111, 117, 112, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 65, 100, 100, 67, 111, 109, 112, 111, 110, 101, 110, 116, 115, 0, 0, 85, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 103, 108, 111, 98, 97, 108, 32, 99, 111, 109, 112, 111, 110, 101, 110, 116, 32, 116, 121, 112, 101, 0, 0, 0, 0, 0, 0, 0, 0, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 99, 114, 101, 97, 116, 101, 32, 97, 32, 99, 111, 109, 112, 111, 110, 101, 110, 116, 32, 104, 97, 115, 104, 32, 116, 97, 98, 108, 101, 0, 65, 32, 103, 108, 111, 98, 97, 108, 32, 37, 115, 32, 39, 37, 115, 39, 32, 100, 111, 101, 115, 32, 97, 108, 114, 101, 97, 100, 121, 32, 101, 120, 105, 115, 116, 0, 0, 0, 0, 0, 84, 104, 101, 32, 37, 115, 32, 39, 37, 115, 39, 32, 116, 111, 32, 98, 101, 32, 114, 101, 100, 101, 102, 105, 110, 101, 100, 32, 99, 111, 117, 108, 100, 32, 110, 111, 116, 32, 98, 101, 32, 102, 111, 117, 110, 100, 32, 105, 110, 32, 116, 104, 101, 32, 114, 101, 100, 101, 102, 105, 110, 101, 100, 32, 115, 99, 104, 101, 109, 97, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 82, 101, 115, 111, 108, 118, 101, 82, 101, 100, 101, 102, 82, 101, 102, 101, 114, 101, 110, 99, 101, 115, 0, 85, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 114, 101, 100, 101, 102, 105, 110, 101, 100, 32, 99, 111, 109, 112, 111, 110, 101, 110, 116, 32, 116, 121, 112, 101, 0, 0, 0, 0, 0, 84, 104, 101, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 100, 32, 37, 115, 32, 119, 97, 115, 32, 97, 108, 114, 101, 97, 100, 121, 32, 114, 101, 100, 101, 102, 105, 110, 101, 100, 46, 32, 77, 117, 108, 116, 105, 112, 108, 101, 32, 114, 101, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 111, 102, 32, 116, 104, 101, 32, 115, 97, 109, 101, 32, 99, 111, 109, 112, 111, 110, 101, 110, 116, 32, 105, 115, 32, 110, 111, 116, 32, 115, 117, 112, 112, 111, 114, 116, 101, 100, 0, 0, 0, 105, 110, 99, 108, 117, 100, 101, 0, 105, 109, 112, 111, 114, 116, 0, 0, 114, 101, 100, 101, 102, 105, 110, 101, 0, 0, 0, 0, 0, 0, 0, 0, 97, 110, 110, 111, 116, 97, 116, 105, 111, 110, 0, 0, 0, 0, 0, 0, 99, 111, 109, 112, 108, 101, 120, 84, 121, 112, 101, 0, 0, 0, 0, 0, 115, 105, 109, 112, 108, 101, 84, 121, 112, 101, 0, 0, 0, 0, 0, 0, 101, 108, 101, 109, 101, 110, 116, 0, 97, 116, 116, 114, 105, 98, 117, 116, 101, 0, 0, 0, 0, 0, 0, 0, 97, 116, 116, 114, 105, 98, 117, 116, 101, 71, 114, 111, 117, 112, 0, 0, 103, 114, 111, 117, 112, 0, 0, 0, 110, 111, 116, 97, 116, 105, 111, 110, 0, 0, 0, 0, 0, 0, 0, 0, 40, 40, 105, 110, 99, 108, 117, 100, 101, 32, 124, 32, 105, 109, 112, 111, 114, 116, 32, 124, 32, 114, 101, 100, 101, 102, 105, 110, 101, 32, 124, 32, 97, 110, 110, 111, 116, 97, 116, 105, 111, 110, 41, 42, 44, 32, 40, 40, 40, 115, 105, 109, 112, 108, 101, 84, 121, 112, 101, 32, 124, 32, 99, 111, 109, 112, 108, 101, 120, 84, 121, 112, 101, 32, 124, 32, 103, 114, 111, 117, 112, 32, 124, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 71, 114, 111, 117, 112, 41, 32, 124, 32, 101, 108, 101, 109, 101, 110, 116, 32, 124, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 124, 32, 110, 111, 116, 97, 116, 105, 111, 110, 41, 44, 32, 97, 110, 110, 111, 116, 97, 116, 105, 111, 110, 42, 41, 42, 41, 0, 0, 0, 37, 115, 58, 32, 37, 115, 46, 10, 0, 0, 0, 0, 0, 0, 0, 0, 37, 115, 58, 32, 84, 104, 101, 32, 99, 111, 110, 116, 101, 110, 116, 32, 105, 115, 32, 110, 111, 116, 32, 118, 97, 108, 105, 100, 46, 32, 69, 120, 112, 101, 99, 116, 101, 100, 32, 105, 115, 32, 37, 115, 46, 10, 0, 0, 37, 115, 58, 32, 84, 104, 101, 32, 99, 111, 110, 116, 101, 110, 116, 32, 105, 115, 32, 110, 111, 116, 32, 118, 97, 108, 105, 100, 46, 10, 0, 0, 110, 97, 109, 101, 0, 0, 0, 0, 78, 111, 116, 97, 116, 105, 111, 110, 32, 104, 97, 115, 32, 110, 111, 32, 110, 97, 109, 101, 10, 0, 0, 0, 105, 100, 0, 0, 0, 0, 0, 0, 40, 97, 110, 110, 111, 116, 97, 116, 105, 111, 110, 63, 41, 0, 0, 0, 68, 117, 112, 108, 105, 99, 97, 116, 101, 32, 118, 97, 108, 117, 101, 32, 39, 37, 115, 39, 32, 111, 102, 32, 115, 105, 109, 112, 108, 101, 32, 116, 121, 112, 101, 32, 39, 120, 115, 58, 73, 68, 39, 0, 0, 0, 0, 0, 84, 104, 101, 32, 118, 97, 108, 117, 101, 32, 39, 37, 115, 39, 32, 111, 102, 32, 115, 105, 109, 112, 108, 101, 32, 116, 121, 112, 101, 32, 39, 120, 115, 58, 73, 68, 39, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 118, 97, 108, 105, 100, 32, 39, 120, 115, 58, 78, 67, 78, 97, 109, 101, 39, 0, 0, 0, 0, 0, 0, 0, 0, 39, 46, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 118, 97, 108, 117, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 118, 97, 108, 105, 100, 46, 0, 0, 0, 0, 84, 104, 101, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 99, 111, 110, 116, 101, 110, 116, 32, 105, 115, 32, 110, 111, 116, 32, 118, 97, 108, 105, 100, 46, 0, 0, 0, 0, 0, 32, 69, 120, 112, 101, 99, 116, 101, 100, 32, 105, 115, 32, 39, 0, 0, 39, 46, 10, 0, 0, 0, 0, 0, 97, 100, 100, 32, 97, 110, 110, 111, 116, 97, 116, 105, 111, 110, 0, 0, 97, 108, 108, 0, 0, 0, 0, 0, 99, 104, 111, 105, 99, 101, 0, 0, 115, 101, 113, 117, 101, 110, 99, 101, 0, 0, 0, 0, 0, 0, 0, 0, 40, 97, 110, 110, 111, 116, 97, 116, 105, 111, 110, 63, 44, 32, 40, 97, 108, 108, 32, 124, 32, 99, 104, 111, 105, 99, 101, 32, 124, 32, 115, 101, 113, 117, 101, 110, 99, 101, 41, 63, 41, 0, 0, 0, 0, 0, 0, 0, 40, 48, 32, 124, 32, 49, 41, 0, 49, 0, 0, 0, 0, 0, 0, 0, 120, 115, 58, 110, 111, 110, 78, 101, 103, 97, 116, 105, 118, 101, 73, 110, 116, 101, 103, 101, 114, 0, 0, 0, 40, 120, 115, 58, 110, 111, 110, 78, 101, 103, 97, 116, 105, 118, 101, 73, 110, 116, 101, 103, 101, 114, 32, 124, 32, 117, 110, 98, 111, 117, 110, 100, 101, 100, 41, 0, 0, 0, 0, 0, 109, 97, 120, 79, 99, 99, 117, 114, 115, 0, 0, 0, 0, 0, 0, 0, 109, 105, 110, 79, 99, 99, 117, 114, 115, 0, 0, 0, 0, 0, 0, 0, 73, 110, 118, 97, 108, 105, 100, 32, 118, 97, 108, 117, 101, 32, 102, 111, 114, 32, 109, 105, 110, 79, 99, 99, 117, 114, 115, 32, 40, 109, 117, 115, 116, 32, 98, 101, 32, 48, 32, 111, 114, 32, 49, 41, 0, 0, 0, 0, 73, 110, 118, 97, 108, 105, 100, 32, 118, 97, 108, 117, 101, 32, 102, 111, 114, 32, 109, 97, 120, 79, 99, 99, 117, 114, 115, 32, 40, 109, 117, 115, 116, 32, 98, 101, 32, 48, 32, 111, 114, 32, 49, 41, 0, 0, 0, 0, 40, 97, 110, 110, 111, 116, 97, 116, 105, 111, 110, 63, 44, 32, 40, 97, 110, 110, 111, 116, 97, 116, 105, 111, 110, 63, 44, 32, 101, 108, 101, 109, 101, 110, 116, 42, 41, 0, 0, 0, 97, 110, 121, 0, 0, 0, 0, 0, 84, 104, 101, 32, 114, 101, 100, 101, 102, 105, 110, 105, 110, 103, 32, 109, 111, 100, 101, 108, 32, 103, 114, 111, 117, 112, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 39, 37, 115, 39, 32, 109, 117, 115, 116, 32, 110, 111, 116, 32, 99, 111, 110, 116, 97, 105, 110, 32, 109, 111, 114, 101, 32, 116, 104, 97, 110, 32, 111, 110, 101, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 116, 111, 32, 116, 104, 101, 32, 114, 101, 100, 101, 102, 105, 110, 101, 100, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 0, 84, 104, 101, 32, 114, 101, 100, 101, 102, 105, 110, 105, 110, 103, 32, 109, 111, 100, 101, 108, 32, 103, 114, 111, 117, 112, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 39, 37, 115, 39, 32, 109, 117, 115, 116, 32, 110, 111, 116, 32, 99, 111, 110, 116, 97, 105, 110, 32, 97, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 116, 111, 32, 116, 104, 101, 32, 114, 101, 100, 101, 102, 105, 110, 101, 100, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 119, 105, 116, 104, 32, 97, 32, 109, 97, 120, 79, 99, 99, 117, 114, 115, 47, 109, 105, 110, 79, 99, 99, 117, 114, 115, 32, 111, 116, 104, 101, 114, 32, 116, 104, 97, 110, 32, 49, 0, 0, 0, 0, 0, 40, 97, 110, 110, 111, 116, 97, 116, 105, 111, 110, 63, 44, 32, 40, 101, 108, 101, 109, 101, 110, 116, 32, 124, 32, 103, 114, 111, 117, 112, 32, 124, 32, 99, 104, 111, 105, 99, 101, 32, 124, 32, 115, 101, 113, 117, 101, 110, 99, 101, 32, 124, 32, 97, 110, 121, 41, 42, 41, 0, 0, 0, 0, 0, 110, 97, 109, 101, 115, 112, 97, 99, 101, 0, 0, 0, 0, 0, 0, 0, 112, 114, 111, 99, 101, 115, 115, 67, 111, 110, 116, 101, 110, 116, 115, 0, 40, 115, 116, 114, 105, 99, 116, 32, 124, 32, 115, 107, 105, 112, 32, 124, 32, 108, 97, 120, 41, 0, 0, 0, 35, 35, 97, 110, 121, 0, 0, 0, 40, 40, 35, 35, 97, 110, 121, 32, 124, 32, 35, 35, 111, 116, 104, 101, 114, 41, 32, 124, 32, 76, 105, 115, 116, 32, 111, 102, 32, 40, 120, 115, 58, 97, 110, 121, 85, 82, 73, 32, 124, 32, 40, 35, 35, 116, 97, 114, 103, 101, 116, 78, 97, 109, 101, 115, 112, 97, 99, 101, 32, 124, 32, 35, 35, 108, 111, 99, 97, 108, 41, 41, 41, 0, 0, 0, 0, 0, 0, 0, 35, 35, 116, 97, 114, 103, 101, 116, 78, 97, 109, 101, 115, 112, 97, 99, 101, 0, 0, 0, 0, 0, 0, 0, 35, 35, 108, 111, 99, 97, 108, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 80, 86, 97, 108, 65, 116, 116, 114, 78, 111, 100, 101, 86, 97, 108, 117, 101, 0, 0, 0, 0, 0, 0, 116, 104, 101, 32, 103, 105, 118, 101, 110, 32, 116, 121, 112, 101, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 98, 117, 105, 108, 116, 45, 105, 110, 32, 116, 121, 112, 101, 0, 0, 0, 118, 97, 108, 105, 100, 97, 116, 105, 111, 110, 32, 117, 115, 105, 110, 103, 32, 116, 104, 101, 32, 103, 105, 118, 101, 110, 32, 116, 121, 112, 101, 32, 105, 115, 32, 110, 111, 116, 32, 115, 117, 112, 112, 111, 114, 116, 101, 100, 32, 119, 104, 105, 108, 101, 32, 112, 97, 114, 115, 105, 110, 103, 32, 97, 32, 115, 99, 104, 101, 109, 97, 0, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 118, 97, 108, 105, 100, 97, 116, 101, 32, 97, 32, 115, 99, 104, 101, 109, 97, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 118, 97, 108, 117, 101, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 81, 78, 97, 109, 101, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 105, 116, 101, 109, 0, 82, 101, 102, 101, 114, 101, 110, 99, 101, 115, 32, 102, 114, 111, 109, 32, 116, 104, 105, 115, 32, 115, 99, 104, 101, 109, 97, 32, 116, 111, 32, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 32, 105, 110, 32, 110, 111, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 97, 114, 101, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 101, 100, 44, 32, 115, 105, 110, 99, 101, 32, 110, 111, 116, 32, 105, 110, 100, 105, 99, 97, 116, 101, 100, 32, 98, 121, 32, 97, 110, 32, 105, 109, 112, 111, 114, 116, 32, 115, 116, 97, 116, 101, 109, 101, 110, 116, 0, 0, 0, 82, 101, 102, 101, 114, 101, 110, 99, 101, 115, 32, 102, 114, 111, 109, 32, 116, 104, 105, 115, 32, 115, 99, 104, 101, 109, 97, 32, 116, 111, 32, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 32, 105, 110, 32, 116, 104, 101, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 39, 37, 115, 39, 32, 97, 114, 101, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 101, 100, 44, 32, 115, 105, 110, 99, 101, 32, 110, 111, 116, 32, 105, 110, 100, 105, 99, 97, 116, 101, 100, 32, 98, 121, 32, 97, 110, 32, 105, 109, 112, 111, 114, 116, 32, 115, 116, 97, 116, 101, 109, 101, 110, 116, 0, 0, 0, 0, 0, 84, 104, 101, 32, 118, 97, 108, 117, 101, 32, 39, 37, 115, 39, 32, 111, 102, 32, 115, 105, 109, 112, 108, 101, 32, 116, 121, 112, 101, 32, 39, 120, 115, 58, 81, 78, 97, 109, 101, 39, 32, 104, 97, 115, 32, 110, 111, 32, 99, 111, 114, 114, 101, 115, 112, 111, 110, 100, 105, 110, 103, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 105, 110, 32, 115, 99, 111, 112, 101, 0, 0, 0, 0, 84, 104, 101, 32, 118, 97, 108, 117, 101, 32, 109, 117, 115, 116, 32, 98, 101, 32, 103, 114, 101, 97, 116, 101, 114, 32, 116, 104, 97, 110, 32, 111, 114, 32, 101, 113, 117, 97, 108, 32, 116, 111, 32, 49, 0, 0, 0, 0, 84, 104, 101, 32, 118, 97, 108, 117, 101, 32, 109, 117, 115, 116, 32, 110, 111, 116, 32, 98, 101, 32, 103, 114, 101, 97, 116, 101, 114, 32, 116, 104, 97, 110, 32, 116, 104, 101, 32, 118, 97, 108, 117, 101, 32, 111, 102, 32, 39, 109, 97, 120, 79, 99, 99, 117, 114, 115, 39, 0, 0, 0, 0, 0, 37, 115, 44, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 39, 37, 115, 39, 58, 32, 37, 115, 46, 10, 0, 0, 0, 0, 0, 0, 0, 0, 85, 110, 107, 110, 111, 119, 110, 0, 117, 110, 98, 111, 117, 110, 100, 101, 100, 0, 0, 0, 0, 0, 0, 0, 37, 115, 84, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 101, 100, 46, 10, 0, 0, 0, 97, 100, 100, 105, 110, 103, 32, 103, 114, 111, 117, 112, 0, 0, 0, 0, 37, 115, 58, 32, 84, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 114, 101, 113, 117, 105, 114, 101, 100, 32, 98, 117, 116, 32, 109, 105, 115, 115, 105, 110, 103, 46, 10, 0, 0, 0, 0, 0, 0, 0, 0, 97, 110, 121, 65, 116, 116, 114, 105, 98, 117, 116, 101, 0, 0, 0, 0, 40, 97, 110, 110, 111, 116, 97, 116, 105, 111, 110, 63, 44, 32, 40, 40, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 124, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 71, 114, 111, 117, 112, 41, 42, 44, 32, 97, 110, 121, 65, 116, 116, 114, 105, 98, 117, 116, 101, 63, 41, 41, 0, 0, 0, 84, 104, 101, 32, 114, 101, 100, 101, 102, 105, 110, 105, 110, 103, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 103, 114, 111, 117, 112, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 39, 37, 115, 39, 32, 109, 117, 115, 116, 32, 110, 111, 116, 32, 99, 111, 110, 116, 97, 105, 110, 32, 109, 111, 114, 101, 32, 116, 104, 97, 110, 32, 111, 110, 101, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 116, 111, 32, 116, 104, 101, 32, 114, 101, 100, 101, 102, 105, 110, 101, 100, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 0, 0, 0, 0, 0, 102, 111, 114, 109, 0, 0, 0, 0, 113, 117, 97, 108, 105, 102, 105, 101, 100, 0, 0, 0, 0, 0, 0, 0, 117, 110, 113, 117, 97, 108, 105, 102, 105, 101, 100, 0, 0, 0, 0, 0, 40, 113, 117, 97, 108, 105, 102, 105, 101, 100, 32, 124, 32, 117, 110, 113, 117, 97, 108, 105, 102, 105, 101, 100, 41, 0, 0, 0, 0, 0, 0, 0, 117, 115, 101, 0, 0, 0, 0, 0, 111, 112, 116, 105, 111, 110, 97, 108, 0, 0, 0, 0, 0, 0, 0, 0, 112, 114, 111, 104, 105, 98, 105, 116, 101, 100, 0, 0, 0, 0, 0, 0, 114, 101, 113, 117, 105, 114, 101, 100, 0, 0, 0, 0, 0, 0, 0, 0, 40, 111, 112, 116, 105, 111, 110, 97, 108, 32, 124, 32, 112, 114, 111, 104, 105, 98, 105, 116, 101, 100, 32, 124, 32, 114, 101, 113, 117, 105, 114, 101, 100, 41, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 118, 97, 108, 117, 101, 32, 111, 102, 32, 116, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 39, 117, 115, 101, 39, 32, 109, 117, 115, 116, 32, 98, 101, 32, 39, 111, 112, 116, 105, 111, 110, 97, 108, 39, 32, 105, 102, 32, 116, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 39, 100, 101, 102, 97, 117, 108, 116, 39, 32, 105, 115, 32, 112, 114, 101, 115, 101, 110, 116, 0, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 116, 97, 114, 103, 101, 116, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 109, 117, 115, 116, 32, 110, 111, 116, 32, 109, 97, 116, 99, 104, 32, 39, 37, 115, 39, 0, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 110, 115, 0, 0, 0, 84, 104, 101, 32, 118, 97, 108, 117, 101, 32, 111, 102, 32, 116, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 109, 117, 115, 116, 32, 110, 111, 116, 32, 109, 97, 116, 99, 104, 32, 39, 120, 109, 108, 110, 115, 39, 0, 0, 0, 0, 0, 0, 0, 83, 107, 105, 112, 112, 105, 110, 103, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 117, 115, 101, 32, 112, 114, 111, 104, 105, 98, 105, 116, 105, 111, 110, 44, 32, 115, 105, 110, 99, 101, 32, 105, 116, 32, 105, 115, 32, 112, 111, 105, 110, 116, 108, 101, 115, 115, 32, 105, 110, 115, 105, 100, 101, 32, 97, 110, 32, 60, 97, 116, 116, 114, 105, 98, 117, 116, 101, 71, 114, 111, 117, 112, 62, 0, 0, 0, 0, 83, 107, 105, 112, 112, 105, 110, 103, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 117, 115, 101, 32, 112, 114, 111, 104, 105, 98, 105, 116, 105, 111, 110, 44, 32, 115, 105, 110, 99, 101, 32, 105, 116, 32, 105, 115, 32, 112, 111, 105, 110, 116, 108, 101, 115, 115, 32, 119, 104, 101, 110, 32, 101, 120, 116, 101, 110, 100, 105, 110, 103, 32, 97, 32, 116, 121, 112, 101, 0, 83, 107, 105, 112, 112, 105, 110, 103, 32, 100, 117, 112, 108, 105, 99, 97, 116, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 117, 115, 101, 32, 112, 114, 111, 104, 105, 98, 105, 116, 105, 111, 110, 32, 39, 37, 115, 39, 0, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 39, 116, 121, 112, 101, 39, 32, 97, 110, 100, 32, 116, 104, 101, 32, 60, 115, 105, 109, 112, 108, 101, 84, 121, 112, 101, 62, 32, 99, 104, 105, 108, 100, 32, 97, 114, 101, 32, 109, 117, 116, 117, 97, 108, 108, 121, 32, 101, 120, 99, 108, 117, 115, 105, 118, 101, 0, 0, 40, 97, 110, 110, 111, 116, 97, 116, 105, 111, 110, 63, 44, 32, 115, 105, 109, 112, 108, 101, 84, 121, 112, 101, 63, 41, 0, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 117, 115, 101, 32, 112, 114, 111, 104, 105, 98, 105, 116, 105, 111, 110, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 0, 0, 0, 0, 37, 115, 58, 32, 84, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 115, 32, 39, 37, 115, 39, 32, 97, 110, 100, 32, 39, 37, 115, 39, 32, 97, 114, 101, 32, 109, 117, 116, 117, 97, 108, 108, 121, 32, 101, 120, 99, 108, 117, 115, 105, 118, 101, 46, 10, 0, 0, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 103, 114, 111, 117, 112, 0, 0, 0, 0, 0, 0, 79, 110, 108, 121, 32, 116, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 115, 32, 39, 109, 105, 110, 79, 99, 99, 117, 114, 115, 39, 44, 32, 39, 109, 97, 120, 79, 99, 99, 117, 114, 115, 39, 32, 97, 110, 100, 32, 39, 105, 100, 39, 32, 97, 114, 101, 32, 97, 108, 108, 111, 119, 101, 100, 32, 105, 110, 32, 97, 100, 100, 105, 116, 105, 111, 110, 32, 116, 111, 32, 39, 114, 101, 102, 39, 0, 0, 98, 108, 111, 99, 107, 0, 0, 0, 110, 105, 108, 108, 97, 98, 108, 101, 0, 0, 0, 0, 0, 0, 0, 0, 102, 105, 110, 97, 108, 0, 0, 0, 97, 98, 115, 116, 114, 97, 99, 116, 0, 0, 0, 0, 0, 0, 0, 0, 40, 35, 97, 108, 108, 32, 124, 32, 76, 105, 115, 116, 32, 111, 102, 32, 40, 101, 120, 116, 101, 110, 115, 105, 111, 110, 32, 124, 32, 114, 101, 115, 116, 114, 105, 99, 116, 105, 111, 110, 41, 41, 0, 0, 0, 0, 0, 0, 40, 35, 97, 108, 108, 32, 124, 32, 76, 105, 115, 116, 32, 111, 102, 32, 40, 101, 120, 116, 101, 110, 115, 105, 111, 110, 32, 124, 32, 114, 101, 115, 116, 114, 105, 99, 116, 105, 111, 110, 32, 124, 32, 115, 117, 98, 115, 116, 105, 116, 117, 116, 105, 111, 110, 41, 41, 0, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 39, 116, 121, 112, 101, 39, 32, 97, 110, 100, 32, 116, 104, 101, 32, 60, 99, 111, 109, 112, 108, 101, 120, 84, 121, 112, 101, 62, 32, 99, 104, 105, 108, 100, 32, 97, 114, 101, 32, 109, 117, 116, 117, 97, 108, 108, 121, 32, 101, 120, 99, 108, 117, 115, 105, 118, 101, 0, 117, 110, 105, 113, 117, 101, 0, 0, 107, 101, 121, 0, 0, 0, 0, 0, 107, 101, 121, 114, 101, 102, 0, 0, 40, 97, 110, 110, 111, 116, 97, 116, 105, 111, 110, 63, 44, 32, 40, 40, 115, 105, 109, 112, 108, 101, 84, 121, 112, 101, 32, 124, 32, 99, 111, 109, 112, 108, 101, 120, 84, 121, 112, 101, 41, 63, 44, 32, 40, 117, 110, 105, 113, 117, 101, 32, 124, 32, 107, 101, 121, 32, 124, 32, 107, 101, 121, 114, 101, 102, 41, 42, 41, 41, 0, 0, 65, 32, 99, 104, 105, 108, 100, 32, 101, 108, 101, 109, 101, 110, 116, 32, 105, 115, 32, 109, 105, 115, 115, 105, 110, 103, 0, 0, 0, 0, 0, 0, 40, 97, 110, 110, 111, 116, 97, 116, 105, 111, 110, 63, 44, 32, 40, 115, 101, 108, 101, 99, 116, 111, 114, 44, 32, 102, 105, 101, 108, 100, 43, 41, 41, 0, 0, 0, 0, 0, 0, 0, 115, 101, 108, 101, 99, 116, 111, 114, 0, 0, 0, 0, 0, 0, 0, 0, 102, 105, 101, 108, 100, 0, 0, 0, 120, 112, 97, 116, 104, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 97, 32, 39, 115, 101, 108, 101, 99, 116, 111, 114, 39, 32, 111, 102, 32, 97, 110, 32, 105, 100, 101, 110, 116, 105, 116, 121, 45, 99, 111, 110, 115, 116, 114, 97, 105, 110, 116, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 0, 0, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 58, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 80, 97, 114, 115, 101, 73, 68, 67, 83, 101, 108, 101, 99, 116, 111, 114, 65, 110, 100, 70, 105, 101, 108, 100, 44, 32, 118, 97, 108, 105, 100, 97, 116, 105, 110, 103, 32, 116, 104, 101, 32, 88, 80, 97, 116, 104, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 111, 102, 32, 97, 32, 73, 68, 67, 32, 115, 101, 108, 101, 99, 116, 111, 114, 46, 10, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 58, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 65, 100, 100, 65, 110, 110, 111, 116, 97, 116, 105, 111, 110, 44, 32, 84, 104, 101, 32, 105, 116, 101, 109, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 97, 110, 110, 111, 116, 97, 116, 101, 100, 32, 115, 99, 104, 101, 109, 97, 32, 99, 111, 109, 112, 111, 110, 101, 110, 116, 0, 0, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 58, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 67, 104, 101, 99, 107, 67, 83, 101, 108, 101, 99, 116, 111, 114, 88, 80, 97, 116, 104, 44, 32, 116, 104, 101, 32, 115, 101, 108, 101, 99, 116, 111, 114, 32, 105, 115, 32, 110, 111, 116, 32, 115, 112, 101, 99, 105, 102, 105, 101, 100, 46, 10, 0, 0, 0, 84, 104, 101, 32, 88, 80, 97, 116, 104, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 111, 102, 32, 116, 104, 101, 32, 115, 101, 108, 101, 99, 116, 111, 114, 32, 105, 115, 32, 110, 111, 116, 32, 118, 97, 108, 105, 100, 0, 0, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 97, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 97, 114, 114, 97, 121, 0, 0, 0, 0, 84, 104, 101, 32, 88, 80, 97, 116, 104, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 39, 37, 115, 39, 32, 99, 111, 117, 108, 100, 32, 110, 111, 116, 32, 98, 101, 32, 99, 111, 109, 112, 105, 108, 101, 100, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 97, 110, 32, 105, 100, 101, 110, 116, 105, 116, 121, 45, 99, 111, 110, 115, 116, 114, 97, 105, 110, 116, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 0, 0, 0, 0, 35, 97, 108, 108, 0, 0, 0, 0, 101, 120, 116, 101, 110, 115, 105, 111, 110, 0, 0, 0, 0, 0, 0, 0, 114, 101, 115, 116, 114, 105, 99, 116, 105, 111, 110, 0, 0, 0, 0, 0, 115, 117, 98, 115, 116, 105, 116, 117, 116, 105, 111, 110, 0, 0, 0, 0, 108, 105, 115, 116, 0, 0, 0, 0, 117, 110, 105, 111, 110, 0, 0, 0, 116, 114, 117, 101, 0, 0, 0, 0, 102, 97, 108, 115, 101, 0, 0, 0, 48, 0, 0, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 101, 108, 101, 109, 101, 110, 116, 0, 0, 0, 0, 0, 0, 82, 101, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 111, 102, 32, 98, 117, 105, 108, 116, 45, 105, 110, 32, 115, 105, 109, 112, 108, 101, 32, 116, 121, 112, 101, 115, 32, 105, 115, 32, 110, 111, 116, 32, 115, 117, 112, 112, 111, 114, 116, 101, 100, 0, 0, 40, 35, 97, 108, 108, 32, 124, 32, 76, 105, 115, 116, 32, 111, 102, 32, 40, 108, 105, 115, 116, 32, 124, 32, 117, 110, 105, 111, 110, 32, 124, 32, 114, 101, 115, 116, 114, 105, 99, 116, 105, 111, 110, 41, 0, 0, 0, 0, 40, 97, 110, 110, 111, 116, 97, 116, 105, 111, 110, 63, 44, 32, 40, 114, 101, 115, 116, 114, 105, 99, 116, 105, 111, 110, 32, 124, 32, 108, 105, 115, 116, 32, 124, 32, 117, 110, 105, 111, 110, 41, 41, 0, 0, 0, 0, 0, 84, 104, 105, 115, 32, 105, 115, 32, 97, 32, 114, 101, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 44, 32, 116, 104, 117, 115, 32, 116, 104, 101, 32, 60, 115, 105, 109, 112, 108, 101, 84, 121, 112, 101, 62, 32, 109, 117, 115, 116, 32, 104, 97, 118, 101, 32, 97, 32, 60, 114, 101, 115, 116, 114, 105, 99, 116, 105, 111, 110, 62, 32, 99, 104, 105, 108, 100, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 80, 97, 114, 115, 101, 85, 110, 105, 111, 110, 44, 32, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 97, 32, 116, 121, 112, 101, 32, 108, 105, 110, 107, 0, 0, 0, 0, 0, 40, 97, 110, 110, 111, 116, 97, 116, 105, 111, 110, 63, 44, 32, 115, 105, 109, 112, 108, 101, 84, 121, 112, 101, 42, 41, 0, 0, 0, 0, 0, 0, 69, 105, 116, 104, 101, 114, 32, 116, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 39, 109, 101, 109, 98, 101, 114, 84, 121, 112, 101, 115, 39, 32, 111, 114, 32, 97, 116, 32, 108, 101, 97, 115, 116, 32, 111, 110, 101, 32, 60, 115, 105, 109, 112, 108, 101, 84, 121, 112, 101, 62, 32, 99, 104, 105, 108, 100, 32, 109, 117, 115, 116, 32, 98, 101, 32, 112, 114, 101, 115, 101, 110, 116, 0, 0, 0, 84, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 39, 105, 116, 101, 109, 84, 121, 112, 101, 39, 32, 97, 110, 100, 32, 116, 104, 101, 32, 60, 115, 105, 109, 112, 108, 101, 84, 121, 112, 101, 62, 32, 99, 104, 105, 108, 100, 32, 97, 114, 101, 32, 109, 117, 116, 117, 97, 108, 108, 121, 32, 101, 120, 99, 108, 117, 115, 105, 118, 101, 0, 0, 0, 0, 0, 0, 69, 105, 116, 104, 101, 114, 32, 116, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 39, 105, 116, 101, 109, 84, 121, 112, 101, 39, 32, 111, 114, 32, 116, 104, 101, 32, 60, 115, 105, 109, 112, 108, 101, 84, 121, 112, 101, 62, 32, 99, 104, 105, 108, 100, 32, 109, 117, 115, 116, 32, 98, 101, 32, 112, 114, 101, 115, 101, 110, 116, 0, 0, 0, 0, 0, 0, 0, 84, 104, 105, 115, 32, 105, 115, 32, 97, 32, 114, 101, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 44, 32, 98, 117, 116, 32, 116, 104, 101, 32, 81, 78, 97, 109, 101, 32, 118, 97, 108, 117, 101, 32, 39, 37, 115, 39, 32, 111, 102, 32, 116, 104, 101, 32, 39, 98, 97, 115, 101, 39, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 109, 97, 116, 99, 104, 32, 116, 104, 101, 32, 116, 121, 112, 101, 39, 115, 32, 100, 101, 115, 105, 103, 110, 97, 116, 105, 111, 110, 32, 39, 37, 115, 39, 0, 0, 0, 0, 0, 84, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 39, 98, 97, 115, 101, 39, 32, 97, 110, 100, 32, 116, 104, 101, 32, 60, 115, 105, 109, 112, 108, 101, 84, 121, 112, 101, 62, 32, 99, 104, 105, 108, 100, 32, 97, 114, 101, 32, 109, 117, 116, 117, 97, 108, 108, 121, 32, 101, 120, 99, 108, 117, 115, 105, 118, 101, 0, 0, 69, 105, 116, 104, 101, 114, 32, 116, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 39, 98, 97, 115, 101, 39, 32, 111, 114, 32, 97, 32, 60, 115, 105, 109, 112, 108, 101, 84, 121, 112, 101, 62, 32, 99, 104, 105, 108, 100, 32, 109, 117, 115, 116, 32, 98, 101, 32, 112, 114, 101, 115, 101, 110, 116, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 97, 32, 102, 97, 99, 101, 116, 32, 108, 105, 110, 107, 0, 97, 110, 110, 111, 116, 97, 116, 105, 111, 110, 63, 44, 32, 40, 103, 114, 111, 117, 112, 32, 124, 32, 97, 108, 108, 32, 124, 32, 99, 104, 111, 105, 99, 101, 32, 124, 32, 115, 101, 113, 117, 101, 110, 99, 101, 41, 63, 44, 32, 40, 40, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 124, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 71, 114, 111, 117, 112, 41, 42, 44, 32, 97, 110, 121, 65, 116, 116, 114, 105, 98, 117, 116, 101, 63, 41, 41, 0, 0, 0, 0, 0, 0, 0, 0, 40, 97, 110, 110, 111, 116, 97, 116, 105, 111, 110, 63, 44, 32, 40, 115, 105, 109, 112, 108, 101, 84, 121, 112, 101, 63, 44, 32, 40, 109, 105, 110, 69, 120, 99, 108, 117, 115, 105, 118, 101, 32, 124, 32, 109, 105, 110, 73, 110, 99, 108, 117, 115, 105, 118, 101, 32, 124, 32, 109, 97, 120, 69, 120, 99, 108, 117, 115, 105, 118, 101, 32, 124, 32, 109, 97, 120, 73, 110, 99, 108, 117, 115, 105, 118, 101, 32, 124, 32, 116, 111, 116, 97, 108, 68, 105, 103, 105, 116, 115, 32, 124, 32, 102, 114, 97, 99, 116, 105, 111, 110, 68, 105, 103, 105, 116, 115, 32, 124, 32, 108, 101, 110, 103, 116, 104, 32, 124, 32, 109, 105, 110, 76, 101, 110, 103, 116, 104, 32, 124, 32, 109, 97, 120, 76, 101, 110, 103, 116, 104, 32, 124, 32, 101, 110, 117, 109, 101, 114, 97, 116, 105, 111, 110, 32, 124, 32, 119, 104, 105, 116, 101, 83, 112, 97, 99, 101, 32, 124, 32, 112, 97, 116, 116, 101, 114, 110, 41, 42, 41, 63, 44, 32, 40, 40, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 124, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 71, 114, 111, 117, 112, 41, 42, 44, 32, 97, 110, 121, 65, 116, 116, 114, 105, 98, 117, 116, 101, 63, 41, 41, 0, 0, 0, 0, 0, 0, 0, 0, 40, 97, 110, 110, 111, 116, 97, 116, 105, 111, 110, 63, 44, 32, 40, 115, 105, 109, 112, 108, 101, 84, 121, 112], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 156528);
	        allocate([101, 63, 44, 32, 40, 109, 105, 110, 69, 120, 99, 108, 117, 115, 105, 118, 101, 32, 124, 32, 109, 105, 110, 73, 110, 99, 108, 117, 115, 105, 118, 101, 32, 124, 32, 109, 97, 120, 69, 120, 99, 108, 117, 115, 105, 118, 101, 32, 124, 32, 109, 97, 120, 73, 110, 99, 108, 117, 115, 105, 118, 101, 32, 124, 32, 116, 111, 116, 97, 108, 68, 105, 103, 105, 116, 115, 32, 124, 32, 102, 114, 97, 99, 116, 105, 111, 110, 68, 105, 103, 105, 116, 115, 32, 124, 32, 108, 101, 110, 103, 116, 104, 32, 124, 32, 109, 105, 110, 76, 101, 110, 103, 116, 104, 32, 124, 32, 109, 97, 120, 76, 101, 110, 103, 116, 104, 32, 124, 32, 101, 110, 117, 109, 101, 114, 97, 116, 105, 111, 110, 32, 124, 32, 119, 104, 105, 116, 101, 83, 112, 97, 99, 101, 32, 124, 32, 112, 97, 116, 116, 101, 114, 110, 41, 42, 41, 41, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 102, 97, 99, 101, 116, 0, 0, 0, 0, 0, 0, 0, 0, 118, 97, 108, 117, 101, 0, 0, 0, 70, 97, 99, 101, 116, 32, 37, 115, 32, 104, 97, 115, 32, 110, 111, 32, 118, 97, 108, 117, 101, 10, 0, 0, 85, 110, 107, 110, 111, 119, 110, 32, 102, 97, 99, 101, 116, 32, 116, 121, 112, 101, 32, 37, 115, 10, 0, 0, 70, 97, 99, 101, 116, 32, 37, 115, 32, 104, 97, 115, 32, 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 99, 104, 105, 108, 100, 32, 99, 111, 110, 116, 101, 110, 116, 10, 0, 0, 109, 105, 120, 101, 100, 0, 0, 0, 40, 35, 97, 108, 108, 32, 124, 32, 76, 105, 115, 116, 32, 111, 102, 32, 40, 101, 120, 116, 101, 110, 115, 105, 111, 110, 32, 124, 32, 114, 101, 115, 116, 114, 105, 99, 116, 105, 111, 110, 41, 41, 32, 0, 0, 0, 0, 0, 115, 105, 109, 112, 108, 101, 67, 111, 110, 116, 101, 110, 116, 0, 0, 0, 99, 111, 109, 112, 108, 101, 120, 67, 111, 110, 116, 101, 110, 116, 0, 0, 40, 97, 110, 110, 111, 116, 97, 116, 105, 111, 110, 63, 44, 32, 40, 115, 105, 109, 112, 108, 101, 67, 111, 110, 116, 101, 110, 116, 32, 124, 32, 99, 111, 109, 112, 108, 101, 120, 67, 111, 110, 116, 101, 110, 116, 32, 124, 32, 40, 40, 103, 114, 111, 117, 112, 32, 124, 32, 97, 108, 108, 32, 124, 32, 99, 104, 111, 105, 99, 101, 32, 124, 32, 115, 101, 113, 117, 101, 110, 99, 101, 41, 63, 44, 32, 40, 40, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 124, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 71, 114, 111, 117, 112, 41, 42, 44, 32, 97, 110, 121, 65, 116, 116, 114, 105, 98, 117, 116, 101, 63, 41, 41, 41, 41, 0, 0, 84, 104, 105, 115, 32, 105, 115, 32, 97, 32, 114, 101, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 44, 32, 116, 104, 117, 115, 32, 116, 104, 101, 32, 60, 99, 111, 109, 112, 108, 101, 120, 84, 121, 112, 101, 62, 32, 109, 117, 115, 116, 32, 104, 97, 118, 101, 32, 97, 32, 60, 114, 101, 115, 116, 114, 105, 99, 116, 105, 111, 110, 62, 32, 111, 114, 32, 60, 101, 120, 116, 101, 110, 115, 105, 111, 110, 62, 32, 103, 114, 97, 110, 100, 45, 99, 104, 105, 108, 100, 0, 0, 0, 0, 0, 40, 97, 110, 110, 111, 116, 97, 116, 105, 111, 110, 63, 44, 32, 40, 114, 101, 115, 116, 114, 105, 99, 116, 105, 111, 110, 32, 124, 32, 101, 120, 116, 101, 110, 115, 105, 111, 110, 41, 41, 0, 0, 0, 0, 0, 0, 0, 0, 40, 97, 110, 110, 111, 116, 97, 116, 105, 111, 110, 63, 44, 32, 40, 40, 103, 114, 111, 117, 112, 32, 124, 32, 97, 108, 108, 32, 124, 32, 99, 104, 111, 105, 99, 101, 32, 124, 32, 115, 101, 113, 117, 101, 110, 99, 101, 41, 63, 44, 32, 40, 40, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 124, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 71, 114, 111, 117, 112, 41, 42, 44, 32, 97, 110, 121, 65, 116, 116, 114, 105, 98, 117, 116, 101, 63, 41, 41, 41, 0, 0, 0, 0, 0, 70, 97, 105, 108, 101, 100, 32, 116, 111, 32, 108, 111, 97, 100, 32, 116, 104, 101, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 39, 37, 115, 39, 32, 102, 111, 114, 32, 105, 110, 99, 108, 117, 115, 105, 111, 110, 0, 0, 70, 97, 105, 108, 101, 100, 32, 116, 111, 32, 108, 111, 97, 100, 32, 116, 104, 101, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 39, 37, 115, 39, 32, 102, 111, 114, 32, 114, 101, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 0, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 116, 97, 114, 103, 101, 116, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 111, 102, 32, 116, 104, 101, 32, 105, 110, 99, 108, 117, 100, 101, 100, 47, 114, 101, 100, 101, 102, 105, 110, 101, 100, 32, 115, 99, 104, 101, 109, 97, 32, 39, 37, 115, 39, 32, 104, 97, 115, 32, 116, 111, 32, 98, 101, 32, 97, 98, 115, 101, 110, 116, 44, 32, 115, 105, 110, 99, 101, 32, 116, 104, 101, 32, 105, 110, 99, 108, 117, 100, 105, 110, 103, 47, 114, 101, 100, 101, 102, 105, 110, 105, 110, 103, 32, 115, 99, 104, 101, 109, 97, 32, 104, 97, 115, 32, 110, 111, 32, 116, 97, 114, 103, 101, 116, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 116, 97, 114, 103, 101, 116, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 39, 37, 115, 39, 32, 111, 102, 32, 116, 104, 101, 32, 105, 110, 99, 108, 117, 100, 101, 100, 47, 114, 101, 100, 101, 102, 105, 110, 101, 100, 32, 115, 99, 104, 101, 109, 97, 32, 39, 37, 115, 39, 32, 100, 105, 102, 102, 101, 114, 115, 32, 102, 114, 111, 109, 32, 39, 37, 115, 39, 32, 111, 102, 32, 116, 104, 101, 32, 105, 110, 99, 108, 117, 100, 105, 110, 103, 47, 114, 101, 100, 101, 102, 105, 110, 105, 110, 103, 32, 115, 99, 104, 101, 109, 97, 0, 0, 0, 0, 84, 104, 101, 32, 116, 97, 114, 103, 101, 116, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 111, 102, 32, 116, 104, 101, 32, 105, 110, 99, 108, 117, 100, 101, 100, 47, 114, 101, 100, 101, 102, 105, 110, 101, 100, 32, 115, 99, 104, 101, 109, 97, 32, 39, 37, 115, 39, 32, 104, 97, 115, 32, 116, 111, 32, 98, 101, 32, 97, 98, 115, 101, 110, 116, 32, 111, 114, 32, 116, 104, 101, 32, 115, 97, 109, 101, 32, 97, 115, 32, 116, 104, 101, 32, 105, 110, 99, 108, 117, 100, 105, 110, 103, 47, 114, 101, 100, 101, 102, 105, 110, 105, 110, 103, 32, 115, 99, 104, 101, 109, 97, 39, 115, 32, 116, 97, 114, 103, 101, 116, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 0, 0, 0, 40, 97, 110, 110, 111, 116, 97, 116, 105, 111, 110, 32, 124, 32, 40, 115, 105, 109, 112, 108, 101, 84, 121, 112, 101, 32, 124, 32, 99, 111, 109, 112, 108, 101, 120, 84, 121, 112, 101, 32, 124, 32, 103, 114, 111, 117, 112, 32, 124, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 71, 114, 111, 117, 112, 41, 41, 42, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 80, 97, 114, 115, 101, 78, 101, 119, 68, 111, 99, 0, 0, 0, 0, 114, 101, 112, 97, 114, 115, 105, 110, 103, 32, 97, 32, 115, 99, 104, 101, 109, 97, 32, 100, 111, 99, 0, 0, 112, 97, 114, 115, 105, 110, 103, 32, 97, 32, 115, 99, 104, 101, 109, 97, 32, 100, 111, 99, 44, 32, 98, 117, 116, 32, 116, 104, 101, 114, 101, 39, 115, 32, 110, 111, 32, 100, 111, 99, 0, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 80, 97, 114, 115, 101, 73, 110, 99, 108, 117, 100, 101, 79, 114, 82, 101, 100, 101, 102, 105, 110, 101, 0, 99, 111, 117, 108, 100, 32, 110, 111, 116, 32, 98, 117, 105, 108, 100, 32, 97, 110, 32, 85, 82, 73, 32, 102, 114, 111, 109, 32, 116, 104, 101, 32, 115, 99, 104, 101, 109, 97, 76, 111, 99, 97, 116, 105, 111, 110, 0, 0, 84, 104, 101, 32, 115, 99, 104, 101, 109, 97, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 39, 37, 115, 39, 32, 99, 97, 110, 110, 111, 116, 32, 114, 101, 100, 101, 102, 105, 110, 101, 32, 105, 116, 115, 101, 108, 102, 46, 0, 0, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 115, 99, 104, 101, 109, 97, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 39, 37, 115, 39, 32, 99, 97, 110, 110, 111, 116, 32, 105, 110, 99, 108, 117, 100, 101, 32, 105, 116, 115, 101, 108, 102, 46, 0, 84, 104, 101, 32, 118, 97, 108, 117, 101, 32, 111, 102, 32, 116, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 39, 110, 97, 109, 101, 115, 112, 97, 99, 101, 39, 32, 109, 117, 115, 116, 32, 110, 111, 116, 32, 109, 97, 116, 99, 104, 32, 116, 104, 101, 32, 116, 97, 114, 103, 101, 116, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 39, 37, 115, 39, 32, 111, 102, 32, 116, 104, 101, 32, 105, 109, 112, 111, 114, 116, 105, 110, 103, 32, 115, 99, 104, 101, 109, 97, 0, 84, 104, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 39, 110, 97, 109, 101, 115, 112, 97, 99, 101, 39, 32, 109, 117, 115, 116, 32, 98, 101, 32, 101, 120, 105, 115, 116, 101, 110, 116, 32, 105, 102, 32, 116, 104, 101, 32, 105, 109, 112, 111, 114, 116, 105, 110, 103, 32, 115, 99, 104, 101, 109, 97, 32, 104, 97, 115, 32, 110, 111, 32, 116, 97, 114, 103, 101, 116, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 0, 0, 0, 0, 0, 0, 70, 97, 105, 108, 101, 100, 32, 116, 111, 32, 108, 111, 99, 97, 116, 101, 32, 97, 32, 115, 99, 104, 101, 109, 97, 32, 97, 116, 32, 108, 111, 99, 97, 116, 105, 111, 110, 32, 39, 37, 115, 39, 46, 32, 83, 107, 105, 112, 112, 105, 110, 103, 32, 116, 104, 101, 32, 105, 109, 112, 111, 114, 116, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 58, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 80, 86, 97, 108, 65, 116, 116, 114, 44, 32, 116, 104, 101, 32, 103, 105, 118, 101, 110, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 98, 117, 105, 108, 116, 45, 105, 110, 32, 116, 121, 112, 101, 46, 10, 0, 97, 112, 112, 105, 110, 102, 111, 0, 115, 111, 117, 114, 99, 101, 0, 0, 100, 111, 99, 117, 109, 101, 110, 116, 97, 116, 105, 111, 110, 0, 0, 0, 108, 97, 110, 103, 0, 0, 0, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 88, 77, 76, 47, 49, 57, 57, 56, 47, 110, 97, 109, 101, 115, 112, 97, 99, 101, 0, 0, 0, 0, 40, 97, 112, 112, 105, 110, 102, 111, 32, 124, 32, 100, 111, 99, 117, 109, 101, 110, 116, 97, 116, 105, 111, 110, 41, 42, 0, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 97, 110, 110, 111, 116, 97, 116, 105, 111, 110, 0, 0, 0, 116, 97, 114, 103, 101, 116, 78, 97, 109, 101, 115, 112, 97, 99, 101, 0, 101, 108, 101, 109, 101, 110, 116, 70, 111, 114, 109, 68, 101, 102, 97, 117, 108, 116, 0, 0, 0, 0, 0, 0, 97, 116, 116, 114, 105, 98, 117, 116, 101, 70, 111, 114, 109, 68, 101, 102, 97, 117, 108, 116, 0, 0, 0, 0, 102, 105, 110, 97, 108, 68, 101, 102, 97, 117, 108, 116, 0, 0, 0, 0, 40, 35, 97, 108, 108, 32, 124, 32, 76, 105, 115, 116, 32, 111, 102, 32, 40, 101, 120, 116, 101, 110, 115, 105, 111, 110, 32, 124, 32, 114, 101, 115, 116, 114, 105, 99, 116, 105, 111, 110, 32, 124, 32, 108, 105, 115, 116, 32, 124, 32, 117, 110, 105, 111, 110, 41, 41, 0, 0, 0, 0, 0, 0, 0, 98, 108, 111, 99, 107, 68, 101, 102, 97, 117, 108, 116, 0, 0, 0, 0, 84, 104, 101, 32, 115, 99, 104, 101, 109, 97, 32, 109, 117, 115, 116, 32, 110, 111, 116, 32, 105, 109, 112, 111, 114, 116, 47, 105, 110, 99, 108, 117, 100, 101, 47, 114, 101, 100, 101, 102, 105, 110, 101, 32, 105, 116, 115, 101, 108, 102, 0, 0, 0, 0, 0, 0, 105, 110, 95, 109, 101, 109, 111, 114, 121, 95, 98, 117, 102, 102, 101, 114, 0, 0, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 115, 99, 104, 101, 109, 97, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 39, 37, 115, 39, 32, 99, 97, 110, 110, 111, 116, 32, 98, 101, 32, 105, 109, 112, 111, 114, 116, 101, 100, 44, 32, 115, 105, 110, 99, 101, 32, 105, 116, 32, 119, 97, 115, 32, 97, 108, 114, 101, 97, 100, 121, 32, 105, 110, 99, 108, 117, 100, 101, 100, 32, 111, 114, 32, 114, 101, 100, 101, 102, 105, 110, 101, 100, 0, 84, 104, 101, 32, 115, 99, 104, 101, 109, 97, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 39, 37, 115, 39, 32, 99, 97, 110, 110, 111, 116, 32, 98, 101, 32, 105, 110, 99, 108, 117, 100, 101, 100, 32, 111, 114, 32, 114, 101, 100, 101, 102, 105, 110, 101, 100, 44, 32, 115, 105, 110, 99, 101, 32, 105, 116, 32, 119, 97, 115, 32, 97, 108, 114, 101, 97, 100, 121, 32, 105, 109, 112, 111, 114, 116, 101, 100, 0, 83, 107, 105, 112, 112, 105, 110, 103, 32, 105, 109, 112, 111, 114, 116, 32, 111, 102, 32, 115, 99, 104, 101, 109, 97, 32, 108, 111, 99, 97, 116, 101, 100, 32, 97, 116, 32, 39, 37, 115, 39, 32, 102, 111, 114, 32, 116, 104, 101, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 39, 37, 115, 39, 44, 32, 115, 105, 110, 99, 101, 32, 116, 104, 105, 115, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 119, 97, 115, 32, 97, 108, 114, 101, 97, 100, 121, 32, 105, 109, 112, 111, 114, 116, 101, 100, 32, 119, 105, 116, 104, 32, 116, 104, 101, 32, 115, 99, 104, 101, 109, 97, 32, 108, 111, 99, 97, 116, 101, 100, 32, 97, 116, 32, 39, 37, 115, 39, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 65, 100, 100, 83, 99, 104, 101, 109, 97, 68, 111, 99, 0, 0, 0, 116, 114, 121, 105, 110, 103, 32, 116, 111, 32, 108, 111, 97, 100, 32, 97, 32, 115, 99, 104, 101, 109, 97, 32, 100, 111, 99, 44, 32, 98, 117, 116, 32, 97, 32, 100, 111, 99, 32, 105, 115, 32, 97, 108, 114, 101, 97, 100, 121, 32, 97, 115, 115, 105, 103, 110, 101, 100, 32, 116, 111, 32, 116, 104, 101, 32, 115, 99, 104, 101, 109, 97, 32, 98, 117, 99, 107, 101, 116, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 71, 101, 116, 68, 111, 99, 44, 32, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 97, 32, 112, 97, 114, 115, 101, 114, 32, 99, 111, 110, 116, 101, 120, 116, 0, 0, 0, 0, 70, 97, 105, 108, 101, 100, 32, 116, 111, 32, 112, 97, 114, 115, 101, 32, 116, 104, 101, 32, 88, 77, 76, 32, 114, 101, 115, 111, 117, 114, 99, 101, 32, 39, 37, 115, 39, 0, 0, 0, 78, 111, 32, 105, 110, 102, 111, 114, 109, 97, 116, 105, 111, 110, 32, 102, 111, 114, 32, 112, 97, 114, 115, 105, 110, 103, 32, 119, 97, 115, 32, 112, 114, 111, 118, 105, 100, 101, 100, 32, 119, 105, 116, 104, 32, 116, 104, 101, 32, 103, 105, 118, 101, 110, 32, 115, 99, 104, 101, 109, 97, 32, 112, 97, 114, 115, 101, 114, 32, 99, 111, 110, 116, 101, 120, 116, 46, 10, 0, 0, 84, 104, 101, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 39, 37, 115, 39, 32, 104, 97, 115, 32, 110, 111, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 101, 108, 101, 109, 101, 110, 116, 0, 0, 0, 0, 0, 0, 0, 115, 99, 104, 101, 109, 97, 0, 0, 84, 104, 101, 32, 88, 77, 76, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 115, 99, 104, 101, 109, 97, 32, 100, 111, 99, 117, 109, 101, 110, 116, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 66, 117, 99, 107, 101, 116, 67, 114, 101, 97, 116, 101, 0, 0, 0, 110, 111, 32, 109, 97, 105, 110, 32, 115, 99, 104, 101, 109, 97, 32, 111, 110, 32, 99, 111, 110, 115, 116, 114, 117, 99, 116, 111, 114, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 115, 99, 104, 101, 109, 97, 32, 98, 117, 99, 107, 101, 116, 0, 0, 0, 0, 0, 0, 0, 0, 102, 105, 114, 115, 116, 32, 98, 117, 99, 107, 101, 116, 32, 98, 117, 116, 32, 105, 116, 39, 115, 32, 97, 110, 32, 105, 110, 99, 108, 117, 100, 101, 32, 111, 114, 32, 114, 101, 100, 101, 102, 105, 110, 101, 0, 0, 0, 0, 109, 97, 105, 110, 32, 98, 117, 99, 107, 101, 116, 32, 98, 117, 116, 32, 105, 116, 39, 115, 32, 110, 111, 116, 32, 116, 104, 101, 32, 102, 105, 114, 115, 116, 32, 111, 110, 101, 0, 0, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 97, 100, 100, 32, 116, 104, 101, 32, 115, 99, 104, 101, 109, 97, 32, 98, 117, 99, 107, 101, 116, 32, 116, 111, 32, 116, 104, 101, 32, 104, 97, 115, 104, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 115, 99, 104, 101, 109, 97, 32, 114, 101, 108, 97, 116, 105, 111, 110, 0, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 115, 99, 104, 101, 109, 97, 32, 99, 111, 110, 115, 116, 114, 117, 99, 116, 105, 111, 110, 32, 99, 111, 110, 116, 101, 120, 116, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 108, 105, 115, 116, 32, 111, 102, 32, 115, 99, 104, 101, 109, 97, 32, 98, 117, 99, 107, 101, 116, 115, 0, 0, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 108, 105, 115, 116, 32, 111, 102, 32, 112, 101, 110, 100, 105, 110, 103, 32, 103, 108, 111, 98, 97, 108, 32, 99, 111, 109, 112, 111, 110, 101, 110, 116, 115, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 115, 99, 104, 101, 109, 97, 0, 0, 0, 0, 0, 0, 0, 40, 78, 85, 76, 76, 41, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 115, 99, 104, 101, 109, 97, 32, 112, 97, 114, 115, 101, 114, 32, 99, 111, 110, 116, 101, 120, 116, 0, 0, 0, 0, 0, 0, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 58, 32, 120, 109, 108, 83, 99, 104, 101, 109, 97, 67, 111, 109, 112, 111, 110, 101, 110, 116, 76, 105, 115, 116, 70, 114, 101, 101, 44, 32, 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 99, 111, 109, 112, 111, 110, 101, 110, 116, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 110, 121, 84, 121, 112, 101, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 109, 111, 100, 101, 108, 32, 103, 114, 111, 117, 112, 32, 99, 111, 109, 112, 111, 110, 101, 110, 116, 0, 0, 0, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 119, 105, 108, 100, 99, 97, 114, 100, 32, 99, 111, 109, 112, 111, 110, 101, 110, 116, 0, 0, 0, 99, 111, 117, 108, 100, 32, 110, 111, 116, 32, 99, 114, 101, 97, 116, 101, 32, 97, 110, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 119, 105, 108, 100, 99, 97, 114, 100, 32, 111, 110, 32, 97, 110, 121, 84, 121, 112, 101, 0, 0, 0, 0, 0, 0, 0, 97, 110, 121, 83, 105, 109, 112, 108, 101, 84, 121, 112, 101, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 115, 116, 114, 105, 110, 103, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 100, 101, 99, 105, 109, 97, 108, 0, 0, 0, 0, 0, 0, 0, 0, 0, 100, 97, 116, 101, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 100, 97, 116, 101, 84, 105, 109, 101, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 116, 105, 109, 101, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 103, 89, 101, 97, 114, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 103, 89, 101, 97, 114, 77, 111, 110, 116, 104, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 103, 77, 111, 110, 116, 104, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 103, 77, 111, 110, 116, 104, 68, 97, 121, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 103, 68, 97, 121, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 100, 117, 114, 97, 116, 105, 111, 110, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 102, 108, 111, 97, 116, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 100, 111, 117, 98, 108, 101, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 98, 111, 111, 108, 101, 97, 110, 0, 0, 0, 0, 0, 0, 0, 0, 0, 97, 110, 121, 85, 82, 73, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 104, 101, 120, 66, 105, 110, 97, 114, 121, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 98, 97, 115, 101, 54, 52, 66, 105, 110, 97, 114, 121, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 78, 79, 84, 65, 84, 73, 79, 78, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 81, 78, 97, 109, 101, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 105, 110, 116, 101, 103, 101, 114, 0, 0, 0, 0, 0, 0, 0, 0, 0, 110, 111, 110, 80, 111, 115, 105, 116, 105, 118, 101, 73, 110, 116, 101, 103, 101, 114, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 110, 101, 103, 97, 116, 105, 118, 101, 73, 110, 116, 101, 103, 101, 114, 0, 0, 0, 0, 0, 0, 0, 0, 0, 108, 111, 110, 103, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 105, 110, 116, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 115, 104, 111, 114, 116, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 98, 121, 116, 101, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 110, 111, 110, 78, 101, 103, 97, 116, 105, 118, 101, 73, 110, 116, 101, 103, 101, 114, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 117, 110, 115, 105, 103, 110, 101, 100, 76, 111, 110, 103, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 117, 110, 115, 105, 103, 110, 101, 100, 73, 110, 116, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 117, 110, 115, 105, 103, 110, 101, 100, 83, 104, 111, 114, 116, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 117, 110, 115, 105, 103, 110, 101, 100, 66, 121, 116, 101, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 112, 111, 115, 105, 116, 105, 118, 101, 73, 110, 116, 101, 103, 101, 114, 0, 0, 0, 0, 0, 0, 0, 0, 0, 110, 111, 114, 109, 97, 108, 105, 122, 101, 100, 83, 116, 114, 105, 110, 103, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 116, 111, 107, 101, 110, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 108, 97, 110, 103, 117, 97, 103, 101, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 78, 97, 109, 101, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 78, 77, 84, 79, 75, 69, 78, 0, 0, 0, 0, 0, 0, 0, 0, 0, 78, 67, 78, 97, 109, 101, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 73, 68, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 73, 68, 82, 69, 70, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 69, 78, 84, 73, 84, 89, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 69, 78, 84, 73, 84, 73, 69, 83, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 73, 68, 82, 69, 70, 83, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 78, 77, 84, 79, 75, 69, 78, 83, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 123, 0, 0, 0, 0, 0, 0, 0, 125, 0, 0, 0, 0, 0, 0, 0, 48, 46, 48, 0, 0, 0, 0, 0, 37, 108, 117, 37, 108, 117, 37, 108, 117, 0, 0, 0, 0, 0, 0, 0, 37, 108, 117, 37, 108, 117, 0, 0, 37, 108, 117, 0, 0, 0, 0, 0, 48, 0, 0, 0, 0, 0, 0, 0, 45, 37, 108, 117, 37, 108, 117, 37, 108, 117, 0, 0, 0, 0, 0, 0, 45, 37, 108, 117, 37, 108, 117, 0, 45, 37, 108, 117, 0, 0, 0, 0, 116, 114, 117, 101, 0, 0, 0, 0, 102, 97, 108, 115, 101, 0, 0, 0, 80, 37, 108, 117, 89, 37, 108, 117, 77, 37, 108, 117, 68, 84, 37, 108, 117, 72, 37, 108, 117, 77, 37, 46, 49, 52, 103, 83, 0, 0, 0, 0, 45, 80, 37, 108, 117, 89, 37, 108, 117, 77, 37, 108, 117, 68, 84, 37, 108, 117, 72, 37, 108, 117, 77, 37, 46, 49, 52, 103, 83, 0, 0, 0, 37, 48, 52, 108, 100, 0, 0, 0, 45, 45, 37, 48, 50, 117, 0, 0, 45, 45, 45, 37, 48, 50, 117, 0, 45, 45, 37, 48, 50, 117, 45, 37, 48, 50, 117, 0, 0, 0, 0, 0, 45, 37, 48, 52, 108, 100, 45, 37, 48, 50, 117, 0, 0, 0, 0, 0, 37, 48, 52, 108, 100, 45, 37, 48, 50, 117, 0, 0, 0, 0, 0, 0, 37, 48, 50, 117, 58, 37, 48, 50, 117, 58, 37, 48, 50, 46, 49, 52, 103, 90, 0, 0, 0, 0, 0, 0, 37, 48, 50, 117, 58, 37, 48, 50, 117, 58, 37, 48, 50, 46, 49, 52, 103, 0, 0, 0, 0, 0, 0, 0, 37, 48, 52, 108, 100, 58, 37, 48, 50, 117, 58, 37, 48, 50, 117, 90, 0, 0, 0, 0, 0, 0, 0, 0, 37, 48, 52, 108, 100, 58, 37, 48, 50, 117, 58, 37, 48, 50, 117, 0, 37, 48, 52, 108, 100, 58, 37, 48, 50, 117, 58, 37, 48, 50, 117, 84, 37, 48, 50, 117, 58, 37, 48, 50, 117, 58, 37, 48, 50, 46, 49, 52, 103, 90, 0, 0, 0, 0, 0, 0, 37, 48, 52, 108, 100, 58, 37, 48, 50, 117, 58, 37, 48, 50, 117, 84, 37, 48, 50, 117, 58, 37, 48, 50, 117, 58, 37, 48, 50, 46, 49, 52, 103, 0, 0, 0, 0, 0, 0, 0, 37, 48, 49, 46, 49, 52, 101, 0, 63, 63, 63, 0, 0, 0, 0, 0, 31, 0, 0, 0, 29, 0, 0, 0, 31, 0, 0, 0, 30, 0, 0, 0, 31, 0, 0, 0, 30, 0, 0, 0, 31, 0, 0, 0, 31, 0, 0, 0, 30, 0, 0, 0, 31, 0, 0, 0, 30, 0, 0, 0, 31, 0, 0, 0, 31, 0, 0, 0, 28, 0, 0, 0, 31, 0, 0, 0, 30, 0, 0, 0, 31, 0, 0, 0, 30, 0, 0, 0, 31, 0, 0, 0, 31, 0, 0, 0, 30, 0, 0, 0, 31, 0, 0, 0, 30, 0, 0, 0, 31, 0, 0, 0, 85, 110, 105, 109, 112, 108, 101, 109, 101, 110, 116, 101, 100, 32, 98, 108, 111, 99, 107, 32, 97, 116, 32, 37, 115, 58, 37, 100, 10, 0, 0, 0, 46, 46, 47, 108, 105, 98, 120, 109, 108, 50, 47, 120, 109, 108, 115, 99, 104, 101, 109, 97, 115, 116, 121, 112, 101, 115, 46, 99, 0, 0, 0, 0, 0, 0, 0, 0, 31, 0, 0, 0, 60, 0, 0, 0, 91, 0, 0, 0, 121, 0, 0, 0, 152, 0, 0, 0, 182, 0, 0, 0, 213, 0, 0, 0, 244, 0, 0, 0, 18, 1, 0, 0, 49, 1, 0, 0, 79, 1, 0, 0, 0, 0, 0, 0, 31, 0, 0, 0, 59, 0, 0, 0, 90, 0, 0, 0, 120, 0, 0, 0, 151, 0, 0, 0, 181, 0, 0, 0, 212, 0, 0, 0, 243, 0, 0, 0, 17, 1, 0, 0, 48, 1, 0, 0, 78, 1, 0, 0, 0, 0, 0, 0, 28, 0, 0, 0, 59, 0, 0, 0, 89, 0, 0, 0, 120, 0, 0, 0, 150, 0, 0, 0, 181, 0, 0, 0, 212, 0, 0, 0, 242, 0, 0, 0, 17, 1, 0, 0, 47, 1, 0, 0, 78, 1, 0, 0, 0, 0, 0, 0, 31, 0, 0, 0, 62, 0, 0, 0, 92, 0, 0, 0, 123, 0, 0, 0, 153, 0, 0, 0, 184, 0, 0, 0, 215, 0, 0, 0, 245, 0, 0, 0, 20, 1, 0, 0, 50, 1, 0, 0, 81, 1, 0, 0, 37, 102, 0, 0, 0, 0, 0, 0, 37, 108, 102, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 104, 101, 120, 98, 105, 110, 32, 100, 97, 116, 97, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 98, 97, 115, 101, 54, 52, 32, 100, 97, 116, 97, 0, 0, 89, 77, 68, 72, 77, 83, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 24, 245, 64, 0, 0, 0, 0, 0, 32, 172, 64, 0, 0, 0, 0, 0, 0, 78, 64, 0, 0, 0, 0, 0, 0, 240, 63, 0, 0, 0, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 112, 97, 114, 116, 105, 99, 108, 101, 32, 99, 111, 109, 112, 111, 110, 101, 110, 116, 0, 0, 0, 99, 111, 117, 108, 100, 32, 110, 111, 116, 32, 105, 110, 105, 116, 105, 97, 108, 105, 122, 101, 32, 98, 97, 115, 105, 99, 32, 116, 121, 112, 101, 115, 0, 0, 0, 0, 0, 0, 0, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 50, 48, 48, 49, 47, 88, 77, 76, 83, 99, 104, 101, 109, 97, 0, 0, 0, 0, 0, 0, 0, 0, 16, 206, 2, 0, 128, 0, 0, 0, 18, 0, 0, 0, 7, 0, 0, 0, 144, 205, 2, 0, 216, 205, 2, 0, 11, 0, 0, 0, 3, 0, 0, 0, 72, 205, 2, 0, 120, 205, 2, 0, 23, 1, 0, 0, 50, 0, 0, 0, 88, 199, 2, 0, 184, 203, 2, 0, 140, 1, 0, 0, 28, 0, 0, 0, 72, 192, 2, 0, 120, 198, 2, 0, 20, 0, 0, 0, 0, 0, 0, 0, 248, 191, 2, 0, 0, 0, 0, 0, 211, 0, 0, 0, 20, 0, 0, 0, 8, 188, 2, 0, 88, 191, 2, 0, 10, 0, 0, 0, 0, 0, 0, 0, 224, 187, 2, 0, 0, 0, 0, 0, 134, 1, 0, 0, 31, 0, 0, 0, 208, 180, 2, 0, 232, 186, 2, 0, 113, 0, 0, 0, 6, 0, 0, 0, 216, 178, 2, 0, 160, 180, 2, 0, 55, 0, 0, 0, 2, 0, 0, 0, 232, 177, 2, 0, 200, 178, 2, 0, 108, 0, 0, 0, 5, 0, 0, 0, 16, 176, 2, 0, 192, 177, 2, 0, 42, 0, 0, 0, 5, 0, 0, 0, 64, 175, 2, 0, 232, 175, 2, 0, 21, 0, 0, 0, 2, 0, 0, 0, 216, 174, 2, 0, 48, 175, 2, 0, 20, 0, 0, 0, 2, 0, 0, 0, 120, 174, 2, 0, 200, 174, 2, 0, 84, 0, 0, 0, 2, 0, 0, 0, 24, 173, 2, 0, 104, 174, 2, 0, 11, 0, 0, 0, 0, 0, 0, 0, 232, 172, 2, 0, 0, 0, 0, 0, 63, 0, 0, 0, 0, 0, 0, 0, 232, 171, 2, 0, 0, 0, 0, 0, 72, 0, 0, 0, 2, 0, 0, 0, 184, 170, 2, 0, 216, 171, 2, 0, 65, 0, 0, 0, 0, 0, 0, 0, 176, 169, 2, 0, 0, 0, 0, 0, 133, 0, 0, 0, 20, 0, 0, 0, 248, 166, 2, 0, 16, 169, 2, 0, 13, 0, 0, 0, 0, 0, 0, 0, 192, 166, 2, 0, 0, 0, 0, 0, 22, 0, 0, 0, 0, 0, 0, 0, 104, 166, 2, 0, 0, 0, 0, 0, 48, 0, 0, 0, 10, 0, 0, 0, 88, 165, 2, 0, 24, 166, 2, 0, 103, 0, 0, 0, 10, 0, 0, 0, 104, 163, 2, 0, 8, 165, 2, 0, 9, 0, 0, 0, 0, 0, 0, 0, 64, 163, 2, 0, 0, 0, 0, 0, 32, 0, 32, 0, 160, 0, 160, 0, 128, 22, 128, 22, 14, 24, 14, 24, 0, 32, 10, 32, 40, 32, 41, 32, 47, 32, 47, 32, 95, 32, 95, 32, 0, 48, 0, 48, 0, 0, 0, 0, 166, 0, 167, 0, 169, 0, 169, 0, 174, 0, 174, 0, 176, 0, 176, 0, 182, 0, 182, 0, 130, 4, 130, 4, 14, 6, 15, 6, 233, 6, 233, 6, 253, 6, 254, 6, 250, 9, 250, 9, 112, 11, 112, 11, 243, 11, 248, 11, 250, 11, 250, 11, 1, 15, 3, 15, 19, 15, 23, 15, 26, 15, 31, 15, 52, 15, 52, 15, 54, 15, 54, 15, 56, 15, 56, 15, 190, 15, 197, 15, 199, 15, 204, 15, 207, 15, 207, 15, 64, 25, 64, 25, 224, 25, 255, 25, 0, 33, 1, 33, 3, 33, 6, 33, 8, 33, 9, 33, 20, 33, 20, 33, 22, 33, 24, 33, 30, 33, 35, 33, 37, 33, 37, 33, 39, 33, 39, 33, 41, 33, 41, 33, 46, 33, 46, 33, 50, 33, 50, 33, 58, 33, 59, 33, 74, 33, 74, 33, 149, 33, 153, 33, 156, 33, 159, 33, 161, 33, 162, 33, 164, 33, 165, 33, 167, 33, 173, 33, 175, 33, 205, 33, 208, 33, 209, 33, 211, 33, 211, 33, 213, 33, 243, 33, 0, 35, 7, 35, 12, 35, 31, 35, 34, 35, 40, 35, 43, 35, 123, 35, 125, 35, 154, 35, 183, 35, 208, 35, 0, 36, 38, 36, 64, 36, 74, 36, 156, 36, 233, 36, 0, 37, 182, 37, 184, 37, 192, 37, 194, 37, 247, 37, 0, 38, 23, 38, 25, 38, 110, 38, 112, 38, 125, 38, 128, 38, 145, 38, 160, 38, 161, 38, 1, 39, 4, 39, 6, 39, 9, 39, 12, 39, 39, 39, 41, 39, 75, 39, 77, 39, 77, 39, 79, 39, 82, 39, 86, 39, 86, 39, 88, 39, 94, 39, 97, 39, 103, 39, 148, 39, 148, 39, 152, 39, 175, 39, 177, 39, 190, 39, 0, 40, 255, 40, 0, 43, 13, 43, 128, 46, 153, 46, 155, 46, 243, 46, 0, 47, 213, 47, 240, 47, 251, 47, 4, 48, 4, 48, 18, 48, 19, 48, 32, 48, 32, 48, 54, 48, 55, 48, 62, 48, 63, 48, 144, 49, 145, 49, 150, 49, 159, 49, 0, 50, 30, 50, 42, 50, 67, 50, 80, 50, 80, 50, 96, 50, 125, 50, 127, 50, 127, 50, 138, 50, 176, 50, 192, 50, 254, 50, 0, 51, 255, 51, 192, 77, 255, 77, 144, 164, 198, 164, 253, 253, 253, 253, 228, 255, 228, 255, 232, 255, 232, 255, 237, 255, 238, 255, 252, 255, 253, 255, 0, 0, 0, 0, 2, 1, 1, 0, 2, 1, 1, 0, 55, 1, 1, 0, 63, 1, 1, 0, 0, 208, 1, 0, 245, 208, 1, 0, 0, 209, 1, 0, 38, 209, 1, 0, 42, 209, 1, 0, 100, 209, 1, 0, 106, 209, 1, 0, 108, 209, 1, 0, 131, 209, 1, 0, 132, 209, 1, 0, 140, 209, 1, 0, 169, 209, 1, 0, 174, 209, 1, 0, 221, 209, 1, 0, 0, 211, 1, 0, 86, 211, 1, 0, 43, 0, 43, 0, 60, 0, 62, 0, 124, 0, 124, 0, 126, 0, 126, 0, 172, 0, 172, 0, 177, 0, 177, 0, 215, 0, 215, 0, 247, 0, 247, 0, 246, 3, 246, 3, 68, 32, 68, 32, 82, 32, 82, 32, 122, 32, 124, 32, 138, 32, 140, 32, 64, 33, 68, 33, 75, 33, 75, 33, 144, 33, 148, 33, 154, 33, 155, 33, 160, 33, 160, 33, 163, 33, 163, 33, 166, 33, 166, 33, 174, 33, 174, 33, 206, 33, 207, 33, 210, 33, 210, 33, 212, 33, 212, 33, 244, 33, 255, 34, 8, 35, 11, 35, 32, 35, 33, 35, 124, 35, 124, 35, 155, 35, 179, 35, 183, 37, 183, 37, 193, 37, 193, 37, 248, 37, 255, 37, 111, 38, 111, 38, 208, 39, 229, 39, 240, 39, 255, 39, 0, 41, 130, 41, 153, 41, 215, 41, 220, 41, 251, 41, 254, 41, 255, 42, 41, 251, 41, 251, 98, 254, 98, 254, 100, 254, 102, 254, 11, 255, 11, 255, 28, 255, 30, 255, 92, 255, 92, 255, 94, 255, 94, 255, 226, 255, 226, 255, 233, 255, 236, 255, 193, 214, 1, 0, 193, 214, 1, 0, 219, 214, 1, 0, 219, 214, 1, 0, 251, 214, 1, 0, 251, 214, 1, 0, 21, 215, 1, 0, 21, 215, 1, 0, 53, 215, 1, 0, 53, 215, 1, 0, 79, 215, 1, 0, 79, 215, 1, 0, 111, 215, 1, 0, 111, 215, 1, 0, 137, 215, 1, 0, 137, 215, 1, 0, 169, 215, 1, 0, 169, 215, 1, 0, 195, 215, 1, 0, 195, 215, 1, 0, 94, 0, 94, 0, 96, 0, 96, 0, 168, 0, 168, 0, 175, 0, 175, 0, 180, 0, 180, 0, 184, 0, 184, 0, 194, 2, 197, 2, 210, 2, 223, 2, 229, 2, 237, 2, 239, 2, 255, 2, 116, 3, 117, 3, 132, 3, 133, 3, 189, 31, 189, 31, 191, 31, 193, 31, 205, 31, 207, 31, 221, 31, 223, 31, 237, 31, 239, 31, 253, 31, 254, 31, 155, 48, 156, 48, 62, 255, 62, 255, 64, 255, 64, 255, 227, 255, 227, 255, 36, 0, 36, 0, 162, 0, 165, 0, 242, 9, 243, 9, 241, 10, 241, 10, 249, 11, 249, 11, 63, 14, 63, 14, 219, 23, 219, 23, 160, 32, 177, 32, 252, 253, 252, 253, 105, 254, 105, 254, 4, 255, 4, 255, 224, 255, 225, 255, 229, 255, 230, 255, 0, 0, 0, 0, 36, 0, 36, 0, 43, 0, 43, 0, 60, 0, 62, 0, 94, 0, 94, 0, 96, 0, 96, 0, 124, 0, 124, 0, 126, 0, 126, 0, 162, 0, 169, 0, 172, 0, 172, 0, 174, 0, 177, 0, 180, 0, 180, 0, 182, 0, 182, 0, 184, 0, 184, 0, 215, 0, 215, 0, 247, 0, 247, 0, 194, 2, 197, 2, 210, 2, 223, 2, 229, 2, 237, 2, 239, 2, 255, 2, 116, 3, 117, 3, 132, 3, 133, 3, 246, 3, 246, 3, 130, 4, 130, 4, 14, 6, 15, 6, 233, 6, 233, 6, 253, 6, 254, 6, 242, 9, 243, 9, 250, 9, 250, 9, 241, 10, 241, 10, 112, 11, 112, 11, 243, 11, 250, 11, 63, 14, 63, 14, 1, 15, 3, 15, 19, 15, 23, 15, 26, 15, 31, 15, 52, 15, 52, 15, 54, 15, 54, 15, 56, 15, 56, 15, 190, 15, 197, 15, 199, 15, 204, 15, 207, 15, 207, 15, 219, 23, 219, 23, 64, 25, 64, 25, 224, 25, 255, 25, 189, 31, 189, 31, 191, 31, 193, 31, 205, 31, 207, 31, 221, 31, 223, 31, 237, 31, 239, 31, 253, 31, 254, 31, 68, 32, 68, 32, 82, 32, 82, 32, 122, 32, 124, 32, 138, 32, 140, 32, 160, 32, 177, 32, 0, 33, 1, 33, 3, 33, 6, 33, 8, 33, 9, 33, 20, 33, 20, 33, 22, 33, 24, 33, 30, 33, 35, 33, 37, 33, 37, 33, 39, 33, 39, 33, 41, 33, 41, 33, 46, 33, 46, 33, 50, 33, 50, 33, 58, 33, 59, 33, 64, 33, 68, 33, 74, 33, 75, 33, 144, 33, 40, 35, 43, 35, 179, 35, 183, 35, 208, 35, 0, 36, 38, 36, 64, 36, 74, 36, 156, 36, 233, 36, 0, 37, 23, 38, 25, 38, 125, 38, 128, 38, 145, 38, 160, 38, 161, 38, 1, 39, 4, 39, 6, 39, 9, 39, 12, 39, 39, 39, 41, 39, 75, 39, 77, 39, 77, 39, 79, 39, 82, 39, 86, 39, 86, 39, 88, 39, 94, 39, 97, 39, 103, 39, 148, 39, 148, 39, 152, 39, 175, 39, 177, 39, 190, 39, 208, 39, 229, 39, 240, 39, 130, 41, 153, 41, 215, 41, 220, 41, 251, 41, 254, 41, 13, 43, 128, 46, 153, 46, 155, 46, 243, 46, 0, 47, 213, 47, 240, 47, 251, 47, 4, 48, 4, 48, 18, 48, 19, 48, 32, 48, 32, 48, 54, 48, 55, 48, 62, 48, 63, 48, 155, 48, 156, 48, 144, 49, 145, 49, 150, 49, 159, 49, 0, 50, 30, 50, 42, 50, 67, 50, 80, 50, 80, 50, 96, 50, 125, 50, 127, 50, 127, 50, 138, 50, 176, 50, 192, 50, 254, 50, 0, 51, 255, 51, 192, 77, 255, 77, 144, 164, 198, 164, 41, 251, 41, 251, 252, 253, 253, 253, 98, 254, 98, 254, 100, 254, 102, 254, 105, 254, 105, 254, 4, 255, 4, 255, 11, 255, 11, 255, 28, 255, 30, 255, 62, 255, 62, 255, 64, 255, 64, 255, 92, 255, 92, 255, 94, 255, 94, 255, 224, 255, 230, 255, 232, 255, 238, 255, 252, 255, 253, 255, 0, 0, 0, 0, 2, 1, 1, 0, 2, 1, 1, 0, 55, 1, 1, 0, 63, 1, 1, 0, 0, 208, 1, 0, 245, 208, 1, 0, 0, 209, 1, 0, 38, 209, 1, 0, 42, 209, 1, 0, 100, 209, 1, 0, 106, 209, 1, 0, 108, 209, 1, 0, 131, 209, 1, 0, 132, 209, 1, 0, 140, 209, 1, 0, 169, 209, 1, 0, 174, 209, 1, 0, 221, 209, 1, 0, 0, 211, 1, 0, 86, 211, 1, 0, 193, 214, 1, 0, 193, 214, 1, 0, 219, 214, 1, 0, 219, 214, 1, 0, 251, 214, 1, 0, 251, 214, 1, 0, 21, 215, 1, 0, 21, 215, 1, 0, 53, 215, 1, 0, 53, 215, 1, 0, 79, 215, 1, 0, 79, 215, 1, 0, 111, 215, 1, 0, 111, 215, 1, 0, 137, 215, 1, 0, 137, 215, 1, 0, 169, 215, 1, 0, 169, 215, 1, 0, 195, 215, 1, 0, 195, 215, 1, 0, 40, 0, 40, 0, 91, 0, 91, 0, 123, 0, 123, 0, 58, 15, 58, 15, 60, 15, 60, 15, 155, 22, 155, 22, 26, 32, 26, 32, 30, 32, 30, 32, 69, 32, 69, 32, 125, 32, 125, 32, 141, 32, 141, 32, 41, 35, 41, 35, 180, 35, 180, 35, 104, 39, 104, 39, 106, 39, 106, 39, 108, 39, 108, 39, 110, 39, 110, 39, 112, 39, 112, 39, 114, 39, 114, 39, 116, 39, 116, 39, 230, 39, 230, 39, 232, 39, 232, 39, 234, 39, 234, 39, 131, 41, 131, 41, 133, 41, 133, 41, 135, 41, 135, 41, 137, 41, 137, 41, 139, 41, 139, 41, 141, 41, 141, 41, 143, 41, 143, 41, 145, 41, 145, 41, 147, 41, 147, 41, 149, 41, 149, 41, 151, 41, 151, 41, 216, 41, 216, 41, 218, 41, 218, 41, 252, 41, 252, 41, 8, 48, 8, 48, 10, 48, 10, 48, 12, 48, 12, 48, 14, 48, 14, 48, 16, 48, 16, 48, 20, 48, 20, 48, 22, 48, 22, 48, 24, 48, 24, 48, 26, 48, 26, 48, 29, 48, 29, 48, 62, 253, 62, 253, 53, 254, 53, 254, 55, 254, 55, 254, 57, 254, 57, 254, 59, 254, 59, 254, 61, 254, 61, 254, 63, 254, 63, 254, 65, 254, 65, 254, 67, 254, 67, 254, 71, 254, 71, 254, 89, 254, 89, 254, 91, 254, 91, 254, 93, 254, 93, 254, 8, 255, 8, 255, 59, 255, 59, 255, 91, 255, 91, 255, 95, 255, 95, 255, 98, 255, 98, 255, 0, 0, 0, 0, 33, 0, 35, 0, 37, 0, 39, 0, 42, 0, 42, 0, 44, 0, 44, 0, 46, 0, 47, 0, 58, 0, 59, 0, 63, 0, 64, 0, 92, 0, 92, 0, 161, 0, 161, 0, 183, 0, 183, 0, 191, 0, 191, 0, 126, 3, 126, 3, 135, 3, 135, 3, 90, 5, 95, 5, 137, 5, 137, 5, 190, 5, 190, 5, 192, 5, 192, 5, 195, 5, 195, 5, 243, 5, 244, 5, 12, 6, 13, 6, 27, 6, 27, 6, 31, 6, 31, 6, 106, 6, 109, 6, 212, 6, 212, 6, 0, 7, 13, 7, 100, 9, 101, 9, 112, 9, 112, 9, 244, 13, 244, 13, 79, 14, 79, 14, 90, 14, 91, 14, 4, 15, 18, 15, 133, 15, 133, 15, 74, 16, 79, 16, 251, 16, 251, 16, 97, 19, 104, 19, 109, 22, 110, 22, 235, 22, 237, 22, 53, 23, 54, 23, 212, 23, 214, 23, 216, 23, 218, 23, 0, 24, 5, 24, 7, 24, 10, 24, 68, 25, 69, 25, 22, 32, 23, 32, 32, 32, 39, 32, 48, 32, 56, 32, 59, 32, 62, 32, 65, 32, 67, 32, 71, 32, 81, 32, 83, 32, 83, 32, 87, 32, 87, 32, 182, 35, 182, 35, 1, 48, 3, 48, 61, 48, 61, 48, 48, 254, 48, 254, 69, 254, 70, 254, 73, 254, 76, 254, 80, 254, 82, 254, 84, 254, 87, 254, 95, 254, 97, 254, 104, 254, 104, 254, 106, 254, 107, 254, 1, 255, 3, 255, 5, 255, 7, 255, 10, 255, 10, 255, 12, 255, 12, 255, 14, 255, 15, 255, 26, 255, 27, 255, 31, 255, 32, 255, 60, 255, 60, 255, 97, 255, 97, 255, 100, 255, 100, 255, 0, 1, 1, 0, 1, 1, 1, 0, 159, 3, 1, 0, 159, 3, 1, 0, 41, 0, 41, 0, 93, 0, 93, 0, 125, 0, 125, 0, 59, 15, 59, 15, 61, 15, 61, 15, 156, 22, 156, 22, 70, 32, 70, 32, 126, 32, 126, 32, 142, 32, 142, 32, 42, 35, 42, 35, 181, 35, 181, 35, 105, 39, 105, 39, 107, 39, 107, 39, 109, 39, 109, 39, 111, 39, 111, 39, 113, 39, 113, 39, 115, 39, 115, 39, 117, 39, 117, 39, 231, 39, 231, 39, 233, 39, 233, 39, 235, 39, 235, 39, 132, 41, 132, 41, 134, 41, 134, 41, 136, 41, 136, 41, 138, 41, 138, 41, 140, 41, 140, 41, 142, 41, 142, 41, 144, 41, 144, 41, 146, 41, 146, 41, 148, 41, 148, 41, 150, 41, 150, 41, 152, 41, 152, 41, 217, 41, 217, 41, 219, 41, 219, 41, 253, 41, 253, 41, 9, 48, 9, 48, 11, 48, 11, 48, 13, 48, 13, 48, 15, 48, 15, 48, 17, 48, 17, 48, 21, 48, 21, 48, 23, 48, 23, 48, 25, 48, 25, 48, 27, 48, 27, 48, 30, 48, 31, 48, 63, 253, 63, 253, 54, 254, 54, 254, 56, 254, 56, 254, 58, 254, 58, 254, 60, 254, 60, 254, 62, 254, 62, 254, 64, 254, 64, 254, 66, 254, 66, 254, 68, 254, 68, 254, 72, 254, 72, 254, 90, 254, 90, 254, 92, 254, 92, 254, 94, 254, 94, 254, 9, 255, 9, 255, 61, 255, 61, 255, 93, 255, 93, 255, 96, 255, 96, 255, 99, 255, 99, 255, 0, 0, 0, 0, 45, 0, 45, 0, 138, 5, 138, 5, 6, 24, 6, 24, 16, 32, 21, 32, 28, 48, 28, 48, 48, 48, 48, 48, 160, 48, 160, 48, 49, 254, 50, 254, 88, 254, 88, 254, 99, 254, 99, 254, 13, 255, 13, 255, 0, 0, 0, 0, 33, 0, 35, 0, 37, 0, 42, 0, 44, 0, 47, 0, 58, 0, 59, 0, 63, 0, 64, 0, 91, 0, 93, 0, 95, 0, 95, 0, 123, 0, 123, 0, 125, 0, 125, 0, 161, 0, 161, 0, 171, 0, 171, 0, 183, 0, 183, 0, 187, 0, 187, 0, 191, 0, 191, 0, 126, 3, 126, 3, 135, 3, 135, 3, 90, 5, 95, 5, 137, 5, 138, 5, 190, 5, 190, 5, 192, 5, 192, 5, 195, 5, 195, 5, 243, 5, 244, 5, 12, 6, 13, 6, 27, 6, 27, 6, 31, 6, 31, 6, 106, 6, 109, 6, 212, 6, 212, 6, 0, 7, 13, 7, 100, 9, 101, 9, 112, 9, 112, 9, 244, 13, 244, 13, 79, 14, 79, 14, 90, 14, 91, 14, 4, 15, 18, 15, 58, 15, 61, 15, 133, 15, 133, 15, 74, 16, 79, 16, 251, 16, 251, 16, 97, 19, 104, 19, 109, 22, 110, 22, 155, 22, 156, 22, 235, 22, 237, 22, 53, 23, 54, 23, 212, 23, 214, 23, 216, 23, 218, 23, 0, 24, 10, 24, 68, 25, 69, 25, 16, 32, 39, 32, 48, 32, 67, 32, 69, 32, 81, 32, 83, 32, 84, 32, 87, 32, 87, 32, 125, 32, 126, 32, 141, 32, 142, 32, 41, 35, 42, 35, 180, 35, 182, 35, 104, 39, 117, 39, 230, 39, 235, 39, 131, 41, 152, 41, 216, 41, 219, 41, 252, 41, 253, 41, 1, 48, 3, 48, 8, 48, 17, 48, 20, 48, 31, 48, 48, 48, 48, 48, 61, 48, 61, 48, 160, 48, 160, 48, 251, 48, 251, 48, 62, 253, 63, 253, 48, 254, 82, 254, 84, 254, 97, 254, 99, 254, 99, 254, 104, 254, 104, 254, 106, 254, 107, 254, 1, 255, 3, 255, 5, 255, 10, 255, 12, 255, 15, 255, 26, 255, 27, 255, 31, 255, 32, 255, 59, 255, 61, 255, 63, 255, 63, 255, 91, 255, 91, 255, 93, 255, 93, 255, 95, 255, 101, 255, 0, 1, 1, 0, 1, 1, 1, 0, 159, 3, 1, 0, 159, 3, 1, 0, 178, 0, 179, 0, 185, 0, 185, 0, 188, 0, 190, 0, 244, 9, 249, 9, 240, 11, 242, 11, 42, 15, 51, 15, 114, 19, 124, 19, 240, 23, 249, 23, 112, 32, 112, 32, 116, 32, 121, 32, 128, 32, 137, 32, 83, 33, 95, 33, 96, 36, 155, 36, 234, 36, 255, 36, 118, 39, 147, 39, 146, 49, 149, 49, 32, 50, 41, 50, 81, 50, 95, 50, 128, 50, 137, 50, 177, 50, 191, 50, 7, 1, 1, 0, 51, 1, 1, 0, 32, 3, 1, 0, 35, 3, 1, 0, 48, 0, 57, 0, 96, 6, 105, 6, 240, 6, 249, 6, 102, 9, 111, 9, 230, 9, 239, 9, 102, 10, 111, 10, 230, 10, 239, 10, 102, 11, 111, 11, 231, 11, 239, 11, 102, 12, 111, 12, 230, 12, 239, 12, 102, 13, 111, 13, 80, 14, 89, 14, 208, 14, 217, 14, 32, 15, 41, 15, 64, 16, 73, 16, 105, 19, 113, 19, 224, 23, 233, 23, 16, 24, 25, 24, 70, 25, 79, 25, 16, 255, 25, 255, 0, 0, 0, 0, 160, 4, 1, 0, 169, 4, 1, 0, 206, 215, 1, 0, 255, 215, 1, 0, 48, 0, 57, 0, 178, 0, 179, 0, 185, 0, 185, 0, 188, 0, 190, 0, 96, 6, 105, 6, 240, 6, 249, 6, 102, 9, 111, 9, 230, 9, 239, 9, 244, 9, 249, 9, 102, 10, 111, 10, 230, 10, 239, 10, 102, 11, 111, 11, 231, 11, 242, 11, 102, 12, 111, 12, 230, 12, 239, 12, 102, 13, 111, 13, 80, 14, 89, 14, 208, 14, 217, 14, 32, 15, 51, 15, 64, 16, 73, 16, 105, 19, 124, 19, 238, 22, 240, 22, 224, 23, 233, 23, 240, 23, 249, 23, 16, 24, 25, 24, 70, 25, 79, 25, 112, 32, 112, 32, 116, 32, 121, 32, 128, 32, 137, 32, 83, 33, 131, 33, 96, 36, 155, 36, 234, 36, 255, 36, 118, 39, 147, 39, 7, 48, 7, 48, 33, 48, 41, 48, 56, 48, 58, 48, 146, 49, 149, 49, 32, 50, 41, 50, 81, 50, 95, 50, 128, 50, 137, 50, 177, 50, 191, 50, 16, 255, 25, 255, 7, 1, 1, 0, 51, 1, 1, 0, 32, 3, 1, 0, 35, 3, 1, 0, 74, 3, 1, 0, 74, 3, 1, 0, 160, 4, 1, 0, 169, 4, 1, 0, 206, 215, 1, 0, 255, 215, 1, 0, 0, 3, 87, 3, 93, 3, 111, 3, 131, 4, 134, 4, 145, 5, 161, 5, 163, 5, 185, 5, 187, 5, 189, 5, 191, 5, 191, 5, 193, 5, 194, 5, 196, 5, 196, 5, 16, 6, 21, 6, 75, 6, 88, 6, 112, 6, 112, 6, 214, 6, 220, 6, 223, 6, 228, 6, 231, 6, 232, 6, 234, 6, 237, 6, 17, 7, 17, 7, 48, 7, 74, 7, 166, 7, 176, 7, 1, 9, 2, 9, 60, 9, 60, 9, 65, 9, 72, 9, 77, 9, 77, 9, 81, 9, 84, 9, 98, 9, 99, 9, 129, 9, 129, 9, 188, 9, 188, 9, 193, 9, 196, 9, 205, 9, 205, 9, 226, 9, 227, 9, 1, 10, 2, 10, 60, 10, 60, 10, 65, 10, 66, 10, 71, 10, 72, 10, 75, 10, 77, 10, 112, 10, 113, 10, 129, 10, 130, 10, 188, 10, 188, 10, 193, 10, 197, 10, 199, 10, 200, 10, 205, 10, 205, 10, 226, 10, 227, 10, 1, 11, 1, 11, 60, 11, 60, 11, 63, 11, 63, 11, 65, 11, 67, 11, 77, 11, 77, 11, 86, 11, 86, 11, 130, 11, 130, 11, 192, 11, 192, 11, 205, 11, 205, 11, 62, 12, 64, 12, 70, 12, 72, 12, 74, 12, 77, 12, 85, 12, 86, 12, 188, 12, 188, 12, 191, 12, 191, 12, 198, 12, 198, 12, 204, 12, 205, 12, 65, 13, 67, 13, 77, 13, 77, 13, 202, 13, 202, 13, 210, 13, 212, 13, 214, 13, 214, 13, 49, 14, 49, 14, 52, 14, 58, 14, 71, 14, 78, 14, 177, 14, 177, 14, 180, 14, 185, 14, 187, 14, 188, 14, 200, 14, 205, 14, 24, 15, 25, 15, 53, 15, 53, 15, 55, 15, 55, 15, 57, 15, 57, 15, 113, 15, 126, 15, 128, 15, 132, 15, 134, 15, 135, 15, 144, 15, 151, 15, 153, 15, 188, 15, 198, 15, 198, 15, 45, 16, 48, 16, 50, 16, 50, 16, 54, 16, 55, 16, 57, 16, 57, 16, 88, 16, 89, 16, 18, 23, 20, 23, 50, 23, 52, 23, 82, 23, 83, 23, 114, 23, 115, 23, 183, 23, 189, 23, 198, 23, 198, 23, 201, 23, 211, 23, 221, 23, 221, 23, 11, 24, 13, 24, 169, 24, 169, 24, 32, 25, 34, 25, 39, 25, 40, 25, 50, 25, 50, 25, 57, 25, 59, 25, 208, 32, 220, 32, 225, 32, 225, 32, 229, 32, 234, 32, 42, 48, 47, 48, 153, 48, 154, 48, 30, 251, 30, 251, 0, 254, 15, 254, 32, 254, 35, 254, 103, 209, 1, 0, 105, 209, 1, 0, 123, 209, 1, 0, 130, 209, 1, 0, 133, 209, 1, 0, 139, 209, 1, 0, 170, 209, 1, 0, 173, 209, 1, 0, 0, 1, 14, 0, 239, 1, 14, 0, 3, 9, 3, 9, 62, 9, 64, 9, 73, 9, 76, 9, 130, 9, 131, 9, 190, 9, 192, 9, 199, 9, 200, 9, 203, 9, 204, 9, 215, 9, 215, 9, 3, 10, 3, 10, 62, 10, 64, 10, 131, 10, 131, 10, 190, 10, 192, 10, 201, 10, 201, 10, 203, 10, 204, 10, 2, 11, 3, 11, 62, 11, 62, 11, 64, 11, 64, 11, 71, 11, 72, 11, 75, 11, 76, 11, 87, 11, 87, 11, 190, 11, 191, 11, 193, 11, 194, 11, 198, 11, 200, 11, 202, 11, 204, 11, 215, 11, 215, 11, 1, 12, 3, 12, 65, 12, 68, 12, 130, 12, 131, 12, 190, 12, 190, 12, 192, 12, 196, 12, 199, 12, 200, 12, 202, 12, 203, 12, 213, 12, 214, 12, 2, 13, 3, 13, 62, 13, 64, 13, 70, 13, 72, 13, 74, 13, 76, 13, 87, 13, 87, 13, 130, 13, 131, 13, 207, 13, 209, 13, 216, 13, 223, 13, 242, 13, 243, 13, 62, 15, 63, 15, 127, 15, 127, 15, 44, 16, 44, 16, 49, 16, 49, 16, 56, 16, 56, 16, 86, 16, 87, 16, 182, 23, 182, 23, 190, 23, 197, 23, 199, 23, 200, 23, 35, 25, 38, 25, 41, 25, 43, 25, 48, 25, 49, 25, 51, 25, 56, 25, 0, 0, 0, 0, 101, 209, 1, 0, 102, 209, 1, 0, 109, 209, 1, 0, 114, 209, 1, 0, 0, 3, 87, 3, 93, 3, 111, 3, 131, 4, 134, 4, 136, 4, 137, 4, 145, 5, 161, 5, 163, 5, 185, 5, 187, 5, 189, 5, 191, 5, 191, 5, 193, 5, 194, 5, 196, 5, 196, 5, 16, 6, 21, 6, 75, 6, 88, 6, 112, 6, 112, 6, 214, 6, 220, 6, 222, 6, 228, 6, 231, 6, 232, 6, 234, 6, 237, 6, 17, 7, 17, 7, 48, 7, 74, 7, 166, 7, 176, 7, 1, 9, 3, 9, 60, 9, 60, 9, 62, 9, 77, 9, 81, 9, 84, 9, 98, 9, 99, 9, 129, 9, 131, 9, 188, 9, 188, 9, 190, 9, 196, 9, 199, 9, 200, 9, 203, 9, 205, 9, 215, 9, 215, 9, 226, 9, 227, 9, 1, 10, 3, 10, 60, 10, 60, 10, 62, 10, 66, 10, 71, 10, 72, 10, 75, 10, 77, 10, 112, 10, 113, 10, 129, 10, 131, 10, 188, 10, 188, 10], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 166768);
	        allocate([190, 10, 197, 10, 199, 10, 201, 10, 203, 10, 205, 10, 226, 10, 227, 10, 1, 11, 3, 11, 60, 11, 60, 11, 62, 11, 67, 11, 71, 11, 72, 11, 75, 11, 77, 11, 86, 11, 87, 11, 130, 11, 130, 11, 190, 11, 194, 11, 198, 11, 200, 11, 202, 11, 205, 11, 215, 11, 215, 11, 1, 12, 3, 12, 62, 12, 68, 12, 70, 12, 72, 12, 74, 12, 77, 12, 85, 12, 86, 12, 130, 12, 131, 12, 188, 12, 188, 12, 190, 12, 196, 12, 198, 12, 200, 12, 202, 12, 205, 12, 213, 12, 214, 12, 2, 13, 3, 13, 62, 13, 67, 13, 70, 13, 72, 13, 74, 13, 77, 13, 87, 13, 87, 13, 130, 13, 131, 13, 202, 13, 202, 13, 207, 13, 212, 13, 214, 13, 214, 13, 216, 13, 223, 13, 242, 13, 243, 13, 49, 14, 49, 14, 52, 14, 58, 14, 71, 14, 78, 14, 177, 14, 177, 14, 180, 14, 185, 14, 187, 14, 188, 14, 200, 14, 205, 14, 24, 15, 25, 15, 53, 15, 53, 15, 55, 15, 55, 15, 57, 15, 57, 15, 62, 15, 63, 15, 113, 15, 132, 15, 134, 15, 135, 15, 144, 15, 151, 15, 153, 15, 188, 15, 198, 15, 198, 15, 44, 16, 50, 16, 54, 16, 57, 16, 86, 16, 89, 16, 18, 23, 20, 23, 50, 23, 52, 23, 82, 23, 83, 23, 114, 23, 115, 23, 182, 23, 211, 23, 221, 23, 221, 23, 11, 24, 13, 24, 169, 24, 169, 24, 32, 25, 43, 25, 48, 25, 59, 25, 208, 32, 234, 32, 42, 48, 47, 48, 153, 48, 154, 48, 30, 251, 30, 251, 0, 254, 15, 254, 32, 254, 35, 254, 0, 0, 0, 0, 101, 209, 1, 0, 105, 209, 1, 0, 109, 209, 1, 0, 114, 209, 1, 0, 123, 209, 1, 0, 130, 209, 1, 0, 133, 209, 1, 0, 139, 209, 1, 0, 170, 209, 1, 0, 173, 209, 1, 0, 0, 1, 14, 0, 239, 1, 14, 0, 65, 0, 90, 0, 192, 0, 214, 0, 216, 0, 222, 0, 0, 1, 0, 1, 2, 1, 2, 1, 4, 1, 4, 1, 6, 1, 6, 1, 8, 1, 8, 1, 10, 1, 10, 1, 12, 1, 12, 1, 14, 1, 14, 1, 16, 1, 16, 1, 18, 1, 18, 1, 20, 1, 20, 1, 22, 1, 22, 1, 24, 1, 24, 1, 26, 1, 26, 1, 28, 1, 28, 1, 30, 1, 30, 1, 32, 1, 32, 1, 34, 1, 34, 1, 36, 1, 36, 1, 38, 1, 38, 1, 40, 1, 40, 1, 42, 1, 42, 1, 44, 1, 44, 1, 46, 1, 46, 1, 48, 1, 48, 1, 50, 1, 50, 1, 52, 1, 52, 1, 54, 1, 54, 1, 57, 1, 57, 1, 59, 1, 59, 1, 61, 1, 61, 1, 63, 1, 63, 1, 65, 1, 65, 1, 67, 1, 67, 1, 69, 1, 69, 1, 71, 1, 71, 1, 74, 1, 74, 1, 76, 1, 76, 1, 78, 1, 78, 1, 80, 1, 80, 1, 82, 1, 82, 1, 84, 1, 84, 1, 86, 1, 86, 1, 88, 1, 88, 1, 90, 1, 90, 1, 92, 1, 92, 1, 94, 1, 94, 1, 96, 1, 96, 1, 98, 1, 98, 1, 100, 1, 100, 1, 102, 1, 102, 1, 104, 1, 104, 1, 106, 1, 106, 1, 108, 1, 108, 1, 110, 1, 110, 1, 112, 1, 112, 1, 114, 1, 114, 1, 116, 1, 116, 1, 118, 1, 118, 1, 120, 1, 121, 1, 123, 1, 123, 1, 125, 1, 125, 1, 129, 1, 130, 1, 132, 1, 132, 1, 134, 1, 135, 1, 137, 1, 139, 1, 142, 1, 145, 1, 147, 1, 148, 1, 150, 1, 152, 1, 156, 1, 157, 1, 159, 1, 160, 1, 162, 1, 162, 1, 164, 1, 164, 1, 166, 1, 167, 1, 169, 1, 169, 1, 172, 1, 172, 1, 174, 1, 175, 1, 177, 1, 179, 1, 181, 1, 181, 1, 183, 1, 184, 1, 188, 1, 188, 1, 196, 1, 196, 1, 199, 1, 199, 1, 202, 1, 202, 1, 205, 1, 205, 1, 207, 1, 207, 1, 209, 1, 209, 1, 211, 1, 211, 1, 213, 1, 213, 1, 215, 1, 215, 1, 217, 1, 217, 1, 219, 1, 219, 1, 222, 1, 222, 1, 224, 1, 224, 1, 226, 1, 226, 1, 228, 1, 228, 1, 230, 1, 230, 1, 232, 1, 232, 1, 234, 1, 234, 1, 236, 1, 236, 1, 238, 1, 238, 1, 241, 1, 241, 1, 244, 1, 244, 1, 246, 1, 248, 1, 250, 1, 250, 1, 252, 1, 252, 1, 254, 1, 254, 1, 0, 2, 0, 2, 2, 2, 2, 2, 4, 2, 4, 2, 6, 2, 6, 2, 8, 2, 8, 2, 10, 2, 10, 2, 12, 2, 12, 2, 14, 2, 14, 2, 16, 2, 16, 2, 18, 2, 18, 2, 20, 2, 20, 2, 22, 2, 22, 2, 24, 2, 24, 2, 26, 2, 26, 2, 28, 2, 28, 2, 30, 2, 30, 2, 32, 2, 32, 2, 34, 2, 34, 2, 36, 2, 36, 2, 38, 2, 38, 2, 40, 2, 40, 2, 42, 2, 42, 2, 44, 2, 44, 2, 46, 2, 46, 2, 48, 2, 48, 2, 50, 2, 50, 2, 134, 3, 134, 3, 136, 3, 138, 3, 140, 3, 140, 3, 142, 3, 143, 3, 145, 3, 161, 3, 163, 3, 171, 3, 210, 3, 212, 3, 216, 3, 216, 3, 218, 3, 218, 3, 220, 3, 220, 3, 222, 3, 222, 3, 224, 3, 224, 3, 226, 3, 226, 3, 228, 3, 228, 3, 230, 3, 230, 3, 232, 3, 232, 3, 234, 3, 234, 3, 236, 3, 236, 3, 238, 3, 238, 3, 244, 3, 244, 3, 247, 3, 247, 3, 249, 3, 250, 3, 0, 4, 47, 4, 96, 4, 96, 4, 98, 4, 98, 4, 100, 4, 100, 4, 102, 4, 102, 4, 104, 4, 104, 4, 106, 4, 106, 4, 108, 4, 108, 4, 110, 4, 110, 4, 112, 4, 112, 4, 114, 4, 114, 4, 116, 4, 116, 4, 118, 4, 118, 4, 120, 4, 120, 4, 122, 4, 122, 4, 124, 4, 124, 4, 126, 4, 126, 4, 128, 4, 128, 4, 138, 4, 138, 4, 140, 4, 140, 4, 142, 4, 142, 4, 144, 4, 144, 4, 146, 4, 146, 4, 148, 4, 148, 4, 150, 4, 150, 4, 152, 4, 152, 4, 154, 4, 154, 4, 156, 4, 156, 4, 158, 4, 158, 4, 160, 4, 160, 4, 162, 4, 162, 4, 164, 4, 164, 4, 166, 4, 166, 4, 168, 4, 168, 4, 170, 4, 170, 4, 172, 4, 172, 4, 174, 4, 174, 4, 176, 4, 176, 4, 178, 4, 178, 4, 180, 4, 180, 4, 182, 4, 182, 4, 184, 4, 184, 4, 186, 4, 186, 4, 188, 4, 188, 4, 190, 4, 190, 4, 192, 4, 193, 4, 195, 4, 195, 4, 197, 4, 197, 4, 199, 4, 199, 4, 201, 4, 201, 4, 203, 4, 203, 4, 205, 4, 205, 4, 208, 4, 208, 4, 210, 4, 210, 4, 212, 4, 212, 4, 214, 4, 214, 4, 216, 4, 216, 4, 218, 4, 218, 4, 220, 4, 220, 4, 222, 4, 222, 4, 224, 4, 224, 4, 226, 4, 226, 4, 228, 4, 228, 4, 230, 4, 230, 4, 232, 4, 232, 4, 234, 4, 234, 4, 236, 4, 236, 4, 238, 4, 238, 4, 240, 4, 240, 4, 242, 4, 242, 4, 244, 4, 244, 4, 248, 4, 248, 4, 0, 5, 0, 5, 2, 5, 2, 5, 4, 5, 4, 5, 6, 5, 6, 5, 8, 5, 8, 5, 10, 5, 10, 5, 12, 5, 12, 5, 14, 5, 14, 5, 49, 5, 86, 5, 160, 16, 197, 16, 0, 30, 0, 30, 2, 30, 2, 30, 4, 30, 4, 30, 6, 30, 6, 30, 8, 30, 8, 30, 10, 30, 10, 30, 12, 30, 12, 30, 14, 30, 14, 30, 16, 30, 16, 30, 18, 30, 18, 30, 20, 30, 20, 30, 22, 30, 22, 30, 24, 30, 24, 30, 26, 30, 26, 30, 28, 30, 28, 30, 30, 30, 30, 30, 32, 30, 32, 30, 34, 30, 34, 30, 36, 30, 36, 30, 38, 30, 38, 30, 40, 30, 40, 30, 42, 30, 42, 30, 44, 30, 44, 30, 46, 30, 46, 30, 48, 30, 48, 30, 50, 30, 50, 30, 52, 30, 52, 30, 54, 30, 54, 30, 56, 30, 56, 30, 58, 30, 58, 30, 60, 30, 60, 30, 62, 30, 62, 30, 64, 30, 64, 30, 66, 30, 66, 30, 68, 30, 68, 30, 70, 30, 70, 30, 72, 30, 72, 30, 74, 30, 74, 30, 76, 30, 76, 30, 78, 30, 78, 30, 80, 30, 80, 30, 82, 30, 82, 30, 84, 30, 84, 30, 86, 30, 86, 30, 88, 30, 88, 30, 90, 30, 90, 30, 92, 30, 92, 30, 94, 30, 94, 30, 96, 30, 96, 30, 98, 30, 98, 30, 100, 30, 100, 30, 102, 30, 102, 30, 104, 30, 104, 30, 106, 30, 106, 30, 108, 30, 108, 30, 110, 30, 110, 30, 112, 30, 112, 30, 114, 30, 114, 30, 116, 30, 116, 30, 118, 30, 118, 30, 120, 30, 120, 30, 122, 30, 122, 30, 124, 30, 124, 30, 126, 30, 126, 30, 128, 30, 128, 30, 130, 30, 130, 30, 132, 30, 132, 30, 134, 30, 134, 30, 136, 30, 136, 30, 138, 30, 138, 30, 140, 30, 140, 30, 142, 30, 142, 30, 144, 30, 144, 30, 146, 30, 146, 30, 148, 30, 148, 30, 160, 30, 160, 30, 162, 30, 162, 30, 164, 30, 164, 30, 166, 30, 166, 30, 168, 30, 168, 30, 170, 30, 170, 30, 172, 30, 172, 30, 174, 30, 174, 30, 176, 30, 176, 30, 178, 30, 178, 30, 180, 30, 180, 30, 182, 30, 182, 30, 184, 30, 184, 30, 186, 30, 186, 30, 188, 30, 188, 30, 190, 30, 190, 30, 192, 30, 192, 30, 194, 30, 194, 30, 196, 30, 196, 30, 198, 30, 198, 30, 200, 30, 200, 30, 202, 30, 202, 30, 204, 30, 204, 30, 206, 30, 206, 30, 208, 30, 208, 30, 210, 30, 210, 30, 212, 30, 212, 30, 214, 30, 214, 30, 216, 30, 216, 30, 218, 30, 218, 30, 220, 30, 220, 30, 222, 30, 222, 30, 224, 30, 224, 30, 226, 30, 226, 30, 228, 30, 228, 30, 230, 30, 230, 30, 232, 30, 232, 30, 234, 30, 234, 30, 236, 30, 236, 30, 238, 30, 238, 30, 240, 30, 240, 30, 242, 30, 242, 30, 244, 30, 244, 30, 246, 30, 246, 30, 248, 30, 248, 30, 8, 31, 15, 31, 24, 31, 29, 31, 40, 31, 47, 31, 56, 31, 63, 31, 72, 31, 77, 31, 89, 31, 89, 31, 91, 31, 91, 31, 93, 31, 93, 31, 95, 31, 95, 31, 104, 31, 111, 31, 184, 31, 187, 31, 200, 31, 203, 31, 216, 31, 219, 31, 232, 31, 236, 31, 248, 31, 251, 31, 2, 33, 2, 33, 7, 33, 7, 33, 11, 33, 13, 33, 16, 33, 18, 33, 21, 33, 21, 33, 25, 33, 29, 33, 36, 33, 36, 33, 38, 33, 38, 33, 40, 33, 40, 33, 42, 33, 45, 33, 48, 33, 49, 33, 51, 33, 51, 33, 62, 33, 63, 33, 69, 33, 69, 33, 33, 255, 58, 255, 0, 4, 1, 0, 39, 4, 1, 0, 0, 212, 1, 0, 25, 212, 1, 0, 52, 212, 1, 0, 77, 212, 1, 0, 104, 212, 1, 0, 129, 212, 1, 0, 156, 212, 1, 0, 156, 212, 1, 0, 158, 212, 1, 0, 159, 212, 1, 0, 162, 212, 1, 0, 162, 212, 1, 0, 165, 212, 1, 0, 166, 212, 1, 0, 169, 212, 1, 0, 172, 212, 1, 0, 174, 212, 1, 0, 181, 212, 1, 0, 208, 212, 1, 0, 233, 212, 1, 0, 4, 213, 1, 0, 5, 213, 1, 0, 7, 213, 1, 0, 10, 213, 1, 0, 13, 213, 1, 0, 20, 213, 1, 0, 22, 213, 1, 0, 28, 213, 1, 0, 56, 213, 1, 0, 57, 213, 1, 0, 59, 213, 1, 0, 62, 213, 1, 0, 64, 213, 1, 0, 68, 213, 1, 0, 70, 213, 1, 0, 70, 213, 1, 0, 74, 213, 1, 0, 80, 213, 1, 0, 108, 213, 1, 0, 133, 213, 1, 0, 160, 213, 1, 0, 185, 213, 1, 0, 212, 213, 1, 0, 237, 213, 1, 0, 8, 214, 1, 0, 33, 214, 1, 0, 60, 214, 1, 0, 85, 214, 1, 0, 112, 214, 1, 0, 137, 214, 1, 0, 168, 214, 1, 0, 192, 214, 1, 0, 226, 214, 1, 0, 250, 214, 1, 0, 28, 215, 1, 0, 52, 215, 1, 0, 86, 215, 1, 0, 110, 215, 1, 0, 144, 215, 1, 0, 168, 215, 1, 0, 197, 1, 197, 1, 200, 1, 200, 1, 203, 1, 203, 1, 242, 1, 242, 1, 136, 31, 143, 31, 152, 31, 159, 31, 168, 31, 175, 31, 188, 31, 188, 31, 204, 31, 204, 31, 252, 31, 252, 31, 187, 1, 187, 1, 192, 1, 195, 1, 208, 5, 234, 5, 240, 5, 242, 5, 33, 6, 58, 6, 65, 6, 74, 6, 110, 6, 111, 6, 113, 6, 211, 6, 213, 6, 213, 6, 238, 6, 239, 6, 250, 6, 252, 6, 255, 6, 255, 6, 16, 7, 16, 7, 18, 7, 47, 7, 77, 7, 79, 7, 128, 7, 165, 7, 177, 7, 177, 7, 4, 9, 57, 9, 61, 9, 61, 9, 80, 9, 80, 9, 88, 9, 97, 9, 133, 9, 140, 9, 143, 9, 144, 9, 147, 9, 168, 9, 170, 9, 176, 9, 178, 9, 178, 9, 182, 9, 185, 9, 189, 9, 189, 9, 220, 9, 221, 9, 223, 9, 225, 9, 240, 9, 241, 9, 5, 10, 10, 10, 15, 10, 16, 10, 19, 10, 40, 10, 42, 10, 48, 10, 50, 10, 51, 10, 53, 10, 54, 10, 56, 10, 57, 10, 89, 10, 92, 10, 94, 10, 94, 10, 114, 10, 116, 10, 133, 10, 141, 10, 143, 10, 145, 10, 147, 10, 168, 10, 170, 10, 176, 10, 178, 10, 179, 10, 181, 10, 185, 10, 189, 10, 189, 10, 208, 10, 208, 10, 224, 10, 225, 10, 5, 11, 12, 11, 15, 11, 16, 11, 19, 11, 40, 11, 42, 11, 48, 11, 50, 11, 51, 11, 53, 11, 57, 11, 61, 11, 61, 11, 92, 11, 93, 11, 95, 11, 97, 11, 113, 11, 113, 11, 131, 11, 131, 11, 133, 11, 138, 11, 142, 11, 144, 11, 146, 11, 149, 11, 153, 11, 154, 11, 156, 11, 156, 11, 158, 11, 159, 11, 163, 11, 164, 11, 168, 11, 170, 11, 174, 11, 181, 11, 183, 11, 185, 11, 5, 12, 12, 12, 14, 12, 16, 12, 18, 12, 40, 12, 42, 12, 51, 12, 53, 12, 57, 12, 96, 12, 97, 12, 133, 12, 140, 12, 142, 12, 144, 12, 146, 12, 168, 12, 170, 12, 179, 12, 181, 12, 185, 12, 189, 12, 189, 12, 222, 12, 222, 12, 224, 12, 225, 12, 5, 13, 12, 13, 14, 13, 16, 13, 18, 13, 40, 13, 42, 13, 57, 13, 96, 13, 97, 13, 133, 13, 150, 13, 154, 13, 177, 13, 179, 13, 187, 13, 189, 13, 189, 13, 192, 13, 198, 13, 1, 14, 48, 14, 50, 14, 51, 14, 64, 14, 69, 14, 129, 14, 130, 14, 132, 14, 132, 14, 135, 14, 136, 14, 138, 14, 138, 14, 141, 14, 141, 14, 148, 14, 151, 14, 153, 14, 159, 14, 161, 14, 163, 14, 165, 14, 165, 14, 167, 14, 167, 14, 170, 14, 171, 14, 173, 14, 176, 14, 178, 14, 179, 14, 189, 14, 189, 14, 192, 14, 196, 14, 220, 14, 221, 14, 0, 15, 0, 15, 64, 15, 71, 15, 73, 15, 106, 15, 136, 15, 139, 15, 0, 16, 33, 16, 35, 16, 39, 16, 41, 16, 42, 16, 80, 16, 85, 16, 208, 16, 248, 16, 0, 17, 89, 17, 95, 17, 162, 17, 168, 17, 249, 17, 0, 18, 6, 18, 8, 18, 70, 18, 72, 18, 72, 18, 74, 18, 77, 18, 80, 18, 86, 18, 88, 18, 88, 18, 90, 18, 93, 18, 96, 18, 134, 18, 136, 18, 136, 18, 138, 18, 141, 18, 144, 18, 174, 18, 176, 18, 176, 18, 178, 18, 181, 18, 184, 18, 190, 18, 192, 18, 192, 18, 194, 18, 197, 18, 200, 18, 206, 18, 208, 18, 214, 18, 216, 18, 238, 18, 240, 18, 14, 19, 16, 19, 16, 19, 18, 19, 21, 19, 24, 19, 30, 19, 32, 19, 70, 19, 72, 19, 90, 19, 160, 19, 244, 19, 1, 20, 108, 22, 111, 22, 118, 22, 129, 22, 154, 22, 160, 22, 234, 22, 0, 23, 12, 23, 14, 23, 17, 23, 32, 23, 49, 23, 64, 23, 81, 23, 96, 23, 108, 23, 110, 23, 112, 23, 128, 23, 179, 23, 220, 23, 220, 23, 32, 24, 66, 24, 68, 24, 119, 24, 128, 24, 168, 24, 0, 25, 28, 25, 80, 25, 109, 25, 112, 25, 116, 25, 53, 33, 56, 33, 6, 48, 6, 48, 60, 48, 60, 48, 65, 48, 150, 48, 159, 48, 159, 48, 161, 48, 250, 48, 255, 48, 255, 48, 5, 49, 44, 49, 49, 49, 142, 49, 160, 49, 183, 49, 240, 49, 255, 49, 0, 52, 0, 52, 181, 77, 181, 77, 0, 78, 0, 78, 165, 159, 165, 159, 0, 160, 140, 164, 0, 172, 0, 172, 163, 215, 163, 215, 0, 249, 45, 250, 48, 250, 106, 250, 29, 251, 29, 251, 31, 251, 40, 251, 42, 251, 54, 251, 56, 251, 60, 251, 62, 251, 62, 251, 64, 251, 65, 251, 67, 251, 68, 251, 70, 251, 177, 251, 211, 251, 61, 253, 80, 253, 143, 253, 146, 253, 199, 253, 240, 253, 251, 253, 112, 254, 116, 254, 118, 254, 252, 254, 102, 255, 111, 255, 113, 255, 157, 255, 160, 255, 190, 255, 194, 255, 199, 255, 202, 255, 207, 255, 210, 255, 215, 255, 218, 255, 220, 255, 0, 0, 0, 0, 0, 0, 1, 0, 11, 0, 1, 0, 13, 0, 1, 0, 38, 0, 1, 0, 40, 0, 1, 0, 58, 0, 1, 0, 60, 0, 1, 0, 61, 0, 1, 0, 63, 0, 1, 0, 77, 0, 1, 0, 80, 0, 1, 0, 93, 0, 1, 0, 128, 0, 1, 0, 250, 0, 1, 0, 0, 3, 1, 0, 30, 3, 1, 0, 48, 3, 1, 0, 73, 3, 1, 0, 128, 3, 1, 0, 157, 3, 1, 0, 80, 4, 1, 0, 157, 4, 1, 0, 0, 8, 1, 0, 5, 8, 1, 0, 8, 8, 1, 0, 8, 8, 1, 0, 10, 8, 1, 0, 53, 8, 1, 0, 55, 8, 1, 0, 56, 8, 1, 0, 60, 8, 1, 0, 60, 8, 1, 0, 63, 8, 1, 0, 63, 8, 1, 0, 0, 0, 2, 0, 0, 0, 2, 0, 214, 166, 2, 0, 214, 166, 2, 0, 0, 248, 2, 0, 29, 250, 2, 0, 176, 2, 193, 2, 198, 2, 209, 2, 224, 2, 228, 2, 238, 2, 238, 2, 122, 3, 122, 3, 89, 5, 89, 5, 64, 6, 64, 6, 229, 6, 230, 6, 70, 14, 70, 14, 198, 14, 198, 14, 215, 23, 215, 23, 67, 24, 67, 24, 44, 29, 97, 29, 5, 48, 5, 48, 49, 48, 53, 48, 59, 48, 59, 48, 157, 48, 158, 48, 252, 48, 254, 48, 112, 255, 112, 255, 158, 255, 159, 255, 97, 0, 122, 0, 170, 0, 170, 0, 181, 0, 181, 0, 186, 0, 186, 0, 223, 0, 246, 0, 248, 0, 255, 0, 1, 1, 1, 1, 3, 1, 3, 1, 5, 1, 5, 1, 7, 1, 7, 1, 9, 1, 9, 1, 11, 1, 11, 1, 13, 1, 13, 1, 15, 1, 15, 1, 17, 1, 17, 1, 19, 1, 19, 1, 21, 1, 21, 1, 23, 1, 23, 1, 25, 1, 25, 1, 27, 1, 27, 1, 29, 1, 29, 1, 31, 1, 31, 1, 33, 1, 33, 1, 35, 1, 35, 1, 37, 1, 37, 1, 39, 1, 39, 1, 41, 1, 41, 1, 43, 1, 43, 1, 45, 1, 45, 1, 47, 1, 47, 1, 49, 1, 49, 1, 51, 1, 51, 1, 53, 1, 53, 1, 55, 1, 56, 1, 58, 1, 58, 1, 60, 1, 60, 1, 62, 1, 62, 1, 64, 1, 64, 1, 66, 1, 66, 1, 68, 1, 68, 1, 70, 1, 70, 1, 72, 1, 73, 1, 75, 1, 75, 1, 77, 1, 77, 1, 79, 1, 79, 1, 81, 1, 81, 1, 83, 1, 83, 1, 85, 1, 85, 1, 87, 1, 87, 1, 89, 1, 89, 1, 91, 1, 91, 1, 93, 1, 93, 1, 95, 1, 95, 1, 97, 1, 97, 1, 99, 1, 99, 1, 101, 1, 101, 1, 103, 1, 103, 1, 105, 1, 105, 1, 107, 1, 107, 1, 109, 1, 109, 1, 111, 1, 111, 1, 113, 1, 113, 1, 115, 1, 115, 1, 117, 1, 117, 1, 119, 1, 119, 1, 122, 1, 122, 1, 124, 1, 124, 1, 126, 1, 128, 1, 131, 1, 131, 1, 133, 1, 133, 1, 136, 1, 136, 1, 140, 1, 141, 1, 146, 1, 146, 1, 149, 1, 149, 1, 153, 1, 155, 1, 158, 1, 158, 1, 161, 1, 161, 1, 163, 1, 163, 1, 165, 1, 165, 1, 168, 1, 168, 1, 170, 1, 171, 1, 173, 1, 173, 1, 176, 1, 176, 1, 180, 1, 180, 1, 182, 1, 182, 1, 185, 1, 186, 1, 189, 1, 191, 1, 198, 1, 198, 1, 201, 1, 201, 1, 204, 1, 204, 1, 206, 1, 206, 1, 208, 1, 208, 1, 210, 1, 210, 1, 212, 1, 212, 1, 214, 1, 214, 1, 216, 1, 216, 1, 218, 1, 218, 1, 220, 1, 221, 1, 223, 1, 223, 1, 225, 1, 225, 1, 227, 1, 227, 1, 229, 1, 229, 1, 231, 1, 231, 1, 233, 1, 233, 1, 235, 1, 235, 1, 237, 1, 237, 1, 239, 1, 240, 1, 243, 1, 243, 1, 245, 1, 245, 1, 249, 1, 249, 1, 251, 1, 251, 1, 253, 1, 253, 1, 255, 1, 255, 1, 1, 2, 1, 2, 3, 2, 3, 2, 5, 2, 5, 2, 7, 2, 7, 2, 9, 2, 9, 2, 11, 2, 11, 2, 13, 2, 13, 2, 15, 2, 15, 2, 17, 2, 17, 2, 19, 2, 19, 2, 21, 2, 21, 2, 23, 2, 23, 2, 25, 2, 25, 2, 27, 2, 27, 2, 29, 2, 29, 2, 31, 2, 31, 2, 33, 2, 33, 2, 35, 2, 35, 2, 37, 2, 37, 2, 39, 2, 39, 2, 41, 2, 41, 2, 43, 2, 43, 2, 45, 2, 45, 2, 47, 2, 47, 2, 49, 2, 49, 2, 51, 2, 54, 2, 80, 2, 175, 2, 144, 3, 144, 3, 172, 3, 206, 3, 208, 3, 209, 3, 213, 3, 215, 3, 217, 3, 217, 3, 219, 3, 219, 3, 221, 3, 221, 3, 223, 3, 223, 3, 225, 3, 225, 3, 227, 3, 227, 3, 229, 3, 229, 3, 231, 3, 231, 3, 233, 3, 233, 3, 235, 3, 235, 3, 237, 3, 237, 3, 239, 3, 243, 3, 245, 3, 245, 3, 248, 3, 248, 3, 251, 3, 251, 3, 48, 4, 95, 4, 97, 4, 97, 4, 99, 4, 99, 4, 101, 4, 101, 4, 103, 4, 103, 4, 105, 4, 105, 4, 107, 4, 107, 4, 109, 4, 109, 4, 111, 4, 111, 4, 113, 4, 113, 4, 115, 4, 115, 4, 117, 4, 117, 4, 119, 4, 119, 4, 121, 4, 121, 4, 123, 4, 123, 4, 125, 4, 125, 4, 127, 4, 127, 4, 129, 4, 129, 4, 139, 4, 139, 4, 141, 4, 141, 4, 143, 4, 143, 4, 145, 4, 145, 4, 147, 4, 147, 4, 149, 4, 149, 4, 151, 4, 151, 4, 153, 4, 153, 4, 155, 4, 155, 4, 157, 4, 157, 4, 159, 4, 159, 4, 161, 4, 161, 4, 163, 4, 163, 4, 165, 4, 165, 4, 167, 4, 167, 4, 169, 4, 169, 4, 171, 4, 171, 4, 173, 4, 173, 4, 175, 4, 175, 4, 177, 4, 177, 4, 179, 4, 179, 4, 181, 4, 181, 4, 183, 4, 183, 4, 185, 4, 185, 4, 187, 4, 187, 4, 189, 4, 189, 4, 191, 4, 191, 4, 194, 4, 194, 4, 196, 4, 196, 4, 198, 4, 198, 4, 200, 4, 200, 4, 202, 4, 202, 4, 204, 4, 204, 4, 206, 4, 206, 4, 209, 4, 209, 4, 211, 4, 211, 4, 213, 4, 213, 4, 215, 4, 215, 4, 217, 4, 217, 4, 219, 4, 219, 4, 221, 4, 221, 4, 223, 4, 223, 4, 225, 4, 225, 4, 227, 4, 227, 4, 229, 4, 229, 4, 231, 4, 231, 4, 233, 4, 233, 4, 235, 4, 235, 4, 237, 4, 237, 4, 239, 4, 239, 4, 241, 4, 241, 4, 243, 4, 243, 4, 245, 4, 245, 4, 249, 4, 249, 4, 1, 5, 1, 5, 3, 5, 3, 5, 5, 5, 5, 5, 7, 5, 7, 5, 9, 5, 9, 5, 11, 5, 11, 5, 13, 5, 13, 5, 15, 5, 15, 5, 97, 5, 135, 5, 0, 29, 43, 29, 98, 29, 107, 29, 1, 30, 1, 30, 3, 30, 3, 30, 5, 30, 5, 30, 7, 30, 7, 30, 9, 30, 9, 30, 11, 30, 11, 30, 13, 30, 13, 30, 15, 30, 15, 30, 17, 30, 17, 30, 19, 30, 19, 30, 21, 30, 21, 30, 23, 30, 23, 30, 25, 30, 25, 30, 27, 30, 27, 30, 29, 30, 29, 30, 31, 30, 31, 30, 33, 30, 33, 30, 35, 30, 35, 30, 37, 30, 37, 30, 39, 30, 39, 30, 41, 30, 41, 30, 43, 30, 43, 30, 45, 30, 45, 30, 47, 30, 47, 30, 49, 30, 49, 30, 51, 30, 51, 30, 53, 30, 53, 30, 55, 30, 55, 30, 57, 30, 57, 30, 59, 30, 59, 30, 61, 30, 61, 30, 63, 30, 63, 30, 65, 30, 65, 30, 67, 30, 67, 30, 69, 30, 69, 30, 71, 30, 71, 30, 73, 30, 73, 30, 75, 30, 75, 30, 77, 30, 77, 30, 79, 30, 79, 30, 81, 30, 81, 30, 83, 30, 83, 30, 85, 30, 85, 30, 87, 30, 87, 30, 89, 30, 89, 30, 91, 30, 91, 30, 93, 30, 93, 30, 95, 30, 95, 30, 97, 30, 97, 30, 99, 30, 99, 30, 101, 30, 101, 30, 103, 30, 103, 30, 105, 30, 105, 30, 107, 30, 107, 30, 109, 30, 109, 30, 111, 30, 111, 30, 113, 30, 113, 30, 115, 30, 115, 30, 117, 30, 117, 30, 119, 30, 119, 30, 121, 30, 121, 30, 123, 30, 123, 30, 125, 30, 125, 30, 127, 30, 127, 30, 129, 30, 129, 30, 131, 30, 131, 30, 133, 30, 133, 30, 135, 30, 135, 30, 137, 30, 137, 30, 139, 30, 139, 30, 141, 30, 141, 30, 143, 30, 143, 30, 145, 30, 145, 30, 147, 30, 147, 30, 149, 30, 155, 30, 161, 30, 161, 30, 163, 30, 163, 30, 165, 30, 165, 30, 167, 30, 167, 30, 169, 30, 169, 30, 171, 30, 171, 30, 173, 30, 173, 30, 175, 30, 175, 30, 177, 30, 177, 30, 179, 30, 179, 30, 181, 30, 181, 30, 183, 30, 183, 30, 185, 30, 185, 30, 187, 30, 187, 30, 189, 30, 189, 30, 191, 30, 191, 30, 193, 30, 193, 30, 195, 30, 195, 30, 197, 30, 197, 30, 199, 30, 199, 30, 201, 30, 201, 30, 203, 30, 203, 30, 205, 30, 205, 30, 207, 30, 207, 30, 209, 30, 209, 30, 211, 30, 211, 30, 213, 30, 213, 30, 215, 30, 215, 30, 217, 30, 217, 30, 219, 30, 219, 30, 221, 30, 221, 30, 223, 30, 223, 30, 225, 30, 225, 30, 227, 30, 227, 30, 229, 30, 229, 30, 231, 30, 231, 30, 233, 30, 233, 30, 235, 30, 235, 30, 237, 30, 237, 30, 239, 30, 239, 30, 241, 30, 241, 30, 243, 30, 243, 30, 245, 30, 245, 30, 247, 30, 247, 30, 249, 30, 249, 30, 0, 31, 7, 31, 16, 31, 21, 31, 32, 31, 39, 31, 48, 31, 55, 31, 64, 31, 69, 31, 80, 31, 87, 31, 96, 31, 103, 31, 112, 31, 125, 31, 128, 31, 135, 31, 144, 31, 151, 31, 160, 31, 167, 31, 176, 31, 180, 31, 182, 31, 183, 31, 190, 31, 190, 31, 194, 31, 196, 31, 198, 31, 199, 31, 208, 31, 211, 31, 214, 31, 215, 31, 224, 31, 231, 31, 242, 31, 244, 31, 246, 31, 247, 31, 113, 32, 113, 32, 127, 32, 127, 32, 10, 33, 10, 33, 14, 33, 15, 33, 19, 33, 19, 33, 47, 33, 47, 33, 52, 33, 52, 33, 57, 33, 57, 33, 61, 33, 61, 33, 70, 33, 73, 33, 0, 251, 6, 251, 19, 251, 23, 251, 65, 255, 90, 255, 40, 4, 1, 0, 79, 4, 1, 0, 26, 212, 1, 0, 51, 212, 1, 0, 78, 212, 1, 0, 84, 212, 1, 0, 86, 212, 1, 0, 103, 212, 1, 0, 130, 212, 1, 0, 155, 212, 1, 0, 182, 212, 1, 0, 185, 212, 1, 0, 187, 212, 1, 0, 187, 212, 1, 0, 189, 212, 1, 0, 195, 212, 1, 0, 197, 212, 1, 0, 207, 212, 1, 0, 234, 212, 1, 0, 3, 213, 1, 0, 30, 213, 1, 0, 55, 213, 1, 0, 82, 213, 1, 0, 107, 213, 1, 0, 134, 213, 1, 0, 159, 213, 1, 0, 186, 213, 1, 0, 211, 213, 1, 0, 238, 213, 1, 0, 7, 214, 1, 0, 34, 214, 1, 0, 59, 214, 1, 0, 86, 214, 1, 0, 111, 214, 1, 0, 138, 214, 1, 0, 163, 214, 1, 0, 194, 214, 1, 0, 218, 214, 1, 0, 220, 214, 1, 0, 225, 214, 1, 0, 252, 214, 1, 0, 20, 215, 1, 0, 22, 215, 1, 0, 27, 215, 1, 0, 54, 215, 1, 0, 78, 215, 1, 0, 80, 215, 1, 0, 85, 215, 1, 0, 112, 215, 1, 0, 136, 215, 1, 0, 138, 215, 1, 0, 143, 215, 1, 0, 170, 215, 1, 0, 194, 215, 1, 0, 196, 215, 1, 0, 201, 215, 1, 0, 65, 0, 90, 0, 97, 0, 122, 0, 170, 0, 170, 0, 181, 0, 181, 0, 186, 0, 186, 0, 192, 0, 214, 0, 216, 0, 246, 0, 248, 0, 54, 2, 80, 2, 193, 2, 198, 2, 209, 2, 224, 2, 228, 2, 238, 2, 238, 2, 122, 3, 122, 3, 134, 3, 134, 3, 136, 3, 138, 3, 140, 3, 140, 3, 142, 3, 161, 3, 163, 3, 206, 3, 208, 3, 245, 3, 247, 3, 251, 3, 0, 4, 129, 4, 138, 4, 206, 4, 208, 4, 245, 4, 248, 4, 249, 4, 0, 5, 15, 5, 49, 5, 86, 5, 89, 5, 89, 5, 97, 5, 135, 5, 208, 5, 234, 5, 240, 5, 242, 5, 33, 6, 58, 6, 64, 6, 74, 6, 110, 6, 111, 6, 113, 6, 211, 6, 213, 6, 213, 6, 229, 6, 230, 6, 238, 6, 239, 6, 250, 6, 252, 6, 255, 6, 255, 6, 16, 7, 16, 7, 18, 7, 47, 7, 77, 7, 79, 7, 128, 7, 165, 7, 177, 7, 177, 7, 4, 9, 57, 9, 61, 9, 61, 9, 80, 9, 80, 9, 88, 9, 97, 9, 133, 9, 140, 9, 143, 9, 144, 9, 147, 9, 168, 9, 170, 9, 176, 9, 178, 9, 178, 9, 182, 9, 185, 9, 189, 9, 189, 9, 220, 9, 221, 9, 223, 9, 225, 9, 240, 9, 241, 9, 5, 10, 10, 10, 15, 10, 16, 10, 19, 10, 40, 10, 42, 10, 48, 10, 50, 10, 51, 10, 53, 10, 54, 10, 56, 10, 57, 10, 89, 10, 92, 10, 94, 10, 94, 10, 114, 10, 116, 10, 133, 10, 141, 10, 143, 10, 145, 10, 147, 10, 168, 10, 170, 10, 176, 10, 178, 10, 179, 10, 181, 10, 185, 10, 189, 10, 189, 10, 208, 10, 208, 10, 224, 10, 225, 10, 5, 11, 12, 11, 15, 11, 16, 11, 19, 11, 40, 11, 42, 11, 48, 11, 50, 11, 51, 11, 53, 11, 57, 11, 61, 11, 61, 11, 92, 11, 93, 11, 95, 11, 97, 11, 113, 11, 113, 11, 131, 11, 131, 11, 133, 11, 138, 11, 142, 11, 144, 11, 146, 11, 149, 11, 153, 11, 154, 11, 156, 11, 156, 11, 158, 11, 159, 11, 163, 11, 164, 11, 168, 11, 170, 11, 174, 11, 181, 11, 183, 11, 185, 11, 5, 12, 12, 12, 14, 12, 16, 12, 18, 12, 40, 12, 42, 12, 51, 12, 53, 12, 57, 12, 96, 12, 97, 12, 133, 12, 140, 12, 142, 12, 144, 12, 146, 12, 168, 12, 170, 12, 179, 12, 181, 12, 185, 12, 189, 12, 189, 12, 222, 12, 222, 12, 224, 12, 225, 12, 5, 13, 12, 13, 14, 13, 16, 13, 18, 13, 40, 13, 42, 13, 57, 13, 96, 13, 97, 13, 133, 13, 150, 13, 154, 13, 177, 13, 179, 13, 187, 13, 189, 13, 189, 13, 192, 13, 198, 13, 1, 14, 48, 14, 50, 14, 51, 14, 64, 14, 70, 14, 129, 14, 130, 14, 132, 14, 132, 14, 135, 14, 136, 14, 138, 14, 138, 14, 141, 14, 141, 14, 148, 14, 151, 14, 153, 14, 159, 14, 161, 14, 163, 14, 165, 14, 165, 14, 167, 14, 167, 14, 170, 14, 171, 14, 173, 14, 176, 14, 178, 14, 179, 14, 189, 14, 189, 14, 192, 14, 196, 14, 198, 14, 198, 14, 220, 14, 221, 14, 0, 15, 0, 15, 64, 15, 71, 15, 73, 15, 106, 15, 136, 15, 139, 15, 0, 16, 33, 16, 35, 16, 39, 16, 41, 16, 42, 16, 80, 16, 85, 16, 160, 16, 197, 16, 208, 16, 248, 16, 0, 17, 89, 17, 95, 17, 162, 17, 168, 17, 249, 17, 0, 18, 6, 18, 8, 18, 70, 18, 72, 18, 72, 18, 74, 18, 77, 18, 80, 18, 86, 18, 88, 18, 88, 18, 90, 18, 93, 18, 96, 18, 134, 18, 136, 18, 136, 18, 138, 18, 141, 18, 144, 18, 174, 18, 176, 18, 176, 18, 178, 18, 181, 18, 184, 18, 190, 18, 192, 18, 192, 18, 194, 18, 197, 18, 200, 18, 206, 18, 208, 18, 214, 18, 216, 18, 238, 18, 240, 18, 14, 19, 16, 19, 16, 19, 18, 19, 21, 19, 24, 19, 30, 19, 32, 19, 70, 19, 72, 19, 90, 19, 160, 19, 244, 19, 1, 20, 108, 22, 111, 22, 118, 22, 129, 22, 154, 22, 160, 22, 234, 22, 0, 23, 12, 23, 14, 23, 17, 23, 32, 23, 49, 23, 64, 23, 81, 23, 96, 23, 108, 23, 110, 23, 112, 23, 128, 23, 179, 23, 215, 23, 215, 23, 220, 23, 220, 23, 32, 24, 119, 24, 128, 24, 168, 24, 0, 25, 28, 25, 80, 25, 109, 25, 112, 25, 116, 25, 0, 29, 107, 29, 0, 30, 155, 30, 160, 30, 249, 30, 0, 31, 21, 31, 24, 31, 29, 31, 32, 31, 69, 31, 72, 31, 77, 31, 80, 31, 87, 31, 89, 31, 89, 31, 91, 31, 91, 31, 93, 31, 93, 31, 95, 31, 125, 31, 128, 31, 180, 31, 182, 31, 188, 31, 190, 31, 190, 31, 194, 31, 196, 31, 198, 31, 204, 31, 208, 31, 211, 31, 214, 31, 219, 31, 224, 31, 236, 31, 242, 31, 244, 31, 246, 31, 252, 31, 113, 32, 113, 32, 127, 32, 127, 32, 2, 33, 2, 33, 7, 33, 7, 33, 10, 33, 19, 33, 21, 33, 21, 33, 25, 33, 29, 33, 36, 33, 36, 33, 38, 33, 38, 33, 40, 33, 40, 33, 42, 33, 45, 33, 47, 33, 49, 33, 51, 33, 57, 33, 61, 33, 63, 33, 69, 33, 73, 33, 5, 48, 6, 48, 49, 48, 53, 48, 59, 48, 60, 48, 65, 48, 150, 48, 157, 48, 159, 48, 161, 48, 250, 48, 252, 48, 255, 48, 5, 49, 44, 49, 49, 49, 142, 49, 160, 49, 183, 49, 240, 49, 255, 49, 0, 52, 0, 52, 181, 77, 181, 77, 0, 78, 0, 78, 165, 159, 165, 159, 0, 160, 140, 164, 0, 172, 0, 172, 163, 215, 163, 215, 0, 249, 45, 250, 48, 250, 106, 250, 0, 251, 6, 251, 19, 251, 23, 251, 29, 251, 29, 251, 31, 251, 40, 251, 42, 251, 54, 251, 56, 251, 60, 251, 62, 251, 62, 251, 64, 251, 65, 251, 67, 251, 68, 251, 70, 251, 177, 251, 211, 251, 61, 253, 80, 253, 143, 253, 146, 253, 199, 253, 240, 253, 251, 253, 112, 254, 116, 254, 118, 254, 252, 254, 33, 255, 58, 255, 65, 255, 90, 255, 102, 255, 190, 255, 194, 255, 199, 255, 202, 255, 207, 255, 210, 255, 215, 255, 218, 255, 220, 255, 0, 0, 0, 0, 0, 0, 1, 0, 11, 0, 1, 0, 13, 0, 1, 0, 38, 0, 1, 0, 40, 0, 1, 0, 58, 0, 1, 0, 60, 0, 1, 0, 61, 0, 1, 0, 63, 0, 1, 0, 77, 0, 1, 0, 80, 0, 1, 0, 93, 0, 1, 0, 128, 0, 1, 0, 250, 0, 1, 0, 0, 3, 1, 0, 30, 3, 1, 0, 48, 3, 1, 0, 73, 3, 1, 0, 128, 3, 1, 0, 157, 3, 1, 0, 0, 4, 1, 0, 157, 4, 1, 0, 0, 8, 1, 0, 5, 8, 1, 0, 8, 8, 1, 0, 8, 8, 1, 0, 10, 8, 1, 0, 53, 8, 1, 0, 55, 8, 1, 0, 56, 8, 1, 0, 60, 8, 1, 0, 60, 8, 1, 0, 63, 8, 1, 0, 63, 8, 1, 0, 0, 212, 1, 0, 84, 212, 1, 0, 86, 212, 1, 0, 156, 212, 1, 0, 158, 212, 1, 0, 159, 212, 1, 0, 162, 212, 1, 0, 162, 212, 1, 0, 165, 212, 1, 0, 166, 212, 1, 0, 169, 212, 1, 0, 172, 212, 1, 0, 174, 212, 1, 0, 185, 212, 1, 0, 187, 212, 1, 0, 187, 212, 1, 0, 189, 212, 1, 0, 195, 212, 1, 0, 197, 212, 1, 0, 5, 213, 1, 0, 7, 213, 1, 0, 10, 213, 1, 0, 13, 213, 1, 0, 20, 213, 1, 0, 22, 213, 1, 0, 28, 213, 1, 0, 30, 213, 1, 0, 57, 213, 1, 0, 59, 213, 1, 0, 62, 213, 1, 0, 64, 213, 1, 0, 68, 213, 1, 0, 70, 213, 1, 0, 70, 213, 1, 0, 74, 213, 1, 0, 80, 213, 1, 0, 82, 213, 1, 0, 163, 214, 1, 0, 168, 214, 1, 0, 192, 214, 1, 0, 194, 214, 1, 0, 218, 214, 1, 0, 220, 214, 1, 0, 250, 214, 1, 0, 252, 214, 1, 0, 20, 215, 1, 0, 22, 215, 1, 0, 52, 215, 1, 0, 54, 215, 1, 0, 78, 215, 1, 0, 80, 215, 1, 0, 110, 215, 1, 0, 112, 215, 1, 0, 136, 215, 1, 0, 138, 215, 1, 0, 168, 215, 1, 0, 170, 215, 1, 0, 194, 215, 1, 0, 196, 215, 1, 0, 201, 215, 1, 0, 0, 0, 2, 0, 0, 0, 2, 0, 214, 166, 2, 0, 214, 166, 2, 0, 0, 248, 2, 0, 29, 250, 2, 0, 173, 0, 173, 0, 0, 6, 3, 6, 221, 6, 221, 6, 15, 7, 15, 7, 180, 23, 181, 23, 11, 32, 15, 32, 42, 32, 46, 32, 96, 32, 99, 32, 106, 32, 111, 32, 255, 254, 255, 254, 249, 255, 251, 255, 0, 0, 0, 0, 115, 209, 1, 0, 122, 209, 1, 0, 1, 0, 14, 0, 1, 0, 14, 0, 32, 0, 14, 0, 127, 0, 14, 0, 0, 0, 31, 0, 127, 0, 159, 0, 173, 0, 173, 0, 0, 6, 3, 6, 221, 6, 221, 6, 15, 7, 15, 7, 180, 23, 181, 23, 11, 32, 15, 32, 42, 32, 46, 32, 96, 32, 99, 32, 106, 32, 111, 32, 0, 216, 0, 216, 127, 219, 128, 219, 255, 219, 0, 220, 255, 223, 0, 224, 255, 248, 255, 248, 255, 254, 255, 254, 249, 255, 251, 255, 115, 209, 1, 0, 122, 209, 1, 0, 1, 0, 14, 0, 1, 0, 14, 0, 32, 0, 14, 0, 127, 0, 14, 0, 0, 0, 15, 0, 0, 0, 15, 0, 253, 255, 15, 0, 253, 255, 15, 0, 0, 0, 16, 0, 0, 0, 16, 0, 253, 255, 16, 0, 253, 255, 16, 0, 16, 210, 2, 0, 66, 0, 0, 0, 32, 210, 2, 0, 67, 0, 0, 0, 64, 210, 2, 0, 68, 0, 0, 0, 72, 210, 2, 0, 69, 0, 0, 0, 104, 210, 2, 0, 70, 0, 0, 0, 136, 210, 2, 0, 71, 0, 0, 0, 152, 210, 2, 0, 72, 0, 0, 0, 160, 210, 2, 0, 73, 0, 0, 0, 176, 210, 2, 0, 74, 0, 0, 0, 184, 210, 2, 0, 75, 0, 0, 0, 200, 210, 2, 0, 76, 0, 0, 0, 216, 210, 2, 0, 77, 0, 0, 0, 240, 210, 2, 0, 78, 0, 0, 0, 0, 211, 2, 0, 79, 0, 0, 0, 16, 211, 2, 0, 80, 0, 0, 0, 24, 211, 2, 0, 81, 0, 0, 0, 48, 211, 2, 0, 82, 0, 0, 0, 72, 211, 2, 0, 83, 0, 0, 0, 96, 211, 2, 0, 84, 0, 0, 0, 128, 211, 2, 0, 85, 0, 0, 0, 168, 211, 2, 0, 86, 0, 0, 0, 192, 211, 2, 0, 87, 0, 0, 0, 224, 211, 2, 0, 88, 0, 0, 0, 248, 211, 2, 0, 89, 0, 0, 0, 24, 212, 2, 0, 90, 0, 0, 0, 56, 212, 2, 0, 91, 0, 0, 0, 72, 212, 2, 0, 92, 0, 0, 0, 104, 212, 2, 0, 93, 0, 0, 0, 144, 212, 2, 0, 94, 0, 0, 0, 168, 212, 2, 0, 95, 0, 0, 0, 200, 212, 2, 0, 96, 0, 0, 0, 216, 212, 2, 0, 97, 0, 0, 0, 232, 212, 2, 0, 98, 0, 0, 0, 0, 213, 2, 0, 99, 0, 0, 0, 16, 213, 2, 0, 100, 0, 0, 0, 40, 213, 2, 0, 101, 0, 0, 0, 48, 213, 2, 0, 102, 0, 0, 0, 64, 213, 2, 0, 103, 0, 0, 0, 80, 213, 2, 0, 104, 0, 0, 0, 104, 213, 2, 0, 105, 0, 0, 0, 136, 213, 2, 0, 106, 0, 0, 0, 152, 213, 2, 0, 107, 0, 0, 0, 176, 213, 2, 0, 108, 0, 0, 0, 192, 213, 2, 0, 109, 0, 0, 0, 208, 213, 2, 0, 110, 0, 0, 0, 216, 213, 2, 0, 111, 0, 0, 0, 224, 213, 2, 0, 112, 0, 0, 0, 240, 213, 2, 0, 113, 0, 0, 0, 0, 214, 2, 0, 114, 0, 0, 0, 16, 214, 2, 0, 115, 0, 0, 0, 32, 214, 2, 0, 116, 0, 0, 0, 64, 214, 2, 0, 117, 0, 0, 0, 88, 214, 2, 0, 118, 0, 0, 0, 104, 214, 2, 0, 119, 0, 0, 0, 120, 214, 2, 0, 120, 0, 0, 0, 128, 214, 2, 0, 121, 0, 0, 0, 136, 214, 2, 0, 122, 0, 0, 0, 168, 214, 2, 0, 123, 0, 0, 0, 184, 214, 2, 0, 124, 0, 0, 0, 200, 214, 2, 0, 125, 0, 0, 0, 216, 214, 2, 0, 126, 0, 0, 0, 0, 215, 2, 0, 127, 0, 0, 0, 8, 215, 2, 0, 128, 0, 0, 0, 24, 215, 2, 0, 129, 0, 0, 0, 32, 215, 2, 0, 130, 0, 0, 0, 48, 215, 2, 0, 131, 0, 0, 0, 80, 215, 2, 0, 132, 0, 0, 0, 88, 215, 2, 0, 133, 0, 0, 0, 104, 215, 2, 0, 134, 0, 0, 0, 112, 215, 2, 0, 135, 0, 0, 0, 136, 215, 2, 0, 136, 0, 0, 0, 152, 215, 2, 0, 137, 0, 0, 0, 168, 215, 2, 0, 138, 0, 0, 0, 192, 215, 2, 0, 139, 0, 0, 0, 216, 215, 2, 0, 140, 0, 0, 0, 224, 215, 2, 0, 141, 0, 0, 0, 248, 215, 2, 0, 142, 0, 0, 0, 16, 216, 2, 0, 143, 0, 0, 0, 32, 216, 2, 0, 144, 0, 0, 0, 48, 216, 2, 0, 145, 0, 0, 0, 80, 216, 2, 0, 146, 0, 0, 0, 104, 216, 2, 0, 147, 0, 0, 0, 144, 216, 2, 0, 148, 0, 0, 0, 184, 216, 2, 0, 149, 0, 0, 0, 208, 216, 2, 0, 150, 0, 0, 0, 240, 216, 2, 0, 151, 0, 0, 0, 8, 217, 2, 0, 152, 0, 0, 0, 24, 217, 2, 0, 153, 0, 0, 0, 40, 217, 2, 0, 154, 0, 0, 0, 48, 217, 2, 0, 155, 0, 0, 0, 64, 217, 2, 0, 156, 0, 0, 0, 72, 217, 2, 0, 157, 0, 0, 0, 88, 217, 2, 0, 158, 0, 0, 0, 120, 217, 2, 0, 159, 0, 0, 0, 128, 217, 2, 0, 160, 0, 0, 0, 136, 217, 2, 0, 161, 0, 0, 0, 160, 217, 2, 0, 162, 0, 0, 0, 176, 217, 2, 0, 163, 0, 0, 0, 192, 217, 2, 0, 164, 0, 0, 0, 200, 217, 2, 0, 165, 0, 0, 0, 208, 217, 2, 0, 166, 0, 0, 0, 216, 217, 2, 0, 167, 0, 0, 0, 240, 217, 2, 0, 168, 0, 0, 0, 8, 218, 2, 0, 169, 0, 0, 0, 24, 218, 2, 0, 170, 0, 0, 0, 56, 218, 2, 0, 171, 0, 0, 0, 80, 218, 2, 0, 172, 0, 0, 0, 104, 218, 2, 0, 173, 0, 0, 0, 144, 218, 2, 0, 174, 0, 0, 0, 176, 218, 2, 0, 175, 0, 0, 0, 208, 218, 2, 0, 176, 0, 0, 0, 216, 218, 2, 0, 177, 0, 0, 0, 224, 218, 2, 0, 178, 0, 0, 0, 240, 218, 2, 0, 179, 0, 0, 0, 248, 218, 2, 0, 180, 0, 0, 0, 0, 219, 2, 0, 181, 0, 0, 0, 24, 219, 2, 0, 182, 0, 0, 0, 32, 219, 2, 0, 183, 0, 0, 0, 40, 219, 2, 0, 184, 0, 0, 0, 48, 219, 2, 0, 185, 0, 0, 0, 56, 219, 2, 0, 186, 0, 0, 0, 64, 219, 2, 0, 187, 0, 0, 0, 80, 219, 2, 0, 188, 0, 0, 0, 120, 219, 2, 0, 189, 0, 0, 0, 144, 219, 2, 0, 190, 0, 0, 0, 176, 219, 2, 0, 191, 0, 0, 0, 192, 219, 2, 0, 192, 0, 0, 0, 208, 219, 2, 0, 193, 0, 0, 0, 65, 101, 103, 101, 97, 110, 78, 117, 109, 98, 101, 114, 115, 0, 0, 0, 65, 108, 112, 104, 97, 98, 101, 116, 105, 99, 80, 114, 101, 115, 101, 110, 116, 97, 116, 105, 111, 110, 70, 111, 114, 109, 115, 0, 0, 0, 0, 0, 65, 114, 97, 98, 105, 99, 0, 0, 65, 114, 97, 98, 105, 99, 80, 114, 101, 115, 101, 110, 116, 97, 116, 105, 111, 110, 70, 111, 114, 109, 115, 45, 65, 0, 0, 0, 0, 0, 0, 0, 65, 114, 97, 98, 105, 99, 80, 114, 101, 115, 101, 110, 116, 97, 116, 105, 111, 110, 70, 111, 114, 109, 115, 45, 66, 0, 0, 0, 0, 0, 0, 0, 65, 114, 109, 101, 110, 105, 97, 110, 0, 0, 0, 0, 0, 0, 0, 0, 65, 114, 114, 111, 119, 115, 0, 0, 66, 97, 115, 105, 99, 76, 97, 116, 105, 110, 0, 0, 0, 0, 0, 0, 66, 101, 110, 103, 97, 108, 105, 0, 66, 108, 111, 99, 107, 69, 108, 101, 109, 101, 110, 116, 115, 0, 0, 0, 66, 111, 112, 111, 109, 111, 102, 111, 0, 0, 0, 0, 0, 0, 0, 0, 66, 111, 112, 111, 109, 111, 102, 111, 69, 120, 116, 101, 110, 100, 101, 100, 0, 0, 0, 0, 0, 0, 0, 0, 66, 111, 120, 68, 114, 97, 119, 105, 110, 103, 0, 0, 0, 0, 0, 0, 66, 114, 97, 105, 108, 108, 101, 80, 97, 116, 116, 101, 114, 110, 115, 0, 66, 117, 104, 105, 100, 0, 0, 0, 66, 121, 122, 97, 110, 116, 105, 110, 101, 77, 117, 115, 105, 99, 97, 108, 83, 121, 109, 98, 111, 108, 115, 0, 67, 74, 75, 67, 111, 109, 112, 97, 116, 105, 98, 105, 108, 105, 116, 121, 0, 0, 0, 0, 0, 0, 0, 0, 67, 74, 75, 67, 111, 109, 112, 97, 116, 105, 98, 105, 108, 105, 116, 121, 70, 111, 114, 109, 115, 0, 0, 0, 67, 74, 75, 67, 111, 109, 112, 97, 116, 105, 98, 105, 108, 105, 116, 121, 73, 100, 101, 111, 103, 114, 97, 112, 104, 115, 0, 0, 0, 0, 0, 0, 67, 74, 75, 67, 111, 109, 112, 97, 116, 105, 98, 105, 108, 105, 116, 121, 73, 100, 101, 111, 103, 114, 97, 112, 104, 115, 83, 117, 112, 112, 108, 101, 109, 101, 110, 116, 0, 0, 0, 0, 67, 74, 75, 82, 97, 100, 105, 99, 97, 108, 115, 83, 117, 112, 112, 108, 101, 109, 101, 110, 116, 0, 0, 0, 67, 74, 75, 83, 121, 109, 98, 111, 108, 115, 97, 110, 100, 80, 117, 110, 99, 116, 117, 97, 116, 105, 111, 110, 0, 0, 0, 0, 0, 0, 0, 0, 67, 74, 75, 85, 110, 105, 102, 105, 101, 100, 73, 100, 101, 111, 103, 114, 97, 112, 104, 115, 0, 0, 0, 0, 67, 74, 75, 85, 110, 105, 102, 105, 101, 100, 73, 100, 101, 111, 103, 114, 97, 112, 104, 115, 69, 120, 116, 101, 110, 115, 105, 111, 110, 65, 0, 0, 67, 74, 75, 85, 110, 105, 102, 105, 101, 100, 73, 100, 101, 111, 103, 114, 97, 112, 104, 115, 69, 120, 116, 101, 110, 115, 105, 111, 110, 66, 0, 0, 67, 104, 101, 114, 111, 107, 101, 101, 0, 0, 0, 0, 0, 0, 0, 0, 67, 111, 109, 98, 105, 110, 105, 110, 103, 68, 105, 97, 99, 114, 105, 116, 105, 99, 97, 108, 77, 97, 114, 107, 115, 0, 0, 0, 0, 0, 0, 0, 67, 111, 109, 98, 105, 110, 105, 110, 103, 68, 105, 97, 99, 114, 105, 116, 105, 99, 97, 108, 77, 97, 114, 107, 115, 102, 111, 114, 83, 121, 109, 98, 111, 108, 115, 0, 0, 0, 0, 0, 67, 111, 109, 98, 105, 110, 105, 110, 103, 72, 97, 108, 102, 77, 97, 114, 107, 115, 0, 0, 0, 0, 0, 0, 67, 111, 109, 98, 105, 110, 105, 110, 103, 77, 97, 114, 107, 115, 102, 111, 114, 83, 121, 109, 98, 111, 108, 115, 0, 0, 0, 0, 0, 0, 0, 0, 67, 111, 110, 116, 114, 111, 108, 80, 105, 99, 116, 117, 114, 101, 115, 0, 67, 117, 114, 114, 101, 110, 99, 121, 83, 121, 109, 98, 111, 108, 115, 0, 67, 121, 112, 114, 105, 111, 116, 83, 121, 108, 108, 97, 98, 97, 114, 121, 0, 0, 0, 0, 0, 0, 0, 0, 67, 121, 114, 105, 108, 108, 105, 99, 0, 0, 0, 0, 0, 0, 0, 0, 67, 121, 114, 105, 108, 108, 105, 99, 83, 117, 112, 112, 108, 101, 109, 101, 110, 116, 0, 0, 0, 0, 0, 0, 68, 101, 115, 101, 114, 101, 116, 0, 68, 101, 118, 97, 110, 97, 103, 97, 114, 105, 0, 0, 0, 0, 0, 0, 68, 105, 110, 103, 98, 97, 116, 115, 0, 0, 0, 0, 0, 0, 0, 0, 69, 110, 99, 108, 111, 115, 101, 100, 65, 108, 112, 104, 97, 110, 117, 109, 101, 114, 105, 99, 115, 0, 0, 0, 69, 110, 99, 108, 111, 115, 101, 100, 67, 74, 75, 76, 101, 116, 116, 101, 114, 115, 97, 110, 100, 77, 111, 110, 116, 104, 115, 0, 0, 0, 0, 0, 69, 116, 104, 105, 111, 112, 105, 99, 0, 0, 0, 0, 0, 0, 0, 0, 71, 101, 110, 101, 114, 97, 108, 80, 117, 110, 99, 116, 117, 97, 116, 105, 111, 110, 0, 0, 0, 0, 0, 0, 71, 101, 111, 109, 101, 116, 114, 105, 99, 83, 104, 97, 112, 101, 115, 0, 71, 101, 111, 114, 103, 105, 97, 110, 0, 0, 0, 0, 0, 0, 0, 0, 71, 111, 116, 104, 105, 99, 0, 0, 71, 114, 101, 101, 107, 0, 0, 0, 71, 114, 101, 101, 107, 69, 120, 116, 101, 110, 100, 101, 100, 0, 0, 0, 71, 114, 101, 101, 107, 97, 110, 100, 67, 111, 112, 116, 105, 99, 0, 0, 71, 117, 106, 97, 114, 97, 116, 105, 0, 0, 0, 0, 0, 0, 0, 0, 71, 117, 114, 109, 117, 107, 104, 105, 0, 0, 0, 0, 0, 0, 0, 0, 72, 97, 108, 102, 119, 105, 100, 116, 104, 97, 110, 100, 70, 117, 108, 108, 119, 105, 100, 116, 104, 70, 111, 114, 109, 115, 0, 0, 0, 0, 0, 0, 72, 97, 110, 103, 117, 108, 67, 111, 109, 112, 97, 116, 105, 98, 105, 108, 105, 116, 121, 74, 97, 109, 111, 0, 72, 97, 110, 103, 117, 108, 74, 97, 109, 111, 0, 0, 0, 0, 0, 0, 72, 97, 110, 103, 117, 108, 83, 121, 108, 108, 97, 98, 108, 101, 115, 0, 72, 97, 110, 117, 110, 111, 111, 0, 72, 101, 98, 114, 101, 119, 0, 0, 72, 105, 103, 104, 80, 114, 105, 118, 97, 116, 101, 85, 115, 101, 83, 117, 114, 114, 111, 103, 97, 116, 101, 115, 0, 0, 0, 0, 0, 0, 0, 0, 72, 105, 103, 104, 83, 117, 114, 114, 111, 103, 97, 116, 101, 115, 0, 0, 72, 105, 114, 97, 103, 97, 110, 97, 0, 0, 0, 0, 0, 0, 0, 0, 73, 80, 65, 69, 120, 116, 101, 110, 115, 105, 111, 110, 115, 0, 0, 0, 73, 100, 101, 111, 103, 114, 97, 112, 104, 105, 99, 68, 101, 115, 99, 114, 105, 112, 116, 105, 111, 110, 67, 104, 97, 114, 97, 99, 116, 101, 114, 115, 0, 0, 0, 0, 0, 0, 0, 0, 75, 97, 110, 98, 117, 110, 0, 0, 75, 97, 110, 103, 120, 105, 82, 97, 100, 105, 99, 97, 108, 115, 0, 0, 75, 97, 110, 110, 97, 100, 97, 0, 75, 97, 116, 97, 107, 97, 110, 97, 0, 0, 0, 0, 0, 0, 0, 0, 75, 97, 116, 97, 107, 97, 110, 97, 80, 104, 111, 110, 101, 116, 105, 99, 69, 120, 116, 101, 110, 115, 105, 111, 110, 115, 0, 0, 0, 0, 0, 0, 75, 104, 109, 101, 114, 0, 0, 0, 75, 104, 109, 101, 114, 83, 121, 109, 98, 111, 108, 115, 0, 0, 0, 0, 76, 97, 111, 0, 0, 0, 0, 0, 76, 97, 116, 105, 110, 45, 49, 83, 117, 112, 112, 108, 101, 109, 101, 110, 116, 0, 0, 0, 0, 0, 0, 0, 76, 97, 116, 105, 110, 69, 120, 116, 101, 110, 100, 101, 100, 45, 65, 0, 76, 97, 116, 105, 110, 69, 120, 116, 101, 110, 100, 101, 100, 45, 66, 0, 76, 97, 116, 105, 110, 69, 120, 116, 101, 110, 100, 101, 100, 65, 100, 100, 105, 116, 105, 111, 110, 97, 108, 0, 76, 101, 116, 116, 101, 114, 108, 105, 107, 101, 83, 121, 109, 98, 111, 108, 115, 0, 0, 0, 0, 0, 0, 0, 76, 105, 109, 98, 117, 0, 0, 0, 76, 105, 110, 101, 97, 114, 66, 73, 100, 101, 111, 103, 114, 97, 109, 115, 0, 0, 0, 0, 0, 0, 0, 0, 76, 105, 110, 101, 97, 114, 66, 83, 121, 108, 108, 97, 98, 97, 114, 121, 0, 0, 0, 0, 0, 0, 0, 0, 76, 111, 119, 83, 117, 114, 114, 111, 103, 97, 116, 101, 115, 0, 0, 0, 77, 97, 108, 97, 121, 97, 108, 97, 109, 0, 0, 0, 0, 0, 0, 0, 77, 97, 116, 104, 101, 109, 97, 116, 105, 99, 97, 108, 65, 108, 112, 104, 97, 110, 117, 109, 101, 114, 105, 99, 83, 121, 109, 98, 111, 108, 115, 0, 77, 97, 116, 104, 101, 109, 97, 116, 105, 99, 97, 108, 79, 112, 101, 114, 97, 116, 111, 114, 115, 0, 0, 0, 77, 105, 115, 99, 101, 108, 108, 97, 110, 101, 111, 117, 115, 77, 97, 116, 104, 101, 109, 97, 116, 105, 99, 97, 108, 83, 121, 109, 98, 111, 108, 115, 45, 65, 0, 0, 0, 0, 0, 0, 77, 105, 115, 99, 101, 108, 108, 97, 110, 101, 111, 117, 115, 77, 97, 116, 104, 101, 109, 97, 116, 105, 99, 97, 108, 83, 121, 109, 98, 111, 108, 115, 45, 66, 0, 0, 0, 0, 0, 0, 77, 105, 115, 99, 101, 108, 108, 97, 110, 101, 111, 117, 115, 83, 121, 109, 98, 111, 108, 115, 0, 0, 0, 0, 77, 105, 115, 99, 101, 108, 108, 97, 110, 101, 111, 117, 115, 83, 121, 109, 98, 111, 108, 115, 97, 110, 100, 65, 114, 114, 111, 119, 115, 0, 0, 0, 77, 105, 115, 99, 101, 108, 108, 97, 110, 101, 111, 117, 115, 84, 101, 99, 104, 110, 105, 99, 97, 108, 0, 0, 77, 111, 110, 103, 111, 108, 105, 97, 110, 0, 0, 0, 0, 0, 0, 0, 77, 117, 115, 105, 99, 97, 108, 83, 121, 109, 98, 111, 108, 115, 0, 0, 77, 121, 97, 110, 109, 97, 114, 0, 78, 117, 109, 98, 101, 114, 70, 111, 114, 109, 115, 0, 0, 0, 0, 0, 79, 103, 104, 97, 109, 0, 0, 0, 79, 108, 100, 73, 116, 97, 108, 105, 99, 0, 0, 0, 0, 0, 0, 0, 79, 112, 116, 105, 99, 97, 108, 67, 104, 97, 114, 97, 99, 116, 101, 114, 82, 101, 99, 111, 103, 110, 105, 116, 105, 111, 110, 0, 0, 0, 0, 0, 79, 114, 105, 121, 97, 0, 0, 0, 79, 115, 109, 97, 110, 121, 97, 0, 80, 104, 111, 110, 101, 116, 105, 99, 69, 120, 116, 101, 110, 115, 105, 111, 110, 115, 0, 0, 0, 0, 0, 0, 80, 114, 105, 118, 97, 116, 101, 85, 115, 101, 0, 0, 0, 0, 0, 0, 80, 114, 105, 118, 97, 116, 101, 85, 115, 101, 65, 114, 101, 97, 0, 0, 82, 117, 110, 105, 99, 0, 0, 0, 83, 104, 97, 118, 105, 97, 110, 0, 83, 105, 110, 104, 97, 108, 97, 0, 83, 109, 97, 108, 108, 70, 111, 114, 109, 86, 97, 114, 105, 97, 110, 116, 115, 0, 0, 0, 0, 0, 0, 0, 83, 112, 97, 99, 105, 110, 103, 77, 111, 100, 105, 102, 105, 101, 114, 76, 101, 116, 116, 101, 114, 115, 0, 0, 83, 112, 101, 99, 105, 97, 108, 115, 0, 0, 0, 0, 0, 0, 0, 0, 83, 117, 112, 101, 114, 115, 99, 114, 105, 112, 116, 115, 97, 110, 100, 83, 117, 98, 115, 99, 114, 105, 112, 116, 115, 0, 0, 0, 0, 0, 0, 0, 83, 117, 112, 112, 108, 101, 109, 101, 110, 116, 97, 108, 65, 114, 114, 111, 119, 115, 45, 65, 0, 0, 0, 0, 83, 117, 112, 112, 108, 101, 109, 101, 110, 116, 97, 108, 65, 114, 114, 111, 119, 115, 45, 66, 0, 0, 0, 0, 83, 117, 112, 112, 108, 101, 109, 101, 110, 116, 97, 108, 77, 97, 116, 104, 101, 109, 97, 116, 105, 99, 97, 108, 79, 112, 101, 114, 97, 116, 111, 114, 115, 0, 0, 0, 0, 0, 0, 0, 83, 117, 112, 112, 108, 101, 109, 101, 110, 116, 97, 114, 121, 80, 114, 105, 118, 97, 116, 101, 85, 115, 101, 65, 114, 101, 97, 45, 65, 0, 0, 0, 83, 117, 112, 112, 108, 101, 109, 101, 110, 116, 97, 114, 121, 80, 114, 105, 118, 97, 116, 101, 85, 115, 101, 65, 114, 101, 97, 45, 66, 0, 0, 0, 83, 121, 114, 105, 97, 99, 0, 0, 84, 97, 103, 97, 108, 111, 103, 0, 84, 97, 103, 98, 97, 110, 119, 97, 0, 0, 0, 0, 0, 0, 0, 0, 84, 97, 103, 115, 0, 0, 0, 0, 84, 97, 105, 76, 101, 0, 0, 0, 84, 97, 105, 88, 117, 97, 110, 74, 105, 110, 103, 83, 121, 109, 98, 111, 108, 115, 0, 0, 0, 0, 0, 0, 84, 97, 109, 105, 108, 0, 0, 0, 84, 101, 108, 117, 103, 117, 0, 0, 84, 104, 97, 97, 110, 97, 0, 0, 84, 104, 97, 105, 0, 0, 0, 0, 84, 105, 98, 101, 116, 97, 110, 0, 85, 103, 97, 114, 105, 116, 105, 99, 0, 0, 0, 0, 0, 0, 0, 0, 85, 110, 105, 102, 105, 101, 100, 67, 97, 110, 97, 100, 105, 97, 110, 65, 98, 111, 114, 105, 103, 105, 110, 97, 108, 83, 121, 108, 108, 97, 98, 105, 99, 115], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 177008);
	        allocate([86, 97, 114, 105, 97, 116, 105, 111, 110, 83, 101, 108, 101, 99, 116, 111, 114, 115, 0, 0, 0, 0, 0, 0, 86, 97, 114, 105, 97, 116, 105, 111, 110, 83, 101, 108, 101, 99, 116, 111, 114, 115, 83, 117, 112, 112, 108, 101, 109, 101, 110, 116, 0, 0, 0, 0, 89, 105, 82, 97, 100, 105, 99, 97, 108, 115, 0, 0, 0, 0, 0, 0, 89, 105, 83, 121, 108, 108, 97, 98, 108, 101, 115, 0, 0, 0, 0, 0, 89, 105, 106, 105, 110, 103, 72, 101, 120, 97, 103, 114, 97, 109, 83, 121, 109, 98, 111, 108, 115, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 50, 48, 48, 51, 47, 88, 73, 110, 99, 108, 117, 100, 101, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 50, 48, 48, 49, 47, 88, 73, 110, 99, 108, 117, 100, 101, 0, 120, 109, 108, 78, 101, 119, 84, 101, 120, 116, 82, 101, 97, 100, 101, 114, 32, 58, 32, 109, 97, 108, 108, 111, 99, 32, 102, 97, 105, 108, 101, 100, 10, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 110, 115, 0, 0, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 50, 48, 48, 48, 47, 120, 109, 108, 110, 115, 47, 0, 0, 0, 58, 0, 0, 0, 0, 0, 0, 0, 35, 116, 101, 120, 116, 0, 0, 0, 35, 99, 100, 97, 116, 97, 45, 115, 101, 99, 116, 105, 111, 110, 0, 0, 35, 99, 111, 109, 109, 101, 110, 116, 0, 0, 0, 0, 0, 0, 0, 0, 35, 100, 111, 99, 117, 109, 101, 110, 116, 0, 0, 0, 0, 0, 0, 0, 35, 100, 111, 99, 117, 109, 101, 110, 116, 45, 102, 114, 97, 103, 109, 101, 110, 116, 0, 0, 0, 0, 0, 0, 120, 109, 108, 84, 101, 120, 116, 82, 101, 97, 100, 101, 114, 83, 101, 116, 117, 112, 32, 58, 32, 109, 97, 108, 108, 111, 99, 32, 102, 97, 105, 108, 101, 100, 10, 0, 0, 0, 0, 0, 120, 109, 108, 77, 97, 108, 108, 111, 99, 32, 102, 97, 105, 108, 101, 100, 32, 33, 10, 0, 0, 0, 0, 0, 120, 109, 108, 82, 101, 97, 108, 108, 111, 99, 32, 102, 97, 105, 108, 101, 100, 32, 33, 10, 0, 0, 0, 0, 105, 110, 99, 108, 117, 100, 101, 0, 118, 115, 110, 112, 114, 105, 110, 116, 102, 32, 102, 97, 105, 108, 101, 100, 32, 33, 10, 0, 0, 0, 0, 0, 37, 115, 0, 0, 0, 0, 0, 0, 69, 120, 112, 97, 110, 100, 32, 102, 97, 105, 108, 101, 100, 32, 33, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 70, 97, 105, 108, 101, 100, 32, 116, 111, 32, 97, 108, 108, 111, 99, 97, 116, 101, 32, 115, 104, 32, 116, 97, 98, 108, 101, 32, 102, 111, 114, 32, 82, 101, 108, 97, 120, 45, 78, 71, 32, 116, 121, 112, 101, 115, 10, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 50, 48, 48, 49, 47, 88, 77, 76, 83, 99, 104, 101, 109, 97, 45, 100, 97, 116, 97, 116, 121, 112, 101, 115, 0, 0, 0, 0, 0, 0, 64, 241, 2, 0, 0, 0, 0, 0, 98, 117, 105, 108, 100, 105, 110, 103, 32, 112, 97, 114, 115, 101, 114, 10, 0, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 82, 101, 108, 97, 120, 78, 71, 80, 97, 114, 115, 101, 58, 32, 99, 111, 117, 108, 100, 32, 110, 111, 116, 32, 108, 111, 97, 100, 32, 37, 115, 10, 0, 0, 0, 0, 0, 120, 109, 108, 82, 101, 108, 97, 120, 78, 71, 80, 97, 114, 115, 101, 58, 32, 99, 111, 117, 108, 100, 32, 110, 111, 116, 32, 112, 97, 114, 115, 101, 32, 115, 99, 104, 101, 109, 97, 115, 10, 0, 0, 0, 0, 0, 0, 0, 105, 110, 95, 109, 101, 109, 111, 114, 121, 95, 98, 117, 102, 102, 101, 114, 0, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 82, 101, 108, 97, 120, 78, 71, 80, 97, 114, 115, 101, 58, 32, 110, 111, 116, 104, 105, 110, 103, 32, 116, 111, 32, 112, 97, 114, 115, 101, 10, 0, 0, 0, 0, 0, 0, 120, 109, 108, 82, 101, 108, 97, 120, 78, 71, 80, 97, 114, 115, 101, 58, 32, 37, 115, 32, 105, 115, 32, 101, 109, 112, 116, 121, 10, 0, 0, 0, 115, 99, 104, 101, 109, 97, 115, 0, 35, 116, 101, 120, 116, 0, 0, 0, 32, 84, 79, 68, 79, 32, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 98, 117, 105, 108, 100, 105, 110, 103, 32, 99, 111, 110, 116, 101, 120, 116, 10, 0, 0, 0, 0, 0, 0, 0, 111, 117, 116, 32, 111, 102, 32, 109, 101, 109, 111, 114, 121, 10, 0, 0, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 118, 97, 108, 105, 100, 97, 116, 101, 32, 116, 121, 112, 101, 32, 37, 115, 10, 0, 0, 0, 0, 0, 84, 121, 112, 101, 32, 37, 115, 32, 100, 111, 101, 115, 110, 39, 116, 32, 97, 108, 108, 111, 119, 32, 118, 97, 108, 117, 101, 32, 39, 37, 115, 39, 10, 0, 0, 0, 0, 0, 0, 0, 73, 68, 32, 37, 115, 32, 114, 101, 100, 101, 102, 105, 110, 101, 100, 10, 0, 0, 0, 0, 0, 0, 0, 0, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 99, 111, 109, 112, 97, 114, 101, 32, 116, 121, 112, 101, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 58, 32, 110, 111, 32, 115, 116, 97, 116, 101, 10, 0, 0, 0, 0, 0, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 58, 32, 110, 111, 32, 100, 101, 102, 105, 110, 101, 10, 0, 0, 0, 0, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 58, 32, 37, 115, 10, 0, 0, 0, 0, 0, 69, 120, 116, 114, 97, 32, 100, 97, 116, 97, 32, 105, 110, 32, 108, 105, 115, 116, 58, 32, 37, 115, 10, 0, 73, 110, 116, 101, 114, 110, 97, 108, 58, 32, 105, 110, 116, 101, 114, 108, 101, 97, 118, 101, 32, 98, 108, 111, 99, 107, 32, 104, 97, 115, 32, 110, 111, 32, 100, 97, 116, 97, 10, 0, 73, 110, 118, 97, 108, 105, 100, 32, 115, 101, 113, 117, 101, 110, 99, 101, 32, 105, 110, 32, 105, 110, 116, 101, 114, 108, 101, 97, 118, 101, 10, 0, 69, 120, 116, 114, 97, 32, 101, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 105, 110, 32, 105, 110, 116, 101, 114, 108, 101, 97, 118, 101, 10, 0, 69, 120, 112, 101, 99, 116, 105, 110, 103, 32, 101, 108, 101, 109, 101, 110, 116, 32, 37, 115, 44, 32, 103, 111, 116, 32, 37, 115, 10, 0, 0, 0, 69, 120, 112, 101, 99, 116, 105, 110, 103, 32, 97, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 102, 111, 114, 32, 101, 108, 101, 109, 101, 110, 116, 32, 37, 115, 10, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 104, 97, 115, 32, 119, 114, 111, 110, 103, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 58, 32, 101, 120, 112, 101, 99, 116, 105, 110, 103, 32, 37, 115, 10, 0, 0, 0, 68, 105, 100, 32, 110, 111, 116, 32, 101, 120, 112, 101, 99, 116, 32, 101, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 116, 104, 101, 114, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 68, 105, 100, 32, 110, 111, 116, 32, 101, 120, 112, 101, 99, 116, 32, 116, 101, 120, 116, 32, 105, 110, 32, 101, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 99, 111, 110, 116, 101, 110, 116, 10, 0, 0, 0, 0, 0, 0, 69, 120, 112, 101, 99, 116, 105, 110, 103, 32, 110, 111, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 102, 111, 114, 32, 101, 108, 101, 109, 101, 110, 116, 32, 37, 115, 10, 0, 0, 69, 120, 112, 101, 99, 116, 105, 110, 103, 32, 101, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 116, 111, 32, 98, 101, 32, 101, 109, 112, 116, 121, 10, 0, 0, 0, 0, 0, 0, 0, 69, 120, 112, 101, 99, 116, 105, 110, 103, 32, 97, 110, 32, 101, 108, 101, 109, 101, 110, 116, 32, 37, 115, 44, 32, 103, 111, 116, 32, 110, 111, 116, 104, 105, 110, 103, 10, 0, 0, 0, 69, 120, 112, 101, 99, 116, 105, 110, 103, 32, 97, 110, 32, 101, 108, 101, 109, 101, 110, 116, 32, 103, 111, 116, 32, 116, 101, 120, 116, 10, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 118, 97, 108, 105, 100, 97, 116, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 115, 10, 0, 0, 0, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 118, 97, 108, 105, 100, 97, 116, 101, 32, 99, 111, 110, 116, 101, 110, 116, 10, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 104, 97, 115, 32, 101, 120, 116, 114, 97, 32, 99, 111, 110, 116, 101, 110, 116, 58, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 73, 110, 118, 97, 108, 105, 100, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 102, 111, 114, 32, 101, 108, 101, 109, 101, 110, 116, 32, 37, 115, 10, 0, 0, 0, 0, 68, 97, 116, 97, 116, 121, 112, 101, 32, 101, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 99, 111, 110, 116, 97, 105, 110, 115, 32, 110, 111, 32, 100, 97, 116, 97, 10, 0, 0, 0, 68, 97, 116, 97, 116, 121, 112, 101, 32, 101, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 104, 97, 115, 32, 99, 104, 105, 108, 100, 32, 101, 108, 101, 109, 101, 110, 116, 115, 10, 0, 86, 97, 108, 117, 101, 32, 101, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 104, 97, 115, 32, 99, 104, 105, 108, 100, 32, 101, 108, 101, 109, 101, 110, 116, 115, 10, 0, 0, 0, 0, 76, 105, 115, 116, 32, 101, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 104, 97, 115, 32, 99, 104, 105, 108, 100, 32, 101, 108, 101, 109, 101, 110, 116, 115, 10, 0, 0, 0, 0, 0, 69, 114, 114, 111, 114, 32, 118, 97, 108, 105, 100, 97, 116, 105, 110, 103, 32, 100, 97, 116, 97, 116, 121, 112, 101, 32, 37, 115, 10, 0, 0, 0, 69, 114, 114, 111, 114, 32, 118, 97, 108, 105, 100, 97, 116, 105, 110, 103, 32, 118, 97, 108, 117, 101, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 69, 114, 114, 111, 114, 32, 118, 97, 108, 105, 100, 97, 116, 105, 110, 103, 32, 108, 105, 115, 116, 10, 0, 0, 78, 111, 32, 116, 111, 112, 32, 103, 114, 97, 109, 109, 97, 114, 32, 100, 101, 102, 105, 110, 101, 100, 10, 0, 69, 120, 116, 114, 97, 32, 100, 97, 116, 97, 32, 105, 110, 32, 116, 104, 101, 32, 100, 111, 99, 117, 109, 101, 110, 116, 10, 0, 0, 0, 0, 0, 85, 110, 107, 110, 111, 119, 110, 32, 101, 114, 114, 111, 114, 32, 33, 10, 0, 0, 0, 0, 0, 0, 0, 0, 85, 110, 107, 110, 111, 119, 110, 32, 101, 114, 114, 111, 114, 32, 99, 111, 100, 101, 32, 37, 100, 10, 0, 0, 115, 116, 111, 114, 105, 110, 103, 32, 115, 116, 97, 116, 101, 115, 10, 0, 77, 101, 109, 111, 114, 121, 32, 97, 108, 108, 111, 99, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 32, 58, 32, 37, 115, 10, 0, 0, 77, 101, 109, 111, 114, 121, 32, 97, 108, 108, 111, 99, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 10, 0, 0, 0, 0, 0, 0, 0, 85, 110, 105, 109, 112, 108, 101, 109, 101, 110, 116, 101, 100, 32, 98, 108, 111, 99, 107, 32, 97, 116, 32, 37, 115, 58, 37, 100, 10, 0, 0, 0, 46, 46, 47, 108, 105, 98, 120, 109, 108, 50, 47, 114, 101, 108, 97, 120, 110, 103, 46, 99, 0, 0, 0, 0, 97, 100, 100, 105, 110, 103, 32, 115, 116, 97, 116, 101, 115, 10, 0, 0, 35, 97, 110, 121, 0, 0, 0, 0, 118, 97, 108, 105, 100, 97, 116, 105, 110, 103, 10, 0, 0, 0, 0, 0, 110, 111, 110, 97, 109, 101, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 115, 116, 97, 116, 101, 115, 10, 0, 0, 0, 0, 0, 0, 78, 85, 76, 76, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 108, 105, 115, 116, 0, 0, 0, 0, 99, 97, 108, 108, 98, 97, 99, 107, 32, 111, 110, 32, 37, 115, 32, 109, 105, 115, 115, 105, 110, 103, 32, 99, 111, 110, 116, 101, 120, 116, 10, 0, 99, 97, 108, 108, 98, 97, 99, 107, 32, 111, 110, 32, 37, 115, 32, 109, 105, 115, 115, 105, 110, 103, 32, 100, 101, 102, 105, 110, 101, 10, 0, 0, 99, 97, 108, 108, 98, 97, 99, 107, 32, 111, 110, 32, 37, 115, 32, 109, 105, 115, 115, 105, 110, 103, 32, 105, 110, 102, 111, 10, 0, 0, 0, 0, 99, 97, 108, 108, 98, 97, 99, 107, 32, 111, 110, 32, 37, 115, 32, 100, 101, 102, 105, 110, 101, 32, 105, 115, 32, 110, 111, 116, 32, 101, 108, 101, 109, 101, 110, 116, 10, 0, 0, 0, 112, 117, 115, 104, 105, 110, 103, 32, 101, 114, 114, 111, 114, 10, 0, 0, 82, 78, 71, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 32, 116, 114, 121, 105, 110, 103, 32, 116, 111, 32, 99, 111, 109, 112, 105, 108, 101, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 0, 110, 111, 110, 101, 0, 0, 0, 0, 101, 109, 112, 116, 121, 0, 0, 0, 110, 111, 116, 65, 108, 108, 111, 119, 101, 100, 0, 0, 0, 0, 0, 0, 101, 120, 99, 101, 112, 116, 0, 0, 116, 101, 120, 116, 0, 0, 0, 0, 101, 108, 101, 109, 101, 110, 116, 0, 100, 97, 116, 97, 116, 121, 112, 101, 0, 0, 0, 0, 0, 0, 0, 0, 118, 97, 108, 117, 101, 0, 0, 0, 108, 105, 115, 116, 0, 0, 0, 0, 97, 116, 116, 114, 105, 98, 117, 116, 101, 0, 0, 0, 0, 0, 0, 0, 100, 101, 102, 0, 0, 0, 0, 0, 114, 101, 102, 0, 0, 0, 0, 0, 101, 120, 116, 101, 114, 110, 97, 108, 82, 101, 102, 0, 0, 0, 0, 0, 112, 97, 114, 101, 110, 116, 82, 101, 102, 0, 0, 0, 0, 0, 0, 0, 111, 112, 116, 105, 111, 110, 97, 108, 0, 0, 0, 0, 0, 0, 0, 0, 122, 101, 114, 111, 79, 114, 77, 111, 114, 101, 0, 0, 0, 0, 0, 0, 111, 110, 101, 79, 114, 77, 111, 114, 101, 0, 0, 0, 0, 0, 0, 0, 99, 104, 111, 105, 99, 101, 0, 0, 103, 114, 111, 117, 112, 0, 0, 0, 105, 110, 116, 101, 114, 108, 101, 97, 118, 101, 0, 0, 0, 0, 0, 0, 115, 116, 97, 114, 116, 0, 0, 0, 110, 111, 111, 112, 0, 0, 0, 0, 112, 97, 114, 97, 109, 0, 0, 0, 117, 110, 107, 110, 111, 119, 110, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 100, 101, 102, 105, 110, 101, 10, 0, 0, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 111, 114, 32, 116, 101, 120, 116, 32, 99, 111, 110, 102, 108, 105, 99, 116, 115, 32, 105, 110, 32, 105, 110, 116, 101, 114, 108, 101, 97, 118, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 65, 116, 116, 114, 105, 98, 117, 116, 101, 115, 32, 99, 111, 110, 102, 108, 105, 99, 116, 115, 32, 105, 110, 32, 105, 110, 116, 101, 114, 108, 101, 97, 118, 101, 10, 0, 0, 0, 0, 0, 105, 110, 32, 105, 110, 116, 101, 114, 108, 101, 97, 118, 101, 32, 99, 111, 109, 112, 117, 116, 97, 116, 105, 111, 110, 10, 0, 0, 0, 0, 0, 0, 24, 231, 2, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 103, 101, 116, 116, 105, 110, 103, 32, 101, 108, 101, 109, 101, 110, 116, 32, 108, 105, 115, 116, 10, 0, 0, 0, 103, 114, 97, 109, 109, 97, 114, 0, 70, 111, 117, 110, 100, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 112, 97, 116, 116, 101, 114, 110, 32, 100, 97, 116, 97, 47, 101, 120, 99, 101, 112, 116, 47, 47, 114, 101, 102, 10, 0, 0, 0, 0, 0, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 102, 111, 117, 110, 100, 32, 110, 111, 32, 100, 101, 102, 105, 110, 101, 32, 102, 111, 114, 32, 112, 97, 114, 101, 110, 116, 32, 114, 101, 102, 115, 10, 0, 0, 0, 0, 0, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 102, 111, 117, 110, 100, 32, 110, 111, 32, 100, 101, 102, 105, 110, 101, 32, 102, 111, 114, 32, 114, 101, 102, 32, 37, 115, 10, 0, 0, 0, 0, 110, 117, 108, 108, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 112, 97, 116, 116, 101, 114, 110, 32, 100, 97, 116, 97, 47, 101, 120, 99, 101, 112, 116, 47, 47, 101, 108, 101, 109, 101, 110, 116, 40, 114, 101, 102, 41, 10, 0, 0, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 112, 97, 116, 116, 101, 114, 110, 32, 108, 105, 115, 116, 47, 47, 101, 108, 101, 109, 101, 110, 116, 40, 114, 101, 102, 41, 10, 0, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 112, 97, 116, 116, 101, 114, 110, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 47, 47, 101, 108, 101, 109, 101, 110, 116, 40, 114, 101, 102, 41, 10, 0, 0, 0, 0, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 115, 32, 104, 97, 118, 101, 32, 97, 32, 99, 111, 110, 116, 101, 110, 116, 32, 116, 121, 112, 101, 32, 101, 114, 114, 111, 114, 10, 0, 0, 0, 0, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 104, 97, 115, 32, 97, 32, 99, 111, 110, 116, 101, 110, 116, 32, 116, 121, 112, 101, 32, 101, 114, 114, 111, 114, 10, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 112, 97, 116, 116, 101, 114, 110, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 47, 47, 97, 116, 116, 114, 105, 98, 117, 116, 101, 10, 0, 0, 0, 70, 111, 117, 110, 100, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 112, 97, 116, 116, 101, 114, 110, 32, 108, 105, 115, 116, 47, 47, 97, 116, 116, 114, 105, 98, 117, 116, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 112, 97, 116, 116, 101, 114, 110, 32, 111, 110, 101, 79, 114, 77, 111, 114, 101, 47, 47, 103, 114, 111, 117, 112, 47, 47, 97, 116, 116, 114, 105, 98, 117, 116, 101, 10, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 112, 97, 116, 116, 101, 114, 110, 32, 111, 110, 101, 79, 114, 77, 111, 114, 101, 47, 47, 105, 110, 116, 101, 114, 108, 101, 97, 118, 101, 47, 47, 97, 116, 116, 114, 105, 98, 117, 116, 101, 10, 0, 0, 0, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 112, 97, 116, 116, 101, 114, 110, 32, 100, 97, 116, 97, 47, 101, 120, 99, 101, 112, 116, 47, 47, 97, 116, 116, 114, 105, 98, 117, 116, 101, 10, 0, 70, 111, 117, 110, 100, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 112, 97, 116, 116, 101, 114, 110, 32, 115, 116, 97, 114, 116, 47, 47, 97, 116, 116, 114, 105, 98, 117, 116, 101, 10, 0, 0, 0, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 97, 110, 121, 78, 97, 109, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 119, 105, 116, 104, 111, 117, 116, 32, 111, 110, 101, 79, 114, 77, 111, 114, 101, 32, 97, 110, 99, 101, 115, 116, 111, 114, 10, 0, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 110, 115, 78, 97, 109, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 119, 105, 116, 104, 111, 117, 116, 32, 111, 110, 101, 79, 114, 77, 111, 114, 101, 32, 97, 110, 99, 101, 115, 116, 111, 114, 10, 0, 0, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 112, 97, 116, 116, 101, 114, 110, 32, 100, 97, 116, 97, 47, 101, 120, 99, 101, 112, 116, 47, 47, 111, 110, 101, 79, 114, 77, 111, 114, 101, 10, 0, 70, 111, 117, 110, 100, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 112, 97, 116, 116, 101, 114, 110, 32, 115, 116, 97, 114, 116, 47, 47, 111, 110, 101, 79, 114, 77, 111, 114, 101, 10, 0, 0, 0, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 112, 97, 116, 116, 101, 114, 110, 32, 108, 105, 115, 116, 47, 47, 108, 105, 115, 116, 10, 0, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 112, 97, 116, 116, 101, 114, 110, 32, 100, 97, 116, 97, 47, 101, 120, 99, 101, 112, 116, 47, 47, 108, 105, 115, 116, 10, 0, 0, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 112, 97, 116, 116, 101, 114, 110, 32, 115, 116, 97, 114, 116, 47, 47, 108, 105, 115, 116, 10, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 112, 97, 116, 116, 101, 114, 110, 32, 100, 97, 116, 97, 47, 101, 120, 99, 101, 112, 116, 47, 47, 103, 114, 111, 117, 112, 10, 0, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 112, 97, 116, 116, 101, 114, 110, 32, 115, 116, 97, 114, 116, 47, 47, 103, 114, 111, 117, 112, 10, 0, 0, 0, 70, 111, 117, 110, 100, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 112, 97, 116, 116, 101, 114, 110, 32, 108, 105, 115, 116, 47, 47, 105, 110, 116, 101, 114, 108, 101, 97, 118, 101, 10, 0, 0, 0, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 112, 97, 116, 116, 101, 114, 110, 32, 100, 97, 116, 97, 47, 101, 120, 99, 101, 112, 116, 47, 47, 105, 110, 116, 101, 114, 108, 101, 97, 118, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 112, 97, 116, 116, 101, 114, 110, 32, 115, 116, 97, 114, 116, 47, 47, 105, 110, 116, 101, 114, 108, 101, 97, 118, 101, 10, 0, 0, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 112, 97, 116, 116, 101, 114, 110, 32, 115, 116, 97, 114, 116, 47, 47, 100, 97, 116, 97, 10, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 112, 97, 116, 116, 101, 114, 110, 32, 115, 116, 97, 114, 116, 47, 47, 118, 97, 108, 117, 101, 10, 0, 0, 0, 70, 111, 117, 110, 100, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 112, 97, 116, 116, 101, 114, 110, 32, 108, 105, 115, 116, 47, 47, 116, 101, 120, 116, 10, 0, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 112, 97, 116, 116, 101, 114, 110, 32, 100, 97, 116, 97, 47, 101, 120, 99, 101, 112, 116, 47, 47, 116, 101, 120, 116, 10, 0, 0, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 112, 97, 116, 116, 101, 114, 110, 32, 115, 116, 97, 114, 116, 47, 47, 116, 101, 120, 116, 10, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 112, 97, 116, 116, 101, 114, 110, 32, 100, 97, 116, 97, 47, 101, 120, 99, 101, 112, 116, 47, 47, 101, 109, 112, 116, 121, 10, 0, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 112, 97, 116, 116, 101, 114, 110, 32, 115, 116, 97, 114, 116, 47, 47, 101, 109, 112, 116, 121, 10, 0, 0, 0, 98, 117, 105, 108, 100, 105, 110, 103, 32, 99, 104, 111, 105, 99, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 98, 117, 105, 108, 100, 105, 110, 103, 32, 103, 114, 111, 117, 112, 10, 0, 65, 116, 116, 114, 105, 98, 117, 116, 101, 115, 32, 99, 111, 110, 102, 108, 105, 99, 116, 115, 32, 105, 110, 32, 103, 114, 111, 117, 112, 10, 0, 0, 68, 101, 116, 101, 99, 116, 101, 100, 32, 97, 32, 99, 121, 99, 108, 101, 32, 105, 110, 32, 37, 115, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 115, 10, 0, 0, 0, 0, 0, 0, 115, 116, 97, 114, 116, 32, 104, 97, 115, 32, 110, 111, 32, 99, 104, 105, 108, 100, 114, 101, 110, 10, 0, 0, 101, 108, 101, 109, 101, 110, 116, 32, 101, 109, 112, 116, 121, 32, 105, 115, 32, 110, 111, 116, 32, 101, 109, 112, 116, 121, 10, 0, 0, 0, 0, 0, 101, 108, 101, 109, 101, 110, 116, 32, 110, 111, 116, 65, 108, 108, 111, 119, 101, 100, 32, 105, 115, 32, 110, 111, 116, 32, 101, 109, 112, 116, 121, 10, 0, 0, 0, 0, 0, 0, 0, 0, 115, 116, 97, 114, 116, 32, 109, 111, 114, 101, 32, 116, 104, 97, 110, 32, 111, 110, 101, 32, 99, 104, 105, 108, 100, 114, 101, 110, 10, 0, 0, 0, 101, 109, 112, 116, 121, 58, 32, 104, 97, 100, 32, 97, 32, 99, 104, 105, 108, 100, 32, 110, 111, 100, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 116, 101, 120, 116, 58, 32, 104, 97, 100, 32, 97, 32, 99, 104, 105, 108, 100, 32, 110, 111, 100, 101, 10, 0, 69, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 105, 115, 32, 101, 109, 112, 116, 121, 10, 0, 0, 0, 0, 110, 97, 109, 101, 0, 0, 0, 0, 114, 101, 102, 32, 104, 97, 115, 32, 110, 111, 32, 110, 97, 109, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 114, 101, 102, 32, 110, 97, 109, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 97, 110, 32, 78, 67, 78, 97, 109, 101, 10, 0, 114, 101, 102, 32, 105, 115, 32, 110, 111, 116, 32, 101, 109, 112, 116, 121, 10, 0, 0, 0, 0, 0, 0, 0, 67, 111, 117, 108, 100, 32, 110, 111, 116, 32, 99, 114, 101, 97, 116, 101, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 115, 32, 104, 97, 115, 104, 10, 0, 0, 0, 0, 0, 0, 0, 69, 114, 114, 111, 114, 32, 114, 101, 102, 115, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 115, 32, 39, 37, 115, 39, 10, 0, 0, 0, 0, 69, 114, 114, 111, 114, 32, 114, 101, 102, 115, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 115, 10, 0, 100, 97, 116, 97, 0, 0, 0, 0, 120, 109, 108, 82, 101, 108, 97, 120, 78, 71, 80, 97, 114, 115, 101, 58, 32, 110, 111, 116, 65, 108, 108, 111, 119, 101, 100, 32, 101, 108, 101, 109, 101, 110, 116, 32, 105, 115, 32, 110, 111, 116, 32, 101, 109, 112, 116, 121, 10, 0, 0, 0, 0, 0, 0, 0, 85, 115, 101, 32, 111, 102, 32, 112, 97, 114, 101, 110, 116, 82, 101, 102, 32, 119, 105, 116, 104, 111, 117, 116, 32, 97, 32, 112, 97, 114, 101, 110, 116, 32, 103, 114, 97, 109, 109, 97, 114, 10, 0, 0, 0, 0, 0, 0, 112, 97, 114, 101, 110, 116, 82, 101, 102, 32, 104, 97, 115, 32, 110, 111, 32, 110, 97, 109, 101, 10, 0, 0, 112, 97, 114, 101, 110, 116, 82, 101, 102, 32, 110, 97, 109, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 97, 110, 32, 78, 67, 78, 97, 109, 101, 10, 0, 0, 0, 112, 97, 114, 101, 110, 116, 82, 101, 102, 32, 105, 115, 32, 110, 111, 116, 32, 101, 109, 112, 116, 121, 10, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 32, 112, 97, 114, 101, 110, 116, 82, 101, 102, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 115, 32, 39, 37, 115, 39, 10, 0, 0, 0, 0, 0, 0, 109, 105, 120, 101, 100, 0, 0, 0, 77, 105, 120, 101, 100, 32, 105, 115, 32, 101, 109, 112, 116, 121, 10, 0, 85, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 110, 111, 100, 101, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 112, 97, 116, 116, 101, 114, 110, 10, 0, 0, 0, 0, 110, 115, 0, 0, 0, 0, 0, 0, 99, 114, 101, 97, 116, 101, 32, 105, 110, 116, 101, 114, 108, 101, 97, 118, 101, 115, 10, 0, 0, 0, 0, 0, 105, 110, 116, 101, 114, 108, 101, 97, 118, 101, 37, 100, 0, 0, 0, 0, 70, 97, 105, 108, 101, 100, 32, 116, 111, 32, 97, 100, 100, 32, 37, 115, 32, 116, 111, 32, 104, 97, 115, 104, 32, 116, 97, 98, 108, 101, 10, 0, 69, 108, 101, 109, 101, 110, 116, 32, 105, 110, 116, 101, 114, 108, 101, 97, 118, 101, 32, 105, 115, 32, 101, 109, 112, 116, 121, 10, 0, 0, 0, 0, 116, 121, 112, 101, 0, 0, 0, 0, 118, 97, 108, 117, 101, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 97, 110, 32, 78, 67, 78, 97, 109, 101, 10, 0, 0, 0, 0, 0, 0, 0, 104, 116, 116, 112, 58, 47, 47, 114, 101, 108, 97, 120, 110, 103, 46, 111, 114, 103, 47, 110, 115, 47, 115, 116, 114, 117, 99, 116, 117, 114, 101, 47, 49, 46, 48, 0, 0, 0, 0, 0, 85, 115, 101, 32, 111, 102, 32, 117, 110, 114, 101, 103, 105, 115, 116, 101, 114, 101, 100, 32, 116, 121, 112, 101, 32, 108, 105, 98, 114, 97, 114, 121, 32, 39, 37, 115, 39, 10, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 32, 119, 105, 116, 104, 32, 116, 121, 112, 101, 32, 108, 105, 98, 114, 97, 114, 121, 32, 39, 37, 115, 39, 58, 32, 110, 111, 32, 39, 104, 97, 118, 101, 39, 10, 0, 0, 0, 0, 0, 0, 0, 69, 114, 114, 111, 114, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 101, 120, 112, 111, 114, 116, 101, 100, 32, 98, 121, 32, 116, 121, 112, 101, 32, 108, 105, 98, 114, 97, 114, 121, 32, 39, 37, 115, 39, 10, 0, 0, 0, 69, 120, 112, 101, 99, 116, 105, 110, 103, 32, 97, 32, 115, 105, 110, 103, 108, 101, 32, 116, 101, 120, 116, 32, 118, 97, 108, 117, 101, 32, 102, 111, 114, 32, 60, 118, 97, 108, 117, 101, 62, 99, 111, 110, 116, 101, 110, 116, 10, 0, 0, 0, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 60, 118, 97, 108, 117, 101, 62, 32, 104, 97, 115, 32, 110, 111, 32, 99, 111, 110, 116, 101, 110, 116, 10, 0, 86, 97, 108, 117, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 97, 99, 99, 101, 112, 116, 97, 98, 108, 101, 32, 102, 111, 114, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 10, 0, 0, 0, 0, 0, 100, 97, 116, 97, 116, 121, 112, 101, 76, 105, 98, 114, 97, 114, 121, 0, 58, 47, 35, 63, 0, 0, 0, 0, 100, 97, 116, 97, 32, 104, 97, 115, 32, 110, 111, 32, 116, 121, 112, 101, 10, 0, 0, 0, 0, 0, 0, 0, 100, 97, 116, 97, 32, 116, 121, 112, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 97, 110, 32, 78, 67, 78, 97, 109, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 73, 68, 82, 69, 70, 0, 0, 0, 73, 68, 82, 69, 70, 83, 0, 0, 84, 121, 112, 101, 32, 108, 105, 98, 114, 97, 114, 121, 32, 39, 37, 115, 39, 32, 100, 111, 101, 115, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 32, 116, 121, 112, 101, 32, 112, 97, 114, 97, 109, 101, 116, 101, 114, 115, 10, 0, 0, 0, 0, 0, 0, 0, 112, 97, 114, 97, 109, 32, 104, 97, 115, 32, 110, 111, 32, 110, 97, 109, 101, 10, 0, 0, 0, 0, 0, 0, 101, 120, 99, 101, 112, 116, 32, 104, 97, 115, 32, 110, 111, 32, 99, 111, 110, 116, 101, 110, 116, 10, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 100, 97, 116, 97, 32, 104, 97, 115, 32, 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 99, 111, 110, 116, 101, 110, 116, 32, 37, 115, 10, 0, 120, 109, 108, 82, 101, 108, 97, 120, 78, 71, 80, 97, 114, 115, 101, 97, 116, 116, 114, 105, 98, 117, 116, 101, 58, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 104, 97, 115, 32, 110, 111, 32, 99, 104, 105, 108, 100, 114, 101, 110, 10, 0, 0, 0, 0, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 104, 97, 115, 32, 105, 110, 118, 97, 108, 105, 100, 32, 99, 111, 110, 116, 101, 110, 116, 10, 0, 0, 82, 78, 71, 32, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 44, 32, 110, 111, 111, 112, 32, 102, 111, 117, 110, 100, 32, 105, 110, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 10, 0, 0, 0, 0, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 104, 97, 115, 32, 109, 117, 108, 116, 105, 112, 108, 101, 32, 99, 104, 105, 108, 100, 114, 101, 110, 10, 0, 0, 0, 0, 0, 0, 0, 0, 97, 110, 121, 78, 97, 109, 101, 0, 110, 115, 78, 97, 109, 101, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 110, 97, 109, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 97, 110, 32, 78, 67, 78, 97, 109, 101, 10, 0, 0, 110, 97, 109, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 97, 110, 32, 78, 67, 78, 97, 109, 101, 10, 0, 0, 0, 0, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 50, 48, 48, 48, 47, 120, 109, 108, 110, 115, 0, 0, 0, 0, 65, 116, 116, 114, 105, 98, 117, 116, 101, 32, 119, 105, 116, 104, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 101, 100, 10, 0, 0, 0, 120, 109, 108, 110, 115, 0, 0, 0, 65, 116, 116, 114, 105, 98, 117, 116, 101, 32, 119, 105, 116, 104, 32, 81, 78, 97, 109, 101, 32, 39, 120, 109, 108, 110, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 101, 100, 10, 0, 0, 0, 0, 110, 115, 78, 97, 109, 101, 32, 104, 97, 115, 32, 110, 111, 32, 110, 115, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 10, 0, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 99, 104, 111, 105, 99, 101, 32, 105, 115, 32, 101, 109, 112, 116, 121, 10, 0, 0, 0, 0, 0, 0, 0, 0, 101, 120, 112, 101, 99, 116, 105, 110, 103, 32, 110, 97, 109, 101, 44, 32, 97, 110, 121, 78, 97, 109, 101, 44, 32, 110, 115, 78, 97, 109, 101, 32, 111, 114, 32, 99, 104, 111, 105, 99, 101, 32, 58, 32, 103, 111, 116, 32, 37, 115, 10, 0, 0, 0, 0, 0, 110, 111, 116, 104, 105, 110, 103, 0, 69, 120, 112, 101, 99, 116, 105, 110, 103, 32, 97, 110, 32, 101, 120, 99, 101, 112, 116, 32, 110, 111, 100, 101, 10, 0, 0, 0, 0, 0, 0, 0, 101, 120, 99, 101, 112, 116, 78, 97, 109, 101, 67, 108, 97, 115, 115, 32, 97, 108, 108, 111, 119, 115, 32, 111, 110, 108, 121, 32, 97, 32, 115, 105, 110, 103, 108, 101, 32, 101, 120, 99, 101, 112, 116, 32, 110, 111, 100, 101, 10, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 82, 101, 108, 97, 120, 78, 71, 80, 97, 114, 115, 101, 69, 108, 101, 109, 101, 110, 116, 58, 32, 101, 108, 101, 109, 101, 110, 116, 32, 104, 97, 115, 32, 110, 111, 32, 99, 104, 105, 108, 100, 114, 101, 110, 10, 0, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 82, 101, 108, 97, 120, 78, 71, 80, 97, 114, 115, 101, 69, 108, 101, 109, 101, 110, 116, 58, 32, 101, 108, 101, 109, 101, 110, 116, 32, 104, 97, 115, 32, 110, 111, 32, 99, 111, 110, 116, 101, 110, 116, 10, 0, 82, 78, 71, 32, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 44, 32, 115, 116, 97, 114, 116, 32, 102, 111, 117, 110, 100, 32, 105, 110, 32, 101, 108, 101, 109, 101, 110, 116, 10, 0, 0, 0, 0, 0, 82, 78, 71, 32, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 44, 32, 112, 97, 114, 97, 109, 32, 102, 111, 117, 110, 100, 32, 105, 110, 32, 101, 108, 101, 109, 101, 110, 116, 10, 0, 0, 0, 0, 0, 82, 78, 71, 32, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 44, 32, 101, 120, 99, 101, 112, 116, 32, 102, 111, 117, 110, 100, 32, 105, 110, 32, 101, 108, 101, 109, 101, 110, 116, 10, 0, 0, 0, 0, 82, 78, 71, 32, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 44, 32, 110, 111, 111, 112, 32, 102, 111, 117, 110, 100, 32, 105, 110, 32, 101, 108, 101, 109, 101, 110, 116, 10, 0, 0, 0, 0, 0, 0, 70, 97, 105, 108, 101, 100, 32, 116, 111, 32, 112, 97, 114, 115, 101, 32, 60, 103, 114, 97, 109, 109, 97, 114, 62, 32, 99, 111, 110, 116, 101, 110, 116, 10, 0, 0, 0, 0, 0, 0, 69, 108, 101, 109, 101, 110, 116, 32, 60, 103, 114, 97, 109, 109, 97, 114, 62, 32, 104, 97, 115, 32, 110, 111, 32, 60, 115, 116, 97, 114, 116, 62, 10, 0, 0, 0, 0, 0, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 58, 32, 110, 111, 32, 103, 114, 97, 109, 109, 97, 114, 32, 105, 110, 32, 67, 104, 101, 99, 107, 82, 101, 102, 101, 114, 101, 110, 99, 101, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 58, 32, 114, 101, 102, 101, 114, 101, 110, 99, 101, 32, 104, 97, 115, 32, 99, 111, 110, 116, 101, 110, 116, 32, 105, 110, 32, 67, 104, 101, 99, 107, 82, 101, 102, 101, 114, 101, 110, 99, 101, 32, 37, 115, 10, 0, 0, 0, 0, 0, 82, 101, 102, 101, 114, 101, 110, 99, 101, 32, 37, 115, 32, 104, 97, 115, 32, 110, 111, 32, 109, 97, 116, 99, 104, 105, 110, 103, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 10, 0, 0, 0, 0, 0, 0, 0, 0, 99, 111, 109, 98, 105, 110, 101, 0, 68, 101, 102, 105, 110, 101, 115, 32, 102, 111, 114, 32, 37, 115, 32, 117, 115, 101, 32, 98, 111, 116, 104, 32, 39, 99, 104, 111, 105, 99, 101, 39, 32, 97, 110, 100, 32, 39, 105, 110, 116, 101, 114, 108, 101, 97, 118, 101, 39, 10, 0, 0, 0, 0, 0, 0, 68, 101, 102, 105, 110, 101, 115, 32, 102, 111, 114, 32, 37, 115, 32, 117, 115, 101, 32, 117, 110, 107, 110, 111, 119, 110, 32, 99, 111, 109, 98, 105, 110, 101, 32, 118, 97, 108, 117, 101, 32, 39, 37, 115, 39, 39, 10, 0, 83, 111, 109, 101, 32, 100, 101, 102, 105, 110, 101, 115, 32, 102, 111, 114, 32, 37, 115, 32, 110, 101, 101, 100, 115, 32, 116, 104, 101, 32, 99, 111, 109, 98, 105, 110, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 70, 97, 105, 108, 101, 100, 32, 116, 111, 32, 99, 114, 101, 97, 116, 101, 32, 105, 110, 116, 101, 114, 108, 101, 97, 118, 101, 115, 32, 104, 97, 115, 104, 32, 116, 97, 98, 108, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 58, 32, 115, 116, 97, 114, 116, 32, 101, 108, 101, 109, 101, 110, 116, 32, 110, 111, 116, 32, 102, 111, 117, 110, 100, 10, 0, 0, 0, 0, 0, 0, 0, 0, 60, 115, 116, 97, 114, 116, 62, 32, 117, 115, 101, 32, 98, 111, 116, 104, 32, 39, 99, 104, 111, 105, 99, 101, 39, 32, 97, 110, 100, 32, 39, 105, 110, 116, 101, 114, 108, 101, 97, 118, 101, 39, 10, 0, 0, 0, 0, 0, 60, 115, 116, 97, 114, 116, 62, 32, 117, 115, 101, 115, 32, 117, 110, 107, 110, 111, 119, 110, 32, 99, 111, 109, 98, 105, 110, 101, 32, 118, 97, 108, 117, 101, 32, 39, 37, 115, 39, 39, 10, 0, 0, 0, 0, 0, 0, 0, 83, 111, 109, 101, 32, 60, 115, 116, 97, 114, 116, 62, 32, 101, 108, 101, 109, 101, 110, 116, 32, 109, 105, 115, 115, 32, 116, 104, 101, 32, 99, 111, 109, 98, 105, 110, 101, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 103, 114, 97, 109, 109, 97, 114, 32, 104, 97, 115, 32, 110, 111, 32, 99, 104, 105, 108, 100, 114, 101, 110, 10, 0, 0, 0, 0, 0, 0, 0, 0, 100, 101, 102, 105, 110, 101, 0, 0, 105, 110, 99, 108, 117, 100, 101, 0, 103, 114, 97, 109, 109, 97, 114, 32, 104, 97, 115, 32, 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 99, 104, 105, 108, 100, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 0, 73, 110, 99, 108, 117, 100, 101, 32, 110, 111, 100, 101, 32, 104, 97, 115, 32, 110, 111, 32, 100, 97, 116, 97, 10, 0, 0, 0, 0, 0, 0, 0, 73, 110, 99, 108, 117, 100, 101, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 105, 115, 32, 101, 109, 112, 116, 121, 10, 0, 0, 0, 0, 0, 0, 73, 110, 99, 108, 117, 100, 101, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 114, 111, 111, 116, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 103, 114, 97, 109, 109, 97, 114, 10, 0, 100, 101, 102, 105, 110, 101, 32, 104, 97, 115, 32, 110, 111, 32, 110, 97, 109, 101, 10, 0, 0, 0, 0, 0, 100, 101, 102, 105, 110, 101, 32, 110, 97, 109, 101, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 97, 110, 32, 78, 67, 78, 97, 109, 101, 10, 0, 0, 0, 0, 0, 0, 100, 101, 102, 105, 110, 101, 32, 104, 97, 115, 32, 110, 111, 32, 99, 104, 105, 108, 100, 114, 101, 110, 10, 0, 67, 111, 117, 108, 100, 32, 110, 111, 116, 32, 99, 114, 101, 97, 116, 101, 32, 100, 101, 102, 105, 110, 105, 116, 105, 111, 110, 32, 104, 97, 115, 104, 10, 0, 0, 0, 0, 0, 0, 0, 73, 110, 116, 101, 114, 110, 97, 108, 32, 101, 114, 114, 111, 114, 32, 111, 110, 32, 100, 101, 102, 105, 110, 101, 32, 97, 103, 103, 114, 101, 103, 97, 116, 105, 111, 110, 32, 111, 102, 32, 37, 115, 10, 0, 0, 0, 0, 0, 101, 108, 101, 109, 101, 110, 116, 32, 37, 115, 32, 100, 111, 101, 115, 110, 39, 116, 32, 97, 108, 108, 111, 119, 32, 102, 111, 114, 101, 105, 103, 110, 32, 101, 108, 101, 109, 101, 110, 116, 115, 10, 0, 0, 0, 0, 0, 0, 104, 114, 101, 102, 0, 0, 0, 0, 120, 109, 108, 82, 101, 108, 97, 120, 78, 71, 80, 97, 114, 115, 101, 58, 32, 101, 120, 116, 101, 114, 110, 97, 108, 82, 101, 102, 32, 104, 97, 115, 32, 110, 111, 32, 104, 114, 101, 102, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 10, 0, 0, 0, 0, 0, 73, 110, 99, 111, 114, 114, 101, 99, 116, 32, 85, 82, 73, 32, 102, 111, 114, 32, 101, 120, 116, 101, 114, 110, 97, 108, 82, 101, 102, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 70, 114, 97, 103, 109, 101, 110, 116, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 105, 110, 32, 85, 82, 73, 32, 102, 111, 114, 32, 101, 120, 116, 101, 114, 110, 97, 108, 82, 101, 102, 32, 37, 115, 10, 0, 0, 0, 70, 97, 105, 108, 101, 100, 32, 116, 111, 32, 99, 111, 109, 112, 117, 116, 101, 32, 85, 82, 76, 32, 102, 111, 114, 32, 101, 120, 116, 101, 114, 110, 97, 108, 82, 101, 102, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 70, 97, 105, 108, 101, 100, 32, 116, 111, 32, 108, 111, 97, 100, 32, 101, 120, 116, 101, 114, 110, 97, 108, 82, 101, 102, 32, 37, 115, 10, 0, 0, 120, 109, 108, 82, 101, 108, 97, 120, 78, 71, 80, 97, 114, 115, 101, 58, 32, 105, 110, 99, 108, 117, 100, 101, 32, 104, 97, 115, 32, 110, 111, 32, 104, 114, 101, 102, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 10, 0, 70, 97, 105, 108, 101, 100, 32, 116, 111, 32, 99, 111, 109, 112, 117, 116, 101, 32, 85, 82, 76, 32, 102, 111, 114, 32, 105, 110, 99, 108, 117, 100, 101, 32, 37, 115, 10, 0, 0, 0, 70, 97, 105, 108, 101, 100, 32, 116, 111, 32, 108, 111, 97, 100, 32, 105, 110, 99, 108, 117, 100, 101, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 70, 97, 105, 108, 101, 100, 32, 116, 111, 32, 99, 114, 101, 97, 116, 101, 32, 97, 32, 110, 97, 109, 101, 32, 37, 115, 32, 101, 108, 101, 109, 101, 110, 116, 10, 0, 0, 0, 0, 0, 120, 109, 108, 82, 101, 108, 97, 120, 78, 71, 80, 97, 114, 115, 101, 58, 32, 110, 111, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 102, 111, 114, 32, 112, 114, 101, 102, 105, 120, 32, 37, 115, 10, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 110, 115, 78, 97, 109, 101, 47, 101, 120, 99, 101, 112, 116, 47, 47, 110, 115, 78, 97, 109, 101, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 99, 111, 110, 115, 116, 114, 117, 99, 116, 10, 0, 0, 0, 0, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 97, 110, 121, 78, 97, 109, 101, 47, 101, 120, 99, 101, 112, 116, 47, 47, 97, 110, 121, 78, 97, 109, 101, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 99, 111, 110, 115, 116, 114, 117, 99, 116, 10, 0, 0, 0, 0, 0, 0, 70, 111, 117, 110, 100, 32, 110, 115, 78, 97, 109, 101, 47, 101, 120, 99, 101, 112, 116, 47, 47, 97, 110, 121, 78, 97, 109, 101, 32, 102, 111, 114, 98, 105, 100, 100, 101, 110, 32, 99, 111, 110, 115, 116, 114, 117, 99, 116, 10, 0, 0, 0, 0, 0, 0, 0, 100, 105, 118, 0, 0, 0, 0, 0, 68, 101, 116, 101, 99, 116, 101, 100, 32, 97, 110, 32, 73, 110, 99, 108, 117, 100, 101, 32, 114, 101, 99, 117, 114, 115, 105, 111, 110, 32, 102, 111, 114, 32, 37, 115, 10, 0, 0, 0, 120, 109, 108, 82, 101, 108, 97, 120, 78, 71, 58, 32, 99, 111, 117, 108, 100, 32, 110, 111, 116, 32, 108, 111, 97, 100, 32, 37, 115, 10, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 105, 110, 99, 108, 117, 100, 101, 10, 0, 0, 0, 0, 0, 120, 109, 108, 82, 101, 108, 97, 120, 78, 71, 58, 32, 105, 110, 99, 108, 117, 100, 101, 100, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 105, 115, 32, 101, 109, 112, 116, 121, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 120, 109, 108, 82, 101, 108, 97, 120, 78, 71, 58, 32, 105, 110, 99, 108, 117, 100, 101, 100, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 37, 115, 32, 114, 111, 111, 116, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 103, 114, 97, 109, 109, 97, 114, 10, 0, 120, 109, 108, 82, 101, 108, 97, 120, 78, 71, 58, 32, 105, 110, 99, 108, 117, 100, 101, 32, 37, 115, 32, 104, 97, 115, 32, 97, 32, 115, 116, 97, 114, 116, 32, 98, 117, 116, 32, 110, 111, 116, 32, 116, 104, 101, 32, 105, 110, 99, 108, 117, 100, 101, 100, 32, 103, 114, 97, 109, 109, 97, 114, 10, 0, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 82, 101, 108, 97, 120, 78, 71, 58, 32, 105, 110, 99, 108, 117, 100, 101, 32, 37, 115, 32, 104, 97, 115, 32, 100, 101, 102, 105, 110, 101, 32, 119, 105, 116, 104, 111, 117, 116, 32, 110, 97, 109, 101, 10, 0, 120, 109, 108, 82, 101, 108, 97, 120, 78, 71, 58, 32, 105, 110, 99, 108, 117, 100, 101, 32, 37, 115, 32, 104, 97, 115, 32, 97, 32, 100, 101, 102, 105, 110, 101, 32, 37, 115, 32, 98, 117, 116, 32, 110, 111, 116, 32, 116, 104, 101, 32, 105, 110, 99, 108, 117, 100, 101, 100, 32, 103, 114, 97, 109, 109, 97, 114, 10, 0, 0, 0, 0, 68, 101, 116, 101, 99, 116, 101, 100, 32, 97, 110, 32, 101, 120, 116, 101, 114, 110, 97, 108, 82, 101, 102, 32, 114, 101, 99, 117, 114, 115, 105, 111, 110, 32, 102, 111, 114, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 82, 101, 108, 97, 120, 78, 71, 58, 32, 97, 108, 108, 111, 99, 97, 116, 101, 32, 109, 101, 109, 111, 114, 121, 32, 102, 111, 114, 32, 100, 111, 99, 32, 37, 115, 10, 0, 97, 100, 100, 105, 110, 103, 32, 100, 111, 99, 117, 109, 101, 110, 116, 10, 0, 0, 0, 0, 0, 0, 0, 0, 65, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 97, 108, 108, 111, 119, 101, 100, 32, 111, 110, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 65, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 99, 111, 110, 116, 97, 105, 110, 115, 32, 105, 110, 118, 97, 108, 105, 100, 32, 85, 82, 73, 32, 37, 115, 10, 0, 0, 0, 65, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 85, 82, 73, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 97, 98, 115, 111, 108, 117, 116, 101, 10, 0, 0, 0, 0, 65, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 85, 82, 73, 32, 37, 115, 32, 104, 97, 115, 32, 97, 32, 102, 114, 97, 103, 109, 101, 110, 116, 32, 73, 68, 10, 0, 0, 85, 110, 107, 110, 111, 119, 110, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 111, 110, 32, 37, 115, 10, 0, 0, 0, 0, 0, 115, 116, 114, 105, 110, 103, 0, 0, 116, 111, 107, 101, 110, 0, 0, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 50, 48, 48, 49, 47, 88, 77, 76, 83, 99, 104, 101, 109, 97, 0, 0, 0, 0, 0, 0, 0, 0, 109, 105, 110, 73, 110, 99, 108, 117, 115, 105, 118, 101, 0, 0, 0, 0, 109, 105, 110, 69, 120, 99, 108, 117, 115, 105, 118, 101, 0, 0, 0, 0, 109, 97, 120, 73, 110, 99, 108, 117, 115, 105, 118, 101, 0, 0, 0, 0, 109, 97, 120, 69, 120, 99, 108, 117, 115, 105, 118, 101, 0, 0, 0, 0, 116, 111, 116, 97, 108, 68, 105, 103, 105, 116, 115, 0, 0, 0, 0, 0, 102, 114, 97, 99, 116, 105, 111, 110, 68, 105, 103, 105, 116, 115, 0, 0, 112, 97, 116, 116, 101, 114, 110, 0, 101, 110, 117, 109, 101, 114, 97, 116, 105, 111, 110, 0, 0, 0, 0, 0, 119, 104, 105, 116, 101, 83, 112, 97, 99, 101, 0, 0, 0, 0, 0, 0, 108, 101, 110, 103, 116, 104, 0, 0, 109, 97, 120, 76, 101, 110, 103, 116, 104, 0, 0, 0, 0, 0, 0, 0, 109, 105, 110, 76, 101, 110, 103, 116, 104, 0, 0, 0, 0, 0, 0, 0, 82, 101, 108, 97, 120, 45, 78, 71, 32, 116, 121, 112, 101, 115, 32, 108, 105, 98, 114, 97, 114, 121, 32, 39, 37, 115, 39, 32, 97, 108, 114, 101, 97, 100, 121, 32, 114, 101, 103, 105, 115, 116, 101, 114, 101, 100, 10, 0, 97, 100, 100, 105, 110, 103, 32, 116, 121, 112, 101, 115, 32, 108, 105, 98, 114, 97, 114, 121, 10, 0, 0, 0, 82, 101, 108, 97, 120, 45, 78, 71, 32, 116, 121, 112, 101, 115, 32, 108, 105, 98, 114, 97, 114, 121, 32, 102, 97, 105, 108, 101, 100, 32, 116, 111, 32, 114, 101, 103, 105, 115, 116, 101, 114, 32, 39, 37, 115, 39, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 83, 65, 88, 50, 73, 110, 116, 101, 114, 110, 97, 108, 83, 117, 98, 115, 101, 116, 0, 0, 0, 120, 109, 108, 83, 65, 88, 50, 69, 120, 116, 101, 114, 110, 97, 108, 83, 117, 98, 115, 101, 116, 0, 0, 0, 69, 110, 116, 105, 116, 121, 40, 37, 115, 41, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 109, 97, 114, 107, 101, 100, 32, 115, 116, 97, 110, 100, 97, 108, 111, 110, 101, 32, 98, 117, 116, 32, 114, 101, 113, 117, 105, 114, 101, 115, 32, 101, 120, 116, 101, 114, 110, 97, 108, 32, 115, 117, 98, 115, 101, 116, 10, 0, 0, 0, 0, 0, 70, 97, 105, 108, 117, 114, 101, 32, 116, 111, 32, 112, 114, 111, 99, 101, 115, 115, 32, 101, 110, 116, 105, 116, 121, 32, 37, 115, 10, 0, 0, 0, 69, 110, 116, 105, 116, 121, 40, 37, 115, 41, 32, 97, 108, 114, 101, 97, 100, 121, 32, 100, 101, 102, 105, 110, 101, 100, 32, 105, 110, 32, 116, 104, 101, 32, 105, 110, 116, 101, 114, 110, 97, 108, 32, 115, 117, 98, 115, 101, 116, 10, 0, 0, 0, 0, 0, 0, 69, 110, 116, 105, 116, 121, 40, 37, 115, 41, 32, 97, 108, 114, 101, 97, 100, 121, 32, 100, 101, 102, 105, 110, 101, 100, 32, 105, 110, 32, 116, 104, 101, 32, 101, 120, 116, 101, 114, 110, 97, 108, 32, 115, 117, 98, 115, 101, 116, 10, 0, 0, 0, 0, 0, 0, 83, 65, 88, 46, 120, 109, 108, 83, 65, 88, 50, 69, 110, 116, 105, 116, 121, 68, 101, 99, 108, 40, 37, 115, 41, 32, 99, 97, 108, 108, 101, 100, 32, 119, 104, 105, 108, 101, 32, 110, 111, 116, 32, 105, 110, 32, 115, 117, 98, 115, 101, 116, 10, 0, 0, 0, 120, 109, 108, 58, 105, 100, 0, 0, 120, 109, 108, 58, 105, 100, 32, 58, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 116, 121, 112, 101, 32, 115, 104, 111, 117, 108, 100, 32, 98, 101, 32, 73, 68, 10, 0, 0, 0, 83, 65, 88, 46, 120, 109, 108, 83, 65, 88, 50, 65, 116, 116, 114, 105, 98, 117, 116, 101, 68, 101, 99, 108, 40, 37, 115, 41, 32, 99, 97, 108, 108, 101, 100, 32, 119, 104, 105, 108], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 187248);
	        allocate([101, 32, 110, 111, 116, 32, 105, 110, 32, 115, 117, 98, 115, 101, 116, 10, 0, 0, 0, 0, 0, 0, 0, 0, 83, 65, 88, 46, 120, 109, 108, 83, 65, 88, 50, 69, 108, 101, 109, 101, 110, 116, 68, 101, 99, 108, 40, 37, 115, 41, 32, 99, 97, 108, 108, 101, 100, 32, 119, 104, 105, 108, 101, 32, 110, 111, 116, 32, 105, 110, 32, 115, 117, 98, 115, 101, 116, 10, 0, 0, 83, 65, 88, 46, 120, 109, 108, 83, 65, 88, 50, 78, 111, 116, 97, 116, 105, 111, 110, 68, 101, 99, 108, 40, 37, 115, 41, 32, 101, 120, 116, 101, 114, 110, 97, 108, 73, 68, 32, 111, 114, 32, 80, 117, 98, 108, 105, 99, 73, 68, 32, 109, 105, 115, 115, 105, 110, 103, 10, 0, 0, 0, 0, 0, 83, 65, 88, 46, 120, 109, 108, 83, 65, 88, 50, 78, 111, 116, 97, 116, 105, 111, 110, 68, 101, 99, 108, 40, 37, 115, 41, 32, 99, 97, 108, 108, 101, 100, 32, 119, 104, 105, 108, 101, 32, 110, 111, 116, 32, 105, 110, 32, 115, 117, 98, 115, 101, 116, 10, 0, 83, 65, 88, 46, 120, 109, 108, 83, 65, 88, 50, 85, 110, 112, 97, 114, 115, 101, 100, 69, 110, 116, 105, 116, 121, 68, 101, 99, 108, 40, 37, 115, 41, 32, 99, 97, 108, 108, 101, 100, 32, 119, 104, 105, 108, 101, 32, 110, 111, 116, 32, 105, 110, 32, 115, 117, 98, 115, 101, 116, 10, 0, 0, 0, 120, 109, 108, 83, 65, 88, 50, 83, 116, 97, 114, 116, 68, 111, 99, 117, 109, 101, 110, 116, 0, 0, 0, 0, 86, 97, 108, 105, 100, 97, 116, 105, 111, 110, 32, 102, 97, 105, 108, 101, 100, 58, 32, 110, 111, 32, 68, 84, 68, 32, 102, 111, 117, 110, 100, 32, 33, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 83, 65, 88, 50, 83, 116, 97, 114, 116, 69, 108, 101, 109, 101, 110, 116, 0, 0, 0, 0, 0, 78, 97, 109, 101, 115, 112, 97, 99, 101, 32, 112, 114, 101, 102, 105, 120, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 100, 101, 102, 105, 110, 101, 100, 10, 0, 0, 0, 0, 0, 120, 109, 108, 83, 65, 88, 50, 83, 116, 97, 114, 116, 69, 108, 101, 109, 101, 110, 116, 78, 115, 0, 0, 0, 120, 109, 108, 0, 0, 0, 0, 0, 78, 97, 109, 101, 115, 112, 97, 99, 101, 32, 112, 114, 101, 102, 105, 120, 32, 37, 115, 32, 119, 97, 115, 32, 110, 111, 116, 32, 102, 111, 117, 110, 100, 10, 0, 0, 0, 0, 0, 0, 78, 97, 109, 101, 115, 112, 97, 99, 101, 32, 100, 101, 102, 97, 117, 108, 116, 32, 112, 114, 101, 102, 105, 120, 32, 119, 97, 115, 32, 110, 111, 116, 32, 102, 111, 117, 110, 100, 10, 0, 120, 109, 108, 83, 65, 88, 50, 67, 104, 97, 114, 97, 99, 116, 101, 114, 115, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 83, 65, 88, 50, 67, 104, 97, 114, 97, 99, 116, 101, 114, 115, 58, 32, 120, 109, 108, 83, 116, 114, 100, 117, 112, 32, 114, 101, 116, 117, 114, 110, 101, 100, 32, 78, 85, 76, 76, 0, 0, 0, 0, 0, 0, 120, 109, 108, 83, 65, 88, 50, 67, 104, 97, 114, 97, 99, 116, 101, 114, 115, 58, 32, 104, 117, 103, 101, 32, 116, 101, 120, 116, 32, 110, 111, 100, 101, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 83, 65, 88, 50, 67, 104, 97, 114, 97, 99, 116, 101, 114, 115, 32, 111, 118, 101, 114, 102, 108, 111, 119, 32, 112, 114, 101, 118, 101, 110, 116, 101, 100, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 83, 65, 88, 50, 84, 101, 120, 116, 78, 111, 100, 101, 0, 120, 109, 108, 83, 65, 88, 50, 65, 116, 116, 114, 105, 98, 117, 116, 101, 78, 115, 0, 0, 0, 0, 0, 0, 120, 109, 108, 58, 105, 100, 32, 58, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 118, 97, 108, 117, 101, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 97, 110, 32, 78, 67, 78, 97, 109, 101, 10, 0, 0, 0, 120, 109, 108, 110, 115, 0, 0, 0, 105, 110, 118, 97, 108, 105, 100, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 100, 101, 99, 108, 97, 114, 97, 116, 105, 111, 110, 32, 39, 37, 115, 39, 10, 0, 0, 0, 0, 0, 65, 118, 111, 105, 100, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 101, 110, 100, 105, 110, 103, 32, 119, 105, 116, 104, 32, 39, 58, 39, 32, 108, 105, 107, 101, 32, 39, 37, 115, 39, 10, 0, 0, 0, 0, 0, 0, 120, 109, 108, 110, 115, 58, 32, 37, 115, 32, 110, 111, 116, 32, 97, 32, 118, 97, 108, 105, 100, 32, 85, 82, 73, 10, 0, 0, 0, 0, 0, 0, 120, 109, 108, 110, 115, 58, 32, 85, 82, 73, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 97, 98, 115, 111, 108, 117, 116, 101, 10, 0, 0, 69, 109, 112, 116, 121, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 32, 110, 97, 109, 101, 32, 102, 111, 114, 32, 112, 114, 101, 102, 105, 120, 32, 37, 115, 10, 0, 0, 0, 0, 0, 120, 109, 108, 110, 115, 58, 37, 115, 58, 32, 37, 115, 32, 110, 111, 116, 32, 97, 32, 118, 97, 108, 105, 100, 32, 85, 82, 73, 10, 0, 0, 0, 120, 109, 108, 110, 115, 58, 37, 115, 58, 32, 85, 82, 73, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 97, 98, 115, 111, 108, 117, 116, 101, 10, 0, 0, 0, 0, 0, 0, 0, 78, 97, 109, 101, 115, 112, 97, 99, 101, 32, 112, 114, 101, 102, 105, 120, 32, 37, 115, 32, 111, 102, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 105, 115, 32, 110, 111, 116, 32, 100, 101, 102, 105, 110, 101, 100, 10, 0, 0, 0, 0, 0, 65, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 105, 110, 32, 37, 115, 32, 114, 101, 100, 101, 102, 105, 110, 101, 100, 10, 0, 0, 0, 58, 0, 0, 0, 0, 0, 0, 0, 115, 116, 97, 110, 100, 97, 108, 111, 110, 101, 58, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 32, 37, 115, 32, 111, 110, 32, 37, 115, 32, 100, 101, 102, 97, 117, 108, 116, 101, 100, 32, 102, 114, 111, 109, 32, 101, 120, 116, 101, 114, 110, 97, 108, 32, 115, 117, 98, 115, 101, 116, 10, 0, 0, 111, 117, 116, 32, 111, 102, 32, 109, 101, 109, 111, 114, 121, 10, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 1, 1, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 1, 0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 49, 1, 52, 1, 62, 1, 65, 1, 72, 1, 74, 1, 126, 1, 128, 1, 195, 1, 205, 1, 240, 1, 244, 1, 245, 1, 250, 1, 23, 2, 80, 2, 168, 2, 187, 2, 193, 2, 134, 3, 134, 3, 136, 3, 138, 3, 140, 3, 140, 3, 142, 3, 161, 3, 163, 3, 206, 3, 208, 3, 214, 3, 218, 3, 218, 3, 220, 3, 220, 3, 222, 3, 222, 3, 224, 3, 224, 3, 226, 3, 243, 3, 1, 4, 12, 4, 14, 4, 79, 4, 81, 4, 92, 4, 94, 4, 129, 4, 144, 4, 196, 4, 199, 4, 200, 4, 203, 4, 204, 4, 208, 4, 235, 4, 238, 4, 245, 4, 248, 4, 249, 4, 49, 5, 86, 5, 89, 5, 89, 5, 97, 5, 134, 5, 208, 5, 234, 5, 240, 5, 242, 5, 33, 6, 58, 6, 65, 6, 74, 6, 113, 6, 183, 6, 186, 6, 190, 6, 192, 6, 206, 6, 208, 6, 211, 6, 213, 6, 213, 6, 229, 6, 230, 6, 5, 9, 57, 9, 61, 9, 61, 9, 88, 9, 97, 9, 133, 9, 140, 9, 143, 9, 144, 9, 147, 9, 168, 9, 170, 9, 176, 9, 178, 9, 178, 9, 182, 9, 185, 9, 220, 9, 221, 9, 223, 9, 225, 9, 240, 9, 241, 9, 5, 10, 10, 10, 15, 10, 16, 10, 19, 10, 40, 10, 42, 10, 48, 10, 50, 10, 51, 10, 53, 10, 54, 10, 56, 10, 57, 10, 89, 10, 92, 10, 94, 10, 94, 10, 114, 10, 116, 10, 133, 10, 139, 10, 141, 10, 141, 10, 143, 10, 145, 10, 147, 10, 168, 10, 170, 10, 176, 10, 178, 10, 179, 10, 181, 10, 185, 10, 189, 10, 189, 10, 224, 10, 224, 10, 5, 11, 12, 11, 15, 11, 16, 11, 19, 11, 40, 11, 42, 11, 48, 11, 50, 11, 51, 11, 54, 11, 57, 11, 61, 11, 61, 11, 92, 11, 93, 11, 95, 11, 97, 11, 133, 11, 138, 11, 142, 11, 144, 11, 146, 11, 149, 11, 153, 11, 154, 11, 156, 11, 156, 11, 158, 11, 159, 11, 163, 11, 164, 11, 168, 11, 170, 11, 174, 11, 181, 11, 183, 11, 185, 11, 5, 12, 12, 12, 14, 12, 16, 12, 18, 12, 40, 12, 42, 12, 51, 12, 53, 12, 57, 12, 96, 12, 97, 12, 133, 12, 140, 12, 142, 12, 144, 12, 146, 12, 168, 12, 170, 12, 179, 12, 181, 12, 185, 12, 222, 12, 222, 12, 224, 12, 225, 12, 5, 13, 12, 13, 14, 13, 16, 13, 18, 13, 40, 13, 42, 13, 57, 13, 96, 13, 97, 13, 1, 14, 46, 14, 48, 14, 48, 14, 50, 14, 51, 14, 64, 14, 69, 14, 129, 14, 130, 14, 132, 14, 132, 14, 135, 14, 136, 14, 138, 14, 138, 14, 141, 14, 141, 14, 148, 14, 151, 14, 153, 14, 159, 14, 161, 14, 163, 14, 165, 14, 165, 14, 167, 14, 167, 14, 170, 14, 171, 14, 173, 14, 174, 14, 176, 14, 176, 14, 178, 14, 179, 14, 189, 14, 189, 14, 192, 14, 196, 14, 64, 15, 71, 15, 73, 15, 105, 15, 160, 16, 197, 16, 208, 16, 246, 16, 0, 17, 0, 17, 2, 17, 3, 17, 5, 17, 7, 17, 9, 17, 9, 17, 11, 17, 12, 17, 14, 17, 18, 17, 60, 17, 60, 17, 62, 17, 62, 17, 64, 17, 64, 17, 76, 17, 76, 17, 78, 17, 78, 17, 80, 17, 80, 17, 84, 17, 85, 17, 89, 17, 89, 17, 95, 17, 97, 17, 99, 17, 99, 17, 101, 17, 101, 17, 103, 17, 103, 17, 105, 17, 105, 17, 109, 17, 110, 17, 114, 17, 115, 17, 117, 17, 117, 17, 158, 17, 158, 17, 168, 17, 168, 17, 171, 17, 171, 17, 174, 17, 175, 17, 183, 17, 184, 17, 186, 17, 186, 17, 188, 17, 194, 17, 235, 17, 235, 17, 240, 17, 240, 17, 249, 17, 249, 17, 0, 30, 155, 30, 160, 30, 249, 30, 0, 31, 21, 31, 24, 31, 29, 31, 32, 31, 69, 31, 72, 31, 77, 31, 80, 31, 87, 31, 89, 31, 89, 31, 91, 31, 91, 31, 93, 31, 93, 31, 95, 31, 125, 31, 128, 31, 180, 31, 182, 31, 188, 31, 190, 31, 190, 31, 194, 31, 196, 31, 198, 31, 204, 31, 208, 31, 211, 31, 214, 31, 219, 31, 224, 31, 236, 31, 242, 31, 244, 31, 246, 31, 252, 31, 38, 33, 38, 33, 42, 33, 43, 33, 46, 33, 46, 33, 128, 33, 130, 33, 65, 48, 148, 48, 161, 48, 250, 48, 5, 49, 44, 49, 0, 172, 163, 215, 0, 0, 0, 0, 197, 0, 0, 0, 0, 0, 0, 0, 40, 9, 3, 0, 0, 0, 0, 0, 0, 3, 69, 3, 96, 3, 97, 3, 131, 4, 134, 4, 145, 5, 161, 5, 163, 5, 185, 5, 187, 5, 189, 5, 191, 5, 191, 5, 193, 5, 194, 5, 196, 5, 196, 5, 75, 6, 82, 6, 112, 6, 112, 6, 214, 6, 220, 6, 221, 6, 223, 6, 224, 6, 228, 6, 231, 6, 232, 6, 234, 6, 237, 6, 1, 9, 3, 9, 60, 9, 60, 9, 62, 9, 76, 9, 77, 9, 77, 9, 81, 9, 84, 9, 98, 9, 99, 9, 129, 9, 131, 9, 188, 9, 188, 9, 190, 9, 190, 9, 191, 9, 191, 9, 192, 9, 196, 9, 199, 9, 200, 9, 203, 9, 205, 9, 215, 9, 215, 9, 226, 9, 227, 9, 2, 10, 2, 10, 60, 10, 60, 10, 62, 10, 62, 10, 63, 10, 63, 10, 64, 10, 66, 10, 71, 10, 72, 10, 75, 10, 77, 10, 112, 10, 113, 10, 129, 10, 131, 10, 188, 10, 188, 10, 190, 10, 197, 10, 199, 10, 201, 10, 203, 10, 205, 10, 1, 11, 3, 11, 60, 11, 60, 11, 62, 11, 67, 11, 71, 11, 72, 11, 75, 11, 77, 11, 86, 11, 87, 11, 130, 11, 131, 11, 190, 11, 194, 11, 198, 11, 200, 11, 202, 11, 205, 11, 215, 11, 215, 11, 1, 12, 3, 12, 62, 12, 68, 12, 70, 12, 72, 12, 74, 12, 77, 12, 85, 12, 86, 12, 130, 12, 131, 12, 190, 12, 196, 12, 198, 12, 200, 12, 202, 12, 205, 12, 213, 12, 214, 12, 2, 13, 3, 13, 62, 13, 67, 13, 70, 13, 72, 13, 74, 13, 77, 13, 87, 13, 87, 13, 49, 14, 49, 14, 52, 14, 58, 14, 71, 14, 78, 14, 177, 14, 177, 14, 180, 14, 185, 14, 187, 14, 188, 14, 200, 14, 205, 14, 24, 15, 25, 15, 53, 15, 53, 15, 55, 15, 55, 15, 57, 15, 57, 15, 62, 15, 62, 15, 63, 15, 63, 15, 113, 15, 132, 15, 134, 15, 139, 15, 144, 15, 149, 15, 151, 15, 151, 15, 153, 15, 173, 15, 177, 15, 183, 15, 185, 15, 185, 15, 208, 32, 220, 32, 225, 32, 225, 32, 42, 48, 47, 48, 153, 48, 153, 48, 154, 48, 154, 48, 0, 0, 0, 0, 95, 0, 0, 0, 0, 0, 0, 0, 80, 12, 3, 0, 0, 0, 0, 0, 96, 6, 105, 6, 240, 6, 249, 6, 102, 9, 111, 9, 230, 9, 239, 9, 102, 10, 111, 10, 230, 10, 239, 10, 102, 11, 111, 11, 231, 11, 239, 11, 102, 12, 111, 12, 230, 12, 239, 12, 102, 13, 111, 13, 80, 14, 89, 14, 208, 14, 217, 14, 32, 15, 41, 15, 14, 0, 0, 0, 0, 0, 0, 0, 224, 13, 3, 0, 0, 0, 0, 0, 208, 2, 208, 2, 209, 2, 209, 2, 135, 3, 135, 3, 64, 6, 64, 6, 70, 14, 70, 14, 198, 14, 198, 14, 5, 48, 5, 48, 49, 48, 53, 48, 157, 48, 158, 48, 252, 48, 254, 48, 10, 0, 0, 0, 0, 0, 0, 0, 40, 14, 3, 0, 0, 0, 0, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 88, 77, 76, 47, 49, 57, 57, 56, 47, 110, 97, 109, 101, 115, 112, 97, 99, 101, 0, 0, 0, 0, 99, 104, 105, 108, 100, 0, 0, 0, 97, 116, 116, 114, 105, 98, 117, 116, 101, 0, 0, 0, 0, 0, 0, 0, 45, 47, 47, 87, 51, 67, 47, 47, 68, 84, 68, 32, 88, 72, 84, 77, 76, 32, 49, 46, 48, 32, 83, 116, 114, 105, 99, 116, 47, 47, 69, 78, 0, 0, 0, 0, 0, 0, 0, 0, 45, 47, 47, 87, 51, 67, 47, 47, 68, 84, 68, 32, 88, 72, 84, 77, 76, 32, 49, 46, 48, 32, 70, 114, 97, 109, 101, 115, 101, 116, 47, 47, 69, 78, 0, 0, 0, 0, 0, 0, 45, 47, 47, 87, 51, 67, 47, 47, 68, 84, 68, 32, 88, 72, 84, 77, 76, 32, 49, 46, 48, 32, 84, 114, 97, 110, 115, 105, 116, 105, 111, 110, 97, 108, 47, 47, 69, 78, 0, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 84, 82, 47, 120, 104, 116, 109, 108, 49, 47, 68, 84, 68, 47, 120, 104, 116, 109, 108, 49, 45, 115, 116, 114, 105, 99, 116, 46, 100, 116, 100, 0, 0, 0, 0, 0, 0, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 84, 82, 47, 120, 104, 116, 109, 108, 49, 47, 68, 84, 68, 47, 120, 104, 116, 109, 108, 49, 45, 102, 114, 97, 109, 101, 115, 101, 116, 46, 100, 116, 100, 0, 0, 0, 0, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 84, 82, 47, 120, 104, 116, 109, 108, 49, 47, 68, 84, 68, 47, 120, 104, 116, 109, 108, 49, 45, 116, 114, 97, 110, 115, 105, 116, 105, 111, 110, 97, 108, 46, 100, 116, 100, 0, 38, 35, 49, 48, 59, 0, 0, 0, 38, 35, 49, 51, 59, 0, 0, 0, 38, 35, 57, 59, 0, 0, 0, 0, 38, 113, 117, 111, 116, 59, 0, 0, 38, 108, 116, 59, 0, 0, 0, 0, 38, 103, 116, 59, 0, 0, 0, 0, 38, 97, 109, 112, 59, 0, 0, 0, 73, 83, 79, 45, 56, 56, 53, 57, 45, 49, 0, 0, 0, 0, 0, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 98, 117, 102, 102, 101, 114, 0, 85, 84, 70, 45, 56, 0, 0, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 111, 117, 116, 112, 117, 116, 0, 60, 63, 0, 0, 0, 0, 0, 0, 32, 0, 0, 0, 0, 0, 0, 0, 63, 62, 0, 0, 0, 0, 0, 0, 60, 33, 45, 45, 0, 0, 0, 0, 45, 45, 62, 0, 0, 0, 0, 0, 38, 0, 0, 0, 0, 0, 0, 0, 59, 0, 0, 0, 0, 0, 0, 0, 60, 33, 91, 67, 68, 65, 84, 65, 91, 93, 93, 62, 0, 0, 0, 0, 60, 33, 91, 67, 68, 65, 84, 65, 91, 0, 0, 0, 0, 0, 0, 0, 93, 93, 62, 0, 0, 0, 0, 0, 60, 0, 0, 0, 0, 0, 0, 0, 58, 0, 0, 0, 0, 0, 0, 0, 104, 116, 109, 108, 0, 0, 0, 0, 32, 120, 109, 108, 110, 115, 61, 34, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 49, 57, 57, 57, 47, 120, 104, 116, 109, 108, 34, 0, 0, 0, 104, 101, 97, 100, 0, 0, 0, 0, 109, 101, 116, 97, 0, 0, 0, 0, 104, 116, 116, 112, 45, 101, 113, 117, 105, 118, 0, 0, 0, 0, 0, 0, 67, 111, 110, 116, 101, 110, 116, 45, 84, 121, 112, 101, 0, 0, 0, 0, 32, 47, 62, 0, 0, 0, 0, 0, 62, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0, 0, 0, 0, 0, 0, 60, 109, 101, 116, 97, 32, 104, 116, 116, 112, 45, 101, 113, 117, 105, 118, 61, 34, 67, 111, 110, 116, 101, 110, 116, 45, 84, 121, 112, 101, 34, 32, 99, 111, 110, 116, 101, 110, 116, 61, 34, 116, 101, 120, 116, 47, 104, 116, 109, 108, 59, 32, 99, 104, 97, 114, 115, 101, 116, 61, 0, 0, 0, 0, 34, 32, 47, 62, 0, 0, 0, 0, 60, 47, 0, 0, 0, 0, 0, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 119, 51, 46, 111, 114, 103, 47, 49, 57, 57, 57, 47, 120, 104, 116, 109, 108, 0, 0, 0, 0, 97, 114, 101, 97, 0, 0, 0, 0, 98, 114, 0, 0, 0, 0, 0, 0, 98, 97, 115, 101, 0, 0, 0, 0, 98, 97, 115, 101, 102, 111, 110, 116, 0, 0, 0, 0, 0, 0, 0, 0, 99, 111, 108, 0, 0, 0, 0, 0, 102, 114, 97, 109, 101, 0, 0, 0, 104, 114, 0, 0, 0, 0, 0, 0, 105, 109, 103, 0, 0, 0, 0, 0, 105, 110, 112, 117, 116, 0, 0, 0, 105, 115, 105, 110, 100, 101, 120, 0, 108, 105, 110, 107, 0, 0, 0, 0, 112, 97, 114, 97, 109, 0, 0, 0, 105, 100, 0, 0, 0, 0, 0, 0, 110, 97, 109, 101, 0, 0, 0, 0, 108, 97, 110, 103, 0, 0, 0, 0, 120, 109, 108, 0, 0, 0, 0, 0, 97, 0, 0, 0, 0, 0, 0, 0, 112, 0, 0, 0, 0, 0, 0, 0, 100, 105, 118, 0, 0, 0, 0, 0, 109, 97, 112, 0, 0, 0, 0, 0, 97, 112, 112, 108, 101, 116, 0, 0, 102, 111, 114, 109, 0, 0, 0, 0, 105, 102, 114, 97, 109, 101, 0, 0, 32, 105, 100, 61, 34, 0, 0, 0, 34, 0, 0, 0, 0, 0, 0, 0, 32, 120, 109, 108, 58, 108, 97, 110, 103, 61, 34, 0, 0, 0, 0, 0, 32, 108, 97, 110, 103, 61, 34, 0, 61, 34, 0, 0, 0, 0, 0, 0, 60, 33, 68, 79, 67, 84, 89, 80, 69, 32, 0, 0, 0, 0, 0, 0, 32, 80, 85, 66, 76, 73, 67, 32, 0, 0, 0, 0, 0, 0, 0, 0, 32, 83, 89, 83, 84, 69, 77, 32, 0, 0, 0, 0, 0, 0, 0, 0, 32, 91, 10, 0, 0, 0, 0, 0, 93, 62, 0, 0, 0, 0, 0, 0, 120, 109, 108, 69, 115, 99, 97, 112, 101, 69, 110, 116, 105, 116, 105, 101, 115, 32, 58, 32, 99, 104, 97, 114, 32, 111, 117, 116, 32, 111, 102, 32, 114, 97, 110, 103, 101, 10, 0, 0, 115, 116, 114, 105, 110, 103, 32, 105, 115, 32, 110, 111, 116, 32, 105, 110, 32, 85, 84, 70, 45, 56, 10, 0, 105, 110, 118, 97, 108, 105, 100, 32, 99, 104, 97, 114, 97, 99, 116, 101, 114, 32, 118, 97, 108, 117, 101, 10, 0, 0, 0, 0, 0, 0, 0, 0, 117, 110, 107, 110, 111, 119, 110, 32, 101, 110, 99, 111, 100, 105, 110, 103, 32, 37, 115, 10, 0, 0, 0, 0, 100, 111, 99, 117, 109, 101, 110, 116, 32, 104, 97, 115, 32, 110, 111, 32, 68, 79, 67, 84, 89, 80, 69, 10, 0, 0, 0, 0, 0, 0, 0, 0, 117, 110, 101, 120, 112, 101, 99, 116, 101, 100, 32, 101, 114, 114, 111, 114, 32, 110, 117, 109, 98, 101, 114, 10, 0, 0, 0, 0, 0, 0, 0, 0, 47, 62, 0, 0, 0, 0, 0, 0, 72, 84, 77, 76, 0, 0, 0, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 101, 110, 99, 111, 100, 105, 110, 103, 32, 98, 117, 102, 102, 101, 114, 0, 0, 0, 0, 0, 0, 0, 0, 60, 63, 120, 109, 108, 32, 118, 101, 114, 115, 105, 111, 110, 61, 0, 0, 34, 49, 46, 48, 34, 0, 0, 0, 32, 101, 110, 99, 111, 100, 105, 110, 103, 61, 0, 0, 0, 0, 0, 0, 32, 115, 116, 97, 110, 100, 97, 108, 111, 110, 101, 61, 34, 110, 111, 34, 0, 0, 0, 0, 0, 0, 0, 0, 32, 115, 116, 97, 110, 100, 97, 108, 111, 110, 101, 61, 34, 121, 101, 115, 34, 0, 0, 0, 0, 0, 0, 0, 63, 62, 10, 0, 0, 0, 0, 0, 99, 114, 101, 97, 116, 105, 110, 103, 32, 115, 97, 118, 105, 110, 103, 32, 99, 111, 110, 116, 101, 120, 116, 0, 120, 109, 108, 110, 115, 58, 0, 0, 120, 109, 108, 110, 115, 0, 0, 0, 61, 0, 0, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 115, 99, 104, 101, 109, 97, 32, 112, 97, 114, 115, 101, 114, 32, 99, 111, 110, 116, 101, 120, 116, 0, 0, 0, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 115, 99, 104, 101, 109, 97, 32, 112, 97, 114, 115, 101, 114, 32, 88, 80, 97, 116, 104, 32, 99, 111, 110, 116, 101, 120, 116, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 116, 114, 111, 110, 80, 97, 114, 115, 101, 58, 32, 99, 111, 117, 108, 100, 32, 110, 111, 116, 32, 108, 111, 97, 100, 32, 39, 37, 115, 39, 46, 10, 0, 0, 0, 0, 0, 0, 0, 120, 109, 108, 83, 99, 104, 101, 109, 97, 116, 114, 111, 110, 80, 97, 114, 115, 101, 58, 32, 99, 111, 117, 108, 100, 32, 110, 111, 116, 32, 112, 97, 114, 115, 101, 46, 10, 0, 0, 0, 105, 110, 95, 109, 101, 109, 111, 114, 121, 95, 98, 117, 102, 102, 101, 114, 0, 0, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 115, 99, 104, 101, 109, 97, 32, 104, 97, 115, 32, 110, 111, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 101, 108, 101, 109, 101, 110, 116, 46, 10, 0, 0, 0, 0, 115, 99, 104, 101, 109, 97, 0, 0, 96, 25, 3, 0, 0, 0, 0, 0, 56, 25, 3, 0, 0, 0, 0, 0, 84, 104, 101, 32, 88, 77, 76, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 39, 37, 115, 39, 32, 105, 115, 32, 110, 111, 116, 32, 97, 32, 88, 77, 76, 32, 115, 99, 104, 101, 109, 97, 116, 114, 111, 110, 32, 100, 111, 99, 117, 109, 101, 110, 116, 0, 0, 116, 105, 116, 108, 101, 0, 0, 0, 110, 115, 0, 0, 0, 0, 0, 0, 112, 114, 101, 102, 105, 120, 0, 0, 117, 114, 105, 0, 0, 0, 0, 0, 110, 115, 32, 101, 108, 101, 109, 101, 110, 116, 32, 104, 97, 115, 32, 110, 111, 32, 117, 114, 105, 0, 0, 0, 110, 115, 32, 101, 108, 101, 109, 101, 110, 116, 32, 104, 97, 115, 32, 110, 111, 32, 112, 114, 101, 102, 105, 120, 0, 0, 0, 0, 0, 0, 0, 0, 112, 97, 116, 116, 101, 114, 110, 0, 69, 120, 112, 101, 99, 116, 105, 110, 103, 32, 97, 32, 112, 97, 116, 116, 101, 114, 110, 32, 101, 108, 101, 109, 101, 110, 116, 32, 105, 110, 115, 116, 101, 97, 100, 32, 111, 102, 32, 37, 115, 0, 0, 0, 0, 0, 0, 0, 84, 104, 101, 32, 115, 99, 104, 101, 109, 97, 116, 114, 111, 110, 32, 100, 111, 99, 117, 109, 101, 110, 116, 32, 39, 37, 115, 39, 32, 104, 97, 115, 32, 110, 111, 32, 112, 97, 116, 116, 101, 114, 110, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 118, 97, 108, 105, 100, 97, 116, 105, 111, 110, 32, 99, 111, 110, 116, 101, 120, 116, 0, 0, 0, 85, 110, 105, 109, 112, 108, 101, 109, 101, 110, 116, 101, 100, 32, 98, 108, 111, 99, 107, 32, 97, 116, 32, 37, 115, 58, 37, 100, 10, 0, 0, 0, 46, 46, 47, 108, 105, 98, 120, 109, 108, 50, 47, 115, 99, 104, 101, 109, 97, 116, 114, 111, 110, 46, 99, 0, 80, 97, 116, 116, 101, 114, 110, 58, 32, 37, 115, 10, 0, 0, 0, 0, 37, 115, 0, 0, 0, 0, 0, 0, 110, 111, 100, 101, 32, 102, 97, 105, 108, 101, 100, 32, 97, 115, 115, 101, 114, 116, 0, 0, 0, 0, 0, 0, 110, 111, 100, 101, 32, 102, 97, 105, 108, 101, 100, 32, 114, 101, 112, 111, 114, 116, 0, 0, 0, 0, 0, 0, 37, 115, 32, 108, 105, 110, 101, 32, 37, 108, 100, 58, 32, 37, 115, 10, 0, 0, 0, 0, 0, 0, 0, 0, 110, 97, 109, 101, 0, 0, 0, 0, 112, 97, 116, 104, 0, 0, 0, 0, 58, 0, 0, 0, 0, 0, 0, 0, 105, 100, 0, 0, 0, 0, 0, 0, 114, 117, 108, 101, 0, 0, 0, 0, 69, 120, 112, 101, 99, 116, 105, 110, 103, 32, 97, 32, 114, 117, 108, 101, 32, 101, 108, 101, 109, 101, 110, 116, 32, 105, 110, 115, 116, 101, 97, 100, 32, 111, 102, 32, 37, 115, 0, 0, 80, 97, 116, 116, 101, 114, 110, 32, 104, 97, 115, 32, 110, 111, 32, 114, 117, 108, 101, 32, 101, 108, 101, 109, 101, 110, 116, 0, 0, 0, 0, 0, 99, 111, 110, 116, 101, 120, 116, 0, 114, 117, 108, 101, 32, 104, 97, 115, 32, 110, 111, 32, 99, 111, 110, 116, 101, 120, 116, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 0, 0, 0, 114, 117, 108, 101, 32, 104, 97, 115, 32, 97, 110, 32, 101, 109, 112, 116, 121, 32, 99, 111, 110, 116, 101, 120, 116, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 0, 0, 0, 0, 0, 97, 115, 115, 101, 114, 116, 0, 0, 116, 101, 115, 116, 0, 0, 0, 0, 97, 115, 115, 101, 114, 116, 32, 104, 97, 115, 32, 110, 111, 32, 116, 101, 115, 116, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 0, 0, 0, 0, 97, 115, 115, 101, 114, 116, 32, 104, 97, 115, 32, 97, 110, 32, 101, 109, 112, 116, 121, 32, 116, 101, 115, 116, 32, 97, 116, 116, 114, 105, 98, 117, 116, 101, 0, 0, 0, 0, 0, 0, 114, 101, 112, 111, 114, 116, 0, 0, 69, 120, 112, 101, 99, 116, 105, 110, 103, 32, 97, 110, 32, 97, 115, 115, 101, 114, 116, 32, 111, 114, 32, 97, 32, 114, 101, 112, 111, 114, 116, 32, 101, 108, 101, 109, 101, 110, 116, 32, 105, 110, 115, 116, 101, 97, 100, 32, 111, 102, 32, 37, 115, 0, 0, 0, 114, 117, 108, 101, 32, 104, 97, 115, 32, 110, 111, 32, 97, 115, 115, 101, 114, 116, 32, 110, 111, 114, 32, 114, 101, 112, 111, 114, 116, 32, 101, 108, 101, 109, 101, 110, 116, 0, 0, 0, 70, 97, 105, 108, 101, 100, 32, 116, 111, 32, 99, 111, 109, 112, 105, 108, 101, 32, 116, 101, 115, 116, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 37, 115, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 115, 99, 104, 101, 109, 97, 32, 116, 101, 115, 116, 0, 0, 70, 97, 105, 108, 101, 100, 32, 116, 111, 32, 99, 111, 109, 112, 105, 108, 101, 32, 99, 111, 110, 116, 101, 120, 116, 32, 101, 120, 112, 114, 101, 115, 115, 105, 111, 110, 32, 37, 115, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 115, 99, 104, 101, 109, 97, 32, 114, 117, 108, 101, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 115, 99, 104, 101, 109, 97, 32, 112, 97, 116, 116, 101, 114, 110, 0, 0, 0, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 112, 97, 114, 115, 101, 114, 32, 110, 97, 109, 101, 115, 112, 97, 99, 101, 115, 0, 0, 0, 0, 97, 108, 108, 111, 99, 97, 116, 105, 110, 103, 32, 115, 99, 104, 101, 109, 97, 0, 0, 0, 0, 0, 0, 0, 104, 116, 116, 112, 58, 47, 47, 119, 119, 119, 46, 97, 115, 99, 99, 46, 110, 101, 116, 47, 120, 109, 108, 47, 115, 99, 104, 101, 109, 97, 116, 114, 111, 110, 0, 0, 0, 0, 0, 0, 104, 116, 116, 112, 58, 47, 47, 112, 117, 114, 108, 46, 111, 99, 108, 99, 46, 111, 114, 103, 47, 100, 115, 100, 108, 47, 115, 99, 104, 101, 109, 97, 116, 114, 111, 110, 0, 0, 0, 0, 67, 97, 110, 110, 111, 116, 32, 105, 110, 105, 116, 105, 97, 108, 105, 122, 101, 32, 109, 101, 109, 111, 114, 121, 32, 102, 111, 114, 32, 108, 105, 115, 116, 0, 0, 0, 0, 0, 0, 0, 67, 97, 110, 110, 111, 116, 32, 105, 110, 105, 116, 105, 97, 108, 105, 122, 101, 32, 109, 101, 109, 111, 114, 121, 32, 102, 111, 114, 32, 115, 101, 110, 116, 105, 110, 101, 108, 0, 0, 0, 67, 97, 110, 110, 111, 116, 32, 105, 110, 105, 116, 105, 97, 108, 105, 122, 101, 32, 109, 101, 109, 111, 114, 121, 32, 102, 111, 114, 32, 110, 101, 119, 32, 108, 105, 110, 107, 0, 0, 0, 117, 116, 102, 56, 0, 0, 200, 119, 99, 104, 97, 114, 116, 0, 0, 198, 117, 99, 115, 50, 0, 117, 99, 115, 50, 98, 101, 0, 0, 196, 117, 99, 115, 50, 108, 101, 0, 0, 197, 117, 116, 102, 49, 54, 0, 117, 116, 102, 49, 54, 98, 101, 0, 0, 194, 117, 116, 102, 49, 54, 108, 101, 0, 0, 193, 117, 99, 115, 52, 0, 117, 99, 115, 52, 98, 101, 0, 117, 116, 102, 51, 50, 0, 117, 116, 102, 51, 50, 98, 101, 0, 0, 192, 117, 99, 115, 52, 108, 101, 0, 117, 116, 102, 51, 50, 108, 101, 0, 0, 195, 97, 115, 99, 105, 105, 0, 117, 115, 97, 115, 99, 105, 105, 0, 105, 115, 111, 54, 52, 54, 0, 105, 115, 111, 54, 52, 54, 117, 115, 0, 0, 199, 101, 117, 99, 106, 112, 0, 0, 208, 115, 104, 105, 102, 116, 106, 105, 115, 0, 115, 106, 105, 115, 0, 0, 209, 103, 98, 49, 56, 48, 51, 48, 0, 0, 216, 103, 98, 107, 0, 0, 217, 103, 98, 50, 51, 49, 50, 0, 0, 218, 98, 105, 103, 53, 0, 98, 105, 103, 102, 105, 118, 101, 0, 99, 112, 57, 53, 48, 0, 98, 105, 103, 53, 104, 107, 115, 99, 115, 0, 0, 224, 101, 117, 99, 107, 114, 0, 107, 115, 99, 53, 54, 48, 49, 0, 107, 115, 120, 49, 48, 48, 49, 0, 99, 112, 57, 52, 57, 0, 0, 232, 105, 115, 111, 56, 56, 53, 57, 49, 0, 108, 97, 116, 105, 110, 49, 0, 0, 128, 105, 115, 111, 56, 56, 53, 57, 50, 0, 0, 32, 0, 84, 0, 137, 18, 0, 32, 1, 6, 0, 0, 152, 65, 134, 26, 127, 0, 48, 72, 32, 0, 88, 32, 201, 18, 0, 36, 17, 198, 35, 0, 156, 81, 198, 26, 128, 80, 66, 136, 32, 90, 0, 0, 192, 4, 0, 16, 113, 1, 0, 29, 0, 112, 2, 0, 41, 0, 0, 192, 7, 33, 48, 1, 5, 0, 0, 88, 1, 0, 0, 94, 208, 1, 128, 29, 0, 0, 128, 6, 0, 91, 0, 0, 0, 5, 0, 20, 129, 1, 0, 30, 0, 128, 2, 0, 42, 0, 0, 0, 8, 34, 52, 17, 5, 0, 0, 92, 1, 0, 0, 95, 212, 1, 192, 29, 0, 0, 144, 70, 36, 105, 115, 111, 56, 56, 53, 57, 51, 0, 0, 32, 0, 212, 0, 9, 0, 0, 4, 48, 3, 0, 0, 244, 64, 70, 11, 63, 0, 16, 64, 32, 0, 216, 0, 0, 0, 0, 0, 64, 3, 0, 0, 248, 80, 134, 11, 64, 0, 16, 128, 32, 0, 0, 0, 64, 0, 0, 108, 144, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 188, 0, 0, 0, 43, 0, 0, 0, 0, 0, 200, 33, 6, 0, 0, 0, 0, 64, 0, 0, 112, 160, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0, 0, 192, 0, 0, 0, 44, 0, 0, 0, 0, 0, 204, 49, 70, 36, 105, 115, 111, 56, 56, 53, 57, 52, 0, 0, 32, 0, 84, 48, 4, 23, 0, 220, 96, 4, 0, 0, 152, 49, 66, 12, 108, 0, 48, 8, 0, 0, 88, 32, 73, 23, 0, 224, 112, 196, 35, 0, 156, 65, 130, 12, 109, 72, 65, 200, 20, 17, 0, 0, 0, 0, 0, 0, 0, 192, 14, 29, 0, 112, 2, 0, 37, 0, 0, 64, 14, 33, 56, 65, 69, 16, 0, 0, 0, 0, 0, 0, 224, 1, 0, 0, 0, 184, 1, 7, 0, 18, 0, 0, 0, 0, 0, 0, 0, 0, 15, 30, 0, 128, 2, 0, 38, 0, 0, 128, 14, 34, 60, 81, 133, 16, 0, 0, 0, 0, 0, 0, 228, 1, 0, 0, 0, 188, 17, 71, 36, 105, 115, 111, 56, 56, 53, 57, 53, 0, 0, 32, 0, 136, 51, 14, 57, 229, 152, 115, 14, 58, 233, 168, 179, 14, 59, 237, 0, 224, 206, 59, 240, 196, 35, 207, 60, 244, 212, 99, 207, 61, 248, 228, 163, 207, 62, 252, 244, 227, 207, 63, 0, 5, 36, 208, 64, 4, 21, 100, 208, 65, 8, 37, 164, 208, 66, 12, 53, 228, 208, 67, 16, 69, 36, 209, 68, 20, 85, 100, 209, 69, 24, 101, 164, 209, 70, 28, 117, 228, 209, 71, 32, 133, 36, 210, 72, 36, 149, 100, 210, 73, 40, 165, 164, 210, 74, 44, 181, 228, 210, 75, 53, 194, 20, 147, 76, 51, 209, 84, 147, 77, 55, 225, 148, 147, 78, 59, 13, 192, 83, 79, 105, 115, 111, 56, 56, 53, 57, 54, 0, 0, 32, 0, 4, 16, 64, 0, 0, 4, 16, 64, 0, 1, 4, 16, 64, 0, 115, 1, 16, 64, 0, 1, 4, 16, 64, 0, 1, 4, 16, 64, 0, 1, 4, 16, 0, 93, 1, 4, 16, 64, 93, 1, 216, 117, 23, 94, 121, 233, 181, 23, 95, 125, 249, 245, 23, 96, 129, 9, 54, 24, 97, 133, 25, 118, 24, 98, 137, 41, 182, 24, 99, 141, 57, 246, 88, 0, 1, 4, 16, 64, 0, 144, 69, 38, 217, 100, 148, 85, 102, 217, 101, 152, 101, 166, 217, 102, 156, 117, 230, 217, 103, 160, 133, 38, 90, 0, 1, 4, 16, 64, 0, 1, 4, 16, 64, 0, 1, 4, 16, 64, 0, 105, 115, 111, 56, 56, 53, 57, 55, 0, 0, 32, 0, 144, 88, 34, 0, 51, 210, 8, 0, 0, 0, 0, 160, 9, 0, 0, 0, 16, 128, 136, 0, 0, 0, 0, 0, 155, 112, 210, 9, 0, 158, 124, 2, 10, 0, 161, 0, 32, 202, 40, 164, 148, 98, 202, 41, 168, 164, 162, 202, 42, 172, 180, 226, 202, 43, 176, 196, 34, 203, 44, 180, 212, 18, 128, 45, 183, 224, 146, 139, 46, 187, 240, 210, 139, 47, 191, 0, 19, 140, 48, 195, 16, 83, 140, 49, 199, 32, 147, 140, 50, 203, 48, 211, 140, 51, 207, 64, 19, 141, 52, 211, 80, 83, 141, 53, 215, 96, 147, 141, 54, 219, 112, 211, 141, 55, 223, 128, 19, 78, 0, 105, 115, 111, 56, 56, 53, 57, 56, 0, 0, 32, 0, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 192, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 240, 0, 0, 0, 0, 0, 64, 0, 1, 4, 16, 64, 0, 1, 4, 16, 64, 0, 1, 4, 16, 64, 0, 1, 4, 16, 64, 0, 1, 4, 16, 64, 0, 1, 4, 16, 64, 0, 1, 4, 16, 64, 0, 1, 4, 16, 192, 136, 83, 81, 85, 149, 85, 87, 97, 149, 149, 86, 91, 113, 213, 149, 87, 95, 129, 21, 150, 88, 99, 145, 85, 150, 89, 103, 161, 149, 150, 90, 107, 177, 213, 86, 0, 1, 120, 248, 97, 0, 105, 115, 111, 56, 56, 53, 57, 57, 0, 0, 80, 45, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 244, 64, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 46, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 248, 80, 6, 0, 105, 115, 111, 56, 56, 53, 57, 49, 48, 0, 0, 32, 0, 84, 48, 66, 12, 57, 220, 16, 4, 0, 70, 132, 96, 6, 27, 131, 0, 0, 135, 20, 0, 88, 64, 130, 12, 58, 224, 32, 4, 0, 71, 136, 112, 70, 27, 132, 136, 24, 199, 20, 17, 0, 0, 0, 0, 0, 0, 0, 192, 14, 29, 0, 112, 2, 0, 37, 0, 0, 0, 0, 0, 56, 65, 5, 0, 0, 0, 0, 128, 27, 0, 224, 1, 0, 0, 0, 0, 0, 0, 0, 18, 0, 0, 0, 0, 0, 0, 0, 0, 15, 30, 0, 128, 2, 0, 38, 0, 0, 0, 0, 0, 60, 81, 5, 0, 0, 0, 0, 192, 27, 0, 228, 1, 0, 0, 0, 0, 0, 192, 16, 105, 115, 111, 56, 56, 53, 57, 49, 49, 0, 116, 105, 115, 54, 50, 48, 0, 0, 32, 0, 188, 6, 91, 108, 178, 205, 70, 91, 109, 182, 221, 134, 91, 110, 186, 237, 198, 91, 111, 190, 253, 6, 92, 112, 194, 13, 71, 92, 113, 198, 29, 135, 92, 114, 202, 45, 199, 92, 115, 206, 61, 7, 93, 116, 210, 77, 71, 93, 117, 214, 93, 135, 93, 118, 218, 109, 199, 93, 119, 222, 125, 7, 94, 120, 226, 141, 71, 94, 121, 230, 157, 135, 94, 0, 1, 4, 16, 64, 122, 234, 173, 199, 94, 123, 238, 189, 7, 95, 124, 242, 205, 71, 95, 125, 246, 221, 135, 95, 126, 250, 237, 199, 95, 127, 254, 253, 7, 96, 128, 2, 14, 72, 96, 129, 1, 4, 16, 64, 0, 105, 115, 111, 56, 56, 53, 57, 49, 51, 0, 0, 32, 0, 160, 8, 0, 0, 0, 164, 8, 0, 0, 13, 0, 192, 5, 0, 0, 0, 0, 192, 2, 0, 0, 0, 0, 0, 39, 2, 0, 0, 0, 16, 0, 208, 5, 0, 0, 0, 0, 128, 3, 21, 236, 16, 193, 5, 0, 0, 112, 194, 8, 29, 0, 240, 71, 9, 49, 4, 145, 131, 17, 102, 48, 225, 4, 0, 84, 0, 0, 0, 0, 120, 40, 1, 6, 28, 0, 4, 50, 8, 0, 22, 240, 32, 1, 6, 0, 0, 128, 2, 9, 30, 0, 0, 136, 9, 50, 8, 161, 195, 17, 103, 52, 241, 4, 0, 85, 0, 0, 0, 0, 121, 44, 17, 70, 28, 0, 8, 66, 72, 137, 105, 115, 111, 56, 56, 53, 57, 49, 52, 0, 0, 32, 0, 24, 120, 32, 0, 27, 112, 128, 32, 0, 20, 2, 96, 97, 130, 26, 2, 0, 128, 31, 10, 46, 248, 2, 12, 12, 54, 8, 128, 131, 21, 62, 120, 33, 132, 27, 98, 152, 97, 132, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 122, 0, 0, 0, 0, 0, 0, 0, 128, 132, 0, 0, 0, 0, 0, 0, 0, 192, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 123, 0, 0, 0, 0, 0, 0, 0, 192, 132, 0, 0, 0, 0, 0, 0, 0, 208, 7, 0, 105, 115, 111, 56, 56, 53, 57, 49, 53, 0, 108, 97, 116, 105, 110, 57, 0, 0, 36, 51, 2, 96, 6, 0, 103, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 131, 0, 0, 0, 0, 132, 0, 0, 0, 0, 88, 100, 225, 7, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 105, 115, 111, 56, 56, 53, 57, 49, 54, 0, 0, 32, 0, 84, 96, 129, 18, 51, 166, 104, 6, 0, 103, 0, 160, 8, 0, 127, 0, 0, 72, 32, 0, 0, 208, 193, 18, 131, 160, 8, 0, 0, 132, 120, 176, 8, 0, 88, 100, 225, 135, 32, 0, 0, 0, 192, 4, 0, 92, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 33, 48, 1, 0, 0, 0, 88, 1, 0, 24, 118, 0, 0, 0, 0, 0, 156, 192, 8, 0, 0, 0, 0, 0, 5, 0, 96, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 34, 52, 1, 0, 0, 0, 92, 1, 64, 24, 119, 0, 0, 0, 0, 0, 160, 208, 8, 0, 99, 112, 49, 50, 53, 48, 0, 119, 105, 110, 100, 111, 119, 115, 49, 50, 53, 48, 0, 0, 0, 51, 6, 96, 98, 0, 41, 182, 168, 226, 138, 1, 184, 104, 198, 139, 96, 168, 49, 200, 31, 1, 144, 88, 226, 137, 40, 178, 8, 98, 136, 1, 216, 120, 6, 140, 97, 172, 65, 8, 32, 0, 60, 2, 137, 18, 0, 84, 0, 0, 0, 0, 0, 64, 6, 0, 0, 0, 0, 64, 32, 0, 0, 32, 201, 18, 0, 0, 0, 0, 0, 0, 88, 80, 6, 0, 72, 80, 146, 132, 32, 90, 0, 0, 192, 4, 0, 16, 113, 1, 0, 29, 0, 112, 2, 0, 41, 0, 0, 192, 7, 33, 48, 1, 5, 0, 0, 88, 1, 0, 0, 94, 208, 1, 128, 29, 0, 0, 128, 6, 0, 91, 0, 0, 0, 5, 0, 20, 129, 1, 0, 30, 0, 128, 2, 0, 42, 0, 0, 0, 8, 34, 52, 17, 5, 0, 0, 92, 1, 0, 0, 95, 212, 1, 192, 29, 0, 0, 144, 70, 36, 99, 112, 49, 50, 53, 49, 0, 119, 105, 110, 100, 111, 119, 115, 49, 50, 53, 49, 0, 0, 0, 227, 144, 99, 162, 76, 41, 182, 168, 226, 138, 51, 186, 168, 206, 139, 235, 180, 195, 206, 59, 49, 145, 88, 226, 137, 40, 178, 8, 98, 136, 1, 216, 136, 19, 140, 57, 237, 164, 83, 79, 0, 184, 195, 83, 58, 0, 248, 4, 0, 0, 226, 0, 80, 14, 0, 0, 0, 0, 0, 58, 0, 0, 112, 78, 77, 63, 1, 0, 0, 0, 48, 213, 56, 19, 0, 55, 153, 67, 147, 77, 240, 196, 35, 207, 60, 244, 212, 99, 207, 61, 248, 228, 163, 207, 62, 252, 244, 227, 207, 63, 0, 5, 36, 208, 64, 4, 21, 100, 208, 65, 8, 37, 164, 208, 66, 12, 53, 228, 208, 67, 16, 69, 36, 209, 68, 20, 85, 100, 209, 69, 24, 101, 164, 209, 70, 28, 117, 228, 209, 71, 32, 133, 36, 210, 72, 36, 149, 100, 210, 73, 40, 165, 164, 210, 74, 44, 181, 228, 210, 75, 99, 112, 49, 50, 53, 50, 0, 119, 105, 110, 100, 111, 119, 115, 49, 50, 53, 50, 0, 0, 0, 51, 6, 96, 98, 33, 41, 182, 168, 226, 138, 142, 184, 104, 198, 139, 88, 4, 48, 72, 0, 1, 144, 88, 226, 137, 40, 178, 8, 98, 136, 147, 216, 120, 6, 140, 89, 4, 64, 136, 31, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 99, 112, 49, 50, 53, 51, 0, 119, 105, 110, 100, 111, 119, 115, 49, 50, 53, 51, 0, 0, 0, 51, 6, 96, 98, 33, 41, 182, 168, 226, 138, 1, 184, 24, 192, 139, 1, 4, 16, 64, 0, 1, 144, 88, 226, 137, 40, 178, 8, 98, 136, 1, 216, 24, 0, 140, 1, 4, 16, 64, 0, 0, 112, 210, 9, 0, 0, 0, 0, 0, 0, 0, 0, 16, 0, 0, 0, 0, 0, 128, 136, 0, 0, 0, 0, 0, 155, 0, 0, 0, 0, 158, 124, 2, 10, 0, 161, 0, 32, 202, 40, 164, 148, 98, 202, 41, 168, 164, 162, 202, 42, 172, 180, 226, 202, 43, 176, 196, 34, 203, 44, 180, 212, 18, 128, 45, 183, 224, 146, 139, 46, 187, 240, 210, 139, 47, 191, 0, 19, 140, 48, 195, 16, 83, 140, 49, 199, 32, 147, 140, 50, 203, 48, 211, 140, 51, 207, 64, 19, 141, 52, 211, 80, 83, 141, 53, 215, 96, 147, 141, 54, 219, 112, 211, 141, 55, 223, 128, 19, 78, 0, 99, 112, 49, 50, 53, 52, 0, 119, 105, 110, 100, 111, 119, 115, 49, 50, 53, 52, 0, 0, 0, 51, 6, 96, 98, 33, 41, 182, 168, 226, 138, 142, 184, 104, 198, 139, 88, 4, 16, 64, 0, 1, 144, 88, 226, 137, 40, 178, 8, 98, 136, 147, 216, 120, 6, 140, 89, 4, 16, 128, 31, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 45, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 244, 64, 6, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 46, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 248, 80, 6, 0, 99, 112, 49, 50, 53, 53, 0, 119, 105, 110, 100, 111, 119, 115, 49, 50, 53, 53, 0, 0, 0, 51, 6, 96, 98, 33, 41, 182, 168, 226, 138, 142, 184, 24, 192, 139, 1, 4, 16, 64, 0, 1, 144, 88, 226, 137, 40, 178, 8, 98, 136, 147, 216, 24, 0, 140, 1, 4, 16, 64, 0, 0, 0, 0, 0, 0, 49, 2, 0, 0, 0, 0, 0, 192, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 240, 0, 0, 0, 0, 0, 0, 0, 64, 5, 37, 212, 80, 68, 21, 101, 212, 81, 72, 37, 21, 128, 82, 75, 49, 213, 148, 83, 79, 65, 21, 149, 84, 110, 189, 5, 87, 92, 114, 5, 16, 64, 0, 1, 4, 16, 64, 0, 83, 81, 85, 149, 85, 87, 97, 149, 149, 86, 91, 113, 213, 149, 87, 95, 129, 21, 150, 88, 99, 145, 85, 150, 89, 103, 161, 149, 150, 90, 107, 177, 213, 86, 0, 1, 120, 248, 97, 0, 99, 112, 49, 50, 53, 54, 0, 119, 105, 110, 100, 111, 119, 115, 49, 50, 53, 54, 0, 0, 0, 51, 146, 102, 98, 33, 41, 182, 168, 226, 138, 142, 184, 56, 218, 139, 88, 148, 134, 154, 105, 170, 145, 88, 226, 137, 40, 178, 8, 98, 136, 169, 217, 120, 26, 140, 89, 112, 216, 225, 106, 0, 204, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 192, 26, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 64, 23, 0, 0, 0, 0, 64, 93, 173, 217, 117, 23, 94, 121, 233, 181, 23, 95, 125, 249, 245, 23, 96, 129, 9, 54, 24, 97, 133, 25, 118, 24, 98, 137, 41, 182, 24, 0, 140, 53, 230, 216, 99, 144, 69, 38, 217, 100, 0, 80, 6, 64, 101, 150, 93, 134, 25, 0, 0, 0, 0, 0, 0, 153, 105, 6, 0, 0, 155, 113, 214, 153, 103, 0, 124, 6, 26, 0, 161, 1, 32, 26, 0, 0, 120, 248, 161, 107, 99, 112, 49, 50, 53, 55, 0, 119, 105, 110, 100, 111, 119, 115, 49, 50, 53, 55, 0, 0, 0, 51, 6, 96, 98, 0, 41, 182, 168, 226, 138, 1, 184, 24, 192, 139, 1, 16, 240, 136, 2, 1, 144, 88, 226, 137, 40, 178, 8, 98, 136, 1, 216, 24, 0, 140, 1, 24, 32, 73, 0, 0, 4, 0, 0, 0, 0, 4, 0, 0, 0, 13, 0, 192, 5, 0, 0, 0, 0, 192, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 16, 0, 208, 5, 0, 0, 0, 0, 128, 3, 21, 236, 16, 193, 5, 0, 0, 112, 194, 8, 29, 0, 240, 71, 9, 49, 4, 145, 131, 17, 102, 48, 225, 4, 0, 84, 0, 0, 0, 0, 120, 40, 1, 6, 28, 0, 4, 50, 8, 0, 22, 240, 32, 1, 6, 0, 0, 128, 2, 9, 30, 0, 0, 136, 9, 50, 8, 161, 195, 17, 103, 52, 241, 4, 0, 85, 0, 0, 0, 0, 121, 44, 17, 70, 28, 0, 8, 66, 72, 36, 99, 112, 49, 50, 53, 56, 0, 119, 105, 110, 100, 111, 119, 115, 49, 50, 53, 56, 0, 0, 0, 51, 6, 96, 98, 33, 41, 182, 168, 226, 138, 142, 184, 24, 192, 139, 88, 4, 16, 64, 0, 1, 144, 88, 226, 137, 40, 178, 8, 98, 136, 147, 216, 24, 0, 140, 89, 4, 16, 128, 31, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 192, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 149, 0, 0, 0, 0, 33, 0, 128, 9, 0, 0, 24, 2, 0, 0, 0, 0, 0, 0, 0, 0, 32, 114, 9, 0, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 150, 0, 0, 0, 0, 34, 0, 144, 9, 0, 0, 28, 2, 0, 0, 0, 0, 0, 0, 0, 0, 36, 34, 35, 0, 107, 111, 105, 56, 114, 0, 0, 0, 62, 254, 8, 100, 144, 66, 14, 73, 100, 145, 70, 30, 137, 164, 153, 103, 162, 153, 166, 154, 107, 178, 217, 38, 143, 110, 222, 136, 99, 142, 58, 238, 40, 64, 143, 7, 32, 144, 192, 3, 73, 42, 185, 36, 76, 76, 54, 233, 228, 147, 80, 70, 41, 229, 148, 84, 86, 105, 229, 149, 88, 102, 169, 165, 56, 91, 114, 217, 165, 151, 95, 130, 25, 166, 152, 99, 146, 89, 102, 1, 46, 65, 20, 145, 73, 20, 85, 68, 210, 68, 37, 97, 148, 145, 70, 27, 113, 212, 145, 71, 31, 189, 4, 82, 72, 34, 141, 100, 145, 68, 44, 173, 116, 17, 74, 45, 165, 116, 146, 74, 14, 193, 19, 143, 65, 244, 212, 67, 208, 60, 5, 225, 147, 143, 62, 251, 240, 211, 143, 63, 255, 60, 4, 80, 64, 2, 13, 100, 143, 60, 12, 45, 116, 15, 66, 13, 37, 116, 144, 66, 107, 111, 105, 56, 117, 0, 0, 0, 62, 254, 8, 100, 144, 66, 14, 73, 100, 145, 70, 30, 137, 164, 153, 103, 162, 153, 166, 154, 107, 178, 217, 38, 143, 110, 222, 136, 99, 142, 58, 238, 40, 64, 143, 7, 32, 144, 192, 3, 73, 42, 185, 36, 76, 51, 53, 89, 147, 77, 80, 70, 41, 229, 148, 84, 254, 100, 229, 149, 88, 102, 169, 165, 56, 229, 112, 121, 14, 58, 95, 130, 25, 166, 152, 99, 250, 84, 102, 1, 46, 65, 20, 145, 73, 20, 85, 68, 210, 68, 37, 97, 148, 145, 70, 27, 113, 212, 145, 71, 31, 189, 4, 82, 72, 34, 141, 100, 145, 68, 44, 173, 116, 17, 74, 45, 165, 116, 146, 74, 14, 193, 19, 143, 65, 244, 212, 67, 208, 60, 5, 225, 147, 143, 62, 251, 240, 211, 143, 63, 255, 60, 4, 80, 64, 2, 13, 100, 143, 60, 12, 45, 116, 15, 66, 13, 37, 116, 144, 66, 0, 0, 0, 0, 0, 0, 0, 0, 0, 48, 1, 48, 2, 48, 12, 255, 14, 255, 251, 48, 26, 255, 27, 255, 31, 255, 1, 255, 155, 48, 156, 48, 180, 0, 64, 255, 168, 0, 62, 255, 227, 255, 63, 255, 253, 48, 254, 48, 157, 48, 158, 48, 3, 48, 221, 78, 5, 48, 6, 48, 7, 48, 252, 48, 21, 32, 16, 32, 15, 255, 92, 0, 28, 48, 22, 32, 92, 255, 38, 32, 37, 32, 24, 32, 25, 32, 28, 32, 29, 32, 8, 255, 9, 255, 20, 48, 21, 48, 59, 255, 61, 255, 91, 255, 93, 255, 8, 48, 9, 48, 10, 48, 11, 48, 12, 48, 13, 48, 14, 48, 15, 48, 16, 48, 17, 48, 11, 255, 18, 34, 177, 0, 215, 0, 247, 0, 29, 255, 96, 34, 28, 255, 30, 255, 102, 34, 103, 34, 30, 34, 52, 34, 66, 38, 64, 38, 176, 0, 50, 32, 51, 32, 3, 33, 229, 255, 4, 255, 162, 0, 163, 0, 5, 255, 3, 255, 6, 255, 10, 255, 32, 255, 167, 0, 6, 38, 5, 38, 203, 37, 207, 37, 206, 37, 199, 37, 198, 37, 161, 37, 160, 37, 179, 37, 178, 37, 189, 37, 188, 37, 59, 32, 18, 48, 146, 33, 144, 33, 145, 33, 147, 33, 19, 48, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 34, 11, 34, 134, 34, 135, 34, 130, 34, 131, 34, 42, 34, 41, 34, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 39, 34, 40, 34, 172, 0, 210, 33, 212, 33, 0, 34, 3, 34, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 32, 34, 165, 34, 18, 35, 2, 34, 7, 34, 97, 34, 82, 34, 106, 34, 107, 34, 26, 34, 61, 34, 29, 34, 53, 34, 43, 34, 44, 34, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 43, 33, 48, 32, 111, 38, 109, 38, 106, 38, 32, 32, 33, 32, 182, 0, 0, 0, 0, 0, 0, 0, 0, 0, 239, 37, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 16, 255, 17, 255, 18, 255, 19, 255, 20, 255, 21, 255, 22, 255, 23, 255, 24, 255, 25, 255], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 197488);
	        allocate([33, 255, 34, 255, 35, 255, 36, 255, 37, 255, 38, 255, 39, 255, 40, 255, 41, 255, 42, 255, 43, 255, 44, 255, 45, 255, 46, 255, 47, 255, 48, 255, 49, 255, 50, 255, 51, 255, 52, 255, 53, 255, 54, 255, 55, 255, 56, 255, 57, 255, 58, 255, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 65, 255, 66, 255, 67, 255, 68, 255, 69, 255, 70, 255, 71, 255, 72, 255, 73, 255, 74, 255, 75, 255, 76, 255, 77, 255, 78, 255, 79, 255, 80, 255, 81, 255, 82, 255, 83, 255, 84, 255, 85, 255, 86, 255, 87, 255, 88, 255, 89, 255, 90, 255, 0, 0, 0, 0, 0, 0, 0, 0, 65, 48, 66, 48, 67, 48, 68, 48, 69, 48, 70, 48, 71, 48, 72, 48, 73, 48, 74, 48, 75, 48, 76, 48, 77, 48, 78, 48, 79, 48, 80, 48, 81, 48, 82, 48, 83, 48, 84, 48, 85, 48, 86, 48, 87, 48, 88, 48, 89, 48, 90, 48, 91, 48, 92, 48, 93, 48, 94, 48, 95, 48, 96, 48, 97, 48, 98, 48, 99, 48, 100, 48, 101, 48, 102, 48, 103, 48, 104, 48, 105, 48, 106, 48, 107, 48, 108, 48, 109, 48, 110, 48, 111, 48, 112, 48, 113, 48, 114, 48, 115, 48, 116, 48, 117, 48, 118, 48, 119, 48, 120, 48, 121, 48, 122, 48, 123, 48, 124, 48, 125, 48, 126, 48, 127, 48, 128, 48, 129, 48, 130, 48, 131, 48, 132, 48, 133, 48, 134, 48, 135, 48, 136, 48, 137, 48, 138, 48, 139, 48, 140, 48, 141, 48, 142, 48, 143, 48, 144, 48, 145, 48, 146, 48, 147, 48, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 161, 48, 162, 48, 163, 48, 164, 48, 165, 48, 166, 48, 167, 48, 168, 48, 169, 48, 170, 48, 171, 48, 172, 48, 173, 48, 174, 48, 175, 48, 176, 48, 177, 48, 178, 48, 179, 48, 180, 48, 181, 48, 182, 48, 183, 48, 184, 48, 185, 48, 186, 48, 187, 48, 188, 48, 189, 48, 190, 48, 191, 48, 192, 48, 193, 48, 194, 48, 195, 48, 196, 48, 197, 48, 198, 48, 199, 48, 200, 48, 201, 48, 202, 48, 203, 48, 204, 48, 205, 48, 206, 48, 207, 48, 208, 48, 209, 48, 210, 48, 211, 48, 212, 48, 213, 48, 214, 48, 215, 48, 216, 48, 217, 48, 218, 48, 219, 48, 220, 48, 221, 48, 222, 48, 223, 48, 224, 48, 225, 48, 226, 48, 227, 48, 228, 48, 229, 48, 230, 48, 231, 48, 232, 48, 233, 48, 234, 48, 235, 48, 236, 48, 237, 48, 238, 48, 239, 48, 240, 48, 241, 48, 242, 48, 243, 48, 244, 48, 245, 48, 246, 48, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 145, 3, 146, 3, 147, 3, 148, 3, 149, 3, 150, 3, 151, 3, 152, 3, 153, 3, 154, 3, 155, 3, 156, 3, 157, 3, 158, 3, 159, 3, 160, 3, 161, 3, 163, 3, 164, 3, 165, 3, 166, 3, 167, 3, 168, 3, 169, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 177, 3, 178, 3, 179, 3, 180, 3, 181, 3, 182, 3, 183, 3, 184, 3, 185, 3, 186, 3, 187, 3, 188, 3, 189, 3, 190, 3, 191, 3, 192, 3, 193, 3, 195, 3, 196, 3, 197, 3, 198, 3, 199, 3, 200, 3, 201, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 16, 4, 17, 4, 18, 4, 19, 4, 20, 4, 21, 4, 1, 4, 22, 4, 23, 4, 24, 4, 25, 4, 26, 4, 27, 4, 28, 4, 29, 4, 30, 4, 31, 4, 32, 4, 33, 4, 34, 4, 35, 4, 36, 4, 37, 4, 38, 4, 39, 4, 40, 4, 41, 4, 42, 4, 43, 4, 44, 4, 45, 4, 46, 4, 47, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 48, 4, 49, 4, 50, 4, 51, 4, 52, 4, 53, 4, 81, 4, 54, 4, 55, 4, 56, 4, 57, 4, 58, 4, 59, 4, 60, 4, 61, 4, 62, 4, 63, 4, 64, 4, 65, 4, 66, 4, 67, 4, 68, 4, 69, 4, 70, 4, 71, 4, 72, 4, 73, 4, 74, 4, 75, 4, 76, 4, 77, 4, 78, 4, 79, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 37, 2, 37, 12, 37, 16, 37, 24, 37, 20, 37, 28, 37, 44, 37, 36, 37, 52, 37, 60, 37, 1, 37, 3, 37, 15, 37, 19, 37, 27, 37, 23, 37, 35, 37, 51, 37, 43, 37, 59, 37, 75, 37, 32, 37, 47, 37, 40, 37, 55, 37, 63, 37, 29, 37, 48, 37, 37, 37, 56, 37, 66, 37], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 207728);
	        allocate([156, 78, 22, 85, 3, 90, 63, 150, 192, 84, 27, 97, 40, 99, 246, 89, 34, 144, 117, 132, 28, 131, 80, 122, 170, 96, 225, 99, 37, 110, 237, 101, 102, 132, 166, 130, 245, 155, 147, 104, 39, 87, 161, 101, 113, 98, 155, 91, 208, 89, 123, 134, 244, 152, 98, 125, 190, 125, 142, 155, 22, 98, 159, 124, 183, 136, 137, 91, 181, 94, 9, 99, 151, 102, 72, 104, 199, 149, 141, 151, 79, 103, 229, 78, 10, 79, 77, 79, 157, 79, 73, 80, 242, 86, 55, 89, 212, 89, 1, 90, 9, 92, 223, 96, 15, 97, 112, 97, 19, 102, 5, 105, 186, 112, 79, 117, 112, 117, 251, 121, 173, 125, 239, 125, 195, 128, 14, 132, 99, 136, 2, 139, 85, 144, 122, 144, 59, 83, 149, 78, 165, 78, 223, 87, 178, 128, 193, 144, 239, 120, 0, 78, 241, 88, 162, 110, 56, 144, 50, 122, 40, 131, 139, 130, 47, 156, 65, 81, 112, 83, 189, 84, 225, 84, 224, 86, 251, 89, 21, 95, 242, 152, 235, 109, 228, 128, 45, 133, 98, 150, 112, 150, 160, 150, 251, 151, 11, 84, 243, 83, 135, 91, 207, 112, 189, 127, 194, 143, 232, 150, 111, 83, 92, 157, 186, 122, 17, 78, 147, 120, 252, 129, 38, 110, 24, 86, 4, 85, 29, 107, 26, 133, 59, 156, 229, 89, 169, 83, 102, 109, 220, 116, 143, 149, 66, 86, 145, 78, 75, 144, 242, 150, 79, 131, 12, 153, 225, 83, 182, 85, 48, 91, 113, 95, 32, 102, 243, 102, 4, 104, 56, 108, 243, 108, 41, 109, 91, 116, 200, 118, 78, 122, 52, 152, 241, 130, 91, 136, 96, 138, 237, 146, 178, 109, 171, 117, 202, 118, 197, 153, 166, 96, 1, 139, 138, 141, 178, 149, 142, 105, 173, 83, 134, 81, 18, 87, 48, 88, 68, 89, 180, 91, 246, 94, 40, 96, 169, 99, 244, 99, 191, 108, 20, 111, 142, 112, 20, 113, 89, 113, 213, 113, 63, 115, 1, 126, 118, 130, 209, 130, 151, 133, 96, 144, 91, 146, 27, 157, 105, 88, 188, 101, 90, 108, 37, 117, 249, 81, 46, 89, 101, 89, 128, 95, 220, 95, 188, 98, 250, 101, 42, 106, 39, 107, 180, 107, 139, 115, 193, 127, 86, 137, 44, 157, 14, 157, 196, 158, 161, 92, 150, 108, 123, 131, 4, 81, 75, 92, 182, 97, 198, 129, 118, 104, 97, 114, 89, 78, 250, 79, 120, 83, 105, 96, 41, 110, 79, 122, 243, 151, 11, 78, 22, 83, 238, 78, 85, 79, 61, 79, 161, 79, 115, 79, 160, 82, 239, 83, 9, 86, 15, 89, 193, 90, 182, 91, 225, 91, 209, 121, 135, 102, 156, 103, 182, 103, 76, 107, 179, 108, 107, 112, 194, 115, 141, 121, 190, 121, 60, 122, 135, 123, 177, 130, 219, 130, 4, 131, 119, 131, 239, 131, 211, 131, 102, 135, 178, 138, 41, 86, 168, 140, 230, 143, 78, 144, 30, 151, 138, 134, 196, 79, 232, 92, 17, 98, 89, 114, 59, 117, 229, 129, 189, 130, 254, 134, 192, 140, 197, 150, 19, 153, 213, 153, 203, 78, 26, 79, 227, 137, 222, 86, 74, 88, 202, 88, 251, 94, 235, 95, 42, 96, 148, 96, 98, 96, 208, 97, 18, 98, 208, 98, 57, 101, 65, 155, 102, 102, 176, 104, 119, 109, 112, 112, 76, 117, 134, 118, 117, 125, 165, 130, 249, 135, 139, 149, 142, 150, 157, 140, 241, 81, 190, 82, 22, 89, 179, 84, 179, 91, 22, 93, 104, 97, 130, 105, 175, 109, 141, 120, 203, 132, 87, 136, 114, 138, 167, 147, 184, 154, 108, 109, 168, 153, 217, 134, 163, 87, 255, 103, 206, 134, 14, 146, 131, 82, 135, 86, 4, 84, 211, 94, 225, 98, 185, 100, 60, 104, 56, 104, 187, 107, 114, 115, 186, 120, 107, 122, 154, 137, 210, 137, 107, 141, 3, 143, 237, 144, 163, 149, 148, 150, 105, 151, 102, 91, 179, 92, 125, 105, 77, 152, 78, 152, 155, 99, 32, 123, 43, 106, 127, 106, 182, 104, 13, 156, 95, 111, 114, 82, 157, 85, 112, 96, 236, 98, 59, 109, 7, 110, 209, 110, 91, 132, 16, 137, 68, 143, 20, 78, 57, 156, 246, 83, 27, 105, 58, 106, 132, 151, 42, 104, 92, 81, 195, 122, 178, 132, 220, 145, 140, 147, 91, 86, 40, 157, 34, 104, 5, 131, 49, 132, 165, 124, 8, 82, 197, 130, 230, 116, 126, 78, 131, 79, 160, 81, 210, 91, 10, 82, 216, 82, 231, 82, 251, 93, 154, 85, 42, 88, 230, 89, 140, 91, 152, 91, 219, 91, 114, 94, 121, 94, 163, 96, 31, 97, 99, 97, 190, 97, 219, 99, 98, 101, 209, 103, 83, 104, 250, 104, 62, 107, 83, 107, 87, 108, 34, 111, 151, 111, 69, 111, 176, 116, 24, 117, 227, 118, 11, 119, 255, 122, 161, 123, 33, 124, 233, 125, 54, 127, 240, 127, 157, 128, 102, 130, 158, 131, 179, 137, 204, 138, 171, 140, 132, 144, 81, 148, 147, 149, 145, 149, 162, 149, 101, 150, 211, 151, 40, 153, 24, 130, 56, 78, 43, 84, 184, 92, 204, 93, 169, 115, 76, 118, 60, 119, 169, 92, 235, 127, 11, 141, 193, 150, 17, 152, 84, 152, 88, 152, 1, 79, 14, 79, 113, 83, 156, 85, 104, 86, 250, 87, 71, 89, 9, 91, 196, 91, 144, 92, 12, 94, 126, 94, 204, 95, 238, 99, 58, 103, 215, 101, 226, 101, 31, 103, 203, 104, 196, 104, 95, 106, 48, 94, 197, 107, 23, 108, 125, 108, 127, 117, 72, 121, 99, 91, 0, 122, 0, 125, 189, 95, 143, 137, 24, 138, 180, 140, 119, 141, 204, 142, 29, 143, 226, 152, 14, 154, 60, 155, 128, 78, 125, 80, 0, 81, 147, 89, 156, 91, 47, 98, 128, 98, 236, 100, 58, 107, 160, 114, 145, 117, 71, 121, 169, 127, 251, 135, 188, 138, 112, 139, 172, 99, 202, 131, 160, 151, 9, 84, 3, 84, 171, 85, 84, 104, 88, 106, 112, 138, 39, 120, 117, 103, 205, 158, 116, 83, 162, 91, 26, 129, 80, 134, 6, 144, 24, 78, 69, 78, 199, 78, 17, 79, 202, 83, 56, 84, 174, 91, 19, 95, 37, 96, 81, 101, 61, 103, 66, 108, 114, 108, 227, 108, 120, 112, 3, 116, 118, 122, 174, 122, 8, 123, 26, 125, 254, 124, 102, 125, 231, 101, 91, 114, 187, 83, 69, 92, 232, 93, 210, 98, 224, 98, 25, 99, 32, 110, 90, 134, 49, 138, 221, 141, 248, 146, 1, 111, 166, 121, 90, 155, 168, 78, 171, 78, 172, 78, 155, 79, 160, 79, 209, 80, 71, 81, 246, 122, 113, 81, 246, 81, 84, 83, 33, 83, 127, 83, 235, 83, 172, 85, 131, 88, 225, 92, 55, 95, 74, 95, 47, 96, 80, 96, 109, 96, 31, 99, 89, 101, 75, 106, 193, 108, 194, 114, 237, 114, 239, 119, 248, 128, 5, 129, 8, 130, 78, 133, 247, 144, 225, 147, 255, 151, 87, 153, 90, 154, 240, 78, 221, 81, 45, 92, 129, 102, 109, 105, 64, 92, 242, 102, 117, 105, 137, 115, 80, 104, 129, 124, 197, 80, 228, 82, 71, 87, 254, 93, 38, 147, 164, 101, 35, 107, 61, 107, 52, 116, 129, 121, 189, 121, 75, 123, 202, 125, 185, 130, 204, 131, 127, 136, 95, 137, 57, 139, 209, 143, 209, 145, 31, 84, 128, 146, 93, 78, 54, 80, 229, 83, 58, 83, 215, 114, 150, 115, 233, 119, 230, 130, 175, 142, 198, 153, 200, 153, 210, 153, 119, 81, 26, 97, 94, 134, 176, 85, 122, 122, 118, 80, 211, 91, 71, 144, 133, 150, 50, 78, 219, 106, 231, 145, 81, 92, 72, 92, 152, 99, 159, 122, 147, 108, 116, 151, 97, 143, 170, 122, 138, 113, 136, 150, 130, 124, 23, 104, 112, 126, 81, 104, 108, 147, 242, 82, 27, 84, 171, 133, 19, 138, 164, 127, 205, 142, 225, 144, 102, 83, 136, 136, 65, 121, 194, 79, 190, 80, 17, 82, 68, 81, 83, 85, 45, 87, 234, 115, 139, 87, 81, 89, 98, 95, 132, 95, 117, 96, 118, 97, 103, 97, 169, 97, 178, 99, 58, 100, 108, 101, 111, 102, 66, 104, 19, 110, 102, 117, 61, 122, 251, 124, 76, 125, 153, 125, 75, 126, 107, 127, 14, 131, 74, 131, 205, 134, 8, 138, 99, 138, 102, 139, 253, 142, 26, 152, 143, 157, 184, 130, 206, 143, 232, 155, 135, 82, 31, 98, 131, 100, 192, 111, 153, 150, 65, 104, 145, 80, 32, 107, 122, 108, 84, 111, 116, 122, 80, 125, 64, 136, 35, 138, 8, 103, 246, 78, 57, 80, 38, 80, 101, 80, 124, 81, 56, 82, 99, 82, 167, 85, 15, 87, 5, 88, 204, 90, 250, 94, 178, 97, 248, 97, 243, 98, 114, 99, 28, 105, 41, 106, 125, 114, 172, 114, 46, 115, 20, 120, 111, 120, 121, 125, 12, 119, 169, 128, 139, 137, 25, 139, 226, 140, 210, 142, 99, 144, 117, 147, 122, 150, 85, 152, 19, 154, 120, 158, 67, 81, 159, 83, 179, 83, 123, 94, 38, 95, 27, 110, 144, 110, 132, 115, 254, 115, 67, 125, 55, 130, 0, 138, 250, 138, 80, 150, 78, 78, 11, 80, 228, 83, 124, 84, 250, 86, 209, 89, 100, 91, 241, 93, 171, 94, 39, 95, 56, 98, 69, 101, 175, 103, 86, 110, 208, 114, 202, 124, 180, 136, 161, 128, 225, 128, 240, 131, 78, 134, 135, 138, 232, 141, 55, 146, 199, 150, 103, 152, 19, 159, 148, 78, 146, 78, 13, 79, 72, 83, 73, 84, 62, 84, 47, 90, 140, 95, 161, 95, 159, 96, 167, 104, 142, 106, 90, 116, 129, 120, 158, 138, 164, 138, 119, 139, 144, 145, 94, 78, 201, 155, 164, 78, 124, 79, 175, 79, 25, 80, 22, 80, 73, 81, 108, 81, 159, 82, 185, 82, 254, 82, 154, 83, 227, 83, 17, 84, 14, 84, 137, 85, 81, 87, 162, 87, 125, 89, 84, 91, 93, 91, 143, 91, 229, 93, 231, 93, 247, 93, 120, 94, 131, 94, 154, 94, 183, 94, 24, 95, 82, 96, 76, 97, 151, 98, 216, 98, 167, 99, 59, 101, 2, 102, 67, 102, 244, 102, 109, 103, 33, 104, 151, 104, 203, 105, 95, 108, 42, 109, 105, 109, 47, 110, 157, 110, 50, 117, 135, 118, 108, 120, 63, 122, 224, 124, 5, 125, 24, 125, 94, 125, 177, 125, 21, 128, 3, 128, 175, 128, 177, 128, 84, 129, 143, 129, 42, 130, 82, 131, 76, 136, 97, 136, 27, 139, 162, 140, 252, 140, 202, 144, 117, 145, 113, 146, 63, 120, 252, 146, 164, 149, 77, 150, 5, 152, 153, 153, 216, 154, 59, 157, 91, 82, 171, 82, 247, 83, 8, 84, 213, 88, 247, 98, 224, 111, 106, 140, 95, 143, 185, 158, 75, 81, 59, 82, 74, 84, 253, 86, 64, 122, 119, 145, 96, 157, 210, 158, 68, 115, 9, 111, 112, 129, 17, 117, 253, 95, 218, 96, 168, 154, 219, 114, 188, 143, 100, 107, 3, 152, 202, 78, 240, 86, 100, 87, 190, 88, 90, 90, 104, 96, 199, 97, 15, 102, 6, 102, 57, 104, 177, 104, 247, 109, 213, 117, 58, 125, 110, 130, 66, 155, 155, 78, 80, 79, 201, 83, 6, 85, 111, 93, 230, 93, 238, 93, 251, 103, 153, 108, 115, 116, 2, 120, 80, 138, 150, 147, 223, 136, 80, 87, 167, 94, 43, 99, 181, 80, 172, 80, 141, 81, 0, 103, 201, 84, 94, 88, 187, 89, 176, 91, 105, 95, 77, 98, 161, 99, 61, 104, 115, 107, 8, 110, 125, 112, 199, 145, 128, 114, 21, 120, 38, 120, 109, 121, 142, 101, 48, 125, 220, 131, 193, 136, 9, 143, 155, 150, 100, 82, 40, 87, 80, 103, 106, 127, 161, 140, 180, 81, 66, 87, 42, 150, 58, 88, 138, 105, 180, 128, 178, 84, 14, 93, 252, 87, 149, 120, 250, 157, 92, 79, 74, 82, 139, 84, 62, 100, 40, 102, 20, 103, 245, 103, 132, 122, 86, 123, 34, 125, 47, 147, 92, 104, 173, 155, 57, 123, 25, 83, 138, 81, 55, 82, 223, 91, 246, 98, 174, 100, 230, 100, 45, 103, 186, 107, 169, 133, 209, 150, 144, 118, 214, 155, 76, 99, 6, 147, 171, 155, 191, 118, 82, 102, 9, 78, 152, 80, 194, 83, 113, 92, 232, 96, 146, 100, 99, 101, 95, 104, 230, 113, 202, 115, 35, 117, 151, 123, 130, 126, 149, 134, 131, 139, 219, 140, 120, 145, 16, 153, 172, 101, 171, 102, 139, 107, 213, 78, 212, 78, 58, 79, 127, 79, 58, 82, 248, 83, 242, 83, 227, 85, 219, 86, 235, 88, 203, 89, 201, 89, 255, 89, 80, 91, 77, 92, 2, 94, 43, 94, 215, 95, 29, 96, 7, 99, 47, 101, 92, 91, 175, 101, 189, 101, 232, 101, 157, 103, 98, 107, 123, 107, 15, 108, 69, 115, 73, 121, 193, 121, 248, 124, 25, 125, 43, 125, 162, 128, 2, 129, 243, 129, 150, 137, 94, 138, 105, 138, 102, 138, 140, 138, 238, 138, 199, 140, 220, 140, 204, 150, 252, 152, 111, 107, 139, 78, 60, 79, 141, 79, 80, 81, 87, 91, 250, 91, 72, 97, 1, 99, 66, 102, 33, 107, 203, 110, 187, 108, 62, 114, 189, 116, 212, 117, 193, 120, 58, 121, 12, 128, 51, 128, 234, 129, 148, 132, 158, 143, 80, 108, 127, 158, 15, 95, 88, 139, 43, 157, 250, 122, 248, 142, 141, 91, 235, 150, 3, 78, 241, 83, 247, 87, 49, 89, 201, 90, 164, 91, 137, 96, 127, 110, 6, 111, 190, 117, 234, 140, 159, 91, 0, 133, 224, 123, 114, 80, 244, 103, 157, 130, 97, 92, 74, 133, 30, 126, 14, 130, 153, 81, 4, 92, 104, 99, 102, 141, 156, 101, 110, 113, 62, 121, 23, 125, 5, 128, 29, 139, 202, 142, 110, 144, 199, 134, 170, 144, 31, 80, 250, 82, 58, 92, 83, 103, 124, 112, 53, 114, 76, 145, 200, 145, 43, 147, 229, 130, 194, 91, 49, 95, 249, 96, 59, 78, 214, 83, 136, 91, 75, 98, 49, 103, 138, 107, 233, 114, 224, 115, 46, 122, 107, 129, 163, 141, 82, 145, 150, 153, 18, 81, 215, 83, 106, 84, 255, 91, 136, 99, 57, 106, 172, 125, 0, 151, 218, 86, 206, 83, 104, 84, 151, 91, 49, 92, 222, 93, 238, 79, 1, 97, 254, 98, 50, 109, 192, 121, 203, 121, 66, 125, 77, 126, 210, 127, 237, 129, 31, 130, 144, 132, 70, 136, 114, 137, 144, 139, 116, 142, 47, 143, 49, 144, 75, 145, 108, 145, 198, 150, 156, 145, 192, 78, 79, 79, 69, 81, 65, 83, 147, 95, 14, 98, 212, 103, 65, 108, 11, 110, 99, 115, 38, 126, 205, 145, 131, 146, 212, 83, 25, 89, 191, 91, 209, 109, 93, 121, 46, 126, 155, 124, 126, 88, 159, 113, 250, 81, 83, 136, 240, 143, 202, 79, 251, 92, 37, 102, 172, 119, 227, 122, 28, 130, 255, 153, 198, 81, 170, 95, 236, 101, 111, 105, 137, 107, 243, 109, 150, 110, 100, 111, 254, 118, 20, 125, 225, 93, 117, 144, 135, 145, 6, 152, 230, 81, 29, 82, 64, 98, 145, 102, 217, 102, 26, 110, 182, 94, 210, 125, 114, 127, 248, 102, 175, 133, 247, 133, 248, 138, 169, 82, 217, 83, 115, 89, 143, 94, 144, 95, 85, 96, 228, 146, 100, 150, 183, 80, 31, 81, 221, 82, 32, 83, 71, 83, 236, 83, 232, 84, 70, 85, 49, 85, 23, 86, 104, 89, 190, 89, 60, 90, 181, 91, 6, 92, 15, 92, 17, 92, 26, 92, 132, 94, 138, 94, 224, 94, 112, 95, 127, 98, 132, 98, 219, 98, 140, 99, 119, 99, 7, 102, 12, 102, 45, 102, 118, 102, 126, 103, 162, 104, 31, 106, 53, 106, 188, 108, 136, 109, 9, 110, 88, 110, 60, 113, 38, 113, 103, 113, 199, 117, 1, 119, 93, 120, 1, 121, 101, 121, 240, 121, 224, 122, 17, 123, 167, 124, 57, 125, 150, 128, 214, 131, 139, 132, 73, 133, 93, 136, 243, 136, 31, 138, 60, 138, 84, 138, 115, 138, 97, 140, 222, 140, 164, 145, 102, 146, 126, 147, 24, 148, 156, 150, 152, 151, 10, 78, 8, 78, 30, 78, 87, 78, 151, 81, 112, 82, 206, 87, 52, 88, 204, 88, 34, 91, 56, 94, 197, 96, 254, 100, 97, 103, 86, 103, 68, 109, 182, 114, 115, 117, 99, 122, 184, 132, 114, 139, 184, 145, 32, 147, 49, 86, 244, 87, 254, 152, 237, 98, 13, 105, 150, 107, 237, 113, 84, 126, 119, 128, 114, 130, 230, 137, 223, 152, 85, 135, 177, 143, 59, 92, 56, 79, 225, 79, 181, 79, 7, 85, 32, 90, 221, 91, 233, 91, 195, 95, 78, 97, 47, 99, 176, 101, 75, 102, 238, 104, 155, 105, 120, 109, 241, 109, 51, 117, 185, 117, 31, 119, 94, 121, 230, 121, 51, 125, 227, 129, 175, 130, 170, 133, 170, 137, 58, 138, 171, 142, 155, 143, 50, 144, 221, 145, 7, 151, 186, 78, 193, 78, 3, 82, 117, 88, 236, 88, 11, 92, 26, 117, 61, 92, 78, 129, 10, 138, 197, 143, 99, 150, 109, 151, 37, 123, 207, 138, 8, 152, 98, 145, 243, 86, 168, 83, 23, 144, 57, 84, 130, 87, 37, 94, 168, 99, 52, 108, 138, 112, 97, 119, 139, 124, 224, 127, 112, 136, 66, 144, 84, 145, 16, 147, 24, 147, 143, 150, 94, 116, 196, 154, 7, 93, 105, 93, 112, 101, 162, 103, 168, 141, 219, 150, 110, 99, 73, 103, 25, 105, 197, 131, 23, 152, 192, 150, 254, 136, 132, 111, 122, 100, 248, 91, 22, 78, 44, 112, 93, 117, 47, 102, 196, 81, 54, 82, 226, 82, 211, 89, 129, 95, 39, 96, 16, 98, 63, 101, 116, 101, 31, 102, 116, 102, 242, 104, 22, 104, 99, 107, 5, 110, 114, 114, 31, 117, 219, 118, 190, 124, 86, 128, 240, 88, 253, 136, 127, 137, 160, 138, 147, 138, 203, 138, 29, 144, 146, 145, 82, 151, 89, 151, 137, 101, 14, 122, 6, 129, 187, 150, 45, 94, 220, 96, 26, 98, 165, 101, 20, 102, 144, 103, 243, 119, 77, 122, 77, 124, 62, 126, 10, 129, 172, 140, 100, 141, 225, 141, 95, 142, 169, 120, 7, 82, 217, 98, 165, 99, 66, 100, 152, 98, 45, 138, 131, 122, 192, 123, 172, 138, 234, 150, 118, 125, 12, 130, 73, 135, 217, 78, 72, 81, 67, 83, 96, 83, 163, 91, 2, 92, 22, 92, 221, 93, 38, 98, 71, 98, 176, 100, 19, 104, 52, 104, 201, 108, 69, 109, 23, 109, 211, 103, 92, 111, 78, 113, 125, 113, 203, 101, 127, 122, 173, 123, 218, 125, 74, 126, 168, 127, 122, 129, 27, 130, 57, 130, 166, 133, 110, 138, 206, 140, 245, 141, 120, 144, 119, 144, 173, 146, 145, 146, 131, 149, 174, 155, 77, 82, 132, 85, 56, 111, 54, 113, 104, 81, 133, 121, 85, 126, 179, 129, 206, 124, 76, 86, 81, 88, 168, 92, 170, 99, 254, 102, 253, 102, 90, 105, 217, 114, 143, 117, 142, 117, 14, 121, 86, 121, 223, 121, 151, 124, 32, 125, 68, 125, 7, 134, 52, 138, 59, 150, 97, 144, 32, 159, 231, 80, 117, 82, 204, 83, 226, 83, 9, 80, 170, 85, 238, 88, 79, 89, 61, 114, 139, 91, 100, 92, 29, 83, 227, 96, 243, 96, 92, 99, 131, 99, 63, 99, 187, 99, 205, 100, 233, 101, 249, 102, 227, 93, 205, 105, 253, 105, 21, 111, 229, 113, 137, 78, 233, 117, 248, 118, 147, 122, 223, 124, 207, 125, 156, 125, 97, 128, 73, 131, 88, 131, 108, 132, 188, 132, 251, 133, 197, 136, 112, 141, 1, 144, 109, 144, 151, 147, 28, 151, 18, 154, 207, 80, 151, 88, 142, 97, 211, 129, 53, 133, 8, 141, 32, 144, 195, 79, 116, 80, 71, 82, 115, 83, 111, 96, 73, 99, 95, 103, 44, 110, 179, 141, 31, 144, 215, 79, 94, 92, 202, 140, 207, 101, 154, 125, 82, 83, 150, 136, 118, 81, 195, 99, 88, 91, 107, 91, 10, 92, 13, 100, 81, 103, 92, 144, 214, 78, 26, 89, 42, 89, 112, 108, 81, 138, 62, 85, 21, 88, 165, 89, 240, 96, 83, 98, 193, 103, 53, 130, 85, 105, 64, 150, 196, 153, 40, 154, 83, 79, 6, 88, 254, 91, 16, 128, 177, 92, 47, 94, 133, 95, 32, 96, 75, 97, 52, 98, 255, 102, 240, 108, 222, 110, 206, 128, 127, 129, 212, 130, 139, 136, 184, 140, 0, 144, 46, 144, 138, 150, 219, 158, 219, 155, 227, 78, 240, 83, 39, 89, 44, 123, 141, 145, 76, 152, 249, 157, 221, 110, 39, 112, 83, 83, 68, 85, 133, 91, 88, 98, 158, 98, 211, 98, 162, 108, 239, 111, 34, 116, 23, 138, 56, 148, 193, 111, 254, 138, 56, 131, 231, 81, 248, 134, 234, 83, 233, 83, 70, 79, 84, 144, 176, 143, 106, 89, 49, 129, 253, 93, 234, 122, 191, 143, 218, 104, 55, 140, 248, 114, 72, 156, 61, 106, 176, 138, 57, 78, 88, 83, 6, 86, 102, 87, 197, 98, 162, 99, 230, 101, 78, 107, 225, 109, 91, 110, 173, 112, 237, 119, 239, 122, 170, 123, 187, 125, 61, 128, 198, 128, 203, 134, 149, 138, 91, 147, 227, 86, 199, 88, 62, 95, 173, 101, 150, 102, 128, 106, 181, 107, 55, 117, 199, 138, 36, 80, 229, 119, 48, 87, 27, 95, 101, 96, 122, 102, 96, 108, 244, 117, 26, 122, 110, 127, 244, 129, 24, 135, 69, 144, 179, 153, 201, 123, 92, 117, 249, 122, 81, 123, 196, 132, 16, 144, 233, 121, 146, 122, 54, 131, 225, 90, 64, 119, 45, 78, 242, 78, 153, 91, 224, 95, 189, 98, 60, 102, 241, 103, 232, 108, 107, 134, 119, 136, 59, 138, 78, 145, 243, 146, 208, 153, 23, 106, 38, 112, 42, 115, 231, 130, 87, 132, 175, 140, 1, 78, 70, 81, 203, 81, 139, 85, 245, 91, 22, 94, 51, 94, 129, 94, 20, 95, 53, 95, 107, 95, 180, 95, 242, 97, 17, 99, 162, 102, 29, 103, 110, 111, 82, 114, 58, 117, 58, 119, 116, 128, 57, 129, 120, 129, 118, 135, 191, 138, 220, 138, 133, 141, 243, 141, 154, 146, 119, 149, 2, 152, 229, 156, 197, 82, 87, 99, 244, 118, 21, 103, 136, 108, 205, 115, 195, 140, 174, 147, 115, 150, 37, 109, 156, 88, 14, 105, 204, 105, 253, 143, 154, 147, 219, 117, 26, 144, 90, 88, 2, 104, 180, 99, 251, 105, 67, 79, 44, 111, 216, 103, 187, 143, 38, 133, 180, 125, 84, 147, 63, 105, 112, 111, 106, 87, 247, 88, 44, 91, 44, 125, 42, 114, 10, 84, 227, 145, 180, 157, 173, 78, 78, 79, 92, 80, 117, 80, 67, 82, 158, 140, 72, 84, 36, 88, 154, 91, 29, 94, 149, 94, 173, 94, 247, 94, 31, 95, 140, 96, 181, 98, 58, 99, 208, 99, 175, 104, 64, 108, 135, 120, 142, 121, 11, 122, 224, 125, 71, 130, 2, 138, 230, 138, 68, 142, 19, 144, 184, 144, 45, 145, 216, 145, 14, 159, 229, 108, 88, 100, 226, 100, 117, 101, 244, 110, 132, 118, 27, 123, 105, 144, 209, 147, 186, 110, 242, 84, 185, 95, 164, 100, 77, 143, 237, 143, 68, 146, 120, 81, 107, 88, 41, 89, 85, 92, 151, 94, 251, 109, 143, 126, 28, 117, 188, 140, 226, 142, 91, 152, 185, 112, 29, 79, 191, 107, 177, 111, 48, 117, 251, 150, 78, 81, 16, 84, 53, 88, 87, 88, 172, 89, 96, 92, 146, 95, 151, 101, 92, 103, 33, 110, 123, 118, 223, 131, 237, 140, 20, 144, 253, 144, 77, 147, 37, 120, 58, 120, 170, 82, 166, 94, 31, 87, 116, 89, 18, 96, 18, 80, 90, 81, 172, 81, 205, 81, 0, 82, 16, 85, 84, 88, 88, 88, 87, 89, 149, 91, 246, 92, 139, 93, 188, 96, 149, 98, 45, 100, 113, 103, 67, 104, 188, 104, 223, 104, 215, 118, 216, 109, 111, 110, 155, 109, 111, 112, 200, 113, 83, 95, 216, 117, 119, 121, 73, 123, 84, 123, 82, 123, 214, 124, 113, 125, 48, 82, 99, 132, 105, 133, 228, 133, 14, 138, 4, 139, 70, 140, 15, 142, 3, 144, 15, 144, 25, 148, 118, 150, 45, 152, 48, 154, 216, 149, 205, 80, 213, 82, 12, 84, 2, 88, 14, 92, 167, 97, 158, 100, 30, 109, 179, 119, 229, 122, 244, 128, 4, 132, 83, 144, 133, 146, 224, 92, 7, 157, 63, 83, 151, 95, 179, 95, 156, 109, 121, 114, 99, 119, 191, 121, 228, 123, 210, 107, 236, 114, 173, 138, 3, 104, 97, 106, 248, 81, 129, 122, 52, 105, 74, 92, 246, 156, 235, 130, 197, 91, 73, 145, 30, 112, 120, 86, 111, 92, 199, 96, 102, 101, 140, 108, 90, 140, 65, 144, 19, 152, 81, 84, 199, 102, 13, 146, 72, 89, 163, 144, 133, 81, 77, 78, 234, 81, 153, 133, 14, 139, 88, 112, 122, 99, 75, 147, 98, 105, 180, 153, 4, 126, 119, 117, 87, 83, 96, 105, 223, 142, 227, 150, 93, 108, 140, 78, 60, 92, 16, 95, 233, 143, 2, 83, 209, 140, 137, 128, 121, 134, 255, 94, 229, 101, 115, 78, 101, 81, 130, 89, 63, 92, 238, 151, 251, 78, 138, 89, 205, 95, 141, 138, 225, 111, 176, 121, 98, 121, 231, 91, 113, 132, 43, 115, 177, 113, 116, 94, 245, 95, 123, 99, 154, 100, 195, 113, 152, 124, 67, 78, 252, 94, 75, 78, 220, 87, 162, 86, 169, 96, 195, 111, 13, 125, 253, 128, 51, 129, 191, 129, 178, 143, 151, 137, 164, 134, 244, 93, 138, 98, 173, 100, 135, 137, 119, 103, 226, 108, 62, 109, 54, 116, 52, 120, 70, 90, 117, 127, 173, 130, 172, 153, 243, 79, 195, 94, 221, 98, 146, 99, 87, 101, 111, 103, 195, 118, 76, 114, 204, 128, 186, 128, 41, 143, 77, 145, 13, 80, 249, 87, 146, 90, 133, 104, 115, 105, 100, 113, 253, 114, 183, 140, 242, 88, 224, 140, 106, 150, 25, 144, 127, 135, 228, 121, 231, 119, 41, 132, 47, 79, 101, 82, 90, 83, 205, 98, 207, 103, 202, 108, 125, 118, 148, 123, 149, 124, 54, 130, 132, 133, 235, 143, 221, 102, 32, 111, 6, 114, 27, 126, 171, 131, 193, 153, 166, 158, 253, 81, 177, 123, 114, 120, 184, 123, 135, 128, 72, 123, 232, 106, 97, 94, 140, 128, 81, 117, 96, 117, 107, 81, 98, 146, 140, 110, 122, 118, 151, 145, 234, 154, 16, 79, 112, 127, 156, 98, 79, 123, 165, 149, 233, 156, 122, 86, 89, 88, 228, 134, 188, 150, 52, 79, 36, 82, 74, 83, 205, 83, 219, 83, 6, 94, 44, 100, 145, 101, 127, 103, 62, 108, 78, 108, 72, 114, 175, 114, 237, 115, 84, 117, 65, 126, 44, 130, 233, 133, 169, 140, 196, 123, 198, 145, 105, 113, 18, 152, 239, 152, 61, 99, 105, 102, 106, 117, 228, 118, 208, 120, 67, 133, 238, 134, 42, 83, 81, 83, 38, 84, 131, 89, 135, 94, 124, 95, 178, 96, 73, 98, 121, 98, 171, 98, 144, 101, 212, 107, 204, 108, 178, 117, 174, 118, 145, 120, 216, 121, 203, 125, 119, 127, 165, 128, 171, 136, 185, 138, 187, 140, 127, 144, 94, 151, 219, 152, 11, 106, 56, 124, 153, 80, 62, 92, 174, 95, 135, 103, 216, 107, 53, 116, 9, 119, 142, 127, 59, 159, 202, 103, 23, 122, 57, 83, 139, 117, 237, 154, 102, 95, 157, 129, 241, 131, 152, 128, 60, 95, 197, 95, 98, 117, 70, 123, 60, 144, 103, 104, 235, 89, 155, 90, 16, 125, 126, 118, 44, 139, 245, 79, 106, 95, 25, 106, 55, 108, 2, 111, 226, 116, 104, 121, 104, 136, 85, 138, 121, 140, 223, 94, 207, 99, 197, 117, 210, 121, 215, 130, 40, 147, 242, 146, 156, 132, 237, 134, 45, 156, 193, 84, 108, 95, 140, 101, 92, 109, 21, 112, 167, 140, 211, 140, 59, 152, 79, 101, 246, 116, 13, 78, 216, 78, 224, 87, 43, 89, 102, 90, 204, 91, 168, 81, 3, 94, 156, 94, 22, 96, 118, 98, 119, 101, 167, 101, 110, 102, 110, 109, 54, 114, 38, 123, 80, 129, 154, 129, 153, 130, 92, 139, 160, 140, 230, 140, 116, 141, 28, 150, 68, 150, 174, 79, 171, 100, 102, 107, 30, 130, 97, 132, 106, 133, 232, 144, 1, 92, 83, 105, 168, 152, 122, 132, 87, 133, 15, 79, 111, 82, 169, 95, 69, 94, 13, 103, 143, 121, 121, 129, 7, 137, 134, 137, 245, 109, 23, 95, 85, 98, 184, 108, 207, 78, 105, 114, 146, 155, 6, 82, 59, 84, 116, 86, 179, 88, 164, 97, 110, 98, 26, 113, 110, 89, 137, 124, 222, 124, 27, 125, 240, 150, 135, 101, 94, 128, 25, 78, 117, 79, 117, 81, 64, 88, 99, 94, 115, 94, 10, 95, 196, 103, 38, 78, 61, 133, 137, 149, 91, 150, 115, 124, 1, 152, 251, 80, 193, 88, 86, 118, 167, 120, 37, 82, 165, 119, 17, 133, 134, 123, 79, 80, 9, 89, 71, 114, 199, 123, 232, 125, 186, 143, 212, 143, 77, 144, 191, 79, 201, 82, 41, 90, 1, 95, 173, 151, 221, 79, 23, 130, 234, 146, 3, 87, 85, 99, 105, 107, 43, 117, 220, 136, 20, 143, 66, 122, 223, 82, 147, 88, 85, 97, 10, 98, 174, 102, 205, 107, 63, 124, 233, 131, 35, 80, 248, 79, 5, 83, 70, 84, 49, 88, 73, 89, 157, 91, 240, 92, 239, 92, 41, 93, 150, 94, 177, 98, 103, 99, 62, 101, 185, 101, 11, 103, 213, 108, 225, 108, 249, 112, 50, 120, 43, 126, 222, 128, 179, 130, 12, 132, 236, 132, 2, 135, 18, 137, 42, 138, 74, 140, 166, 144, 210, 146, 253, 152, 243, 156, 108, 157, 79, 78, 161, 78, 141, 80, 86, 82, 74, 87, 168, 89, 61, 94, 216, 95, 217, 95, 63, 98, 180, 102, 27, 103, 208, 103, 210, 104, 146, 81, 33, 125, 170, 128, 168, 129, 0, 139, 140, 140, 191, 140, 126, 146, 50, 150, 32, 84, 44, 152, 23, 83, 213, 80, 92, 83, 168, 88, 178, 100, 52, 103, 103, 114, 102, 119, 70, 122, 230, 145, 195, 82, 161, 108, 134, 107, 0, 88, 76, 94, 84, 89, 44, 103, 251, 127, 225, 81, 198, 118, 105, 100, 232, 120, 84, 155, 187, 158, 203, 87, 185, 89, 39, 102, 154, 103, 206, 107, 233, 84, 217, 105, 85, 94, 156, 129, 149, 103, 170, 155, 254, 103, 82, 156, 93, 104, 166, 78, 227, 79, 200, 83, 185, 98, 43, 103, 171, 108, 196, 143, 173, 79, 109, 126, 191, 158, 7, 78, 98, 97, 128, 110, 43, 111, 19, 133, 115, 84, 42, 103, 69, 155, 243, 93, 149, 123, 172, 92, 198, 91, 28, 135, 74, 110, 209, 132, 20, 122, 8, 129, 153, 89, 141, 124, 17, 108, 32, 119, 217, 82, 34, 89, 33, 113, 95, 114, 219, 119, 39, 151, 97, 157, 11, 105, 127, 90, 24, 90, 165, 81, 13, 84, 125, 84, 14, 102, 223, 118, 247, 143, 152, 146, 244, 156, 234, 89, 93, 114, 197, 110, 77, 81, 201, 104, 191, 125, 236, 125, 98, 151, 186, 158, 120, 100, 33, 106, 2, 131, 132, 89, 95, 91, 219, 107, 27, 115, 242, 118, 178, 125, 23, 128, 153, 132, 50, 81, 40, 103, 217, 158, 238, 118, 98, 103, 255, 82, 5, 153, 36, 92, 59, 98, 126, 124, 176, 140, 79, 85, 182, 96, 11, 125, 128, 149, 1, 83, 95, 78, 182, 81, 28, 89, 58, 114, 54, 128, 206, 145, 37, 95, 226, 119, 132, 83, 121, 95, 4, 125, 172, 133, 51, 138, 141, 142, 86, 151, 243, 103, 174, 133, 83, 148, 9, 97, 8, 97, 185, 108, 82, 118, 237, 138, 56, 143, 47, 85, 81, 79, 42, 81, 199, 82, 203, 83, 165, 91, 125, 94, 160, 96, 130, 97, 214, 99, 9, 103, 218, 103, 103, 110, 140, 109, 54, 115, 55, 115, 49, 117, 80, 121, 213, 136, 152, 138, 74, 144, 145, 144, 245, 144, 196, 150, 141, 135, 21, 89, 136, 78, 89, 79, 14, 78, 137, 138, 63, 143, 16, 152, 173, 80, 124, 94, 150, 89, 185, 91, 184, 94, 218, 99, 250, 99, 193, 100, 220, 102, 74, 105, 216, 105, 11, 109, 182, 110, 148, 113, 40, 117, 175, 122, 138, 127, 0, 128, 73, 132, 201, 132, 129, 137, 33, 139, 10, 142, 101, 144, 125, 150, 10, 153, 126, 97, 145, 98, 50, 107, 131, 108, 116, 109, 204, 127, 252, 127, 192, 109, 133, 127, 186, 135, 248, 136, 101, 103, 177, 131, 60, 152, 247, 150, 27, 109, 97, 125, 61, 132, 106, 145, 113, 78, 117, 83, 80, 93, 4, 107, 235, 111, 205, 133, 45, 134, 167, 137, 41, 82, 15, 84, 101, 92, 78, 103, 168, 104, 6, 116, 131, 116, 226, 117, 207, 136, 225, 136, 204, 145, 226, 150, 120, 150, 139, 95, 135, 115, 203, 122, 78, 132, 160, 99, 101, 117, 137, 82, 65, 109, 156, 110, 9, 116, 89, 117, 107, 120, 146, 124, 134, 150, 220, 122, 141, 159, 182, 79, 110, 97, 197, 101, 92, 134, 134, 78, 174, 78, 218, 80, 33, 78, 204, 81, 238, 91, 153, 101, 129, 104, 188, 109, 31, 115, 66, 118, 173, 119, 28, 122, 231, 124, 111, 130, 210, 138, 124, 144, 207, 145, 117, 150, 24, 152, 155, 82, 209, 125, 43, 80, 152, 83, 151, 103, 203, 109, 208, 113, 51, 116, 232, 129, 42, 143, 163, 150, 87, 156, 159, 158, 96, 116, 65, 88, 153, 109, 47, 125, 94, 152, 228, 78, 54, 79, 139, 79, 183, 81, 177, 82, 186, 93, 28, 96, 178, 115, 60, 121, 211, 130, 52, 146, 183, 150, 246, 150, 10, 151, 151, 158, 98, 159, 166, 102, 116, 107, 23, 82, 163, 82, 200, 112, 194, 136, 201, 94, 75, 96, 144, 97, 35, 111, 73, 113, 62, 124, 244, 125, 111, 128, 238, 132, 35, 144, 44, 147, 66, 84, 111, 155, 211, 106, 137, 112, 194, 140, 239, 141, 50, 151, 180, 82, 65, 90, 202, 94, 4, 95, 23, 103, 124, 105, 148, 105, 106, 109, 15, 111, 98, 114, 252, 114, 237, 123, 1, 128, 126, 128, 75, 135, 206, 144, 109, 81, 147, 158, 132, 121, 139, 128, 50, 147, 214, 138, 45, 80, 140, 84, 113, 138, 106, 107, 196, 140, 7, 129, 209, 96, 160, 103, 242, 157, 153, 78, 152, 78, 16, 156, 107, 138, 193, 133, 104, 133, 0, 105, 126, 110, 151, 120, 85, 129, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12, 95, 16, 78, 21, 78, 42, 78, 49, 78, 54, 78, 60, 78, 63, 78, 66, 78, 86, 78, 88, 78, 130, 78, 133, 78, 107, 140, 138, 78, 18, 130, 13, 95, 142, 78, 158, 78, 159, 78, 160, 78, 162, 78, 176, 78, 179, 78, 182, 78, 206, 78, 205, 78, 196, 78, 198, 78, 194, 78, 215, 78, 222, 78, 237, 78, 223, 78, 247, 78, 9, 79, 90, 79, 48, 79, 91, 79, 93, 79, 87, 79, 71, 79, 118, 79, 136, 79, 143, 79, 152, 79, 123, 79, 105, 79, 112, 79, 145, 79, 111, 79, 134, 79, 150, 79, 24, 81, 212, 79, 223, 79, 206, 79, 216, 79, 219, 79, 209, 79, 218, 79, 208, 79, 228, 79, 229, 79, 26, 80, 40, 80, 20, 80, 42, 80, 37, 80, 5, 80, 28, 79, 246, 79, 33, 80, 41, 80, 44, 80, 254, 79, 239, 79, 17, 80, 6, 80, 67, 80, 71, 80, 3, 103, 85, 80, 80, 80, 72, 80, 90, 80, 86, 80, 108, 80, 120, 80, 128, 80, 154, 80, 133, 80, 180, 80, 178, 80, 201, 80, 202, 80, 179, 80, 194, 80, 214, 80, 222, 80, 229, 80, 237, 80, 227, 80, 238, 80, 249, 80, 245, 80, 9, 81, 1, 81, 2, 81, 22, 81, 21, 81, 20, 81, 26, 81, 33, 81, 58, 81, 55, 81, 60, 81, 59, 81, 63, 81, 64, 81, 82, 81, 76, 81, 84, 81, 98, 81, 248, 122, 105, 81, 106, 81, 110, 81, 128, 81, 130, 81, 216, 86, 140, 81, 137, 81, 143, 81, 145, 81, 147, 81, 149, 81, 150, 81, 164, 81, 166, 81, 162, 81, 169, 81, 170, 81, 171, 81, 179, 81, 177, 81, 178, 81, 176, 81, 181, 81, 189, 81, 197, 81, 201, 81, 219, 81, 224, 81, 85, 134, 233, 81, 237, 81, 240, 81, 245, 81, 254, 81, 4, 82, 11, 82, 20, 82, 14, 82, 39, 82, 42, 82, 46, 82, 51, 82, 57, 82, 79, 82, 68, 82, 75, 82, 76, 82, 94, 82, 84, 82, 106, 82, 116, 82, 105, 82, 115, 82, 127, 82, 125, 82, 141, 82, 148, 82, 146, 82, 113, 82, 136, 82, 145, 82, 168, 143, 167, 143, 172, 82, 173, 82, 188, 82, 181, 82, 193, 82, 205, 82, 215, 82, 222, 82, 227, 82, 230, 82, 237, 152, 224, 82, 243, 82, 245, 82, 248, 82, 249, 82, 6, 83, 8, 83, 56, 117, 13, 83, 16, 83, 15, 83, 21, 83, 26, 83, 35, 83, 47, 83, 49, 83, 51, 83, 56, 83, 64, 83, 70, 83, 69, 83, 23, 78, 73, 83, 77, 83, 214, 81, 94, 83, 105, 83, 110, 83, 24, 89, 123, 83, 119, 83, 130, 83, 150, 83, 160, 83, 166, 83, 165, 83, 174, 83, 176, 83, 182, 83, 195, 83, 18, 124, 217, 150, 223, 83, 252, 102, 238, 113, 238, 83, 232, 83, 237, 83, 250, 83, 1, 84, 61, 84, 64, 84, 44, 84, 45, 84, 60, 84, 46, 84, 54, 84, 41, 84, 29, 84, 78, 84, 143, 84, 117, 84, 142, 84, 95, 84, 113, 84, 119, 84, 112, 84, 146, 84, 123, 84, 128, 84, 118, 84, 132, 84, 144, 84, 134, 84, 199, 84, 162, 84, 184, 84, 165, 84, 172, 84, 196, 84, 200, 84, 168, 84, 171, 84, 194, 84, 164, 84, 190, 84, 188, 84, 216, 84, 229, 84, 230, 84, 15, 85, 20, 85, 253, 84, 238, 84, 237, 84, 250, 84, 226, 84, 57, 85, 64, 85, 99, 85, 76, 85, 46, 85, 92, 85, 69, 85, 86, 85, 87, 85, 56, 85, 51, 85, 93, 85, 153, 85, 128, 85, 175, 84, 138, 85, 159, 85, 123, 85, 126, 85, 152, 85, 158, 85, 174, 85, 124, 85, 131, 85, 169, 85, 135, 85, 168, 85, 218, 85, 197, 85, 223, 85, 196, 85, 220, 85, 228, 85, 212, 85, 20, 86, 247, 85, 22, 86, 254, 85, 253, 85, 27, 86, 249, 85, 78, 86, 80, 86, 223, 113, 52, 86, 54, 86, 50, 86, 56, 86, 107, 86, 100, 86, 47, 86, 108, 86, 106, 86, 134, 86, 128, 86, 138, 86, 160, 86, 148, 86, 143, 86, 165, 86, 174, 86, 182, 86, 180, 86, 194, 86, 188, 86, 193, 86, 195, 86, 192, 86, 200, 86, 206, 86, 209, 86, 211, 86, 215, 86, 238, 86, 249, 86, 0, 87, 255, 86, 4, 87, 9, 87, 8, 87, 11, 87, 13, 87, 19, 87, 24, 87, 22, 87, 199, 85, 28, 87, 38, 87, 55, 87, 56, 87, 78, 87, 59, 87, 64, 87, 79, 87, 105, 87, 192, 87, 136, 87, 97, 87, 127, 87, 137, 87, 147, 87, 160, 87, 179, 87, 164, 87, 170, 87, 176, 87, 195, 87, 198, 87, 212, 87, 210, 87, 211, 87, 10, 88, 214, 87, 227, 87, 11, 88, 25, 88, 29, 88, 114, 88, 33, 88, 98, 88, 75, 88, 112, 88, 192, 107, 82, 88, 61, 88, 121, 88, 133, 88, 185, 88, 159, 88, 171, 88, 186, 88, 222, 88, 187, 88, 184, 88, 174, 88, 197, 88, 211, 88, 209, 88, 215, 88, 217, 88, 216, 88, 229, 88, 220, 88, 228, 88, 223, 88, 239, 88, 250, 88, 249, 88, 251, 88, 252, 88, 253, 88, 2, 89, 10, 89, 16, 89, 27, 89, 166, 104, 37, 89, 44, 89, 45, 89, 50, 89, 56, 89, 62, 89, 210, 122, 85, 89, 80, 89, 78, 89, 90, 89, 88, 89, 98, 89, 96, 89, 103, 89, 108, 89, 105, 89, 120, 89, 129, 89, 157, 89, 94, 79, 171, 79, 163, 89, 178, 89, 198, 89, 232, 89, 220, 89, 141, 89, 217, 89, 218, 89, 37, 90, 31, 90, 17, 90, 28, 90, 9, 90, 26, 90, 64, 90, 108, 90, 73, 90, 53, 90, 54, 90, 98, 90, 106, 90, 154, 90, 188, 90, 190, 90, 203, 90, 194, 90, 189, 90, 227, 90, 215, 90, 230, 90, 233, 90, 214, 90, 250, 90, 251, 90, 12, 91, 11, 91, 22, 91, 50, 91, 208, 90, 42, 91, 54, 91, 62, 91, 67, 91, 69, 91, 64, 91, 81, 91, 85, 91, 90, 91, 91, 91, 101, 91, 105, 91, 112, 91, 115, 91, 117, 91, 120, 91, 136, 101, 122, 91, 128, 91, 131, 91, 166, 91, 184, 91, 195, 91, 199, 91, 201, 91, 212, 91, 208, 91, 228, 91, 230, 91, 226, 91, 222, 91, 229, 91, 235, 91, 240, 91, 246, 91, 243, 91, 5, 92, 7, 92, 8, 92, 13, 92, 19, 92, 32, 92, 34, 92, 40, 92, 56, 92, 57, 92, 65, 92, 70, 92, 78, 92, 83, 92, 80, 92, 79, 92, 113, 91, 108, 92, 110, 92, 98, 78, 118, 92, 121, 92, 140, 92, 145, 92, 148, 92, 155, 89, 171, 92, 187, 92, 182, 92, 188, 92, 183, 92, 197, 92, 190, 92, 199, 92, 217, 92, 233, 92, 253, 92, 250, 92, 237, 92, 140, 93, 234, 92, 11, 93, 21, 93, 23, 93, 92, 93, 31, 93, 27, 93, 17, 93, 20, 93, 34, 93, 26, 93, 25, 93, 24, 93, 76, 93, 82, 93, 78, 93, 75, 93, 108, 93, 115, 93, 118, 93, 135, 93, 132, 93, 130, 93, 162, 93, 157, 93, 172, 93, 174, 93, 189, 93, 144, 93, 183, 93, 188, 93, 201, 93, 205, 93, 211, 93, 210, 93, 214, 93, 219, 93, 235, 93, 242, 93, 245, 93, 11, 94, 26, 94, 25, 94, 17, 94, 27, 94, 54, 94, 55, 94, 68, 94, 67, 94, 64, 94, 78, 94, 87, 94, 84, 94, 95, 94, 98, 94, 100, 94, 71, 94, 117, 94, 118, 94, 122, 94, 188, 158, 127, 94, 160, 94, 193, 94, 194, 94, 200, 94, 208, 94, 207, 94, 214, 94, 227, 94, 221, 94, 218, 94, 219, 94, 226, 94, 225, 94, 232, 94, 233, 94, 236, 94, 241, 94, 243, 94, 240, 94, 244, 94, 248, 94, 254, 94, 3, 95, 9, 95, 93, 95, 92, 95, 11, 95, 17, 95, 22, 95, 41, 95, 45, 95, 56, 95, 65, 95, 72, 95, 76, 95, 78, 95, 47, 95, 81, 95, 86, 95, 87, 95, 89, 95, 97, 95, 109, 95, 115, 95, 119, 95, 131, 95, 130, 95, 127, 95, 138, 95, 136, 95, 145, 95, 135, 95, 158, 95, 153, 95, 152, 95, 160, 95, 168, 95, 173, 95, 188, 95, 214, 95, 251, 95, 228, 95, 248, 95, 241, 95, 221, 95, 179, 96, 255, 95, 33, 96, 96, 96, 25, 96, 16, 96, 41, 96, 14, 96, 49, 96, 27, 96, 21, 96, 43, 96, 38, 96, 15, 96, 58, 96, 90, 96, 65, 96, 106, 96, 119, 96, 95, 96, 74, 96, 70, 96, 77, 96, 99, 96, 67, 96, 100, 96, 66, 96, 108, 96, 107, 96, 89, 96, 129, 96, 141, 96, 231, 96, 131, 96, 154, 96, 132, 96, 155, 96, 150, 96, 151, 96, 146, 96, 167, 96, 139, 96, 225, 96, 184, 96, 224, 96, 211, 96, 180, 96, 240, 95, 189, 96, 198, 96, 181, 96, 216, 96, 77, 97, 21, 97, 6, 97, 246, 96, 247, 96, 0, 97, 244, 96, 250, 96, 3, 97, 33, 97, 251, 96, 241, 96, 13, 97, 14, 97, 71, 97, 62, 97, 40, 97, 39, 97, 74, 97, 63, 97, 60, 97, 44, 97, 52, 97, 61, 97, 66, 97, 68, 97, 115, 97, 119, 97, 88, 97, 89, 97, 90, 97, 107, 97, 116, 97, 111, 97, 101, 97, 113, 97, 95, 97, 93, 97, 83, 97, 117, 97, 153, 97, 150, 97, 135, 97, 172, 97, 148, 97, 154, 97, 138, 97, 145, 97, 171, 97, 174, 97, 204, 97, 202, 97, 201, 97, 247, 97, 200, 97, 195, 97, 198, 97, 186, 97, 203, 97, 121, 127, 205, 97, 230, 97, 227, 97, 246, 97, 250, 97, 244, 97, 255, 97, 253, 97, 252, 97, 254, 97, 0, 98, 8, 98, 9, 98, 13, 98, 12, 98, 20, 98, 27, 98, 30, 98, 33, 98, 42, 98, 46, 98, 48, 98, 50, 98, 51, 98, 65, 98, 78, 98, 94, 98, 99, 98, 91, 98, 96, 98, 104, 98, 124, 98, 130, 98, 137, 98, 126, 98, 146, 98, 147, 98, 150, 98, 212, 98, 131, 98, 148, 98, 215, 98, 209, 98, 187, 98, 207, 98, 255, 98, 198, 98, 212, 100, 200, 98, 220, 98, 204, 98, 202, 98, 194, 98, 199, 98, 155, 98, 201, 98, 12, 99, 238, 98, 241, 98, 39, 99, 2, 99, 8, 99, 239, 98, 245, 98, 80, 99, 62, 99, 77, 99, 28, 100, 79, 99, 150, 99, 142, 99, 128, 99, 171, 99, 118, 99, 163, 99, 143, 99, 137, 99, 159, 99, 181, 99, 107, 99, 105, 99, 190, 99, 233, 99, 192, 99, 198, 99, 227, 99, 201, 99, 210, 99, 246, 99, 196, 99, 22, 100, 52, 100, 6, 100, 19, 100, 38, 100, 54, 100, 29, 101, 23, 100, 40, 100, 15, 100, 103, 100, 111, 100, 118, 100, 78, 100, 42, 101, 149, 100, 147, 100, 165, 100, 169, 100, 136, 100, 188, 100, 218, 100, 210, 100, 197, 100, 199, 100, 187, 100, 216, 100, 194, 100, 241, 100, 231, 100, 9, 130, 224, 100, 225, 100, 172, 98, 227, 100, 239, 100, 44, 101, 246, 100, 244, 100, 242, 100, 250, 100, 0, 101, 253, 100, 24, 101, 28, 101, 5, 101, 36, 101, 35, 101, 43, 101, 52, 101, 53, 101, 55, 101, 54, 101, 56, 101, 75, 117, 72, 101, 86, 101, 85, 101, 77, 101, 88, 101, 94, 101, 93, 101, 114, 101, 120, 101, 130, 101, 131, 101, 138, 139, 155, 101, 159, 101, 171, 101, 183, 101, 195, 101, 198, 101, 193, 101, 196, 101, 204, 101, 210, 101, 219, 101, 217, 101, 224, 101, 225, 101, 241, 101, 114, 103, 10, 102, 3, 102, 251, 101, 115, 103, 53, 102, 54, 102, 52, 102, 28, 102, 79, 102, 68, 102, 73, 102, 65, 102, 94, 102, 93, 102, 100, 102, 103, 102, 104, 102, 95, 102, 98, 102, 112, 102, 131, 102, 136, 102, 142, 102, 137, 102, 132, 102, 152, 102, 157, 102, 193, 102, 185, 102, 201, 102, 190, 102, 188, 102, 196, 102, 184, 102, 214, 102, 218, 102, 224, 102, 63, 102, 230, 102, 233, 102, 240, 102, 245, 102, 247, 102, 15, 103, 22, 103, 30, 103, 38, 103, 39, 103, 56, 151, 46, 103, 63, 103, 54, 103, 65, 103, 56, 103, 55, 103, 70, 103, 94, 103, 96, 103, 89, 103, 99, 103, 100, 103, 137, 103, 112, 103, 169, 103, 124, 103, 106, 103, 140, 103, 139, 103, 166, 103, 161, 103, 133, 103, 183, 103, 239, 103, 180, 103, 236, 103, 179, 103, 233, 103, 184, 103, 228, 103, 222, 103, 221, 103, 226, 103, 238, 103, 185, 103, 206, 103, 198, 103, 231, 103, 156, 106, 30, 104, 70, 104, 41, 104, 64, 104, 77, 104, 50, 104, 78, 104, 179, 104, 43, 104, 89, 104, 99, 104, 119, 104, 127, 104, 159, 104, 143, 104, 173, 104, 148, 104, 157, 104, 155, 104, 131, 104, 174, 106, 185, 104, 116, 104, 181, 104, 160, 104, 186, 104, 15, 105, 141, 104, 126, 104, 1, 105, 202, 104, 8, 105, 216, 104, 34, 105, 38, 105, 225, 104, 12, 105, 205, 104, 212, 104, 231, 104, 213, 104, 54, 105, 18, 105, 4, 105, 215, 104, 227, 104, 37, 105, 249, 104, 224, 104, 239, 104, 40, 105, 42, 105, 26, 105, 35, 105, 33, 105, 198, 104, 121, 105, 119, 105, 92, 105, 120, 105, 107, 105, 84, 105, 126, 105, 110, 105, 57, 105, 116, 105, 61, 105, 89, 105, 48, 105, 97, 105, 94, 105, 93, 105, 129, 105, 106, 105, 178, 105, 174, 105, 208, 105, 191, 105, 193, 105, 211, 105, 190, 105, 206, 105, 232, 91, 202, 105, 221, 105, 187, 105, 195, 105, 167, 105, 46, 106, 145, 105, 160, 105, 156, 105, 149, 105, 180, 105, 222, 105, 232, 105, 2, 106, 27, 106, 255, 105, 10, 107, 249, 105, 242, 105, 231, 105, 5, 106, 177, 105, 30, 106, 237, 105, 20, 106, 235, 105, 10, 106, 18, 106, 193, 106, 35, 106, 19, 106, 68, 106, 12, 106, 114, 106, 54, 106, 120, 106, 71, 106, 98, 106, 89, 106, 102, 106, 72, 106, 56, 106, 34, 106, 144, 106, 141, 106, 160, 106, 132, 106, 162, 106, 163, 106, 151, 106, 23, 134, 187, 106, 195, 106, 194, 106, 184, 106, 179, 106, 172, 106, 222, 106, 209, 106, 223, 106, 170, 106, 218, 106, 234, 106, 251, 106, 5, 107, 22, 134, 250, 106, 18, 107, 22, 107, 49, 155, 31, 107, 56, 107, 55, 107, 220, 118, 57, 107, 238, 152, 71, 107, 67, 107, 73, 107, 80, 107, 89, 107, 84, 107, 91, 107, 95, 107, 97, 107, 120, 107, 121, 107, 127, 107, 128, 107, 132, 107, 131, 107, 141, 107, 152, 107, 149, 107, 158, 107, 164, 107, 170, 107, 171, 107, 175, 107, 178, 107, 177, 107, 179, 107, 183, 107, 188, 107, 198, 107, 203, 107, 211, 107, 223, 107, 236, 107, 235, 107, 243, 107, 239, 107, 190, 158, 8, 108, 19, 108, 20, 108, 27, 108, 36, 108, 35, 108, 94, 108, 85, 108, 98, 108, 106, 108, 130, 108, 141, 108, 154, 108, 129, 108, 155, 108, 126, 108, 104, 108, 115, 108, 146, 108, 144, 108, 196, 108, 241, 108, 211, 108, 189, 108, 215, 108, 197, 108, 221, 108, 174, 108, 177, 108, 190, 108, 186, 108, 219, 108, 239, 108, 217, 108, 234, 108, 31, 109, 77, 136, 54, 109, 43, 109, 61, 109, 56, 109, 25, 109, 53, 109, 51, 109, 18, 109, 12, 109, 99, 109, 147, 109, 100, 109, 90, 109, 121, 109, 89, 109, 142, 109, 149, 109, 228, 111, 133, 109, 249, 109, 21, 110, 10, 110, 181, 109, 199, 109, 230, 109, 184, 109, 198, 109, 236, 109, 222, 109, 204, 109, 232, 109, 210, 109, 197, 109, 250, 109, 217, 109, 228, 109, 213, 109, 234, 109, 238, 109, 45, 110, 110, 110, 46, 110, 25, 110, 114, 110, 95, 110, 62, 110, 35, 110, 107, 110, 43, 110, 118, 110, 77, 110, 31, 110, 67, 110, 58, 110, 78, 110, 36, 110, 255, 110, 29, 110, 56, 110, 130, 110, 170, 110, 152, 110, 201, 110, 183, 110, 211, 110, 189, 110, 175, 110, 196, 110, 178, 110, 212, 110, 213, 110, 143, 110, 165, 110, 194, 110, 159, 110, 65, 111, 17, 111, 76, 112, 236, 110, 248, 110, 254, 110, 63, 111, 242, 110, 49, 111, 239, 110, 50, 111, 204, 110, 62, 111, 19, 111, 247, 110, 134, 111, 122, 111, 120, 111, 129, 111, 128, 111, 111, 111, 91, 111, 243, 111, 109, 111, 130, 111, 124, 111, 88, 111, 142, 111, 145, 111, 194, 111, 102, 111, 179, 111, 163, 111, 161, 111, 164, 111, 185, 111, 198, 111, 170, 111, 223, 111, 213, 111, 236, 111, 212, 111, 216, 111, 241, 111, 238, 111, 219, 111, 9, 112, 11, 112, 250, 111, 17, 112, 1, 112, 15, 112, 254, 111, 27, 112, 26, 112, 116, 111, 29, 112, 24, 112, 31, 112, 48, 112, 62, 112, 50, 112, 81, 112, 99, 112, 153, 112, 146, 112, 175, 112, 241, 112, 172, 112, 184, 112, 179, 112, 174, 112, 223, 112, 203, 112, 221, 112, 217, 112, 9, 113, 253, 112, 28, 113, 25, 113, 101, 113, 85, 113, 136, 113, 102, 113, 98, 113, 76, 113, 86, 113, 108, 113, 143, 113, 251, 113, 132, 113, 149, 113, 168, 113, 172, 113, 215, 113, 185, 113, 190, 113, 210, 113, 201, 113, 212, 113, 206, 113, 224, 113, 236, 113, 231, 113, 245, 113, 252, 113, 249, 113, 255, 113, 13, 114, 16, 114, 27, 114, 40, 114, 45, 114, 44, 114, 48, 114, 50, 114, 59, 114, 60, 114, 63, 114, 64, 114, 70, 114, 75, 114, 88, 114, 116, 114, 126, 114, 130, 114, 129, 114, 135, 114, 146, 114, 150, 114, 162, 114, 167, 114, 185, 114, 178, 114, 195, 114, 198, 114, 196, 114, 206, 114, 210, 114, 226, 114, 224, 114, 225, 114, 249, 114, 247, 114, 15, 80, 23, 115, 10, 115, 28, 115, 22, 115, 29, 115, 52, 115, 47, 115, 41, 115, 37, 115, 62, 115, 78, 115, 79, 115, 216, 158, 87, 115, 106, 115, 104, 115, 112, 115, 120, 115, 117, 115, 123, 115, 122, 115, 200, 115, 179, 115, 206, 115, 187, 115, 192, 115, 229, 115, 238, 115, 222, 115, 162, 116, 5, 116, 111, 116, 37, 116, 248, 115, 50, 116, 58, 116, 85, 116, 63, 116, 95, 116, 89, 116, 65, 116, 92, 116, 105, 116, 112, 116, 99, 116, 106, 116, 118, 116, 126, 116, 139, 116, 158, 116, 167, 116, 202, 116, 207, 116, 212, 116, 241, 115, 224, 116, 227, 116, 231, 116, 233, 116, 238, 116, 242, 116, 240, 116, 241, 116, 248, 116, 247, 116, 4, 117, 3, 117, 5, 117, 12, 117, 14, 117, 13, 117, 21, 117, 19, 117, 30, 117, 38, 117, 44, 117, 60, 117, 68, 117, 77, 117, 74, 117, 73, 117, 91, 117, 70, 117, 90, 117, 105, 117, 100, 117, 103, 117, 107, 117, 109, 117, 120, 117, 118, 117, 134, 117, 135, 117, 116, 117, 138, 117, 137, 117, 130, 117, 148, 117, 154, 117, 157, 117, 165, 117, 163, 117, 194, 117, 179, 117, 195, 117, 181, 117, 189, 117, 184, 117, 188, 117, 177, 117, 205, 117, 202, 117, 210, 117, 217, 117, 227, 117, 222, 117, 254, 117, 255, 117, 252, 117, 1, 118, 240, 117, 250, 117, 242, 117, 243, 117, 11, 118, 13, 118, 9, 118, 31, 118, 39, 118, 32, 118, 33, 118, 34, 118, 36, 118, 52, 118, 48, 118, 59, 118, 71, 118, 72, 118, 70, 118, 92, 118, 88, 118, 97, 118, 98, 118, 104, 118, 105, 118, 106, 118, 103, 118, 108, 118, 112, 118, 114, 118, 118, 118, 120, 118, 124, 118, 128, 118, 131, 118, 136, 118, 139, 118, 142, 118, 150, 118, 147, 118, 153, 118, 154, 118, 176, 118, 180, 118, 184, 118, 185, 118, 186, 118, 194, 118, 205, 118, 214, 118, 210, 118, 222, 118, 225, 118, 229, 118, 231, 118, 234, 118, 47, 134, 251, 118, 8, 119, 7, 119, 4, 119, 41, 119, 36, 119, 30, 119, 37, 119, 38, 119, 27, 119, 55, 119, 56, 119, 71, 119, 90, 119, 104, 119, 107, 119, 91, 119, 101, 119, 127, 119, 126, 119, 121, 119, 142, 119, 139, 119, 145, 119, 160, 119, 158, 119, 176, 119, 182, 119, 185, 119, 191, 119, 188, 119, 189, 119, 187, 119, 199, 119, 205, 119, 215, 119, 218, 119, 220, 119, 227, 119, 238, 119, 252, 119, 12, 120, 18, 120, 38, 121, 32, 120, 42, 121, 69, 120, 142, 120, 116, 120, 134, 120, 124, 120, 154, 120, 140, 120, 163, 120, 181, 120, 170, 120, 175, 120, 209, 120, 198, 120, 203, 120, 212, 120, 190, 120, 188, 120, 197, 120, 202, 120, 236, 120, 231, 120, 218, 120, 253, 120, 244, 120, 7, 121, 18, 121, 17, 121, 25, 121, 44, 121, 43, 121, 64, 121, 96, 121, 87, 121, 95, 121, 90, 121, 85, 121, 83, 121, 122, 121, 127, 121, 138, 121, 157, 121, 167, 121, 75, 159, 170, 121, 174, 121, 179, 121, 185, 121, 186, 121, 201, 121, 213, 121, 231, 121, 236, 121, 225, 121, 227, 121, 8, 122, 13, 122, 24, 122, 25, 122, 32, 122, 31, 122, 128, 121, 49, 122, 59, 122, 62, 122, 55, 122, 67, 122, 87, 122, 73, 122, 97, 122, 98, 122, 105, 122, 157, 159, 112, 122, 121, 122, 125, 122, 136, 122, 151, 122, 149, 122, 152, 122, 150, 122, 169, 122, 200, 122, 176, 122, 182, 122, 197, 122, 196, 122, 191, 122, 131, 144, 199, 122, 202, 122, 205, 122, 207, 122, 213, 122, 211, 122, 217, 122, 218, 122, 221, 122, 225, 122, 226, 122, 230, 122, 237, 122, 240, 122, 2, 123, 15, 123, 10, 123, 6, 123, 51, 123, 24, 123, 25, 123, 30, 123, 53, 123, 40, 123, 54, 123, 80, 123, 122, 123, 4, 123, 77, 123, 11, 123, 76, 123, 69, 123, 117, 123, 101, 123, 116, 123, 103, 123, 112, 123, 113, 123, 108, 123, 110, 123, 157, 123, 152, 123, 159, 123, 141, 123, 156, 123, 154, 123, 139, 123, 146, 123, 143, 123, 93, 123, 153, 123, 203, 123, 193, 123, 204, 123, 207, 123, 180, 123, 198, 123, 221, 123, 233, 123, 17, 124, 20, 124, 230, 123, 229, 123, 96, 124, 0, 124, 7, 124, 19, 124, 243, 123, 247, 123, 23, 124, 13, 124, 246, 123, 35, 124, 39, 124, 42, 124, 31, 124, 55, 124, 43, 124, 61, 124, 76, 124, 67, 124, 84, 124, 79, 124, 64, 124, 80, 124, 88, 124, 95, 124, 100, 124, 86, 124, 101, 124, 108, 124, 117, 124, 131, 124, 144, 124, 164, 124, 173, 124, 162, 124, 171, 124, 161, 124, 168, 124, 179, 124, 178, 124, 177, 124, 174, 124, 185, 124, 189, 124, 192, 124, 197, 124, 194, 124, 216, 124, 210, 124, 220, 124, 226, 124, 59, 155, 239, 124, 242, 124, 244, 124, 246, 124, 250, 124, 6, 125, 2, 125, 28, 125, 21, 125, 10, 125, 69, 125, 75, 125, 46, 125, 50, 125, 63, 125, 53, 125, 70, 125, 115, 125, 86, 125, 78, 125, 114, 125, 104, 125, 110, 125, 79, 125, 99, 125, 147, 125, 137, 125, 91, 125, 143, 125, 125, 125, 155, 125, 186, 125, 174, 125, 163, 125, 181, 125, 199, 125, 189, 125, 171, 125, 61, 126, 162, 125, 175, 125, 220, 125, 184, 125, 159, 125, 176, 125, 216, 125, 221, 125, 228, 125, 222, 125, 251, 125, 242, 125, 225, 125, 5, 126, 10, 126, 35, 126, 33, 126, 18, 126, 49, 126, 31, 126, 9, 126, 11, 126, 34, 126, 70, 126, 102, 126, 59, 126, 53, 126, 57, 126, 67, 126, 55, 126, 50, 126, 58, 126, 103, 126, 93, 126, 86, 126, 94, 126, 89, 126, 90, 126, 121, 126, 106, 126, 105, 126, 124, 126, 123, 126, 131, 126, 213, 125, 125, 126, 174, 143, 127, 126, 136, 126, 137, 126, 140, 126, 146, 126, 144, 126, 147, 126, 148, 126, 150, 126, 142, 126, 155, 126, 156, 126, 56, 127, 58, 127, 69, 127, 76, 127, 77, 127, 78, 127, 80, 127, 81, 127, 85, 127, 84, 127, 88, 127, 95, 127, 96, 127, 104, 127, 105, 127, 103, 127, 120, 127, 130, 127, 134, 127, 131, 127, 136, 127, 135, 127, 140, 127, 148, 127, 158, 127, 157, 127, 154, 127, 163, 127, 175, 127, 178, 127, 185, 127, 174, 127, 182, 127, 184, 127, 113, 139, 197, 127, 198, 127, 202, 127, 213, 127, 212, 127, 225, 127, 230, 127, 233, 127, 243, 127, 249, 127, 220, 152], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 210108);
	        allocate([6, 128, 4, 128, 11, 128, 18, 128, 24, 128, 25, 128, 28, 128, 33, 128, 40, 128, 63, 128, 59, 128, 74, 128, 70, 128, 82, 128, 88, 128, 90, 128, 95, 128, 98, 128, 104, 128, 115, 128, 114, 128, 112, 128, 118, 128, 121, 128, 125, 128, 127, 128, 132, 128, 134, 128, 133, 128, 155, 128, 147, 128, 154, 128, 173, 128, 144, 81, 172, 128, 219, 128, 229, 128, 217, 128, 221, 128, 196, 128, 218, 128, 214, 128, 9, 129, 239, 128, 241, 128, 27, 129, 41, 129, 35, 129, 47, 129, 75, 129, 139, 150, 70, 129, 62, 129, 83, 129, 81, 129, 252, 128, 113, 129, 110, 129, 101, 129, 102, 129, 116, 129, 131, 129, 136, 129, 138, 129, 128, 129, 130, 129, 160, 129, 149, 129, 164, 129, 163, 129, 95, 129, 147, 129, 169, 129, 176, 129, 181, 129, 190, 129, 184, 129, 189, 129, 192, 129, 194, 129, 186, 129, 201, 129, 205, 129, 209, 129, 217, 129, 216, 129, 200, 129, 218, 129, 223, 129, 224, 129, 231, 129, 250, 129, 251, 129, 254, 129, 1, 130, 2, 130, 5, 130, 7, 130, 10, 130, 13, 130, 16, 130, 22, 130, 41, 130, 43, 130, 56, 130, 51, 130, 64, 130, 89, 130, 88, 130, 93, 130, 90, 130, 95, 130, 100, 130, 98, 130, 104, 130, 106, 130, 107, 130, 46, 130, 113, 130, 119, 130, 120, 130, 126, 130, 141, 130, 146, 130, 171, 130, 159, 130, 187, 130, 172, 130, 225, 130, 227, 130, 223, 130, 210, 130, 244, 130, 243, 130, 250, 130, 147, 131, 3, 131, 251, 130, 249, 130, 222, 130, 6, 131, 220, 130, 9, 131, 217, 130, 53, 131, 52, 131, 22, 131, 50, 131, 49, 131, 64, 131, 57, 131, 80, 131, 69, 131, 47, 131, 43, 131, 23, 131, 24, 131, 133, 131, 154, 131, 170, 131, 159, 131, 162, 131, 150, 131, 35, 131, 142, 131, 135, 131, 138, 131, 124, 131, 181, 131, 115, 131, 117, 131, 160, 131, 137, 131, 168, 131, 244, 131, 19, 132, 235, 131, 206, 131, 253, 131, 3, 132, 216, 131, 11, 132, 193, 131, 247, 131, 7, 132, 224, 131, 242, 131, 13, 132, 34, 132, 32, 132, 189, 131, 56, 132, 6, 133, 251, 131, 109, 132, 42, 132, 60, 132, 90, 133, 132, 132, 119, 132, 107, 132, 173, 132, 110, 132, 130, 132, 105, 132, 70, 132, 44, 132, 111, 132, 121, 132, 53, 132, 202, 132, 98, 132, 185, 132, 191, 132, 159, 132, 217, 132, 205, 132, 187, 132, 218, 132, 208, 132, 193, 132, 198, 132, 214, 132, 161, 132, 33, 133, 255, 132, 244, 132, 23, 133, 24, 133, 44, 133, 31, 133, 21, 133, 20, 133, 252, 132, 64, 133, 99, 133, 88, 133, 72, 133, 65, 133, 2, 134, 75, 133, 85, 133, 128, 133, 164, 133, 136, 133, 145, 133, 138, 133, 168, 133, 109, 133, 148, 133, 155, 133, 234, 133, 135, 133, 156, 133, 119, 133, 126, 133, 144, 133, 201, 133, 186, 133, 207, 133, 185, 133, 208, 133, 213, 133, 221, 133, 229, 133, 220, 133, 249, 133, 10, 134, 19, 134, 11, 134, 254, 133, 250, 133, 6, 134, 34, 134, 26, 134, 48, 134, 63, 134, 77, 134, 85, 78, 84, 134, 95, 134, 103, 134, 113, 134, 147, 134, 163, 134, 169, 134, 170, 134, 139, 134, 140, 134, 182, 134, 175, 134, 196, 134, 198, 134, 176, 134, 201, 134, 35, 136, 171, 134, 212, 134, 222, 134, 233, 134, 236, 134, 223, 134, 219, 134, 239, 134, 18, 135, 6, 135, 8, 135, 0, 135, 3, 135, 251, 134, 17, 135, 9, 135, 13, 135, 249, 134, 10, 135, 52, 135, 63, 135, 55, 135, 59, 135, 37, 135, 41, 135, 26, 135, 96, 135, 95, 135, 120, 135, 76, 135, 78, 135, 116, 135, 87, 135, 104, 135, 110, 135, 89, 135, 83, 135, 99, 135, 106, 135, 5, 136, 162, 135, 159, 135, 130, 135, 175, 135, 203, 135, 189, 135, 192, 135, 208, 135, 214, 150, 171, 135, 196, 135, 179, 135, 199, 135, 198, 135, 187, 135, 239, 135, 242, 135, 224, 135, 15, 136, 13, 136, 254, 135, 246, 135, 247, 135, 14, 136, 210, 135, 17, 136, 22, 136, 21, 136, 34, 136, 33, 136, 49, 136, 54, 136, 57, 136, 39, 136, 59, 136, 68, 136, 66, 136, 82, 136, 89, 136, 94, 136, 98, 136, 107, 136, 129, 136, 126, 136, 158, 136, 117, 136, 125, 136, 181, 136, 114, 136, 130, 136, 151, 136, 146, 136, 174, 136, 153, 136, 162, 136, 141, 136, 164, 136, 176, 136, 191, 136, 177, 136, 195, 136, 196, 136, 212, 136, 216, 136, 217, 136, 221, 136, 249, 136, 2, 137, 252, 136, 244, 136, 232, 136, 242, 136, 4, 137, 12, 137, 10, 137, 19, 137, 67, 137, 30, 137, 37, 137, 42, 137, 43, 137, 65, 137, 68, 137, 59, 137, 54, 137, 56, 137, 76, 137, 29, 137, 96, 137, 94, 137, 102, 137, 100, 137, 109, 137, 106, 137, 111, 137, 116, 137, 119, 137, 126, 137, 131, 137, 136, 137, 138, 137, 147, 137, 152, 137, 161, 137, 169, 137, 166, 137, 172, 137, 175, 137, 178, 137, 186, 137, 189, 137, 191, 137, 192, 137, 218, 137, 220, 137, 221, 137, 231, 137, 244, 137, 248, 137, 3, 138, 22, 138, 16, 138, 12, 138, 27, 138, 29, 138, 37, 138, 54, 138, 65, 138, 91, 138, 82, 138, 70, 138, 72, 138, 124, 138, 109, 138, 108, 138, 98, 138, 133, 138, 130, 138, 132, 138, 168, 138, 161, 138, 145, 138, 165, 138, 166, 138, 154, 138, 163, 138, 196, 138, 205, 138, 194, 138, 218, 138, 235, 138, 243, 138, 231, 138, 228, 138, 241, 138, 20, 139, 224, 138, 226, 138, 247, 138, 222, 138, 219, 138, 12, 139, 7, 139, 26, 139, 225, 138, 22, 139, 16, 139, 23, 139, 32, 139, 51, 139, 171, 151, 38, 139, 43, 139, 62, 139, 40, 139, 65, 139, 76, 139, 79, 139, 78, 139, 73, 139, 86, 139, 91, 139, 90, 139, 107, 139, 95, 139, 108, 139, 111, 139, 116, 139, 125, 139, 128, 139, 140, 139, 142, 139, 146, 139, 147, 139, 150, 139, 153, 139, 154, 139, 58, 140, 65, 140, 63, 140, 72, 140, 76, 140, 78, 140, 80, 140, 85, 140, 98, 140, 108, 140, 120, 140, 122, 140, 130, 140, 137, 140, 133, 140, 138, 140, 141, 140, 142, 140, 148, 140, 124, 140, 152, 140, 29, 98, 173, 140, 170, 140, 189, 140, 178, 140, 179, 140, 174, 140, 182, 140, 200, 140, 193, 140, 228, 140, 227, 140, 218, 140, 253, 140, 250, 140, 251, 140, 4, 141, 5, 141, 10, 141, 7, 141, 15, 141, 13, 141, 16, 141, 78, 159, 19, 141, 205, 140, 20, 141, 22, 141, 103, 141, 109, 141, 113, 141, 115, 141, 129, 141, 153, 141, 194, 141, 190, 141, 186, 141, 207, 141, 218, 141, 214, 141, 204, 141, 219, 141, 203, 141, 234, 141, 235, 141, 223, 141, 227, 141, 252, 141, 8, 142, 9, 142, 255, 141, 29, 142, 30, 142, 16, 142, 31, 142, 66, 142, 53, 142, 48, 142, 52, 142, 74, 142, 71, 142, 73, 142, 76, 142, 80, 142, 72, 142, 89, 142, 100, 142, 96, 142, 42, 142, 99, 142, 85, 142, 118, 142, 114, 142, 124, 142, 129, 142, 135, 142, 133, 142, 132, 142, 139, 142, 138, 142, 147, 142, 145, 142, 148, 142, 153, 142, 170, 142, 161, 142, 172, 142, 176, 142, 198, 142, 177, 142, 190, 142, 197, 142, 200, 142, 203, 142, 219, 142, 227, 142, 252, 142, 251, 142, 235, 142, 254, 142, 10, 143, 5, 143, 21, 143, 18, 143, 25, 143, 19, 143, 28, 143, 31, 143, 27, 143, 12, 143, 38, 143, 51, 143, 59, 143, 57, 143, 69, 143, 66, 143, 62, 143, 76, 143, 73, 143, 70, 143, 78, 143, 87, 143, 92, 143, 98, 143, 99, 143, 100, 143, 156, 143, 159, 143, 163, 143, 173, 143, 175, 143, 183, 143, 218, 143, 229, 143, 226, 143, 234, 143, 239, 143, 135, 144, 244, 143, 5, 144, 249, 143, 250, 143, 17, 144, 21, 144, 33, 144, 13, 144, 30, 144, 22, 144, 11, 144, 39, 144, 54, 144, 53, 144, 57, 144, 248, 143, 79, 144, 80, 144, 81, 144, 82, 144, 14, 144, 73, 144, 62, 144, 86, 144, 88, 144, 94, 144, 104, 144, 111, 144, 118, 144, 168, 150, 114, 144, 130, 144, 125, 144, 129, 144, 128, 144, 138, 144, 137, 144, 143, 144, 168, 144, 175, 144, 177, 144, 181, 144, 226, 144, 228, 144, 72, 98, 219, 144, 2, 145, 18, 145, 25, 145, 50, 145, 48, 145, 74, 145, 86, 145, 88, 145, 99, 145, 101, 145, 105, 145, 115, 145, 114, 145, 139, 145, 137, 145, 130, 145, 162, 145, 171, 145, 175, 145, 170, 145, 181, 145, 180, 145, 186, 145, 192, 145, 193, 145, 201, 145, 203, 145, 208, 145, 214, 145, 223, 145, 225, 145, 219, 145, 252, 145, 245, 145, 246, 145, 30, 146, 255, 145, 20, 146, 44, 146, 21, 146, 17, 146, 94, 146, 87, 146, 69, 146, 73, 146, 100, 146, 72, 146, 149, 146, 63, 146, 75, 146, 80, 146, 156, 146, 150, 146, 147, 146, 155, 146, 90, 146, 207, 146, 185, 146, 183, 146, 233, 146, 15, 147, 250, 146, 68, 147, 46, 147, 25, 147, 34, 147, 26, 147, 35, 147, 58, 147, 53, 147, 59, 147, 92, 147, 96, 147, 124, 147, 110, 147, 86, 147, 176, 147, 172, 147, 173, 147, 148, 147, 185, 147, 214, 147, 215, 147, 232, 147, 229, 147, 216, 147, 195, 147, 221, 147, 208, 147, 200, 147, 228, 147, 26, 148, 20, 148, 19, 148, 3, 148, 7, 148, 16, 148, 54, 148, 43, 148, 53, 148, 33, 148, 58, 148, 65, 148, 82, 148, 68, 148, 91, 148, 96, 148, 98, 148, 94, 148, 106, 148, 41, 146, 112, 148, 117, 148, 119, 148, 125, 148, 90, 148, 124, 148, 126, 148, 129, 148, 127, 148, 130, 149, 135, 149, 138, 149, 148, 149, 150, 149, 152, 149, 153, 149, 160, 149, 168, 149, 167, 149, 173, 149, 188, 149, 187, 149, 185, 149, 190, 149, 202, 149, 246, 111, 195, 149, 205, 149, 204, 149, 213, 149, 212, 149, 214, 149, 220, 149, 225, 149, 229, 149, 226, 149, 33, 150, 40, 150, 46, 150, 47, 150, 66, 150, 76, 150, 79, 150, 75, 150, 119, 150, 92, 150, 94, 150, 93, 150, 95, 150, 102, 150, 114, 150, 108, 150, 141, 150, 152, 150, 149, 150, 151, 150, 170, 150, 167, 150, 177, 150, 178, 150, 176, 150, 180, 150, 182, 150, 184, 150, 185, 150, 206, 150, 203, 150, 201, 150, 205, 150, 77, 137, 220, 150, 13, 151, 213, 150, 249, 150, 4, 151, 6, 151, 8, 151, 19, 151, 14, 151, 17, 151, 15, 151, 22, 151, 25, 151, 36, 151, 42, 151, 48, 151, 57, 151, 61, 151, 62, 151, 68, 151, 70, 151, 72, 151, 66, 151, 73, 151, 92, 151, 96, 151, 100, 151, 102, 151, 104, 151, 210, 82, 107, 151, 113, 151, 121, 151, 133, 151, 124, 151, 129, 151, 122, 151, 134, 151, 139, 151, 143, 151, 144, 151, 156, 151, 168, 151, 166, 151, 163, 151, 179, 151, 180, 151, 195, 151, 198, 151, 200, 151, 203, 151, 220, 151, 237, 151, 79, 159, 242, 151, 223, 122, 246, 151, 245, 151, 15, 152, 12, 152, 56, 152, 36, 152, 33, 152, 55, 152, 61, 152, 70, 152, 79, 152, 75, 152, 107, 152, 111, 152, 112, 152, 113, 152, 116, 152, 115, 152, 170, 152, 175, 152, 177, 152, 182, 152, 196, 152, 195, 152, 198, 152, 233, 152, 235, 152, 3, 153, 9, 153, 18, 153, 20, 153, 24, 153, 33, 153, 29, 153, 30, 153, 36, 153, 32, 153, 44, 153, 46, 153, 61, 153, 62, 153, 66, 153, 73, 153, 69, 153, 80, 153, 75, 153, 81, 153, 82, 153, 76, 153, 85, 153, 151, 153, 152, 153, 165, 153, 173, 153, 174, 153, 188, 153, 223, 153, 219, 153, 221, 153, 216, 153, 209, 153, 237, 153, 238, 153, 241, 153, 242, 153, 251, 153, 248, 153, 1, 154, 15, 154, 5, 154, 226, 153, 25, 154, 43, 154, 55, 154, 69, 154, 66, 154, 64, 154, 67, 154, 62, 154, 85, 154, 77, 154, 91, 154, 87, 154, 95, 154, 98, 154, 101, 154, 100, 154, 105, 154, 107, 154, 106, 154, 173, 154, 176, 154, 188, 154, 192, 154, 207, 154, 209, 154, 211, 154, 212, 154, 222, 154, 223, 154, 226, 154, 227, 154, 230, 154, 239, 154, 235, 154, 238, 154, 244, 154, 241, 154, 247, 154, 251, 154, 6, 155, 24, 155, 26, 155, 31, 155, 34, 155, 35, 155, 37, 155, 39, 155, 40, 155, 41, 155, 42, 155, 46, 155, 47, 155, 50, 155, 68, 155, 67, 155, 79, 155, 77, 155, 78, 155, 81, 155, 88, 155, 116, 155, 147, 155, 131, 155, 145, 155, 150, 155, 151, 155, 159, 155, 160, 155, 168, 155, 180, 155, 192, 155, 202, 155, 185, 155, 198, 155, 207, 155, 209, 155, 210, 155, 227, 155, 226, 155, 228, 155, 212, 155, 225, 155, 58, 156, 242, 155, 241, 155, 240, 155, 21, 156, 20, 156, 9, 156, 19, 156, 12, 156, 6, 156, 8, 156, 18, 156, 10, 156, 4, 156, 46, 156, 27, 156, 37, 156, 36, 156, 33, 156, 48, 156, 71, 156, 50, 156, 70, 156, 62, 156, 90, 156, 96, 156, 103, 156, 118, 156, 120, 156, 231, 156, 236, 156, 240, 156, 9, 157, 8, 157, 235, 156, 3, 157, 6, 157, 42, 157, 38, 157, 175, 157, 35, 157, 31, 157, 68, 157, 21, 157, 18, 157, 65, 157, 63, 157, 62, 157, 70, 157, 72, 157, 93, 157, 94, 157, 100, 157, 81, 157, 80, 157, 89, 157, 114, 157, 137, 157, 135, 157, 171, 157, 111, 157, 122, 157, 154, 157, 164, 157, 169, 157, 178, 157, 196, 157, 193, 157, 187, 157, 184, 157, 186, 157, 198, 157, 207, 157, 194, 157, 217, 157, 211, 157, 248, 157, 230, 157, 237, 157, 239, 157, 253, 157, 26, 158, 27, 158, 30, 158, 117, 158, 121, 158, 125, 158, 129, 158, 136, 158, 139, 158, 140, 158, 146, 158, 149, 158, 145, 158, 157, 158, 165, 158, 169, 158, 184, 158, 170, 158, 173, 158, 97, 151, 204, 158, 206, 158, 207, 158, 208, 158, 212, 158, 220, 158, 222, 158, 221, 158, 224, 158, 229, 158, 232, 158, 239, 158, 244, 158, 246, 158, 247, 158, 249, 158, 251, 158, 252, 158, 253, 158, 7, 159, 8, 159, 183, 118, 21, 159, 33, 159, 44, 159, 62, 159, 74, 159, 82, 159, 84, 159, 99, 159, 95, 159, 96, 159, 97, 159, 102, 159, 103, 159, 108, 159, 106, 159, 119, 159, 114, 159, 118, 159, 149, 159, 156, 159, 160, 159, 47, 88, 199, 105, 89, 144, 100, 116, 220, 81, 153, 113, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 2, 78, 4, 78, 5, 78, 6, 78, 15, 78, 18, 78, 23, 78, 31, 78, 32, 78, 33, 78, 35, 78, 38, 78, 41, 78, 46, 78, 47, 78, 49, 78, 51, 78, 53, 78, 55, 78, 60, 78, 64, 78, 65, 78, 66, 78, 68, 78, 70, 78, 74, 78, 81, 78, 85, 78, 87, 78, 90, 78, 91, 78, 98, 78, 99, 78, 100, 78, 101, 78, 103, 78, 104, 78, 106, 78, 107, 78, 108, 78, 109, 78, 110, 78, 111, 78, 114, 78, 116, 78, 117, 78, 118, 78, 119, 78, 120, 78, 121, 78, 122, 78, 123, 78, 124, 78, 125, 78, 127, 78, 128, 78, 129, 78, 130, 78, 131, 78, 132, 78, 133, 78, 135, 78, 138, 78, 144, 78, 150, 78, 151, 78, 153, 78, 156, 78, 157, 78, 158, 78, 163, 78, 170, 78, 175, 78, 176, 78, 177, 78, 180, 78, 182, 78, 183, 78, 184, 78, 185, 78, 188, 78, 189, 78, 190, 78, 200, 78, 204, 78, 207, 78, 208, 78, 210, 78, 218, 78, 219, 78, 220, 78, 224, 78, 226, 78, 230, 78, 231, 78, 233, 78, 237, 78, 238, 78, 239, 78, 241, 78, 244, 78, 248, 78, 249, 78, 250, 78, 252, 78, 254, 78, 0, 79, 2, 79, 3, 79, 4, 79, 5, 79, 6, 79, 7, 79, 8, 79, 11, 79, 12, 79, 18, 79, 19, 79, 20, 79, 21, 79, 22, 79, 28, 79, 29, 79, 33, 79, 35, 79, 40, 79, 41, 79, 44, 79, 45, 79, 46, 79, 49, 79, 51, 79, 53, 79, 55, 79, 57, 79, 59, 79, 62, 79, 63, 79, 64, 79, 65, 79, 66, 79, 68, 79, 69, 79, 71, 79, 72, 79, 73, 79, 74, 79, 75, 79, 76, 79, 82, 79, 84, 79, 86, 79, 97, 79, 98, 79, 102, 79, 104, 79, 106, 79, 107, 79, 109, 79, 110, 79, 113, 79, 114, 79, 117, 79, 119, 79, 120, 79, 121, 79, 122, 79, 125, 79, 128, 79, 129, 79, 130, 79, 133, 79, 134, 79, 135, 79, 138, 79, 140, 79, 142, 79, 144, 79, 146, 79, 147, 79, 149, 79, 150, 79, 152, 79, 153, 79, 154, 79, 156, 79, 158, 79, 159, 79, 161, 79, 162, 79, 164, 79, 171, 79, 173, 79, 176, 79, 177, 79, 178, 79, 179, 79, 180, 79, 182, 79, 183, 79, 184, 79, 185, 79, 186, 79, 187, 79, 188, 79, 189, 79, 190, 79, 192, 79, 193, 79, 194, 79, 198, 79, 199, 79, 200, 79, 201, 79, 203, 79, 204, 79, 205, 79, 210, 79, 211, 79, 212, 79, 213, 79, 214, 79, 217, 79, 219, 79, 224, 79, 226, 79, 228, 79, 229, 79, 231, 79, 235, 79, 236, 79, 240, 79, 242, 79, 244, 79, 245, 79, 246, 79, 247, 79, 249, 79, 251, 79, 252, 79, 253, 79, 255, 79, 0, 80, 1, 80, 2, 80, 3, 80, 4, 80, 5, 80, 6, 80, 7, 80, 8, 80, 9, 80, 10, 80, 11, 80, 14, 80, 16, 80, 17, 80, 19, 80, 21, 80, 22, 80, 23, 80, 27, 80, 29, 80, 30, 80, 32, 80, 34, 80, 35, 80, 36, 80, 39, 80, 43, 80, 47, 80, 48, 80, 49, 80, 50, 80, 51, 80, 52, 80, 53, 80, 54, 80, 55, 80, 56, 80, 57, 80, 59, 80, 61, 80, 63, 80, 64, 80, 65, 80, 66, 80, 68, 80, 69, 80, 70, 80, 73, 80, 74, 80, 75, 80, 77, 80, 80, 80, 81, 80, 82, 80, 83, 80, 84, 80, 86, 80, 87, 80, 88, 80, 89, 80, 91, 80, 93, 80, 94, 80, 95, 80, 96, 80, 97, 80, 98, 80, 99, 80, 100, 80, 102, 80, 103, 80, 104, 80, 105, 80, 106, 80, 107, 80, 109, 80, 110, 80, 111, 80, 112, 80, 113, 80, 114, 80, 115, 80, 116, 80, 117, 80, 120, 80, 121, 80, 122, 80, 124, 80, 125, 80, 129, 80, 130, 80, 131, 80, 132, 80, 134, 80, 135, 80, 137, 80, 138, 80, 139, 80, 140, 80, 142, 80, 143, 80, 144, 80, 145, 80, 146, 80, 147, 80, 148, 80, 149, 80, 150, 80, 151, 80, 152, 80, 153, 80, 154, 80, 155, 80, 156, 80, 157, 80, 158, 80, 159, 80, 160, 80, 161, 80, 162, 80, 164, 80, 166, 80, 170, 80, 171, 80, 173, 80, 174, 80, 175, 80, 176, 80, 177, 80, 179, 80, 180, 80, 181, 80, 182, 80, 183, 80, 184, 80, 185, 80, 188, 80, 189, 80, 190, 80, 191, 80, 192, 80, 193, 80, 194, 80, 195, 80, 196, 80, 197, 80, 198, 80, 199, 80, 200, 80, 201, 80, 202, 80, 203, 80, 204, 80, 205, 80, 206, 80, 208, 80, 209, 80, 210, 80, 211, 80, 212, 80, 213, 80, 215, 80, 216, 80, 217, 80, 219, 80, 220, 80, 221, 80, 222, 80, 223, 80, 224, 80, 225, 80, 226, 80, 227, 80, 228, 80, 229, 80, 232, 80, 233, 80, 234, 80, 235, 80, 239, 80, 240, 80, 241, 80, 242, 80, 244, 80, 246, 80, 247, 80, 248, 80, 249, 80, 250, 80, 252, 80, 253, 80, 254, 80, 255, 80, 0, 81, 1, 81, 2, 81, 3, 81, 4, 81, 5, 81, 8, 81, 9, 81, 10, 81, 12, 81, 13, 81, 14, 81, 15, 81, 16, 81, 17, 81, 19, 81, 20, 81, 21, 81, 22, 81, 23, 81, 24, 81, 25, 81, 26, 81, 27, 81, 28, 81, 29, 81, 30, 81, 31, 81, 32, 81, 34, 81, 35, 81, 36, 81, 37, 81, 38, 81, 39, 81, 40, 81, 41, 81, 42, 81, 43, 81, 44, 81, 45, 81, 46, 81, 47, 81, 48, 81, 49, 81, 50, 81, 51, 81, 52, 81, 53, 81, 54, 81, 55, 81, 56, 81, 57, 81, 58, 81, 59, 81, 60, 81, 61, 81, 62, 81, 66, 81, 71, 81, 74, 81, 76, 81, 78, 81, 79, 81, 80, 81, 82, 81, 83, 81, 87, 81, 88, 81, 89, 81, 91, 81, 93, 81, 94, 81, 95, 81, 96, 81, 97, 81, 99, 81, 100, 81, 102, 81, 103, 81, 105, 81, 106, 81, 111, 81, 114, 81, 122, 81, 126, 81, 127, 81, 131, 81, 132, 81, 134, 81, 135, 81, 138, 81, 139, 81, 142, 81, 143, 81, 144, 81, 145, 81, 147, 81, 148, 81, 152, 81, 154, 81, 157, 81, 158, 81, 159, 81, 161, 81, 163, 81, 166, 81, 167, 81, 168, 81, 169, 81, 170, 81, 173, 81, 174, 81, 180, 81, 184, 81, 185, 81, 186, 81, 190, 81, 191, 81, 193, 81, 194, 81, 195, 81, 197, 81, 200, 81, 202, 81, 205, 81, 206, 81, 208, 81, 210, 81, 211, 81, 212, 81, 213, 81, 214, 81, 215, 81, 216, 81, 217, 81, 218, 81, 220, 81, 222, 81, 223, 81, 226, 81, 227, 81, 229, 81, 230, 81, 231, 81, 232, 81, 233, 81, 234, 81, 236, 81, 238, 81, 241, 81, 242, 81, 244, 81, 247, 81, 254, 81, 4, 82, 5, 82, 9, 82, 11, 82, 12, 82, 15, 82, 16, 82, 19, 82, 20, 82, 21, 82, 28, 82, 30, 82, 31, 82, 33, 82, 34, 82, 35, 82, 37, 82, 38, 82, 39, 82, 42, 82, 44, 82, 47, 82, 49, 82, 50, 82, 52, 82, 53, 82, 60, 82, 62, 82, 68, 82, 69, 82, 70, 82, 71, 82, 72, 82, 73, 82, 75, 82, 78, 82, 79, 82, 82, 82, 83, 82, 85, 82, 87, 82, 88, 82, 89, 82, 90, 82, 91, 82, 93, 82, 95, 82, 96, 82, 98, 82, 99, 82, 100, 82, 102, 82, 104, 82, 107, 82, 108, 82, 109, 82, 110, 82, 112, 82, 113, 82, 115, 82, 116, 82, 117, 82, 118, 82, 119, 82, 120, 82, 121, 82, 122, 82, 123, 82, 124, 82, 126, 82, 128, 82, 131, 82, 132, 82, 133, 82, 134, 82, 135, 82, 137, 82, 138, 82, 139, 82, 140, 82, 141, 82, 142, 82, 143, 82, 145, 82, 146, 82, 148, 82, 149, 82, 150, 82, 151, 82, 152, 82, 153, 82, 154, 82, 156, 82, 164, 82, 165, 82, 166, 82, 167, 82, 174, 82, 175, 82, 176, 82, 180, 82, 181, 82, 182, 82, 183, 82, 184, 82, 185, 82, 186, 82, 187, 82, 188, 82, 189, 82, 192, 82, 193, 82, 194, 82, 196, 82, 197, 82, 198, 82, 200, 82, 202, 82, 204, 82, 205, 82, 206, 82, 207, 82, 209, 82, 211, 82, 212, 82, 213, 82, 215, 82, 217, 82, 218, 82, 219, 82, 220, 82, 221, 82, 222, 82, 224, 82, 225, 82, 226, 82, 227, 82, 229, 82, 230, 82, 231, 82, 232, 82, 233, 82, 234, 82, 235, 82, 236, 82, 237, 82, 238, 82, 239, 82, 241, 82, 242, 82, 243, 82, 244, 82, 245, 82, 246, 82, 247, 82, 248, 82, 251, 82, 252, 82, 253, 82, 1, 83, 2, 83, 3, 83, 4, 83, 7, 83, 9, 83, 10, 83, 11, 83, 12, 83, 14, 83, 17, 83, 18, 83, 19, 83, 20, 83, 24, 83, 27, 83, 28, 83, 30, 83, 31, 83, 34, 83, 36, 83, 37, 83, 39, 83, 40, 83, 41, 83, 43, 83, 44, 83, 45, 83, 47, 83, 48, 83, 49, 83, 50, 83, 51, 83, 52, 83, 53, 83, 54, 83, 55, 83, 56, 83, 60, 83, 61, 83, 64, 83, 66, 83, 68, 83, 70, 83, 75, 83, 76, 83, 77, 83, 80, 83, 84, 83, 88, 83, 89, 83, 91, 83, 93, 83, 101, 83, 104, 83, 106, 83, 108, 83, 109, 83, 114, 83, 118, 83, 121, 83, 123, 83, 124, 83, 125, 83, 126, 83, 128, 83, 129, 83, 131, 83, 135, 83, 136, 83, 138, 83, 142, 83, 143, 83, 144, 83, 145, 83, 146, 83, 147, 83, 148, 83, 150, 83, 151, 83, 153, 83, 155, 83, 156, 83, 158, 83, 160, 83, 161, 83, 164, 83, 167, 83, 170, 83, 171, 83, 172, 83, 173, 83, 175, 83, 176, 83, 177, 83, 178, 83, 179, 83, 180, 83, 181, 83, 183, 83, 184, 83, 185, 83, 186, 83, 188, 83, 189, 83, 190, 83, 192, 83, 195, 83, 196, 83, 197, 83, 198, 83, 199, 83, 206, 83, 207, 83, 208, 83, 210, 83, 211, 83, 213, 83, 218, 83, 220, 83, 221, 83, 222, 83, 225, 83, 226, 83, 231, 83, 244, 83, 250, 83, 254, 83, 255, 83, 0, 84, 2, 84, 5, 84, 7, 84, 11, 84, 20, 84, 24, 84, 25, 84, 26, 84, 28, 84, 34, 84, 36, 84, 37, 84, 42, 84, 48, 84, 51, 84, 54, 84, 55, 84, 58, 84, 61, 84, 63, 84, 65, 84, 66, 84, 68, 84, 69, 84, 71, 84, 73, 84, 76, 84, 77, 84, 78, 84, 79, 84, 81, 84, 90, 84, 93, 84, 94, 84, 95, 84, 96, 84, 97, 84, 99, 84, 101, 84, 103, 84, 105, 84, 106, 84, 107, 84, 108, 84, 109, 84, 110, 84, 111, 84, 112, 84, 116, 84, 121, 84, 122, 84, 126, 84, 127, 84, 129, 84, 131, 84, 133, 84, 135, 84, 136, 84, 137, 84, 138, 84, 141, 84, 145, 84, 147, 84, 151, 84, 152, 84, 156, 84, 158, 84, 159, 84, 160, 84, 161, 84, 162, 84, 165, 84, 174, 84, 176, 84, 178, 84, 181, 84, 182, 84, 183, 84, 185, 84, 186, 84, 188, 84, 190, 84, 195, 84, 197, 84, 202, 84, 203, 84, 214, 84, 216, 84, 219, 84, 224, 84, 225, 84, 226, 84, 227, 84, 228, 84, 235, 84, 236, 84, 239, 84, 240, 84, 241, 84, 244, 84, 245, 84, 246, 84, 247, 84, 248, 84, 249, 84, 251, 84, 254, 84, 0, 85, 2, 85, 3, 85, 4, 85, 5, 85, 8, 85, 10, 85, 11, 85, 12, 85, 13, 85, 14, 85, 18, 85, 19, 85, 21, 85, 22, 85, 23, 85, 24, 85, 25, 85, 26, 85, 28, 85, 29, 85, 30, 85, 31, 85, 33, 85, 37, 85, 38, 85, 40, 85, 41, 85, 43, 85, 45, 85, 50, 85, 52, 85, 53, 85, 54, 85, 56, 85, 57, 85, 58, 85, 59, 85, 61, 85, 64, 85, 66, 85, 69, 85, 71, 85, 72, 85, 75, 85, 76, 85, 77, 85, 78, 85, 79, 85, 81, 85, 82, 85, 83, 85, 84, 85, 87, 85, 88, 85, 89, 85, 90, 85, 91, 85, 93, 85, 94, 85, 95, 85, 96, 85, 98, 85, 99, 85, 104, 85, 105, 85, 107, 85, 111, 85, 112, 85, 113, 85, 114, 85, 115, 85, 116, 85, 121, 85, 122, 85, 125, 85, 127, 85, 133, 85, 134, 85, 140, 85, 141, 85, 142, 85, 144, 85, 146, 85, 147, 85, 149, 85, 150, 85, 151, 85, 154, 85, 155, 85, 158, 85, 160, 85, 161, 85, 162, 85, 163, 85, 164, 85, 165, 85, 166, 85, 168, 85, 169, 85, 170, 85, 171, 85, 172, 85, 173, 85, 174, 85, 175, 85, 176, 85, 178, 85, 180, 85, 182, 85, 184, 85, 186, 85, 188, 85, 191, 85, 192, 85, 193, 85, 194, 85, 195, 85, 198, 85, 199, 85, 200, 85, 202, 85, 203, 85, 206, 85, 207, 85, 208, 85, 213, 85, 215, 85, 216, 85, 217, 85, 218, 85, 219, 85, 222, 85, 224, 85, 226, 85, 231, 85, 233, 85, 237, 85, 238, 85, 240, 85, 241, 85, 244, 85, 246, 85, 248, 85, 249, 85, 250, 85, 251, 85, 252, 85, 255, 85, 2, 86, 3, 86, 4, 86, 5, 86, 6, 86, 7, 86, 10, 86, 11, 86, 13, 86, 16, 86, 17, 86, 18, 86, 19, 86, 20, 86, 21, 86, 22, 86, 23, 86, 25, 86, 26, 86, 28, 86, 29, 86, 32, 86, 33, 86, 34, 86, 37, 86, 38, 86, 40, 86, 41, 86, 42, 86, 43, 86, 46, 86, 47, 86, 48, 86, 51, 86, 53, 86, 55, 86, 56, 86, 58, 86, 60, 86, 61, 86, 62, 86, 64, 86, 65, 86, 66, 86, 67, 86, 68, 86, 69, 86, 70, 86, 71, 86, 72, 86, 73, 86, 74, 86, 75, 86, 79, 86, 80, 86, 81, 86, 82, 86, 83, 86, 85, 86, 86, 86, 90, 86, 91, 86, 93, 86, 94, 86, 95, 86, 96, 86, 97, 86, 99, 86, 101, 86, 102, 86, 103, 86, 109, 86, 110, 86, 111, 86, 112, 86, 114, 86, 115, 86, 116, 86, 117, 86, 119, 86, 120, 86, 121, 86, 122, 86, 125, 86, 126, 86, 127, 86, 128, 86, 129, 86, 130, 86, 131, 86, 132, 86, 135, 86, 136, 86, 137, 86, 138, 86, 139, 86, 140, 86, 141, 86, 144, 86, 145, 86, 146, 86, 148, 86, 149, 86, 150, 86, 151, 86, 152, 86, 153, 86, 154, 86, 155, 86, 156, 86, 157, 86, 158, 86, 159, 86, 160, 86, 161, 86, 162, 86, 164, 86, 165, 86, 166, 86, 167, 86, 168, 86, 169, 86, 170, 86, 171, 86, 172, 86, 173, 86, 174, 86, 176, 86, 177, 86, 178, 86, 179, 86, 180, 86, 181, 86, 182, 86, 184, 86, 185, 86, 186, 86, 187, 86, 189, 86, 190, 86, 191, 86, 192, 86, 193, 86, 194, 86, 195, 86, 196, 86, 197, 86, 198, 86, 199, 86, 200, 86, 201, 86, 203, 86, 204, 86, 205, 86, 206, 86, 207, 86, 208, 86, 209, 86, 210, 86, 211, 86, 213, 86, 214, 86, 216, 86, 217, 86, 220, 86, 227, 86, 229, 86, 230, 86, 231, 86, 232, 86, 233, 86, 234, 86, 236, 86, 238, 86, 239, 86, 242, 86, 243, 86, 246, 86, 247, 86, 248, 86, 251, 86, 252, 86, 0, 87, 1, 87, 2, 87, 5, 87, 7, 87, 11, 87, 12, 87, 13, 87, 14, 87, 15, 87, 16, 87, 17, 87, 18, 87, 19, 87, 20, 87, 21, 87, 22, 87, 23, 87, 24, 87, 25, 87, 26, 87, 27, 87, 29, 87, 30, 87, 32, 87, 33, 87, 34, 87, 36, 87, 37, 87, 38, 87, 39, 87, 43, 87, 49, 87, 50, 87, 52, 87, 53, 87, 54, 87, 55, 87, 56, 87, 60, 87, 61, 87, 63, 87, 65, 87, 67, 87, 68, 87, 69, 87, 70, 87, 72, 87, 73, 87, 75, 87, 82, 87, 83, 87, 84, 87, 85, 87, 86, 87, 88, 87, 89, 87, 98, 87, 99, 87, 101, 87, 103, 87, 108, 87, 110, 87, 112, 87, 113, 87, 114, 87, 116, 87, 117, 87, 120, 87, 121, 87, 122, 87, 125, 87, 126, 87, 127, 87, 128, 87, 129, 87, 135, 87, 136, 87, 137, 87, 138, 87, 141, 87, 142, 87, 143, 87, 144, 87, 145, 87, 148, 87, 149, 87, 150, 87, 151, 87, 152, 87, 153, 87, 154, 87, 156, 87, 157, 87, 158, 87, 159, 87, 165, 87, 168, 87, 170, 87, 172, 87, 175, 87, 176, 87, 177, 87, 179, 87, 181, 87, 182, 87, 183, 87, 185, 87, 186, 87, 187, 87, 188, 87, 189, 87, 190, 87, 191, 87, 192, 87, 193, 87, 196, 87, 197, 87, 198, 87, 199, 87, 200, 87, 201, 87, 202, 87, 204, 87, 205, 87, 208, 87, 209, 87, 211, 87, 214, 87, 215, 87, 219, 87, 220, 87, 222, 87, 225, 87, 226, 87, 227, 87, 229, 87, 230, 87, 231, 87, 232, 87, 233, 87, 234, 87, 235, 87, 236, 87, 238, 87, 240, 87, 241, 87, 242, 87, 243, 87, 245, 87, 246, 87, 247, 87, 251, 87, 252, 87, 254, 87, 255, 87, 1, 88, 3, 88, 4, 88, 5, 88, 8, 88, 9, 88, 10, 88, 12, 88, 14, 88, 15, 88, 16, 88, 18, 88, 19, 88, 20, 88, 22, 88, 23, 88, 24, 88, 26, 88, 27, 88, 28, 88, 29, 88, 31, 88, 34, 88, 35, 88, 37, 88, 38, 88, 39, 88, 40, 88, 41, 88, 43, 88, 44, 88, 45, 88, 46, 88, 47, 88, 49, 88, 50, 88, 51, 88, 52, 88, 54, 88, 55, 88, 56, 88, 57, 88, 58, 88, 59, 88, 60, 88, 61, 88, 62, 88, 63, 88, 64, 88, 65, 88, 66, 88, 67, 88, 69, 88, 70, 88, 71, 88, 72, 88, 73, 88, 74, 88, 75, 88, 78, 88, 79, 88, 80, 88, 82, 88, 83, 88, 85, 88, 86, 88, 87, 88, 89, 88, 90, 88, 91, 88, 92, 88, 93, 88, 95, 88, 96, 88, 97, 88, 98, 88, 99, 88, 100, 88, 102, 88, 103, 88, 104, 88, 105, 88, 106, 88, 109, 88, 110, 88, 111, 88, 112, 88, 113, 88, 114, 88, 115, 88, 116, 88, 117, 88, 118, 88, 119, 88, 120, 88, 121, 88, 122, 88, 123, 88, 124, 88, 125, 88, 127, 88, 130, 88, 132, 88, 134, 88, 135, 88, 136, 88, 138, 88, 139, 88, 140, 88, 141, 88, 142, 88, 143, 88, 144, 88, 145, 88, 148, 88, 149, 88, 150, 88, 151, 88, 152, 88, 155, 88, 156, 88, 157, 88, 160, 88, 161, 88, 162, 88, 163, 88, 164, 88, 165, 88, 166, 88, 167, 88, 170, 88, 171, 88, 172, 88, 173, 88, 174, 88, 175, 88, 176, 88, 177, 88, 178, 88, 179, 88, 180, 88, 181, 88, 182, 88, 183, 88, 184, 88, 185, 88, 186, 88, 187, 88, 189, 88, 190, 88, 191, 88, 192, 88, 194, 88, 195, 88, 196, 88, 198, 88, 199, 88, 200, 88, 201, 88, 202, 88, 203, 88, 204, 88, 205, 88, 206, 88, 207, 88, 208, 88, 210, 88, 211, 88, 212, 88, 214, 88, 215, 88, 216, 88, 217, 88, 218, 88, 219, 88, 220, 88, 221, 88, 222, 88, 223, 88, 224, 88, 225, 88, 226, 88, 227, 88, 229, 88, 230, 88, 231, 88, 232, 88, 233, 88, 234, 88, 237, 88, 239, 88, 241, 88, 242, 88, 244, 88, 245, 88, 247, 88, 248, 88, 250, 88, 251, 88, 252, 88, 253, 88, 254, 88, 255, 88, 0, 89, 1, 89, 3, 89, 5, 89, 6, 89, 8, 89, 9, 89, 10, 89, 11, 89, 12, 89, 14, 89, 16, 89, 17, 89, 18, 89, 19, 89, 23, 89, 24, 89, 27, 89, 29, 89, 30, 89, 32, 89, 33, 89, 34, 89, 35, 89, 38, 89, 40, 89, 44, 89, 48, 89, 50, 89, 51, 89, 53, 89, 54, 89, 59, 89, 61, 89, 62, 89, 63, 89, 64, 89, 67, 89, 69, 89, 70, 89, 74, 89, 76, 89, 77, 89, 80, 89, 82, 89, 83, 89, 89, 89, 91, 89, 92, 89, 93, 89, 94, 89, 95, 89, 97, 89, 99, 89, 100, 89, 102, 89, 103, 89, 104, 89, 105, 89, 106, 89, 107, 89, 108, 89, 109, 89, 110, 89, 111, 89, 112, 89, 113, 89, 114, 89, 117, 89, 119, 89, 122, 89, 123, 89, 124, 89, 126, 89, 127, 89, 128, 89, 133, 89, 137, 89, 139, 89, 140, 89, 142, 89, 143, 89, 144, 89, 145, 89, 148, 89, 149, 89, 152, 89, 154, 89, 155, 89, 156, 89, 157, 89, 159, 89, 160, 89, 161, 89, 162, 89, 166, 89, 167, 89, 172, 89, 173, 89, 176, 89, 177, 89, 179, 89, 180, 89, 181, 89, 182, 89, 183, 89, 184, 89, 186, 89, 188, 89, 189, 89, 191, 89, 192, 89, 193, 89, 194, 89, 195, 89, 196, 89, 197, 89, 199, 89, 200, 89, 201, 89, 204, 89, 205, 89, 206, 89, 207, 89, 213, 89, 214, 89, 217, 89, 219, 89, 222, 89, 223, 89, 224, 89, 225, 89, 226, 89, 228, 89, 230, 89, 231, 89, 233, 89, 234, 89, 235, 89, 237, 89, 238, 89, 239, 89, 240, 89, 241, 89, 242, 89, 243, 89, 244, 89, 245, 89, 246, 89, 247, 89, 248, 89, 250, 89, 252, 89, 253, 89, 254, 89, 0, 90, 2, 90, 10, 90, 11, 90, 13, 90, 14, 90, 15, 90, 16, 90, 18, 90, 20, 90, 21, 90, 22, 90, 23, 90, 25, 90, 26, 90, 27, 90, 29, 90, 30, 90, 33, 90, 34, 90, 36, 90, 38, 90, 39, 90, 40, 90, 42, 90, 43, 90, 44, 90, 45, 90, 46, 90, 47, 90, 48, 90, 51, 90, 53, 90, 55, 90, 56, 90, 57, 90, 58, 90, 59, 90, 61, 90, 62, 90, 63, 90, 65, 90, 66, 90, 67, 90, 68, 90, 69, 90, 71, 90, 72, 90, 75, 90, 76, 90, 77, 90, 78, 90, 79, 90, 80, 90, 81, 90, 82, 90, 83, 90, 84, 90, 86, 90, 87, 90, 88, 90, 89, 90, 91, 90, 92, 90, 93, 90, 94, 90, 95, 90, 96, 90, 97, 90, 99, 90, 100, 90, 101, 90, 102, 90, 104, 90, 105, 90, 107, 90, 108, 90, 109, 90, 110, 90, 111, 90, 112, 90, 113, 90, 114, 90, 115, 90, 120, 90, 121, 90, 123, 90, 124, 90, 125, 90, 126, 90, 128, 90, 129, 90, 130, 90, 131, 90, 132, 90, 133, 90, 134, 90, 135, 90, 136, 90, 137, 90, 138, 90, 139, 90, 140, 90, 141, 90, 142, 90, 143, 90, 144, 90, 145, 90, 147, 90, 148, 90, 149, 90, 150, 90, 151, 90, 152, 90, 153, 90, 156, 90, 157, 90, 158, 90, 159, 90, 160, 90, 161, 90, 162, 90, 163, 90, 164, 90, 165, 90, 166, 90, 167, 90, 168, 90, 169, 90, 171, 90, 172, 90, 173, 90, 174, 90, 175, 90, 176, 90, 177, 90, 180, 90, 182, 90, 183, 90, 185, 90, 186, 90, 187, 90, 188, 90, 189, 90, 191, 90, 192, 90, 195, 90, 196, 90, 197, 90, 198, 90, 199, 90, 200, 90, 202, 90, 203, 90, 205, 90, 206, 90, 207, 90, 208, 90, 209, 90, 211, 90, 213, 90, 215, 90, 217, 90, 218, 90, 219, 90, 221, 90, 222, 90, 223, 90, 226, 90, 228, 90, 229, 90, 231, 90, 232, 90, 234, 90, 236, 90, 237, 90, 238, 90, 239, 90, 240, 90, 242, 90, 243, 90, 244, 90, 245, 90, 246, 90, 247, 90, 248, 90, 249, 90, 250, 90, 251, 90, 252, 90, 253, 90, 254, 90, 255, 90, 0, 91, 1, 91, 2, 91, 3, 91, 4, 91, 5, 91, 6, 91, 7, 91, 8, 91, 10, 91, 11, 91, 12, 91, 13, 91, 14, 91, 15, 91, 16, 91, 17, 91, 18, 91, 19, 91, 20, 91, 21, 91, 24, 91, 25, 91, 26, 91, 27, 91, 28, 91, 29, 91, 30, 91, 31, 91, 32, 91, 33, 91, 34, 91, 35, 91, 36, 91, 37, 91, 38, 91, 39, 91, 40, 91, 41, 91, 42, 91, 43, 91, 44, 91, 45, 91, 46, 91, 47, 91, 48, 91, 49, 91, 51, 91, 53, 91, 54, 91, 56, 91, 57, 91, 58, 91, 59, 91, 60, 91, 61, 91, 62, 91, 63, 91, 65, 91, 66, 91, 67, 91, 68, 91, 69, 91, 70, 91, 71, 91, 72, 91, 73, 91, 74, 91, 75, 91, 76, 91, 77, 91, 78, 91, 79, 91, 82, 91, 86, 91, 94, 91, 96, 91, 97, 91, 103, 91, 104, 91, 107, 91, 109, 91, 110, 91, 111, 91, 114, 91, 116, 91, 118, 91, 119, 91, 120, 91, 121, 91, 123, 91, 124, 91, 126, 91, 127, 91, 130, 91, 134, 91, 138, 91, 141, 91, 142, 91, 144, 91, 145, 91, 146, 91, 148, 91, 150, 91, 159, 91, 167, 91, 168, 91, 169, 91, 172, 91, 173, 91, 174, 91, 175, 91, 177, 91, 178, 91, 183, 91, 186, 91, 187, 91, 188, 91, 192, 91, 193, 91, 195, 91, 200, 91, 201, 91, 202, 91, 203, 91, 205, 91, 206, 91, 207, 91, 209, 91, 212, 91, 213, 91, 214, 91, 215, 91, 216, 91, 217, 91, 218, 91, 219, 91, 220, 91, 224, 91, 226, 91, 227, 91, 230, 91, 231, 91, 233, 91, 234, 91, 235, 91, 236, 91, 237, 91, 239, 91, 241, 91, 242, 91, 243, 91, 244, 91, 245, 91, 246, 91, 247, 91, 253, 91, 254, 91, 0, 92, 2, 92, 3, 92, 5, 92, 7, 92, 8, 92, 11, 92, 12, 92, 13, 92, 14, 92, 16, 92, 18, 92, 19, 92, 23, 92, 25, 92, 27, 92, 30, 92, 31, 92, 32, 92, 33, 92, 35, 92, 38, 92, 40, 92, 41, 92, 42, 92, 43, 92, 45, 92, 46, 92, 47, 92, 48, 92, 50, 92, 51, 92, 53, 92, 54, 92, 55, 92, 67, 92, 68, 92, 70, 92, 71, 92, 76, 92, 77, 92, 82, 92, 83, 92, 84, 92, 86, 92, 87, 92, 88, 92, 90, 92, 91, 92, 92, 92, 93, 92, 95, 92, 98, 92, 100, 92, 103, 92, 104, 92, 105, 92, 106, 92, 107, 92, 108, 92, 109, 92, 112, 92, 114, 92, 115, 92, 116, 92, 117, 92, 118, 92, 119, 92, 120, 92, 123, 92, 124, 92, 125, 92, 126, 92, 128, 92, 131, 92, 132, 92, 133, 92, 134, 92, 135, 92, 137, 92, 138, 92, 139, 92, 142, 92, 143, 92, 146, 92, 147, 92, 149, 92, 157, 92, 158, 92, 159, 92, 160, 92, 161, 92, 164, 92, 165, 92, 166, 92, 167, 92, 168, 92, 170, 92, 174, 92, 175, 92, 176, 92, 178, 92, 180, 92, 182, 92, 185, 92, 186, 92, 187, 92, 188, 92, 190, 92, 192, 92, 194, 92, 195, 92, 197, 92, 198, 92, 199, 92, 200, 92, 201, 92, 202, 92, 204, 92, 205, 92, 206, 92, 207, 92, 208, 92, 209, 92, 211, 92, 212, 92, 213, 92, 214, 92, 215, 92, 216, 92, 218, 92, 219, 92, 220, 92, 221, 92, 222, 92, 223, 92, 224, 92, 226, 92, 227, 92, 231, 92, 233, 92, 235, 92, 236, 92, 238, 92, 239, 92, 241, 92, 242, 92, 243, 92, 244, 92, 245, 92, 246, 92, 247, 92, 248, 92, 249, 92, 250, 92, 252, 92, 253, 92, 254, 92, 255, 92, 0, 93, 1, 93, 4, 93, 5, 93, 8, 93, 9, 93, 10, 93, 11, 93, 12, 93, 13, 93, 15, 93, 16, 93, 17, 93, 18, 93, 19, 93, 21, 93, 23, 93, 24, 93, 25, 93, 26, 93, 28, 93, 29, 93, 31, 93, 32, 93, 33, 93, 34, 93, 35, 93, 37, 93, 40, 93, 42, 93, 43, 93, 44, 93, 47, 93, 48, 93, 49, 93, 50, 93, 51, 93, 53, 93, 54, 93, 55, 93, 56, 93, 57, 93, 58, 93, 59, 93, 60, 93, 63, 93, 64, 93, 65, 93, 66, 93, 67, 93, 68, 93, 69, 93, 70, 93, 72, 93, 73, 93, 77, 93, 78, 93, 79, 93, 80, 93, 81, 93, 82, 93, 83, 93, 84, 93, 85, 93, 86, 93, 87, 93, 89, 93, 90, 93, 92, 93, 94, 93, 95, 93, 96, 93, 97, 93, 98, 93, 99, 93, 100, 93, 101, 93, 102, 93, 103, 93, 104, 93, 106, 93, 109, 93, 110, 93, 112, 93, 113, 93, 114, 93, 115, 93, 117, 93, 118, 93, 119, 93, 120, 93, 121, 93, 122, 93, 123, 93, 124, 93, 125, 93, 126, 93, 127, 93, 128, 93, 129, 93, 131, 93, 132, 93, 133, 93, 134, 93, 135, 93, 136, 93, 137, 93, 138, 93, 139, 93, 140, 93, 141, 93, 142, 93, 143, 93, 144, 93, 145, 93, 146, 93, 147, 93, 148, 93, 149, 93, 150, 93, 151, 93, 152, 93, 154, 93, 155, 93, 156, 93, 158, 93, 159, 93, 160, 93, 161, 93, 162, 93, 163, 93, 164, 93, 165, 93, 166, 93, 167, 93, 168, 93, 169, 93, 170, 93, 171, 93, 172, 93, 173, 93, 174, 93, 175, 93, 176, 93, 177, 93, 178, 93, 179, 93, 180, 93, 181, 93, 182, 93, 184, 93, 185, 93, 186, 93, 187, 93, 188, 93, 189, 93, 190, 93, 191, 93, 192, 93, 193, 93, 194, 93, 195, 93, 196, 93, 198, 93, 199, 93, 200, 93, 201, 93, 202, 93, 203, 93, 204, 93, 206, 93, 207, 93, 208, 93, 209, 93, 210, 93, 211, 93, 212, 93, 213, 93, 214, 93, 215, 93, 216, 93, 217, 93, 218, 93, 220, 93, 223, 93, 224, 93, 227, 93, 228, 93, 234, 93, 236, 93, 237, 93, 240, 93, 245, 93, 246, 93, 248, 93, 249, 93, 250, 93, 251, 93, 252, 93, 255, 93, 0, 94, 4, 94, 7, 94, 9, 94, 10, 94, 11, 94, 13, 94, 14, 94, 18, 94, 19, 94, 23, 94, 30, 94, 31, 94, 32, 94, 33, 94, 34, 94, 35, 94, 36, 94, 37, 94, 40, 94, 41, 94, 42, 94, 43, 94, 44, 94, 47, 94, 48, 94, 50, 94, 51, 94, 52, 94, 53, 94, 54, 94, 57, 94, 58, 94, 62, 94, 63, 94, 64, 94, 65, 94, 67, 94, 70, 94, 71, 94, 72, 94, 73, 94, 74, 94, 75, 94, 77, 94, 78, 94, 79, 94, 80, 94, 81, 94, 82, 94, 83, 94, 86, 94, 87, 94, 88, 94, 89, 94, 90, 94, 92, 94, 93, 94, 95, 94, 96, 94, 99, 94, 100, 94, 101, 94, 102, 94, 103, 94, 104, 94, 105, 94, 106, 94, 107, 94, 108, 94, 109, 94, 110, 94, 111, 94, 112, 94, 113, 94, 117, 94, 119, 94, 121, 94, 126, 94, 129, 94, 130, 94, 131, 94, 133, 94, 136, 94, 137, 94, 140, 94, 141, 94, 142, 94, 146, 94, 152, 94, 155, 94, 157, 94, 161, 94, 162, 94, 163, 94, 164, 94, 168, 94, 169, 94, 170, 94, 171, 94, 172, 94, 174, 94, 175, 94, 176, 94, 177, 94, 178, 94, 180, 94, 186, 94, 187, 94, 188, 94, 189, 94, 191, 94, 192, 94, 193, 94, 194, 94, 195, 94, 196, 94, 197, 94, 198, 94, 199, 94, 200, 94, 203, 94, 204, 94, 205, 94, 206, 94, 207, 94, 208, 94, 212, 94, 213, 94, 215, 94, 216, 94, 217, 94, 218, 94, 220, 94, 221, 94, 222, 94, 223, 94, 224, 94, 225, 94, 226, 94, 227, 94, 228, 94, 229, 94, 230, 94, 231, 94, 233, 94, 235, 94, 236, 94, 237, 94, 238, 94, 239, 94, 240, 94, 241, 94, 242, 94, 243, 94, 245, 94, 248, 94, 249, 94, 251, 94, 252, 94, 253, 94, 5, 95, 6, 95, 7, 95, 9, 95, 12, 95, 13, 95, 14, 95, 16, 95, 18, 95, 20, 95, 22, 95, 25, 95, 26, 95, 28, 95, 29, 95, 30, 95, 33, 95, 34, 95, 35, 95, 36, 95, 40, 95, 43, 95, 44, 95, 46, 95, 48, 95, 50, 95, 51, 95, 52, 95, 53, 95, 54, 95, 55, 95, 56, 95, 59, 95, 61, 95, 62, 95, 63, 95, 65, 95, 66, 95, 67, 95, 68, 95, 69, 95, 70, 95, 71, 95, 72, 95, 73, 95, 74, 95, 75, 95, 76, 95, 77, 95, 78, 95, 79, 95, 81, 95, 84, 95, 89, 95, 90, 95, 91, 95, 92, 95, 94, 95, 95, 95, 96, 95, 99, 95, 101, 95, 103, 95, 104, 95, 107, 95, 110, 95, 111, 95, 114, 95, 116, 95, 117, 95, 118, 95, 120, 95, 122, 95, 125, 95, 126, 95, 127, 95, 131, 95, 134, 95, 141, 95, 142, 95, 143, 95, 145, 95, 147, 95, 148, 95, 150, 95, 154, 95, 155, 95, 157, 95, 158, 95, 159, 95, 160, 95, 162, 95, 163, 95, 164, 95, 165, 95, 166, 95, 167, 95, 169, 95, 171, 95, 172, 95, 175, 95, 176, 95, 177, 95, 178, 95, 179, 95, 180, 95, 182, 95, 184, 95, 185, 95, 186, 95, 187, 95, 190, 95, 191, 95, 192, 95, 193, 95, 194, 95, 199, 95, 200, 95, 202, 95, 203, 95, 206, 95, 211, 95, 212, 95, 213, 95, 218, 95, 219, 95, 220, 95, 222, 95, 223, 95, 226, 95, 227, 95, 229, 95, 230, 95, 232, 95, 233, 95, 236, 95, 239, 95, 240, 95, 242, 95, 243, 95, 244, 95, 246, 95, 247, 95, 249, 95, 250, 95, 252, 95, 7, 96, 8, 96, 9, 96, 11, 96, 12, 96, 16, 96, 17, 96, 19, 96, 23, 96, 24, 96, 26, 96, 30, 96, 31, 96, 34, 96, 35, 96, 36, 96, 44, 96, 45, 96, 46, 96, 48, 96, 49, 96, 50, 96, 51, 96, 52, 96, 54, 96, 55, 96, 56, 96, 57, 96, 58, 96, 61, 96, 62, 96, 64, 96, 68, 96, 69, 96, 70, 96, 71, 96, 72, 96, 73, 96, 74, 96, 76, 96, 78, 96, 79, 96, 81, 96, 83, 96, 84, 96, 86, 96, 87, 96, 88, 96, 91, 96, 92, 96, 94, 96, 95, 96, 96, 96, 97, 96, 101, 96, 102, 96, 110, 96, 113, 96, 114, 96, 116, 96, 117, 96, 119, 96, 126, 96, 128, 96, 129, 96, 130, 96, 133, 96, 134, 96, 135, 96, 136, 96, 138, 96, 139, 96, 142, 96, 143, 96, 144, 96, 145, 96, 147, 96, 149, 96, 151, 96, 152, 96, 153, 96, 156, 96, 158, 96, 161, 96, 162, 96, 164, 96, 165, 96, 167, 96, 169, 96, 170, 96, 174, 96, 176, 96, 179, 96, 181, 96, 182, 96, 183, 96, 185, 96, 186, 96, 189, 96, 190, 96, 191, 96, 192, 96, 193, 96, 194, 96, 195, 96, 196, 96, 199, 96, 200, 96, 201, 96, 204, 96, 205, 96, 206, 96, 207, 96, 208, 96, 210, 96, 211, 96, 212, 96, 214, 96, 215, 96, 217, 96, 219, 96, 222, 96, 225, 96, 226, 96, 227, 96, 228, 96, 229, 96, 234, 96, 241, 96, 242, 96, 245, 96, 247, 96, 248, 96, 251, 96, 252, 96, 253, 96, 254, 96, 255, 96, 2, 97, 3, 97, 4, 97, 5, 97, 7, 97, 10, 97, 11, 97, 12, 97, 16, 97, 17, 97, 18, 97, 19, 97, 20, 97, 22, 97, 23, 97, 24, 97, 25, 97, 27, 97, 28, 97, 29, 97, 30, 97, 33, 97, 34, 97, 37, 97, 40, 97, 41, 97, 42, 97, 44, 97, 45, 97, 46, 97, 47, 97, 48, 97, 49, 97, 50, 97, 51, 97, 52, 97, 53, 97, 54, 97, 55, 97, 56, 97, 57, 97, 58, 97, 59, 97, 60, 97, 61, 97, 62, 97, 64, 97, 65, 97, 66, 97, 67, 97, 68, 97, 69, 97, 70, 97, 71, 97, 73, 97, 75, 97, 77, 97, 79, 97, 80, 97, 82, 97, 83, 97, 84, 97, 86, 97, 87, 97, 88, 97, 89, 97, 90, 97, 91, 97, 92, 97, 94, 97, 95, 97, 96, 97, 97, 97, 99, 97, 100, 97, 101, 97, 102, 97, 105, 97, 106, 97, 107, 97, 108, 97, 109, 97, 110, 97, 111, 97, 113, 97, 114, 97, 115, 97, 116, 97, 118, 97, 120, 97, 121, 97, 122, 97, 123, 97, 124, 97, 125, 97, 126, 97, 127, 97, 128, 97, 129, 97, 130, 97, 131, 97, 132, 97, 133, 97, 134, 97, 135, 97, 136, 97, 137, 97, 138, 97, 140, 97, 141, 97, 143, 97, 144, 97, 145, 97, 146, 97, 147, 97, 149, 97, 150, 97, 151, 97, 152, 97, 153, 97, 154, 97, 155, 97, 156, 97, 158, 97, 159, 97, 160, 97, 161, 97, 162, 97, 163, 97, 164, 97, 165, 97, 166, 97, 170, 97, 171, 97, 173, 97, 174, 97, 175, 97, 176, 97, 177, 97, 178, 97, 179, 97, 180, 97, 181, 97, 182, 97, 184, 97, 185, 97, 186, 97, 187, 97, 188, 97, 189, 97, 191, 97, 192, 97, 193, 97, 195, 97, 196, 97, 197, 97, 198, 97, 199, 97, 201, 97, 204, 97, 205, 97, 206, 97, 207, 97, 208, 97, 211, 97, 213, 97, 214, 97, 215, 97, 216, 97, 217, 97, 218, 97, 219, 97, 220, 97, 221, 97, 222, 97, 223, 97, 224, 97, 225, 97, 226, 97, 227, 97, 228, 97, 229, 97, 231, 97, 232, 97, 233, 97, 234, 97, 235, 97, 236, 97, 237, 97, 238, 97, 239, 97, 240, 97, 241, 97, 242, 97, 243, 97, 244, 97, 246, 97, 247, 97, 248, 97, 249, 97, 250, 97, 251, 97, 252, 97, 253, 97, 254, 97, 0, 98, 1, 98, 2, 98, 3, 98, 4, 98, 5, 98, 7, 98, 9, 98, 19, 98, 20, 98, 25, 98, 28, 98, 29, 98, 30, 98, 32, 98, 35, 98, 38, 98, 39, 98, 40, 98, 41, 98, 43, 98, 45, 98, 47, 98, 48, 98, 49, 98, 50, 98, 53, 98, 54, 98, 56, 98, 57, 98, 58, 98, 59, 98, 60, 98, 66, 98, 68, 98, 69, 98, 70, 98, 74, 98, 79, 98, 80, 98, 85, 98, 86, 98, 87, 98, 89, 98, 90, 98, 92, 98, 93, 98, 94, 98, 95, 98, 96, 98, 97, 98, 98, 98, 100, 98, 101, 98, 104, 98, 113, 98, 114, 98, 116, 98, 117, 98, 119, 98, 120, 98, 122, 98, 123, 98, 125, 98, 129, 98, 130, 98, 131, 98, 133, 98, 134, 98, 135, 98, 136, 98, 139, 98, 140, 98, 141, 98, 142, 98, 143, 98, 144, 98, 148, 98, 153, 98, 156, 98, 157, 98, 158, 98, 163, 98, 166, 98, 167, 98, 169, 98, 170, 98, 173, 98, 174, 98, 175, 98, 176, 98, 178, 98, 179, 98, 180, 98, 182, 98, 183, 98, 184, 98, 186, 98, 190, 98, 192, 98, 193, 98, 195, 98, 203, 98, 207, 98, 209, 98, 213, 98, 221, 98, 222, 98, 224, 98, 225, 98, 228, 98, 234, 98, 235, 98, 240, 98, 242, 98, 245, 98, 248, 98, 249, 98, 250, 98, 251, 98, 0, 99, 3, 99, 4, 99, 5, 99, 6, 99, 10, 99, 11, 99, 12, 99, 13, 99, 15, 99, 16, 99, 18, 99, 19, 99, 20, 99, 21, 99, 23, 99, 24, 99, 25, 99, 28, 99, 38, 99, 39, 99, 41, 99, 44, 99, 45, 99, 46, 99, 48, 99, 49, 99, 51, 99, 52, 99, 53, 99, 54, 99, 55, 99, 56, 99, 59, 99, 60, 99, 62, 99, 63, 99, 64, 99, 65, 99, 68, 99, 71, 99, 72, 99, 74, 99, 81, 99, 82, 99, 83, 99, 84, 99, 86, 99, 87, 99, 88, 99, 89, 99, 90, 99, 91, 99, 92, 99, 93, 99, 96, 99, 100, 99, 101, 99, 102, 99, 104, 99, 106, 99, 107, 99, 108, 99, 111, 99, 112, 99, 114, 99, 115, 99, 116, 99, 117, 99, 120, 99, 121, 99, 124, 99, 125, 99, 126, 99, 127, 99, 129, 99, 131, 99, 132, 99, 133, 99, 134, 99, 139, 99, 141, 99, 145, 99, 147, 99, 148, 99, 149, 99, 151, 99, 153, 99, 154, 99, 155, 99, 156, 99, 157, 99, 158, 99, 159, 99, 161, 99, 164, 99, 166, 99, 171, 99, 175, 99, 177, 99, 178, 99, 181, 99, 182, 99, 185, 99, 187, 99, 189, 99, 191, 99, 192, 99, 193, 99, 194, 99, 195, 99, 197, 99, 199, 99, 200, 99, 202, 99, 203, 99, 204, 99, 209, 99, 211, 99, 212, 99, 213, 99, 215, 99, 216, 99, 217, 99, 218, 99, 219, 99, 220, 99, 221, 99, 223, 99, 226, 99, 228, 99, 229, 99, 230, 99, 231, 99, 232, 99, 235, 99, 236, 99, 238, 99, 239, 99, 240, 99, 241, 99, 243, 99, 245, 99, 247, 99, 249, 99, 250, 99, 251, 99, 252, 99, 254, 99, 3, 100, 4, 100, 6, 100, 7, 100, 8, 100, 9, 100, 10, 100, 13, 100, 14, 100, 17, 100, 18, 100, 21, 100, 22, 100, 23, 100, 24, 100, 25, 100, 26, 100, 29, 100, 31, 100, 34, 100, 35, 100, 36, 100, 37, 100, 39, 100, 40, 100, 41, 100, 43, 100, 46, 100, 47, 100, 48, 100, 49, 100, 50, 100, 51, 100, 53, 100, 54, 100, 55, 100, 56, 100, 57, 100, 59, 100, 60, 100, 62, 100, 64, 100, 66, 100, 67, 100, 73, 100, 75, 100, 76, 100, 77, 100, 78, 100, 79, 100, 80, 100, 81, 100, 83, 100, 85, 100, 86, 100, 87, 100, 89, 100, 90, 100, 91, 100, 92, 100, 93, 100, 95, 100, 96, 100, 97, 100, 98, 100, 99, 100, 100, 100, 101, 100, 102, 100, 104, 100, 106, 100, 107, 100, 108, 100, 110, 100, 111, 100, 112, 100, 113, 100, 114, 100, 115, 100, 116, 100, 117, 100, 118, 100, 119, 100, 123, 100, 124, 100, 125, 100, 126, 100, 127, 100, 128, 100, 129, 100, 131, 100, 134, 100, 136, 100, 137, 100, 138, 100, 139, 100, 140, 100, 141, 100, 142, 100, 143, 100, 144, 100, 147, 100, 148, 100, 151, 100, 152, 100, 154, 100, 155, 100, 156, 100, 157, 100, 159, 100, 160, 100, 161, 100, 162, 100, 163, 100, 165, 100, 166, 100, 167, 100, 168, 100, 170, 100, 171, 100, 175, 100, 177, 100, 178, 100, 179, 100, 180, 100, 182, 100, 185, 100, 187, 100, 189, 100, 190, 100, 191, 100, 193, 100, 195, 100, 196, 100, 198, 100, 199, 100, 200, 100, 201, 100, 202, 100, 203, 100, 204, 100, 207, 100, 209, 100, 211, 100, 212, 100, 213, 100, 214, 100, 217, 100, 218, 100, 219, 100, 220, 100, 221, 100, 223, 100, 224, 100, 225, 100, 227, 100, 229, 100, 231, 100, 232, 100, 233, 100, 234, 100, 235, 100, 236, 100, 237, 100, 238, 100, 239, 100, 240, 100, 241, 100, 242, 100, 243, 100, 244, 100, 245, 100, 246, 100, 247, 100, 248, 100, 249, 100, 250, 100, 251, 100, 252, 100, 253, 100, 254, 100, 255, 100, 1, 101, 2, 101, 3, 101, 4, 101, 5, 101, 6, 101, 7, 101, 8, 101, 10, 101, 11, 101, 12, 101, 13, 101, 14, 101, 15, 101, 16, 101, 17, 101, 19, 101, 20, 101, 21, 101, 22, 101, 23, 101, 25, 101, 26, 101, 27, 101, 28, 101, 29, 101, 30, 101, 31, 101, 32, 101, 33, 101, 34, 101, 35, 101, 36, 101, 38, 101, 39, 101, 40, 101, 41, 101, 42, 101, 44, 101, 45, 101, 48, 101, 49, 101, 50, 101, 51, 101, 55, 101, 58, 101, 60, 101, 61, 101, 64, 101, 65, 101, 66, 101, 67, 101, 68, 101, 70, 101, 71, 101, 74, 101, 75, 101, 77, 101, 78, 101, 80, 101, 82, 101, 83, 101, 84, 101, 87, 101, 88, 101, 90, 101, 92, 101, 95, 101, 96, 101, 97, 101, 100, 101, 101, 101, 103, 101, 104, 101, 105, 101, 106, 101, 109, 101, 110, 101, 111, 101, 113, 101, 115, 101, 117, 101, 118, 101, 120, 101, 121, 101, 122, 101, 123, 101, 124, 101, 125, 101, 126, 101, 127, 101, 128, 101, 129, 101, 130, 101, 131, 101, 132, 101, 133, 101, 134, 101, 136, 101, 137, 101, 138, 101, 141, 101, 142, 101, 143, 101, 146, 101, 148, 101, 149, 101, 150, 101, 152, 101, 154, 101, 157, 101], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 220348);
	        allocate([158, 101, 160, 101, 162, 101, 163, 101, 166, 101, 168, 101, 170, 101, 172, 101, 174, 101, 177, 101, 178, 101, 179, 101, 180, 101, 181, 101, 182, 101, 183, 101, 184, 101, 186, 101, 187, 101, 190, 101, 191, 101, 192, 101, 194, 101, 199, 101, 200, 101, 201, 101, 202, 101, 205, 101, 208, 101, 209, 101, 211, 101, 212, 101, 213, 101, 216, 101, 217, 101, 218, 101, 219, 101, 220, 101, 221, 101, 222, 101, 223, 101, 225, 101, 227, 101, 228, 101, 234, 101, 235, 101, 242, 101, 243, 101, 244, 101, 245, 101, 248, 101, 249, 101, 251, 101, 252, 101, 253, 101, 254, 101, 255, 101, 1, 102, 4, 102, 5, 102, 7, 102, 8, 102, 9, 102, 11, 102, 13, 102, 16, 102, 17, 102, 18, 102, 22, 102, 23, 102, 24, 102, 26, 102, 27, 102, 28, 102, 30, 102, 33, 102, 34, 102, 35, 102, 36, 102, 38, 102, 41, 102, 42, 102, 43, 102, 44, 102, 46, 102, 48, 102, 50, 102, 51, 102, 55, 102, 56, 102, 57, 102, 58, 102, 59, 102, 61, 102, 63, 102, 64, 102, 66, 102, 68, 102, 69, 102, 70, 102, 71, 102, 72, 102, 73, 102, 74, 102, 77, 102, 78, 102, 80, 102, 81, 102, 88, 102, 89, 102, 91, 102, 92, 102, 93, 102, 94, 102, 96, 102, 98, 102, 99, 102, 101, 102, 103, 102, 105, 102, 106, 102, 107, 102, 108, 102, 109, 102, 113, 102, 114, 102, 115, 102, 117, 102, 120, 102, 121, 102, 123, 102, 124, 102, 125, 102, 127, 102, 128, 102, 129, 102, 131, 102, 133, 102, 134, 102, 136, 102, 137, 102, 138, 102, 139, 102, 141, 102, 142, 102, 143, 102, 144, 102, 146, 102, 147, 102, 148, 102, 149, 102, 152, 102, 153, 102, 154, 102, 155, 102, 156, 102, 158, 102, 159, 102, 160, 102, 161, 102, 162, 102, 163, 102, 164, 102, 165, 102, 166, 102, 169, 102, 170, 102, 171, 102, 172, 102, 173, 102, 175, 102, 176, 102, 177, 102, 178, 102, 179, 102, 181, 102, 182, 102, 183, 102, 184, 102, 186, 102, 187, 102, 188, 102, 189, 102, 191, 102, 192, 102, 193, 102, 194, 102, 195, 102, 196, 102, 197, 102, 198, 102, 199, 102, 200, 102, 201, 102, 202, 102, 203, 102, 204, 102, 205, 102, 206, 102, 207, 102, 208, 102, 209, 102, 210, 102, 211, 102, 212, 102, 213, 102, 214, 102, 215, 102, 216, 102, 218, 102, 222, 102, 223, 102, 224, 102, 225, 102, 226, 102, 227, 102, 228, 102, 229, 102, 231, 102, 232, 102, 234, 102, 235, 102, 236, 102, 237, 102, 238, 102, 239, 102, 241, 102, 245, 102, 246, 102, 248, 102, 250, 102, 251, 102, 253, 102, 1, 103, 2, 103, 3, 103, 4, 103, 5, 103, 6, 103, 7, 103, 12, 103, 14, 103, 15, 103, 17, 103, 18, 103, 19, 103, 22, 103, 24, 103, 25, 103, 26, 103, 28, 103, 30, 103, 32, 103, 33, 103, 34, 103, 35, 103, 36, 103, 37, 103, 39, 103, 41, 103, 46, 103, 48, 103, 50, 103, 51, 103, 54, 103, 55, 103, 56, 103, 57, 103, 59, 103, 60, 103, 62, 103, 63, 103, 65, 103, 68, 103, 69, 103, 71, 103, 74, 103, 75, 103, 77, 103, 82, 103, 84, 103, 85, 103, 87, 103, 88, 103, 89, 103, 90, 103, 91, 103, 93, 103, 98, 103, 99, 103, 100, 103, 102, 103, 103, 103, 107, 103, 108, 103, 110, 103, 113, 103, 116, 103, 118, 103, 120, 103, 121, 103, 122, 103, 123, 103, 125, 103, 128, 103, 130, 103, 131, 103, 133, 103, 134, 103, 136, 103, 138, 103, 140, 103, 141, 103, 142, 103, 143, 103, 145, 103, 146, 103, 147, 103, 148, 103, 150, 103, 153, 103, 155, 103, 159, 103, 160, 103, 161, 103, 164, 103, 166, 103, 169, 103, 172, 103, 174, 103, 177, 103, 178, 103, 180, 103, 185, 103, 186, 103, 187, 103, 188, 103, 189, 103, 190, 103, 191, 103, 192, 103, 194, 103, 197, 103, 198, 103, 199, 103, 200, 103, 201, 103, 202, 103, 203, 103, 204, 103, 205, 103, 206, 103, 213, 103, 214, 103, 215, 103, 219, 103, 223, 103, 225, 103, 227, 103, 228, 103, 230, 103, 231, 103, 232, 103, 234, 103, 235, 103, 237, 103, 238, 103, 242, 103, 245, 103, 246, 103, 247, 103, 248, 103, 249, 103, 250, 103, 251, 103, 252, 103, 254, 103, 1, 104, 2, 104, 3, 104, 4, 104, 6, 104, 13, 104, 16, 104, 18, 104, 20, 104, 21, 104, 24, 104, 25, 104, 26, 104, 27, 104, 28, 104, 30, 104, 31, 104, 32, 104, 34, 104, 35, 104, 36, 104, 37, 104, 38, 104, 39, 104, 40, 104, 43, 104, 44, 104, 45, 104, 46, 104, 47, 104, 48, 104, 49, 104, 52, 104, 53, 104, 54, 104, 58, 104, 59, 104, 63, 104, 71, 104, 75, 104, 77, 104, 79, 104, 82, 104, 86, 104, 87, 104, 88, 104, 89, 104, 90, 104, 91, 104, 92, 104, 93, 104, 94, 104, 95, 104, 106, 104, 108, 104, 109, 104, 110, 104, 111, 104, 112, 104, 113, 104, 114, 104, 115, 104, 117, 104, 120, 104, 121, 104, 122, 104, 123, 104, 124, 104, 125, 104, 126, 104, 127, 104, 128, 104, 130, 104, 132, 104, 135, 104, 136, 104, 137, 104, 138, 104, 139, 104, 140, 104, 141, 104, 142, 104, 144, 104, 145, 104, 146, 104, 148, 104, 149, 104, 150, 104, 152, 104, 153, 104, 154, 104, 155, 104, 156, 104, 157, 104, 158, 104, 159, 104, 160, 104, 161, 104, 163, 104, 164, 104, 165, 104, 169, 104, 170, 104, 171, 104, 172, 104, 174, 104, 177, 104, 178, 104, 180, 104, 182, 104, 183, 104, 184, 104, 185, 104, 186, 104, 187, 104, 188, 104, 189, 104, 190, 104, 191, 104, 193, 104, 195, 104, 196, 104, 197, 104, 198, 104, 199, 104, 200, 104, 202, 104, 204, 104, 206, 104, 207, 104, 208, 104, 209, 104, 211, 104, 212, 104, 214, 104, 215, 104, 217, 104, 219, 104, 220, 104, 221, 104, 222, 104, 223, 104, 225, 104, 226, 104, 228, 104, 229, 104, 230, 104, 231, 104, 232, 104, 233, 104, 234, 104, 235, 104, 236, 104, 237, 104, 239, 104, 242, 104, 243, 104, 244, 104, 246, 104, 247, 104, 248, 104, 251, 104, 253, 104, 254, 104, 255, 104, 0, 105, 2, 105, 3, 105, 4, 105, 6, 105, 7, 105, 8, 105, 9, 105, 10, 105, 12, 105, 15, 105, 17, 105, 19, 105, 20, 105, 21, 105, 22, 105, 23, 105, 24, 105, 25, 105, 26, 105, 27, 105, 28, 105, 29, 105, 30, 105, 33, 105, 34, 105, 35, 105, 37, 105, 38, 105, 39, 105, 40, 105, 41, 105, 42, 105, 43, 105, 44, 105, 46, 105, 47, 105, 49, 105, 50, 105, 51, 105, 53, 105, 54, 105, 55, 105, 56, 105, 58, 105, 59, 105, 60, 105, 62, 105, 64, 105, 65, 105, 67, 105, 68, 105, 69, 105, 70, 105, 71, 105, 72, 105, 73, 105, 74, 105, 75, 105, 76, 105, 77, 105, 78, 105, 79, 105, 80, 105, 81, 105, 82, 105, 83, 105, 85, 105, 86, 105, 88, 105, 89, 105, 91, 105, 92, 105, 95, 105, 97, 105, 98, 105, 100, 105, 101, 105, 103, 105, 104, 105, 105, 105, 106, 105, 108, 105, 109, 105, 111, 105, 112, 105, 114, 105, 115, 105, 116, 105, 117, 105, 118, 105, 122, 105, 123, 105, 125, 105, 126, 105, 127, 105, 129, 105, 131, 105, 133, 105, 138, 105, 139, 105, 140, 105, 142, 105, 143, 105, 144, 105, 145, 105, 146, 105, 147, 105, 150, 105, 151, 105, 153, 105, 154, 105, 157, 105, 158, 105, 159, 105, 160, 105, 161, 105, 162, 105, 163, 105, 164, 105, 165, 105, 166, 105, 169, 105, 170, 105, 172, 105, 174, 105, 175, 105, 176, 105, 178, 105, 179, 105, 181, 105, 182, 105, 184, 105, 185, 105, 186, 105, 188, 105, 189, 105, 190, 105, 191, 105, 192, 105, 194, 105, 195, 105, 196, 105, 197, 105, 198, 105, 199, 105, 200, 105, 201, 105, 203, 105, 205, 105, 207, 105, 209, 105, 210, 105, 211, 105, 213, 105, 214, 105, 215, 105, 216, 105, 217, 105, 218, 105, 220, 105, 221, 105, 222, 105, 225, 105, 226, 105, 227, 105, 228, 105, 229, 105, 230, 105, 231, 105, 232, 105, 233, 105, 234, 105, 235, 105, 236, 105, 238, 105, 239, 105, 240, 105, 241, 105, 243, 105, 244, 105, 245, 105, 246, 105, 247, 105, 248, 105, 249, 105, 250, 105, 251, 105, 252, 105, 254, 105, 0, 106, 1, 106, 2, 106, 3, 106, 4, 106, 5, 106, 6, 106, 7, 106, 8, 106, 9, 106, 11, 106, 12, 106, 13, 106, 14, 106, 15, 106, 16, 106, 17, 106, 18, 106, 19, 106, 20, 106, 21, 106, 22, 106, 25, 106, 26, 106, 27, 106, 28, 106, 29, 106, 30, 106, 32, 106, 34, 106, 35, 106, 36, 106, 37, 106, 38, 106, 39, 106, 41, 106, 43, 106, 44, 106, 45, 106, 46, 106, 48, 106, 50, 106, 51, 106, 52, 106, 54, 106, 55, 106, 56, 106, 57, 106, 58, 106, 59, 106, 60, 106, 63, 106, 64, 106, 65, 106, 66, 106, 67, 106, 69, 106, 70, 106, 72, 106, 73, 106, 74, 106, 75, 106, 76, 106, 77, 106, 78, 106, 79, 106, 81, 106, 82, 106, 83, 106, 84, 106, 85, 106, 86, 106, 87, 106, 90, 106, 92, 106, 93, 106, 94, 106, 95, 106, 96, 106, 98, 106, 99, 106, 100, 106, 102, 106, 103, 106, 104, 106, 105, 106, 106, 106, 107, 106, 108, 106, 109, 106, 110, 106, 111, 106, 112, 106, 114, 106, 115, 106, 116, 106, 117, 106, 118, 106, 119, 106, 120, 106, 122, 106, 123, 106, 125, 106, 126, 106, 127, 106, 129, 106, 130, 106, 131, 106, 133, 106, 134, 106, 135, 106, 136, 106, 137, 106, 138, 106, 139, 106, 140, 106, 141, 106, 143, 106, 146, 106, 147, 106, 148, 106, 149, 106, 150, 106, 152, 106, 153, 106, 154, 106, 155, 106, 156, 106, 157, 106, 158, 106, 159, 106, 161, 106, 162, 106, 163, 106, 164, 106, 165, 106, 166, 106, 167, 106, 168, 106, 170, 106, 173, 106, 174, 106, 175, 106, 176, 106, 177, 106, 178, 106, 179, 106, 180, 106, 181, 106, 182, 106, 183, 106, 184, 106, 185, 106, 186, 106, 187, 106, 188, 106, 189, 106, 190, 106, 191, 106, 192, 106, 193, 106, 194, 106, 195, 106, 196, 106, 197, 106, 198, 106, 199, 106, 200, 106, 201, 106, 202, 106, 203, 106, 204, 106, 205, 106, 206, 106, 207, 106, 208, 106, 209, 106, 210, 106, 211, 106, 212, 106, 213, 106, 214, 106, 215, 106, 216, 106, 217, 106, 218, 106, 219, 106, 220, 106, 221, 106, 222, 106, 223, 106, 224, 106, 225, 106, 226, 106, 227, 106, 228, 106, 229, 106, 230, 106, 231, 106, 232, 106, 233, 106, 234, 106, 235, 106, 236, 106, 237, 106, 238, 106, 239, 106, 240, 106, 241, 106, 242, 106, 243, 106, 244, 106, 245, 106, 246, 106, 247, 106, 248, 106, 249, 106, 250, 106, 251, 106, 252, 106, 253, 106, 254, 106, 255, 106, 0, 107, 1, 107, 2, 107, 3, 107, 4, 107, 5, 107, 6, 107, 7, 107, 8, 107, 9, 107, 10, 107, 11, 107, 12, 107, 13, 107, 14, 107, 15, 107, 16, 107, 17, 107, 18, 107, 19, 107, 20, 107, 21, 107, 22, 107, 23, 107, 24, 107, 25, 107, 26, 107, 27, 107, 28, 107, 29, 107, 30, 107, 31, 107, 37, 107, 38, 107, 40, 107, 41, 107, 42, 107, 43, 107, 44, 107, 45, 107, 46, 107, 47, 107, 48, 107, 49, 107, 51, 107, 52, 107, 53, 107, 54, 107, 56, 107, 59, 107, 60, 107, 61, 107, 63, 107, 64, 107, 65, 107, 66, 107, 68, 107, 69, 107, 72, 107, 74, 107, 75, 107, 77, 107, 78, 107, 79, 107, 80, 107, 81, 107, 82, 107, 83, 107, 84, 107, 85, 107, 86, 107, 87, 107, 88, 107, 90, 107, 91, 107, 92, 107, 93, 107, 94, 107, 95, 107, 96, 107, 97, 107, 104, 107, 105, 107, 107, 107, 108, 107, 109, 107, 110, 107, 111, 107, 112, 107, 113, 107, 114, 107, 115, 107, 116, 107, 117, 107, 118, 107, 119, 107, 120, 107, 122, 107, 125, 107, 126, 107, 127, 107, 128, 107, 133, 107, 136, 107, 140, 107, 142, 107, 143, 107, 144, 107, 145, 107, 148, 107, 149, 107, 151, 107, 152, 107, 153, 107, 156, 107, 157, 107, 158, 107, 159, 107, 160, 107, 162, 107, 163, 107, 164, 107, 165, 107, 166, 107, 167, 107, 168, 107, 169, 107, 171, 107, 172, 107, 173, 107, 174, 107, 175, 107, 176, 107, 177, 107, 178, 107, 182, 107, 184, 107, 185, 107, 186, 107, 187, 107, 188, 107, 189, 107, 190, 107, 192, 107, 195, 107, 196, 107, 198, 107, 199, 107, 200, 107, 201, 107, 202, 107, 204, 107, 206, 107, 208, 107, 209, 107, 216, 107, 218, 107, 220, 107, 221, 107, 222, 107, 223, 107, 224, 107, 226, 107, 227, 107, 228, 107, 229, 107, 230, 107, 231, 107, 232, 107, 233, 107, 236, 107, 237, 107, 238, 107, 240, 107, 241, 107, 242, 107, 244, 107, 246, 107, 247, 107, 248, 107, 250, 107, 251, 107, 252, 107, 254, 107, 255, 107, 0, 108, 1, 108, 2, 108, 3, 108, 4, 108, 8, 108, 9, 108, 10, 108, 11, 108, 12, 108, 14, 108, 18, 108, 23, 108, 28, 108, 29, 108, 30, 108, 32, 108, 35, 108, 37, 108, 43, 108, 44, 108, 45, 108, 49, 108, 51, 108, 54, 108, 55, 108, 57, 108, 58, 108, 59, 108, 60, 108, 62, 108, 63, 108, 67, 108, 68, 108, 69, 108, 72, 108, 75, 108, 76, 108, 77, 108, 78, 108, 79, 108, 81, 108, 82, 108, 83, 108, 86, 108, 88, 108, 89, 108, 90, 108, 98, 108, 99, 108, 101, 108, 102, 108, 103, 108, 107, 108, 108, 108, 109, 108, 110, 108, 111, 108, 113, 108, 115, 108, 117, 108, 119, 108, 120, 108, 122, 108, 123, 108, 124, 108, 127, 108, 128, 108, 132, 108, 135, 108, 138, 108, 139, 108, 141, 108, 142, 108, 145, 108, 146, 108, 149, 108, 150, 108, 151, 108, 152, 108, 154, 108, 156, 108, 157, 108, 158, 108, 160, 108, 162, 108, 168, 108, 172, 108, 175, 108, 176, 108, 180, 108, 181, 108, 182, 108, 183, 108, 186, 108, 192, 108, 193, 108, 194, 108, 195, 108, 198, 108, 199, 108, 200, 108, 203, 108, 205, 108, 206, 108, 207, 108, 209, 108, 210, 108, 216, 108, 217, 108, 218, 108, 220, 108, 221, 108, 223, 108, 228, 108, 230, 108, 231, 108, 233, 108, 236, 108, 237, 108, 242, 108, 244, 108, 249, 108, 255, 108, 0, 109, 2, 109, 3, 109, 5, 109, 6, 109, 8, 109, 9, 109, 10, 109, 13, 109, 15, 109, 16, 109, 17, 109, 19, 109, 20, 109, 21, 109, 22, 109, 24, 109, 28, 109, 29, 109, 31, 109, 32, 109, 33, 109, 34, 109, 35, 109, 36, 109, 38, 109, 40, 109, 41, 109, 44, 109, 45, 109, 47, 109, 48, 109, 52, 109, 54, 109, 55, 109, 56, 109, 58, 109, 63, 109, 64, 109, 66, 109, 68, 109, 73, 109, 76, 109, 80, 109, 85, 109, 86, 109, 87, 109, 88, 109, 91, 109, 93, 109, 95, 109, 97, 109, 98, 109, 100, 109, 101, 109, 103, 109, 104, 109, 107, 109, 108, 109, 109, 109, 112, 109, 113, 109, 114, 109, 115, 109, 117, 109, 118, 109, 121, 109, 122, 109, 123, 109, 125, 109, 126, 109, 127, 109, 128, 109, 129, 109, 131, 109, 132, 109, 134, 109, 135, 109, 138, 109, 139, 109, 141, 109, 143, 109, 144, 109, 146, 109, 150, 109, 151, 109, 152, 109, 153, 109, 154, 109, 156, 109, 162, 109, 165, 109, 172, 109, 173, 109, 176, 109, 177, 109, 179, 109, 180, 109, 182, 109, 183, 109, 185, 109, 186, 109, 187, 109, 188, 109, 189, 109, 190, 109, 193, 109, 194, 109, 195, 109, 200, 109, 201, 109, 202, 109, 205, 109, 206, 109, 207, 109, 208, 109, 210, 109, 211, 109, 212, 109, 213, 109, 215, 109, 218, 109, 219, 109, 220, 109, 223, 109, 226, 109, 227, 109, 229, 109, 231, 109, 232, 109, 233, 109, 234, 109, 237, 109, 239, 109, 240, 109, 242, 109, 244, 109, 245, 109, 246, 109, 248, 109, 250, 109, 253, 109, 254, 109, 255, 109, 0, 110, 1, 110, 2, 110, 3, 110, 4, 110, 6, 110, 7, 110, 8, 110, 9, 110, 11, 110, 15, 110, 18, 110, 19, 110, 21, 110, 24, 110, 25, 110, 27, 110, 28, 110, 30, 110, 31, 110, 34, 110, 38, 110, 39, 110, 40, 110, 42, 110, 44, 110, 46, 110, 48, 110, 49, 110, 51, 110, 53, 110, 54, 110, 55, 110, 57, 110, 59, 110, 60, 110, 61, 110, 62, 110, 63, 110, 64, 110, 65, 110, 66, 110, 69, 110, 70, 110, 71, 110, 72, 110, 73, 110, 74, 110, 75, 110, 76, 110, 79, 110, 80, 110, 81, 110, 82, 110, 85, 110, 87, 110, 89, 110, 90, 110, 92, 110, 93, 110, 94, 110, 96, 110, 97, 110, 98, 110, 99, 110, 100, 110, 101, 110, 102, 110, 103, 110, 104, 110, 105, 110, 106, 110, 108, 110, 109, 110, 111, 110, 112, 110, 113, 110, 114, 110, 115, 110, 116, 110, 117, 110, 118, 110, 119, 110, 120, 110, 121, 110, 122, 110, 123, 110, 124, 110, 125, 110, 128, 110, 129, 110, 130, 110, 132, 110, 135, 110, 136, 110, 138, 110, 139, 110, 140, 110, 141, 110, 142, 110, 145, 110, 146, 110, 147, 110, 148, 110, 149, 110, 150, 110, 151, 110, 153, 110, 154, 110, 155, 110, 157, 110, 158, 110, 160, 110, 161, 110, 163, 110, 164, 110, 166, 110, 168, 110, 169, 110, 171, 110, 172, 110, 173, 110, 174, 110, 176, 110, 179, 110, 181, 110, 184, 110, 185, 110, 188, 110, 190, 110, 191, 110, 192, 110, 195, 110, 196, 110, 197, 110, 198, 110, 200, 110, 201, 110, 202, 110, 204, 110, 205, 110, 206, 110, 208, 110, 210, 110, 214, 110, 216, 110, 217, 110, 219, 110, 220, 110, 221, 110, 227, 110, 231, 110, 234, 110, 235, 110, 236, 110, 237, 110, 238, 110, 239, 110, 240, 110, 241, 110, 242, 110, 243, 110, 245, 110, 246, 110, 247, 110, 248, 110, 250, 110, 251, 110, 252, 110, 253, 110, 254, 110, 255, 110, 0, 111, 1, 111, 3, 111, 4, 111, 5, 111, 7, 111, 8, 111, 10, 111, 11, 111, 12, 111, 13, 111, 14, 111, 16, 111, 17, 111, 18, 111, 22, 111, 23, 111, 24, 111, 25, 111, 26, 111, 27, 111, 28, 111, 29, 111, 30, 111, 31, 111, 33, 111, 34, 111, 35, 111, 37, 111, 38, 111, 39, 111, 40, 111, 44, 111, 46, 111, 48, 111, 50, 111, 52, 111, 53, 111, 55, 111, 56, 111, 57, 111, 58, 111, 59, 111, 60, 111, 61, 111, 63, 111, 64, 111, 65, 111, 66, 111, 67, 111, 68, 111, 69, 111, 72, 111, 73, 111, 74, 111, 76, 111, 78, 111, 79, 111, 80, 111, 81, 111, 82, 111, 83, 111, 84, 111, 85, 111, 86, 111, 87, 111, 89, 111, 90, 111, 91, 111, 93, 111, 95, 111, 96, 111, 97, 111, 99, 111, 100, 111, 101, 111, 103, 111, 104, 111, 105, 111, 106, 111, 107, 111, 108, 111, 111, 111, 112, 111, 113, 111, 115, 111, 117, 111, 118, 111, 119, 111, 121, 111, 123, 111, 125, 111, 126, 111, 127, 111, 128, 111, 129, 111, 130, 111, 131, 111, 133, 111, 134, 111, 135, 111, 138, 111, 139, 111, 143, 111, 144, 111, 145, 111, 146, 111, 147, 111, 148, 111, 149, 111, 150, 111, 151, 111, 152, 111, 153, 111, 154, 111, 155, 111, 157, 111, 158, 111, 159, 111, 160, 111, 162, 111, 163, 111, 164, 111, 165, 111, 166, 111, 168, 111, 169, 111, 170, 111, 171, 111, 172, 111, 173, 111, 174, 111, 175, 111, 176, 111, 177, 111, 178, 111, 180, 111, 181, 111, 183, 111, 184, 111, 186, 111, 187, 111, 188, 111, 189, 111, 190, 111, 191, 111, 193, 111, 195, 111, 196, 111, 197, 111, 198, 111, 199, 111, 200, 111, 202, 111, 203, 111, 204, 111, 205, 111, 206, 111, 207, 111, 208, 111, 211, 111, 212, 111, 213, 111, 214, 111, 215, 111, 216, 111, 217, 111, 218, 111, 219, 111, 220, 111, 221, 111, 223, 111, 226, 111, 227, 111, 228, 111, 229, 111, 230, 111, 231, 111, 232, 111, 233, 111, 234, 111, 235, 111, 236, 111, 237, 111, 240, 111, 241, 111, 242, 111, 243, 111, 244, 111, 245, 111, 246, 111, 247, 111, 248, 111, 249, 111, 250, 111, 251, 111, 252, 111, 253, 111, 254, 111, 255, 111, 0, 112, 1, 112, 2, 112, 3, 112, 4, 112, 5, 112, 6, 112, 7, 112, 8, 112, 9, 112, 10, 112, 11, 112, 12, 112, 13, 112, 14, 112, 15, 112, 16, 112, 18, 112, 19, 112, 20, 112, 21, 112, 22, 112, 23, 112, 24, 112, 25, 112, 28, 112, 29, 112, 30, 112, 31, 112, 32, 112, 33, 112, 34, 112, 36, 112, 37, 112, 38, 112, 39, 112, 40, 112, 41, 112, 42, 112, 43, 112, 44, 112, 45, 112, 46, 112, 47, 112, 48, 112, 49, 112, 50, 112, 51, 112, 52, 112, 54, 112, 55, 112, 56, 112, 58, 112, 59, 112, 60, 112, 61, 112, 62, 112, 63, 112, 64, 112, 65, 112, 66, 112, 67, 112, 68, 112, 69, 112, 70, 112, 71, 112, 72, 112, 73, 112, 74, 112, 75, 112, 77, 112, 78, 112, 80, 112, 81, 112, 82, 112, 83, 112, 84, 112, 85, 112, 86, 112, 87, 112, 88, 112, 89, 112, 90, 112, 91, 112, 92, 112, 93, 112, 95, 112, 96, 112, 97, 112, 98, 112, 99, 112, 100, 112, 101, 112, 102, 112, 103, 112, 104, 112, 105, 112, 106, 112, 110, 112, 113, 112, 114, 112, 115, 112, 116, 112, 119, 112, 121, 112, 122, 112, 123, 112, 125, 112, 129, 112, 130, 112, 131, 112, 132, 112, 134, 112, 135, 112, 136, 112, 139, 112, 140, 112, 141, 112, 143, 112, 144, 112, 145, 112, 147, 112, 151, 112, 152, 112, 154, 112, 155, 112, 158, 112, 159, 112, 160, 112, 161, 112, 162, 112, 163, 112, 164, 112, 165, 112, 166, 112, 167, 112, 168, 112, 169, 112, 170, 112, 176, 112, 178, 112, 180, 112, 181, 112, 182, 112, 186, 112, 190, 112, 191, 112, 196, 112, 197, 112, 198, 112, 199, 112, 201, 112, 203, 112, 204, 112, 205, 112, 206, 112, 207, 112, 208, 112, 209, 112, 210, 112, 211, 112, 212, 112, 213, 112, 214, 112, 215, 112, 218, 112, 220, 112, 221, 112, 222, 112, 224, 112, 225, 112, 226, 112, 227, 112, 229, 112, 234, 112, 238, 112, 240, 112, 241, 112, 242, 112, 243, 112, 244, 112, 245, 112, 246, 112, 248, 112, 250, 112, 251, 112, 252, 112, 254, 112, 255, 112, 0, 113, 1, 113, 2, 113, 3, 113, 4, 113, 5, 113, 6, 113, 7, 113, 8, 113, 11, 113, 12, 113, 13, 113, 14, 113, 15, 113, 17, 113, 18, 113, 20, 113, 23, 113, 27, 113, 28, 113, 29, 113, 30, 113, 31, 113, 32, 113, 33, 113, 34, 113, 35, 113, 36, 113, 37, 113, 39, 113, 40, 113, 41, 113, 42, 113, 43, 113, 44, 113, 45, 113, 46, 113, 50, 113, 51, 113, 52, 113, 53, 113, 55, 113, 56, 113, 57, 113, 58, 113, 59, 113, 60, 113, 61, 113, 62, 113, 63, 113, 64, 113, 65, 113, 66, 113, 67, 113, 68, 113, 70, 113, 71, 113, 72, 113, 73, 113, 75, 113, 77, 113, 79, 113, 80, 113, 81, 113, 82, 113, 83, 113, 84, 113, 85, 113, 86, 113, 87, 113, 88, 113, 89, 113, 90, 113, 91, 113, 93, 113, 95, 113, 96, 113, 97, 113, 98, 113, 99, 113, 101, 113, 105, 113, 106, 113, 107, 113, 108, 113, 109, 113, 111, 113, 112, 113, 113, 113, 116, 113, 117, 113, 118, 113, 119, 113, 121, 113, 123, 113, 124, 113, 126, 113, 127, 113, 128, 113, 129, 113, 130, 113, 131, 113, 133, 113, 134, 113, 135, 113, 136, 113, 137, 113, 139, 113, 140, 113, 141, 113, 142, 113, 144, 113, 145, 113, 146, 113, 147, 113, 149, 113, 150, 113, 151, 113, 154, 113, 155, 113, 156, 113, 157, 113, 158, 113, 161, 113, 162, 113, 163, 113, 164, 113, 165, 113, 166, 113, 167, 113, 169, 113, 170, 113, 171, 113, 173, 113, 174, 113, 175, 113, 176, 113, 177, 113, 178, 113, 180, 113, 182, 113, 183, 113, 184, 113, 186, 113, 187, 113, 188, 113, 189, 113, 190, 113, 191, 113, 192, 113, 193, 113, 194, 113, 196, 113, 197, 113, 198, 113, 199, 113, 200, 113, 201, 113, 202, 113, 203, 113, 204, 113, 205, 113, 207, 113, 208, 113, 209, 113, 210, 113, 211, 113, 214, 113, 215, 113, 216, 113, 217, 113, 218, 113, 219, 113, 220, 113, 221, 113, 222, 113, 223, 113, 225, 113, 226, 113, 227, 113, 228, 113, 230, 113, 232, 113, 233, 113, 234, 113, 235, 113, 236, 113, 237, 113, 239, 113, 240, 113, 241, 113, 242, 113, 243, 113, 244, 113, 245, 113, 246, 113, 247, 113, 248, 113, 250, 113, 251, 113, 252, 113, 253, 113, 254, 113, 255, 113, 0, 114, 1, 114, 2, 114, 3, 114, 4, 114, 5, 114, 7, 114, 8, 114, 9, 114, 10, 114, 11, 114, 12, 114, 13, 114, 14, 114, 15, 114, 16, 114, 17, 114, 18, 114, 19, 114, 20, 114, 21, 114, 22, 114, 23, 114, 24, 114, 25, 114, 26, 114, 27, 114, 28, 114, 30, 114, 31, 114, 32, 114, 33, 114, 34, 114, 35, 114, 36, 114, 37, 114, 38, 114, 39, 114, 41, 114, 43, 114, 45, 114, 46, 114, 47, 114, 50, 114, 51, 114, 52, 114, 58, 114, 60, 114, 62, 114, 64, 114, 65, 114, 66, 114, 67, 114, 68, 114, 69, 114, 70, 114, 73, 114, 74, 114, 75, 114, 78, 114, 79, 114, 80, 114, 81, 114, 83, 114, 84, 114, 85, 114, 87, 114, 88, 114, 90, 114, 92, 114, 94, 114, 96, 114, 99, 114, 100, 114, 101, 114, 104, 114, 106, 114, 107, 114, 108, 114, 109, 114, 112, 114, 113, 114, 115, 114, 116, 114, 118, 114, 119, 114, 120, 114, 123, 114, 124, 114, 125, 114, 130, 114, 131, 114, 133, 114, 134, 114, 135, 114, 136, 114, 137, 114, 140, 114, 142, 114, 144, 114, 145, 114, 147, 114, 148, 114, 149, 114, 150, 114, 151, 114, 152, 114, 153, 114, 154, 114, 155, 114, 156, 114, 157, 114, 158, 114, 160, 114, 161, 114, 162, 114, 163, 114, 164, 114, 165, 114, 166, 114, 167, 114, 168, 114, 169, 114, 170, 114, 171, 114, 174, 114, 177, 114, 178, 114, 179, 114, 181, 114, 186, 114, 187, 114, 188, 114, 189, 114, 190, 114, 191, 114, 192, 114, 197, 114, 198, 114, 199, 114, 201, 114, 202, 114, 203, 114, 204, 114, 207, 114, 209, 114, 211, 114, 212, 114, 213, 114, 214, 114, 216, 114, 218, 114, 219, 114, 198, 228, 199, 228, 200, 228, 201, 228, 202, 228, 203, 228, 204, 228, 205, 228, 206, 228, 207, 228, 208, 228, 209, 228, 210, 228, 211, 228, 212, 228, 213, 228, 214, 228, 215, 228, 216, 228, 217, 228, 218, 228, 219, 228, 220, 228, 221, 228, 222, 228, 223, 228, 224, 228, 225, 228, 226, 228, 227, 228, 228, 228, 229, 228, 230, 228, 231, 228, 232, 228, 233, 228, 234, 228, 235, 228, 236, 228, 237, 228, 238, 228, 239, 228, 240, 228, 241, 228, 242, 228, 243, 228, 244, 228, 245, 228, 246, 228, 247, 228, 248, 228, 249, 228, 250, 228, 251, 228, 252, 228, 253, 228, 254, 228, 255, 228, 0, 229, 1, 229, 2, 229, 3, 229, 4, 229, 5, 229, 6, 229, 7, 229, 8, 229, 9, 229, 10, 229, 11, 229, 12, 229, 13, 229, 14, 229, 15, 229, 16, 229, 17, 229, 18, 229, 19, 229, 20, 229, 21, 229, 22, 229, 23, 229, 24, 229, 25, 229, 26, 229, 27, 229, 28, 229, 29, 229, 30, 229, 31, 229, 32, 229, 33, 229, 34, 229, 35, 229, 36, 229, 37, 229, 0, 48, 1, 48, 2, 48, 183, 0, 201, 2, 199, 2, 168, 0, 3, 48, 5, 48, 20, 32, 94, 255, 22, 32, 38, 32, 24, 32, 25, 32, 28, 32, 29, 32, 20, 48, 21, 48, 8, 48, 9, 48, 10, 48, 11, 48, 12, 48, 13, 48, 14, 48, 15, 48, 22, 48, 23, 48, 16, 48, 17, 48, 177, 0, 215, 0, 247, 0, 54, 34, 39, 34, 40, 34, 17, 34, 15, 34, 42, 34, 41, 34, 8, 34, 55, 34, 26, 34, 165, 34, 37, 34, 32, 34, 18, 35, 153, 34, 43, 34, 46, 34, 97, 34, 76, 34, 72, 34, 61, 34, 29, 34, 96, 34, 110, 34, 111, 34, 100, 34, 101, 34, 30, 34, 53, 34, 52, 34, 66, 38, 64, 38, 176, 0, 50, 32, 51, 32, 3, 33, 4, 255, 164, 0, 224, 255, 225, 255, 48, 32, 167, 0, 22, 33, 6, 38, 5, 38, 203, 37, 207, 37, 206, 37, 199, 37, 198, 37, 161, 37, 160, 37, 179, 37, 178, 37, 59, 32, 146, 33, 144, 33, 145, 33, 147, 33, 19, 48, 38, 229, 39, 229, 40, 229, 41, 229, 42, 229, 43, 229, 44, 229, 45, 229, 46, 229, 47, 229, 48, 229, 49, 229, 50, 229, 51, 229, 52, 229, 53, 229, 54, 229, 55, 229, 56, 229, 57, 229, 58, 229, 59, 229, 60, 229, 61, 229, 62, 229, 63, 229, 64, 229, 65, 229, 66, 229, 67, 229, 68, 229, 69, 229, 70, 229, 71, 229, 72, 229, 73, 229, 74, 229, 75, 229, 76, 229, 77, 229, 78, 229, 79, 229, 80, 229, 81, 229, 82, 229, 83, 229, 84, 229, 85, 229, 86, 229, 87, 229, 88, 229, 89, 229, 90, 229, 91, 229, 92, 229, 93, 229, 94, 229, 95, 229, 96, 229, 97, 229, 98, 229, 99, 229, 100, 229, 101, 229, 102, 229, 103, 229, 104, 229, 105, 229, 106, 229, 107, 229, 108, 229, 109, 229, 110, 229, 111, 229, 112, 229, 113, 229, 114, 229, 115, 229, 116, 229, 117, 229, 118, 229, 119, 229, 120, 229, 121, 229, 122, 229, 123, 229, 124, 229, 125, 229, 126, 229, 127, 229, 128, 229, 129, 229, 130, 229, 131, 229, 132, 229, 133, 229, 112, 33, 113, 33, 114, 33, 115, 33, 116, 33, 117, 33, 118, 33, 119, 33, 120, 33, 121, 33, 102, 231, 103, 231, 104, 231, 105, 231, 106, 231, 107, 231, 136, 36, 137, 36, 138, 36, 139, 36, 140, 36, 141, 36, 142, 36, 143, 36, 144, 36, 145, 36, 146, 36, 147, 36, 148, 36, 149, 36, 150, 36, 151, 36, 152, 36, 153, 36, 154, 36, 155, 36, 116, 36, 117, 36, 118, 36, 119, 36, 120, 36, 121, 36, 122, 36, 123, 36, 124, 36, 125, 36, 126, 36, 127, 36, 128, 36, 129, 36, 130, 36, 131, 36, 132, 36, 133, 36, 134, 36, 135, 36, 96, 36, 97, 36, 98, 36, 99, 36, 100, 36, 101, 36, 102, 36, 103, 36, 104, 36, 105, 36, 172, 32, 109, 231, 32, 50, 33, 50, 34, 50, 35, 50, 36, 50, 37, 50, 38, 50, 39, 50, 40, 50, 41, 50, 110, 231, 111, 231, 96, 33, 97, 33, 98, 33, 99, 33, 100, 33, 101, 33, 102, 33, 103, 33, 104, 33, 105, 33, 106, 33, 107, 33, 112, 231, 113, 231, 134, 229, 135, 229, 136, 229, 137, 229, 138, 229, 139, 229, 140, 229, 141, 229, 142, 229, 143, 229, 144, 229, 145, 229, 146, 229, 147, 229, 148, 229, 149, 229, 150, 229, 151, 229, 152, 229, 153, 229, 154, 229, 155, 229, 156, 229, 157, 229, 158, 229, 159, 229, 160, 229, 161, 229, 162, 229, 163, 229, 164, 229, 165, 229, 166, 229, 167, 229, 168, 229, 169, 229, 170, 229, 171, 229, 172, 229, 173, 229, 174, 229, 175, 229, 176, 229, 177, 229, 178, 229, 179, 229, 180, 229, 181, 229, 182, 229, 183, 229, 184, 229, 185, 229, 186, 229, 187, 229, 188, 229, 189, 229, 190, 229, 191, 229, 192, 229, 193, 229, 194, 229, 195, 229, 196, 229, 197, 229, 198, 229, 199, 229, 200, 229, 201, 229, 202, 229, 203, 229, 204, 229, 205, 229, 206, 229, 207, 229, 208, 229, 209, 229, 210, 229, 211, 229, 212, 229, 213, 229, 214, 229, 215, 229, 216, 229, 217, 229, 218, 229, 219, 229, 220, 229, 221, 229, 222, 229, 223, 229, 224, 229, 225, 229, 226, 229, 227, 229, 228, 229, 229, 229, 1, 255, 2, 255, 3, 255, 229, 255, 5, 255, 6, 255, 7, 255, 8, 255, 9, 255, 10, 255, 11, 255, 12, 255, 13, 255, 14, 255, 15, 255, 16, 255, 17, 255, 18, 255, 19, 255, 20, 255, 21, 255, 22, 255, 23, 255, 24, 255, 25, 255, 26, 255, 27, 255, 28, 255, 29, 255, 30, 255, 31, 255, 32, 255, 33, 255, 34, 255, 35, 255, 36, 255, 37, 255, 38, 255, 39, 255, 40, 255, 41, 255, 42, 255, 43, 255, 44, 255, 45, 255, 46, 255, 47, 255, 48, 255, 49, 255, 50, 255, 51, 255, 52, 255, 53, 255, 54, 255, 55, 255, 56, 255, 57, 255, 58, 255, 59, 255, 60, 255, 61, 255, 62, 255, 63, 255, 64, 255, 65, 255, 66, 255, 67, 255, 68, 255, 69, 255, 70, 255, 71, 255, 72, 255, 73, 255, 74, 255, 75, 255, 76, 255, 77, 255, 78, 255, 79, 255, 80, 255, 81, 255, 82, 255, 83, 255, 84, 255, 85, 255, 86, 255, 87, 255, 88, 255, 89, 255, 90, 255, 91, 255, 92, 255, 93, 255, 227, 255, 230, 229, 231, 229, 232, 229, 233, 229, 234, 229, 235, 229, 236, 229, 237, 229, 238, 229, 239, 229, 240, 229, 241, 229, 242, 229, 243, 229, 244, 229, 245, 229, 246, 229, 247, 229, 248, 229, 249, 229, 250, 229, 251, 229, 252, 229, 253, 229, 254, 229, 255, 229, 0, 230, 1, 230, 2, 230, 3, 230, 4, 230, 5, 230, 6, 230, 7, 230, 8, 230, 9, 230, 10, 230, 11, 230, 12, 230, 13, 230, 14, 230, 15, 230, 16, 230, 17, 230, 18, 230, 19, 230, 20, 230, 21, 230, 22, 230, 23, 230, 24, 230, 25, 230, 26, 230, 27, 230, 28, 230, 29, 230, 30, 230, 31, 230, 32, 230, 33, 230, 34, 230, 35, 230, 36, 230, 37, 230, 38, 230, 39, 230, 40, 230, 41, 230, 42, 230, 43, 230, 44, 230, 45, 230, 46, 230, 47, 230, 48, 230, 49, 230, 50, 230, 51, 230, 52, 230, 53, 230, 54, 230, 55, 230, 56, 230, 57, 230, 58, 230, 59, 230, 60, 230, 61, 230, 62, 230, 63, 230, 64, 230, 65, 230, 66, 230, 67, 230, 68, 230, 69, 230, 65, 48, 66, 48, 67, 48, 68, 48, 69, 48, 70, 48, 71, 48, 72, 48, 73, 48, 74, 48, 75, 48, 76, 48, 77, 48, 78, 48, 79, 48, 80, 48, 81, 48, 82, 48, 83, 48, 84, 48, 85, 48, 86, 48, 87, 48, 88, 48, 89, 48, 90, 48, 91, 48, 92, 48, 93, 48, 94, 48, 95, 48, 96, 48, 97, 48, 98, 48, 99, 48, 100, 48, 101, 48, 102, 48, 103, 48, 104, 48, 105, 48, 106, 48, 107, 48, 108, 48, 109, 48, 110, 48, 111, 48, 112, 48, 113, 48, 114, 48, 115, 48, 116, 48, 117, 48, 118, 48, 119, 48, 120, 48, 121, 48, 122, 48, 123, 48, 124, 48, 125, 48, 126, 48, 127, 48, 128, 48, 129, 48, 130, 48, 131, 48, 132, 48, 133, 48, 134, 48, 135, 48, 136, 48, 137, 48, 138, 48, 139, 48, 140, 48, 141, 48, 142, 48, 143, 48, 144, 48, 145, 48, 146, 48, 147, 48, 114, 231, 115, 231, 116, 231, 117, 231, 118, 231, 119, 231, 120, 231, 121, 231, 122, 231, 123, 231, 124, 231, 70, 230, 71, 230, 72, 230, 73, 230, 74, 230, 75, 230, 76, 230, 77, 230, 78, 230, 79, 230, 80, 230, 81, 230, 82, 230, 83, 230, 84, 230, 85, 230, 86, 230, 87, 230, 88, 230, 89, 230, 90, 230, 91, 230, 92, 230, 93, 230, 94, 230, 95, 230, 96, 230, 97, 230, 98, 230, 99, 230, 100, 230, 101, 230, 102, 230, 103, 230, 104, 230, 105, 230, 106, 230, 107, 230, 108, 230, 109, 230, 110, 230, 111, 230, 112, 230, 113, 230, 114, 230, 115, 230, 116, 230, 117, 230, 118, 230, 119, 230, 120, 230, 121, 230, 122, 230, 123, 230, 124, 230, 125, 230, 126, 230, 127, 230, 128, 230, 129, 230, 130, 230, 131, 230, 132, 230, 133, 230, 134, 230, 135, 230, 136, 230, 137, 230, 138, 230, 139, 230, 140, 230, 141, 230, 142, 230, 143, 230, 144, 230, 145, 230, 146, 230, 147, 230, 148, 230, 149, 230, 150, 230, 151, 230, 152, 230, 153, 230, 154, 230, 155, 230, 156, 230, 157, 230, 158, 230, 159, 230, 160, 230, 161, 230, 162, 230, 163, 230, 164, 230, 165, 230, 161, 48, 162, 48, 163, 48, 164, 48, 165, 48, 166, 48, 167, 48, 168, 48, 169, 48, 170, 48, 171, 48, 172, 48, 173, 48, 174, 48, 175, 48, 176, 48, 177, 48, 178, 48, 179, 48, 180, 48, 181, 48, 182, 48, 183, 48, 184, 48, 185, 48, 186, 48, 187, 48, 188, 48, 189, 48, 190, 48, 191, 48, 192, 48, 193, 48, 194, 48, 195, 48, 196, 48, 197, 48, 198, 48, 199, 48, 200, 48, 201, 48, 202, 48, 203, 48, 204, 48, 205, 48, 206, 48, 207, 48, 208, 48, 209, 48, 210, 48, 211, 48, 212, 48, 213, 48, 214, 48, 215, 48, 216, 48, 217, 48, 218, 48, 219, 48, 220, 48, 221, 48, 222, 48, 223, 48, 224, 48, 225, 48, 226, 48, 227, 48, 228, 48, 229, 48, 230, 48, 231, 48, 232, 48, 233, 48, 234, 48, 235, 48, 236, 48, 237, 48, 238, 48, 239, 48, 240, 48, 241, 48, 242, 48, 243, 48, 244, 48, 245, 48, 246, 48, 125, 231, 126, 231, 127, 231, 128, 231, 129, 231, 130, 231, 131, 231, 132, 231, 166, 230, 167, 230, 168, 230, 169, 230, 170, 230, 171, 230, 172, 230, 173, 230, 174, 230, 175, 230, 176, 230, 177, 230, 178, 230, 179, 230, 180, 230, 181, 230, 182, 230, 183, 230, 184, 230, 185, 230, 186, 230, 187, 230, 188, 230, 189, 230, 190, 230, 191, 230, 192, 230, 193, 230, 194, 230, 195, 230, 196, 230, 197, 230, 198, 230, 199, 230, 200, 230, 201, 230, 202, 230, 203, 230, 204, 230, 205, 230, 206, 230, 207, 230, 208, 230, 209, 230, 210, 230, 211, 230, 212, 230, 213, 230, 214, 230, 215, 230, 216, 230, 217, 230, 218, 230, 219, 230, 220, 230, 221, 230, 222, 230, 223, 230, 224, 230, 225, 230, 226, 230, 227, 230, 228, 230, 229, 230, 230, 230, 231, 230, 232, 230, 233, 230, 234, 230, 235, 230, 236, 230, 237, 230, 238, 230, 239, 230, 240, 230, 241, 230, 242, 230, 243, 230, 244, 230, 245, 230, 246, 230, 247, 230, 248, 230, 249, 230, 250, 230, 251, 230, 252, 230, 253, 230, 254, 230, 255, 230, 0, 231, 1, 231, 2, 231, 3, 231, 4, 231, 5, 231, 145, 3, 146, 3, 147, 3, 148, 3, 149, 3, 150, 3, 151, 3, 152, 3, 153, 3, 154, 3, 155, 3, 156, 3, 157, 3, 158, 3, 159, 3, 160, 3, 161, 3, 163, 3, 164, 3, 165, 3, 166, 3, 167, 3, 168, 3, 169, 3, 133, 231, 134, 231, 135, 231, 136, 231, 137, 231, 138, 231, 139, 231, 140, 231, 177, 3, 178, 3, 179, 3, 180, 3, 181, 3, 182, 3, 183, 3, 184, 3, 185, 3, 186, 3, 187, 3, 188, 3, 189, 3, 190, 3, 191, 3, 192, 3, 193, 3, 195, 3, 196, 3, 197, 3, 198, 3, 199, 3, 200, 3, 201, 3, 141, 231, 142, 231, 143, 231, 144, 231, 145, 231, 146, 231, 147, 231, 53, 254, 54, 254, 57, 254, 58, 254, 63, 254, 64, 254, 61, 254, 62, 254, 65, 254, 66, 254, 67, 254, 68, 254, 148, 231, 149, 231, 59, 254, 60, 254, 55, 254, 56, 254, 49, 254, 150, 231, 51, 254, 52, 254, 151, 231, 152, 231, 153, 231, 154, 231, 155, 231, 156, 231, 157, 231, 158, 231, 159, 231, 6, 231, 7, 231, 8, 231, 9, 231, 10, 231, 11, 231, 12, 231, 13, 231, 14, 231, 15, 231, 16, 231, 17, 231, 18, 231, 19, 231, 20, 231, 21, 231, 22, 231, 23, 231, 24, 231, 25, 231, 26, 231, 27, 231, 28, 231, 29, 231, 30, 231, 31, 231, 32, 231, 33, 231, 34, 231, 35, 231, 36, 231, 37, 231, 38, 231, 39, 231, 40, 231, 41, 231, 42, 231, 43, 231, 44, 231, 45, 231, 46, 231, 47, 231, 48, 231, 49, 231, 50, 231, 51, 231, 52, 231, 53, 231, 54, 231, 55, 231, 56, 231, 57, 231, 58, 231, 59, 231, 60, 231, 61, 231, 62, 231, 63, 231, 64, 231, 65, 231, 66, 231, 67, 231, 68, 231, 69, 231, 70, 231, 71, 231, 72, 231, 73, 231, 74, 231, 75, 231, 76, 231, 77, 231, 78, 231, 79, 231, 80, 231, 81, 231, 82, 231, 83, 231, 84, 231, 85, 231, 86, 231, 87, 231, 88, 231, 89, 231, 90, 231, 91, 231, 92, 231, 93, 231, 94, 231, 95, 231, 96, 231, 97, 231, 98, 231, 99, 231, 100, 231, 101, 231, 16, 4, 17, 4, 18, 4, 19, 4, 20, 4, 21, 4, 1, 4, 22, 4, 23, 4, 24, 4, 25, 4, 26, 4, 27, 4, 28, 4, 29, 4, 30, 4, 31, 4, 32, 4, 33, 4, 34, 4, 35, 4, 36, 4, 37, 4, 38, 4, 39, 4, 40, 4, 41, 4, 42, 4, 43, 4, 44, 4, 45, 4, 46, 4, 47, 4, 160, 231, 161, 231, 162, 231, 163, 231, 164, 231, 165, 231, 166, 231, 167, 231, 168, 231, 169, 231, 170, 231, 171, 231, 172, 231, 173, 231, 174, 231, 48, 4, 49, 4, 50, 4, 51, 4, 52, 4, 53, 4, 81, 4, 54, 4, 55, 4, 56, 4, 57, 4, 58, 4, 59, 4, 60, 4, 61, 4, 62, 4, 63, 4, 64, 4, 65, 4, 66, 4, 67, 4, 68, 4, 69, 4, 70, 4, 71, 4, 72, 4, 73, 4, 74, 4, 75, 4, 76, 4, 77, 4, 78, 4, 79, 4, 175, 231, 176, 231, 177, 231, 178, 231, 179, 231, 180, 231, 181, 231, 182, 231, 183, 231, 184, 231, 185, 231, 186, 231, 187, 231, 202, 2, 203, 2, 217, 2, 19, 32, 21, 32, 37, 32, 53, 32, 5, 33, 9, 33, 150, 33, 151, 33, 152, 33, 153, 33, 21, 34, 31, 34, 35, 34, 82, 34, 102, 34, 103, 34, 191, 34, 80, 37, 81, 37, 82, 37, 83, 37, 84, 37, 85, 37, 86, 37, 87, 37, 88, 37, 89, 37, 90, 37, 91, 37, 92, 37, 93, 37, 94, 37, 95, 37, 96, 37, 97, 37, 98, 37, 99, 37, 100, 37, 101, 37, 102, 37, 103, 37, 104, 37, 105, 37, 106, 37, 107, 37, 108, 37, 109, 37, 110, 37, 111, 37, 112, 37, 113, 37, 114, 37, 115, 37, 129, 37, 130, 37, 131, 37, 132, 37, 133, 37, 134, 37, 135, 37, 136, 37, 137, 37, 138, 37, 139, 37, 140, 37, 141, 37, 142, 37, 143, 37, 147, 37, 148, 37, 149, 37, 188, 37, 189, 37, 226, 37, 227, 37, 228, 37, 229, 37, 9, 38, 149, 34, 18, 48, 29, 48, 30, 48, 188, 231, 189, 231, 190, 231, 191, 231, 192, 231, 193, 231, 194, 231, 195, 231, 196, 231, 197, 231, 198, 231, 1, 1, 225, 0, 206, 1, 224, 0, 19, 1, 233, 0, 27, 1, 232, 0, 43, 1, 237, 0, 208, 1, 236, 0, 77, 1, 243, 0, 210, 1, 242, 0, 107, 1, 250, 0, 212, 1, 249, 0, 214, 1, 216, 1, 218, 1, 220, 1, 252, 0, 234, 0, 81, 2, 199, 231, 68, 1, 72, 1, 249, 1, 97, 2, 201, 231, 202, 231, 203, 231, 204, 231, 5, 49, 6, 49, 7, 49, 8, 49, 9, 49, 10, 49, 11, 49, 12, 49, 13, 49, 14, 49, 15, 49, 16, 49, 17, 49, 18, 49, 19, 49, 20, 49, 21, 49, 22, 49, 23, 49, 24, 49, 25, 49, 26, 49, 27, 49, 28, 49, 29, 49, 30, 49, 31, 49, 32, 49, 33, 49, 34, 49, 35, 49, 36, 49, 37, 49, 38, 49, 39, 49, 40, 49, 41, 49, 205, 231, 206, 231, 207, 231, 208, 231, 209, 231, 210, 231, 211, 231, 212, 231, 213, 231, 214, 231, 215, 231, 216, 231, 217, 231, 218, 231, 219, 231, 220, 231, 221, 231, 222, 231, 223, 231, 224, 231, 225, 231, 33, 48, 34, 48, 35, 48, 36, 48, 37, 48, 38, 48, 39, 48, 40, 48, 41, 48, 163, 50, 142, 51, 143, 51, 156, 51, 157, 51, 158, 51, 161, 51, 196, 51, 206, 51, 209, 51, 210, 51, 213, 51, 48, 254, 226, 255, 228, 255, 226, 231, 33, 33, 49, 50, 227, 231, 16, 32, 228, 231, 229, 231, 230, 231, 252, 48, 155, 48, 156, 48, 253, 48, 254, 48, 6, 48, 157, 48, 158, 48, 73, 254, 74, 254, 75, 254, 76, 254, 77, 254, 78, 254, 79, 254, 80, 254, 81, 254, 82, 254, 84, 254, 85, 254, 86, 254, 87, 254, 89, 254, 90, 254, 91, 254, 92, 254, 93, 254, 94, 254, 95, 254, 96, 254, 97, 254, 98, 254, 99, 254, 100, 254, 101, 254, 102, 254, 104, 254, 105, 254, 106, 254, 107, 254, 62, 48, 240, 47, 241, 47, 242, 47, 243, 47, 244, 47, 245, 47, 246, 47, 247, 47, 248, 47, 249, 47, 250, 47, 251, 47, 7, 48, 244, 231, 245, 231, 246, 231, 247, 231, 248, 231, 249, 231, 250, 231, 251, 231, 252, 231, 253, 231, 254, 231, 255, 231, 0, 232, 0, 37, 1, 37, 2, 37, 3, 37, 4, 37, 5, 37, 6, 37, 7, 37, 8, 37, 9, 37, 10, 37, 11, 37, 12, 37, 13, 37, 14, 37, 15, 37, 16, 37, 17, 37, 18, 37, 19, 37, 20, 37, 21, 37, 22, 37, 23, 37, 24, 37, 25, 37, 26, 37, 27, 37, 28, 37, 29, 37, 30, 37, 31, 37, 32, 37, 33, 37, 34, 37, 35, 37, 36, 37, 37, 37, 38, 37, 39, 37, 40, 37, 41, 37, 42, 37, 43, 37, 44, 37, 45, 37, 46, 37, 47, 37, 48, 37, 49, 37, 50, 37, 51, 37, 52, 37, 53, 37, 54, 37, 55, 37, 56, 37, 57, 37, 58, 37, 59, 37, 60, 37, 61, 37, 62, 37, 63, 37, 64, 37, 65, 37, 66, 37, 67, 37, 68, 37, 69, 37, 70, 37, 71, 37, 72, 37, 73, 37, 74, 37, 75, 37, 1, 232, 2, 232, 3, 232, 4, 232, 5, 232, 6, 232, 7, 232, 8, 232, 9, 232, 10, 232, 11, 232, 12, 232, 13, 232, 14, 232, 15, 232, 220, 114, 221, 114, 223, 114, 226, 114, 227, 114, 228, 114, 229, 114, 230, 114, 231, 114, 234, 114, 235, 114, 245, 114, 246, 114, 249, 114, 253, 114, 254, 114, 255, 114, 0, 115, 2, 115, 4, 115, 5, 115, 6, 115, 7, 115, 8, 115, 9, 115, 11, 115, 12, 115, 13, 115, 15, 115, 16, 115, 17, 115, 18, 115, 20, 115, 24, 115, 25, 115, 26, 115, 31, 115, 32, 115, 35, 115, 36, 115, 38, 115, 39, 115, 40, 115, 45, 115, 47, 115, 48, 115, 50, 115, 51, 115, 53, 115, 54, 115, 58, 115, 59, 115, 60, 115, 61, 115, 64, 115, 65, 115, 66, 115, 67, 115, 68, 115, 69, 115, 70, 115, 71, 115, 72, 115, 73, 115, 74, 115, 75, 115, 76, 115, 78, 115, 79, 115, 81, 115, 83, 115, 84, 115, 85, 115, 86, 115, 88, 115, 89, 115, 90, 115, 91, 115, 92, 115, 93, 115, 94, 115, 95, 115, 97, 115, 98, 115, 99, 115, 100, 115, 101, 115, 102, 115, 103, 115, 104, 115, 105, 115, 106, 115, 107, 115, 110, 115, 112, 115, 113, 115, 0, 224, 1, 224, 2, 224, 3, 224, 4, 224, 5, 224, 6, 224, 7, 224, 8, 224, 9, 224, 10, 224, 11, 224, 12, 224, 13, 224, 14, 224, 15, 224, 16, 224, 17, 224, 18, 224, 19, 224, 20, 224, 21, 224, 22, 224, 23, 224, 24, 224, 25, 224, 26, 224, 27, 224, 28, 224, 29, 224, 30, 224, 31, 224, 32, 224, 33, 224, 34, 224, 35, 224, 36, 224, 37, 224, 38, 224, 39, 224, 40, 224, 41, 224, 42, 224, 43, 224, 44, 224, 45, 224, 46, 224, 47, 224, 48, 224, 49, 224, 50, 224, 51, 224, 52, 224, 53, 224, 54, 224, 55, 224, 56, 224, 57, 224, 58, 224, 59, 224, 60, 224, 61, 224, 62, 224, 63, 224, 64, 224, 65, 224, 66, 224, 67, 224, 68, 224, 69, 224, 70, 224, 71, 224, 72, 224, 73, 224, 74, 224, 75, 224, 76, 224, 77, 224, 78, 224, 79, 224, 80, 224, 81, 224, 82, 224, 83, 224, 84, 224, 85, 224, 86, 224, 87, 224, 88, 224, 89, 224, 90, 224, 91, 224, 92, 224, 93, 224, 114, 115, 115, 115, 116, 115, 117, 115, 118, 115, 119, 115, 120, 115, 121, 115, 122, 115, 123, 115, 124, 115, 125, 115, 127, 115, 128, 115, 129, 115, 130, 115, 131, 115, 133, 115, 134, 115, 136, 115, 138, 115, 140, 115, 141, 115, 143, 115, 144, 115, 146, 115, 147, 115, 148, 115, 149, 115, 151, 115, 152, 115, 153, 115, 154, 115, 156, 115, 157, 115, 158, 115, 160, 115, 161, 115, 163, 115, 164, 115, 165, 115, 166, 115, 167, 115, 168, 115, 170, 115, 172, 115, 173, 115, 177, 115, 180, 115, 181, 115, 182, 115, 184, 115, 185, 115, 188, 115, 189, 115, 190, 115, 191, 115, 193, 115, 195, 115, 196, 115, 197, 115, 198, 115, 199, 115, 203, 115, 204, 115, 206, 115, 210, 115, 211, 115, 212, 115, 213, 115, 214, 115, 215, 115, 216, 115, 218, 115, 219, 115, 220, 115, 221, 115, 223, 115, 225, 115, 226, 115, 227, 115, 228, 115, 230, 115, 232, 115, 234, 115, 235, 115, 236, 115, 238, 115, 239, 115, 240, 115, 241, 115, 243, 115, 244, 115, 245, 115, 246, 115, 247, 115, 94, 224, 95, 224, 96, 224, 97, 224, 98, 224, 99, 224, 100, 224, 101, 224, 102, 224, 103, 224, 104, 224, 105, 224, 106, 224, 107, 224, 108, 224, 109, 224, 110, 224, 111, 224, 112, 224, 113, 224, 114, 224, 115, 224, 116, 224, 117, 224, 118, 224, 119, 224, 120, 224, 121, 224, 122, 224, 123, 224, 124, 224, 125, 224, 126, 224, 127, 224, 128, 224, 129, 224, 130, 224, 131, 224, 132, 224, 133, 224, 134, 224, 135, 224, 136, 224, 137, 224, 138, 224, 139, 224, 140, 224, 141, 224, 142, 224, 143, 224, 144, 224, 145, 224, 146, 224, 147, 224, 148, 224, 149, 224, 150, 224, 151, 224, 152, 224, 153, 224, 154, 224, 155, 224, 156, 224, 157, 224, 158, 224, 159, 224, 160, 224, 161, 224, 162, 224, 163, 224, 164, 224, 165, 224, 166, 224, 167, 224, 168, 224, 169, 224, 170, 224, 171, 224, 172, 224, 173, 224, 174, 224, 175, 224, 176, 224, 177, 224, 178, 224, 179, 224, 180, 224, 181, 224, 182, 224, 183, 224, 184, 224, 185, 224, 186, 224, 187, 224, 248, 115, 249, 115, 250, 115, 251, 115, 252, 115, 253, 115, 254, 115, 255, 115, 0, 116, 1, 116, 2, 116, 4, 116, 7, 116, 8, 116, 11, 116, 12, 116, 13, 116, 14, 116, 17, 116, 18, 116, 19, 116, 20, 116, 21, 116, 22, 116, 23, 116, 24, 116, 25, 116, 28, 116, 29, 116, 30, 116, 31, 116, 32, 116, 33, 116, 35, 116, 36, 116, 39, 116, 41, 116, 43, 116, 45, 116, 47, 116, 49, 116, 50, 116, 55, 116, 56, 116, 57, 116, 58, 116, 59, 116, 61, 116, 62, 116, 63, 116, 64, 116, 66, 116, 67, 116, 68, 116, 69, 116, 70, 116, 71, 116, 72, 116, 73, 116, 74, 116, 75, 116, 76, 116, 77, 116, 78, 116, 79, 116, 80, 116, 81, 116, 82, 116, 83, 116, 84, 116, 86, 116, 88, 116, 93, 116, 96, 116, 97, 116, 98, 116, 99, 116, 100, 116, 101, 116, 102, 116, 103, 116, 104, 116, 105, 116, 106, 116, 107, 116, 108, 116, 110, 116, 111, 116, 113, 116, 114, 116, 115, 116, 116, 116, 117, 116, 120, 116, 121, 116, 122, 116, 188, 224, 189, 224, 190, 224, 191, 224, 192, 224, 193, 224, 194, 224, 195, 224, 196, 224, 197, 224, 198, 224, 199, 224, 200, 224, 201, 224, 202, 224, 203, 224, 204, 224, 205, 224, 206, 224, 207, 224, 208, 224, 209, 224, 210, 224, 211, 224, 212, 224, 213, 224, 214, 224, 215, 224, 216, 224, 217, 224, 218, 224, 219, 224, 220, 224, 221, 224, 222, 224, 223, 224, 224, 224, 225, 224, 226, 224, 227, 224, 228, 224, 229, 224, 230, 224, 231, 224, 232, 224, 233, 224, 234, 224, 235, 224, 236, 224, 237, 224, 238, 224, 239, 224, 240, 224, 241, 224, 242, 224, 243, 224, 244, 224, 245, 224, 246, 224, 247, 224, 248, 224, 249, 224, 250, 224, 251, 224, 252, 224, 253, 224, 254, 224, 255, 224, 0, 225, 1, 225, 2, 225, 3, 225, 4, 225, 5, 225, 6, 225, 7, 225, 8, 225, 9, 225, 10, 225, 11, 225, 12, 225, 13, 225, 14, 225, 15, 225, 16, 225, 17, 225, 18, 225, 19, 225, 20, 225, 21, 225, 22, 225, 23, 225, 24, 225, 25, 225, 123, 116, 124, 116, 125, 116, 127, 116, 130, 116, 132, 116, 133, 116, 134, 116, 136, 116, 137, 116, 138, 116, 140, 116, 141, 116, 143, 116, 145, 116, 146, 116, 147, 116, 148, 116, 149, 116, 150, 116, 151, 116, 152, 116, 153, 116, 154, 116, 155, 116, 157, 116, 159, 116, 160, 116, 161, 116, 162, 116, 163, 116, 164, 116, 165, 116, 166, 116, 170, 116, 171, 116, 172, 116, 173, 116, 174, 116, 175, 116, 176, 116, 177, 116, 178, 116, 179, 116, 180, 116, 181, 116, 182, 116, 183, 116, 184, 116, 185, 116, 187, 116, 188, 116, 189, 116, 190, 116, 191, 116, 192, 116, 193, 116, 194, 116, 195, 116, 196, 116, 197, 116, 198, 116, 199, 116, 200, 116, 201, 116, 202, 116, 203, 116, 204, 116, 205, 116, 206, 116, 207, 116, 208, 116, 209, 116, 211, 116, 212, 116, 213, 116, 214, 116, 215, 116, 216, 116, 217, 116, 218, 116, 219, 116, 221, 116, 223, 116, 225, 116, 229, 116, 231, 116, 232, 116, 233, 116, 234, 116, 235, 116, 236, 116, 237, 116, 240, 116, 241, 116, 242, 116, 26, 225, 27, 225, 28, 225, 29, 225, 30, 225, 31, 225, 32, 225, 33, 225, 34, 225, 35, 225, 36, 225, 37, 225, 38, 225, 39, 225, 40, 225, 41, 225, 42, 225, 43, 225, 44, 225, 45, 225, 46, 225, 47, 225, 48, 225, 49, 225, 50, 225, 51, 225, 52, 225, 53, 225, 54, 225, 55, 225, 56, 225, 57, 225, 58, 225, 59, 225, 60, 225, 61, 225, 62, 225, 63, 225, 64, 225, 65, 225, 66, 225, 67, 225, 68, 225, 69, 225, 70, 225, 71, 225, 72, 225, 73, 225, 74, 225, 75, 225, 76, 225, 77, 225, 78, 225, 79, 225, 80, 225, 81, 225, 82, 225, 83, 225, 84, 225, 85, 225, 86, 225, 87, 225, 88, 225, 89, 225, 90, 225, 91, 225, 92, 225, 93, 225, 94, 225, 95, 225, 96, 225, 97, 225, 98, 225, 99, 225, 100, 225, 101, 225, 102, 225, 103, 225, 104, 225, 105, 225, 106, 225, 107, 225, 108, 225, 109, 225, 110, 225, 111, 225, 112, 225, 113, 225, 114, 225, 115, 225, 116, 225, 117, 225, 118, 225, 119, 225, 243, 116, 245, 116, 248, 116, 249, 116, 250, 116, 251, 116, 252, 116, 253, 116, 254, 116, 0, 117, 1, 117, 2, 117, 3, 117, 5, 117, 6, 117, 7, 117, 8, 117, 9, 117, 10, 117, 11, 117, 12, 117, 14, 117, 16, 117, 18, 117, 20, 117, 21, 117, 22, 117, 23, 117, 27, 117, 29, 117, 30, 117, 32, 117, 33, 117, 34, 117, 35, 117, 36, 117, 38, 117, 39, 117, 42, 117, 46, 117, 52, 117, 54, 117, 57, 117, 60, 117, 61, 117, 63, 117, 65, 117, 66, 117, 67, 117, 68, 117, 70, 117, 71, 117, 73, 117, 74, 117, 77, 117, 80, 117, 81, 117, 82, 117, 83, 117, 85, 117, 86, 117, 87, 117, 88, 117, 93, 117, 94, 117, 95, 117, 96, 117, 97, 117, 98, 117, 99, 117, 100, 117, 103, 117, 104, 117, 105, 117, 107, 117, 108, 117, 109, 117, 110, 117, 111, 117, 112, 117, 113, 117, 115, 117, 117, 117, 118, 117, 119, 117, 122, 117, 123, 117, 124, 117, 125, 117, 126, 117, 128, 117, 129, 117, 130, 117, 132, 117, 133, 117, 135, 117, 120, 225, 121, 225, 122, 225, 123, 225, 124, 225, 125, 225, 126, 225, 127, 225, 128, 225, 129, 225, 130, 225, 131, 225, 132, 225, 133, 225, 134, 225, 135, 225, 136, 225, 137, 225, 138, 225, 139, 225, 140, 225, 141, 225, 142, 225, 143, 225, 144, 225, 145, 225, 146, 225, 147, 225, 148, 225, 149, 225, 150, 225, 151, 225, 152, 225, 153, 225, 154, 225, 155, 225, 156, 225, 157, 225, 158, 225, 159, 225, 160, 225, 161, 225, 162, 225, 163, 225, 164, 225, 165, 225, 166, 225, 167, 225, 168, 225, 169, 225, 170, 225, 171, 225, 172, 225, 173, 225, 174, 225, 175, 225, 176, 225, 177, 225, 178, 225, 179, 225, 180, 225, 181, 225, 182, 225, 183, 225, 184, 225, 185, 225, 186, 225, 187, 225, 188, 225, 189, 225, 190, 225, 191, 225, 192, 225, 193, 225, 194, 225, 195, 225, 196, 225, 197, 225, 198, 225, 199, 225, 200, 225, 201, 225, 202, 225, 203, 225, 204, 225, 205, 225, 206, 225, 207, 225, 208, 225, 209, 225, 210, 225, 211, 225, 212, 225, 213, 225, 136, 117, 137, 117, 138, 117, 140, 117, 141, 117, 142, 117, 144, 117, 147, 117, 149, 117, 152, 117, 155, 117, 156, 117, 158, 117, 162, 117, 166, 117, 167, 117, 168, 117, 169, 117, 170, 117, 173, 117, 182, 117, 183, 117, 186, 117, 187, 117, 191, 117, 192, 117, 193, 117, 198, 117, 203, 117, 204, 117, 206, 117, 207, 117, 208, 117, 209, 117, 211, 117, 215, 117, 217, 117, 218, 117, 220, 117, 221, 117, 223, 117, 224, 117, 225, 117, 229, 117, 233, 117, 236, 117, 237, 117, 238, 117, 239, 117, 242, 117, 243, 117, 245, 117, 246, 117, 247, 117, 248, 117, 250, 117, 251, 117, 253, 117, 254, 117, 2, 118, 4, 118, 6, 118, 7, 118, 8, 118, 9, 118, 11, 118, 13, 118, 14, 118, 15, 118, 17, 118, 18, 118, 19, 118, 20, 118, 22, 118, 26, 118, 28, 118, 29, 118, 30, 118, 33, 118, 35, 118, 39, 118, 40, 118, 44, 118, 46, 118, 47, 118, 49, 118, 50, 118, 54, 118, 55, 118, 57, 118, 58, 118, 59, 118, 61, 118, 65, 118, 66, 118, 68, 118, 214, 225, 215, 225, 216, 225, 217, 225, 218, 225, 219, 225, 220, 225, 221, 225, 222, 225, 223, 225, 224, 225, 225, 225, 226, 225, 227, 225, 228, 225, 229, 225, 230, 225, 231, 225, 232, 225, 233, 225, 234, 225, 235, 225, 236, 225, 237, 225, 238, 225, 239, 225, 240, 225, 241, 225, 242, 225, 243, 225, 244, 225, 245, 225, 246, 225, 247, 225, 248, 225, 249, 225, 250, 225, 251, 225], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 230588);
	        allocate([252, 225, 253, 225, 254, 225, 255, 225, 0, 226, 1, 226, 2, 226, 3, 226, 4, 226, 5, 226, 6, 226, 7, 226, 8, 226, 9, 226, 10, 226, 11, 226, 12, 226, 13, 226, 14, 226, 15, 226, 16, 226, 17, 226, 18, 226, 19, 226, 20, 226, 21, 226, 22, 226, 23, 226, 24, 226, 25, 226, 26, 226, 27, 226, 28, 226, 29, 226, 30, 226, 31, 226, 32, 226, 33, 226, 34, 226, 35, 226, 36, 226, 37, 226, 38, 226, 39, 226, 40, 226, 41, 226, 42, 226, 43, 226, 44, 226, 45, 226, 46, 226, 47, 226, 48, 226, 49, 226, 50, 226, 51, 226, 69, 118, 70, 118, 71, 118, 72, 118, 73, 118, 74, 118, 75, 118, 78, 118, 79, 118, 80, 118, 81, 118, 82, 118, 83, 118, 85, 118, 87, 118, 88, 118, 89, 118, 90, 118, 91, 118, 93, 118, 95, 118, 96, 118, 97, 118, 98, 118, 100, 118, 101, 118, 102, 118, 103, 118, 104, 118, 105, 118, 106, 118, 108, 118, 109, 118, 110, 118, 112, 118, 113, 118, 114, 118, 115, 118, 116, 118, 117, 118, 118, 118, 119, 118, 121, 118, 122, 118, 124, 118, 127, 118, 128, 118, 129, 118, 131, 118, 133, 118, 137, 118, 138, 118, 140, 118, 141, 118, 143, 118, 144, 118, 146, 118, 148, 118, 149, 118, 151, 118, 152, 118, 154, 118, 155, 118, 156, 118, 157, 118, 158, 118, 159, 118, 160, 118, 161, 118, 162, 118, 163, 118, 165, 118, 166, 118, 167, 118, 168, 118, 169, 118, 170, 118, 171, 118, 172, 118, 173, 118, 175, 118, 176, 118, 179, 118, 181, 118, 182, 118, 183, 118, 184, 118, 185, 118, 186, 118, 187, 118, 188, 118, 189, 118, 190, 118, 192, 118, 193, 118, 195, 118, 74, 85, 63, 150, 195, 87, 40, 99, 206, 84, 9, 85, 192, 84, 145, 118, 76, 118, 60, 133, 238, 119, 126, 130, 141, 120, 49, 114, 152, 150, 141, 151, 40, 108, 137, 91, 250, 79, 9, 99, 151, 102, 184, 92, 250, 128, 72, 104, 174, 128, 2, 102, 206, 118, 249, 81, 86, 101, 172, 113, 241, 127, 132, 136, 178, 80, 101, 89, 202, 97, 179, 111, 173, 130, 76, 99, 82, 98, 237, 83, 39, 84, 6, 123, 107, 81, 164, 117, 244, 93, 212, 98, 203, 141, 118, 151, 138, 98, 25, 128, 93, 87, 56, 151, 98, 127, 56, 114, 125, 118, 207, 103, 126, 118, 70, 100, 112, 79, 37, 141, 220, 98, 23, 122, 145, 101, 237, 115, 44, 100, 115, 98, 44, 130, 129, 152, 127, 103, 72, 114, 110, 98, 204, 98, 52, 79, 227, 116, 74, 83, 158, 82, 202, 126, 166, 144, 46, 94, 134, 104, 156, 105, 128, 129, 209, 126, 210, 104, 197, 120, 140, 134, 81, 149, 141, 80, 36, 140, 222, 130, 222, 128, 5, 83, 18, 137, 101, 82, 196, 118, 199, 118, 201, 118, 203, 118, 204, 118, 211, 118, 213, 118, 217, 118, 218, 118, 220, 118, 221, 118, 222, 118, 224, 118, 225, 118, 226, 118, 227, 118, 228, 118, 230, 118, 231, 118, 232, 118, 233, 118, 234, 118, 235, 118, 236, 118, 237, 118, 240, 118, 243, 118, 245, 118, 246, 118, 247, 118, 250, 118, 251, 118, 253, 118, 255, 118, 0, 119, 2, 119, 3, 119, 5, 119, 6, 119, 10, 119, 12, 119, 14, 119, 15, 119, 16, 119, 17, 119, 18, 119, 19, 119, 20, 119, 21, 119, 22, 119, 23, 119, 24, 119, 27, 119, 28, 119, 29, 119, 30, 119, 33, 119, 35, 119, 36, 119, 37, 119, 39, 119, 42, 119, 43, 119, 44, 119, 46, 119, 48, 119, 49, 119, 50, 119, 51, 119, 52, 119, 57, 119, 59, 119, 61, 119, 62, 119, 63, 119, 66, 119, 68, 119, 69, 119, 70, 119, 72, 119, 73, 119, 74, 119, 75, 119, 76, 119, 77, 119, 78, 119, 79, 119, 82, 119, 83, 119, 84, 119, 85, 119, 86, 119, 87, 119, 88, 119, 89, 119, 92, 119, 132, 133, 249, 150, 221, 79, 33, 88, 113, 153, 157, 91, 177, 98, 165, 98, 180, 102, 121, 140, 141, 156, 6, 114, 111, 103, 145, 120, 178, 96, 81, 83, 23, 83, 136, 143, 204, 128, 29, 141, 161, 148, 13, 80, 200, 114, 7, 89, 235, 96, 25, 113, 171, 136, 84, 89, 239, 130, 44, 103, 40, 123, 41, 93, 247, 126, 45, 117, 245, 108, 102, 142, 248, 143, 60, 144, 59, 159, 212, 107, 25, 145, 20, 123, 124, 95, 167, 120, 214, 132, 61, 133, 213, 107, 217, 107, 214, 107, 1, 94, 135, 94, 249, 117, 237, 149, 93, 101, 10, 95, 197, 95, 159, 143, 193, 88, 194, 129, 127, 144, 91, 150, 173, 151, 185, 143, 22, 127, 44, 141, 65, 98, 191, 79, 216, 83, 94, 83, 168, 143, 169, 143, 171, 143, 77, 144, 7, 104, 106, 95, 152, 129, 104, 136, 214, 156, 139, 97, 43, 82, 42, 118, 108, 95, 140, 101, 210, 111, 232, 110, 190, 91, 72, 100, 117, 81, 176, 81, 196, 103, 25, 78, 201, 121, 124, 153, 179, 112, 93, 119, 94, 119, 95, 119, 96, 119, 100, 119, 103, 119, 105, 119, 106, 119, 109, 119, 110, 119, 111, 119, 112, 119, 113, 119, 114, 119, 115, 119, 116, 119, 117, 119, 118, 119, 119, 119, 120, 119, 122, 119, 123, 119, 124, 119, 129, 119, 130, 119, 131, 119, 134, 119, 135, 119, 136, 119, 137, 119, 138, 119, 139, 119, 143, 119, 144, 119, 147, 119, 148, 119, 149, 119, 150, 119, 151, 119, 152, 119, 153, 119, 154, 119, 155, 119, 156, 119, 157, 119, 158, 119, 161, 119, 163, 119, 164, 119, 166, 119, 168, 119, 171, 119, 173, 119, 174, 119, 175, 119, 177, 119, 178, 119, 180, 119, 182, 119, 183, 119, 184, 119, 185, 119, 186, 119, 188, 119, 190, 119, 192, 119, 193, 119, 194, 119, 195, 119, 196, 119, 197, 119, 198, 119, 199, 119, 200, 119, 201, 119, 202, 119, 203, 119, 204, 119, 206, 119, 207, 119, 208, 119, 209, 119, 210, 119, 211, 119, 212, 119, 213, 119, 214, 119, 216, 119, 217, 119, 218, 119, 221, 119, 222, 119, 223, 119, 224, 119, 225, 119, 228, 119, 197, 117, 118, 94, 187, 115, 224, 131, 173, 100, 232, 98, 181, 148, 226, 108, 90, 83, 195, 82, 15, 100, 194, 148, 148, 123, 47, 79, 27, 94, 54, 130, 22, 129, 138, 129, 36, 110, 202, 108, 115, 154, 85, 99, 92, 83, 250, 84, 101, 136, 224, 87, 13, 78, 3, 94, 101, 107, 63, 124, 232, 144, 22, 96, 230, 100, 28, 115, 193, 136, 80, 103, 77, 98, 34, 141, 108, 119, 41, 142, 199, 145, 105, 95, 220, 131, 33, 133, 16, 153, 194, 83, 149, 134, 139, 107, 237, 96, 232, 96, 127, 112, 205, 130, 49, 130, 211, 78, 167, 108, 207, 133, 205, 100, 217, 124, 253, 105, 249, 102, 73, 131, 149, 83, 86, 123, 167, 79, 140, 81, 75, 109, 66, 92, 109, 142, 210, 99, 201, 83, 44, 131, 54, 131, 229, 103, 180, 120, 61, 100, 223, 91, 148, 92, 238, 93, 231, 139, 198, 98, 244, 103, 122, 140, 0, 100, 186, 99, 73, 135, 139, 153, 23, 140, 32, 127, 242, 148, 167, 78, 16, 150, 164, 152, 12, 102, 22, 115, 230, 119, 232, 119, 234, 119, 239, 119, 240, 119, 241, 119, 242, 119, 244, 119, 245, 119, 247, 119, 249, 119, 250, 119, 251, 119, 252, 119, 3, 120, 4, 120, 5, 120, 6, 120, 7, 120, 8, 120, 10, 120, 11, 120, 14, 120, 15, 120, 16, 120, 19, 120, 21, 120, 25, 120, 27, 120, 30, 120, 32, 120, 33, 120, 34, 120, 36, 120, 40, 120, 42, 120, 43, 120, 46, 120, 47, 120, 49, 120, 50, 120, 51, 120, 53, 120, 54, 120, 61, 120, 63, 120, 65, 120, 66, 120, 67, 120, 68, 120, 70, 120, 72, 120, 73, 120, 74, 120, 75, 120, 77, 120, 79, 120, 81, 120, 83, 120, 84, 120, 88, 120, 89, 120, 90, 120, 91, 120, 92, 120, 94, 120, 95, 120, 96, 120, 97, 120, 98, 120, 99, 120, 100, 120, 101, 120, 102, 120, 103, 120, 104, 120, 105, 120, 111, 120, 112, 120, 113, 120, 114, 120, 115, 120, 116, 120, 117, 120, 118, 120, 120, 120, 121, 120, 122, 120, 123, 120, 125, 120, 126, 120, 127, 120, 128, 120, 129, 120, 130, 120, 131, 120, 58, 87, 29, 92, 56, 94, 127, 149, 127, 80, 160, 128, 130, 83, 94, 101, 69, 117, 49, 85, 33, 80, 133, 141, 132, 98, 158, 148, 29, 103, 50, 86, 110, 111, 226, 93, 53, 84, 146, 112, 102, 143, 111, 98, 164, 100, 163, 99, 123, 95, 136, 111, 244, 144, 227, 129, 176, 143, 24, 92, 104, 102, 241, 95, 137, 108, 72, 150, 129, 141, 108, 136, 145, 100, 240, 121, 206, 87, 89, 106, 16, 98, 72, 84, 88, 78, 11, 122, 233, 96, 132, 111, 218, 139, 127, 98, 30, 144, 139, 154, 228, 121, 3, 84, 244, 117, 1, 99, 25, 83, 96, 108, 223, 143, 27, 95, 112, 154, 59, 128, 127, 159, 136, 79, 58, 92, 100, 141, 197, 127, 165, 101, 189, 112, 69, 81, 178, 81, 107, 134, 7, 93, 160, 91, 189, 98, 108, 145, 116, 117, 12, 142, 32, 122, 1, 97, 121, 123, 199, 78, 248, 126, 133, 119, 17, 78, 237, 129, 29, 82, 250, 81, 113, 106, 168, 83, 135, 142, 4, 149, 207, 150, 193, 110, 100, 150, 90, 105, 132, 120, 133, 120, 134, 120, 136, 120, 138, 120, 139, 120, 143, 120, 144, 120, 146, 120, 148, 120, 149, 120, 150, 120, 153, 120, 157, 120, 158, 120, 160, 120, 162, 120, 164, 120, 166, 120, 168, 120, 169, 120, 170, 120, 171, 120, 172, 120, 173, 120, 174, 120, 175, 120, 181, 120, 182, 120, 183, 120, 184, 120, 186, 120, 187, 120, 188, 120, 189, 120, 191, 120, 192, 120, 194, 120, 195, 120, 196, 120, 198, 120, 199, 120, 200, 120, 204, 120, 205, 120, 206, 120, 207, 120, 209, 120, 210, 120, 211, 120, 214, 120, 215, 120, 216, 120, 218, 120, 219, 120, 220, 120, 221, 120, 222, 120, 223, 120, 224, 120, 225, 120, 226, 120, 227, 120, 228, 120, 229, 120, 230, 120, 231, 120, 233, 120, 234, 120, 235, 120, 237, 120, 238, 120, 239, 120, 240, 120, 241, 120, 243, 120, 245, 120, 246, 120, 248, 120, 249, 120, 251, 120, 252, 120, 253, 120, 254, 120, 255, 120, 0, 121, 2, 121, 3, 121, 4, 121, 6, 121, 7, 121, 8, 121, 9, 121, 10, 121, 11, 121, 12, 121, 64, 120, 168, 80, 215, 119, 16, 100, 230, 137, 4, 89, 227, 99, 221, 93, 127, 122, 61, 105, 32, 79, 57, 130, 152, 85, 50, 78, 174, 117, 151, 122, 98, 94, 138, 94, 239, 149, 27, 82, 57, 84, 138, 112, 118, 99, 36, 149, 130, 87, 37, 102, 63, 105, 135, 145, 7, 85, 243, 109, 175, 126, 34, 136, 51, 98, 240, 126, 181, 117, 40, 131, 193, 120, 204, 150, 158, 143, 72, 97, 247, 116, 205, 139, 100, 107, 58, 82, 80, 141, 33, 107, 106, 128, 113, 132, 241, 86, 6, 83, 206, 78, 27, 78, 209, 81, 151, 124, 139, 145, 7, 124, 195, 79, 127, 142, 225, 123, 156, 122, 103, 100, 20, 93, 172, 80, 6, 129, 1, 118, 185, 124, 236, 109, 224, 127, 81, 103, 88, 91, 248, 91, 203, 120, 174, 100, 19, 100, 170, 99, 43, 99, 25, 149, 45, 100, 190, 143, 84, 123, 41, 118, 83, 98, 39, 89, 70, 84, 121, 107, 163, 80, 52, 98, 38, 94, 134, 107, 227, 78, 55, 141, 139, 136, 133, 95, 46, 144, 13, 121, 14, 121, 15, 121, 16, 121, 17, 121, 18, 121, 20, 121, 21, 121, 22, 121, 23, 121, 24, 121, 25, 121, 26, 121, 27, 121, 28, 121, 29, 121, 31, 121, 32, 121, 33, 121, 34, 121, 35, 121, 37, 121, 38, 121, 39, 121, 40, 121, 41, 121, 42, 121, 43, 121, 44, 121, 45, 121, 46, 121, 47, 121, 48, 121, 49, 121, 50, 121, 51, 121, 53, 121, 54, 121, 55, 121, 56, 121, 57, 121, 61, 121, 63, 121, 66, 121, 67, 121, 68, 121, 69, 121, 71, 121, 74, 121, 75, 121, 76, 121, 77, 121, 78, 121, 79, 121, 80, 121, 81, 121, 82, 121, 84, 121, 85, 121, 88, 121, 89, 121, 97, 121, 99, 121, 100, 121, 102, 121, 105, 121, 106, 121, 107, 121, 108, 121, 110, 121, 112, 121, 113, 121, 114, 121, 115, 121, 116, 121, 117, 121, 118, 121, 121, 121, 123, 121, 124, 121, 125, 121, 126, 121, 127, 121, 130, 121, 131, 121, 134, 121, 135, 121, 136, 121, 137, 121, 139, 121, 140, 121, 141, 121, 142, 121, 144, 121, 145, 121, 146, 121, 32, 96, 61, 128, 197, 98, 57, 78, 85, 83, 248, 144, 184, 99, 198, 128, 230, 101, 46, 108, 70, 79, 238, 96, 225, 109, 222, 139, 57, 95, 203, 134, 83, 95, 33, 99, 90, 81, 97, 131, 99, 104, 0, 82, 99, 99, 72, 142, 18, 80, 155, 92, 119, 121, 252, 91, 48, 82, 59, 122, 188, 96, 83, 144, 215, 118, 183, 95, 151, 95, 132, 118, 108, 142, 111, 112, 123, 118, 73, 123, 170, 119, 243, 81, 147, 144, 36, 88, 78, 79, 244, 110, 234, 143, 76, 101, 27, 123, 196, 114, 164, 109, 223, 127, 225, 90, 181, 98, 149, 94, 48, 87, 130, 132, 44, 123, 29, 94, 31, 95, 18, 144, 20, 127, 160, 152, 130, 99, 199, 110, 152, 120, 185, 112, 120, 81, 91, 151, 171, 87, 53, 117, 67, 79, 56, 117, 151, 94, 230, 96, 96, 89, 192, 109, 191, 107, 137, 120, 252, 83, 213, 150, 203, 81, 1, 82, 137, 99, 10, 84, 147, 148, 3, 140, 204, 141, 57, 114, 159, 120, 118, 135, 237, 143, 13, 140, 224, 83, 147, 121, 148, 121, 149, 121, 150, 121, 151, 121, 152, 121, 153, 121, 155, 121, 156, 121, 157, 121, 158, 121, 159, 121, 160, 121, 161, 121, 162, 121, 163, 121, 164, 121, 165, 121, 166, 121, 168, 121, 169, 121, 170, 121, 171, 121, 172, 121, 173, 121, 174, 121, 175, 121, 176, 121, 177, 121, 178, 121, 180, 121, 181, 121, 182, 121, 183, 121, 184, 121, 188, 121, 191, 121, 194, 121, 196, 121, 197, 121, 199, 121, 200, 121, 202, 121, 204, 121, 206, 121, 207, 121, 208, 121, 211, 121, 212, 121, 214, 121, 215, 121, 217, 121, 218, 121, 219, 121, 220, 121, 221, 121, 222, 121, 224, 121, 225, 121, 226, 121, 229, 121, 232, 121, 234, 121, 236, 121, 238, 121, 241, 121, 242, 121, 243, 121, 244, 121, 245, 121, 246, 121, 247, 121, 249, 121, 250, 121, 252, 121, 254, 121, 255, 121, 1, 122, 4, 122, 5, 122, 7, 122, 8, 122, 9, 122, 10, 122, 12, 122, 15, 122, 16, 122, 17, 122, 18, 122, 19, 122, 21, 122, 22, 122, 24, 122, 25, 122, 27, 122, 28, 122, 1, 78, 239, 118, 238, 83, 137, 148, 118, 152, 14, 159, 45, 149, 154, 91, 162, 139, 34, 78, 28, 78, 172, 81, 99, 132, 194, 97, 168, 82, 11, 104, 151, 79, 107, 96, 187, 81, 30, 109, 92, 81, 150, 98, 151, 101, 97, 150, 70, 140, 23, 144, 216, 117, 253, 144, 99, 119, 210, 107, 138, 114, 236, 114, 251, 139, 53, 88, 121, 119, 76, 141, 92, 103, 64, 149, 154, 128, 166, 94, 33, 110, 146, 89, 239, 122, 237, 119, 59, 149, 181, 107, 173, 101, 14, 127, 6, 88, 81, 81, 31, 150, 249, 91, 169, 88, 40, 84, 114, 142, 102, 101, 127, 152, 228, 86, 157, 148, 254, 118, 65, 144, 135, 99, 198, 84, 26, 89, 58, 89, 155, 87, 178, 142, 53, 103, 250, 141, 53, 130, 65, 82, 240, 96, 21, 88, 254, 134, 232, 92, 69, 158, 196, 79, 157, 152, 185, 139, 37, 90, 118, 96, 132, 83, 124, 98, 79, 144, 2, 145, 127, 153, 105, 96, 12, 128, 63, 81, 51, 128, 20, 92, 117, 153, 49, 109, 140, 78, 29, 122, 31, 122, 33, 122, 34, 122, 36, 122, 37, 122, 38, 122, 39, 122, 40, 122, 41, 122, 42, 122, 43, 122, 44, 122, 45, 122, 46, 122, 47, 122, 48, 122, 49, 122, 50, 122, 52, 122, 53, 122, 54, 122, 56, 122, 58, 122, 62, 122, 64, 122, 65, 122, 66, 122, 67, 122, 68, 122, 69, 122, 71, 122, 72, 122, 73, 122, 74, 122, 75, 122, 76, 122, 77, 122, 78, 122, 79, 122, 80, 122, 82, 122, 83, 122, 84, 122, 85, 122, 86, 122, 88, 122, 89, 122, 90, 122, 91, 122, 92, 122, 93, 122, 94, 122, 95, 122, 96, 122, 97, 122, 98, 122, 99, 122, 100, 122, 101, 122, 102, 122, 103, 122, 104, 122, 105, 122, 106, 122, 107, 122, 108, 122, 109, 122, 110, 122, 111, 122, 113, 122, 114, 122, 115, 122, 117, 122, 123, 122, 124, 122, 125, 122, 126, 122, 130, 122, 133, 122, 135, 122, 137, 122, 138, 122, 139, 122, 140, 122, 142, 122, 143, 122, 144, 122, 147, 122, 148, 122, 153, 122, 154, 122, 155, 122, 158, 122, 161, 122, 162, 122, 48, 141, 209, 83, 90, 127, 79, 123, 16, 79, 79, 78, 0, 150, 213, 108, 208, 115, 233, 133, 6, 94, 106, 117, 251, 127, 10, 106, 254, 119, 146, 148, 65, 126, 225, 81, 230, 112, 205, 83, 212, 143, 3, 131, 41, 141, 175, 114, 109, 153, 219, 108, 74, 87, 179, 130, 185, 101, 170, 128, 63, 98, 50, 150, 168, 89, 255, 78, 191, 139, 186, 126, 62, 101, 242, 131, 94, 151, 97, 85, 222, 152, 165, 128, 42, 83, 253, 139, 32, 84, 186, 128, 159, 94, 184, 108, 57, 141, 172, 130, 90, 145, 41, 84, 27, 108, 6, 82, 183, 126, 95, 87, 26, 113, 126, 108, 137, 124, 75, 89, 253, 78, 255, 95, 36, 97, 170, 124, 48, 78, 1, 92, 171, 103, 2, 135, 240, 92, 11, 149, 206, 152, 175, 117, 253, 112, 34, 144, 175, 81, 29, 127, 189, 139, 73, 89, 228, 81, 91, 79, 38, 84, 43, 89, 119, 101, 164, 128, 117, 91, 118, 98, 194, 98, 144, 143, 69, 94, 31, 108, 38, 123, 15, 79, 216, 79, 13, 103, 163, 122, 164, 122, 167, 122, 169, 122, 170, 122, 171, 122, 174, 122, 175, 122, 176, 122, 177, 122, 178, 122, 180, 122, 181, 122, 182, 122, 183, 122, 184, 122, 185, 122, 186, 122, 187, 122, 188, 122, 189, 122, 190, 122, 192, 122, 193, 122, 194, 122, 195, 122, 196, 122, 197, 122, 198, 122, 199, 122, 200, 122, 201, 122, 202, 122, 204, 122, 205, 122, 206, 122, 207, 122, 208, 122, 209, 122, 210, 122, 211, 122, 212, 122, 213, 122, 215, 122, 216, 122, 218, 122, 219, 122, 220, 122, 221, 122, 225, 122, 226, 122, 228, 122, 231, 122, 232, 122, 233, 122, 234, 122, 235, 122, 236, 122, 238, 122, 240, 122, 241, 122, 242, 122, 243, 122, 244, 122, 245, 122, 246, 122, 247, 122, 248, 122, 251, 122, 252, 122, 254, 122, 0, 123, 1, 123, 2, 123, 5, 123, 7, 123, 9, 123, 12, 123, 13, 123, 14, 123, 16, 123, 18, 123, 19, 123, 22, 123, 23, 123, 24, 123, 26, 123, 28, 123, 29, 123, 31, 123, 33, 123, 34, 123, 35, 123, 39, 123, 41, 123, 45, 123, 110, 109, 170, 109, 143, 121, 177, 136, 23, 95, 43, 117, 154, 98, 133, 143, 239, 79, 220, 145, 167, 101, 47, 129, 81, 129, 156, 94, 80, 129, 116, 141, 111, 82, 134, 137, 75, 141, 13, 89, 133, 80, 216, 78, 28, 150, 54, 114, 121, 129, 31, 141, 204, 91, 163, 139, 68, 150, 135, 89, 26, 127, 144, 84, 118, 86, 14, 86, 229, 139, 57, 101, 130, 105, 153, 148, 214, 118, 137, 110, 114, 94, 24, 117, 70, 103, 209, 103, 255, 122, 157, 128, 118, 141, 31, 97, 198, 121, 98, 101, 99, 141, 136, 81, 26, 82, 162, 148, 56, 127, 155, 128, 178, 126, 151, 92, 47, 110, 96, 103, 217, 123, 139, 118, 216, 154, 143, 129, 148, 127, 213, 124, 30, 100, 80, 149, 63, 122, 74, 84, 229, 84, 76, 107, 1, 100, 8, 98, 61, 158, 243, 128, 153, 117, 114, 82, 105, 151, 91, 132, 60, 104, 228, 134, 1, 150, 148, 150, 236, 148, 42, 78, 4, 84, 217, 126, 57, 104, 223, 141, 21, 128, 244, 102, 154, 94, 185, 127, 47, 123, 48, 123, 50, 123, 52, 123, 53, 123, 54, 123, 55, 123, 57, 123, 59, 123, 61, 123, 63, 123, 64, 123, 65, 123, 66, 123, 67, 123, 68, 123, 70, 123, 72, 123, 74, 123, 77, 123, 78, 123, 83, 123, 85, 123, 87, 123, 89, 123, 92, 123, 94, 123, 95, 123, 97, 123, 99, 123, 100, 123, 101, 123, 102, 123, 103, 123, 104, 123, 105, 123, 106, 123, 107, 123, 108, 123, 109, 123, 111, 123, 112, 123, 115, 123, 116, 123, 118, 123, 120, 123, 122, 123, 124, 123, 125, 123, 127, 123, 129, 123, 130, 123, 131, 123, 132, 123, 134, 123, 135, 123, 136, 123, 137, 123, 138, 123, 139, 123, 140, 123, 142, 123, 143, 123, 145, 123, 146, 123, 147, 123, 150, 123, 152, 123, 153, 123, 154, 123, 155, 123, 158, 123, 159, 123, 160, 123, 163, 123, 164, 123, 165, 123, 174, 123, 175, 123, 176, 123, 178, 123, 179, 123, 181, 123, 182, 123, 183, 123, 185, 123, 186, 123, 187, 123, 188, 123, 189, 123, 190, 123, 191, 123, 192, 123, 194, 123, 195, 123, 196, 123, 194, 87, 63, 128, 151, 104, 229, 93, 59, 101, 159, 82, 109, 96, 154, 159, 155, 79, 172, 142, 108, 81, 171, 91, 19, 95, 233, 93, 94, 108, 241, 98, 33, 141, 113, 81, 169, 148, 254, 82, 159, 108, 223, 130, 215, 114, 162, 87, 132, 103, 45, 141, 31, 89, 156, 143, 199, 131, 149, 84, 141, 123, 48, 79, 189, 108, 100, 91, 209, 89, 19, 159, 228, 83, 202, 134, 168, 154, 55, 140, 161, 128, 69, 101, 126, 152, 250, 86, 199, 150, 46, 82, 220, 116, 80, 82, 225, 91, 2, 99, 2, 137, 86, 78, 208, 98, 42, 96, 250, 104, 115, 81, 152, 91, 160, 81, 194, 137, 161, 123, 134, 153, 80, 127, 239, 96, 76, 112, 47, 141, 73, 81, 127, 94, 27, 144, 112, 116, 196, 137, 45, 87, 69, 120, 82, 95, 159, 159, 250, 149, 104, 143, 60, 155, 225, 139, 120, 118, 66, 104, 220, 103, 234, 141, 53, 141, 61, 82, 138, 143, 218, 110, 205, 104, 5, 149, 237, 144, 253, 86, 156, 103, 249, 136, 199, 143, 200, 84, 197, 123, 200, 123, 201, 123, 202, 123, 203, 123, 205, 123, 206, 123, 207, 123, 208, 123, 210, 123, 212, 123, 213, 123, 214, 123, 215, 123, 216, 123, 219, 123, 220, 123, 222, 123, 223, 123, 224, 123, 226, 123, 227, 123, 228, 123, 231, 123, 232, 123, 233, 123, 235, 123, 236, 123, 237, 123, 239, 123, 240, 123, 242, 123, 243, 123, 244, 123, 245, 123, 246, 123, 248, 123, 249, 123, 250, 123, 251, 123, 253, 123, 255, 123, 0, 124, 1, 124, 2, 124, 3, 124, 4, 124, 5, 124, 6, 124, 8, 124, 9, 124, 10, 124, 13, 124, 14, 124, 16, 124, 17, 124, 18, 124, 19, 124, 20, 124, 21, 124, 23, 124, 24, 124, 25, 124, 26, 124, 27, 124, 28, 124, 29, 124, 30, 124, 32, 124, 33, 124, 34, 124, 35, 124, 36, 124, 37, 124, 40, 124, 41, 124, 43, 124, 44, 124, 45, 124, 46, 124, 47, 124, 48, 124, 49, 124, 50, 124, 51, 124, 52, 124, 53, 124, 54, 124, 55, 124, 57, 124, 58, 124, 59, 124, 60, 124, 61, 124, 62, 124, 66, 124, 184, 154, 105, 91, 119, 109, 38, 108, 165, 78, 179, 91, 135, 154, 99, 145, 168, 97, 175, 144, 233, 151, 43, 84, 181, 109, 210, 91, 253, 81, 138, 85, 85, 127, 240, 127, 188, 100, 77, 99, 241, 101, 190, 97, 141, 96, 10, 113, 87, 108, 73, 108, 47, 89, 109, 103, 42, 130, 213, 88, 142, 86, 106, 140, 235, 107, 221, 144, 125, 89, 23, 128, 247, 83, 105, 109, 117, 84, 157, 85, 119, 131, 207, 131, 56, 104, 190, 121, 140, 84, 85, 79, 8, 84, 210, 118, 137, 140, 2, 150, 179, 108, 184, 109, 107, 141, 16, 137, 100, 158, 58, 141, 63, 86, 209, 158, 213, 117, 136, 95, 224, 114, 104, 96, 252, 84, 168, 78, 42, 106, 97, 136, 82, 96, 112, 143, 196, 84, 216, 112, 121, 134, 63, 158, 42, 109, 143, 91, 24, 95, 162, 126, 137, 85, 175, 79, 52, 115, 60, 84, 154, 83, 25, 80, 14, 84, 124, 84, 78, 78, 253, 95, 90, 116, 246, 88, 107, 132, 225, 128, 116, 135, 208, 114, 202, 124, 86, 110, 67, 124, 68, 124, 69, 124, 70, 124, 71, 124, 72, 124, 73, 124, 74, 124, 75, 124, 76, 124, 78, 124, 79, 124, 80, 124, 81, 124, 82, 124, 83, 124, 84, 124, 85, 124, 86, 124, 87, 124, 88, 124, 89, 124, 90, 124, 91, 124, 92, 124, 93, 124, 94, 124, 95, 124, 96, 124, 97, 124, 98, 124, 99, 124, 100, 124, 101, 124, 102, 124, 103, 124, 104, 124, 105, 124, 106, 124, 107, 124, 108, 124, 109, 124, 110, 124, 111, 124, 112, 124, 113, 124, 114, 124, 117, 124, 118, 124, 119, 124, 120, 124, 121, 124, 122, 124, 126, 124, 127, 124, 128, 124, 129, 124, 130, 124, 131, 124, 132, 124, 133, 124, 134, 124, 135, 124, 136, 124, 138, 124, 139, 124, 140, 124, 141, 124, 142, 124, 143, 124, 144, 124, 147, 124, 148, 124, 150, 124, 153, 124, 154, 124, 155, 124, 160, 124, 161, 124, 163, 124, 166, 124, 167, 124, 168, 124, 169, 124, 171, 124, 172, 124, 173, 124, 175, 124, 176, 124, 180, 124, 181, 124, 182, 124, 183, 124, 184, 124, 186, 124, 187, 124, 39, 95, 78, 134, 44, 85, 164, 98, 146, 78, 170, 108, 55, 98, 177, 130, 215, 84, 78, 83, 62, 115, 209, 110, 59, 117, 18, 82, 22, 83, 221, 139, 208, 105, 138, 95, 0, 96, 238, 109, 79, 87, 34, 107, 175, 115, 83, 104, 216, 143, 19, 127, 98, 99, 163, 96, 36, 85, 234, 117, 98, 140, 21, 113, 163, 109, 166, 91, 123, 94, 82, 131, 76, 97, 196, 158, 250, 120, 87, 135, 39, 124, 135, 118, 240, 81, 246, 96, 76, 113, 67, 102, 76, 94, 77, 96, 14, 140, 112, 112, 37, 99, 137, 143, 189, 95, 98, 96, 212, 134, 222, 86, 193, 107, 148, 96, 103, 97, 73, 83, 224, 96, 102, 102, 63, 141, 253, 121, 26, 79, 233, 112, 71, 108, 179, 139, 242, 139, 216, 126, 100, 131, 15, 102, 90, 90, 66, 155, 81, 109, 247, 109, 65, 140, 59, 109, 25, 79, 107, 112, 183, 131, 22, 98, 209, 96, 13, 151, 39, 141, 120, 121, 251, 81, 62, 87, 250, 87, 58, 103, 120, 117, 61, 122, 239, 121, 149, 123, 191, 124, 192, 124, 194, 124, 195, 124, 196, 124, 198, 124, 201, 124, 203, 124, 206, 124, 207, 124, 208, 124, 209, 124, 210, 124, 211, 124, 212, 124, 216, 124, 218, 124, 219, 124, 221, 124, 222, 124, 225, 124, 226, 124, 227, 124, 228, 124, 229, 124, 230, 124, 231, 124, 233, 124, 234, 124, 235, 124, 236, 124, 237, 124, 238, 124, 240, 124, 241, 124, 242, 124, 243, 124, 244, 124, 245, 124, 246, 124, 247, 124, 249, 124, 250, 124, 252, 124, 253, 124, 254, 124, 255, 124, 0, 125, 1, 125, 2, 125, 3, 125, 4, 125, 5, 125, 6, 125, 7, 125, 8, 125, 9, 125, 11, 125, 12, 125, 13, 125, 14, 125, 15, 125, 16, 125, 17, 125, 18, 125, 19, 125, 20, 125, 21, 125, 22, 125, 23, 125, 24, 125, 25, 125, 26, 125, 27, 125, 28, 125, 29, 125, 30, 125, 31, 125, 33, 125, 35, 125, 36, 125, 37, 125, 38, 125, 40, 125, 41, 125, 42, 125, 44, 125, 45, 125, 46, 125, 48, 125, 49, 125, 50, 125, 51, 125, 52, 125, 53, 125, 54, 125, 140, 128, 101, 153, 249, 143, 192, 111, 165, 139, 33, 158, 236, 89, 233, 126, 9, 127, 9, 84, 129, 103, 216, 104, 145, 143, 77, 124, 198, 150, 202, 83, 37, 96, 190, 117, 114, 108, 115, 83, 201, 90, 167, 126, 36, 99, 224, 81, 10, 129, 241, 93, 223, 132, 128, 98, 128, 81, 99, 91, 14, 79, 109, 121, 66, 82, 184, 96, 78, 109, 196, 91, 194, 91, 161, 139, 176, 139, 226, 101, 204, 95, 69, 150, 147, 89, 231, 126, 170, 126, 9, 86, 183, 103, 57, 89, 115, 79, 182, 91, 160, 82, 90, 131, 138, 152, 62, 141, 50, 117, 190, 148, 71, 80, 60, 122, 247, 78, 182, 103, 126, 154, 193, 90, 124, 107, 209, 118, 90, 87, 22, 92, 58, 123, 244, 149, 78, 113, 124, 81, 169, 128, 112, 130, 120, 89, 4, 127, 39, 131, 192, 104, 236, 103, 177, 120, 119, 120, 227, 98, 97, 99, 128, 123, 237, 79, 106, 82, 207, 81, 80, 131, 219, 105, 116, 146, 245, 141, 49, 141, 193, 137, 46, 149, 173, 123, 246, 78, 55, 125, 56, 125, 57, 125, 58, 125, 59, 125, 60, 125, 61, 125, 62, 125, 63, 125, 64, 125, 65, 125, 66, 125, 67, 125, 68, 125, 69, 125, 70, 125, 71, 125, 72, 125, 73, 125, 74, 125, 75, 125, 76, 125, 77, 125, 78, 125, 79, 125, 80, 125, 81, 125, 82, 125, 83, 125, 84, 125, 85, 125, 86, 125, 87, 125, 88, 125, 89, 125, 90, 125, 91, 125, 92, 125, 93, 125, 94, 125, 95, 125, 96, 125, 97, 125, 98, 125, 99, 125, 100, 125, 101, 125, 102, 125, 103, 125, 104, 125, 105, 125, 106, 125, 107, 125, 108, 125, 109, 125, 111, 125, 112, 125, 113, 125, 114, 125, 115, 125, 116, 125, 117, 125, 118, 125, 120, 125, 121, 125, 122, 125, 123, 125, 124, 125, 125, 125, 126, 125, 127, 125, 128, 125, 129, 125, 130, 125, 131, 125, 132, 125, 133, 125, 134, 125, 135, 125, 136, 125, 137, 125, 138, 125, 139, 125, 140, 125, 141, 125, 142, 125, 143, 125, 144, 125, 145, 125, 146, 125, 147, 125, 148, 125, 149, 125, 150, 125, 151, 125, 152, 125, 101, 80, 48, 130, 81, 82, 111, 153, 16, 110, 133, 110, 167, 109, 250, 94, 245, 80, 220, 89, 6, 92, 70, 109, 95, 108, 134, 117, 139, 132, 104, 104, 86, 89, 178, 139, 32, 83, 113, 145, 77, 150, 73, 133, 18, 105, 1, 121, 38, 113, 246, 128, 164, 78, 202, 144, 71, 109, 132, 154, 7, 90, 188, 86, 5, 100, 240, 148, 235, 119, 165, 79, 26, 129, 225, 114, 210, 137, 122, 153, 52, 127, 222, 126, 127, 82, 89, 101, 117, 145, 127, 143, 131, 143, 235, 83, 150, 122, 237, 99, 165, 99, 134, 118, 248, 121, 87, 136, 54, 150, 42, 98, 171, 82, 130, 130, 84, 104, 112, 103, 119, 99, 107, 119, 237, 122, 1, 109, 211, 126, 227, 137, 208, 89, 18, 98, 201, 133, 165, 130, 76, 117, 31, 80, 203, 78, 165, 117, 235, 139, 74, 92, 254, 93, 75, 123, 164, 101, 209, 145, 202, 78, 37, 109, 95, 137, 39, 125, 38, 149, 197, 78, 40, 140, 219, 143, 115, 151, 75, 102, 129, 121, 209, 143, 236, 112, 120, 109, 153, 125, 154, 125, 155, 125, 156, 125, 157, 125, 158, 125, 159, 125, 160, 125, 161, 125, 162, 125, 163, 125, 164, 125, 165, 125, 167, 125, 168, 125, 169, 125, 170, 125, 171, 125, 172, 125, 173, 125, 175, 125, 176, 125, 177, 125, 178, 125, 179, 125, 180, 125, 181, 125, 182, 125, 183, 125, 184, 125, 185, 125, 186, 125, 187, 125, 188, 125, 189, 125, 190, 125, 191, 125, 192, 125, 193, 125, 194, 125, 195, 125, 196, 125, 197, 125, 198, 125, 199, 125, 200, 125, 201, 125, 202, 125, 203, 125, 204, 125, 205, 125, 206, 125, 207, 125, 208, 125, 209, 125, 210, 125, 211, 125, 212, 125, 213, 125, 214, 125, 215, 125, 216, 125, 217, 125, 218, 125, 219, 125, 220, 125, 221, 125, 222, 125, 223, 125, 224, 125, 225, 125, 226, 125, 227, 125, 228, 125, 229, 125, 230, 125, 231, 125, 232, 125, 233, 125, 234, 125, 235, 125, 236, 125, 237, 125, 238, 125, 239, 125, 240, 125, 241, 125, 242, 125, 243, 125, 244, 125, 245, 125, 246, 125, 247, 125, 248, 125, 249, 125, 250, 125, 61, 92, 178, 82, 70, 131, 98, 81, 14, 131, 91, 119, 118, 102, 184, 156, 172, 78, 202, 96, 190, 124, 179, 124, 207, 126, 149, 78, 102, 139, 111, 102, 136, 152, 89, 151, 131, 88, 108, 101, 92, 149, 132, 95, 201, 117, 86, 151, 223, 122, 222, 122, 192, 81, 175, 112, 152, 122, 234, 99, 118, 122, 160, 126, 150, 115, 237, 151, 69, 78, 120, 112, 93, 78, 82, 145, 169, 83, 81, 101, 231, 101, 252, 129, 5, 130, 142, 84, 49, 92, 154, 117, 160, 151, 216, 98, 217, 114, 189, 117, 69, 92, 121, 154, 202, 131, 64, 92, 128, 84, 233, 119, 62, 78, 174, 108, 90, 128, 210, 98, 110, 99, 232, 93, 119, 81, 221, 141, 30, 142, 47, 149, 241, 79, 229, 83, 231, 96, 172, 112, 103, 82, 80, 99, 67, 158, 31, 90, 38, 80, 55, 119, 119, 83, 226, 126, 133, 100, 43, 101, 137, 98, 152, 99, 20, 80, 53, 114, 201, 137, 179, 81, 192, 139, 221, 126, 71, 87, 204, 131, 167, 148, 155, 81, 27, 84, 251, 92, 251, 125, 252, 125, 253, 125, 254, 125, 255, 125, 0, 126, 1, 126, 2, 126, 3, 126, 4, 126, 5, 126, 6, 126, 7, 126, 8, 126, 9, 126, 10, 126, 11, 126, 12, 126, 13, 126, 14, 126, 15, 126, 16, 126, 17, 126, 18, 126, 19, 126, 20, 126, 21, 126, 22, 126, 23, 126, 24, 126, 25, 126, 26, 126, 27, 126, 28, 126, 29, 126, 30, 126, 31, 126, 32, 126, 33, 126, 34, 126, 35, 126, 36, 126, 37, 126, 38, 126, 39, 126, 40, 126, 41, 126, 42, 126, 43, 126, 44, 126, 45, 126, 46, 126, 47, 126, 48, 126, 49, 126, 50, 126, 51, 126, 52, 126, 53, 126, 54, 126, 55, 126, 56, 126, 57, 126, 58, 126, 60, 126, 61, 126, 62, 126, 63, 126, 64, 126, 66, 126, 67, 126, 68, 126, 69, 126, 70, 126, 72, 126, 73, 126, 74, 126, 75, 126, 76, 126, 77, 126, 78, 126, 79, 126, 80, 126, 81, 126, 82, 126, 83, 126, 84, 126, 85, 126, 86, 126, 87, 126, 88, 126, 89, 126, 90, 126, 91, 126, 92, 126, 93, 126, 202, 79, 227, 122, 90, 109, 225, 144, 143, 154, 128, 85, 150, 84, 97, 83, 175, 84, 0, 95, 233, 99, 119, 105, 239, 81, 104, 97, 10, 82, 42, 88, 216, 82, 78, 87, 13, 120, 11, 119, 183, 94, 119, 97, 224, 124, 91, 98, 151, 98, 162, 78, 149, 112, 3, 128, 247, 98, 228, 112, 96, 151, 119, 87, 219, 130, 239, 103, 245, 104, 213, 120, 151, 152, 209, 121, 243, 88, 179, 84, 239, 83, 52, 110, 75, 81, 59, 82, 162, 91, 254, 139, 175, 128, 67, 85, 166, 87, 115, 96, 81, 87, 45, 84, 122, 122, 80, 96, 84, 91, 167, 99, 160, 98, 227, 83, 99, 98, 199, 91, 175, 103, 237, 84, 159, 122, 230, 130, 119, 145, 147, 94, 228, 136, 56, 89, 174, 87, 14, 99, 232, 141, 239, 128, 87, 87, 119, 123, 169, 79, 235, 95, 189, 91, 62, 107, 33, 83, 80, 123, 194, 114, 70, 104, 255, 119, 54, 119, 247, 101, 181, 81, 143, 78, 212, 118, 191, 92, 165, 122, 117, 132, 78, 89, 65, 155, 128, 80, 94, 126, 95, 126, 96, 126, 97, 126, 98, 126, 99, 126, 100, 126, 101, 126, 102, 126, 103, 126, 104, 126, 105, 126, 106, 126, 107, 126, 108, 126, 109, 126, 110, 126, 111, 126, 112, 126, 113, 126, 114, 126, 115, 126, 116, 126, 117, 126, 118, 126, 119, 126, 120, 126, 121, 126, 122, 126, 123, 126, 124, 126, 125, 126, 126, 126, 127, 126, 128, 126, 129, 126, 131, 126, 132, 126, 133, 126, 134, 126, 135, 126, 136, 126, 137, 126, 138, 126, 139, 126, 140, 126, 141, 126, 142, 126, 143, 126, 144, 126, 145, 126, 146, 126, 147, 126, 148, 126, 149, 126, 150, 126, 151, 126, 152, 126, 153, 126, 154, 126, 156, 126, 157, 126, 158, 126, 174, 126, 180, 126, 187, 126, 188, 126, 214, 126, 228, 126, 236, 126, 249, 126, 10, 127, 16, 127, 30, 127, 55, 127, 57, 127, 59, 127, 60, 127, 61, 127, 62, 127, 63, 127, 64, 127, 65, 127, 67, 127, 70, 127, 71, 127, 72, 127, 73, 127, 74, 127, 75, 127, 76, 127, 77, 127, 78, 127, 79, 127, 82, 127, 83, 127, 136, 153, 39, 97, 131, 110, 100, 87, 6, 102, 70, 99, 240, 86, 236, 98, 105, 98, 211, 94, 20, 150, 131, 87, 201, 98, 135, 85, 33, 135, 74, 129, 163, 143, 102, 85, 177, 131, 101, 103, 86, 141, 221, 132, 106, 90, 15, 104, 230, 98, 238, 123, 17, 150, 112, 81, 156, 111, 48, 140, 253, 99, 200, 137, 210, 97, 6, 127, 194, 112, 229, 110, 5, 116, 148, 105, 252, 114, 202, 94, 206, 144, 23, 103, 106, 109, 94, 99, 179, 82, 98, 114, 1, 128, 108, 79, 229, 89, 106, 145, 217, 112, 157, 109, 210, 82, 80, 78, 247, 150, 109, 149, 126, 133, 202, 120, 47, 125, 33, 81, 146, 87, 194, 100, 139, 128, 123, 124, 234, 108, 241, 104, 94, 105, 183, 81, 152, 83, 168, 104, 129, 114, 206, 158, 241, 123, 248, 114, 187, 121, 19, 111, 6, 116, 78, 103, 204, 145, 164, 156, 60, 121, 137, 131, 84, 131, 15, 84, 23, 104, 61, 78, 137, 83, 177, 82, 62, 120, 134, 83, 41, 82, 136, 80, 139, 79, 208, 79, 86, 127, 89, 127, 91, 127, 92, 127, 93, 127, 94, 127, 96, 127, 99, 127, 100, 127, 101, 127, 102, 127, 103, 127, 107, 127, 108, 127, 109, 127, 111, 127, 112, 127, 115, 127, 117, 127, 118, 127, 119, 127, 120, 127, 122, 127, 123, 127, 124, 127, 125, 127, 127, 127, 128, 127, 130, 127, 131, 127, 132, 127, 133, 127, 134, 127, 135, 127, 136, 127, 137, 127, 139, 127, 141, 127, 143, 127, 144, 127, 145, 127, 146, 127, 147, 127, 149, 127, 150, 127, 151, 127, 152, 127, 153, 127, 155, 127, 156, 127, 160, 127, 162, 127, 163, 127, 165, 127, 166, 127, 168, 127, 169, 127, 170, 127, 171, 127, 172, 127, 173, 127, 174, 127, 177, 127, 179, 127, 180, 127, 181, 127, 182, 127, 183, 127, 186, 127, 187, 127, 190, 127, 192, 127, 194, 127, 195, 127, 196, 127, 198, 127, 199, 127, 200, 127, 201, 127, 203, 127, 205, 127, 207, 127, 208, 127, 209, 127, 210, 127, 211, 127, 214, 127, 215, 127, 217, 127, 218, 127, 219, 127, 220, 127, 221, 127, 222, 127, 226, 127, 227, 127, 226, 117, 203, 122, 146, 124, 165, 108, 182, 150, 155, 82, 131, 116, 233, 84, 233, 79, 84, 128, 178, 131, 222, 143, 112, 149, 201, 94, 28, 96, 159, 109, 24, 94, 91, 101, 56, 129, 254, 148, 75, 96, 188, 112, 195, 126, 174, 124, 201, 81, 129, 104, 177, 124, 111, 130, 36, 78, 134, 143, 207, 145, 126, 102, 174, 78, 5, 140, 169, 100, 74, 128, 218, 80, 151, 117, 206, 113, 229, 91, 189, 143, 102, 111, 134, 78, 130, 100, 99, 149, 214, 94, 153, 101, 23, 82, 194, 136, 200, 112, 163, 82, 14, 115, 51, 116, 151, 103, 247, 120, 22, 151, 52, 78, 187, 144, 222, 156, 203, 109, 219, 81, 65, 141, 29, 84, 206, 98, 178, 115, 241, 131, 246, 150, 132, 159, 195, 148, 54, 79, 154, 127, 204, 81, 117, 112, 117, 150, 173, 92, 134, 152, 230, 83, 228, 78, 156, 110, 9, 116, 180, 105, 107, 120, 143, 153, 89, 117, 24, 82, 36, 118, 65, 109, 243, 103, 109, 81, 153, 159, 75, 128, 153, 84, 60, 123, 191, 122, 228, 127, 231, 127, 232, 127, 234, 127, 235, 127, 236, 127, 237, 127, 239, 127, 242, 127, 244, 127, 245, 127, 246, 127, 247, 127, 248, 127, 249, 127, 250, 127, 253, 127, 254, 127, 255, 127, 2, 128, 7, 128, 8, 128, 9, 128, 10, 128, 14, 128, 15, 128, 17, 128, 19, 128, 26, 128, 27, 128, 29, 128, 30, 128, 31, 128, 33, 128, 35, 128, 36, 128, 43, 128, 44, 128, 45, 128, 46, 128, 47, 128, 48, 128, 50, 128, 52, 128, 57, 128, 58, 128, 60, 128, 62, 128, 64, 128, 65, 128, 68, 128, 69, 128, 71, 128, 72, 128, 73, 128, 78, 128, 79, 128, 80, 128, 81, 128, 83, 128, 85, 128, 86, 128, 87, 128, 89, 128, 91, 128, 92, 128, 93, 128, 94, 128, 95, 128, 96, 128, 97, 128, 98, 128, 99, 128, 100, 128, 101, 128, 102, 128, 103, 128, 104, 128, 107, 128, 108, 128, 109, 128, 110, 128, 111, 128, 112, 128, 114, 128, 115, 128, 116, 128, 117, 128, 118, 128, 119, 128, 120, 128, 121, 128, 122, 128, 123, 128, 124, 128, 125, 128, 134, 150, 132, 87, 226, 98, 71, 150, 124, 105, 4, 90, 2, 100, 211, 123, 15, 111, 75, 150, 166, 130, 98, 83, 133, 152, 144, 94, 137, 112, 179, 99, 100, 83, 79, 134, 129, 156, 147, 158, 140, 120, 50, 151, 239, 141, 66, 141, 127, 158, 94, 111, 132, 121, 85, 95, 70, 150, 46, 98, 116, 154, 21, 84, 221, 148, 163, 79, 197, 101, 101, 92, 97, 92, 21, 127, 81, 134, 47, 108, 139, 95, 135, 115, 228, 110, 255, 126, 230, 92, 27, 99, 106, 91, 230, 110, 117, 83, 113, 78, 160, 99, 101, 117, 161, 98, 110, 143, 38, 79, 209, 78, 166, 108, 182, 126, 186, 139, 29, 132, 186, 135, 87, 127, 59, 144, 35, 149, 169, 123, 161, 154, 248, 136, 61, 132, 27, 109, 134, 154, 220, 126, 136, 89, 187, 158, 155, 115, 1, 120, 130, 134, 108, 154, 130, 154, 27, 86, 23, 84, 203, 87, 112, 78, 166, 158, 86, 83, 200, 143, 9, 129, 146, 119, 146, 153, 238, 134, 225, 110, 19, 133, 252, 102, 98, 97, 43, 111, 126, 128, 129, 128, 130, 128, 133, 128, 136, 128, 138, 128, 141, 128, 142, 128, 143, 128, 144, 128, 145, 128, 146, 128, 148, 128, 149, 128, 151, 128, 153, 128, 158, 128, 163, 128, 166, 128, 167, 128, 168, 128, 172, 128, 176, 128, 179, 128, 181, 128, 182, 128, 184, 128, 185, 128, 187, 128, 197, 128, 199, 128, 200, 128, 201, 128, 202, 128, 203, 128, 207, 128, 208, 128, 209, 128, 210, 128, 211, 128, 212, 128, 213, 128, 216, 128, 223, 128, 224, 128, 226, 128, 227, 128, 230, 128, 238, 128, 245, 128, 247, 128, 249, 128, 251, 128, 254, 128, 255, 128, 0, 129, 1, 129, 3, 129, 4, 129, 5, 129, 7, 129, 8, 129, 11, 129, 12, 129, 21, 129, 23, 129, 25, 129, 27, 129, 28, 129, 29, 129, 31, 129, 32, 129, 33, 129, 34, 129, 35, 129, 36, 129, 37, 129, 38, 129, 39, 129, 40, 129, 41, 129, 42, 129, 43, 129, 45, 129, 46, 129, 48, 129, 51, 129, 52, 129, 53, 129, 55, 129, 57, 129, 58, 129, 59, 129, 60, 129, 61, 129, 63, 129, 41, 140, 146, 130, 43, 131, 242, 118, 19, 108, 217, 95, 189, 131, 43, 115, 5, 131, 26, 149, 219, 107, 219, 119, 198, 148, 111, 83, 2, 131, 146, 81, 61, 94, 140, 140, 56, 141, 72, 78, 171, 115, 154, 103, 133, 104, 118, 145, 9, 151, 100, 113, 161, 108, 9, 119, 146, 90, 65, 149, 207, 107, 142, 127, 39, 102, 208, 91, 185, 89, 154, 90, 232, 149, 247, 149, 236, 78, 12, 132, 153, 132, 172, 106, 223, 118, 48, 149, 27, 115, 166, 104, 95, 91, 47, 119, 154, 145, 97, 151, 220, 124, 247, 143, 28, 140, 37, 95, 115, 124, 216, 121, 197, 137, 204, 108, 28, 135, 198, 91, 66, 94, 201, 104, 32, 119, 245, 126, 149, 81, 77, 81, 201, 82, 41, 90, 5, 127, 98, 151, 215, 130, 207, 99, 132, 119, 208, 133, 210, 121, 58, 110, 153, 94, 153, 89, 17, 133, 109, 112, 17, 108, 191, 98, 191, 118, 79, 101, 175, 96, 253, 149, 14, 102, 159, 135, 35, 158, 237, 148, 13, 84, 125, 84, 44, 140, 120, 100, 64, 129, 65, 129, 66, 129, 67, 129, 68, 129, 69, 129, 71, 129, 73, 129, 77, 129, 78, 129, 79, 129, 82, 129, 86, 129, 87, 129, 88, 129, 91, 129, 92, 129, 93, 129, 94, 129, 95, 129, 97, 129, 98, 129, 99, 129, 100, 129, 102, 129, 104, 129, 106, 129, 107, 129, 108, 129, 111, 129, 114, 129, 115, 129, 117, 129, 118, 129, 119, 129, 120, 129, 129, 129, 131, 129, 132, 129, 133, 129, 134, 129, 135, 129, 137, 129, 139, 129, 140, 129, 141, 129, 142, 129, 144, 129, 146, 129, 147, 129, 148, 129, 149, 129, 150, 129, 151, 129, 153, 129, 154, 129, 158, 129, 159, 129, 160, 129, 161, 129, 162, 129, 164, 129, 165, 129, 167, 129, 169, 129, 171, 129, 172, 129, 173, 129, 174, 129, 175, 129, 176, 129, 177, 129, 178, 129, 180, 129, 181, 129, 182, 129, 183, 129, 184, 129, 185, 129, 188, 129, 189, 129, 190, 129, 191, 129, 196, 129, 197, 129, 199, 129, 200, 129, 201, 129, 203, 129, 205, 129, 206, 129, 207, 129, 208, 129, 209, 129, 210, 129, 211, 129, 121, 100, 17, 134, 33, 106, 156, 129, 232, 120, 105, 100, 84, 155, 185, 98, 43, 103, 171, 131, 168, 88, 216, 158, 171, 108, 32, 111, 222, 91, 76, 150, 11, 140, 95, 114, 208, 103, 199, 98, 97, 114, 169, 78, 198, 89, 205, 107, 147, 88, 174, 102, 85, 94, 223, 82, 85, 97, 40, 103, 238, 118, 102, 119, 103, 114, 70, 122, 255, 98, 234, 84, 80, 84, 160, 148, 163, 144, 28, 90, 179, 126, 22, 108, 67, 78, 118, 89, 16, 128, 72, 89, 87, 83, 55, 117, 190, 150, 202, 86, 32, 99, 17, 129, 124, 96, 249, 149, 214, 109, 98, 84, 129, 153, 133, 81, 233, 90, 253, 128, 174, 89, 19, 151, 42, 80, 229, 108, 60, 92, 223, 98, 96, 79, 63, 83, 123, 129, 6, 144, 186, 110, 43, 133, 200, 98, 116, 94, 190, 120, 181, 100, 123, 99, 245, 95, 24, 90, 127, 145, 31, 158, 63, 92, 79, 99, 66, 128, 125, 91, 110, 85, 74, 149, 77, 149, 133, 109, 168, 96, 224, 103, 222, 114, 221, 81, 129, 91, 212, 129, 213, 129, 214, 129, 215, 129, 216, 129, 217, 129, 218, 129, 219, 129, 220, 129, 221, 129, 222, 129, 223, 129, 224, 129, 225, 129, 226, 129, 228, 129, 229, 129, 230, 129, 232, 129, 233, 129, 235, 129, 238, 129, 239, 129, 240, 129, 241, 129, 242, 129, 245, 129, 246, 129, 247, 129, 248, 129, 249, 129, 250, 129, 253, 129, 255, 129, 3, 130, 7, 130, 8, 130, 9, 130, 10, 130, 11, 130, 14, 130, 15, 130, 17, 130, 19, 130, 21, 130, 22, 130, 23, 130, 24, 130, 25, 130, 26, 130, 29, 130, 32, 130, 36, 130, 37, 130, 38, 130, 39, 130, 41, 130, 46, 130, 50, 130, 58, 130, 60, 130, 61, 130, 63, 130, 64, 130, 65, 130, 66, 130, 67, 130, 69, 130, 70, 130, 72, 130, 74, 130, 76, 130, 77, 130, 78, 130, 80, 130, 81, 130, 82, 130, 83, 130, 84, 130, 85, 130, 86, 130, 87, 130, 89, 130, 91, 130, 92, 130, 93, 130, 94, 130, 96, 130, 97, 130, 98, 130, 99, 130, 100, 130, 101, 130, 102, 130, 103, 130, 105, 130, 231, 98, 222, 108, 91, 114, 109, 98, 174, 148, 189, 126, 19, 129, 83, 109, 156, 81, 4, 95, 116, 89, 170, 82, 18, 96, 115, 89, 150, 102, 80, 134, 159, 117, 42, 99, 230, 97, 239, 124, 250, 139, 230, 84, 39, 107, 37, 158, 180, 107, 213, 133, 85, 84, 118, 80, 164, 108, 106, 85, 180, 141, 44, 114, 21, 94, 21, 96, 54, 116, 205, 98, 146, 99, 76, 114, 152, 95, 67, 110, 62, 109, 0, 101, 88, 111, 216, 118, 208, 120, 252, 118, 84, 117, 36, 82, 219, 83, 83, 78, 158, 94, 193, 101, 42, 128, 214, 128, 155, 98, 134, 84, 40, 82, 174, 112, 141, 136, 209, 141, 225, 108, 120, 84, 218, 128, 249, 87, 244, 136, 84, 141, 106, 150, 77, 145, 105, 79, 155, 108, 183, 85, 198, 118, 48, 120, 168, 98, 249, 112, 142, 111, 109, 95, 236, 132, 218, 104, 124, 120, 247, 123, 168, 129, 11, 103, 79, 158, 103, 99, 176, 120, 111, 87, 18, 120, 57, 151, 121, 98, 171, 98, 136, 82, 53, 116, 215, 107, 106, 130, 107, 130, 108, 130, 109, 130, 113, 130, 117, 130, 118, 130, 119, 130, 120, 130, 123, 130, 124, 130, 128, 130, 129, 130, 131, 130, 133, 130, 134, 130, 135, 130, 137, 130, 140, 130, 144, 130, 147, 130, 148, 130, 149, 130, 150, 130, 154, 130, 155, 130, 158, 130, 160, 130, 162, 130, 163, 130, 167, 130, 178, 130, 181, 130, 182, 130, 186, 130, 187, 130, 188, 130, 191, 130, 192, 130, 194, 130, 195, 130, 197, 130, 198, 130, 201, 130, 208, 130, 214, 130, 217, 130, 218, 130, 221, 130, 226, 130, 231, 130, 232, 130, 233, 130, 234, 130, 236, 130, 237, 130, 238, 130, 240, 130, 242, 130, 243, 130, 245, 130, 246, 130, 248, 130, 250, 130, 252, 130, 253, 130, 254, 130, 255, 130, 0, 131, 10, 131, 11, 131, 13, 131, 16, 131, 18, 131, 19, 131, 22, 131, 24, 131, 25, 131, 29, 131, 30, 131, 31, 131, 32, 131, 33, 131, 34, 131, 35, 131, 36, 131, 37, 131, 38, 131, 41, 131, 42, 131, 46, 131, 48, 131, 50, 131, 55, 131, 59, 131, 61, 131, 100, 85, 62, 129, 178, 117, 174, 118, 57, 83, 222, 117, 251, 80, 65, 92, 108, 139, 199, 123, 79, 80, 71, 114, 151, 154, 216, 152, 2, 111, 226, 116, 104, 121, 135, 100, 165, 119, 252, 98, 145, 152, 43, 141, 193, 84, 88, 128, 82, 78, 106, 87, 249, 130, 13, 132, 115, 94, 237, 81, 246, 116, 196, 139, 79, 92, 97, 87, 252, 108, 135, 152, 70, 90, 52, 120, 68, 155, 235, 143, 149, 124, 86, 82, 81, 98, 250, 148, 198, 78, 134, 131, 97, 132, 233, 131, 178, 132, 212, 87, 52, 103, 3, 87, 110, 102, 102, 109, 49, 140, 221, 102, 17, 112, 31, 103, 58, 107, 22, 104, 26, 98, 187, 89, 3, 78, 196, 81, 6, 111, 210, 103, 143, 108, 118, 81, 203, 104, 71, 89, 103, 107, 102, 117, 14, 93, 16, 129, 80, 159, 215, 101, 72, 121, 65, 121, 145, 154, 119, 141, 130, 92, 94, 78, 1, 79, 47, 84, 81, 89, 12, 120, 104, 86, 20, 108, 196, 143, 3, 95, 125, 108, 227, 108, 171, 139, 144, 99, 62, 131, 63, 131, 65, 131, 66, 131, 68, 131, 69, 131, 72, 131, 74, 131, 75, 131, 76, 131, 77, 131, 78, 131, 83, 131, 85, 131, 86, 131, 87, 131, 88, 131, 89, 131, 93, 131, 98, 131, 112, 131, 113, 131, 114, 131, 115, 131, 116, 131, 117, 131, 118, 131, 121, 131, 122, 131, 126, 131, 127, 131, 128, 131, 129, 131, 130, 131, 131, 131, 132, 131, 135, 131, 136, 131, 138, 131, 139, 131, 140, 131, 141, 131, 143, 131, 144, 131, 145, 131, 148, 131, 149, 131, 150, 131, 151, 131, 153, 131, 154, 131, 157, 131, 159, 131, 161, 131, 162, 131, 163, 131, 164, 131, 165, 131, 166, 131, 167, 131, 172, 131, 173, 131, 174, 131, 175, 131, 181, 131, 187, 131, 190, 131, 191, 131, 194, 131, 195, 131, 196, 131, 198, 131, 200, 131, 201, 131, 203, 131, 205, 131, 206, 131, 208, 131, 209, 131, 210, 131, 211, 131, 213, 131, 215, 131, 217, 131, 218, 131, 219, 131, 222, 131, 226, 131, 227, 131, 228, 131, 230, 131, 231, 131, 232, 131, 235, 131, 236, 131, 237, 131, 112, 96, 61, 109, 117, 114, 102, 98, 142, 148, 197, 148, 67, 83, 193, 143, 126, 123, 223, 78, 38, 140, 126, 78, 212, 158, 177, 148, 179, 148, 77, 82, 92, 111, 99, 144, 69, 109, 52, 140, 17, 88, 76, 93, 32, 107, 73, 107, 170, 103, 91, 84, 84, 129, 140, 127, 153, 88, 55, 133, 58, 95, 162, 98, 71, 106, 57, 149, 114, 101, 132, 96, 101, 104, 167, 119, 84, 78, 168, 79, 231, 93, 152, 151, 172, 100, 216, 127, 237, 92, 207, 79, 141, 122, 7, 82, 4, 131, 20, 78, 47, 96, 131, 122, 166, 148, 181, 79, 178, 78, 230, 121, 52, 116, 228, 82, 185, 130, 210, 100, 189, 121, 221, 91, 129, 108, 82, 151, 123, 143, 34, 108, 62, 80, 127, 83, 5, 110, 206, 100, 116, 102, 48, 108, 197, 96, 119, 152, 247, 139, 134, 94, 60, 116, 119, 122, 203, 121, 24, 78, 177, 144, 3, 116, 66, 108, 218, 86, 75, 145, 197, 108, 139, 141, 58, 83, 198, 134, 242, 102, 175, 142, 72, 92, 113, 154, 32, 110, 238, 131, 239, 131, 243, 131, 244, 131, 245, 131, 246, 131, 247, 131, 250, 131, 251, 131, 252, 131, 254, 131, 255, 131, 0, 132, 2, 132, 5, 132, 7, 132, 8, 132, 9, 132, 10, 132, 16, 132, 18, 132, 19, 132, 20, 132, 21, 132, 22, 132, 23, 132, 25, 132, 26, 132, 27, 132, 30, 132, 31, 132, 32, 132, 33, 132, 34, 132, 35, 132, 41, 132, 42, 132, 43, 132, 44, 132, 45, 132, 46, 132, 47, 132, 48, 132, 50, 132, 51, 132, 52, 132, 53, 132, 54, 132, 55, 132, 57, 132, 58, 132, 59, 132, 62, 132, 63, 132, 64, 132, 65, 132, 66, 132, 67, 132, 68, 132, 69, 132, 71, 132, 72, 132, 73, 132, 74, 132, 75, 132, 76, 132, 77, 132, 78, 132, 79, 132, 80, 132, 82, 132, 83, 132, 84, 132, 85, 132, 86, 132, 88, 132, 93, 132, 94, 132, 95, 132, 96, 132, 98, 132, 100, 132, 101, 132, 102, 132, 103, 132, 104, 132, 106, 132, 110, 132, 111, 132, 112, 132, 114, 132, 116, 132, 119, 132, 121, 132, 123, 132, 124, 132, 214, 83, 54, 90, 139, 159, 163, 141, 187, 83, 8, 87, 167, 152, 67, 103, 155, 145, 201, 108, 104, 81, 202, 117, 243, 98, 172, 114, 56, 82, 157, 82, 58, 127, 148, 112, 56, 118, 116, 83, 74, 158, 183, 105, 110, 120, 192, 150, 217, 136, 164, 127, 54, 113, 195, 113, 137, 81, 211, 103, 228, 116, 228, 88, 24, 101, 183, 86, 169, 139, 118, 153, 112, 98, 213, 126, 249, 96, 237, 112, 236, 88, 193, 78, 186, 78, 205, 95, 231, 151, 251, 78, 164, 139, 3, 82, 138, 89, 171, 126, 84, 98, 205, 78, 229, 101, 14, 98, 56, 131, 201, 132, 99, 131, 141, 135, 148, 113, 182, 110, 185, 91, 210, 126, 151, 81, 201, 99, 212, 103, 137, 128, 57, 131, 21, 136, 18, 81, 122, 91, 130, 89, 177, 143, 115, 78, 93, 108, 101, 81, 37, 137, 111, 143, 46, 150, 74, 133, 94, 116, 16, 149, 240, 149, 166, 109, 229, 130, 49, 95, 146, 100, 18, 109, 40, 132, 110, 129, 195, 156, 94, 88, 91, 141, 9, 78, 193, 83, 125, 132, 126, 132, 127, 132, 128, 132, 129, 132, 131, 132, 132, 132, 133, 132, 134, 132, 138, 132, 141, 132, 143, 132, 144, 132, 145, 132, 146, 132, 147, 132, 148, 132, 149, 132, 150, 132, 152, 132, 154, 132, 155, 132, 157, 132, 158, 132, 159, 132, 160, 132, 162, 132, 163, 132, 164, 132, 165, 132, 166, 132, 167, 132, 168, 132, 169, 132, 170, 132, 171, 132, 172, 132, 173, 132, 174, 132, 176, 132, 177, 132, 179, 132, 181, 132, 182, 132, 183, 132, 187, 132, 188, 132, 190, 132, 192, 132, 194, 132, 195, 132, 197, 132, 198, 132, 199, 132, 200, 132, 203, 132, 204, 132, 206, 132, 207, 132, 210, 132, 212, 132, 213, 132, 215, 132, 216, 132, 217, 132, 218, 132, 219, 132, 220, 132, 222, 132, 225, 132, 226, 132, 228, 132, 231, 132, 232, 132, 233, 132, 234, 132, 235, 132, 237, 132, 238, 132, 239, 132, 241, 132, 242, 132, 243, 132, 244, 132, 245, 132, 246, 132, 247, 132, 248, 132, 249, 132, 250, 132, 251, 132, 253, 132, 254, 132, 0, 133, 1, 133, 2, 133, 30, 79, 99, 101, 81, 104, 211, 85, 39, 78, 20, 100, 154, 154, 107, 98, 194, 90, 95, 116, 114, 130, 169, 109, 238, 104, 231, 80, 142, 131, 2, 120, 64, 103, 57, 82, 153, 108, 177, 126, 187, 80, 101, 85, 94, 113, 91, 123, 82, 102, 202, 115, 235, 130, 73, 103, 113, 92, 32, 82, 125, 113, 107, 136, 234, 149, 85, 150, 197, 100, 97, 141, 179, 129, 132, 85, 85, 108, 71, 98, 46, 127, 146, 88, 36, 79, 70, 85, 79, 141, 76, 102, 10, 78, 26, 92, 243, 136, 162, 104, 78, 99, 13, 122, 231, 112, 141, 130, 250, 82, 246, 151, 17, 92, 232, 84, 181, 144, 205, 126, 98, 89, 74, 141, 199, 134, 12, 130, 13, 130, 102, 141, 68, 100, 4, 92, 81, 97, 137, 109, 62, 121, 190, 139, 55, 120, 51, 117, 123, 84, 56, 79, 171, 142, 241, 109, 32, 90, 197, 126, 94, 121, 136, 108, 161, 91, 118, 90, 26, 117, 190, 128, 78, 97, 23, 110, 240, 88, 31, 117, 37, 117, 114, 114, 71, 83, 243, 126, 3, 133, 4, 133, 5, 133, 6, 133, 7, 133, 8, 133, 9, 133, 10, 133, 11, 133, 13, 133, 14, 133, 15, 133, 16, 133, 18, 133, 20, 133, 21, 133, 22, 133, 24, 133, 25, 133, 27, 133, 28, 133, 29, 133, 30, 133, 32, 133, 34, 133, 35, 133, 36, 133, 37, 133, 38, 133, 39, 133, 40, 133, 41, 133, 42, 133, 45, 133, 46, 133, 47, 133, 48, 133, 49, 133, 50, 133, 51, 133, 52, 133, 53, 133, 54, 133, 62, 133, 63, 133, 64, 133, 65, 133, 66, 133, 68, 133, 69, 133, 70, 133, 71, 133, 75, 133, 76, 133, 77, 133, 78, 133, 79, 133, 80, 133, 81, 133, 82, 133, 83, 133, 84, 133, 85, 133, 87, 133, 88, 133, 90, 133, 91, 133, 92, 133, 93, 133, 95, 133, 96, 133, 97, 133, 98, 133, 99, 133, 101, 133, 102, 133, 103, 133, 105, 133, 106, 133, 107, 133, 108, 133, 109, 133, 110, 133, 111, 133, 112, 133, 113, 133, 115, 133, 117, 133, 118, 133, 119, 133, 120, 133, 124, 133, 125, 133, 127, 133, 128, 133, 129, 133, 1, 119, 219, 118, 105, 82, 220, 128, 35, 87, 8, 94, 49, 89, 238, 114, 189, 101, 127, 110, 215, 139, 56, 92, 113, 134, 65, 83, 243, 119, 254, 98, 246, 101, 192, 78, 223, 152, 128, 134, 158, 91, 198, 139, 242, 83, 226, 119, 127, 79, 78, 92, 118, 154, 203, 89], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 240828);
	        allocate([15, 95, 58, 121, 235, 88, 22, 78, 255, 103, 139, 78, 237, 98, 147, 138, 29, 144, 191, 82, 47, 102, 220, 85, 108, 86, 2, 144, 213, 78, 141, 79, 202, 145, 112, 153, 15, 108, 2, 94, 67, 96, 164, 91, 198, 137, 213, 139, 54, 101, 75, 98, 150, 153, 136, 91, 255, 91, 136, 99, 46, 85, 215, 83, 38, 118, 125, 81, 44, 133, 162, 103, 179, 104, 138, 107, 146, 98, 147, 143, 212, 83, 18, 130, 209, 109, 143, 117, 102, 78, 78, 141, 112, 91, 159, 113, 175, 133, 145, 102, 217, 102, 114, 127, 0, 135, 205, 158, 32, 159, 94, 92, 47, 103, 240, 143, 17, 104, 95, 103, 13, 98, 214, 122, 133, 88, 182, 94, 112, 101, 49, 111, 130, 133, 131, 133, 134, 133, 136, 133, 137, 133, 138, 133, 139, 133, 140, 133, 141, 133, 142, 133, 144, 133, 145, 133, 146, 133, 147, 133, 148, 133, 149, 133, 150, 133, 151, 133, 152, 133, 153, 133, 154, 133, 157, 133, 158, 133, 159, 133, 160, 133, 161, 133, 162, 133, 163, 133, 165, 133, 166, 133, 167, 133, 169, 133, 171, 133, 172, 133, 173, 133, 177, 133, 178, 133, 179, 133, 180, 133, 181, 133, 182, 133, 184, 133, 186, 133, 187, 133, 188, 133, 189, 133, 190, 133, 191, 133, 192, 133, 194, 133, 195, 133, 196, 133, 197, 133, 198, 133, 199, 133, 200, 133, 202, 133, 203, 133, 204, 133, 205, 133, 206, 133, 209, 133, 210, 133, 212, 133, 214, 133, 215, 133, 216, 133, 217, 133, 218, 133, 219, 133, 221, 133, 222, 133, 223, 133, 224, 133, 225, 133, 226, 133, 227, 133, 229, 133, 230, 133, 231, 133, 232, 133, 234, 133, 235, 133, 236, 133, 237, 133, 238, 133, 239, 133, 240, 133, 241, 133, 242, 133, 243, 133, 244, 133, 245, 133, 246, 133, 247, 133, 248, 133, 85, 96, 55, 82, 13, 128, 84, 100, 112, 136, 41, 117, 5, 94, 19, 104, 244, 98, 28, 151, 204, 83, 61, 114, 1, 140, 52, 108, 97, 119, 14, 122, 46, 84, 172, 119, 122, 152, 28, 130, 244, 139, 85, 120, 20, 103, 193, 112, 175, 101, 149, 100, 54, 86, 29, 96, 193, 121, 248, 83, 29, 78, 123, 107, 134, 128, 250, 91, 227, 85, 219, 86, 58, 79, 60, 79, 114, 153, 243, 93, 126, 103, 56, 128, 2, 96, 130, 152, 1, 144, 139, 91, 188, 139, 245, 139, 28, 100, 88, 130, 222, 100, 253, 85, 207, 130, 101, 145, 215, 79, 32, 125, 31, 144, 159, 124, 243, 80, 81, 88, 175, 110, 191, 91, 201, 139, 131, 128, 120, 145, 156, 132, 151, 123, 125, 134, 139, 150, 143, 150, 229, 126, 211, 154, 142, 120, 129, 92, 87, 122, 66, 144, 167, 150, 95, 121, 89, 91, 95, 99, 11, 123, 209, 132, 173, 104, 6, 85, 41, 127, 16, 116, 34, 125, 1, 149, 64, 98, 76, 88, 214, 78, 131, 91, 121, 89, 84, 88, 249, 133, 250, 133, 252, 133, 253, 133, 254, 133, 0, 134, 1, 134, 2, 134, 3, 134, 4, 134, 6, 134, 7, 134, 8, 134, 9, 134, 10, 134, 11, 134, 12, 134, 13, 134, 14, 134, 15, 134, 16, 134, 18, 134, 19, 134, 20, 134, 21, 134, 23, 134, 24, 134, 25, 134, 26, 134, 27, 134, 28, 134, 29, 134, 30, 134, 31, 134, 32, 134, 33, 134, 34, 134, 35, 134, 36, 134, 37, 134, 38, 134, 40, 134, 42, 134, 43, 134, 44, 134, 45, 134, 46, 134, 47, 134, 48, 134, 49, 134, 50, 134, 51, 134, 52, 134, 53, 134, 54, 134, 55, 134, 57, 134, 58, 134, 59, 134, 61, 134, 62, 134, 63, 134, 64, 134, 65, 134, 66, 134, 67, 134, 68, 134, 69, 134, 70, 134, 71, 134, 72, 134, 73, 134, 74, 134, 75, 134, 76, 134, 82, 134, 83, 134, 85, 134, 86, 134, 87, 134, 88, 134, 89, 134, 91, 134, 92, 134, 93, 134, 95, 134, 96, 134, 97, 134, 99, 134, 100, 134, 101, 134, 102, 134, 103, 134, 104, 134, 105, 134, 106, 134, 109, 115, 30, 99, 75, 142, 15, 142, 206, 128, 212, 130, 172, 98, 240, 83, 240, 108, 94, 145, 42, 89, 1, 96, 112, 108, 77, 87, 74, 100, 42, 141, 43, 118, 233, 110, 91, 87, 128, 106, 240, 117, 109, 111, 45, 140, 8, 140, 102, 87, 239, 107, 146, 136, 179, 120, 162, 99, 249, 83, 173, 112, 100, 108, 88, 88, 42, 100, 2, 88, 224, 104, 155, 129, 16, 85, 214, 124, 24, 80, 186, 142, 204, 109, 159, 141, 235, 112, 143, 99, 155, 109, 212, 110, 230, 126, 4, 132, 67, 104, 3, 144, 216, 109, 118, 150, 168, 139, 87, 89, 121, 114, 228, 133, 126, 129, 188, 117, 138, 138, 175, 104, 84, 82, 34, 142, 17, 149, 208, 99, 152, 152, 68, 142, 124, 85, 83, 79, 255, 102, 143, 86, 213, 96, 149, 109, 67, 82, 73, 92, 41, 89, 251, 109, 107, 88, 48, 117, 28, 117, 108, 96, 20, 130, 70, 129, 17, 99, 97, 103, 226, 143, 58, 119, 243, 141, 52, 141, 193, 148, 22, 94, 133, 83, 44, 84, 195, 112, 109, 134, 111, 134, 112, 134, 114, 134, 115, 134, 116, 134, 117, 134, 118, 134, 119, 134, 120, 134, 131, 134, 132, 134, 133, 134, 134, 134, 135, 134, 136, 134, 137, 134, 142, 134, 143, 134, 144, 134, 145, 134, 146, 134, 148, 134, 150, 134, 151, 134, 152, 134, 153, 134, 154, 134, 155, 134, 158, 134, 159, 134, 160, 134, 161, 134, 162, 134, 165, 134, 166, 134, 171, 134, 173, 134, 174, 134, 178, 134, 179, 134, 183, 134, 184, 134, 185, 134, 187, 134, 188, 134, 189, 134, 190, 134, 191, 134, 193, 134, 194, 134, 195, 134, 197, 134, 200, 134, 204, 134, 205, 134, 210, 134, 211, 134, 213, 134, 214, 134, 215, 134, 218, 134, 220, 134, 221, 134, 224, 134, 225, 134, 226, 134, 227, 134, 229, 134, 230, 134, 231, 134, 232, 134, 234, 134, 235, 134, 236, 134, 239, 134, 245, 134, 246, 134, 247, 134, 250, 134, 251, 134, 252, 134, 253, 134, 255, 134, 1, 135, 4, 135, 5, 135, 6, 135, 11, 135, 12, 135, 14, 135, 15, 135, 16, 135, 17, 135, 20, 135, 22, 135, 64, 108, 247, 94, 92, 80, 173, 78, 173, 94, 58, 99, 71, 130, 26, 144, 80, 104, 110, 145, 179, 119, 12, 84, 220, 148, 100, 95, 229, 122, 118, 104, 69, 99, 82, 123, 223, 126, 219, 117, 119, 80, 149, 98, 52, 89, 15, 144, 248, 81, 195, 121, 129, 122, 254, 86, 146, 95, 20, 144, 130, 109, 96, 92, 31, 87, 16, 84, 84, 81, 77, 110, 226, 86, 168, 99, 147, 152, 127, 129, 21, 135, 42, 137, 0, 144, 30, 84, 111, 92, 192, 129, 214, 98, 88, 98, 49, 129, 53, 158, 64, 150, 110, 154, 124, 154, 45, 105, 165, 89, 211, 98, 62, 85, 22, 99, 199, 84, 217, 134, 60, 109, 3, 90, 230, 116, 156, 136, 106, 107, 22, 89, 76, 140, 47, 95, 126, 110, 169, 115, 125, 152, 56, 78, 247, 112, 140, 91, 151, 120, 61, 99, 90, 102, 150, 118, 203, 96, 155, 91, 73, 90, 7, 78, 85, 129, 106, 108, 139, 115, 161, 78, 137, 103, 81, 127, 128, 95, 250, 101, 27, 103, 216, 95, 132, 89, 1, 90, 25, 135, 27, 135, 29, 135, 31, 135, 32, 135, 36, 135, 38, 135, 39, 135, 40, 135, 42, 135, 43, 135, 44, 135, 45, 135, 47, 135, 48, 135, 50, 135, 51, 135, 53, 135, 54, 135, 56, 135, 57, 135, 58, 135, 60, 135, 61, 135, 64, 135, 65, 135, 66, 135, 67, 135, 68, 135, 69, 135, 70, 135, 74, 135, 75, 135, 77, 135, 79, 135, 80, 135, 81, 135, 82, 135, 84, 135, 85, 135, 86, 135, 88, 135, 90, 135, 91, 135, 92, 135, 93, 135, 94, 135, 95, 135, 97, 135, 98, 135, 102, 135, 103, 135, 104, 135, 105, 135, 106, 135, 107, 135, 108, 135, 109, 135, 111, 135, 113, 135, 114, 135, 115, 135, 117, 135, 119, 135, 120, 135, 121, 135, 122, 135, 127, 135, 128, 135, 129, 135, 132, 135, 134, 135, 135, 135, 137, 135, 138, 135, 140, 135, 142, 135, 143, 135, 144, 135, 145, 135, 146, 135, 148, 135, 149, 135, 150, 135, 152, 135, 153, 135, 154, 135, 155, 135, 156, 135, 157, 135, 158, 135, 160, 135, 161, 135, 162, 135, 163, 135, 164, 135, 205, 93, 174, 95, 113, 83, 230, 151, 221, 143, 69, 104, 244, 86, 47, 85, 223, 96, 58, 78, 77, 111, 244, 126, 199, 130, 14, 132, 212, 89, 31, 79, 42, 79, 62, 92, 172, 126, 42, 103, 26, 133, 115, 84, 79, 117, 195, 128, 130, 85, 79, 155, 77, 79, 45, 110, 19, 140, 9, 92, 112, 97, 107, 83, 31, 118, 41, 110, 138, 134, 135, 101, 251, 149, 185, 126, 59, 84, 51, 122, 10, 125, 238, 149, 225, 85, 193, 127, 238, 116, 29, 99, 23, 135, 161, 109, 157, 122, 17, 98, 161, 101, 103, 83, 225, 99, 131, 108, 235, 93, 92, 84, 168, 148, 76, 78, 97, 108, 236, 139, 75, 92, 224, 101, 156, 130, 167, 104, 62, 84, 52, 84, 203, 107, 102, 107, 148, 78, 66, 99, 72, 83, 30, 130, 13, 79, 174, 79, 94, 87, 10, 98, 254, 150, 100, 102, 105, 114, 255, 82, 161, 82, 159, 96, 239, 139, 20, 102, 153, 113, 144, 103, 127, 137, 82, 120, 253, 119, 112, 102, 59, 86, 56, 84, 33, 149, 122, 114, 165, 135, 166, 135, 167, 135, 169, 135, 170, 135, 174, 135, 176, 135, 177, 135, 178, 135, 180, 135, 182, 135, 183, 135, 184, 135, 185, 135, 187, 135, 188, 135, 190, 135, 191, 135, 193, 135, 194, 135, 195, 135, 196, 135, 197, 135, 199, 135, 200, 135, 201, 135, 204, 135, 205, 135, 206, 135, 207, 135, 208, 135, 212, 135, 213, 135, 214, 135, 215, 135, 216, 135, 217, 135, 218, 135, 220, 135, 221, 135, 222, 135, 223, 135, 225, 135, 226, 135, 227, 135, 228, 135, 230, 135, 231, 135, 232, 135, 233, 135, 235, 135, 236, 135, 237, 135, 239, 135, 240, 135, 241, 135, 242, 135, 243, 135, 244, 135, 245, 135, 246, 135, 247, 135, 248, 135, 250, 135, 251, 135, 252, 135, 253, 135, 255, 135, 0, 136, 1, 136, 2, 136, 4, 136, 5, 136, 6, 136, 7, 136, 8, 136, 9, 136, 11, 136, 12, 136, 13, 136, 14, 136, 15, 136, 16, 136, 17, 136, 18, 136, 20, 136, 23, 136, 24, 136, 25, 136, 26, 136, 28, 136, 29, 136, 30, 136, 31, 136, 32, 136, 35, 136, 0, 122, 111, 96, 12, 94, 137, 96, 157, 129, 21, 89, 220, 96, 132, 113, 239, 112, 170, 110, 80, 108, 128, 114, 132, 106, 173, 136, 45, 94, 96, 78, 179, 90, 156, 85, 227, 148, 23, 109, 251, 124, 153, 150, 15, 98, 198, 126, 142, 119, 126, 134, 35, 83, 30, 151, 150, 143, 135, 102, 225, 92, 160, 79, 237, 114, 11, 78, 166, 83, 15, 89, 19, 84, 128, 99, 40, 149, 72, 81, 217, 78, 156, 156, 164, 126, 184, 84, 36, 141, 84, 136, 55, 130, 242, 149, 142, 109, 38, 95, 204, 90, 62, 102, 105, 150, 176, 115, 46, 115, 191, 83, 122, 129, 133, 153, 161, 127, 170, 91, 119, 150, 80, 150, 191, 126, 248, 118, 162, 83, 118, 149, 153, 153, 177, 123, 68, 137, 88, 110, 97, 78, 212, 127, 101, 121, 230, 139, 243, 96, 205, 84, 171, 78, 121, 152, 247, 93, 97, 106, 207, 80, 17, 84, 97, 140, 39, 132, 93, 120, 4, 151, 74, 82, 238, 84, 163, 86, 0, 149, 136, 109, 181, 91, 198, 109, 83, 102, 36, 136, 37, 136, 38, 136, 39, 136, 40, 136, 41, 136, 42, 136, 43, 136, 44, 136, 45, 136, 46, 136, 47, 136, 48, 136, 49, 136, 51, 136, 52, 136, 53, 136, 54, 136, 55, 136, 56, 136, 58, 136, 59, 136, 61, 136, 62, 136, 63, 136, 65, 136, 66, 136, 67, 136, 70, 136, 71, 136, 72, 136, 73, 136, 74, 136, 75, 136, 78, 136, 79, 136, 80, 136, 81, 136, 82, 136, 83, 136, 85, 136, 86, 136, 88, 136, 90, 136, 91, 136, 92, 136, 93, 136, 94, 136, 95, 136, 96, 136, 102, 136, 103, 136, 106, 136, 109, 136, 111, 136, 113, 136, 115, 136, 116, 136, 117, 136, 118, 136, 120, 136, 121, 136, 122, 136, 123, 136, 124, 136, 128, 136, 131, 136, 134, 136, 135, 136, 137, 136, 138, 136, 140, 136, 142, 136, 143, 136, 144, 136, 145, 136, 147, 136, 148, 136, 149, 136, 151, 136, 152, 136, 153, 136, 154, 136, 155, 136, 157, 136, 158, 136, 159, 136, 160, 136, 161, 136, 163, 136, 165, 136, 166, 136, 167, 136, 168, 136, 169, 136, 170, 136, 15, 92, 93, 91, 33, 104, 150, 128, 120, 85, 17, 123, 72, 101, 84, 105, 155, 78, 71, 107, 78, 135, 139, 151, 79, 83, 31, 99, 58, 100, 170, 144, 156, 101, 193, 128, 16, 140, 153, 81, 176, 104, 120, 83, 249, 135, 200, 97, 196, 108, 251, 108, 34, 140, 81, 92, 170, 133, 175, 130, 12, 149, 35, 107, 155, 143, 176, 101, 251, 95, 195, 95, 225, 79, 69, 136, 31, 102, 101, 129, 41, 115, 250, 96, 116, 81, 17, 82, 139, 87, 98, 95, 162, 144, 76, 136, 146, 145, 120, 94, 79, 103, 39, 96, 211, 89, 68, 81, 246, 81, 248, 128, 8, 83, 121, 108, 196, 150, 138, 113, 17, 79, 238, 79, 158, 127, 61, 103, 197, 85, 8, 149, 192, 121, 150, 136, 227, 126, 159, 88, 12, 98, 0, 151, 90, 134, 24, 86, 123, 152, 144, 95, 184, 139, 196, 132, 87, 145, 217, 83, 237, 101, 143, 94, 92, 117, 100, 96, 110, 125, 127, 90, 234, 126, 237, 126, 105, 143, 167, 85, 163, 91, 172, 96, 203, 101, 132, 115, 172, 136, 174, 136, 175, 136, 176, 136, 178, 136, 179, 136, 180, 136, 181, 136, 182, 136, 184, 136, 185, 136, 186, 136, 187, 136, 189, 136, 190, 136, 191, 136, 192, 136, 195, 136, 196, 136, 199, 136, 200, 136, 202, 136, 203, 136, 204, 136, 205, 136, 207, 136, 208, 136, 209, 136, 211, 136, 214, 136, 215, 136, 218, 136, 219, 136, 220, 136, 221, 136, 222, 136, 224, 136, 225, 136, 230, 136, 231, 136, 233, 136, 234, 136, 235, 136, 236, 136, 237, 136, 238, 136, 239, 136, 242, 136, 245, 136, 246, 136, 247, 136, 250, 136, 251, 136, 253, 136, 255, 136, 0, 137, 1, 137, 3, 137, 4, 137, 5, 137, 6, 137, 7, 137, 8, 137, 9, 137, 11, 137, 12, 137, 13, 137, 14, 137, 15, 137, 17, 137, 20, 137, 21, 137, 22, 137, 23, 137, 24, 137, 28, 137, 29, 137, 30, 137, 31, 137, 32, 137, 34, 137, 35, 137, 36, 137, 38, 137, 39, 137, 40, 137, 41, 137, 44, 137, 45, 137, 46, 137, 47, 137, 49, 137, 50, 137, 51, 137, 53, 137, 55, 137, 9, 144, 99, 118, 41, 119, 218, 126, 116, 151, 155, 133, 102, 91, 116, 122, 234, 150, 64, 136, 203, 82, 143, 113, 170, 95, 236, 101, 226, 139, 251, 91, 111, 154, 225, 93, 137, 107, 91, 108, 173, 139, 175, 139, 10, 144, 197, 143, 139, 83, 188, 98, 38, 158, 45, 158, 64, 84, 43, 78, 189, 130, 89, 114, 156, 134, 22, 93, 89, 136, 175, 109, 197, 150, 209, 84, 154, 78, 182, 139, 9, 113, 189, 84, 9, 150, 223, 112, 249, 109, 208, 118, 37, 78, 20, 120, 18, 135, 169, 92, 246, 94, 0, 138, 156, 152, 14, 150, 142, 112, 191, 108, 68, 89, 169, 99, 60, 119, 77, 136, 20, 111, 115, 130, 48, 88, 213, 113, 140, 83, 26, 120, 193, 150, 1, 85, 102, 95, 48, 113, 180, 91, 26, 140, 140, 154, 131, 107, 46, 89, 47, 158, 231, 121, 104, 103, 108, 98, 111, 79, 161, 117, 138, 127, 11, 109, 51, 150, 39, 108, 240, 78, 210, 117, 123, 81, 55, 104, 62, 111, 128, 144, 112, 129, 150, 89, 118, 116, 56, 137, 57, 137, 58, 137, 59, 137, 60, 137, 61, 137, 62, 137, 63, 137, 64, 137, 66, 137, 67, 137, 69, 137, 70, 137, 71, 137, 72, 137, 73, 137, 74, 137, 75, 137, 76, 137, 77, 137, 78, 137, 79, 137, 80, 137, 81, 137, 82, 137, 83, 137, 84, 137, 85, 137, 86, 137, 87, 137, 88, 137, 89, 137, 90, 137, 91, 137, 92, 137, 93, 137, 96, 137, 97, 137, 98, 137, 99, 137, 100, 137, 101, 137, 103, 137, 104, 137, 105, 137, 106, 137, 107, 137, 108, 137, 109, 137, 110, 137, 111, 137, 112, 137, 113, 137, 114, 137, 115, 137, 116, 137, 117, 137, 118, 137, 119, 137, 120, 137, 121, 137, 122, 137, 124, 137, 125, 137, 126, 137, 128, 137, 130, 137, 132, 137, 133, 137, 135, 137, 136, 137, 137, 137, 138, 137, 139, 137, 140, 137, 141, 137, 142, 137, 143, 137, 144, 137, 145, 137, 146, 137, 147, 137, 148, 137, 149, 137, 150, 137, 151, 137, 152, 137, 153, 137, 154, 137, 155, 137, 156, 137, 157, 137, 158, 137, 159, 137, 160, 137, 161, 137, 71, 100, 39, 92, 101, 144, 145, 122, 35, 140, 218, 89, 172, 84, 0, 130, 111, 131, 129, 137, 0, 128, 48, 105, 78, 86, 54, 128, 55, 114, 206, 145, 182, 81, 95, 78, 117, 152, 150, 99, 26, 78, 246, 83, 243, 102, 75, 129, 28, 89, 178, 109, 0, 78, 249, 88, 59, 83, 214, 99, 241, 148, 157, 79, 10, 79, 99, 136, 144, 152, 55, 89, 87, 144, 251, 121, 234, 78, 240, 128, 145, 117, 130, 108, 156, 91, 232, 89, 93, 95, 5, 105, 129, 134, 26, 80, 242, 93, 89, 78, 227, 119, 229, 78, 122, 130, 145, 98, 19, 102, 145, 144, 121, 92, 191, 78, 121, 95, 198, 129, 56, 144, 132, 128, 171, 117, 166, 78, 212, 136, 15, 97, 197, 107, 198, 95, 73, 78, 202, 118, 162, 110, 227, 139, 174, 139, 10, 140, 209, 139, 2, 95, 252, 127, 204, 127, 206, 126, 53, 131, 107, 131, 224, 86, 183, 107, 243, 151, 52, 150, 251, 89, 31, 84, 246, 148, 235, 109, 197, 91, 110, 153, 57, 92, 21, 95, 144, 150, 162, 137, 163, 137, 164, 137, 165, 137, 166, 137, 167, 137, 168, 137, 169, 137, 170, 137, 171, 137, 172, 137, 173, 137, 174, 137, 175, 137, 176, 137, 177, 137, 178, 137, 179, 137, 180, 137, 181, 137, 182, 137, 183, 137, 184, 137, 185, 137, 186, 137, 187, 137, 188, 137, 189, 137, 190, 137, 191, 137, 192, 137, 195, 137, 205, 137, 211, 137, 212, 137, 213, 137, 215, 137, 216, 137, 217, 137, 219, 137, 221, 137, 223, 137, 224, 137, 225, 137, 226, 137, 228, 137, 231, 137, 232, 137, 233, 137, 234, 137, 236, 137, 237, 137, 238, 137, 240, 137, 241, 137, 242, 137, 244, 137, 245, 137, 246, 137, 247, 137, 248, 137, 249, 137, 250, 137, 251, 137, 252, 137, 253, 137, 254, 137, 255, 137, 1, 138, 2, 138, 3, 138, 4, 138, 5, 138, 6, 138, 8, 138, 9, 138, 10, 138, 11, 138, 12, 138, 13, 138, 14, 138, 15, 138, 16, 138, 17, 138, 18, 138, 19, 138, 20, 138, 21, 138, 22, 138, 23, 138, 24, 138, 25, 138, 26, 138, 27, 138, 28, 138, 29, 138, 112, 83, 241, 130, 49, 106, 116, 90, 112, 158, 148, 94, 40, 127, 185, 131, 36, 132, 37, 132, 103, 131, 71, 135, 206, 143, 98, 141, 200, 118, 113, 95, 150, 152, 108, 120, 32, 102, 223, 84, 229, 98, 99, 79, 195, 129, 200, 117, 184, 94, 205, 150, 10, 142, 249, 134, 143, 84, 243, 108, 140, 109, 56, 108, 127, 96, 199, 82, 40, 117, 125, 94, 24, 79, 160, 96, 231, 95, 36, 92, 49, 117, 174, 144, 192, 148, 185, 114, 185, 108, 56, 110, 73, 145, 9, 103, 203, 83, 243, 83, 81, 79, 201, 145, 241, 139, 200, 83, 124, 94, 194, 143, 228, 109, 142, 78, 194, 118, 134, 105, 94, 134, 26, 97, 6, 130, 89, 79, 222, 79, 62, 144, 124, 156, 9, 97, 29, 110, 20, 110, 133, 150, 136, 78, 49, 90, 232, 150, 14, 78, 127, 92, 185, 121, 135, 91, 237, 139, 189, 127, 137, 115, 223, 87, 139, 130, 193, 144, 1, 84, 71, 144, 187, 85, 234, 92, 161, 95, 8, 97, 50, 107, 241, 114, 178, 128, 137, 138, 30, 138, 31, 138, 32, 138, 33, 138, 34, 138, 35, 138, 36, 138, 37, 138, 38, 138, 39, 138, 40, 138, 41, 138, 42, 138, 43, 138, 44, 138, 45, 138, 46, 138, 47, 138, 48, 138, 49, 138, 50, 138, 51, 138, 52, 138, 53, 138, 54, 138, 55, 138, 56, 138, 57, 138, 58, 138, 59, 138, 60, 138, 61, 138, 63, 138, 64, 138, 65, 138, 66, 138, 67, 138, 68, 138, 69, 138, 70, 138, 71, 138, 73, 138, 74, 138, 75, 138, 76, 138, 77, 138, 78, 138, 79, 138, 80, 138, 81, 138, 82, 138, 83, 138, 84, 138, 85, 138, 86, 138, 87, 138, 88, 138, 89, 138, 90, 138, 91, 138, 92, 138, 93, 138, 94, 138, 95, 138, 96, 138, 97, 138, 98, 138, 99, 138, 100, 138, 101, 138, 102, 138, 103, 138, 104, 138, 105, 138, 106, 138, 107, 138, 108, 138, 109, 138, 110, 138, 111, 138, 112, 138, 113, 138, 114, 138, 115, 138, 116, 138, 117, 138, 118, 138, 119, 138, 120, 138, 122, 138, 123, 138, 124, 138, 125, 138, 126, 138, 127, 138, 128, 138, 116, 109, 211, 91, 213, 136, 132, 152, 107, 140, 109, 154, 51, 158, 10, 110, 164, 81, 67, 81, 163, 87, 129, 136, 159, 83, 244, 99, 149, 143, 237, 86, 88, 84, 6, 87, 63, 115, 144, 110, 24, 127, 220, 143, 209, 130, 63, 97, 40, 96, 98, 150, 240, 102, 166, 126, 138, 141, 195, 141, 165, 148, 179, 92, 164, 124, 8, 103, 166, 96, 5, 150, 24, 128, 145, 78, 231, 144, 0, 83, 104, 150, 65, 81, 208, 143, 116, 133, 93, 145, 85, 102, 245, 151, 85, 91, 29, 83, 56, 120, 66, 103, 61, 104, 201, 84, 126, 112, 176, 91, 125, 143, 141, 81, 40, 87, 177, 84, 18, 101, 130, 102, 94, 141, 67, 141, 15, 129, 108, 132, 109, 144, 223, 124, 255, 81, 251, 133, 163, 103, 233, 101, 161, 111, 164, 134, 129, 142, 106, 86, 32, 144, 130, 118, 118, 112, 229, 113, 35, 141, 233, 98, 25, 82, 253, 108, 60, 141, 14, 96, 158, 88, 142, 97, 254, 102, 96, 141, 78, 98, 179, 85, 35, 110, 45, 103, 103, 143, 129, 138, 130, 138, 131, 138, 132, 138, 133, 138, 134, 138, 135, 138, 136, 138, 139, 138, 140, 138, 141, 138, 142, 138, 143, 138, 144, 138, 145, 138, 146, 138, 148, 138, 149, 138, 150, 138, 151, 138, 152, 138, 153, 138, 154, 138, 155, 138, 156, 138, 157, 138, 158, 138, 159, 138, 160, 138, 161, 138, 162, 138, 163, 138, 164, 138, 165, 138, 166, 138, 167, 138, 168, 138, 169, 138, 170, 138, 171, 138, 172, 138, 173, 138, 174, 138, 175, 138, 176, 138, 177, 138, 178, 138, 179, 138, 180, 138, 181, 138, 182, 138, 183, 138, 184, 138, 185, 138, 186, 138, 187, 138, 188, 138, 189, 138, 190, 138, 191, 138, 192, 138, 193, 138, 194, 138, 195, 138, 196, 138, 197, 138, 198, 138, 199, 138, 200, 138, 201, 138, 202, 138, 203, 138, 204, 138, 205, 138, 206, 138, 207, 138, 208, 138, 209, 138, 210, 138, 211, 138, 212, 138, 213, 138, 214, 138, 215, 138, 216, 138, 217, 138, 218, 138, 219, 138, 220, 138, 221, 138, 222, 138, 223, 138, 224, 138, 225, 138, 226, 138, 227, 138, 225, 148, 248, 149, 40, 119, 5, 104, 168, 105, 139, 84, 77, 78, 184, 112, 200, 139, 88, 100, 139, 101, 133, 91, 132, 122, 58, 80, 232, 91, 187, 119, 225, 107, 121, 138, 152, 124, 190, 108, 207, 118, 169, 101, 151, 143, 45, 93, 85, 92, 56, 134, 8, 104, 96, 83, 24, 98, 217, 122, 91, 110, 253, 126, 31, 106, 224, 122, 112, 95, 51, 111, 32, 95, 140, 99, 168, 109, 86, 103, 8, 78, 16, 94, 38, 141, 215, 78, 192, 128, 52, 118, 156, 150, 219, 98, 45, 102, 126, 98, 188, 108, 117, 141, 103, 113, 105, 127, 70, 81, 135, 128, 236, 83, 110, 144, 152, 98, 242, 84, 240, 134, 153, 143, 5, 128, 23, 149, 23, 133, 217, 143, 89, 109, 205, 115, 159, 101, 31, 119, 4, 117, 39, 120, 251, 129, 30, 141, 136, 148, 166, 79, 149, 103, 185, 117, 202, 139, 7, 151, 47, 99, 71, 149, 53, 150, 184, 132, 35, 99, 65, 119, 129, 95, 240, 114, 137, 78, 20, 96, 116, 101, 239, 98, 99, 107, 63, 101, 228, 138, 229, 138, 230, 138, 231, 138, 232, 138, 233, 138, 234, 138, 235, 138, 236, 138, 237, 138, 238, 138, 239, 138, 240, 138, 241, 138, 242, 138, 243, 138, 244, 138, 245, 138, 246, 138, 247, 138, 248, 138, 249, 138, 250, 138, 251, 138, 252, 138, 253, 138, 254, 138, 255, 138, 0, 139, 1, 139, 2, 139, 3, 139, 4, 139, 5, 139, 6, 139, 8, 139, 9, 139, 10, 139, 11, 139, 12, 139, 13, 139, 14, 139, 15, 139, 16, 139, 17, 139, 18, 139, 19, 139, 20, 139, 21, 139, 22, 139, 23, 139, 24, 139, 25, 139, 26, 139, 27, 139, 28, 139, 29, 139, 30, 139, 31, 139, 32, 139, 33, 139, 34, 139, 35, 139, 36, 139, 37, 139, 39, 139, 40, 139, 41, 139, 42, 139, 43, 139, 44, 139, 45, 139, 46, 139, 47, 139, 48, 139, 49, 139, 50, 139, 51, 139, 52, 139, 53, 139, 54, 139, 55, 139, 56, 139, 57, 139, 58, 139, 59, 139, 60, 139, 61, 139, 62, 139, 63, 139, 64, 139, 65, 139, 66, 139, 67, 139, 68, 139, 69, 139, 39, 94, 199, 117, 209, 144, 193, 139, 157, 130, 157, 103, 47, 101, 49, 84, 24, 135, 229, 119, 162, 128, 2, 129, 65, 108, 75, 78, 199, 126, 76, 128, 244, 118, 13, 105, 150, 107, 103, 98, 60, 80, 132, 79, 64, 87, 7, 99, 98, 107, 190, 141, 234, 83, 232, 101, 184, 126, 215, 95, 26, 99, 183, 99, 243, 129, 244, 129, 110, 127, 28, 94, 217, 92, 54, 82, 122, 102, 233, 121, 26, 122, 40, 141, 153, 112, 212, 117, 222, 110, 187, 108, 146, 122, 45, 78, 197, 118, 224, 95, 159, 148, 119, 136, 200, 126, 205, 121, 191, 128, 205, 145, 242, 78, 23, 79, 31, 130, 104, 84, 222, 93, 50, 109, 204, 139, 165, 124, 116, 143, 152, 128, 26, 94, 146, 84, 177, 118, 153, 91, 60, 102, 164, 154, 224, 115, 42, 104, 219, 134, 49, 103, 42, 115, 248, 139, 219, 139, 16, 144, 249, 122, 219, 112, 110, 113, 196, 98, 169, 119, 49, 86, 59, 78, 87, 132, 241, 103, 169, 82, 192, 134, 46, 141, 248, 148, 81, 123, 70, 139, 71, 139, 72, 139, 73, 139, 74, 139, 75, 139, 76, 139, 77, 139, 78, 139, 79, 139, 80, 139, 81, 139, 82, 139, 83, 139, 84, 139, 85, 139, 86, 139, 87, 139, 88, 139, 89, 139, 90, 139, 91, 139, 92, 139, 93, 139, 94, 139, 95, 139, 96, 139, 97, 139, 98, 139, 99, 139, 100, 139, 101, 139, 103, 139, 104, 139, 105, 139, 106, 139, 107, 139, 109, 139, 110, 139, 111, 139, 112, 139, 113, 139, 114, 139, 115, 139, 116, 139, 117, 139, 118, 139, 119, 139, 120, 139, 121, 139, 122, 139, 123, 139, 124, 139, 125, 139, 126, 139, 127, 139, 128, 139, 129, 139, 130, 139, 131, 139, 132, 139, 133, 139, 134, 139, 135, 139, 136, 139, 137, 139, 138, 139, 139, 139, 140, 139, 141, 139, 142, 139, 143, 139, 144, 139, 145, 139, 146, 139, 147, 139, 148, 139, 149, 139, 150, 139, 151, 139, 152, 139, 153, 139, 154, 139, 155, 139, 156, 139, 157, 139, 158, 139, 159, 139, 172, 139, 177, 139, 187, 139, 199, 139, 208, 139, 234, 139, 9, 140, 30, 140, 79, 79, 232, 108, 93, 121, 123, 154, 147, 98, 42, 114, 253, 98, 19, 78, 22, 120, 108, 143, 176, 100, 90, 141, 198, 123, 105, 104, 132, 94, 197, 136, 134, 89, 158, 100, 238, 88, 182, 114, 14, 105, 37, 149, 253, 143, 88, 141, 96, 87, 0, 127, 6, 140, 198, 81, 73, 99, 217, 98, 83, 83, 76, 104, 34, 116, 1, 131, 76, 145, 68, 85, 64, 119, 124, 112, 74, 109, 121, 81, 168, 84, 68, 141, 255, 89, 203, 110, 196, 109, 92, 91, 43, 125, 212, 78, 125, 124, 211, 110, 80, 91, 234, 129, 13, 110, 87, 91, 3, 155, 213, 104, 42, 142, 151, 91, 252, 126, 59, 96, 181, 126, 185, 144, 112, 141, 79, 89, 205, 99, 223, 121, 179, 141, 82, 83, 207, 101, 86, 121, 197, 139, 59, 150, 196, 126, 187, 148, 130, 126, 52, 86, 137, 145, 0, 103, 106, 127, 10, 92, 117, 144, 40, 102, 230, 93, 80, 79, 222, 103, 90, 80, 92, 79, 80, 87, 167, 94, 16, 232, 17, 232, 18, 232, 19, 232, 20, 232, 56, 140, 57, 140, 58, 140, 59, 140, 60, 140, 61, 140, 62, 140, 63, 140, 64, 140, 66, 140, 67, 140, 68, 140, 69, 140, 72, 140, 74, 140, 75, 140, 77, 140, 78, 140, 79, 140, 80, 140, 81, 140, 82, 140, 83, 140, 84, 140, 86, 140, 87, 140, 88, 140, 89, 140, 91, 140, 92, 140, 93, 140, 94, 140, 95, 140, 96, 140, 99, 140, 100, 140, 101, 140, 102, 140, 103, 140, 104, 140, 105, 140, 108, 140, 109, 140, 110, 140, 111, 140, 112, 140, 113, 140, 114, 140, 116, 140, 117, 140, 118, 140, 119, 140, 123, 140, 124, 140, 125, 140, 126, 140, 127, 140, 128, 140, 129, 140, 131, 140, 132, 140, 134, 140, 135, 140, 136, 140, 139, 140, 141, 140, 142, 140, 143, 140, 144, 140, 145, 140, 146, 140, 147, 140, 149, 140, 150, 140, 151, 140, 153, 140, 154, 140, 155, 140, 156, 140, 157, 140, 158, 140, 159, 140, 160, 140, 161, 140, 162, 140, 163, 140, 164, 140, 165, 140, 166, 140, 167, 140, 168, 140, 169, 140, 170, 140, 171, 140, 172, 140, 173, 140, 141, 78, 12, 78, 64, 81, 16, 78, 255, 94, 69, 83, 21, 78, 152, 78, 30, 78, 50, 155, 108, 91, 105, 86, 40, 78, 186, 121, 63, 78, 21, 83, 71, 78, 45, 89, 59, 114, 110, 83, 16, 108, 223, 86, 228, 128, 151, 153, 211, 107, 126, 119, 23, 159, 54, 78, 159, 78, 16, 159, 92, 78, 105, 78, 147, 78, 136, 130, 91, 91, 108, 85, 15, 86, 196, 78, 141, 83, 157, 83, 163, 83, 165, 83, 174, 83, 101, 151, 93, 141, 26, 83, 245, 83, 38, 83, 46, 83, 62, 83, 92, 141, 102, 83, 99, 83, 2, 82, 8, 82, 14, 82, 45, 82, 51, 82, 63, 82, 64, 82, 76, 82, 94, 82, 97, 82, 92, 82, 175, 132, 125, 82, 130, 82, 129, 82, 144, 82, 147, 82, 130, 81, 84, 127, 187, 78, 195, 78, 201, 78, 194, 78, 232, 78, 225, 78, 235, 78, 222, 78, 27, 79, 243, 78, 34, 79, 100, 79, 245, 78, 37, 79, 39, 79, 9, 79, 43, 79, 94, 79, 103, 79, 56, 101, 90, 79, 93, 79, 174, 140, 175, 140, 176, 140, 177, 140, 178, 140, 179, 140, 180, 140, 181, 140, 182, 140, 183, 140, 184, 140, 185, 140, 186, 140, 187, 140, 188, 140, 189, 140, 190, 140, 191, 140, 192, 140, 193, 140, 194, 140, 195, 140, 196, 140, 197, 140, 198, 140, 199, 140, 200, 140, 201, 140, 202, 140, 203, 140, 204, 140, 205, 140, 206, 140, 207, 140, 208, 140, 209, 140, 210, 140, 211, 140, 212, 140, 213, 140, 214, 140, 215, 140, 216, 140, 217, 140, 218, 140, 219, 140, 220, 140, 221, 140, 222, 140, 223, 140, 224, 140, 225, 140, 226, 140, 227, 140, 228, 140, 229, 140, 230, 140, 231, 140, 232, 140, 233, 140, 234, 140, 235, 140, 236, 140, 237, 140, 238, 140, 239, 140, 240, 140, 241, 140, 242, 140, 243, 140, 244, 140, 245, 140, 246, 140, 247, 140, 248, 140, 249, 140, 250, 140, 251, 140, 252, 140, 253, 140, 254, 140, 255, 140, 0, 141, 1, 141, 2, 141, 3, 141, 4, 141, 5, 141, 6, 141, 7, 141, 8, 141, 9, 141, 10, 141, 11, 141, 12, 141, 13, 141, 95, 79, 87, 79, 50, 79, 61, 79, 118, 79, 116, 79, 145, 79, 137, 79, 131, 79, 143, 79, 126, 79, 123, 79, 170, 79, 124, 79, 172, 79, 148, 79, 230, 79, 232, 79, 234, 79, 197, 79, 218, 79, 227, 79, 220, 79, 209, 79, 223, 79, 248, 79, 41, 80, 76, 80, 243, 79, 44, 80, 15, 80, 46, 80, 45, 80, 254, 79, 28, 80, 12, 80, 37, 80, 40, 80, 126, 80, 67, 80, 85, 80, 72, 80, 78, 80, 108, 80, 123, 80, 165, 80, 167, 80, 169, 80, 186, 80, 214, 80, 6, 81, 237, 80, 236, 80, 230, 80, 238, 80, 7, 81, 11, 81, 221, 78, 61, 108, 88, 79, 101, 79, 206, 79, 160, 159, 70, 108, 116, 124, 110, 81, 253, 93, 201, 158, 152, 153, 129, 81, 20, 89, 249, 82, 13, 83, 7, 138, 16, 83, 235, 81, 25, 89, 85, 81, 160, 78, 86, 81, 179, 78, 110, 136, 164, 136, 181, 78, 20, 129, 210, 136, 128, 121, 52, 91, 3, 136, 184, 127, 171, 81, 177, 81, 189, 81, 188, 81, 14, 141, 15, 141, 16, 141, 17, 141, 18, 141, 19, 141, 20, 141, 21, 141, 22, 141, 23, 141, 24, 141, 25, 141, 26, 141, 27, 141, 28, 141, 32, 141, 81, 141, 82, 141, 87, 141, 95, 141, 101, 141, 104, 141, 105, 141, 106, 141, 108, 141, 110, 141, 111, 141, 113, 141, 114, 141, 120, 141, 121, 141, 122, 141, 123, 141, 124, 141, 125, 141, 126, 141, 127, 141, 128, 141, 130, 141, 131, 141, 134, 141, 135, 141, 136, 141, 137, 141, 140, 141, 141, 141, 142, 141, 143, 141, 144, 141, 146, 141, 147, 141, 149, 141, 150, 141, 151, 141, 152, 141, 153, 141, 154, 141, 155, 141, 156, 141, 157, 141, 158, 141, 160, 141, 161, 141, 162, 141, 164, 141, 165, 141, 166, 141, 167, 141, 168, 141, 169, 141, 170, 141, 171, 141, 172, 141, 173, 141, 174, 141, 175, 141, 176, 141, 178, 141, 182, 141, 183, 141, 185, 141, 187, 141, 189, 141, 192, 141, 193, 141, 194, 141, 197, 141, 199, 141, 200, 141, 201, 141, 202, 141, 205, 141, 208, 141, 210, 141, 211, 141, 212, 141, 199, 81, 150, 81, 162, 81, 165, 81, 160, 139, 166, 139, 167, 139, 170, 139, 180, 139, 181, 139, 183, 139, 194, 139, 195, 139, 203, 139, 207, 139, 206, 139, 210, 139, 211, 139, 212, 139, 214, 139, 216, 139, 217, 139, 220, 139, 223, 139, 224, 139, 228, 139, 232, 139, 233, 139, 238, 139, 240, 139, 243, 139, 246, 139, 249, 139, 252, 139, 255, 139, 0, 140, 2, 140, 4, 140, 7, 140, 12, 140, 15, 140, 17, 140, 18, 140, 20, 140, 21, 140, 22, 140, 25, 140, 27, 140, 24, 140, 29, 140, 31, 140, 32, 140, 33, 140, 37, 140, 39, 140, 42, 140, 43, 140, 46, 140, 47, 140, 50, 140, 51, 140, 53, 140, 54, 140, 105, 83, 122, 83, 29, 150, 34, 150, 33, 150, 49, 150, 42, 150, 61, 150, 60, 150, 66, 150, 73, 150, 84, 150, 95, 150, 103, 150, 108, 150, 114, 150, 116, 150, 136, 150, 141, 150, 151, 150, 176, 150, 151, 144, 155, 144, 157, 144, 153, 144, 172, 144, 161, 144, 180, 144, 179, 144, 182, 144, 186, 144, 213, 141, 216, 141, 217, 141, 220, 141, 224, 141, 225, 141, 226, 141, 229, 141, 230, 141, 231, 141, 233, 141, 237, 141, 238, 141, 240, 141, 241, 141, 242, 141, 244, 141, 246, 141, 252, 141, 254, 141, 255, 141, 0, 142, 1, 142, 2, 142, 3, 142, 4, 142, 6, 142, 7, 142, 8, 142, 11, 142, 13, 142, 14, 142, 16, 142, 17, 142, 18, 142, 19, 142, 21, 142, 22, 142, 23, 142, 24, 142, 25, 142, 26, 142, 27, 142, 28, 142, 32, 142, 33, 142, 36, 142, 37, 142, 38, 142, 39, 142, 40, 142, 43, 142, 45, 142, 48, 142, 50, 142, 51, 142, 52, 142, 54, 142, 55, 142, 56, 142, 59, 142, 60, 142, 62, 142, 63, 142, 67, 142, 69, 142, 70, 142, 76, 142, 77, 142, 78, 142, 79, 142, 80, 142, 83, 142, 84, 142, 85, 142, 86, 142, 87, 142, 88, 142, 90, 142, 91, 142, 92, 142, 93, 142, 94, 142, 95, 142, 96, 142, 97, 142, 98, 142, 99, 142, 100, 142, 101, 142, 103, 142, 104, 142, 106, 142, 107, 142, 110, 142, 113, 142, 184, 144, 176, 144, 207, 144, 197, 144, 190, 144, 208, 144, 196, 144, 199, 144, 211, 144, 230, 144, 226, 144, 220, 144, 215, 144, 219, 144, 235, 144, 239, 144, 254, 144, 4, 145, 34, 145, 30, 145, 35, 145, 49, 145, 47, 145, 57, 145, 67, 145, 70, 145, 13, 82, 66, 89, 162, 82, 172, 82, 173, 82, 190, 82, 255, 84, 208, 82, 214, 82, 240, 82, 223, 83, 238, 113, 205, 119, 244, 94, 245, 81, 252, 81, 47, 155, 182, 83, 1, 95, 90, 117, 239, 93, 76, 87, 169, 87, 161, 87, 126, 88, 188, 88, 197, 88, 209, 88, 41, 87, 44, 87, 42, 87, 51, 87, 57, 87, 46, 87, 47, 87, 92, 87, 59, 87, 66, 87, 105, 87, 133, 87, 107, 87, 134, 87, 124, 87, 123, 87, 104, 87, 109, 87, 118, 87, 115, 87, 173, 87, 164, 87, 140, 87, 178, 87, 207, 87, 167, 87, 180, 87, 147, 87, 160, 87, 213, 87, 216, 87, 218, 87, 217, 87, 210, 87, 184, 87, 244, 87, 239, 87, 248, 87, 228, 87, 221, 87, 115, 142, 117, 142, 119, 142, 120, 142, 121, 142, 122, 142, 123, 142, 125, 142, 126, 142, 128, 142, 130, 142, 131, 142, 132, 142, 134, 142, 136, 142, 137, 142, 138, 142, 139, 142, 140, 142, 141, 142, 142, 142, 145, 142, 146, 142, 147, 142, 149, 142, 150, 142, 151, 142, 152, 142, 153, 142, 154, 142, 155, 142, 157, 142, 159, 142, 160, 142, 161, 142, 162, 142, 163, 142, 164, 142, 165, 142, 166, 142, 167, 142, 168, 142, 169, 142, 170, 142, 173, 142, 174, 142, 176, 142, 177, 142, 179, 142, 180, 142, 181, 142, 182, 142, 183, 142, 184, 142, 185, 142, 187, 142, 188, 142, 189, 142, 190, 142, 191, 142, 192, 142, 193, 142, 194, 142, 195, 142, 196, 142, 197, 142, 198, 142, 199, 142, 200, 142, 201, 142, 202, 142, 203, 142, 204, 142, 205, 142, 207, 142, 208, 142, 209, 142, 210, 142, 211, 142, 212, 142, 213, 142, 214, 142, 215, 142, 216, 142, 217, 142, 218, 142, 219, 142, 220, 142, 221, 142, 222, 142, 223, 142, 224, 142, 225, 142, 226, 142, 227, 142, 228, 142, 11, 88, 13, 88, 253, 87, 237, 87, 0, 88, 30, 88, 25, 88, 68, 88, 32, 88, 101, 88, 108, 88, 129, 88, 137, 88, 154, 88, 128, 88, 168, 153, 25, 159, 255, 97, 121, 130, 125, 130, 127, 130, 143, 130, 138, 130, 168, 130, 132, 130, 142, 130, 145, 130, 151, 130, 153, 130, 171, 130, 184, 130, 190, 130, 176, 130, 200, 130, 202, 130, 227, 130, 152, 130, 183, 130, 174, 130, 203, 130, 204, 130, 193, 130, 169, 130, 180, 130, 161, 130, 170, 130, 159, 130, 196, 130, 206, 130, 164, 130, 225, 130, 9, 131, 247, 130, 228, 130, 15, 131, 7, 131, 220, 130, 244, 130, 210, 130, 216, 130, 12, 131, 251, 130, 211, 130, 17, 131, 26, 131, 6, 131, 20, 131, 21, 131, 224, 130, 213, 130, 28, 131, 81, 131, 91, 131, 92, 131, 8, 131, 146, 131, 60, 131, 52, 131, 49, 131, 155, 131, 94, 131, 47, 131, 79, 131, 71, 131, 67, 131, 95, 131, 64, 131, 23, 131, 96, 131, 45, 131, 58, 131, 51, 131, 102, 131, 101, 131, 229, 142, 230, 142, 231, 142, 232, 142, 233, 142, 234, 142, 235, 142, 236, 142, 237, 142, 238, 142, 239, 142, 240, 142, 241, 142, 242, 142, 243, 142, 244, 142, 245, 142, 246, 142, 247, 142, 248, 142, 249, 142, 250, 142, 251, 142, 252, 142, 253, 142, 254, 142, 255, 142, 0, 143, 1, 143, 2, 143, 3, 143, 4, 143, 5, 143, 6, 143, 7, 143, 8, 143, 9, 143, 10, 143, 11, 143, 12, 143, 13, 143, 14, 143, 15, 143, 16, 143, 17, 143, 18, 143, 19, 143, 20, 143, 21, 143, 22, 143, 23, 143, 24, 143, 25, 143, 26, 143, 27, 143, 28, 143, 29, 143, 30, 143, 31, 143, 32, 143, 33, 143, 34, 143, 35, 143, 36, 143, 37, 143, 38, 143, 39, 143, 40, 143, 41, 143, 42, 143, 43, 143, 44, 143, 45, 143, 46, 143, 47, 143, 48, 143, 49, 143, 50, 143, 51, 143, 52, 143, 53, 143, 54, 143, 55, 143, 56, 143, 57, 143, 58, 143, 59, 143, 60, 143, 61, 143, 62, 143, 63, 143, 64, 143, 65, 143, 66, 143, 67, 143, 68, 143, 104, 131, 27, 131, 105, 131, 108, 131, 106, 131, 109, 131, 110, 131, 176, 131, 120, 131, 179, 131, 180, 131, 160, 131, 170, 131, 147, 131, 156, 131, 133, 131, 124, 131, 182, 131, 169, 131, 125, 131, 184, 131, 123, 131, 152, 131, 158, 131, 168, 131, 186, 131, 188, 131, 193, 131, 1, 132, 229, 131, 216, 131, 7, 88, 24, 132, 11, 132, 221, 131, 253, 131, 214, 131, 28, 132, 56, 132, 17, 132, 6, 132, 212, 131, 223, 131, 15, 132, 3, 132, 248, 131, 249, 131, 234, 131, 197, 131, 192, 131, 38, 132, 240, 131, 225, 131, 92, 132, 81, 132, 90, 132, 89, 132, 115, 132, 135, 132, 136, 132, 122, 132, 137, 132, 120, 132, 60, 132, 70, 132, 105, 132, 118, 132, 140, 132, 142, 132, 49, 132, 109, 132, 193, 132, 205, 132, 208, 132, 230, 132, 189, 132, 211, 132, 202, 132, 191, 132, 186, 132, 224, 132, 161, 132, 185, 132, 180, 132, 151, 132, 229, 132, 227, 132, 12, 133, 13, 117, 56, 133, 240, 132, 57, 133, 31, 133, 58, 133, 69, 143, 70, 143, 71, 143, 72, 143, 73, 143, 74, 143, 75, 143, 76, 143, 77, 143, 78, 143, 79, 143, 80, 143, 81, 143, 82, 143, 83, 143, 84, 143, 85, 143, 86, 143, 87, 143, 88, 143, 89, 143, 90, 143, 91, 143, 92, 143, 93, 143, 94, 143, 95, 143, 96, 143, 97, 143, 98, 143, 99, 143, 100, 143, 101, 143, 106, 143, 128, 143, 140, 143, 146, 143, 157, 143, 160, 143, 161, 143, 162, 143, 164, 143, 165, 143, 166, 143, 167, 143, 170, 143, 172, 143, 173, 143, 174, 143, 175, 143, 178, 143, 179, 143, 180, 143, 181, 143, 183, 143, 184, 143, 186, 143, 187, 143, 188, 143, 191, 143, 192, 143, 195, 143, 198, 143, 201, 143, 202, 143, 203, 143, 204, 143, 205, 143, 207, 143, 210, 143, 214, 143, 215, 143, 218, 143, 224, 143, 225, 143, 227, 143, 231, 143, 236, 143, 239, 143, 241, 143, 242, 143, 244, 143, 245, 143, 246, 143, 250, 143, 251, 143, 252, 143, 254, 143, 255, 143, 7, 144, 8, 144, 12, 144, 14, 144, 19, 144, 21, 144, 24, 144, 86, 133, 59, 133, 255, 132, 252, 132, 89, 133, 72, 133, 104, 133, 100, 133, 94, 133, 122, 133, 162, 119, 67, 133, 114, 133, 123, 133, 164, 133, 168, 133, 135, 133, 143, 133, 121, 133, 174, 133, 156, 133, 133, 133, 185, 133, 183, 133, 176, 133, 211, 133, 193, 133, 220, 133, 255, 133, 39, 134, 5, 134, 41, 134, 22, 134, 60, 134, 254, 94, 8, 95, 60, 89, 65, 89, 55, 128, 85, 89, 90, 89, 88, 89, 15, 83, 34, 92, 37, 92, 44, 92, 52, 92, 76, 98, 106, 98, 159, 98, 187, 98, 202, 98, 218, 98, 215, 98, 238, 98, 34, 99, 246, 98, 57, 99, 75, 99, 67, 99, 173, 99, 246, 99, 113, 99, 122, 99, 142, 99, 180, 99, 109, 99, 172, 99, 138, 99, 105, 99, 174, 99, 188, 99, 242, 99, 248, 99, 224, 99, 255, 99, 196, 99, 222, 99, 206, 99, 82, 100, 198, 99, 190, 99, 69, 100, 65, 100, 11, 100, 27, 100, 32, 100, 12, 100, 38, 100, 33, 100, 94, 100, 132, 100, 109, 100, 150, 100, 25, 144, 28, 144, 35, 144, 36, 144, 37, 144, 39, 144, 40, 144, 41, 144, 42, 144, 43, 144, 44, 144, 48, 144, 49, 144, 50, 144, 51, 144, 52, 144, 55, 144, 57, 144, 58, 144, 61, 144, 63, 144, 64, 144, 67, 144, 69, 144, 70, 144, 72, 144, 73, 144, 74, 144, 75, 144, 76, 144, 78, 144, 84, 144, 85, 144, 86, 144, 89, 144, 90, 144, 92, 144, 93, 144, 94, 144, 95, 144, 96, 144, 97, 144, 100, 144, 102, 144, 103, 144, 105, 144, 106, 144, 107, 144, 108, 144, 111, 144, 112, 144, 113, 144, 114, 144, 115, 144, 118, 144, 119, 144, 120, 144, 121, 144, 122, 144, 123, 144, 124, 144, 126, 144, 129, 144, 132, 144, 133, 144, 134, 144, 135, 144, 137, 144, 138, 144, 140, 144, 141, 144, 142, 144, 143, 144, 144, 144, 146, 144, 148, 144, 150, 144, 152, 144, 154, 144, 156, 144, 158, 144, 159, 144, 160, 144, 164, 144, 165, 144, 167, 144, 168, 144, 169, 144, 171, 144, 173, 144, 178, 144, 183, 144, 188, 144, 189, 144, 191, 144, 192, 144, 122, 100, 183, 100, 184, 100, 153, 100, 186, 100, 192, 100, 208, 100, 215, 100, 228, 100, 226, 100, 9, 101, 37, 101, 46, 101, 11, 95, 210, 95, 25, 117, 17, 95, 95, 83, 241, 83, 253, 83, 233, 83, 232, 83, 251, 83, 18, 84, 22, 84, 6, 84, 75, 84, 82, 84, 83, 84, 84, 84, 86, 84, 67, 84, 33, 84, 87, 84, 89, 84, 35, 84, 50, 84, 130, 84, 148, 84, 119, 84, 113, 84, 100, 84, 154, 84, 155, 84, 132, 84, 118, 84, 102, 84, 157, 84, 208, 84, 173, 84, 194, 84, 180, 84, 210, 84, 167, 84, 166, 84, 211, 84, 212, 84, 114, 84, 163, 84, 213, 84, 187, 84, 191, 84, 204, 84, 217, 84, 218, 84, 220, 84, 169, 84, 170, 84, 164, 84, 221, 84, 207, 84, 222, 84, 27, 85, 231, 84, 32, 85, 253, 84, 20, 85, 243, 84, 34, 85, 35, 85, 15, 85, 17, 85, 39, 85, 42, 85, 103, 85, 143, 85, 181, 85, 73, 85, 109, 85, 65, 85, 85, 85, 63, 85, 80, 85, 60, 85, 194, 144, 195, 144, 198, 144, 200, 144, 201, 144, 203, 144, 204, 144, 205, 144, 210, 144, 212, 144, 213, 144, 214, 144, 216, 144, 217, 144, 218, 144, 222, 144, 223, 144, 224, 144, 227, 144, 228, 144, 229, 144, 233, 144, 234, 144, 236, 144, 238, 144, 240, 144, 241, 144, 242, 144, 243, 144, 245, 144, 246, 144, 247, 144, 249, 144, 250, 144, 251, 144, 252, 144, 255, 144, 0, 145, 1, 145, 3, 145, 5, 145, 6, 145, 7, 145, 8, 145, 9, 145, 10, 145, 11, 145, 12, 145, 13, 145, 14, 145, 15, 145, 16, 145, 17, 145, 18, 145, 19, 145, 20, 145, 21, 145, 22, 145, 23, 145, 24, 145, 26, 145, 27, 145, 28, 145, 29, 145, 31, 145, 32, 145, 33, 145, 36, 145, 37, 145, 38, 145, 39, 145, 40, 145, 41, 145, 42, 145, 43, 145, 44, 145, 45, 145, 46, 145, 48, 145, 50, 145, 51, 145, 52, 145, 53, 145, 54, 145, 55, 145, 56, 145, 58, 145, 59, 145, 60, 145, 61, 145, 62, 145, 63, 145, 64, 145, 65, 145, 66, 145, 68, 145, 55, 85, 86, 85, 117, 85, 118, 85, 119, 85, 51, 85, 48, 85, 92, 85, 139, 85, 210, 85, 131, 85, 177, 85, 185, 85, 136, 85, 129, 85, 159, 85, 126, 85, 214, 85, 145, 85, 123, 85, 223, 85, 189, 85, 190, 85, 148, 85, 153, 85, 234, 85, 247, 85, 201, 85, 31, 86, 209, 85, 235, 85, 236, 85, 212, 85, 230, 85, 221, 85, 196, 85, 239, 85, 229, 85, 242, 85, 243, 85, 204, 85, 205, 85, 232, 85, 245, 85, 228, 85, 148, 143, 30, 86, 8, 86, 12, 86, 1, 86, 36, 86, 35, 86, 254, 85, 0, 86, 39, 86, 45, 86, 88, 86, 57, 86, 87, 86, 44, 86, 77, 86, 98, 86, 89, 86, 92, 86, 76, 86, 84, 86, 134, 86, 100, 86, 113, 86, 107, 86, 123, 86, 124, 86, 133, 86, 147, 86, 175, 86, 212, 86, 215, 86, 221, 86, 225, 86, 245, 86, 235, 86, 249, 86, 255, 86, 4, 87, 10, 87, 9, 87, 28, 87, 15, 94, 25, 94, 20, 94, 17, 94, 49, 94, 59, 94, 60, 94, 69, 145, 71, 145, 72, 145, 81, 145, 83, 145, 84, 145, 85, 145, 86, 145, 88, 145, 89, 145, 91, 145, 92, 145, 95, 145, 96, 145, 102, 145, 103, 145, 104, 145, 107, 145, 109, 145, 115, 145, 122, 145, 123, 145, 124, 145, 128, 145, 129, 145, 130, 145, 131, 145, 132, 145, 134, 145, 136, 145, 138, 145, 142, 145, 143, 145, 147, 145, 148, 145, 149, 145, 150, 145, 151, 145, 152, 145, 153, 145, 156, 145, 157, 145, 158, 145, 159, 145, 160, 145, 161, 145, 164, 145, 165, 145, 166, 145, 167, 145, 168, 145, 169, 145, 171, 145, 172, 145, 176, 145, 177, 145, 178, 145, 179, 145, 182, 145, 183, 145, 184, 145, 185, 145, 187, 145, 188, 145, 189, 145, 190, 145, 191, 145, 192, 145, 193, 145, 194, 145, 195, 145, 196, 145, 197, 145, 198, 145, 200, 145, 203, 145, 208, 145, 210, 145, 211, 145, 212, 145, 213, 145, 214, 145, 215, 145, 216, 145, 217, 145, 218, 145, 219, 145, 221, 145, 222, 145, 223, 145, 224, 145, 225, 145, 226, 145, 227, 145, 228, 145, 229, 145, 55, 94, 68, 94, 84, 94, 91, 94, 94, 94, 97, 94, 140, 92, 122, 92, 141, 92, 144, 92, 150, 92, 136, 92, 152, 92, 153, 92, 145, 92, 154, 92, 156, 92, 181, 92, 162, 92, 189, 92, 172, 92, 171, 92, 177, 92, 163, 92, 193, 92, 183, 92, 196, 92, 210, 92, 228, 92, 203, 92, 229, 92, 2, 93, 3, 93, 39, 93, 38, 93, 46, 93, 36, 93, 30, 93, 6, 93, 27, 93, 88, 93, 62, 93, 52, 93, 61, 93, 108, 93, 91, 93, 111, 93, 93, 93, 107, 93, 75, 93, 74, 93, 105, 93, 116, 93, 130, 93, 153, 93, 157, 93, 115, 140, 183, 93, 197, 93, 115, 95, 119, 95, 130, 95, 135, 95, 137, 95, 140, 95, 149, 95, 153, 95, 156, 95, 168, 95, 173, 95, 181, 95, 188, 95, 98, 136, 97, 95, 173, 114, 176, 114, 180, 114, 183, 114, 184, 114, 195, 114, 193, 114, 206, 114, 205, 114, 210, 114, 232, 114, 239, 114, 233, 114, 242, 114, 244, 114, 247, 114, 1, 115, 243, 114, 3, 115, 250, 114, 230, 145, 231, 145, 232, 145, 233, 145, 234, 145, 235, 145, 236, 145, 237, 145, 238, 145, 239, 145, 240, 145, 241, 145, 242, 145, 243, 145, 244, 145, 245, 145, 246, 145, 247, 145, 248, 145, 249, 145, 250, 145, 251, 145, 252, 145, 253, 145, 254, 145, 255, 145, 0, 146, 1, 146, 2, 146, 3, 146, 4, 146, 5, 146, 6, 146, 7, 146, 8, 146, 9, 146, 10, 146, 11, 146, 12, 146, 13, 146, 14, 146, 15, 146, 16, 146, 17, 146, 18, 146, 19, 146, 20, 146, 21, 146, 22, 146, 23, 146, 24, 146, 25, 146, 26, 146, 27, 146, 28, 146, 29, 146, 30, 146, 31, 146, 32, 146, 33, 146, 34, 146, 35, 146, 36, 146, 37, 146, 38, 146, 39, 146, 40, 146, 41, 146, 42, 146, 43, 146, 44, 146, 45, 146, 46, 146, 47, 146, 48, 146, 49, 146, 50, 146, 51, 146, 52, 146, 53, 146, 54, 146, 55, 146, 56, 146, 57, 146, 58, 146, 59, 146, 60, 146, 61, 146, 62, 146, 63, 146, 64, 146, 65, 146, 66, 146, 67, 146, 68, 146, 69, 146, 251, 114, 23, 115, 19, 115, 33, 115, 10, 115, 30, 115, 29, 115, 21, 115, 34, 115, 57, 115, 37, 115, 44, 115, 56, 115, 49, 115, 80, 115, 77, 115, 87, 115, 96, 115, 108, 115, 111, 115, 126, 115, 27, 130, 37, 89, 231, 152, 36, 89, 2, 89, 99, 153, 103, 153, 104, 153, 105, 153, 106, 153, 107, 153, 108, 153, 116, 153, 119, 153, 125, 153, 128, 153, 132, 153, 135, 153, 138, 153, 141, 153, 144, 153, 145, 153, 147, 153, 148, 153, 149, 153, 128, 94, 145, 94, 139, 94, 150, 94, 165, 94, 160, 94, 185, 94, 181, 94, 190, 94, 179, 94, 83, 141, 210, 94, 209, 94, 219, 94, 232, 94, 234, 94, 186, 129, 196, 95, 201, 95, 214, 95, 207, 95, 3, 96, 238, 95, 4, 96, 225, 95, 228, 95, 254, 95, 5, 96, 6, 96, 234, 95, 237, 95, 248, 95, 25, 96, 53, 96, 38, 96, 27, 96, 15, 96, 13, 96, 41, 96, 43, 96, 10, 96, 63, 96, 33, 96, 120, 96, 121, 96, 123, 96, 122, 96, 66, 96, 70, 146, 71, 146, 72, 146, 73, 146, 74, 146, 75, 146, 76, 146, 77, 146, 78, 146, 79, 146, 80, 146, 81, 146, 82, 146, 83, 146, 84, 146, 85, 146, 86, 146, 87, 146, 88, 146, 89, 146, 90, 146, 91, 146, 92, 146, 93, 146, 94, 146, 95, 146, 96, 146, 97, 146, 98, 146, 99, 146, 100, 146, 101, 146, 102, 146, 103, 146, 104, 146, 105, 146, 106, 146, 107, 146, 108, 146, 109, 146, 110, 146, 111, 146, 112, 146, 113, 146, 114, 146, 115, 146, 117, 146, 118, 146, 119, 146, 120, 146, 121, 146, 122, 146, 123, 146, 124, 146, 125, 146, 126, 146, 127, 146, 128, 146, 129, 146, 130, 146, 131, 146, 132, 146, 133, 146, 134, 146, 135, 146, 136, 146, 137, 146, 138, 146, 139, 146, 140, 146, 141, 146, 143, 146, 144, 146, 145, 146, 146, 146, 147, 146, 148, 146, 149, 146, 150, 146, 151, 146, 152, 146, 153, 146, 154, 146, 155, 146, 156, 146, 157, 146, 158, 146, 159, 146, 160, 146, 161, 146, 162, 146, 163, 146, 164, 146, 165, 146, 166, 146, 167, 146, 106, 96, 125, 96, 150, 96, 154, 96, 173, 96, 157, 96, 131, 96, 146, 96, 140, 96, 155, 96, 236, 96, 187, 96, 177, 96, 221, 96, 216, 96, 198, 96, 218, 96, 180, 96, 32, 97, 38, 97, 21, 97, 35, 97, 244, 96, 0, 97, 14, 97, 43, 97, 74, 97, 117, 97, 172, 97, 148, 97, 167, 97, 183, 97, 212, 97, 245, 97, 221, 95, 179, 150, 233, 149, 235, 149, 241, 149, 243, 149, 245, 149, 246, 149, 252, 149, 254, 149, 3, 150, 4, 150, 6, 150, 8, 150, 10, 150, 11, 150, 12, 150, 13, 150, 15, 150, 18, 150, 21, 150, 22, 150, 23, 150, 25, 150, 26, 150, 44, 78, 63, 114, 21, 98, 53, 108, 84, 108, 92, 108, 74, 108, 163, 108, 133, 108, 144, 108, 148, 108, 140, 108, 104, 108, 105, 108, 116, 108, 118, 108, 134, 108, 169, 108, 208, 108, 212, 108, 173, 108, 247, 108, 248, 108, 241, 108, 215, 108, 178, 108, 224, 108, 214, 108, 250, 108, 235, 108, 238, 108, 177, 108, 211, 108, 239, 108, 254, 108, 168, 146, 169, 146, 170, 146, 171, 146, 172, 146, 173, 146, 175, 146, 176, 146, 177, 146, 178, 146, 179, 146, 180, 146, 181, 146, 182, 146, 183, 146, 184, 146, 185, 146, 186, 146, 187, 146, 188, 146, 189, 146, 190, 146, 191, 146, 192, 146, 193, 146, 194, 146, 195, 146, 196, 146, 197, 146, 198, 146, 199, 146, 201, 146, 202, 146, 203, 146, 204, 146, 205, 146, 206, 146, 207, 146, 208, 146, 209, 146, 210, 146, 211, 146, 212, 146, 213, 146, 214, 146, 215, 146, 216, 146, 217, 146, 218, 146, 219, 146, 220, 146, 221, 146, 222, 146, 223, 146, 224, 146, 225, 146, 226, 146, 227, 146, 228, 146, 229, 146, 230, 146, 231, 146, 232, 146, 233, 146, 234, 146, 235, 146, 236, 146, 237, 146, 238, 146, 239, 146, 240, 146, 241, 146, 242, 146, 243, 146, 244, 146, 245, 146, 246, 146, 247, 146, 248, 146, 249, 146, 250, 146, 251, 146, 252, 146, 253, 146, 254, 146, 255, 146, 0, 147, 1, 147, 2, 147, 3, 147, 4, 147, 5, 147, 6, 147, 7, 147, 8, 147, 9, 147, 57, 109, 39, 109, 12, 109, 67, 109, 72, 109, 7, 109, 4, 109, 25, 109, 14, 109, 43, 109, 77, 109, 46, 109, 53, 109, 26, 109, 79, 109, 82, 109, 84, 109, 51, 109, 145, 109, 111, 109, 158, 109, 160, 109, 94, 109, 147, 109, 148, 109, 92, 109, 96, 109, 124, 109, 99, 109, 26, 110, 199, 109, 197, 109, 222, 109, 14, 110, 191, 109, 224, 109, 17, 110, 230, 109, 221, 109, 217, 109, 22, 110, 171, 109, 12, 110, 174, 109, 43, 110, 110, 110, 78, 110, 107, 110, 178, 110, 95, 110, 134, 110, 83, 110, 84, 110, 50, 110, 37, 110, 68, 110, 223, 110, 177, 110, 152, 110, 224, 110, 45, 111, 226, 110, 165, 110, 167, 110, 189, 110, 187, 110, 183, 110, 215, 110, 180, 110, 207, 110, 143, 110, 194, 110, 159, 110, 98, 111, 70, 111, 71, 111, 36, 111, 21, 111, 249, 110, 47, 111, 54, 111, 75, 111, 116, 111, 42, 111, 9, 111, 41, 111, 137, 111, 141, 111, 140, 111, 120, 111, 114, 111, 124, 111, 122, 111, 209, 111, 10, 147, 11, 147, 12, 147, 13, 147, 14, 147, 15, 147, 16, 147, 17, 147, 18, 147, 19, 147, 20, 147, 21, 147, 22, 147, 23, 147, 24, 147, 25, 147, 26, 147, 27, 147, 28, 147, 29, 147, 30, 147, 31, 147, 32, 147, 33, 147, 34, 147, 35, 147, 36, 147, 37, 147, 38, 147, 39, 147, 40, 147, 41, 147, 42, 147, 43, 147, 44, 147, 45, 147, 46, 147, 47, 147, 48, 147, 49, 147, 50, 147, 51, 147, 52, 147, 53, 147, 54, 147, 55, 147, 56, 147, 57, 147, 58, 147, 59, 147, 60, 147, 61, 147, 63, 147, 64, 147, 65, 147, 66, 147, 67, 147, 68, 147, 69, 147, 70, 147, 71, 147, 72, 147, 73, 147, 74, 147, 75, 147, 76, 147, 77, 147, 78, 147, 79, 147, 80, 147, 81, 147, 82, 147, 83, 147, 84, 147, 85, 147, 86, 147, 87, 147, 88, 147, 89, 147, 90, 147, 91, 147, 92, 147, 93, 147, 94, 147, 95, 147, 96, 147, 97, 147, 98, 147, 99, 147, 100, 147, 101, 147, 102, 147, 103, 147, 104, 147, 105, 147, 107, 147, 201, 111, 167, 111, 185, 111, 182, 111, 194, 111, 225, 111, 238, 111, 222, 111, 224, 111, 239, 111, 26, 112, 35, 112, 27, 112, 57, 112, 53, 112, 79, 112, 94, 112, 128, 91], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 251068);
	        allocate([132, 91, 149, 91, 147, 91, 165, 91, 184, 91, 47, 117, 158, 154, 52, 100, 228, 91, 238, 91, 48, 137, 240, 91, 71, 142, 7, 139, 182, 143, 211, 143, 213, 143, 229, 143, 238, 143, 228, 143, 233, 143, 230, 143, 243, 143, 232, 143, 5, 144, 4, 144, 11, 144, 38, 144, 17, 144, 13, 144, 22, 144, 33, 144, 53, 144, 54, 144, 45, 144, 47, 144, 68, 144, 81, 144, 82, 144, 80, 144, 104, 144, 88, 144, 98, 144, 91, 144, 185, 102, 116, 144, 125, 144, 130, 144, 136, 144, 131, 144, 139, 144, 80, 95, 87, 95, 86, 95, 88, 95, 59, 92, 171, 84, 80, 92, 89, 92, 113, 91, 99, 92, 102, 92, 188, 127, 42, 95, 41, 95, 45, 95, 116, 130, 60, 95, 59, 155, 110, 92, 129, 89, 131, 89, 141, 89, 169, 89, 170, 89, 163, 89, 108, 147, 109, 147, 110, 147, 111, 147, 112, 147, 113, 147, 114, 147, 115, 147, 116, 147, 117, 147, 118, 147, 119, 147, 120, 147, 121, 147, 122, 147, 123, 147, 124, 147, 125, 147, 126, 147, 127, 147, 128, 147, 129, 147, 130, 147, 131, 147, 132, 147, 133, 147, 134, 147, 135, 147, 136, 147, 137, 147, 138, 147, 139, 147, 140, 147, 141, 147, 142, 147, 144, 147, 145, 147, 146, 147, 147, 147, 148, 147, 149, 147, 150, 147, 151, 147, 152, 147, 153, 147, 154, 147, 155, 147, 156, 147, 157, 147, 158, 147, 159, 147, 160, 147, 161, 147, 162, 147, 163, 147, 164, 147, 165, 147, 166, 147, 167, 147, 168, 147, 169, 147, 170, 147, 171, 147, 172, 147, 173, 147, 174, 147, 175, 147, 176, 147, 177, 147, 178, 147, 179, 147, 180, 147, 181, 147, 182, 147, 183, 147, 184, 147, 185, 147, 186, 147, 187, 147, 188, 147, 189, 147, 190, 147, 191, 147, 192, 147, 193, 147, 194, 147, 195, 147, 196, 147, 197, 147, 198, 147, 199, 147, 200, 147, 201, 147, 203, 147, 204, 147, 205, 147, 151, 89, 202, 89, 171, 89, 158, 89, 164, 89, 210, 89, 178, 89, 175, 89, 215, 89, 190, 89, 5, 90, 6, 90, 221, 89, 8, 90, 227, 89, 216, 89, 249, 89, 12, 90, 9, 90, 50, 90, 52, 90, 17, 90, 35, 90, 19, 90, 64, 90, 103, 90, 74, 90, 85, 90, 60, 90, 98, 90, 117, 90, 236, 128, 170, 90, 155, 90, 119, 90, 122, 90, 190, 90, 235, 90, 178, 90, 210, 90, 212, 90, 184, 90, 224, 90, 227, 90, 241, 90, 214, 90, 230, 90, 216, 90, 220, 90, 9, 91, 23, 91, 22, 91, 50, 91, 55, 91, 64, 91, 21, 92, 28, 92, 90, 91, 101, 91, 115, 91, 81, 91, 83, 91, 98, 91, 117, 154, 119, 154, 120, 154, 122, 154, 127, 154, 125, 154, 128, 154, 129, 154, 133, 154, 136, 154, 138, 154, 144, 154, 146, 154, 147, 154, 150, 154, 152, 154, 155, 154, 156, 154, 157, 154, 159, 154, 160, 154, 162, 154, 163, 154, 165, 154, 167, 154, 159, 126, 161, 126, 163, 126, 165, 126, 168, 126, 169, 126, 206, 147, 207, 147, 208, 147, 209, 147, 210, 147, 211, 147, 212, 147, 213, 147, 215, 147, 216, 147, 217, 147, 218, 147, 219, 147, 220, 147, 221, 147, 222, 147, 223, 147, 224, 147, 225, 147, 226, 147, 227, 147, 228, 147, 229, 147, 230, 147, 231, 147, 232, 147, 233, 147, 234, 147, 235, 147, 236, 147, 237, 147, 238, 147, 239, 147, 240, 147, 241, 147, 242, 147, 243, 147, 244, 147, 245, 147, 246, 147, 247, 147, 248, 147, 249, 147, 250, 147, 251, 147, 252, 147, 253, 147, 254, 147, 255, 147, 0, 148, 1, 148, 2, 148, 3, 148, 4, 148, 5, 148, 6, 148, 7, 148, 8, 148, 9, 148, 10, 148, 11, 148, 12, 148, 13, 148, 14, 148, 15, 148, 16, 148, 17, 148, 18, 148, 19, 148, 20, 148, 21, 148, 22, 148, 23, 148, 24, 148, 25, 148, 26, 148, 27, 148, 28, 148, 29, 148, 30, 148, 31, 148, 32, 148, 33, 148, 34, 148, 35, 148, 36, 148, 37, 148, 38, 148, 39, 148, 40, 148, 41, 148, 42, 148, 43, 148, 44, 148, 45, 148, 46, 148, 173, 126, 176, 126, 190, 126, 192, 126, 193, 126, 194, 126, 201, 126, 203, 126, 204, 126, 208, 126, 212, 126, 215, 126, 219, 126, 224, 126, 225, 126, 232, 126, 235, 126, 238, 126, 239, 126, 241, 126, 242, 126, 13, 127, 246, 126, 250, 126, 251, 126, 254, 126, 1, 127, 2, 127, 3, 127, 7, 127, 8, 127, 11, 127, 12, 127, 15, 127, 17, 127, 18, 127, 23, 127, 25, 127, 28, 127, 27, 127, 31, 127, 33, 127, 34, 127, 35, 127, 36, 127, 37, 127, 38, 127, 39, 127, 42, 127, 43, 127, 44, 127, 45, 127, 47, 127, 48, 127, 49, 127, 50, 127, 51, 127, 53, 127, 122, 94, 127, 117, 219, 93, 62, 117, 149, 144, 142, 115, 145, 115, 174, 115, 162, 115, 159, 115, 207, 115, 194, 115, 209, 115, 183, 115, 179, 115, 192, 115, 201, 115, 200, 115, 229, 115, 217, 115, 124, 152, 10, 116, 233, 115, 231, 115, 222, 115, 186, 115, 242, 115, 15, 116, 42, 116, 91, 116, 38, 116, 37, 116, 40, 116, 48, 116, 46, 116, 44, 116, 47, 148, 48, 148, 49, 148, 50, 148, 51, 148, 52, 148, 53, 148, 54, 148, 55, 148, 56, 148, 57, 148, 58, 148, 59, 148, 60, 148, 61, 148, 63, 148, 64, 148, 65, 148, 66, 148, 67, 148, 68, 148, 69, 148, 70, 148, 71, 148, 72, 148, 73, 148, 74, 148, 75, 148, 76, 148, 77, 148, 78, 148, 79, 148, 80, 148, 81, 148, 82, 148, 83, 148, 84, 148, 85, 148, 86, 148, 87, 148, 88, 148, 89, 148, 90, 148, 91, 148, 92, 148, 93, 148, 94, 148, 95, 148, 96, 148, 97, 148, 98, 148, 99, 148, 100, 148, 101, 148, 102, 148, 103, 148, 104, 148, 105, 148, 106, 148, 108, 148, 109, 148, 110, 148, 111, 148, 112, 148, 113, 148, 114, 148, 115, 148, 116, 148, 117, 148, 118, 148, 119, 148, 120, 148, 121, 148, 122, 148, 123, 148, 124, 148, 125, 148, 126, 148, 127, 148, 128, 148, 129, 148, 130, 148, 131, 148, 132, 148, 145, 148, 150, 148, 152, 148, 199, 148, 207, 148, 211, 148, 212, 148, 218, 148, 230, 148, 251, 148, 28, 149, 32, 149, 27, 116, 26, 116, 65, 116, 92, 116, 87, 116, 85, 116, 89, 116, 119, 116, 109, 116, 126, 116, 156, 116, 142, 116, 128, 116, 129, 116, 135, 116, 139, 116, 158, 116, 168, 116, 169, 116, 144, 116, 167, 116, 210, 116, 186, 116, 234, 151, 235, 151, 236, 151, 76, 103, 83, 103, 94, 103, 72, 103, 105, 103, 165, 103, 135, 103, 106, 103, 115, 103, 152, 103, 167, 103, 117, 103, 168, 103, 158, 103, 173, 103, 139, 103, 119, 103, 124, 103, 240, 103, 9, 104, 216, 103, 10, 104, 233, 103, 176, 103, 12, 104, 217, 103, 181, 103, 218, 103, 179, 103, 221, 103, 0, 104, 195, 103, 184, 103, 226, 103, 14, 104, 193, 103, 253, 103, 50, 104, 51, 104, 96, 104, 97, 104, 78, 104, 98, 104, 68, 104, 100, 104, 131, 104, 29, 104, 85, 104, 102, 104, 65, 104, 103, 104, 64, 104, 62, 104, 74, 104, 73, 104, 41, 104, 181, 104, 143, 104, 116, 104, 119, 104, 147, 104, 107, 104, 194, 104, 110, 105, 252, 104, 31, 105, 32, 105, 249, 104, 39, 149, 51, 149, 61, 149, 67, 149, 72, 149, 75, 149, 85, 149, 90, 149, 96, 149, 110, 149, 116, 149, 117, 149, 119, 149, 120, 149, 121, 149, 122, 149, 123, 149, 124, 149, 125, 149, 126, 149, 128, 149, 129, 149, 130, 149, 131, 149, 132, 149, 133, 149, 134, 149, 135, 149, 136, 149, 137, 149, 138, 149, 139, 149, 140, 149, 141, 149, 142, 149, 143, 149, 144, 149, 145, 149, 146, 149, 147, 149, 148, 149, 149, 149, 150, 149, 151, 149, 152, 149, 153, 149, 154, 149, 155, 149, 156, 149, 157, 149, 158, 149, 159, 149, 160, 149, 161, 149, 162, 149, 163, 149, 164, 149, 165, 149, 166, 149, 167, 149, 168, 149, 169, 149, 170, 149, 171, 149, 172, 149, 173, 149, 174, 149, 175, 149, 176, 149, 177, 149, 178, 149, 179, 149, 180, 149, 181, 149, 182, 149, 183, 149, 184, 149, 185, 149, 186, 149, 187, 149, 188, 149, 189, 149, 190, 149, 191, 149, 192, 149, 193, 149, 194, 149, 195, 149, 196, 149, 197, 149, 198, 149, 199, 149, 200, 149, 201, 149, 202, 149, 203, 149, 36, 105, 240, 104, 11, 105, 1, 105, 87, 105, 227, 104, 16, 105, 113, 105, 57, 105, 96, 105, 66, 105, 93, 105, 132, 105, 107, 105, 128, 105, 152, 105, 120, 105, 52, 105, 204, 105, 135, 105, 136, 105, 206, 105, 137, 105, 102, 105, 99, 105, 121, 105, 155, 105, 167, 105, 187, 105, 171, 105, 173, 105, 212, 105, 177, 105, 193, 105, 202, 105, 223, 105, 149, 105, 224, 105, 141, 105, 255, 105, 47, 106, 237, 105, 23, 106, 24, 106, 101, 106, 242, 105, 68, 106, 62, 106, 160, 106, 80, 106, 91, 106, 53, 106, 142, 106, 121, 106, 61, 106, 40, 106, 88, 106, 124, 106, 145, 106, 144, 106, 169, 106, 151, 106, 171, 106, 55, 115, 82, 115, 129, 107, 130, 107, 135, 107, 132, 107, 146, 107, 147, 107, 141, 107, 154, 107, 155, 107, 161, 107, 170, 107, 107, 143, 109, 143, 113, 143, 114, 143, 115, 143, 117, 143, 118, 143, 120, 143, 119, 143, 121, 143, 122, 143, 124, 143, 126, 143, 129, 143, 130, 143, 132, 143, 135, 143, 139, 143, 204, 149, 205, 149, 206, 149, 207, 149, 208, 149, 209, 149, 210, 149, 211, 149, 212, 149, 213, 149, 214, 149, 215, 149, 216, 149, 217, 149, 218, 149, 219, 149, 220, 149, 221, 149, 222, 149, 223, 149, 224, 149, 225, 149, 226, 149, 227, 149, 228, 149, 229, 149, 230, 149, 231, 149, 236, 149, 255, 149, 7, 150, 19, 150, 24, 150, 27, 150, 30, 150, 32, 150, 35, 150, 36, 150, 37, 150, 38, 150, 39, 150, 40, 150, 41, 150, 43, 150, 44, 150, 45, 150, 47, 150, 48, 150, 55, 150, 56, 150, 57, 150, 58, 150, 62, 150, 65, 150, 67, 150, 74, 150, 78, 150, 79, 150, 81, 150, 82, 150, 83, 150, 86, 150, 87, 150, 88, 150, 89, 150, 90, 150, 92, 150, 93, 150, 94, 150, 96, 150, 99, 150, 101, 150, 102, 150, 107, 150, 109, 150, 110, 150, 111, 150, 112, 150, 113, 150, 115, 150, 120, 150, 121, 150, 122, 150, 123, 150, 124, 150, 125, 150, 126, 150, 127, 150, 128, 150, 129, 150, 130, 150, 131, 150, 132, 150, 135, 150, 137, 150, 138, 150, 141, 143, 142, 143, 143, 143, 152, 143, 154, 143, 206, 142, 11, 98, 23, 98, 27, 98, 31, 98, 34, 98, 33, 98, 37, 98, 36, 98, 44, 98, 231, 129, 239, 116, 244, 116, 255, 116, 15, 117, 17, 117, 19, 117, 52, 101, 238, 101, 239, 101, 240, 101, 10, 102, 25, 102, 114, 103, 3, 102, 21, 102, 0, 102, 133, 112, 247, 102, 29, 102, 52, 102, 49, 102, 54, 102, 53, 102, 6, 128, 95, 102, 84, 102, 65, 102, 79, 102, 86, 102, 97, 102, 87, 102, 119, 102, 132, 102, 140, 102, 167, 102, 157, 102, 190, 102, 219, 102, 220, 102, 230, 102, 233, 102, 50, 141, 51, 141, 54, 141, 59, 141, 61, 141, 64, 141, 69, 141, 70, 141, 72, 141, 73, 141, 71, 141, 77, 141, 85, 141, 89, 141, 199, 137, 202, 137, 203, 137, 204, 137, 206, 137, 207, 137, 208, 137, 209, 137, 110, 114, 159, 114, 93, 114, 102, 114, 111, 114, 126, 114, 127, 114, 132, 114, 139, 114, 141, 114, 143, 114, 146, 114, 8, 99, 50, 99, 176, 99, 140, 150, 142, 150, 145, 150, 146, 150, 147, 150, 149, 150, 150, 150, 154, 150, 155, 150, 157, 150, 158, 150, 159, 150, 160, 150, 161, 150, 162, 150, 163, 150, 164, 150, 165, 150, 166, 150, 168, 150, 169, 150, 170, 150, 171, 150, 172, 150, 173, 150, 174, 150, 175, 150, 177, 150, 178, 150, 180, 150, 181, 150, 183, 150, 184, 150, 186, 150, 187, 150, 191, 150, 194, 150, 195, 150, 200, 150, 202, 150, 203, 150, 208, 150, 209, 150, 211, 150, 212, 150, 214, 150, 215, 150, 216, 150, 217, 150, 218, 150, 219, 150, 220, 150, 221, 150, 222, 150, 223, 150, 225, 150, 226, 150, 227, 150, 228, 150, 229, 150, 230, 150, 231, 150, 235, 150, 236, 150, 237, 150, 238, 150, 240, 150, 241, 150, 242, 150, 244, 150, 245, 150, 248, 150, 250, 150, 251, 150, 252, 150, 253, 150, 255, 150, 2, 151, 3, 151, 5, 151, 10, 151, 11, 151, 12, 151, 16, 151, 17, 151, 18, 151, 20, 151, 21, 151, 23, 151, 24, 151, 25, 151, 26, 151, 27, 151, 29, 151, 31, 151, 32, 151, 63, 100, 216, 100, 4, 128, 234, 107, 243, 107, 253, 107, 245, 107, 249, 107, 5, 108, 7, 108, 6, 108, 13, 108, 21, 108, 24, 108, 25, 108, 26, 108, 33, 108, 41, 108, 36, 108, 42, 108, 50, 108, 53, 101, 85, 101, 107, 101, 77, 114, 82, 114, 86, 114, 48, 114, 98, 134, 22, 82, 159, 128, 156, 128, 147, 128, 188, 128, 10, 103, 189, 128, 177, 128, 171, 128, 173, 128, 180, 128, 183, 128, 231, 128, 232, 128, 233, 128, 234, 128, 219, 128, 194, 128, 196, 128, 217, 128, 205, 128, 215, 128, 16, 103, 221, 128, 235, 128, 241, 128, 244, 128, 237, 128, 13, 129, 14, 129, 242, 128, 252, 128, 21, 103, 18, 129, 90, 140, 54, 129, 30, 129, 44, 129, 24, 129, 50, 129, 72, 129, 76, 129, 83, 129, 116, 129, 89, 129, 90, 129, 113, 129, 96, 129, 105, 129, 124, 129, 125, 129, 109, 129, 103, 129, 77, 88, 181, 90, 136, 129, 130, 129, 145, 129, 213, 110, 163, 129, 170, 129, 204, 129, 38, 103, 202, 129, 187, 129, 33, 151, 34, 151, 35, 151, 36, 151, 37, 151, 38, 151, 39, 151, 40, 151, 41, 151, 43, 151, 44, 151, 46, 151, 47, 151, 49, 151, 51, 151, 52, 151, 53, 151, 54, 151, 55, 151, 58, 151, 59, 151, 60, 151, 61, 151, 63, 151, 64, 151, 65, 151, 66, 151, 67, 151, 68, 151, 69, 151, 70, 151, 71, 151, 72, 151, 73, 151, 74, 151, 75, 151, 76, 151, 77, 151, 78, 151, 79, 151, 80, 151, 81, 151, 84, 151, 85, 151, 87, 151, 88, 151, 90, 151, 92, 151, 93, 151, 95, 151, 99, 151, 100, 151, 102, 151, 103, 151, 104, 151, 106, 151, 107, 151, 108, 151, 109, 151, 110, 151, 111, 151, 112, 151, 113, 151, 114, 151, 117, 151, 119, 151, 120, 151, 121, 151, 122, 151, 123, 151, 125, 151, 126, 151, 127, 151, 128, 151, 129, 151, 130, 151, 131, 151, 132, 151, 134, 151, 135, 151, 136, 151, 137, 151, 138, 151, 140, 151, 142, 151, 143, 151, 144, 151, 147, 151, 149, 151, 150, 151, 151, 151, 153, 151, 154, 151, 155, 151, 156, 151, 157, 151, 193, 129, 166, 129, 36, 107, 55, 107, 57, 107, 67, 107, 70, 107, 89, 107, 209, 152, 210, 152, 211, 152, 213, 152, 217, 152, 218, 152, 179, 107, 64, 95, 194, 107, 243, 137, 144, 101, 81, 159, 147, 101, 188, 101, 198, 101, 196, 101, 195, 101, 204, 101, 206, 101, 210, 101, 214, 101, 128, 112, 156, 112, 150, 112, 157, 112, 187, 112, 192, 112, 183, 112, 171, 112, 177, 112, 232, 112, 202, 112, 16, 113, 19, 113, 22, 113, 47, 113, 49, 113, 115, 113, 92, 113, 104, 113, 69, 113, 114, 113, 74, 113, 120, 113, 122, 113, 152, 113, 179, 113, 181, 113, 168, 113, 160, 113, 224, 113, 212, 113, 231, 113, 249, 113, 29, 114, 40, 114, 108, 112, 24, 113, 102, 113, 185, 113, 62, 98, 61, 98, 67, 98, 72, 98, 73, 98, 59, 121, 64, 121, 70, 121, 73, 121, 91, 121, 92, 121, 83, 121, 90, 121, 98, 121, 87, 121, 96, 121, 111, 121, 103, 121, 122, 121, 133, 121, 138, 121, 154, 121, 167, 121, 179, 121, 209, 95, 208, 95, 158, 151, 159, 151, 161, 151, 162, 151, 164, 151, 165, 151, 166, 151, 167, 151, 168, 151, 169, 151, 170, 151, 172, 151, 174, 151, 176, 151, 177, 151, 179, 151, 181, 151, 182, 151, 183, 151, 184, 151, 185, 151, 186, 151, 187, 151, 188, 151, 189, 151, 190, 151, 191, 151, 192, 151, 193, 151, 194, 151, 195, 151, 196, 151, 197, 151, 198, 151, 199, 151, 200, 151, 201, 151, 202, 151, 203, 151, 204, 151, 205, 151, 206, 151, 207, 151, 208, 151, 209, 151, 210, 151, 211, 151, 212, 151, 213, 151, 214, 151, 215, 151, 216, 151, 217, 151, 218, 151, 219, 151, 220, 151, 221, 151, 222, 151, 223, 151, 224, 151, 225, 151, 226, 151, 227, 151, 228, 151, 229, 151, 232, 151, 238, 151, 239, 151, 240, 151, 241, 151, 242, 151, 244, 151, 247, 151, 248, 151, 249, 151, 250, 151, 251, 151, 252, 151, 253, 151, 254, 151, 255, 151, 0, 152, 1, 152, 2, 152, 3, 152, 4, 152, 5, 152, 6, 152, 7, 152, 8, 152, 9, 152, 10, 152, 11, 152, 12, 152, 13, 152, 14, 152, 60, 96, 93, 96, 90, 96, 103, 96, 65, 96, 89, 96, 99, 96, 171, 96, 6, 97, 13, 97, 93, 97, 169, 97, 157, 97, 203, 97, 209, 97, 6, 98, 128, 128, 127, 128, 147, 108, 246, 108, 252, 109, 246, 119, 248, 119, 0, 120, 9, 120, 23, 120, 24, 120, 17, 120, 171, 101, 45, 120, 28, 120, 29, 120, 57, 120, 58, 120, 59, 120, 31, 120, 60, 120, 37, 120, 44, 120, 35, 120, 41, 120, 78, 120, 109, 120, 86, 120, 87, 120, 38, 120, 80, 120, 71, 120, 76, 120, 106, 120, 155, 120, 147, 120, 154, 120, 135, 120, 156, 120, 161, 120, 163, 120, 178, 120, 185, 120, 165, 120, 212, 120, 217, 120, 201, 120, 236, 120, 242, 120, 5, 121, 244, 120, 19, 121, 36, 121, 30, 121, 52, 121, 155, 159, 249, 158, 251, 158, 252, 158, 241, 118, 4, 119, 13, 119, 249, 118, 7, 119, 8, 119, 26, 119, 34, 119, 25, 119, 45, 119, 38, 119, 53, 119, 56, 119, 80, 119, 81, 119, 71, 119, 67, 119, 90, 119, 104, 119, 15, 152, 16, 152, 17, 152, 18, 152, 19, 152, 20, 152, 21, 152, 22, 152, 23, 152, 24, 152, 25, 152, 26, 152, 27, 152, 28, 152, 29, 152, 30, 152, 31, 152, 32, 152, 33, 152, 34, 152, 35, 152, 36, 152, 37, 152, 38, 152, 39, 152, 40, 152, 41, 152, 42, 152, 43, 152, 44, 152, 45, 152, 46, 152, 47, 152, 48, 152, 49, 152, 50, 152, 51, 152, 52, 152, 53, 152, 54, 152, 55, 152, 56, 152, 57, 152, 58, 152, 59, 152, 60, 152, 61, 152, 62, 152, 63, 152, 64, 152, 65, 152, 66, 152, 67, 152, 68, 152, 69, 152, 70, 152, 71, 152, 72, 152, 73, 152, 74, 152, 75, 152, 76, 152, 77, 152, 78, 152, 79, 152, 80, 152, 81, 152, 82, 152, 83, 152, 84, 152, 85, 152, 86, 152, 87, 152, 88, 152, 89, 152, 90, 152, 91, 152, 92, 152, 93, 152, 94, 152, 95, 152, 96, 152, 97, 152, 98, 152, 99, 152, 100, 152, 101, 152, 102, 152, 103, 152, 104, 152, 105, 152, 106, 152, 107, 152, 108, 152, 109, 152, 110, 152, 98, 119, 101, 119, 127, 119, 141, 119, 125, 119, 128, 119, 140, 119, 145, 119, 159, 119, 160, 119, 176, 119, 181, 119, 189, 119, 58, 117, 64, 117, 78, 117, 75, 117, 72, 117, 91, 117, 114, 117, 121, 117, 131, 117, 88, 127, 97, 127, 95, 127, 72, 138, 104, 127, 116, 127, 113, 127, 121, 127, 129, 127, 126, 127, 205, 118, 229, 118, 50, 136, 133, 148, 134, 148, 135, 148, 139, 148, 138, 148, 140, 148, 141, 148, 143, 148, 144, 148, 148, 148, 151, 148, 149, 148, 154, 148, 155, 148, 156, 148, 163, 148, 164, 148, 171, 148, 170, 148, 173, 148, 172, 148, 175, 148, 176, 148, 178, 148, 180, 148, 182, 148, 183, 148, 184, 148, 185, 148, 186, 148, 188, 148, 189, 148, 191, 148, 196, 148, 200, 148, 201, 148, 202, 148, 203, 148, 204, 148, 205, 148, 206, 148, 208, 148, 209, 148, 210, 148, 213, 148, 214, 148, 215, 148, 217, 148, 216, 148, 219, 148, 222, 148, 223, 148, 224, 148, 226, 148, 228, 148, 229, 148, 231, 148, 232, 148, 234, 148, 111, 152, 112, 152, 113, 152, 114, 152, 115, 152, 116, 152, 139, 152, 142, 152, 146, 152, 149, 152, 153, 152, 163, 152, 168, 152, 169, 152, 170, 152, 171, 152, 172, 152, 173, 152, 174, 152, 175, 152, 176, 152, 177, 152, 178, 152, 179, 152, 180, 152, 181, 152, 182, 152, 183, 152, 184, 152, 185, 152, 186, 152, 187, 152, 188, 152, 189, 152, 190, 152, 191, 152, 192, 152, 193, 152, 194, 152, 195, 152, 196, 152, 197, 152, 198, 152, 199, 152, 200, 152, 201, 152, 202, 152, 203, 152, 204, 152, 205, 152, 207, 152, 208, 152, 212, 152, 214, 152, 215, 152, 219, 152, 220, 152, 221, 152, 224, 152, 225, 152, 226, 152, 227, 152, 228, 152, 229, 152, 230, 152, 233, 152, 234, 152, 235, 152, 236, 152, 237, 152, 238, 152, 239, 152, 240, 152, 241, 152, 242, 152, 243, 152, 244, 152, 245, 152, 246, 152, 247, 152, 248, 152, 249, 152, 250, 152, 251, 152, 252, 152, 253, 152, 254, 152, 255, 152, 0, 153, 1, 153, 2, 153, 3, 153, 4, 153, 5, 153, 6, 153, 7, 153, 233, 148, 235, 148, 238, 148, 239, 148, 243, 148, 244, 148, 245, 148, 247, 148, 249, 148, 252, 148, 253, 148, 255, 148, 3, 149, 2, 149, 6, 149, 7, 149, 9, 149, 10, 149, 13, 149, 14, 149, 15, 149, 18, 149, 19, 149, 20, 149, 21, 149, 22, 149, 24, 149, 27, 149, 29, 149, 30, 149, 31, 149, 34, 149, 42, 149, 43, 149, 41, 149, 44, 149, 49, 149, 50, 149, 52, 149, 54, 149, 55, 149, 56, 149, 60, 149, 62, 149, 63, 149, 66, 149, 53, 149, 68, 149, 69, 149, 70, 149, 73, 149, 76, 149, 78, 149, 79, 149, 82, 149, 83, 149, 84, 149, 86, 149, 87, 149, 88, 149, 89, 149, 91, 149, 94, 149, 95, 149, 93, 149, 97, 149, 98, 149, 100, 149, 101, 149, 102, 149, 103, 149, 104, 149, 105, 149, 106, 149, 107, 149, 108, 149, 111, 149, 113, 149, 114, 149, 115, 149, 58, 149, 231, 119, 236, 119, 201, 150, 213, 121, 237, 121, 227, 121, 235, 121, 6, 122, 71, 93, 3, 122, 2, 122, 30, 122, 20, 122, 8, 153, 9, 153, 10, 153, 11, 153, 12, 153, 14, 153, 15, 153, 17, 153, 18, 153, 19, 153, 20, 153, 21, 153, 22, 153, 23, 153, 24, 153, 25, 153, 26, 153, 27, 153, 28, 153, 29, 153, 30, 153, 31, 153, 32, 153, 33, 153, 34, 153, 35, 153, 36, 153, 37, 153, 38, 153, 39, 153, 40, 153, 41, 153, 42, 153, 43, 153, 44, 153, 45, 153, 47, 153, 48, 153, 49, 153, 50, 153, 51, 153, 52, 153, 53, 153, 54, 153, 55, 153, 56, 153, 57, 153, 58, 153, 59, 153, 60, 153, 61, 153, 62, 153, 63, 153, 64, 153, 65, 153, 66, 153, 67, 153, 68, 153, 69, 153, 70, 153, 71, 153, 72, 153, 73, 153, 74, 153, 75, 153, 76, 153, 77, 153, 78, 153, 79, 153, 80, 153, 81, 153, 82, 153, 83, 153, 86, 153, 87, 153, 88, 153, 89, 153, 90, 153, 91, 153, 92, 153, 93, 153, 94, 153, 95, 153, 96, 153, 97, 153, 98, 153, 100, 153, 102, 153, 115, 153, 120, 153, 121, 153, 123, 153, 126, 153, 130, 153, 131, 153, 137, 153, 57, 122, 55, 122, 81, 122, 207, 158, 165, 153, 112, 122, 136, 118, 142, 118, 147, 118, 153, 118, 164, 118, 222, 116, 224, 116, 44, 117, 32, 158, 34, 158, 40, 158, 41, 158, 42, 158, 43, 158, 44, 158, 50, 158, 49, 158, 54, 158, 56, 158, 55, 158, 57, 158, 58, 158, 62, 158, 65, 158, 66, 158, 68, 158, 70, 158, 71, 158, 72, 158, 73, 158, 75, 158, 76, 158, 78, 158, 81, 158, 85, 158, 87, 158, 90, 158, 91, 158, 92, 158, 94, 158, 99, 158, 102, 158, 103, 158, 104, 158, 105, 158, 106, 158, 107, 158, 108, 158, 113, 158, 109, 158, 115, 158, 146, 117, 148, 117, 150, 117, 160, 117, 157, 117, 172, 117, 163, 117, 179, 117, 180, 117, 184, 117, 196, 117, 177, 117, 176, 117, 195, 117, 194, 117, 214, 117, 205, 117, 227, 117, 232, 117, 230, 117, 228, 117, 235, 117, 231, 117, 3, 118, 241, 117, 252, 117, 255, 117, 16, 118, 0, 118, 5, 118, 12, 118, 23, 118, 10, 118, 37, 118, 24, 118, 21, 118, 25, 118, 140, 153, 142, 153, 154, 153, 155, 153, 156, 153, 157, 153, 158, 153, 159, 153, 160, 153, 161, 153, 162, 153, 163, 153, 164, 153, 166, 153, 167, 153, 169, 153, 170, 153, 171, 153, 172, 153, 173, 153, 174, 153, 175, 153, 176, 153, 177, 153, 178, 153, 179, 153, 180, 153, 181, 153, 182, 153, 183, 153, 184, 153, 185, 153, 186, 153, 187, 153, 188, 153, 189, 153, 190, 153, 191, 153, 192, 153, 193, 153, 194, 153, 195, 153, 196, 153, 197, 153, 198, 153, 199, 153, 200, 153, 201, 153, 202, 153, 203, 153, 204, 153, 205, 153, 206, 153, 207, 153, 208, 153, 209, 153, 210, 153, 211, 153, 212, 153, 213, 153, 214, 153, 215, 153, 216, 153, 217, 153, 218, 153, 219, 153, 220, 153, 221, 153, 222, 153, 223, 153, 224, 153, 225, 153, 226, 153, 227, 153, 228, 153, 229, 153, 230, 153, 231, 153, 232, 153, 233, 153, 234, 153, 235, 153, 236, 153, 237, 153, 238, 153, 239, 153, 240, 153, 241, 153, 242, 153, 243, 153, 244, 153, 245, 153, 246, 153, 247, 153, 248, 153, 249, 153, 27, 118, 60, 118, 34, 118, 32, 118, 64, 118, 45, 118, 48, 118, 63, 118, 53, 118, 67, 118, 62, 118, 51, 118, 77, 118, 94, 118, 84, 118, 92, 118, 86, 118, 107, 118, 111, 118, 202, 127, 230, 122, 120, 122, 121, 122, 128, 122, 134, 122, 136, 122, 149, 122, 166, 122, 160, 122, 172, 122, 168, 122, 173, 122, 179, 122, 100, 136, 105, 136, 114, 136, 125, 136, 127, 136, 130, 136, 162, 136, 198, 136, 183, 136, 188, 136, 201, 136, 226, 136, 206, 136, 227, 136, 229, 136, 241, 136, 26, 137, 252, 136, 232, 136, 254, 136, 240, 136, 33, 137, 25, 137, 19, 137, 27, 137, 10, 137, 52, 137, 43, 137, 54, 137, 65, 137, 102, 137, 123, 137, 139, 117, 229, 128, 178, 118, 180, 118, 220, 119, 18, 128, 20, 128, 22, 128, 28, 128, 32, 128, 34, 128, 37, 128, 38, 128, 39, 128, 41, 128, 40, 128, 49, 128, 11, 128, 53, 128, 67, 128, 70, 128, 77, 128, 82, 128, 105, 128, 113, 128, 131, 137, 120, 152, 128, 152, 131, 152, 250, 153, 251, 153, 252, 153, 253, 153, 254, 153, 255, 153, 0, 154, 1, 154, 2, 154, 3, 154, 4, 154, 5, 154, 6, 154, 7, 154, 8, 154, 9, 154, 10, 154, 11, 154, 12, 154, 13, 154, 14, 154, 15, 154, 16, 154, 17, 154, 18, 154, 19, 154, 20, 154, 21, 154, 22, 154, 23, 154, 24, 154, 25, 154, 26, 154, 27, 154, 28, 154, 29, 154, 30, 154, 31, 154, 32, 154, 33, 154, 34, 154, 35, 154, 36, 154, 37, 154, 38, 154, 39, 154, 40, 154, 41, 154, 42, 154, 43, 154, 44, 154, 45, 154, 46, 154, 47, 154, 48, 154, 49, 154, 50, 154, 51, 154, 52, 154, 53, 154, 54, 154, 55, 154, 56, 154, 57, 154, 58, 154, 59, 154, 60, 154, 61, 154, 62, 154, 63, 154, 64, 154, 65, 154, 66, 154, 67, 154, 68, 154, 69, 154, 70, 154, 71, 154, 72, 154, 73, 154, 74, 154, 75, 154, 76, 154, 77, 154, 78, 154, 79, 154, 80, 154, 81, 154, 82, 154, 83, 154, 84, 154, 85, 154, 86, 154, 87, 154, 88, 154, 89, 154, 137, 152, 140, 152, 141, 152, 143, 152, 148, 152, 154, 152, 155, 152, 158, 152, 159, 152, 161, 152, 162, 152, 165, 152, 166, 152, 77, 134, 84, 134, 108, 134, 110, 134, 127, 134, 122, 134, 124, 134, 123, 134, 168, 134, 141, 134, 139, 134, 172, 134, 157, 134, 167, 134, 163, 134, 170, 134, 147, 134, 169, 134, 182, 134, 196, 134, 181, 134, 206, 134, 176, 134, 186, 134, 177, 134, 175, 134, 201, 134, 207, 134, 180, 134, 233, 134, 241, 134, 242, 134, 237, 134, 243, 134, 208, 134, 19, 135, 222, 134, 244, 134, 223, 134, 216, 134, 209, 134, 3, 135, 7, 135, 248, 134, 8, 135, 10, 135, 13, 135, 9, 135, 35, 135, 59, 135, 30, 135, 37, 135, 46, 135, 26, 135, 62, 135, 72, 135, 52, 135, 49, 135, 41, 135, 55, 135, 63, 135, 130, 135, 34, 135, 125, 135, 126, 135, 123, 135, 96, 135, 112, 135, 76, 135, 110, 135, 139, 135, 83, 135, 99, 135, 124, 135, 100, 135, 89, 135, 101, 135, 147, 135, 175, 135, 168, 135, 210, 135, 90, 154, 91, 154, 92, 154, 93, 154, 94, 154, 95, 154, 96, 154, 97, 154, 98, 154, 99, 154, 100, 154, 101, 154, 102, 154, 103, 154, 104, 154, 105, 154, 106, 154, 107, 154, 114, 154, 131, 154, 137, 154, 141, 154, 142, 154, 148, 154, 149, 154, 153, 154, 166, 154, 169, 154, 170, 154, 171, 154, 172, 154, 173, 154, 174, 154, 175, 154, 178, 154, 179, 154, 180, 154, 181, 154, 185, 154, 187, 154, 189, 154, 190, 154, 191, 154, 195, 154, 196, 154, 198, 154, 199, 154, 200, 154, 201, 154, 202, 154, 205, 154, 206, 154, 207, 154, 208, 154, 210, 154, 212, 154, 213, 154, 214, 154, 215, 154, 217, 154, 218, 154, 219, 154, 220, 154, 221, 154, 222, 154, 224, 154, 226, 154, 227, 154, 228, 154, 229, 154, 231, 154, 232, 154, 233, 154, 234, 154, 236, 154, 238, 154, 240, 154, 241, 154, 242, 154, 243, 154, 244, 154, 245, 154, 246, 154, 247, 154, 248, 154, 250, 154, 252, 154, 253, 154, 254, 154, 255, 154, 0, 155, 1, 155, 2, 155, 4, 155, 5, 155, 6, 155, 198, 135, 136, 135, 133, 135, 173, 135, 151, 135, 131, 135, 171, 135, 229, 135, 172, 135, 181, 135, 179, 135, 203, 135, 211, 135, 189, 135, 209, 135, 192, 135, 202, 135, 219, 135, 234, 135, 224, 135, 238, 135, 22, 136, 19, 136, 254, 135, 10, 136, 27, 136, 33, 136, 57, 136, 60, 136, 54, 127, 66, 127, 68, 127, 69, 127, 16, 130, 250, 122, 253, 122, 8, 123, 3, 123, 4, 123, 21, 123, 10, 123, 43, 123, 15, 123, 71, 123, 56, 123, 42, 123, 25, 123, 46, 123, 49, 123, 32, 123, 37, 123, 36, 123, 51, 123, 62, 123, 30, 123, 88, 123, 90, 123, 69, 123, 117, 123, 76, 123, 93, 123, 96, 123, 110, 123, 123, 123, 98, 123, 114, 123, 113, 123, 144, 123, 166, 123, 167, 123, 184, 123, 172, 123, 157, 123, 168, 123, 133, 123, 170, 123, 156, 123, 162, 123, 171, 123, 180, 123, 209, 123, 193, 123, 204, 123, 221, 123, 218, 123, 229, 123, 230, 123, 234, 123, 12, 124, 254, 123, 252, 123, 15, 124, 22, 124, 11, 124, 7, 155, 9, 155, 10, 155, 11, 155, 12, 155, 13, 155, 14, 155, 16, 155, 17, 155, 18, 155, 20, 155, 21, 155, 22, 155, 23, 155, 24, 155, 25, 155, 26, 155, 27, 155, 28, 155, 29, 155, 30, 155, 32, 155, 33, 155, 34, 155, 36, 155, 37, 155, 38, 155, 39, 155, 40, 155, 41, 155, 42, 155, 43, 155, 44, 155, 45, 155, 46, 155, 48, 155, 49, 155, 51, 155, 52, 155, 53, 155, 54, 155, 55, 155, 56, 155, 57, 155, 58, 155, 61, 155, 62, 155, 63, 155, 64, 155, 70, 155, 74, 155, 75, 155, 76, 155, 78, 155, 80, 155, 82, 155, 83, 155, 85, 155, 86, 155, 87, 155, 88, 155, 89, 155, 90, 155, 91, 155, 92, 155, 93, 155, 94, 155, 95, 155, 96, 155, 97, 155, 98, 155, 99, 155, 100, 155, 101, 155, 102, 155, 103, 155, 104, 155, 105, 155, 106, 155, 107, 155, 108, 155, 109, 155, 110, 155, 111, 155, 112, 155, 113, 155, 114, 155, 115, 155, 116, 155, 117, 155, 118, 155, 119, 155, 120, 155, 121, 155, 122, 155, 123, 155, 31, 124, 42, 124, 38, 124, 56, 124, 65, 124, 64, 124, 254, 129, 1, 130, 2, 130, 4, 130, 236, 129, 68, 136, 33, 130, 34, 130, 35, 130, 45, 130, 47, 130, 40, 130, 43, 130, 56, 130, 59, 130, 51, 130, 52, 130, 62, 130, 68, 130, 73, 130, 75, 130, 79, 130, 90, 130, 95, 130, 104, 130, 126, 136, 133, 136, 136, 136, 216, 136, 223, 136, 94, 137, 157, 127, 159, 127, 167, 127, 175, 127, 176, 127, 178, 127, 124, 124, 73, 101, 145, 124, 157, 124, 156, 124, 158, 124, 162, 124, 178, 124, 188, 124, 189, 124, 193, 124, 199, 124, 204, 124, 205, 124, 200, 124, 197, 124, 215, 124, 232, 124, 110, 130, 168, 102, 191, 127, 206, 127, 213, 127, 229, 127, 225, 127, 230, 127, 233, 127, 238, 127, 243, 127, 248, 124, 119, 125, 166, 125, 174, 125, 71, 126, 155, 126, 184, 158, 180, 158, 115, 141, 132, 141, 148, 141, 145, 141, 177, 141, 103, 141, 109, 141, 71, 140, 73, 140, 74, 145, 80, 145, 78, 145, 79, 145, 100, 145, 124, 155, 125, 155, 126, 155, 127, 155, 128, 155, 129, 155, 130, 155, 131, 155, 132, 155, 133, 155, 134, 155, 135, 155, 136, 155, 137, 155, 138, 155, 139, 155, 140, 155, 141, 155, 142, 155, 143, 155, 144, 155, 145, 155, 146, 155, 147, 155, 148, 155, 149, 155, 150, 155, 151, 155, 152, 155, 153, 155, 154, 155, 155, 155, 156, 155, 157, 155, 158, 155, 159, 155, 160, 155, 161, 155, 162, 155, 163, 155, 164, 155, 165, 155, 166, 155, 167, 155, 168, 155, 169, 155, 170, 155, 171, 155, 172, 155, 173, 155, 174, 155, 175, 155, 176, 155, 177, 155, 178, 155, 179, 155, 180, 155, 181, 155, 182, 155, 183, 155, 184, 155, 185, 155, 186, 155, 187, 155, 188, 155, 189, 155, 190, 155, 191, 155, 192, 155, 193, 155, 194, 155, 195, 155, 196, 155, 197, 155, 198, 155, 199, 155, 200, 155, 201, 155, 202, 155, 203, 155, 204, 155, 205, 155, 206, 155, 207, 155, 208, 155, 209, 155, 210, 155, 211, 155, 212, 155, 213, 155, 214, 155, 215, 155, 216, 155, 217, 155, 218, 155, 219, 155, 98, 145, 97, 145, 112, 145, 105, 145, 111, 145, 125, 145, 126, 145, 114, 145, 116, 145, 121, 145, 140, 145, 133, 145, 144, 145, 141, 145, 145, 145, 162, 145, 163, 145, 170, 145, 173, 145, 174, 145, 175, 145, 181, 145, 180, 145, 186, 145, 85, 140, 126, 158, 184, 141, 235, 141, 5, 142, 89, 142, 105, 142, 181, 141, 191, 141, 188, 141, 186, 141, 196, 141, 214, 141, 215, 141, 218, 141, 222, 141, 206, 141, 207, 141, 219, 141, 198, 141, 236, 141, 247, 141, 248, 141, 227, 141, 249, 141, 251, 141, 228, 141, 9, 142, 253, 141, 20, 142, 29, 142, 31, 142, 44, 142, 46, 142, 35, 142, 47, 142, 58, 142, 64, 142, 57, 142, 53, 142, 61, 142, 49, 142, 73, 142, 65, 142, 66, 142, 81, 142, 82, 142, 74, 142, 112, 142, 118, 142, 124, 142, 111, 142, 116, 142, 133, 142, 143, 142, 148, 142, 144, 142, 156, 142, 158, 142, 120, 140, 130, 140, 138, 140, 133, 140, 152, 140, 148, 140, 155, 101, 214, 137, 222, 137, 218, 137, 220, 137, 220, 155, 221, 155, 222, 155, 223, 155, 224, 155, 225, 155, 226, 155, 227, 155, 228, 155, 229, 155, 230, 155, 231, 155, 232, 155, 233, 155, 234, 155, 235, 155, 236, 155, 237, 155, 238, 155, 239, 155, 240, 155, 241, 155, 242, 155, 243, 155, 244, 155, 245, 155, 246, 155, 247, 155, 248, 155, 249, 155, 250, 155, 251, 155, 252, 155, 253, 155, 254, 155, 255, 155, 0, 156, 1, 156, 2, 156, 3, 156, 4, 156, 5, 156, 6, 156, 7, 156, 8, 156, 9, 156, 10, 156, 11, 156, 12, 156, 13, 156, 14, 156, 15, 156, 16, 156, 17, 156, 18, 156, 19, 156, 20, 156, 21, 156, 22, 156, 23, 156, 24, 156, 25, 156, 26, 156, 27, 156, 28, 156, 29, 156, 30, 156, 31, 156, 32, 156, 33, 156, 34, 156, 35, 156, 36, 156, 37, 156, 38, 156, 39, 156, 40, 156, 41, 156, 42, 156, 43, 156, 44, 156, 45, 156, 46, 156, 47, 156, 48, 156, 49, 156, 50, 156, 51, 156, 52, 156, 53, 156, 54, 156, 55, 156, 56, 156, 57, 156, 58, 156, 59, 156, 229, 137, 235, 137, 239, 137, 62, 138, 38, 139, 83, 151, 233, 150, 243, 150, 239, 150, 6, 151, 1, 151, 8, 151, 15, 151, 14, 151, 42, 151, 45, 151, 48, 151, 62, 151, 128, 159, 131, 159, 133, 159, 134, 159, 135, 159, 136, 159, 137, 159, 138, 159, 140, 159, 254, 158, 11, 159, 13, 159, 185, 150, 188, 150, 189, 150, 206, 150, 210, 150, 191, 119, 224, 150, 142, 146, 174, 146, 200, 146, 62, 147, 106, 147, 202, 147, 143, 147, 62, 148, 107, 148, 127, 156, 130, 156, 133, 156, 134, 156, 135, 156, 136, 156, 35, 122, 139, 156, 142, 156, 144, 156, 145, 156, 146, 156, 148, 156, 149, 156, 154, 156, 155, 156, 158, 156, 159, 156, 160, 156, 161, 156, 162, 156, 163, 156, 165, 156, 166, 156, 167, 156, 168, 156, 169, 156, 171, 156, 173, 156, 174, 156, 176, 156, 177, 156, 178, 156, 179, 156, 180, 156, 181, 156, 182, 156, 183, 156, 186, 156, 187, 156, 188, 156, 189, 156, 196, 156, 197, 156, 198, 156, 199, 156, 202, 156, 203, 156, 60, 156, 61, 156, 62, 156, 63, 156, 64, 156, 65, 156, 66, 156, 67, 156, 68, 156, 69, 156, 70, 156, 71, 156, 72, 156, 73, 156, 74, 156, 75, 156, 76, 156, 77, 156, 78, 156, 79, 156, 80, 156, 81, 156, 82, 156, 83, 156, 84, 156, 85, 156, 86, 156, 87, 156, 88, 156, 89, 156, 90, 156, 91, 156, 92, 156, 93, 156, 94, 156, 95, 156, 96, 156, 97, 156, 98, 156, 99, 156, 100, 156, 101, 156, 102, 156, 103, 156, 104, 156, 105, 156, 106, 156, 107, 156, 108, 156, 109, 156, 110, 156, 111, 156, 112, 156, 113, 156, 114, 156, 115, 156, 116, 156, 117, 156, 118, 156, 119, 156, 120, 156, 121, 156, 122, 156, 123, 156, 125, 156, 126, 156, 128, 156, 131, 156, 132, 156, 137, 156, 138, 156, 140, 156, 143, 156, 147, 156, 150, 156, 151, 156, 152, 156, 153, 156, 157, 156, 170, 156, 172, 156, 175, 156, 185, 156, 190, 156, 191, 156, 192, 156, 193, 156, 194, 156, 200, 156, 201, 156, 209, 156, 210, 156, 218, 156, 219, 156, 224, 156, 225, 156, 204, 156, 205, 156, 206, 156, 207, 156, 208, 156, 211, 156, 212, 156, 213, 156, 215, 156, 216, 156, 217, 156, 220, 156, 221, 156, 223, 156, 226, 156, 124, 151, 133, 151, 145, 151, 146, 151, 148, 151, 175, 151, 171, 151, 163, 151, 178, 151, 180, 151, 177, 154, 176, 154, 183, 154, 88, 158, 182, 154, 186, 154, 188, 154, 193, 154, 192, 154, 197, 154, 194, 154, 203, 154, 204, 154, 209, 154, 69, 155, 67, 155, 71, 155, 73, 155, 72, 155, 77, 155, 81, 155, 232, 152, 13, 153, 46, 153, 85, 153, 84, 153, 223, 154, 225, 154, 230, 154, 239, 154, 235, 154, 251, 154, 237, 154, 249, 154, 8, 155, 15, 155, 19, 155, 31, 155, 35, 155, 189, 158, 190, 158, 59, 126, 130, 158, 135, 158, 136, 158, 139, 158, 146, 158, 214, 147, 157, 158, 159, 158, 219, 158, 220, 158, 221, 158, 224, 158, 223, 158, 226, 158, 233, 158, 231, 158, 229, 158, 234, 158, 239, 158, 34, 159, 44, 159, 47, 159, 57, 159, 55, 159, 61, 159, 62, 159, 68, 159, 227, 156, 228, 156, 229, 156, 230, 156, 231, 156, 232, 156, 233, 156, 234, 156, 235, 156, 236, 156, 237, 156, 238, 156, 239, 156, 240, 156, 241, 156, 242, 156, 243, 156, 244, 156, 245, 156, 246, 156, 247, 156, 248, 156, 249, 156, 250, 156, 251, 156, 252, 156, 253, 156, 254, 156, 255, 156, 0, 157, 1, 157, 2, 157, 3, 157, 4, 157, 5, 157, 6, 157, 7, 157, 8, 157, 9, 157, 10, 157, 11, 157, 12, 157, 13, 157, 14, 157, 15, 157, 16, 157, 17, 157, 18, 157, 19, 157, 20, 157, 21, 157, 22, 157, 23, 157, 24, 157, 25, 157, 26, 157, 27, 157, 28, 157, 29, 157, 30, 157, 31, 157, 32, 157, 33, 157, 34, 157, 35, 157, 36, 157, 37, 157, 38, 157, 39, 157, 40, 157, 41, 157, 42, 157, 43, 157, 44, 157, 45, 157, 46, 157, 47, 157, 48, 157, 49, 157, 50, 157, 51, 157, 52, 157, 53, 157, 54, 157, 55, 157, 56, 157, 57, 157, 58, 157, 59, 157, 60, 157, 61, 157, 62, 157, 63, 157, 64, 157, 65, 157, 66, 157, 52, 226, 53, 226, 54, 226, 55, 226, 56, 226, 57, 226, 58, 226, 59, 226, 60, 226, 61, 226, 62, 226, 63, 226, 64, 226, 65, 226, 66, 226, 67, 226, 68, 226, 69, 226, 70, 226, 71, 226, 72, 226, 73, 226, 74, 226, 75, 226, 76, 226, 77, 226, 78, 226, 79, 226, 80, 226, 81, 226, 82, 226, 83, 226, 84, 226, 85, 226, 86, 226, 87, 226, 88, 226, 89, 226, 90, 226, 91, 226, 92, 226, 93, 226, 94, 226, 95, 226, 96, 226, 97, 226, 98, 226, 99, 226, 100, 226, 101, 226, 102, 226, 103, 226, 104, 226, 105, 226, 106, 226, 107, 226, 108, 226, 109, 226, 110, 226, 111, 226, 112, 226, 113, 226, 114, 226, 115, 226, 116, 226, 117, 226, 118, 226, 119, 226, 120, 226, 121, 226, 122, 226, 123, 226, 124, 226, 125, 226, 126, 226, 127, 226, 128, 226, 129, 226, 130, 226, 131, 226, 132, 226, 133, 226, 134, 226, 135, 226, 136, 226, 137, 226, 138, 226, 139, 226, 140, 226, 141, 226, 142, 226, 143, 226, 144, 226, 145, 226, 67, 157, 68, 157, 69, 157, 70, 157, 71, 157, 72, 157, 73, 157, 74, 157, 75, 157, 76, 157, 77, 157, 78, 157, 79, 157, 80, 157, 81, 157, 82, 157, 83, 157, 84, 157, 85, 157, 86, 157, 87, 157, 88, 157, 89, 157, 90, 157, 91, 157, 92, 157, 93, 157, 94, 157, 95, 157, 96, 157, 97, 157, 98, 157, 99, 157, 100, 157, 101, 157, 102, 157, 103, 157, 104, 157, 105, 157, 106, 157, 107, 157, 108, 157, 109, 157, 110, 157, 111, 157, 112, 157, 113, 157, 114, 157, 115, 157, 116, 157, 117, 157, 118, 157, 119, 157, 120, 157, 121, 157, 122, 157, 123, 157, 124, 157, 125, 157, 126, 157, 127, 157, 128, 157, 129, 157, 130, 157, 131, 157, 132, 157, 133, 157, 134, 157, 135, 157, 136, 157, 137, 157, 138, 157, 139, 157, 140, 157, 141, 157, 142, 157, 143, 157, 144, 157, 145, 157, 146, 157, 147, 157, 148, 157, 149, 157, 150, 157, 151, 157, 152, 157, 153, 157, 154, 157, 155, 157, 156, 157, 157, 157, 158, 157, 159, 157, 160, 157, 161, 157, 162, 157, 146, 226, 147, 226, 148, 226, 149, 226, 150, 226, 151, 226, 152, 226, 153, 226, 154, 226, 155, 226, 156, 226, 157, 226, 158, 226, 159, 226, 160, 226, 161, 226, 162, 226, 163, 226, 164, 226, 165, 226, 166, 226, 167, 226, 168, 226, 169, 226, 170, 226, 171, 226, 172, 226, 173, 226, 174, 226, 175, 226, 176, 226, 177, 226, 178, 226, 179, 226, 180, 226, 181, 226, 182, 226, 183, 226, 184, 226, 185, 226, 186, 226, 187, 226, 188, 226, 189, 226, 190, 226, 191, 226, 192, 226, 193, 226, 194, 226, 195, 226, 196, 226, 197, 226, 198, 226, 199, 226, 200, 226, 201, 226, 202, 226, 203, 226, 204, 226, 205, 226, 206, 226, 207, 226, 208, 226, 209, 226, 210, 226, 211, 226, 212, 226, 213, 226, 214, 226, 215, 226, 216, 226, 217, 226, 218, 226, 219, 226, 220, 226, 221, 226, 222, 226, 223, 226, 224, 226, 225, 226, 226, 226, 227, 226, 228, 226, 229, 226, 230, 226, 231, 226, 232, 226, 233, 226, 234, 226, 235, 226, 236, 226, 237, 226, 238, 226, 239, 226, 163, 157, 164, 157, 165, 157, 166, 157, 167, 157, 168, 157, 169, 157, 170, 157, 171, 157, 172, 157, 173, 157, 174, 157, 175, 157, 176, 157, 177, 157, 178, 157, 179, 157, 180, 157, 181, 157, 182, 157, 183, 157, 184, 157, 185, 157, 186, 157, 187, 157, 188, 157, 189, 157, 190, 157, 191, 157, 192, 157, 193, 157, 194, 157, 195, 157, 196, 157, 197, 157, 198, 157, 199, 157, 200, 157, 201, 157, 202, 157, 203, 157, 204, 157, 205, 157, 206, 157, 207, 157, 208, 157, 209, 157, 210, 157, 211, 157, 212, 157, 213, 157, 214, 157, 215, 157, 216, 157, 217, 157, 218, 157, 219, 157, 220, 157, 221, 157, 222, 157, 223, 157, 224, 157, 225, 157, 226, 157, 227, 157, 228, 157, 229, 157, 230, 157, 231, 157, 232, 157, 233, 157, 234, 157, 235, 157, 236, 157, 237, 157, 238, 157, 239, 157, 240, 157, 241, 157, 242, 157, 243, 157, 244, 157, 245, 157, 246, 157, 247, 157, 248, 157, 249, 157, 250, 157, 251, 157, 252, 157, 253, 157, 254, 157, 255, 157, 0, 158, 1, 158, 2, 158, 240, 226, 241, 226, 242, 226, 243, 226, 244, 226, 245, 226, 246, 226, 247, 226, 248, 226, 249, 226, 250, 226, 251, 226, 252, 226, 253, 226, 254, 226, 255, 226, 0, 227, 1, 227, 2, 227, 3, 227, 4, 227, 5, 227, 6, 227, 7, 227, 8, 227, 9, 227, 10, 227, 11, 227, 12, 227, 13, 227, 14, 227, 15, 227, 16, 227, 17, 227, 18, 227, 19, 227, 20, 227, 21, 227, 22, 227, 23, 227, 24, 227, 25, 227, 26, 227, 27, 227, 28, 227, 29, 227, 30, 227, 31, 227, 32, 227, 33, 227, 34, 227, 35, 227, 36, 227, 37, 227, 38, 227, 39, 227, 40, 227, 41, 227, 42, 227, 43, 227, 44, 227, 45, 227, 46, 227, 47, 227, 48, 227, 49, 227, 50, 227, 51, 227, 52, 227, 53, 227, 54, 227, 55, 227, 56, 227, 57, 227, 58, 227, 59, 227, 60, 227, 61, 227, 62, 227, 63, 227, 64, 227, 65, 227, 66, 227, 67, 227, 68, 227, 69, 227, 70, 227, 71, 227, 72, 227, 73, 227, 74, 227, 75, 227, 76, 227, 77, 227, 3, 158, 4, 158, 5, 158, 6, 158, 7, 158, 8, 158, 9, 158, 10, 158, 11, 158, 12, 158, 13, 158, 14, 158, 15, 158, 16, 158, 17, 158, 18, 158, 19, 158, 20, 158, 21, 158, 22, 158, 23, 158, 24, 158, 25, 158, 26, 158, 27, 158, 28, 158, 29, 158, 30, 158, 36, 158, 39, 158, 46, 158, 48, 158, 52, 158, 59, 158, 60, 158, 64, 158, 77, 158, 80, 158, 82, 158, 83, 158, 84, 158, 86, 158, 89, 158, 93, 158, 95, 158, 96, 158, 97, 158, 98, 158, 101, 158, 110, 158, 111, 158, 114, 158, 116, 158, 117, 158, 118, 158, 119, 158, 120, 158, 121, 158, 122, 158, 123, 158, 124, 158, 125, 158, 128, 158, 129, 158, 131, 158, 132, 158, 133, 158, 134, 158, 137, 158, 138, 158, 140, 158, 141, 158, 142, 158, 143, 158, 144, 158, 145, 158, 148, 158, 149, 158, 150, 158, 151, 158, 152, 158, 153, 158, 154, 158, 155, 158, 156, 158, 158, 158, 160, 158, 161, 158, 162, 158, 163, 158, 164, 158, 165, 158, 167, 158, 168, 158, 169, 158, 170, 158, 78, 227, 79, 227, 80, 227, 81, 227, 82, 227, 83, 227, 84, 227, 85, 227, 86, 227, 87, 227, 88, 227, 89, 227, 90, 227, 91, 227, 92, 227, 93, 227, 94, 227, 95, 227, 96, 227, 97, 227, 98, 227, 99, 227, 100, 227, 101, 227, 102, 227, 103, 227, 104, 227, 105, 227, 106, 227, 107, 227, 108, 227, 109, 227, 110, 227, 111, 227, 112, 227, 113, 227, 114, 227, 115, 227, 116, 227, 117, 227, 118, 227, 119, 227, 120, 227, 121, 227, 122, 227, 123, 227, 124, 227, 125, 227, 126, 227, 127, 227, 128, 227, 129, 227, 130, 227, 131, 227, 132, 227, 133, 227, 134, 227, 135, 227, 136, 227, 137, 227, 138, 227, 139, 227, 140, 227, 141, 227, 142, 227, 143, 227, 144, 227, 145, 227, 146, 227, 147, 227, 148, 227, 149, 227, 150, 227, 151, 227, 152, 227, 153, 227, 154, 227, 155, 227, 156, 227, 157, 227, 158, 227, 159, 227, 160, 227, 161, 227, 162, 227, 163, 227, 164, 227, 165, 227, 166, 227, 167, 227, 168, 227, 169, 227, 170, 227, 171, 227, 171, 158, 172, 158, 173, 158, 174, 158, 175, 158, 176, 158, 177, 158, 178, 158, 179, 158, 181, 158, 182, 158, 183, 158, 185, 158, 186, 158, 188, 158, 191, 158, 192, 158, 193, 158, 194, 158, 195, 158, 197, 158, 198, 158, 199, 158, 200, 158, 202, 158, 203, 158, 204, 158, 208, 158, 210, 158, 211, 158, 213, 158, 214, 158, 215, 158, 217, 158, 218, 158, 222, 158, 225, 158, 227, 158, 228, 158, 230, 158, 232, 158, 235, 158, 236, 158, 237, 158, 238, 158, 240, 158, 241, 158, 242, 158, 243, 158, 244, 158, 245, 158, 246, 158, 247, 158, 248, 158, 250, 158, 253, 158, 255, 158, 0, 159, 1, 159, 2, 159, 3, 159, 4, 159, 5, 159, 6, 159, 7, 159, 8, 159, 9, 159, 10, 159, 12, 159, 15, 159, 17, 159, 18, 159, 20, 159, 21, 159, 22, 159, 24, 159, 26, 159, 27, 159, 28, 159, 29, 159, 30, 159, 31, 159, 33, 159, 35, 159, 36, 159, 37, 159, 38, 159, 39, 159, 40, 159, 41, 159, 42, 159, 43, 159, 45, 159, 46, 159, 48, 159, 49, 159, 172, 227, 173, 227, 174, 227, 175, 227, 176, 227, 177, 227, 178, 227, 179, 227, 180, 227, 181, 227, 182, 227, 183, 227, 184, 227, 185, 227, 186, 227, 187, 227, 188, 227, 189, 227, 190, 227, 191, 227, 192, 227, 193, 227, 194, 227, 195, 227, 196, 227, 197, 227, 198, 227, 199, 227, 200, 227, 201, 227, 202, 227, 203, 227, 204, 227, 205, 227, 206, 227, 207, 227, 208, 227, 209, 227, 210, 227, 211, 227, 212, 227, 213, 227, 214, 227, 215, 227, 216, 227, 217, 227, 218, 227, 219, 227, 220, 227, 221, 227, 222, 227, 223, 227, 224, 227, 225, 227, 226, 227, 227, 227, 228, 227, 229, 227, 230, 227, 231, 227, 232, 227, 233, 227, 234, 227, 235, 227, 236, 227, 237, 227, 238, 227, 239, 227, 240, 227, 241, 227, 242, 227, 243, 227, 244, 227, 245, 227, 246, 227, 247, 227, 248, 227, 249, 227, 250, 227, 251, 227, 252, 227, 253, 227, 254, 227, 255, 227, 0, 228, 1, 228, 2, 228, 3, 228, 4, 228, 5, 228, 6, 228, 7, 228, 8, 228, 9, 228, 50, 159, 51, 159, 52, 159, 53, 159, 54, 159, 56, 159, 58, 159, 60, 159, 63, 159, 64, 159, 65, 159, 66, 159, 67, 159, 69, 159, 70, 159, 71, 159, 72, 159, 73, 159, 74, 159, 75, 159, 76, 159, 77, 159, 78, 159, 79, 159, 82, 159, 83, 159, 84, 159, 85, 159, 86, 159, 87, 159, 88, 159, 89, 159, 90, 159, 91, 159, 92, 159, 93, 159, 94, 159, 95, 159, 96, 159, 97, 159, 98, 159, 99, 159, 100, 159, 101, 159, 102, 159, 103, 159, 104, 159, 105, 159, 106, 159, 107, 159, 108, 159, 109, 159, 110, 159, 111, 159, 112, 159, 113, 159, 114, 159, 115, 159, 116, 159, 117, 159, 118, 159, 119, 159, 120, 159, 121, 159, 122, 159, 123, 159, 124, 159, 125, 159, 126, 159, 129, 159, 130, 159, 141, 159, 142, 159, 143, 159, 144, 159, 145, 159, 146, 159, 147, 159, 148, 159, 149, 159, 150, 159, 151, 159, 152, 159, 156, 159, 157, 159, 158, 159, 161, 159, 162, 159, 163, 159, 164, 159, 165, 159, 44, 249, 121, 249, 149, 249, 231, 249, 241, 249, 10, 228, 11, 228, 12, 228, 13, 228, 14, 228, 15, 228, 16, 228, 17, 228, 18, 228, 19, 228, 20, 228, 21, 228, 22, 228, 23, 228, 24, 228, 25, 228, 26, 228, 27, 228, 28, 228, 29, 228, 30, 228, 31, 228, 32, 228, 33, 228, 34, 228, 35, 228, 36, 228, 37, 228, 38, 228, 39, 228, 40, 228, 41, 228, 42, 228, 43, 228, 44, 228, 45, 228, 46, 228, 47, 228, 48, 228, 49, 228, 50, 228, 51, 228, 52, 228, 53, 228, 54, 228, 55, 228, 56, 228, 57, 228, 58, 228, 59, 228, 60, 228, 61, 228, 62, 228, 63, 228, 64, 228, 65, 228, 66, 228, 67, 228, 68, 228, 69, 228, 70, 228, 71, 228, 72, 228, 73, 228, 74, 228, 75, 228, 76, 228, 77, 228, 78, 228, 79, 228, 80, 228, 81, 228, 82, 228, 83, 228, 84, 228, 85, 228, 86, 228, 87, 228, 88, 228, 89, 228, 90, 228, 91, 228, 92, 228, 93, 228, 94, 228, 95, 228, 96, 228, 97, 228, 98, 228, 99, 228, 100, 228, 101, 228, 102, 228, 103, 228, 12, 250, 13, 250, 14, 250, 15, 250, 17, 250, 19, 250, 20, 250, 24, 250, 31, 250, 32, 250, 33, 250, 35, 250, 36, 250, 39, 250, 40, 250, 41, 250, 129, 46, 22, 232, 23, 232, 24, 232, 132, 46, 115, 52, 71, 52, 136, 46, 139, 46, 30, 232, 158, 53, 26, 54, 14, 54, 140, 46, 151, 46, 110, 57, 24, 57, 38, 232, 207, 57, 223, 57, 115, 58, 208, 57, 43, 232, 44, 232, 78, 59, 110, 60, 224, 60, 167, 46, 49, 232, 50, 232, 170, 46, 86, 64, 95, 65, 174, 46, 55, 67, 179, 46, 182, 46, 183, 46, 59, 232, 177, 67, 172, 67, 187, 46, 221, 67, 214, 68, 97, 70, 76, 70, 67, 232, 35, 71, 41, 71, 124, 71, 141, 71, 202, 46, 71, 73, 122, 73, 125, 73, 130, 73, 131, 73, 133, 73, 134, 73, 159, 73, 155, 73, 183, 73, 182, 73, 84, 232, 85, 232, 163, 76, 159, 76, 160, 76, 161, 76, 119, 76, 162, 76, 19, 77, 20, 77, 21, 77, 22, 77, 23, 77, 24, 77, 25, 77, 174, 77, 100, 232, 104, 228, 105, 228, 106, 228, 107, 228, 108, 228, 109, 228, 110, 228, 111, 228, 112, 228, 113, 228, 114, 228, 115, 228, 116, 228, 117, 228, 118, 228, 119, 228, 120, 228, 121, 228, 122, 228, 123, 228, 124, 228, 125, 228, 126, 228, 127, 228, 128, 228, 129, 228, 130, 228, 131, 228, 132, 228, 133, 228, 134, 228, 135, 228, 136, 228, 137, 228, 138, 228, 139, 228, 140, 228, 141, 228, 142, 228, 143, 228, 144, 228, 145, 228, 146, 228, 147, 228, 148, 228, 149, 228, 150, 228, 151, 228, 152, 228, 153, 228, 154, 228, 155, 228, 156, 228, 157, 228, 158, 228, 159, 228, 160, 228, 161, 228, 162, 228, 163, 228, 164, 228, 165, 228, 166, 228, 167, 228, 168, 228, 169, 228, 170, 228, 171, 228, 172, 228, 173, 228, 174, 228, 175, 228, 176, 228, 177, 228, 178, 228, 179, 228, 180, 228, 181, 228, 182, 228, 183, 228, 184, 228, 185, 228, 186, 228, 187, 228, 188, 228, 189, 228, 190, 228, 191, 228, 192, 228, 193, 228, 194, 228, 195, 228, 196, 228, 197, 228, 240, 67, 50, 76, 3, 70, 166, 69, 120, 69, 103, 114, 119, 77, 179, 69, 177, 124, 226, 76, 197, 124, 149, 59, 54, 71, 68, 71, 71, 76, 64, 76, 191, 66, 23, 54, 82, 115, 139, 110, 210, 112, 87, 76, 81, 163, 79, 71, 218, 69, 133, 76, 108, 124, 7, 77, 164, 74, 161, 70, 35, 107, 37, 114, 84, 90, 99, 26, 6, 62, 97, 63, 77, 102, 251, 86, 0, 0, 149, 125, 29, 89, 185, 139, 244, 61, 52, 151, 239, 123, 219, 91, 94, 29, 164, 90, 37, 54, 176, 158, 209, 90, 183, 91, 252, 92, 110, 103, 147, 133, 69, 153, 97, 116, 157, 116, 117, 56, 83, 29, 158, 54, 33, 96, 236, 62, 222, 88, 245, 58, 252, 122, 151, 159, 97, 65, 13, 137, 234, 49, 138, 10, 94, 50, 10, 67, 132, 132, 150, 159, 47, 148, 48, 73, 19, 134, 150, 88, 74, 151, 24, 146, 208, 121, 50, 122, 96, 102, 41, 106, 157, 136, 76, 116, 197, 123, 130, 103, 44, 122, 79, 82, 70, 144, 230, 52, 196, 115, 185, 93, 198, 116, 199, 159, 179, 87, 47, 73, 76, 84, 49, 65, 142, 54, 24, 88, 114, 122, 101, 123, 143, 139, 174, 70, 136, 110, 129, 65, 153, 93, 174, 123, 188, 36, 200, 159, 193, 36, 201, 36, 204, 36, 201, 159, 4, 133, 187, 53, 180, 64, 202, 159, 225, 68, 255, 173, 193, 98, 110, 112, 203, 159, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 192, 49, 193, 49, 194, 49, 195, 49, 196, 49, 12, 1, 197, 49, 209, 0, 205, 0, 198, 49, 199, 49, 203, 0, 232, 31, 200, 49, 202, 0, 201, 49, 202, 49, 203, 49, 204, 49, 14, 1, 205, 49, 206, 49, 0, 1, 193, 0, 205, 1, 192, 0, 18, 1, 201, 0, 26, 1, 200, 0, 76, 1, 211, 0, 209, 1, 210, 0, 0, 220, 190, 30, 4, 220, 192, 30, 202, 0, 1, 1, 225, 0, 206, 1, 224, 0, 81, 2, 19, 1, 233, 0, 27, 1, 232, 0, 43, 1, 237, 0, 208, 1, 236, 0, 77, 1, 243, 0, 210, 1, 242, 0, 107, 1, 250, 0, 212, 1, 249, 0, 214, 1, 216, 1, 218, 1, 220, 1, 252, 0, 8, 220, 191, 30, 12, 220, 193, 30, 234, 0, 97, 2, 218, 35, 219, 35], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 261308);
	        allocate([169, 163, 69, 17, 0, 0, 10, 101, 0, 0, 0, 0, 61, 78, 221, 110, 78, 157, 223, 145, 0, 0, 0, 0, 53, 119, 145, 100, 26, 79, 40, 79, 168, 79, 86, 81, 116, 81, 156, 81, 228, 81, 161, 82, 168, 82, 59, 83, 78, 83, 209, 83, 216, 83, 226, 86, 240, 88, 4, 89, 7, 89, 50, 89, 52, 89, 102, 91, 158, 91, 159, 91, 154, 92, 134, 94, 59, 96, 137, 101, 254, 103, 4, 104, 101, 104, 78, 109, 188, 112, 53, 117, 164, 126, 172, 126, 186, 126, 199, 126, 207, 126, 223, 126, 6, 127, 55, 127, 122, 130, 207, 130, 111, 131, 198, 137, 190, 139, 226, 139, 102, 143, 103, 143, 110, 143, 17, 116, 252, 124, 205, 125, 70, 105, 201, 122, 39, 82, 0, 0, 0, 0, 0, 0, 0, 0, 140, 145, 184, 120, 94, 145, 188, 128, 0, 0, 11, 141, 246, 128, 231, 9, 0, 0, 0, 0, 159, 128, 199, 158, 205, 76, 201, 157, 12, 158, 62, 76, 246, 157, 14, 112, 10, 158, 51, 161, 193, 53, 0, 0, 154, 110, 62, 130, 25, 117, 0, 0, 17, 73, 108, 154, 143, 154, 153, 159, 135, 121, 108, 132, 202, 29, 208, 5, 230, 42, 36, 78, 129, 78, 128, 78, 135, 78, 191, 78, 235, 78, 55, 79, 76, 52, 189, 79, 72, 62, 3, 80, 136, 80, 125, 52, 147, 52, 165, 52, 134, 81, 5, 89, 219, 81, 252, 81, 5, 82, 137, 78, 121, 82, 144, 82, 39, 83, 199, 53, 169, 83, 81, 53, 176, 83, 83, 53, 194, 83, 35, 84, 109, 53, 114, 53, 129, 54, 147, 84, 163, 84, 180, 84, 185, 84, 208, 84, 239, 84, 24, 85, 35, 85, 40, 85, 152, 53, 63, 85, 165, 53, 191, 53, 215, 85, 197, 53, 132, 125, 37, 85, 0, 0, 66, 12, 21, 13, 43, 81, 144, 85, 198, 44, 236, 57, 65, 3, 70, 142, 184, 77, 229, 148, 83, 64, 190, 128, 122, 119, 56, 44, 52, 58, 213, 71, 93, 129, 242, 105, 234, 77, 221, 100, 124, 13, 180, 15, 213, 12, 244, 16, 141, 100, 126, 142, 150, 14, 11, 12, 100, 15, 169, 44, 86, 130, 211, 68, 0, 0, 70, 13, 77, 154, 233, 128, 244, 71, 167, 78, 194, 44, 178, 154, 103, 58, 244, 149, 237, 63, 6, 53, 199, 82, 212, 151, 200, 120, 68, 45, 110, 157, 21, 152, 0, 0, 217, 67, 165, 96, 180, 100, 227, 84, 76, 45, 202, 43, 119, 16, 251, 57, 111, 16, 218, 102, 22, 103, 160, 121, 234, 100, 82, 80, 67, 12, 104, 142, 161, 33, 76, 139, 49, 7, 0, 0, 11, 72, 169, 1, 250, 63, 115, 88, 141, 45, 0, 0, 200, 69, 252, 4, 151, 96, 76, 15, 150, 13, 121, 85, 187, 64, 186, 67, 0, 0, 180, 74, 102, 42, 157, 16, 170, 129, 245, 152, 156, 13, 121, 99, 254, 57, 117, 39, 192, 141, 161, 86, 124, 100, 67, 62, 0, 0, 1, 166, 9, 14, 207, 42, 201, 44, 0, 0, 200, 16, 194, 57, 146, 57, 6, 58, 155, 130, 120, 53, 73, 94, 199, 32, 82, 86, 49, 15, 178, 44, 32, 151, 188, 52, 61, 108, 59, 78, 0, 0, 0, 0, 116, 117, 139, 46, 8, 34, 91, 166, 205, 140, 122, 14, 52, 12, 28, 104, 147, 127, 207, 16, 3, 40, 57, 41, 251, 53, 227, 81, 140, 14, 141, 15, 170, 14, 147, 63, 48, 15, 71, 13, 79, 17, 76, 14, 0, 0, 171, 14, 169, 11, 72, 13, 192, 16, 61, 17, 249, 63, 150, 38, 50, 100, 173, 15, 244, 51, 57, 118, 206, 43, 126, 13, 127, 13, 81, 44, 85, 44, 24, 58, 152, 14, 199, 16, 46, 15, 50, 166, 80, 107, 210, 140, 153, 141, 202, 140, 170, 149, 204, 84, 196, 130, 185, 85, 0, 0, 195, 158, 38, 156, 182, 154, 94, 119, 238, 45, 64, 113, 109, 129, 236, 128, 28, 92, 114, 101, 52, 129, 151, 55, 95, 83, 189, 128, 182, 145, 250, 14, 15, 14, 119, 14, 251, 14, 221, 53, 235, 77, 9, 54, 214, 12, 175, 86, 181, 39, 201, 16, 16, 14, 120, 14, 120, 16, 72, 17, 7, 130, 85, 20, 121, 14, 80, 78, 164, 45, 84, 90, 29, 16, 30, 16, 245, 16, 246, 16, 156, 87, 17, 14, 148, 118, 205, 130, 181, 15, 123, 14, 126, 81, 3, 55, 182, 15, 128, 17, 216, 82, 189, 162, 218, 73, 58, 24, 119, 65, 124, 130, 153, 88, 104, 82, 26, 54, 61, 87, 178, 123, 104, 91, 0, 72, 44, 75, 39, 159, 231, 73, 31, 156, 141, 155, 116, 91, 61, 49, 251, 85, 242, 53, 137, 86, 40, 78, 2, 89, 193, 27, 120, 248, 81, 151, 134, 0, 91, 78, 187, 78, 62, 53, 35, 92, 81, 95, 196, 95, 250, 56, 76, 98, 53, 101, 122, 107, 53, 108, 58, 108, 108, 112, 43, 114, 44, 78, 173, 114, 233, 72, 82, 127, 59, 121, 249, 124, 83, 127, 106, 98, 193, 52, 0, 0, 75, 99, 2, 128, 128, 128, 18, 102, 81, 105, 93, 83, 100, 136, 193, 137, 178, 120, 160, 139, 29, 141, 133, 148, 120, 149, 127, 149, 232, 149, 15, 142, 230, 151, 117, 152, 206, 152, 222, 152, 99, 153, 16, 152, 124, 156, 31, 158, 196, 158, 111, 107, 7, 249, 55, 78, 135, 0, 29, 150, 55, 98, 162, 148, 0, 0, 59, 80, 254, 109, 115, 156, 166, 159, 201, 61, 143, 136, 78, 65, 119, 112, 245, 92, 32, 75, 205, 81, 89, 53, 48, 93, 34, 97, 50, 138, 167, 143, 246, 145, 145, 113, 25, 103, 186, 115, 129, 50, 7, 161, 139, 60, 128, 25, 16, 75, 228, 120, 2, 116, 174, 81, 15, 135, 9, 64, 99, 106, 186, 162, 35, 66, 15, 134, 111, 10, 42, 122, 71, 153, 234, 138, 85, 151, 77, 112, 36, 83, 126, 32, 244, 147, 217, 118, 227, 137, 167, 159, 221, 119, 163, 78, 240, 79, 188, 80, 47, 78, 23, 79, 168, 159, 52, 84, 139, 125, 146, 88, 208, 88, 182, 29, 146, 94, 153, 94, 194, 95, 18, 39, 139, 101, 249, 51, 25, 105, 67, 106, 99, 60, 255, 108, 0, 0, 0, 114, 5, 69, 140, 115, 219, 62, 19, 74, 21, 91, 185, 116, 131, 139, 164, 92, 149, 86, 147, 122, 236, 123, 195, 124, 108, 126, 248, 130, 151, 133, 169, 159, 144, 136, 170, 159, 185, 142, 171, 159, 207, 143, 95, 133, 224, 153, 33, 146, 172, 159, 185, 141, 63, 20, 113, 64, 162, 66, 26, 90, 0, 0, 0, 0, 0, 0, 104, 152, 107, 103, 118, 66, 61, 87, 0, 0, 214, 133, 123, 73, 191, 130, 13, 113, 129, 76, 116, 109, 123, 93, 21, 107, 190, 111, 173, 159, 174, 159, 150, 91, 175, 159, 231, 102, 91, 126, 87, 110, 202, 121, 136, 61, 195, 68, 86, 50, 150, 39, 154, 67, 54, 69, 0, 0, 213, 92, 26, 59, 249, 138, 120, 92, 18, 61, 81, 53, 120, 93, 178, 159, 87, 113, 88, 69, 236, 64, 35, 30, 119, 76, 120, 57, 74, 52, 164, 1, 65, 108, 204, 138, 180, 79, 57, 2, 191, 89, 108, 129, 86, 152, 250, 152, 59, 95, 159, 11, 0, 0, 193, 33, 109, 137, 2, 65, 187, 70, 121, 144, 7, 63, 179, 159, 181, 161, 248, 64, 214, 55, 247, 70, 70, 108, 124, 65, 178, 134, 255, 115, 109, 69, 212, 56, 154, 84, 97, 69, 27, 69, 137, 77, 123, 76, 118, 77, 234, 69, 200, 63, 15, 75, 97, 54, 222, 68, 189, 68, 237, 65, 62, 93, 72, 93, 86, 93, 252, 61, 15, 56, 164, 93, 185, 93, 32, 56, 56, 56, 66, 94, 189, 94, 37, 95, 131, 95, 8, 57, 20, 57, 63, 57, 77, 57, 215, 96, 61, 97, 229, 92, 137, 57, 183, 97, 185, 97, 207, 97, 184, 57, 44, 98, 144, 98, 229, 98, 24, 99, 248, 57, 177, 86, 3, 58, 226, 99, 251, 99, 7, 100, 90, 100, 75, 58, 192, 100, 21, 93, 33, 86, 159, 159, 151, 58, 134, 101, 189, 58, 255, 101, 83, 102, 242, 58, 146, 102, 34, 59, 22, 103, 66, 59, 164, 103, 0, 104, 88, 59, 74, 104, 132, 104, 114, 59, 113, 59, 123, 59, 9, 105, 67, 105, 92, 114, 100, 105, 159, 105, 133, 105, 188, 59, 214, 105, 221, 59, 101, 106, 116, 106, 113, 106, 130, 106, 236, 59, 153, 106, 242, 59, 171, 106, 181, 106, 212, 106, 246, 106, 129, 107, 193, 107, 234, 107, 117, 108, 170, 108, 203, 60, 2, 109, 6, 109, 38, 109, 129, 109, 239, 60, 164, 109, 177, 109, 21, 110, 24, 110, 41, 110, 134, 110, 192, 137, 187, 110, 226, 110, 218, 110, 127, 159, 232, 110, 233, 110, 36, 111, 52, 111, 70, 61, 65, 63, 129, 111, 190, 111, 106, 61, 117, 61, 183, 113, 153, 92, 138, 61, 44, 112, 145, 61, 80, 112, 84, 112, 111, 112, 127, 112, 137, 112, 37, 3, 193, 67, 241, 53, 216, 14, 215, 62, 190, 87, 211, 110, 62, 113, 224, 87, 78, 54, 162, 105, 233, 139, 116, 91, 73, 122, 225, 88, 217, 148, 101, 122, 125, 122, 172, 89, 187, 122, 176, 122, 194, 122, 195, 122, 209, 113, 141, 100, 202, 65, 218, 122, 221, 122, 234, 122, 239, 65, 178, 84, 1, 92, 11, 123, 85, 123, 41, 123, 14, 83, 254, 92, 162, 123, 111, 123, 156, 131, 180, 91, 127, 108, 208, 123, 33, 132, 146, 123, 0, 0, 32, 93, 173, 61, 101, 92, 146, 132, 250, 123, 0, 0, 53, 124, 193, 92, 68, 124, 131, 124, 130, 72, 166, 124, 125, 102, 120, 69, 201, 124, 199, 124, 230, 124, 116, 124, 243, 124, 245, 124, 0, 0, 103, 126, 29, 69, 68, 110, 93, 125, 214, 110, 141, 116, 137, 125, 171, 125, 53, 113, 179, 125, 0, 0, 87, 64, 41, 96, 228, 125, 19, 61, 245, 125, 249, 23, 229, 125, 109, 131, 0, 0, 33, 97, 90, 97, 110, 126, 146, 126, 43, 67, 108, 148, 39, 126, 64, 127, 65, 127, 71, 127, 54, 121, 208, 98, 225, 153, 151, 127, 81, 99, 163, 127, 97, 22, 104, 0, 92, 69, 102, 55, 3, 69, 58, 131, 250, 127, 137, 100, 0, 0, 8, 128, 29, 128, 0, 0, 47, 128, 135, 160, 195, 108, 59, 128, 60, 128, 97, 128, 20, 39, 137, 73, 38, 102, 227, 61, 232, 102, 37, 103, 167, 128, 72, 138, 7, 129, 26, 129, 176, 88, 246, 38, 127, 108, 152, 100, 184, 79, 231, 100, 138, 20, 24, 130, 94, 24, 83, 106, 101, 74, 149, 74, 122, 68, 41, 130, 13, 11, 82, 106, 126, 61, 249, 79, 253, 20, 226, 132, 98, 131, 10, 107, 167, 73, 48, 53, 115, 23, 248, 61, 170, 130, 27, 105, 148, 249, 219, 65, 75, 133, 208, 130, 26, 131, 22, 14, 180, 23, 193, 54, 125, 49, 90, 53, 123, 130, 226, 130, 24, 131, 139, 62, 163, 109, 5, 107, 151, 107, 206, 53, 191, 61, 29, 131, 236, 85, 133, 131, 11, 69, 165, 109, 172, 131, 0, 0, 211, 131, 126, 52, 212, 110, 87, 106, 90, 133, 150, 52, 66, 110, 239, 46, 88, 132, 228, 91, 113, 132, 211, 61, 228, 68, 167, 106, 74, 132, 181, 60, 88, 121, 0, 0, 150, 107, 119, 110, 67, 110, 222, 132, 0, 0, 145, 131, 160, 68, 147, 132, 228, 132, 145, 92, 64, 66, 192, 92, 67, 69, 52, 133, 242, 90, 153, 110, 39, 69, 115, 133, 22, 69, 191, 103, 22, 134, 37, 134, 59, 134, 193, 133, 136, 112, 2, 134, 130, 21, 205, 112, 178, 249, 106, 69, 40, 134, 72, 54, 162, 24, 247, 83, 154, 115, 126, 134, 113, 135, 248, 160, 238, 135, 39, 44, 177, 135, 218, 135, 15, 136, 97, 86, 108, 134, 86, 104, 15, 70, 69, 136, 70, 136, 224, 117, 185, 61, 228, 117, 94, 136, 156, 136, 91, 70, 180, 136, 181, 136, 193, 99, 197, 136, 119, 119, 15, 119, 135, 137, 138, 137, 0, 0, 0, 0, 167, 137, 188, 137, 37, 138, 231, 137, 36, 121, 189, 122, 156, 138, 147, 119, 254, 145, 144, 138, 89, 122, 233, 122, 58, 123, 143, 63, 19, 71, 56, 123, 124, 113, 12, 139, 31, 139, 48, 84, 101, 85, 63, 139, 76, 139, 77, 139, 169, 138, 122, 74, 144, 139, 155, 139, 175, 138, 223, 22, 21, 70, 79, 136, 155, 140, 84, 125, 143, 125, 212, 249, 37, 55, 83, 125, 214, 140, 152, 125, 189, 125, 18, 141, 3, 141, 16, 25, 219, 140, 92, 112, 17, 141, 201, 76, 208, 62, 0, 0, 169, 141, 2, 128, 20, 16, 138, 73, 124, 59, 188, 129, 12, 113, 231, 122, 173, 142, 182, 142, 195, 142, 212, 146, 25, 143, 45, 143, 101, 131, 18, 132, 165, 143, 3, 147, 159, 162, 80, 10, 179, 143, 42, 73, 222, 137, 61, 133, 187, 61, 248, 94, 98, 50, 249, 143, 20, 160, 188, 134, 1, 133, 37, 35, 128, 57, 215, 110, 55, 144, 60, 133, 190, 122, 97, 144, 108, 133, 11, 134, 168, 144, 19, 135, 196, 144, 230, 134, 174, 144, 0, 0, 103, 145, 240, 58, 169, 145, 196, 145, 172, 124, 51, 137, 137, 30, 14, 146, 159, 108, 65, 146, 98, 146, 185, 85, 0, 0, 198, 138, 155, 60, 12, 139, 219, 85, 49, 13, 44, 147, 107, 147, 225, 138, 235, 139, 143, 112, 195, 90, 226, 138, 229, 138, 101, 73, 68, 146, 236, 139, 57, 140, 255, 139, 115, 147, 91, 148, 188, 142, 133, 149, 166, 149, 38, 148, 160, 149, 246, 111, 185, 66, 122, 38, 216, 134, 124, 18, 46, 62, 223, 73, 28, 108, 123, 150, 150, 150, 108, 65, 163, 150, 213, 110, 218, 97, 182, 150, 245, 120, 224, 138, 189, 150, 204, 83, 161, 73, 184, 108, 116, 2, 16, 100, 175, 144, 229, 144, 209, 74, 21, 25, 10, 51, 49, 151, 66, 134, 54, 151, 15, 74, 61, 69, 133, 69, 233, 74, 117, 112, 65, 91, 27, 151, 0, 0, 213, 145, 87, 151, 74, 91, 235, 145, 95, 151, 37, 148, 208, 80, 183, 48, 188, 48, 137, 151, 159, 151, 177, 151, 190, 151, 192, 151, 210, 151, 224, 151, 108, 84, 238, 151, 28, 116, 51, 148, 0, 0, 245, 151, 29, 148, 122, 121, 209, 74, 52, 152, 51, 152, 75, 152, 102, 152, 14, 59, 117, 113, 81, 61, 48, 6, 92, 65, 6, 87, 202, 152, 183, 152, 200, 152, 199, 152, 255, 74, 39, 109, 211, 22, 176, 85, 225, 152, 230, 152, 236, 152, 120, 147, 57, 153, 41, 74, 114, 75, 87, 152, 5, 153, 245, 153, 12, 154, 59, 154, 16, 154, 88, 154, 37, 87, 196, 54, 177, 144, 213, 155, 224, 154, 226, 154, 5, 155, 244, 154, 14, 76, 20, 155, 45, 155, 0, 134, 52, 80, 52, 155, 168, 105, 195, 56, 125, 48, 80, 155, 64, 155, 62, 157, 69, 90, 99, 24, 142, 155, 75, 66, 2, 156, 255, 155, 12, 156, 104, 158, 212, 157, 183, 159, 146, 161, 171, 161, 225, 160, 35, 161, 223, 161, 126, 157, 131, 157, 52, 161, 14, 158, 136, 104, 196, 157, 91, 33, 147, 161, 32, 162, 59, 25, 51, 162, 57, 157, 185, 160, 180, 162, 144, 158, 149, 158, 158, 158, 162, 158, 52, 77, 170, 158, 175, 158, 100, 67, 193, 158, 96, 59, 229, 57, 29, 61, 50, 79, 190, 55, 43, 140, 2, 159, 8, 159, 150, 75, 36, 148, 162, 109, 23, 159, 0, 0, 57, 159, 159, 86, 138, 86, 69, 159, 184, 153, 139, 144, 242, 151, 127, 132, 98, 159, 105, 159, 220, 122, 142, 159, 22, 114, 190, 75, 117, 73, 187, 73, 119, 113, 248, 73, 72, 67, 81, 74, 158, 115, 218, 139, 250, 24, 159, 121, 126, 137, 54, 142, 105, 147, 243, 147, 68, 138, 236, 146, 129, 147, 203, 147, 108, 137, 185, 68, 23, 114, 235, 62, 114, 119, 67, 122, 208, 112, 115, 68, 248, 67, 126, 113, 239, 23, 163, 112, 190, 24, 153, 53, 199, 62, 133, 24, 47, 84, 248, 23, 34, 55, 251, 22, 57, 24, 225, 54, 116, 23, 209, 24, 75, 95, 35, 55, 192, 22, 91, 87, 37, 74, 254, 19, 168, 18, 198, 19, 182, 20, 3, 133, 166, 54, 0, 0, 85, 132, 148, 73, 101, 113, 49, 62, 92, 85, 251, 62, 82, 112, 244, 68, 238, 54, 157, 153, 38, 111, 249, 103, 51, 55, 21, 60, 231, 61, 108, 88, 34, 25, 16, 104, 87, 64, 63, 55, 225, 64, 139, 64, 15, 65, 33, 108, 203, 84, 158, 86, 177, 102, 146, 86, 223, 15, 168, 11, 13, 14, 198, 147, 19, 139, 156, 147, 248, 78, 43, 81, 25, 56, 54, 68, 188, 78, 101, 4, 127, 3, 75, 79, 138, 79, 81, 86, 104, 90, 171, 1, 203, 3, 153, 57, 10, 3, 20, 4, 53, 52, 41, 79, 192, 2, 179, 142, 117, 2, 218, 138, 12, 2, 152, 78, 205, 80, 13, 81, 162, 79, 3, 79, 14, 74, 138, 62, 66, 79, 46, 80, 108, 80, 129, 80, 204, 79, 229, 79, 88, 80, 252, 80, 0, 0, 0, 0, 0, 0, 0, 0, 118, 110, 149, 53, 57, 62, 191, 62, 114, 109, 132, 24, 137, 62, 168, 81, 195, 81, 224, 5, 221, 68, 163, 4, 146, 4, 145, 4, 122, 141, 156, 138, 14, 7, 89, 82, 164, 82, 115, 8, 225, 82, 0, 0, 122, 70, 140, 113, 140, 67, 32, 12, 172, 73, 228, 16, 209, 105, 29, 14, 0, 0, 222, 62, 153, 116, 20, 116, 86, 116, 152, 115, 142, 75, 188, 74, 141, 64, 208, 83, 132, 53, 15, 114, 201, 64, 180, 85, 69, 3, 205, 84, 198, 11, 29, 87, 93, 146, 244, 150, 102, 147, 221, 87, 141, 87, 127, 87, 62, 54, 203, 88, 153, 90, 70, 138, 250, 22, 111, 23, 16, 23, 44, 90, 184, 89, 143, 146, 126, 90, 207, 90, 18, 90, 70, 89, 243, 25, 97, 24, 149, 66, 245, 54, 5, 109, 67, 116, 33, 90, 131, 94, 129, 90, 215, 139, 19, 4, 224, 147, 140, 116, 3, 19, 5, 113, 114, 73, 8, 148, 251, 137, 189, 147, 160, 55, 30, 92, 158, 92, 94, 94, 72, 94, 150, 25, 124, 25, 238, 58, 205, 94, 79, 91, 3, 25, 4, 25, 1, 55, 160, 24, 221, 54, 254, 22, 211, 54, 42, 129, 71, 138, 186, 29, 114, 52, 168, 137, 12, 95, 14, 95, 39, 25, 171, 23, 107, 90, 59, 23, 68, 91, 20, 134, 253, 117, 96, 136, 126, 96, 96, 40, 43, 38, 219, 95, 184, 62, 175, 37, 190, 37, 136, 144, 115, 111, 192, 97, 62, 0, 70, 0, 27, 38, 153, 97, 152, 97, 117, 96, 155, 44, 7, 45, 212, 70, 77, 145, 113, 100, 101, 70, 106, 43, 41, 58, 34, 43, 80, 52, 234, 152, 120, 46, 55, 99, 91, 164, 182, 100, 49, 99, 209, 99, 227, 73, 103, 45, 164, 98, 161, 44, 59, 100, 107, 101, 114, 105, 244, 59, 142, 48, 173, 50, 137, 73, 171, 50, 13, 85, 224, 50, 217, 24, 63, 148, 206, 102, 137, 50, 179, 49, 224, 58, 144, 65, 132, 85, 34, 139, 143, 85, 252, 22, 91, 85, 37, 84, 238, 120, 3, 49, 42, 24, 52, 50, 100, 52, 15, 50, 130, 49, 201, 66, 142, 102, 36, 109, 107, 102, 147, 75, 48, 102, 112, 120, 235, 29, 99, 102, 210, 50, 225, 50, 30, 102, 114, 88, 209, 56, 58, 56, 188, 55, 153, 59, 162, 55, 254, 51, 208, 116, 150, 59, 143, 103, 42, 70, 182, 104, 30, 104, 196, 59, 190, 106, 99, 56, 213, 55, 135, 68, 51, 106, 82, 106, 201, 106, 5, 107, 18, 25, 17, 101, 152, 104, 76, 106, 215, 59, 122, 106, 87, 107, 192, 63, 154, 60, 160, 147, 242, 146, 234, 139, 203, 138, 137, 146, 30, 128, 220, 137, 103, 148, 165, 109, 11, 111, 236, 73, 0, 0, 127, 63, 143, 61, 4, 110, 60, 64, 61, 90, 10, 110, 71, 88, 36, 109, 66, 120, 59, 113, 26, 67, 118, 66, 241, 112, 80, 114, 135, 114, 148, 114, 143, 71, 37, 71, 121, 81, 164, 74, 235, 5, 122, 116, 248, 62, 95, 54, 74, 74, 23, 73, 225, 95, 6, 63, 177, 62, 223, 74, 35, 140, 53, 63, 167, 96, 243, 62, 204, 116, 60, 116, 135, 147, 55, 116, 159, 68, 234, 109, 81, 69, 131, 117, 99, 63, 217, 76, 6, 77, 88, 63, 85, 117, 115, 118, 198, 165, 25, 59, 104, 116, 204, 138, 171, 73, 142, 73, 251, 58, 205, 61, 78, 74, 255, 62, 197, 73, 243, 72, 250, 145, 50, 87, 66, 147, 227, 138, 100, 24, 223, 80, 33, 82, 231, 81, 120, 119, 50, 50, 14, 119, 15, 119, 123, 119, 151, 70, 129, 55, 94, 58, 240, 72, 56, 116, 155, 116, 191, 62, 186, 74, 199, 74, 200, 64, 150, 74, 174, 97, 7, 147, 129, 85, 30, 120, 141, 120, 136, 120, 210, 120, 208, 115, 89, 121, 65, 119, 227, 86, 14, 65, 0, 0, 150, 132, 165, 121, 45, 106, 250, 62, 58, 122, 244, 121, 110, 65, 230, 22, 50, 65, 53, 146, 241, 121, 76, 13, 140, 73, 153, 2, 186, 61, 110, 23, 151, 53, 107, 85, 112, 53, 170, 54, 212, 1, 13, 12, 226, 122, 89, 90, 245, 38, 175, 90, 156, 90, 13, 90, 91, 2, 240, 120, 42, 90, 198, 91, 254, 122, 249, 65, 93, 124, 109, 124, 17, 66, 179, 91, 188, 94, 166, 94, 205, 124, 249, 73, 176, 23, 142, 124, 124, 124, 174, 124, 178, 106, 220, 125, 7, 126, 211, 125, 78, 127, 97, 98, 92, 97, 72, 123, 151, 125, 130, 94, 106, 66, 117, 107, 22, 9, 214, 103, 78, 0, 207, 53, 196, 87, 18, 100, 248, 99, 98, 73, 221, 127, 39, 123, 44, 8, 233, 90, 67, 93, 12, 123, 14, 94, 230, 153, 69, 134, 99, 154, 28, 106, 63, 52, 226, 57, 247, 73, 173, 101, 31, 154, 160, 101, 128, 132, 39, 113, 209, 108, 234, 68, 55, 129, 2, 68, 198, 128, 9, 129, 66, 129, 180, 103, 195, 152, 66, 106, 98, 130, 101, 130, 81, 106, 83, 132, 167, 109, 16, 134, 27, 114, 134, 90, 127, 65, 64, 24, 43, 91, 161, 24, 228, 90, 216, 24, 160, 134, 188, 249, 143, 61, 45, 136, 34, 116, 2, 90, 110, 136, 69, 79, 135, 136, 191, 136, 230, 136, 101, 137, 77, 137, 131, 86, 84, 137, 133, 119, 132, 119, 245, 139, 217, 139, 156, 139, 249, 137, 173, 62, 163, 132, 245, 70, 207, 70, 242, 55, 61, 138, 28, 138, 72, 148, 77, 95, 43, 146, 132, 66, 212, 101, 41, 113, 196, 112, 69, 24, 109, 157, 159, 140, 233, 140, 220, 125, 154, 89, 195, 119, 240, 89, 110, 67, 212, 54, 42, 142, 167, 142, 9, 76, 48, 143, 74, 143, 244, 66, 88, 108, 187, 111, 33, 35, 155, 72, 121, 111, 139, 110, 218, 23, 233, 155, 181, 54, 47, 73, 187, 144, 0, 0, 113, 85, 6, 73, 187, 145, 4, 148, 75, 138, 98, 64, 252, 138, 39, 148, 29, 140, 59, 140, 229, 132, 43, 138, 153, 149, 167, 149, 151, 149, 150, 149, 52, 141, 69, 116, 194, 62, 255, 72, 66, 74, 234, 67, 231, 62, 37, 50, 143, 150, 231, 142, 102, 142, 101, 142, 204, 62, 237, 73, 120, 74, 238, 63, 18, 116, 107, 116, 252, 62, 65, 151, 176, 144, 71, 104, 29, 74, 147, 144, 223, 87, 0, 0, 104, 147, 137, 137, 38, 140, 47, 139, 190, 99, 186, 146, 17, 91, 105, 139, 60, 73, 249, 115, 27, 66, 155, 151, 113, 151, 56, 153, 38, 15, 193, 93, 197, 139, 178, 74, 31, 152, 218, 148, 246, 146, 215, 149, 229, 145, 192, 68, 80, 139, 103, 74, 100, 139, 220, 152, 69, 138, 0, 63, 42, 146, 37, 73, 20, 132, 59, 153, 77, 153, 6, 123, 253, 61, 155, 153, 111, 75, 170, 153, 92, 154, 101, 139, 200, 88, 143, 106, 33, 154, 254, 90, 47, 154, 241, 152, 144, 75, 72, 153, 188, 153, 189, 75, 151, 75, 125, 147, 114, 88, 2, 19, 34, 88, 184, 73, 232, 20, 68, 120, 31, 39, 184, 61, 197, 104, 125, 61, 88, 148, 39, 57, 80, 97, 129, 39, 107, 41, 7, 97, 79, 156, 83, 156, 123, 156, 53, 156, 16, 156, 127, 155, 207, 155, 45, 158, 159, 155, 245, 161, 254, 160, 33, 157, 174, 76, 4, 65, 24, 158, 176, 76, 12, 157, 180, 161, 237, 160, 243, 160, 47, 153, 165, 157, 189, 132, 18, 110, 223, 111, 130, 107, 252, 133, 51, 69, 164, 109, 132, 110, 240, 109, 32, 132, 238, 133, 0, 110, 215, 55, 100, 96, 226, 121, 156, 53, 64, 54, 45, 73, 222, 73, 98, 61, 219, 147, 190, 146, 72, 147, 191, 2, 185, 120, 119, 146, 77, 148, 228, 79, 64, 52, 100, 144, 93, 85, 61, 120, 84, 120, 182, 120, 75, 120, 87, 23, 201, 49, 65, 73, 154, 54, 114, 79, 218, 111, 217, 111, 0, 0, 30, 112, 20, 84, 181, 65, 187, 87, 243, 88, 138, 87, 22, 157, 215, 87, 52, 113, 175, 52, 172, 65, 235, 113, 64, 108, 151, 79, 0, 0, 181, 23, 73, 138, 12, 97, 206, 90, 11, 90, 188, 66, 136, 68, 44, 55, 123, 75, 252, 137, 187, 147, 184, 147, 214, 24, 29, 15, 114, 132, 192, 108, 19, 20, 250, 66, 38, 44, 193, 67, 148, 89, 183, 61, 65, 103, 168, 125, 91, 97, 164, 96, 185, 73, 139, 73, 250, 137, 229, 146, 226, 115, 233, 62, 180, 116, 99, 139, 159, 24, 225, 62, 179, 74, 216, 106, 243, 115, 251, 115, 214, 62, 62, 74, 148, 74, 217, 23, 102, 74, 167, 3, 36, 20, 229, 73, 72, 116, 22, 73, 165, 112, 118, 73, 132, 146, 230, 115, 95, 147, 254, 4, 49, 147, 206, 138, 22, 138, 134, 147, 231, 139, 213, 85, 53, 73, 130, 138, 107, 113, 67, 73, 255, 12, 164, 86, 26, 6, 235, 11, 184, 12, 2, 85, 196, 121, 250, 23, 254, 125, 194, 22, 80, 74, 82, 24, 46, 69, 1, 148, 10, 55, 192, 138, 173, 73, 176, 89, 191, 24, 131, 24, 132, 116, 161, 90, 226, 54, 91, 61, 176, 54, 95, 146, 121, 90, 129, 138, 98, 24, 116, 147, 205, 60, 180, 10, 150, 74, 138, 57, 244, 80, 105, 61, 76, 61, 156, 19, 117, 113, 251, 66, 24, 130, 15, 110, 228, 144, 235, 68, 87, 109, 79, 126, 103, 112, 175, 108, 214, 60, 237, 63, 45, 62, 2, 110, 12, 111, 111, 61, 245, 3, 81, 117, 188, 54, 200, 52, 128, 70, 218, 62, 113, 72, 196, 89, 110, 146, 62, 73, 65, 143, 28, 140, 192, 107, 18, 88, 200, 87, 214, 54, 82, 20, 254, 112, 98, 67, 113, 74, 227, 47, 176, 18, 189, 35, 185, 104, 103, 105, 152, 19, 229, 52, 244, 123, 223, 54, 131, 138, 214, 55, 250, 51, 159, 76, 26, 106, 173, 54, 183, 108, 62, 132, 223, 68, 206, 68, 38, 109, 81, 109, 130, 108, 222, 111, 23, 111, 9, 113, 61, 131, 58, 23, 237, 131, 128, 108, 83, 112, 219, 23, 137, 89, 130, 90, 179, 23, 97, 90, 113, 90, 5, 25, 252, 65, 45, 55, 239, 89, 60, 23, 199, 54, 142, 113, 144, 147, 154, 102, 165, 66, 110, 90, 43, 90, 147, 66, 43, 106, 249, 62, 54, 119, 91, 68, 202, 66, 29, 113, 89, 66, 225, 137, 176, 79, 40, 109, 194, 92, 206, 68, 77, 126, 189, 67, 12, 106, 86, 66, 4, 19, 166, 112, 51, 113, 233, 67, 165, 61, 223, 108, 37, 248, 79, 74, 101, 126, 235, 89, 47, 93, 243, 61, 92, 95, 93, 74, 223, 23, 164, 125, 38, 132, 133, 84, 250, 58, 0, 51, 20, 2, 126, 87, 213, 8, 25, 6, 229, 63, 158, 31, 182, 162, 3, 112, 91, 145, 112, 93, 143, 115, 211, 124, 89, 138, 32, 148, 200, 79, 231, 127, 205, 114, 16, 115, 244, 122, 56, 115, 57, 115, 246, 86, 65, 115, 72, 115, 169, 62, 24, 123, 108, 144, 245, 113, 242, 72, 225, 115, 246, 129, 202, 62, 12, 119, 209, 62, 162, 108, 253, 86, 25, 116, 30, 116, 31, 116, 226, 62, 240, 62, 244, 62, 250, 62, 211, 116, 14, 63, 83, 63, 66, 117, 109, 117, 114, 117, 141, 117, 124, 63, 200, 117, 220, 117, 192, 63, 77, 118, 215, 63, 116, 118, 220, 63, 122, 118, 92, 79, 136, 113, 35, 86, 128, 137, 105, 88, 29, 64, 67, 119, 57, 64, 97, 103, 69, 64, 219, 53, 152, 119, 106, 64, 111, 64, 94, 92, 190, 119, 203, 119, 242, 88, 24, 120, 185, 112, 28, 120, 168, 64, 57, 120, 71, 120, 81, 120, 102, 120, 72, 132, 53, 85, 51, 121, 3, 104, 50, 121, 3, 65, 9, 65, 145, 121, 153, 121, 187, 143, 6, 122, 188, 143, 103, 65, 145, 122, 178, 65, 188, 122, 121, 130, 196, 65, 207, 122, 219, 122, 207, 65, 33, 78, 98, 123, 108, 123, 123, 123, 18, 124, 27, 124, 96, 66, 122, 66, 123, 124, 156, 124, 140, 66, 184, 124, 148, 66, 237, 124, 147, 143, 192, 112, 207, 12, 207, 125, 212, 125, 208, 125, 253, 125, 174, 127, 180, 127, 159, 114, 151, 67, 32, 128, 37, 128, 57, 123, 46, 128, 49, 128, 84, 128, 204, 61, 180, 87, 160, 112, 183, 128, 233, 128, 237, 67, 12, 129, 42, 115, 14, 129, 18, 129, 96, 117, 20, 129, 1, 68, 57, 59, 86, 129, 89, 129, 90, 129, 19, 68, 58, 88, 124, 129, 132, 129, 37, 68, 147, 129, 45, 68, 165, 129, 239, 87, 193, 129, 228, 129, 84, 130, 143, 68, 166, 130, 118, 130, 202, 130, 216, 130, 255, 130, 176, 68, 87, 131, 105, 150, 138, 105, 5, 132, 245, 112, 100, 132, 227, 96, 136, 132, 4, 69, 190, 132, 225, 132, 248, 132, 16, 133, 56, 133, 82, 133, 59, 69, 111, 133, 112, 133, 224, 133, 119, 69, 114, 134, 146, 134, 178, 134, 239, 134, 69, 150, 139, 135, 6, 70, 23, 70, 174, 136, 255, 136, 36, 137, 71, 137, 145, 137, 103, 121, 41, 138, 56, 138, 148, 138, 180, 138, 81, 140, 212, 140, 242, 140, 28, 141, 152, 71, 95, 88, 195, 141, 237, 71, 238, 78, 58, 142, 216, 85, 84, 87, 113, 142, 245, 85, 176, 142, 55, 72, 206, 142, 226, 142, 228, 142, 237, 142, 242, 142, 183, 143, 193, 143, 202, 143, 204, 143, 51, 144, 196, 153, 173, 72, 224, 152, 19, 146, 30, 73, 40, 146, 88, 146, 107, 146, 177, 146, 174, 146, 191, 146, 227, 146, 235, 146, 243, 146, 244, 146, 253, 146, 67, 147, 132, 147, 173, 147, 69, 73, 81, 73, 191, 158, 23, 148, 1, 83, 29, 148, 45, 148, 62, 148, 106, 73, 84, 148, 121, 148, 45, 149, 162, 149, 167, 73, 244, 149, 51, 150, 229, 73, 160, 103, 36, 74, 64, 151, 53, 74, 178, 151, 194, 151, 84, 86, 228, 74, 232, 96, 185, 152, 25, 75, 241, 152, 68, 88, 14, 153, 25, 153, 180, 81, 28, 153, 55, 153, 66, 153, 93, 153, 98, 153, 112, 75, 197, 153, 157, 75, 60, 154, 15, 155, 131, 122, 105, 155, 129, 155, 221, 155, 241, 155, 244, 155, 109, 76, 32, 156, 111, 55, 194, 27, 73, 157, 58, 156, 254, 158, 80, 86, 147, 157, 189, 157, 192, 157, 252, 157, 246, 148, 182, 143, 123, 158, 172, 158, 177, 158, 189, 158, 198, 158, 220, 148, 226, 158, 241, 158, 248, 158, 200, 122, 68, 159, 148, 0, 183, 2, 160, 3, 26, 105, 195, 148, 172, 89, 215, 4, 64, 88, 193, 148, 185, 55, 213, 5, 21, 6, 118, 6, 186, 22, 87, 87, 115, 113, 194, 10, 205, 10, 191, 11, 106, 84, 59, 248, 203, 11, 158, 84, 251, 11, 59, 12, 83, 12, 101, 12, 124, 12, 231, 96, 141, 12, 122, 86, 181, 12, 221, 12, 237, 12, 111, 13, 178, 13, 200, 13, 85, 105, 47, 156, 165, 135, 4, 14, 14, 14, 215, 14, 144, 15, 45, 15, 115, 14, 32, 92, 188, 15, 11, 94, 92, 16, 79, 16, 118, 16, 30, 103, 123, 16, 136, 16, 150, 16, 71, 54, 191, 16, 211, 16, 47, 17, 59, 17, 100, 83, 173, 132, 227, 18, 117, 19, 54, 19, 129, 139, 119, 21, 25, 22, 195, 23, 199, 23, 120, 78, 187, 112, 45, 24, 106, 25, 45, 26, 69, 26, 42, 28, 112, 28, 172, 28, 200, 30, 195, 98, 213, 30, 21, 31, 152, 113, 85, 104, 69, 32, 233, 105, 200, 54, 124, 34, 215, 35, 250, 35, 42, 39, 113, 40, 79, 41, 253, 130, 103, 41, 147, 41, 213, 42, 165, 137, 232, 42, 160, 143, 14, 43, 184, 151, 63, 43, 71, 152, 189, 154, 76, 44, 0, 0, 136, 44, 183, 44, 232, 91, 8, 45, 18, 45, 183, 45, 149, 45, 66, 46, 116, 47, 204, 47, 51, 48, 102, 48, 31, 51, 222, 51, 177, 95, 72, 102, 191, 102, 121, 122, 103, 53, 243, 53, 0, 0, 186, 73, 0, 0, 26, 54, 22, 55, 0, 0, 70, 3, 181, 88, 14, 103, 24, 105, 167, 58, 87, 118, 226, 95, 17, 62, 185, 62, 254, 117, 154, 32, 208, 72, 184, 74, 25, 65, 154, 138, 238, 66, 13, 67, 59, 64, 52, 67, 150, 67, 69, 74, 202, 5, 210, 81, 17, 6, 159, 89, 168, 30, 190, 59, 255, 60, 4, 68, 214, 68, 136, 87, 116, 70, 155, 57, 47, 71, 232, 133, 201, 153, 98, 55, 195, 33, 94, 139, 78, 139, 0, 0, 18, 72, 251, 72, 21, 74, 9, 114, 192, 74, 120, 12, 101, 89, 165, 78, 134, 79, 121, 7, 218, 142, 44, 80, 143, 82, 63, 87, 113, 113, 153, 82, 25, 84, 74, 63, 167, 74, 188, 85, 70, 84, 110, 84, 82, 107, 0, 0, 115, 52, 63, 85, 50, 118, 94, 85, 24, 71, 98, 85, 102, 85, 199, 87, 63, 73, 93, 88, 102, 80, 251, 52, 204, 51, 0, 0, 3, 89, 124, 71, 72, 137, 174, 90, 137, 91, 6, 92, 144, 29, 161, 87, 81, 113, 0, 0, 2, 97, 18, 124, 86, 144, 178, 97, 154, 79, 98, 139, 2, 100, 74, 100, 91, 93, 247, 107, 0, 0, 132, 100, 28, 25, 234, 138, 246, 73, 136, 100, 239, 63, 18, 101, 192, 75, 191, 101, 181, 102, 27, 39, 101, 148, 225, 87, 149, 97, 39, 90, 205, 248, 0, 0, 185, 86, 33, 69, 252, 102, 106, 78, 52, 73, 86, 150, 143, 109, 189, 108, 24, 54, 119, 137, 153, 103, 110, 104, 17, 100, 94, 104, 0, 0, 199, 104, 66, 123, 192, 144, 17, 10, 38, 105, 0, 0, 57, 105, 69, 122, 0, 0, 250, 105, 38, 154, 45, 106, 95, 54, 105, 100, 33, 0, 131, 121, 52, 106, 91, 107, 44, 93, 25, 53, 0, 0, 157, 107, 208, 70, 164, 108, 59, 117, 101, 136, 174, 109, 182, 88, 28, 55, 141, 37, 75, 112, 205, 113, 84, 60, 128, 114, 133, 114, 129, 146, 122, 33, 139, 114, 48, 147, 230, 114, 208, 73, 57, 108, 159, 148, 80, 116, 248, 14, 39, 136, 245, 136, 38, 41, 115, 132, 177, 23, 184, 110, 42, 74, 32, 24, 164, 57, 185, 54, 0, 0, 0, 0, 63, 69, 182, 102, 173, 156, 164, 152, 67, 137, 204, 119, 88, 120, 214, 86, 223, 64, 10, 22, 161, 57, 47, 55, 232, 128, 197, 19, 173, 113, 102, 131, 221, 121, 168, 145, 0, 0, 183, 76, 175, 112, 171, 137, 253, 121, 10, 122, 11, 123, 102, 125, 122, 65, 67, 123, 126, 121, 9, 128, 181, 111, 223, 162, 3, 106, 24, 131, 162, 83, 7, 110, 191, 147, 54, 104, 93, 151, 111, 129, 35, 128, 181, 105, 237, 19, 47, 50, 72, 128, 133, 93, 48, 140, 131, 128, 21, 87, 35, 152, 73, 137, 171, 93, 136, 73, 190, 101, 213, 105, 210, 83, 165, 74, 129, 63, 17, 60, 54, 103, 144, 128, 244, 128, 46, 129, 161, 31, 79, 129, 137, 129, 175, 129, 26, 130, 6, 131, 47, 131, 138, 131, 202, 53, 104, 132, 170, 134, 250, 72, 230, 99, 86, 137, 8, 120, 85, 146, 184, 137, 242, 67, 231, 137, 223, 67, 232, 137, 70, 139, 212, 139, 248, 89, 9, 140, 0, 0, 197, 143, 236, 144, 0, 0, 16, 145, 60, 145, 247, 61, 94, 145, 202, 74, 208, 143, 143, 114, 139, 86, 231, 148, 233, 149, 176, 149, 184, 149, 50, 151, 209, 152, 73, 153, 106, 153, 195, 153, 40, 154, 14, 155, 90, 157, 155, 157, 159, 126, 248, 158, 35, 159, 164, 76, 71, 149, 147, 162, 162, 113, 255, 162, 145, 77, 18, 144, 203, 165, 156, 77, 156, 12, 190, 143, 193, 85, 186, 143, 176, 36, 185, 143, 147, 74, 9, 69, 127, 126, 86, 111, 177, 106, 234, 78, 228, 52, 44, 139, 157, 120, 58, 55, 128, 142, 245, 23, 36, 128, 108, 139, 153, 139, 62, 122, 175, 102, 235, 61, 85, 118, 183, 60, 53, 86, 86, 89, 154, 78, 129, 94, 88, 98, 191, 86, 109, 14, 14, 142, 109, 91, 136, 62, 158, 76, 222, 99, 0, 0, 246, 23, 123, 24, 48, 101, 45, 86, 74, 92, 26, 84, 17, 83, 198, 61, 152, 157, 125, 76, 34, 86, 30, 86, 73, 127, 216, 94, 117, 89, 64, 61, 112, 135, 28, 78, 234, 15, 73, 13, 186, 54, 23, 129, 94, 157, 24, 141, 59, 118, 69, 156, 78, 118, 185, 119, 69, 147, 50, 84, 72, 129, 247, 130, 37, 86, 50, 129, 24, 132, 189, 128, 234, 85, 98, 121, 67, 86, 22, 84, 157, 14, 206, 53, 5, 86, 241, 85, 241, 102, 226, 130, 45, 54, 52, 117, 240, 85, 186, 85, 151, 84, 114, 85, 65, 12, 150, 12, 208, 94, 72, 81, 118, 14, 98, 44, 162, 14, 171, 158, 90, 125, 222, 85, 117, 16, 157, 98, 109, 151, 148, 84, 205, 140, 246, 113, 118, 145, 252, 99, 185, 99, 254, 99, 105, 85, 67, 43, 114, 156, 179, 46, 154, 81, 223, 52, 167, 13, 167, 81, 77, 84, 30, 85, 19, 85, 102, 118, 45, 142, 138, 104, 177, 117, 182, 128, 4, 136, 134, 135, 199, 136, 182, 129, 28, 132, 193, 16, 236, 68, 4, 115, 6, 71, 144, 91, 11, 131, 147, 104, 123, 86, 244, 38, 47, 125, 163, 65, 115, 125, 208, 110, 182, 114, 112, 145, 217, 17, 8, 146, 252, 60, 169, 166, 172, 14, 249, 14, 102, 114, 162, 28, 78, 71, 194, 79, 249, 127, 235, 15, 250, 64, 93, 156, 31, 101, 160, 45, 243, 72, 224, 71, 124, 157, 236, 15, 10, 14, 0, 0, 163, 117, 237, 15, 0, 0, 72, 96, 135, 17, 163, 113, 142, 126, 80, 157, 26, 78, 4, 78, 119, 53, 13, 91, 178, 108, 103, 83, 172, 54, 220, 57, 125, 83, 165, 54, 24, 70, 154, 88, 110, 75, 45, 130, 75, 84, 170, 87, 149, 90, 121, 9, 0, 0, 82, 58, 101, 36, 116, 115, 172, 158, 9, 77, 237, 155, 254, 60, 48, 159, 91, 76, 169, 79, 158, 149, 222, 159, 92, 132, 182, 61, 178, 114, 179, 103, 32, 55, 46, 99, 37, 125, 247, 62, 44, 62, 42, 58, 8, 144, 204, 82, 116, 62, 122, 54, 233, 69, 142, 4, 64, 118, 240, 90, 182, 14, 122, 120, 46, 127, 167, 88, 191, 64, 124, 86, 139, 155, 116, 93, 84, 118, 52, 164, 133, 158, 225, 76, 0, 0, 251, 55, 25, 97, 218, 48, 242, 67, 0, 0, 93, 86, 169, 18, 167, 87, 99, 73, 6, 158, 52, 82, 174, 112, 173, 53, 0, 0, 124, 157, 86, 124, 57, 155, 222, 87, 108, 23, 83, 92, 211, 100, 208, 148, 53, 99, 100, 113, 173, 134, 40, 13, 34, 109, 226, 74, 113, 13, 0, 0, 254, 81, 15, 31, 142, 93, 3, 151, 209, 29, 129, 158, 76, 144, 31, 123, 2, 155, 209, 92, 163, 123, 104, 98, 53, 99, 255, 154, 207, 123, 42, 155, 126, 124, 0, 0, 66, 124, 134, 124, 21, 156, 252, 123, 9, 155, 0, 0, 27, 156, 62, 73, 90, 159, 115, 85, 195, 91, 253, 79, 152, 158, 242, 79, 96, 82, 6, 62, 209, 82, 103, 87, 86, 80, 183, 89, 18, 94, 200, 151, 171, 157, 92, 143, 105, 84, 180, 151, 64, 153, 186, 151, 44, 83, 48, 97, 44, 105, 218, 83, 10, 156, 2, 157, 59, 76, 65, 150, 128, 105, 166, 80, 70, 117, 109, 23, 218, 153, 115, 82, 0, 0, 89, 145, 129, 150, 92, 145, 0, 0, 81, 145, 151, 142, 127, 99, 35, 109, 202, 106, 17, 86, 142, 145, 122, 117, 133, 98, 252, 3, 79, 115, 112, 124, 33, 92, 253, 60, 0, 0, 25, 73, 214, 118, 157, 155, 42, 78, 212, 12, 190, 131, 66, 136, 0, 0, 74, 92, 192, 105, 0, 0, 122, 87, 31, 82, 245, 93, 206, 78, 49, 108, 242, 1, 57, 79, 156, 84, 218, 84, 154, 82, 130, 141, 254, 53, 0, 0, 243, 53, 0, 0, 82, 107, 124, 145, 165, 159, 151, 155, 46, 152, 180, 152, 186, 154, 168, 158, 132, 158, 122, 113, 20, 123, 0, 0, 250, 107, 24, 136, 120, 127, 0, 0, 32, 86, 74, 166, 119, 142, 83, 159, 0, 0, 212, 141, 79, 142, 28, 158, 1, 142, 130, 98, 125, 131, 40, 142, 117, 142, 211, 122, 119, 74, 62, 122, 216, 120, 234, 108, 103, 138, 7, 118, 90, 138, 38, 159, 206, 108, 214, 135, 195, 117, 178, 162, 83, 120, 64, 248, 12, 141, 226, 114, 113, 115, 45, 139, 2, 115, 241, 116, 235, 140, 187, 74, 47, 134, 186, 95, 160, 136, 183, 68, 0, 0, 59, 24, 5, 110, 0, 0, 126, 138, 27, 37, 0, 0, 253, 96, 103, 118, 215, 154, 68, 157, 110, 147, 143, 155, 245, 135, 0, 0, 0, 0, 247, 140, 44, 115, 33, 151, 176, 155, 214, 53, 178, 114, 7, 76, 81, 124, 74, 153, 89, 97, 89, 97, 4, 76, 150, 158, 125, 97, 0, 0, 95, 87, 111, 97, 166, 98, 57, 98, 0, 0, 92, 58, 226, 97, 170, 83, 245, 51, 100, 99, 2, 104, 210, 53, 87, 93, 194, 139, 218, 143, 57, 142, 0, 0, 217, 80, 70, 29, 6, 121, 50, 83, 56, 150, 59, 15, 101, 64, 0, 0, 254, 119, 0, 0, 194, 124, 26, 95, 218, 124, 45, 122, 102, 128, 99, 128, 77, 125, 5, 117, 242, 116, 148, 137, 26, 130, 12, 103, 98, 128, 134, 116, 91, 128, 240, 116, 3, 129, 36, 119, 137, 137, 204, 103, 83, 117, 209, 110, 169, 135, 206, 135, 200, 129, 140, 135, 73, 138, 173, 140, 67, 139, 43, 119, 248, 116, 218, 132, 53, 54, 178, 105, 166, 141, 0, 0, 169, 137, 0, 0, 185, 109, 193, 135, 17, 64, 231, 116, 219, 61, 118, 113, 164, 96, 156, 97, 209, 60, 0, 0, 119, 96, 0, 0, 113, 127, 45, 139, 0, 0, 233, 96, 126, 75, 32, 82, 24, 60, 199, 60, 215, 94, 86, 118, 49, 85, 68, 25, 254, 18, 3, 153, 220, 109, 173, 112, 193, 92, 173, 97, 15, 138, 119, 54, 238, 0, 70, 104, 14, 79, 98, 69, 31, 91, 76, 99, 80, 159, 166, 158, 107, 98, 71, 5, 219, 146, 223, 5, 197, 63, 76, 133, 181, 66, 239, 115, 181, 81, 73, 54, 66, 73, 228, 137, 68, 147, 219, 25, 238, 130, 200, 60, 60, 120, 68, 103, 223, 98, 51, 73, 170, 137, 160, 2, 179, 107, 5, 19, 171, 79, 237, 36, 8, 80, 41, 109, 132, 122, 0, 54, 177, 74, 19, 37, 0, 0, 126, 3, 164, 95, 128, 3, 71, 3, 219, 110, 31, 4, 0, 0, 1, 81, 122, 52, 14, 81, 108, 152, 67, 55, 22, 132, 164, 73, 135, 4, 96, 81, 180, 51, 106, 81, 255, 11, 252, 32, 229, 2, 48, 37, 142, 5, 51, 50, 131, 25, 130, 91, 125, 135, 179, 5, 153, 60, 178, 81, 184, 81, 52, 157, 201, 81, 207, 81, 209, 81, 220, 60, 211, 81, 166, 74, 179, 81, 226, 81, 66, 83, 237, 81, 205, 131, 62, 105, 45, 55, 123, 95, 11, 82, 38, 82, 60, 82, 181, 82, 87, 82, 148, 82, 185, 82, 197, 82, 21, 124, 66, 133, 224, 82, 13, 134, 19, 107, 0, 0, 222, 138, 73, 85, 217, 110, 128, 63, 84, 9, 236, 63, 51, 83, 0, 0, 226, 11, 203, 108, 38, 23, 27, 104, 213, 115, 74, 96, 170, 62, 204, 56, 232, 22, 221, 113, 162, 68, 109, 83, 116, 83, 171, 134, 126, 83, 0, 0, 150, 21, 19, 22, 230, 119, 147, 83, 155, 138, 160, 83, 171, 83, 174, 83, 167, 115, 114, 87, 89, 63, 156, 115, 193, 83, 197, 83, 73, 108, 73, 78, 254, 87, 217, 83, 171, 58, 143, 11, 224, 83, 235, 63, 163, 45, 246, 83, 119, 12, 19, 84, 121, 112, 43, 85, 87, 102, 91, 109, 109, 84, 83, 107, 116, 13, 93, 85, 143, 84, 164, 84, 166, 71, 13, 23, 221, 14, 180, 61, 77, 13, 188, 137, 152, 38, 71, 85, 237, 76, 47, 84, 23, 116, 134, 85, 169, 85, 0, 0, 215, 24, 58, 64, 82, 69, 53, 68, 179, 102, 180, 16, 55, 86, 205, 102, 138, 50, 164, 102, 173, 102, 77, 86, 79, 86, 241, 120, 241, 86, 135, 151, 254, 83, 0, 87, 239, 86, 237, 86, 102, 139, 35, 54, 79, 18, 70, 87, 165, 65, 110, 108, 139, 112, 66, 87, 177, 54, 126, 108, 230, 87, 22, 20, 3, 88, 84, 20, 99, 67, 38, 88, 245, 75, 92, 88, 170, 88, 97, 53, 224, 88, 220, 88, 60, 18, 251, 88, 255, 91, 67, 87, 80, 161, 120, 66, 211, 147, 161, 53, 31, 89, 166, 104, 195, 54, 89, 110, 62, 22, 36, 90, 83, 85, 146, 22, 5, 133, 201, 89, 78, 13, 129, 108, 42, 109, 220, 23, 217, 89, 251, 23, 178, 23, 166, 109, 113, 109, 40, 24, 213, 22, 249, 89, 69, 110, 171, 90, 99, 90, 230, 54, 169, 73, 0, 0, 8, 55, 150, 90, 101, 116, 211, 90, 161, 111, 84, 37, 133, 61, 17, 25, 50, 55, 184, 22, 131, 94, 208, 82, 118, 91, 136, 101, 124, 91, 14, 122, 4, 64, 93, 72, 4, 2, 213, 91, 96, 97, 52, 26, 204, 89, 165, 5, 243, 91, 157, 91, 16, 77, 5, 92, 68, 27, 19, 92, 206, 115, 20, 92, 165, 28, 40, 107, 73, 92, 221, 72, 133, 92, 233, 92, 239, 92, 139, 93, 249, 29, 55, 30, 16, 93, 24, 93, 70, 93, 164, 30, 186, 92, 215, 93, 252, 130, 45, 56, 1, 73, 73, 32, 115, 33, 135, 130, 54, 56, 194, 59, 46, 94, 138, 106, 0, 0, 122, 94, 188, 68, 211, 12, 166, 83, 183, 78, 0, 0, 168, 83, 113, 23, 9, 94, 244, 94, 130, 132, 249, 94, 251, 94, 160, 56, 252, 94, 62, 104, 27, 148, 13, 95, 193, 1, 148, 248, 222, 58, 174, 72, 58, 19, 58, 95, 136, 104, 208, 35, 0, 0, 113, 36, 99, 95, 189, 151, 110, 110, 114, 95, 64, 147, 54, 138, 167, 95, 182, 93, 95, 61, 80, 82, 106, 31, 248, 112, 104, 38, 214, 145, 158, 2, 41, 138, 49, 96, 133, 102, 119, 24, 99, 57, 199, 61, 57, 54, 144, 87, 180, 39, 113, 121, 64, 62, 158, 96, 0, 0, 179, 96, 130, 73, 143, 73, 83, 122, 164, 116, 225, 80, 160, 90, 100, 97, 36, 132, 66, 97, 166, 248, 210, 110, 129, 97, 244, 81, 86, 6, 135, 97, 170, 91, 183, 63, 95, 40, 211, 97, 157, 139, 93, 153, 208, 97, 50, 57, 128, 41, 193, 40, 35, 96, 92, 97, 30, 101, 139, 99, 24, 1, 197, 98, 112, 23, 213, 98, 13, 46, 108, 99, 223, 73, 23, 58, 56, 100, 248, 99, 142, 19, 252, 23, 0, 0, 138, 111, 54, 46, 20, 152, 140, 64, 29, 87, 225, 100, 229, 100, 123, 148, 102, 58, 58, 100, 87, 58, 77, 101, 22, 111, 40, 74, 35, 74, 133, 101, 109, 101, 95, 101, 126, 48, 181, 101, 64, 73, 55, 75, 209, 101, 216, 64, 41, 24, 224, 101, 227, 101, 223, 95, 0, 52, 24, 102, 247, 49, 248, 49, 68, 102, 164, 49, 165, 49, 75, 102, 117, 14, 103, 102, 230, 81, 115, 102, 0, 0, 61, 30, 49, 50, 244, 133, 200, 49, 19, 83, 197, 119, 247, 40, 164, 153, 2, 103, 156, 67, 33, 74, 43, 59, 250, 105, 194, 55, 0, 0, 103, 103, 98, 103, 205, 65, 237, 144, 215, 103, 233, 68, 34, 104, 80, 110, 60, 146, 1, 104, 230, 51, 160, 109, 93, 104, 111, 52, 225, 105, 11, 106, 223, 138, 115, 105, 195, 104, 205, 53, 1, 105, 0, 105, 50, 61, 1, 58, 60, 54, 128, 59, 172, 103, 97, 105, 74, 138, 252, 66, 54, 105, 152, 105, 161, 59, 201, 3, 99, 131, 144, 80, 249, 105, 89, 54, 42, 33, 69, 106, 3, 55, 157, 106, 243, 59, 177, 103, 200, 106, 156, 145, 13, 60, 29, 107, 35, 9, 222, 96, 53, 107, 116, 107, 205, 39, 181, 110, 219, 58, 181, 3, 88, 25, 64, 55, 33, 84, 90, 59, 225, 107, 252, 62, 220, 107, 55, 108, 139, 36, 241, 72, 81, 107, 90, 108, 38, 130, 121, 108, 188, 61, 197, 68, 189, 61, 164, 65, 12, 73, 0, 73, 201, 60, 229, 54, 235, 60, 50, 13, 131, 155, 249, 49, 145, 36, 143, 127, 55, 104, 37, 109, 161, 109, 235, 109, 150, 109, 92, 109, 124, 110, 4, 111, 127, 73, 133, 64, 114, 110, 51, 133, 116, 111, 199, 81, 0, 0, 0, 0, 46, 132, 33, 139, 0, 0, 47, 62, 83, 116, 130, 63, 204, 121, 79, 110, 145, 90, 75, 48, 248, 111, 13, 55, 157, 111, 48, 62, 250, 110, 151, 20, 61, 64, 85, 69, 240, 147, 68, 111, 92, 111, 78, 61, 116, 111, 112, 145, 59, 61, 159, 111, 68, 65, 211, 111, 145, 64, 85, 65, 57, 64, 240, 63, 180, 63, 63, 65, 223, 81, 86, 65, 87, 65, 64, 65, 221, 97, 75, 112, 126, 112, 167, 112, 129, 112, 204, 112, 213, 112, 214, 112, 223, 112, 4, 65, 232, 61, 180, 113, 150, 113, 119, 66, 43, 113, 69, 113, 136, 90, 74, 113, 0, 0, 156, 92, 101, 67, 79, 113, 98, 147, 193, 66, 44, 113, 90, 68, 39, 74, 34, 74, 186, 113, 232, 139, 189, 112, 14, 114, 66, 148, 21, 114, 17, 89, 67, 148, 36, 114, 65, 147, 5, 86, 46, 114, 64, 114, 116, 73, 189, 104, 85, 114, 87, 114, 85, 62, 68, 48, 13, 104, 61, 111, 130, 114, 0, 0, 43, 115, 35, 72, 43, 136, 237, 72, 4, 136, 40, 115, 46, 115, 207, 115, 170, 115, 58, 12, 46, 106, 201, 115, 73, 116, 226, 65, 231, 22, 36, 74, 35, 102, 197, 54, 183, 73, 141, 73, 251, 73, 247, 115, 21, 116, 3, 105, 38, 74, 57, 116, 195, 5, 215, 62, 0, 0, 173, 40, 96, 116, 178, 142, 71, 116, 228, 115, 118, 116, 185, 131, 108, 116, 48, 55, 116, 116, 241, 147, 44, 106, 130, 116, 83, 73, 140, 74, 95, 65, 121, 74, 143, 139, 70, 91, 3, 140, 158, 24, 200, 116, 136, 25, 14, 117, 0, 0, 30, 117, 217, 142, 75, 26, 215, 91, 172, 142, 133, 147, 77, 117, 74, 117, 103, 117, 110, 117, 130, 79, 4, 63, 19, 77, 142, 117, 93, 116, 158, 117, 180, 117, 2, 118, 44, 118, 81, 118, 79, 118, 111, 118, 118, 118, 245, 99, 144, 118, 239, 129, 248, 55, 17, 105, 14, 105, 161, 118, 165, 118, 183, 118, 204, 118, 159, 111, 98, 132, 157, 80, 125, 81, 28, 30, 30, 119, 38, 119, 64, 119, 175, 100, 32, 82, 88, 119, 172, 50, 175, 119, 100, 137, 104, 137, 193, 22, 244, 119, 0, 0, 118, 19, 18, 74, 202, 104, 175, 120, 199, 120, 211, 120, 165, 150, 46, 121, 224, 85, 215, 120, 52, 121, 177, 120, 12, 118, 184, 143, 132, 136, 43, 139, 131, 96, 28, 38, 134, 121, 0, 137, 2, 105, 128, 121, 87, 88, 157, 121, 57, 123, 60, 121, 169, 121, 42, 110, 38, 113, 168, 62, 198, 121, 13, 145, 212, 121, 32, 5, 95, 68, 15, 82, 130, 184, 248, 0, 0, 64, 32, 169, 78, 4, 0, 0, 0, 0, 52, 11, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12, 64, 0, 0, 0, 0, 0, 0, 0, 0, 4, 88, 0, 60, 0, 0, 0, 0, 0, 128, 92, 173, 220, 243, 187, 201, 67, 238, 237, 164, 15, 38, 193, 155, 118, 242, 239, 222, 251, 250, 247, 15, 50, 68, 175, 254, 239, 253, 254, 17, 96, 176, 0, 0, 33, 25, 129, 32, 16, 136, 168, 96, 33, 105, 36, 0, 68, 137, 196, 0, 0, 3, 64, 53, 0, 67, 132, 49, 81, 147, 104, 2, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 64, 0, 1, 128, 172, 100, 130, 64, 140, 161, 144, 4, 80, 96, 212, 0, 210, 42, 24, 157, 104, 53, 151, 79, 216, 248, 32, 196, 130, 28, 40, 130, 117, 148, 2, 56, 64, 160, 161, 197, 16, 113, 77, 196, 13, 152, 185, 94, 91, 1, 67, 159, 153, 3, 120, 32, 226, 31, 8, 137, 1, 201, 64, 7, 3, 13, 154, 144, 82, 209, 79, 124, 3, 2, 33, 32, 192, 110, 19, 131, 181, 219, 245, 229, 119, 144, 79, 23, 154, 54, 23, 12, 0, 110, 186, 9, 47, 96, 84, 0, 30, 120, 104, 34, 112, 86, 158, 37, 243, 142, 183, 23, 11, 239, 230, 119, 23, 91, 27, 193, 16, 152, 141, 18, 24, 182, 207, 1, 49, 114, 26, 91, 44, 182, 192, 32, 226, 195, 92, 130, 27, 224, 218, 206, 133, 214, 64, 169, 84, 11, 208, 15, 72, 68, 64, 16, 9, 212, 64, 174, 59, 100, 30, 68, 43, 23, 8, 134, 130, 54, 24, 160, 137, 231, 156, 91, 8, 132, 3, 2, 218, 144, 236, 219, 135, 133, 191, 162, 173, 157, 142, 157, 152, 32, 37, 70, 0, 70, 159, 127, 227, 213, 201, 132, 244, 214, 77, 6, 227, 182, 24, 18, 9, 0, 0, 0, 4, 0, 0, 32, 0, 0, 0, 0, 2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 32, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 8, 0, 0, 142, 120, 110, 95, 63, 126, 221, 61, 247, 252, 155, 252, 174, 210, 255, 143, 107, 241, 231, 191, 186, 174, 110, 23, 239, 220, 167, 62, 182, 181, 119, 201, 146, 215, 165, 182, 74, 110, 155, 185, 129, 77, 103, 254, 84, 241, 155, 98, 254, 111, 82, 215, 54, 254, 191, 41, 69, 129, 249, 189, 101, 166, 66, 57, 0, 0, 66, 96, 143, 0, 148, 64, 64, 210, 175, 215, 209, 219, 0, 160, 152, 178, 123, 6, 82, 32, 152, 22, 200, 61, 9, 0, 0, 1, 0, 0, 0, 1, 10, 178, 8, 128, 0, 0, 0, 4, 136, 32, 20, 16, 76, 0, 0, 4, 0, 161, 68, 16, 0, 65, 1, 0, 8, 64, 240, 223, 79, 54, 88, 241, 245, 181, 128, 245, 103, 128, 64, 0, 80, 78, 65, 200, 132, 0, 90, 96, 216, 1, 43, 1, 80, 161, 22, 196, 64, 242, 110, 17, 172, 32, 57, 196, 192, 8, 7, 12, 9, 152, 150, 196, 155, 16, 28, 152, 108, 134, 42, 166, 1, 70, 17, 109, 229, 203, 196, 192, 146, 16, 33, 22, 18, 157, 114, 244, 105, 14, 23, 42, 162, 129, 244, 123, 0, 8, 164, 11, 144, 16, 44, 204, 57, 74, 1, 240, 22, 11, 10, 64, 12, 29, 234, 12, 68, 14, 69, 2, 0, 8, 4, 4, 8, 4, 4, 8, 2, 4, 0, 0, 0, 0, 0, 0, 0, 195, 138, 204, 132, 195, 138, 204, 140, 195, 170, 204, 132, 195, 170, 204, 140, 0, 0, 0, 0, 0, 0, 0, 0, 0, 48, 12, 255, 1, 48, 2, 48, 14, 255, 39, 32, 27, 255, 26, 255, 31, 255, 1, 255, 48, 254, 38, 32, 37, 32, 80, 254, 81, 254, 82, 254, 183, 0, 84, 254, 85, 254, 86, 254, 87, 254, 92, 255, 19, 32, 49, 254, 20, 32, 51, 254, 116, 37, 52, 254, 79, 254, 8, 255, 9, 255, 53, 254, 54, 254, 91, 255, 93, 255, 55, 254, 56, 254, 20, 48, 21, 48, 57, 254, 58, 254, 16, 48, 17, 48, 59, 254, 60, 254, 10, 48, 11, 48, 61, 254, 62, 254, 8, 48, 9, 48, 63, 254, 64, 254, 12, 48, 13, 48, 65, 254, 66, 254, 14, 48, 15, 48, 67, 254, 68, 254, 89, 254, 90, 254, 91, 254, 92, 254, 93, 254, 94, 254, 24, 32, 25, 32, 28, 32, 29, 32, 29, 48, 30, 48, 53, 32, 50, 32, 3, 255, 6, 255, 10, 255, 59, 32, 167, 0, 3, 48, 203, 37, 207, 37, 179, 37, 178, 37, 206, 37, 6, 38, 5, 38, 199, 37, 198, 37, 161, 37, 160, 37, 189, 37, 188, 37, 163, 50, 5, 33, 175, 0, 227, 255, 63, 255, 205, 2, 73, 254, 74, 254, 77, 254, 78, 254, 75, 254, 76, 254, 95, 254, 96, 254, 97, 254, 11, 255, 13, 255, 215, 0, 247, 0, 177, 0, 26, 34, 28, 255, 30, 255, 29, 255, 102, 34, 103, 34, 96, 34, 30, 34, 82, 34, 97, 34, 98, 254, 99, 254, 100, 254, 101, 254, 102, 254, 94, 255, 41, 34, 42, 34, 165, 34, 32, 34, 31, 34, 191, 34, 210, 51, 209, 51, 43, 34, 46, 34, 53, 34, 52, 34, 64, 38, 66, 38, 149, 34, 153, 34, 145, 33, 147, 33, 144, 33, 146, 33, 150, 33, 151, 33, 153, 33, 152, 33, 37, 34, 35, 34, 15, 255, 60, 255, 21, 34, 104, 254, 4, 255, 229, 255, 18, 48, 224, 255, 225, 255, 5, 255, 32, 255, 3, 33, 9, 33, 105, 254, 106, 254, 107, 254, 213, 51, 156, 51, 157, 51, 158, 51, 206, 51, 161, 51, 142, 51, 143, 51, 196, 51, 176, 0, 89, 81, 91, 81, 94, 81, 93, 81, 97, 81, 99, 81, 231, 85, 233, 116, 206, 124, 129, 37, 130, 37, 131, 37, 132, 37, 133, 37, 134, 37, 135, 37, 136, 37, 143, 37, 142, 37, 141, 37, 140, 37, 139, 37, 138, 37, 137, 37, 60, 37, 52, 37, 44, 37, 36, 37, 28, 37, 148, 37, 0, 37, 2, 37, 149, 37, 12, 37, 16, 37, 20, 37, 24, 37, 109, 37, 110, 37, 112, 37, 111, 37, 80, 37, 94, 37, 106, 37, 97, 37, 226, 37, 227, 37, 229, 37, 228, 37, 113, 37, 114, 37, 115, 37, 16, 255, 17, 255, 18, 255, 19, 255, 20, 255, 21, 255, 22, 255, 23, 255], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 271588);
	        allocate([24, 255, 25, 255, 96, 33, 97, 33, 98, 33, 99, 33, 100, 33, 101, 33, 102, 33, 103, 33, 104, 33, 105, 33, 33, 48, 34, 48, 35, 48, 36, 48, 37, 48, 38, 48, 39, 48, 40, 48, 41, 48, 65, 83, 68, 83, 69, 83, 33, 255, 34, 255, 35, 255, 36, 255, 37, 255, 38, 255, 39, 255, 40, 255, 41, 255, 42, 255, 43, 255, 44, 255, 45, 255, 46, 255, 47, 255, 48, 255, 49, 255, 50, 255, 51, 255, 52, 255, 53, 255, 54, 255, 55, 255, 56, 255, 57, 255, 58, 255, 65, 255, 66, 255, 67, 255, 68, 255, 69, 255, 70, 255, 71, 255, 72, 255, 73, 255, 74, 255, 75, 255, 76, 255, 77, 255, 78, 255, 79, 255, 80, 255, 81, 255, 82, 255, 83, 255, 84, 255, 85, 255, 86, 255, 87, 255, 88, 255, 89, 255, 90, 255, 145, 3, 146, 3, 147, 3, 148, 3, 149, 3, 150, 3, 151, 3, 152, 3, 153, 3, 154, 3, 155, 3, 156, 3, 157, 3, 158, 3, 159, 3, 160, 3, 161, 3, 163, 3, 164, 3, 165, 3, 166, 3, 167, 3, 168, 3, 169, 3, 177, 3, 178, 3, 179, 3, 180, 3, 181, 3, 182, 3, 183, 3, 184, 3, 185, 3, 186, 3, 187, 3, 188, 3, 189, 3, 190, 3, 191, 3, 192, 3, 193, 3, 195, 3, 196, 3, 197, 3, 198, 3, 199, 3, 200, 3, 201, 3, 5, 49, 6, 49, 7, 49, 8, 49, 9, 49, 10, 49, 11, 49, 12, 49, 13, 49, 14, 49, 15, 49, 16, 49, 17, 49, 18, 49, 19, 49, 20, 49, 21, 49, 22, 49, 23, 49, 24, 49, 25, 49, 26, 49, 27, 49, 28, 49, 29, 49, 30, 49, 31, 49, 32, 49, 33, 49, 34, 49, 35, 49, 36, 49, 37, 49, 38, 49, 39, 49, 40, 49, 41, 49, 217, 2, 201, 2, 202, 2, 199, 2, 203, 2, 0, 36, 1, 36, 2, 36, 3, 36, 4, 36, 5, 36, 6, 36, 7, 36, 8, 36, 9, 36, 10, 36, 11, 36, 12, 36, 13, 36, 14, 36, 15, 36, 16, 36, 17, 36, 18, 36, 19, 36, 20, 36, 21, 36, 22, 36, 23, 36, 24, 36, 25, 36, 26, 36, 27, 36, 28, 36, 29, 36, 30, 36, 31, 36, 33, 36, 172, 32, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 78, 89, 78, 1, 78, 3, 78, 67, 78, 93, 78, 134, 78, 140, 78, 186, 78, 63, 81, 101, 81, 107, 81, 224, 81, 0, 82, 1, 82, 155, 82, 21, 83, 65, 83, 92, 83, 200, 83, 9, 78, 11, 78, 8, 78, 10, 78, 43, 78, 56, 78, 225, 81, 69, 78, 72, 78, 95, 78, 94, 78, 142, 78, 161, 78, 64, 81, 3, 82, 250, 82, 67, 83, 201, 83, 227, 83, 31, 87, 235, 88, 21, 89, 39, 89, 115, 89, 80, 91, 81, 91, 83, 91, 248, 91, 15, 92, 34, 92, 56, 92, 113, 92, 221, 93, 229, 93, 241, 93, 242, 93, 243, 93, 254, 93, 114, 94, 254, 94, 11, 95, 19, 95, 77, 98, 17, 78, 16, 78, 13, 78, 45, 78, 48, 78, 57, 78, 75, 78, 57, 92, 136, 78, 145, 78, 149, 78, 146, 78, 148, 78, 162, 78, 193, 78, 192, 78, 195, 78, 198, 78, 199, 78, 205, 78, 202, 78, 203, 78, 196, 78, 67, 81, 65, 81, 103, 81, 109, 81, 110, 81, 108, 81, 151, 81, 246, 81, 6, 82, 7, 82, 8, 82, 251, 82, 254, 82, 255, 82, 22, 83, 57, 83, 72, 83, 71, 83, 69, 83, 94, 83, 132, 83, 203, 83, 202, 83, 205, 83, 236, 88, 41, 89, 43, 89, 42, 89, 45, 89, 84, 91, 17, 92, 36, 92, 58, 92, 111, 92, 244, 93, 123, 94, 255, 94, 20, 95, 21, 95, 195, 95, 8, 98, 54, 98, 75, 98, 78, 98, 47, 101, 135, 101, 151, 101, 164, 101, 185, 101, 229, 101, 240, 102, 8, 103, 40, 103, 32, 107, 98, 107, 121, 107, 203, 107, 212, 107, 219, 107, 15, 108, 52, 108, 107, 112, 42, 114, 54, 114, 59, 114, 71, 114, 89, 114, 91, 114, 172, 114, 139, 115, 25, 78, 22, 78, 21, 78, 20, 78, 24, 78, 59, 78, 77, 78, 79, 78, 78, 78, 229, 78, 216, 78, 212, 78, 213, 78, 214, 78, 215, 78, 227, 78, 228, 78, 217, 78, 222, 78, 69, 81, 68, 81, 137, 81, 138, 81, 172, 81, 249, 81, 250, 81, 248, 81, 10, 82, 160, 82, 159, 82, 5, 83, 6, 83, 23, 83, 29, 83, 223, 78, 74, 83, 73, 83, 97, 83, 96, 83, 111, 83, 110, 83, 187, 83, 239, 83, 228, 83, 243, 83, 236, 83, 238, 83, 233, 83, 232, 83, 252, 83, 248, 83, 245, 83, 235, 83, 230, 83, 234, 83, 242, 83, 241, 83, 240, 83, 229, 83, 237, 83, 251, 83, 219, 86, 218, 86, 22, 89, 46, 89, 49, 89, 116, 89, 118, 89, 85, 91, 131, 91, 60, 92, 232, 93, 231, 93, 230, 93, 2, 94, 3, 94, 115, 94, 124, 94, 1, 95, 24, 95, 23, 95, 197, 95, 10, 98, 83, 98, 84, 98, 82, 98, 81, 98, 165, 101, 230, 101, 46, 103, 44, 103, 42, 103, 43, 103, 45, 103, 99, 107, 205, 107, 17, 108, 16, 108, 56, 108, 65, 108, 64, 108, 62, 108, 175, 114, 132, 115, 137, 115, 220, 116, 230, 116, 24, 117, 31, 117, 40, 117, 41, 117, 48, 117, 49, 117, 50, 117, 51, 117, 139, 117, 125, 118, 174, 118, 191, 118, 238, 118, 219, 119, 226, 119, 243, 119, 58, 121, 190, 121, 116, 122, 203, 122, 30, 78, 31, 78, 82, 78, 83, 78, 105, 78, 153, 78, 164, 78, 166, 78, 165, 78, 255, 78, 9, 79, 25, 79, 10, 79, 21, 79, 13, 79, 16, 79, 17, 79, 15, 79, 242, 78, 246, 78, 251, 78, 240, 78, 243, 78, 253, 78, 1, 79, 11, 79, 73, 81, 71, 81, 70, 81, 72, 81, 104, 81, 113, 81, 141, 81, 176, 81, 23, 82, 17, 82, 18, 82, 14, 82, 22, 82, 163, 82, 8, 83, 33, 83, 32, 83, 112, 83, 113, 83, 9, 84, 15, 84, 12, 84, 10, 84, 16, 84, 1, 84, 11, 84, 4, 84, 17, 84, 13, 84, 8, 84, 3, 84, 14, 84, 6, 84, 18, 84, 224, 86, 222, 86, 221, 86, 51, 87, 48, 87, 40, 87, 45, 87, 44, 87, 47, 87, 41, 87, 25, 89, 26, 89, 55, 89, 56, 89, 132, 89, 120, 89, 131, 89, 125, 89, 121, 89, 130, 89, 129, 89, 87, 91, 88, 91, 135, 91, 136, 91, 133, 91, 137, 91, 250, 91, 22, 92, 121, 92, 222, 93, 6, 94, 118, 94, 116, 94, 15, 95, 27, 95, 217, 95, 214, 95, 14, 98, 12, 98, 13, 98, 16, 98, 99, 98, 91, 98, 88, 98, 54, 101, 233, 101, 232, 101, 236, 101, 237, 101, 242, 102, 243, 102, 9, 103, 61, 103, 52, 103, 49, 103, 53, 103, 33, 107, 100, 107, 123, 107, 22, 108, 93, 108, 87, 108, 89, 108, 95, 108, 96, 108, 80, 108, 85, 108, 97, 108, 91, 108, 77, 108, 78, 108, 112, 112, 95, 114, 93, 114, 126, 118, 249, 122, 115, 124, 248, 124, 54, 127, 138, 127, 189, 127, 1, 128, 3, 128, 12, 128, 18, 128, 51, 128, 127, 128, 137, 128, 139, 128, 140, 128, 227, 129, 234, 129, 243, 129, 252, 129, 12, 130, 27, 130, 31, 130, 110, 130, 114, 130, 126, 130, 107, 134, 64, 136, 76, 136, 99, 136, 127, 137, 33, 150, 50, 78, 168, 78, 77, 79, 79, 79, 71, 79, 87, 79, 94, 79, 52, 79, 91, 79, 85, 79, 48, 79, 80, 79, 81, 79, 61, 79, 58, 79, 56, 79, 67, 79, 84, 79, 60, 79, 70, 79, 99, 79, 92, 79, 96, 79, 47, 79, 78, 79, 54, 79, 89, 79, 93, 79, 72, 79, 90, 79, 76, 81, 75, 81, 77, 81, 117, 81, 182, 81, 183, 81, 37, 82, 36, 82, 41, 82, 42, 82, 40, 82, 171, 82, 169, 82, 170, 82, 172, 82, 35, 83, 115, 83, 117, 83, 29, 84, 45, 84, 30, 84, 62, 84, 38, 84, 78, 84, 39, 84, 70, 84, 67, 84, 51, 84, 72, 84, 66, 84, 27, 84, 41, 84, 74, 84, 57, 84, 59, 84, 56, 84, 46, 84, 53, 84, 54, 84, 32, 84, 60, 84, 64, 84, 49, 84, 43, 84, 31, 84, 44, 84, 234, 86, 240, 86, 228, 86, 235, 86, 74, 87, 81, 87, 64, 87, 77, 87, 71, 87, 78, 87, 62, 87, 80, 87, 79, 87, 59, 87, 239, 88, 62, 89, 157, 89, 146, 89, 168, 89, 158, 89, 163, 89, 153, 89, 150, 89, 141, 89, 164, 89, 147, 89, 138, 89, 165, 89, 93, 91, 92, 91, 90, 91, 91, 91, 140, 91, 139, 91, 143, 91, 44, 92, 64, 92, 65, 92, 63, 92, 62, 92, 144, 92, 145, 92, 148, 92, 140, 92, 235, 93, 12, 94, 143, 94, 135, 94, 138, 94, 247, 94, 4, 95, 31, 95, 100, 95, 98, 95, 119, 95, 121, 95, 216, 95, 204, 95, 215, 95, 205, 95, 241, 95, 235, 95, 248, 95, 234, 95, 18, 98, 17, 98, 132, 98, 151, 98, 150, 98, 128, 98, 118, 98, 137, 98, 109, 98, 138, 98, 124, 98, 126, 98, 121, 98, 115, 98, 146, 98, 111, 98, 152, 98, 110, 98, 149, 98, 147, 98, 145, 98, 134, 98, 57, 101, 59, 101, 56, 101, 241, 101, 244, 102, 95, 103, 78, 103, 79, 103, 80, 103, 81, 103, 92, 103, 86, 103, 94, 103, 73, 103, 70, 103, 96, 103, 83, 103, 87, 103, 101, 107, 207, 107, 66, 108, 94, 108, 153, 108, 129, 108, 136, 108, 137, 108, 133, 108, 155, 108, 106, 108, 122, 108, 144, 108, 112, 108, 140, 108, 104, 108, 150, 108, 146, 108, 125, 108, 131, 108, 114, 108, 126, 108, 116, 108, 134, 108, 118, 108, 141, 108, 148, 108, 152, 108, 130, 108, 118, 112, 124, 112, 125, 112, 120, 112, 98, 114, 97, 114, 96, 114, 196, 114, 194, 114, 150, 115, 44, 117, 43, 117, 55, 117, 56, 117, 130, 118, 239, 118, 227, 119, 193, 121, 192, 121, 191, 121, 118, 122, 251, 124, 85, 127, 150, 128, 147, 128, 157, 128, 152, 128, 155, 128, 154, 128, 178, 128, 111, 130, 146, 130, 139, 130, 141, 130, 139, 137, 210, 137, 0, 138, 55, 140, 70, 140, 85, 140, 157, 140, 100, 141, 112, 141, 179, 141, 171, 142, 202, 142, 155, 143, 176, 143, 194, 143, 198, 143, 197, 143, 196, 143, 225, 93, 145, 144, 162, 144, 170, 144, 166, 144, 163, 144, 73, 145, 198, 145, 204, 145, 50, 150, 46, 150, 49, 150, 42, 150, 44, 150, 38, 78, 86, 78, 115, 78, 139, 78, 155, 78, 158, 78, 171, 78, 172, 78, 111, 79, 157, 79, 141, 79, 115, 79, 127, 79, 108, 79, 155, 79, 139, 79, 134, 79, 131, 79, 112, 79, 117, 79, 136, 79, 105, 79, 123, 79, 150, 79, 126, 79, 143, 79, 145, 79, 122, 79, 84, 81, 82, 81, 85, 81, 105, 81, 119, 81, 118, 81, 120, 81, 189, 81, 253, 81, 59, 82, 56, 82, 55, 82, 58, 82, 48, 82, 46, 82, 54, 82, 65, 82, 190, 82, 187, 82, 82, 83, 84, 83, 83, 83, 81, 83, 102, 83, 119, 83, 120, 83, 121, 83, 214, 83, 212, 83, 215, 83, 115, 84, 117, 84, 150, 84, 120, 84, 149, 84, 128, 84, 123, 84, 119, 84, 132, 84, 146, 84, 134, 84, 124, 84, 144, 84, 113, 84, 118, 84, 140, 84, 154, 84, 98, 84, 104, 84, 139, 84, 125, 84, 142, 84, 250, 86, 131, 87, 119, 87, 106, 87, 105, 87, 97, 87, 102, 87, 100, 87, 124, 87, 28, 89, 73, 89, 71, 89, 72, 89, 68, 89, 84, 89, 190, 89, 187, 89, 212, 89, 185, 89, 174, 89, 209, 89, 198, 89, 208, 89, 205, 89, 203, 89, 211, 89, 202, 89, 175, 89, 179, 89, 210, 89, 197, 89, 95, 91, 100, 91, 99, 91, 151, 91, 154, 91, 152, 91, 156, 91, 153, 91, 155, 91, 26, 92, 72, 92, 69, 92, 70, 92, 183, 92, 161, 92, 184, 92, 169, 92, 171, 92, 177, 92, 179, 92, 24, 94, 26, 94, 22, 94, 21, 94, 27, 94, 17, 94, 120, 94, 154, 94, 151, 94, 156, 94, 149, 94, 150, 94, 246, 94, 38, 95, 39, 95, 41, 95, 128, 95, 129, 95, 127, 95, 124, 95, 221, 95, 224, 95, 253, 95, 245, 95, 255, 95, 15, 96, 20, 96, 47, 96, 53, 96, 22, 96, 42, 96, 21, 96, 33, 96, 39, 96, 41, 96, 43, 96, 27, 96, 22, 98, 21, 98, 63, 98, 62, 98, 64, 98, 127, 98, 201, 98, 204, 98, 196, 98, 191, 98, 194, 98, 185, 98, 210, 98, 219, 98, 171, 98, 211, 98, 212, 98, 203, 98, 200, 98, 168, 98, 189, 98, 188, 98, 208, 98, 217, 98, 199, 98, 205, 98, 181, 98, 218, 98, 177, 98, 216, 98, 214, 98, 215, 98, 198, 98, 172, 98, 206, 98, 62, 101, 167, 101, 188, 101, 250, 101, 20, 102, 19, 102, 12, 102, 6, 102, 2, 102, 14, 102, 0, 102, 15, 102, 21, 102, 10, 102, 7, 102, 13, 103, 11, 103, 109, 103, 139, 103, 149, 103, 113, 103, 156, 103, 115, 103, 119, 103, 135, 103, 157, 103, 151, 103, 111, 103, 112, 103, 127, 103, 137, 103, 126, 103, 144, 103, 117, 103, 154, 103, 147, 103, 124, 103, 106, 103, 114, 103, 35, 107, 102, 107, 103, 107, 127, 107, 19, 108, 27, 108, 227, 108, 232, 108, 243, 108, 177, 108, 204, 108, 229, 108, 179, 108, 189, 108, 190, 108, 188, 108, 226, 108, 171, 108, 213, 108, 211, 108, 184, 108, 196, 108, 185, 108, 193, 108, 174, 108, 215, 108, 197, 108, 241, 108, 191, 108, 187, 108, 225, 108, 219, 108, 202, 108, 172, 108, 239, 108, 220, 108, 214, 108, 224, 108, 149, 112, 142, 112, 146, 112, 138, 112, 153, 112, 44, 114, 45, 114, 56, 114, 72, 114, 103, 114, 105, 114, 192, 114, 206, 114, 217, 114, 215, 114, 208, 114, 169, 115, 168, 115, 159, 115, 171, 115, 165, 115, 61, 117, 157, 117, 153, 117, 154, 117, 132, 118, 194, 118, 242, 118, 244, 118, 229, 119, 253, 119, 62, 121, 64, 121, 65, 121, 201, 121, 200, 121, 122, 122, 121, 122, 250, 122, 254, 124, 84, 127, 140, 127, 139, 127, 5, 128, 186, 128, 165, 128, 162, 128, 177, 128, 161, 128, 171, 128, 169, 128, 180, 128, 170, 128, 175, 128, 229, 129, 254, 129, 13, 130, 179, 130, 157, 130, 153, 130, 173, 130, 189, 130, 159, 130, 185, 130, 177, 130, 172, 130, 165, 130, 175, 130, 184, 130, 163, 130, 176, 130, 190, 130, 183, 130, 78, 134, 113, 134, 29, 82, 104, 136, 203, 142, 206, 143, 212, 143, 209, 143, 181, 144, 184, 144, 177, 144, 182, 144, 199, 145, 209, 145, 119, 149, 128, 149, 28, 150, 64, 150, 63, 150, 59, 150, 68, 150, 66, 150, 185, 150, 232, 150, 82, 151, 94, 151, 159, 78, 173, 78, 174, 78, 225, 79, 181, 79, 175, 79, 191, 79, 224, 79, 209, 79, 207, 79, 221, 79, 195, 79, 182, 79, 216, 79, 223, 79, 202, 79, 215, 79, 174, 79, 208, 79, 196, 79, 194, 79, 218, 79, 206, 79, 222, 79, 183, 79, 87, 81, 146, 81, 145, 81, 160, 81, 78, 82, 67, 82, 74, 82, 77, 82, 76, 82, 75, 82, 71, 82, 199, 82, 201, 82, 195, 82, 193, 82, 13, 83, 87, 83, 123, 83, 154, 83, 219, 83, 172, 84, 192, 84, 168, 84, 206, 84, 201, 84, 184, 84, 166, 84, 179, 84, 199, 84, 194, 84, 189, 84, 170, 84, 193, 84, 196, 84, 200, 84, 175, 84, 171, 84, 177, 84, 187, 84, 169, 84, 167, 84, 191, 84, 255, 86, 130, 87, 139, 87, 160, 87, 163, 87, 162, 87, 206, 87, 174, 87, 147, 87, 85, 89, 81, 89, 79, 89, 78, 89, 80, 89, 220, 89, 216, 89, 255, 89, 227, 89, 232, 89, 3, 90, 229, 89, 234, 89, 218, 89, 230, 89, 1, 90, 251, 89, 105, 91, 163, 91, 166, 91, 164, 91, 162, 91, 165, 91, 1, 92, 78, 92, 79, 92, 77, 92, 75, 92, 217, 92, 210, 92, 247, 93, 29, 94, 37, 94, 31, 94, 125, 94, 160, 94, 166, 94, 250, 94, 8, 95, 45, 95, 101, 95, 136, 95, 133, 95, 138, 95, 139, 95, 135, 95, 140, 95, 137, 95, 18, 96, 29, 96, 32, 96, 37, 96, 14, 96, 40, 96, 77, 96, 112, 96, 104, 96, 98, 96, 70, 96, 67, 96, 108, 96, 107, 96, 106, 96, 100, 96, 65, 98, 220, 98, 22, 99, 9, 99, 252, 98, 237, 98, 1, 99, 238, 98, 253, 98, 7, 99, 241, 98, 247, 98, 239, 98, 236, 98, 254, 98, 244, 98, 17, 99, 2, 99, 63, 101, 69, 101, 171, 101, 189, 101, 226, 101, 37, 102, 45, 102, 32, 102, 39, 102, 47, 102, 31, 102, 40, 102, 49, 102, 36, 102, 247, 102, 255, 103, 211, 103, 241, 103, 212, 103, 208, 103, 236, 103, 182, 103, 175, 103, 245, 103, 233, 103, 239, 103, 196, 103, 209, 103, 180, 103, 218, 103, 229, 103, 184, 103, 207, 103, 222, 103, 243, 103, 176, 103, 217, 103, 226, 103, 221, 103, 210, 103, 106, 107, 131, 107, 134, 107, 181, 107, 210, 107, 215, 107, 31, 108, 201, 108, 11, 109, 50, 109, 42, 109, 65, 109, 37, 109, 12, 109, 49, 109, 30, 109, 23, 109, 59, 109, 61, 109, 62, 109, 54, 109, 27, 109, 245, 108, 57, 109, 39, 109, 56, 109, 41, 109, 46, 109, 53, 109, 14, 109, 43, 109, 171, 112, 186, 112, 179, 112, 172, 112, 175, 112, 173, 112, 184, 112, 174, 112, 164, 112, 48, 114, 114, 114, 111, 114, 116, 114, 233, 114, 224, 114, 225, 114, 183, 115, 202, 115, 187, 115, 178, 115, 205, 115, 192, 115, 179, 115, 26, 117, 45, 117, 79, 117, 76, 117, 78, 117, 75, 117, 171, 117, 164, 117, 165, 117, 162, 117, 163, 117, 120, 118, 134, 118, 135, 118, 136, 118, 200, 118, 198, 118, 195, 118, 197, 118, 1, 119, 249, 118, 248, 118, 9, 119, 11, 119, 254, 118, 252, 118, 7, 119, 220, 119, 2, 120, 20, 120, 12, 120, 13, 120, 70, 121, 73, 121, 72, 121, 71, 121, 185, 121, 186, 121, 209, 121, 210, 121, 203, 121, 127, 122, 129, 122, 255, 122, 253, 122, 125, 124, 2, 125, 5, 125, 0, 125, 9, 125, 7, 125, 4, 125, 6, 125, 56, 127, 142, 127, 191, 127, 4, 128, 16, 128, 13, 128, 17, 128, 54, 128, 214, 128, 229, 128, 218, 128, 195, 128, 196, 128, 204, 128, 225, 128, 219, 128, 206, 128, 222, 128, 228, 128, 221, 128, 244, 129, 34, 130, 231, 130, 3, 131, 5, 131, 227, 130, 219, 130, 230, 130, 4, 131, 229, 130, 2, 131, 9, 131, 210, 130, 215, 130, 241, 130, 1, 131, 220, 130, 212, 130, 209, 130, 222, 130, 211, 130, 223, 130, 239, 130, 6, 131, 80, 134, 121, 134, 123, 134, 122, 134, 77, 136, 107, 136, 129, 137, 212, 137, 8, 138, 2, 138, 3, 138, 158, 140, 160, 140, 116, 141, 115, 141, 180, 141, 205, 142, 204, 142, 240, 143, 230, 143, 226, 143, 234, 143, 229, 143, 237, 143, 235, 143, 228, 143, 232, 143, 202, 144, 206, 144, 193, 144, 195, 144, 75, 145, 74, 145, 205, 145, 130, 149, 80, 150, 75, 150, 76, 150, 77, 150, 98, 151, 105, 151, 203, 151, 237, 151, 243, 151, 1, 152, 168, 152, 219, 152, 223, 152, 150, 153, 153, 153, 88, 78, 179, 78, 12, 80, 13, 80, 35, 80, 239, 79, 38, 80, 37, 80, 248, 79, 41, 80, 22, 80, 6, 80, 60, 80, 31, 80, 26, 80, 18, 80, 17, 80, 250, 79, 0, 80, 20, 80, 40, 80, 241, 79, 33, 80, 11, 80, 25, 80, 24, 80, 243, 79, 238, 79, 45, 80, 42, 80, 254, 79, 43, 80, 9, 80, 124, 81, 164, 81, 165, 81, 162, 81, 205, 81, 204, 81, 198, 81, 203, 81, 86, 82, 92, 82, 84, 82, 91, 82, 93, 82, 42, 83, 127, 83, 159, 83, 157, 83, 223, 83, 232, 84, 16, 85, 1, 85, 55, 85, 252, 84, 229, 84, 242, 84, 6, 85, 250, 84, 20, 85, 233, 84, 237, 84, 225, 84, 9, 85, 238, 84, 234, 84, 230, 84, 39, 85, 7, 85, 253, 84, 15, 85, 3, 87, 4, 87, 194, 87, 212, 87, 203, 87, 195, 87, 9, 88, 15, 89, 87, 89, 88, 89, 90, 89, 17, 90, 24, 90, 28, 90, 31, 90, 27, 90, 19, 90, 236, 89, 32, 90, 35, 90, 41, 90, 37, 90, 12, 90, 9, 90, 107, 91, 88, 92, 176, 91, 179, 91, 182, 91, 180, 91, 174, 91, 181, 91, 185, 91, 184, 91, 4, 92, 81, 92, 85, 92, 80, 92, 237, 92, 253, 92, 251, 92, 234, 92, 232, 92, 240, 92, 246, 92, 1, 93, 244, 92, 238, 93, 45, 94, 43, 94, 171, 94, 173, 94, 167, 94, 49, 95, 146, 95, 145, 95, 144, 95, 89, 96, 99, 96, 101, 96, 80, 96, 85, 96, 109, 96, 105, 96, 111, 96, 132, 96, 159, 96, 154, 96, 141, 96, 148, 96, 140, 96, 133, 96, 150, 96, 71, 98, 243, 98, 8, 99, 255, 98, 78, 99, 62, 99, 47, 99, 85, 99, 66, 99, 70, 99, 79, 99, 73, 99, 58, 99, 80, 99, 61, 99, 42, 99, 43, 99, 40, 99, 77, 99, 76, 99, 72, 101, 73, 101, 153, 101, 193, 101, 197, 101, 66, 102, 73, 102, 79, 102, 67, 102, 82, 102, 76, 102, 69, 102, 65, 102, 248, 102, 20, 103, 21, 103, 23, 103, 33, 104, 56, 104, 72, 104, 70, 104, 83, 104, 57, 104, 66, 104, 84, 104, 41, 104, 179, 104, 23, 104, 76, 104, 81, 104, 61, 104, 244, 103, 80, 104, 64, 104, 60, 104, 67, 104, 42, 104, 69, 104, 19, 104, 24, 104, 65, 104, 138, 107, 137, 107, 183, 107, 35, 108, 39, 108, 40, 108, 38, 108, 36, 108, 240, 108, 106, 109, 149, 109, 136, 109, 135, 109, 102, 109, 120, 109, 119, 109, 89, 109, 147, 109, 108, 109, 137, 109, 110, 109, 90, 109, 116, 109, 105, 109, 140, 109, 138, 109, 121, 109, 133, 109, 101, 109, 148, 109, 202, 112, 216, 112, 228, 112, 217, 112, 200, 112, 207, 112, 57, 114, 121, 114, 252, 114, 249, 114, 253, 114, 248, 114, 247, 114, 134, 115, 237, 115, 9, 116, 238, 115, 224, 115, 234, 115, 222, 115, 84, 117, 93, 117, 92, 117, 90, 117, 89, 117, 190, 117, 197, 117, 199, 117, 178, 117, 179, 117, 189, 117, 188, 117, 185, 117, 194, 117, 184, 117, 139, 118, 176, 118, 202, 118, 205, 118, 206, 118, 41, 119, 31, 119, 32, 119, 40, 119, 233, 119, 48, 120, 39, 120, 56, 120, 29, 120, 52, 120, 55, 120, 37, 120, 45, 120, 32, 120, 31, 120, 50, 120, 85, 121, 80, 121, 96, 121, 95, 121, 86, 121, 94, 121, 93, 121, 87, 121, 90, 121, 228, 121, 227, 121, 231, 121, 223, 121, 230, 121, 233, 121, 216, 121, 132, 122, 136, 122, 217, 122, 6, 123, 17, 123, 137, 124, 33, 125, 23, 125, 11, 125, 10, 125, 32, 125, 34, 125, 20, 125, 16, 125, 21, 125, 26, 125, 28, 125, 13, 125, 25, 125, 27, 125, 58, 127, 95, 127, 148, 127, 197, 127, 193, 127, 6, 128, 24, 128, 21, 128, 25, 128, 23, 128, 61, 128, 63, 128, 241, 128, 2, 129, 240, 128, 5, 129, 237, 128, 244, 128, 6, 129, 248, 128, 243, 128, 8, 129, 253, 128, 10, 129, 252, 128, 239, 128, 237, 129, 236, 129, 0, 130, 16, 130, 42, 130, 43, 130, 40, 130, 44, 130, 187, 130, 43, 131, 82, 131, 84, 131, 74, 131, 56, 131, 80, 131, 73, 131, 53, 131, 52, 131, 79, 131, 50, 131, 57, 131, 54, 131, 23, 131, 64, 131, 49, 131, 40, 131, 67, 131, 84, 134, 138, 134, 170, 134, 147, 134, 164, 134, 169, 134, 140, 134, 163, 134, 156, 134, 112, 136, 119, 136, 129, 136, 130, 136, 125, 136, 121, 136, 24, 138, 16, 138, 14, 138, 12, 138, 21, 138, 10, 138, 23, 138, 19, 138, 22, 138, 15, 138, 17, 138, 72, 140, 122, 140, 121, 140, 161, 140, 162, 140, 119, 141, 172, 142, 210, 142, 212, 142, 207, 142, 177, 143, 1, 144, 6, 144, 247, 143, 0, 144, 250, 143, 244, 143, 3, 144, 253, 143, 5, 144, 248, 143, 149, 144, 225, 144, 221, 144, 226, 144, 82, 145, 77, 145, 76, 145, 216, 145, 221, 145, 215, 145, 220, 145, 217, 145, 131, 149, 98, 150, 99, 150, 97, 150, 91, 150, 93, 150, 100, 150, 88, 150, 94, 150, 187, 150, 226, 152, 172, 153, 168, 154, 216, 154, 37, 155, 50, 155, 60, 155, 126, 78, 122, 80, 125, 80, 92, 80, 71, 80, 67, 80, 76, 80, 90, 80, 73, 80, 101, 80, 118, 80, 78, 80, 85, 80, 117, 80, 116, 80, 119, 80, 79, 80, 15, 80, 111, 80, 109, 80, 92, 81, 149, 81, 240, 81, 106, 82, 111, 82, 210, 82, 217, 82, 216, 82, 213, 82, 16, 83, 15, 83, 25, 83, 63, 83, 64, 83, 62, 83, 195, 83, 252, 102, 70, 85, 106, 85, 102, 85, 68, 85, 94, 85, 97, 85, 67, 85, 74, 85, 49, 85, 86, 85, 79, 85, 85, 85, 47, 85, 100, 85, 56, 85, 46, 85, 92, 85, 44, 85, 99, 85, 51, 85, 65, 85, 87, 85, 8, 87, 11, 87, 9, 87, 223, 87, 5, 88, 10, 88, 6, 88, 224, 87, 228, 87, 250, 87, 2, 88, 53, 88, 247, 87, 249, 87, 32, 89, 98, 89, 54, 90, 65, 90, 73, 90, 102, 90, 106, 90, 64, 90, 60, 90, 98, 90, 90, 90, 70, 90, 74, 90, 112, 91, 199, 91, 197, 91, 196, 91, 194, 91, 191, 91, 198, 91, 9, 92, 8, 92, 7, 92, 96, 92, 92, 92, 93, 92, 7, 93, 6, 93, 14, 93, 27, 93, 22, 93, 34, 93, 17, 93, 41, 93, 20, 93, 25, 93, 36, 93, 39, 93, 23, 93, 226, 93, 56, 94, 54, 94, 51, 94, 55, 94, 183, 94, 184, 94, 182, 94, 181, 94, 190, 94, 53, 95, 55, 95, 87, 95, 108, 95, 105, 95, 107, 95, 151, 95, 153, 95, 158, 95, 152, 95, 161, 95, 160, 95, 156, 95, 127, 96, 163, 96, 137, 96, 160, 96, 168, 96, 203, 96, 180, 96, 230, 96, 189, 96, 197, 96, 187, 96, 181, 96, 220, 96, 188, 96, 216, 96, 213, 96, 198, 96, 223, 96, 184, 96, 218, 96, 199, 96, 26, 98, 27, 98, 72, 98, 160, 99, 167, 99, 114, 99, 150, 99, 162, 99, 165, 99, 119, 99, 103, 99, 152, 99, 170, 99, 113, 99, 169, 99, 137, 99, 131, 99, 155, 99, 107, 99, 168, 99, 132, 99, 136, 99, 153, 99, 161, 99, 172, 99, 146, 99, 143, 99, 128, 99, 123, 99, 105, 99, 104, 99, 122, 99, 93, 101, 86, 101, 81, 101, 89, 101, 87, 101, 95, 85, 79, 101, 88, 101, 85, 101, 84, 101, 156, 101, 155, 101, 172, 101, 207, 101, 203, 101, 204, 101, 206, 101, 93, 102, 90, 102, 100, 102, 104, 102, 102, 102, 94, 102, 249, 102, 215, 82, 27, 103, 129, 104, 175, 104, 162, 104, 147, 104, 181, 104, 127, 104, 118, 104, 177, 104, 167, 104, 151, 104, 176, 104, 131, 104, 196, 104, 173, 104, 134, 104, 133, 104, 148, 104, 157, 104, 168, 104, 159, 104, 161, 104, 130, 104, 50, 107, 186, 107, 235, 107, 236, 107, 43, 108, 142, 109, 188, 109, 243, 109, 217, 109, 178, 109, 225, 109, 204, 109, 228, 109, 251, 109, 250, 109, 5, 110, 199, 109, 203, 109, 175, 109, 209, 109, 174, 109, 222, 109, 249, 109, 184, 109, 247, 109, 245, 109, 197, 109, 210, 109, 26, 110, 181, 109, 218, 109, 235, 109, 216, 109, 234, 109, 241, 109, 238, 109, 232, 109, 198, 109, 196, 109, 170, 109, 236, 109, 191, 109, 230, 109, 249, 112, 9, 113, 10, 113, 253, 112, 239, 112, 61, 114, 125, 114, 129, 114, 28, 115, 27, 115, 22, 115, 19, 115, 25, 115, 135, 115, 5, 116, 10, 116, 3, 116, 6, 116, 254, 115, 13, 116, 224, 116, 246, 116, 247, 116, 28, 117, 34, 117, 101, 117, 102, 117, 98, 117, 112, 117, 143, 117, 212, 117, 213, 117, 181, 117, 202, 117, 205, 117, 142, 118, 212, 118, 210, 118, 219, 118, 55, 119, 62, 119, 60, 119, 54, 119, 56, 119, 58, 119, 107, 120, 67, 120, 78, 120, 101, 121, 104, 121, 109, 121, 251, 121, 146, 122, 149, 122, 32, 123, 40, 123, 27, 123, 44, 123, 38, 123, 25, 123, 30, 123, 46, 123, 146, 124, 151, 124, 149, 124, 70, 125, 67, 125, 113, 125, 46, 125, 57, 125, 60, 125, 64, 125, 48, 125, 51, 125, 68, 125, 47, 125, 66, 125, 50, 125, 49, 125, 61, 127, 158, 127, 154, 127, 204, 127, 206, 127, 210, 127, 28, 128, 74, 128, 70, 128, 47, 129, 22, 129, 35, 129, 43, 129, 41, 129, 48, 129, 36, 129, 2, 130, 53, 130, 55, 130, 54, 130, 57, 130, 142, 131, 158, 131, 152, 131, 120, 131, 162, 131, 150, 131, 189, 131, 171, 131, 146, 131, 138, 131, 147, 131, 137, 131, 160, 131, 119, 131, 123, 131, 124, 131, 134, 131, 167, 131, 85, 134, 106, 95, 199, 134, 192, 134, 182, 134, 196, 134, 181, 134, 198, 134, 203, 134, 177, 134, 175, 134, 201, 134, 83, 136, 158, 136, 136, 136, 171, 136, 146, 136, 150, 136, 141, 136, 139, 136, 147, 137, 143, 137, 42, 138, 29, 138, 35, 138, 37, 138, 49, 138, 45, 138, 31, 138, 27, 138, 34, 138, 73, 140, 90, 140, 169, 140, 172, 140, 171, 140, 168, 140, 170, 140, 167, 140, 103, 141, 102, 141, 190, 141, 186, 141, 219, 142, 223, 142, 25, 144, 13, 144, 26, 144, 23, 144, 35, 144, 31, 144, 29, 144, 16, 144, 21, 144, 30, 144, 32, 144, 15, 144, 34, 144, 22, 144, 27, 144, 20, 144, 232, 144, 237, 144, 253, 144, 87, 145, 206, 145, 245, 145, 230, 145, 227, 145, 231, 145, 237, 145, 233, 145, 137, 149, 106, 150, 117, 150, 115, 150, 120, 150, 112, 150, 116, 150, 118, 150, 119, 150, 108, 150, 192, 150, 234, 150, 233, 150, 224, 122, 223, 122, 2, 152, 3, 152, 90, 155, 229, 156, 117, 158, 127, 158, 165, 158, 187, 158, 162, 80, 141, 80, 133, 80, 153, 80, 145, 80, 128, 80, 150, 80, 152, 80, 154, 80, 0, 103, 241, 81, 114, 82, 116, 82, 117, 82, 105, 82, 222, 82, 221, 82, 219, 82, 90, 83, 165, 83, 123, 85, 128, 85, 167, 85, 124, 85, 138, 85, 157, 85, 152, 85, 130, 85, 156, 85, 170, 85, 148, 85, 135, 85, 139, 85, 131, 85, 179, 85, 174, 85, 159, 85, 62, 85, 178, 85, 154, 85, 187, 85, 172, 85, 177, 85, 126, 85, 137, 85, 171, 85, 153, 85, 13, 87, 47, 88, 42, 88, 52, 88, 36, 88, 48, 88, 49, 88, 33, 88, 29, 88, 32, 88, 249, 88, 250, 88, 96, 89, 119, 90, 154, 90, 127, 90, 146, 90, 155, 90, 167, 90, 115, 91, 113, 91, 210, 91, 204, 91, 211, 91, 208, 91, 10, 92, 11, 92, 49, 92, 76, 93, 80, 93, 52, 93, 71, 93, 253, 93, 69, 94, 61, 94, 64, 94, 67, 94, 126, 94, 202, 94, 193, 94, 194, 94, 196, 94, 60, 95, 109, 95, 169, 95, 170, 95, 168, 95, 209, 96, 225, 96, 178, 96, 182, 96, 224, 96, 28, 97, 35, 97, 250, 96, 21, 97, 240, 96, 251, 96, 244, 96, 104, 97, 241, 96, 14, 97, 246, 96, 9, 97, 0, 97, 18, 97, 31, 98, 73, 98, 163, 99, 140, 99, 207, 99, 192, 99, 233, 99, 201, 99, 198, 99, 205, 99, 210, 99, 227, 99, 208, 99, 225, 99, 214, 99, 237, 99, 238, 99, 118, 99, 244, 99, 234, 99, 219, 99, 82, 100, 218, 99, 249, 99, 94, 101, 102, 101, 98, 101, 99, 101, 145, 101, 144, 101, 175, 101, 110, 102, 112, 102, 116, 102, 118, 102, 111, 102, 145, 102, 122, 102, 126, 102, 119, 102, 254, 102, 255, 102, 31, 103, 29, 103, 250, 104, 213, 104, 224, 104, 216, 104, 215, 104, 5, 105, 223, 104, 245, 104, 238, 104, 231, 104, 249, 104, 210, 104, 242, 104, 227, 104, 203, 104, 205, 104, 13, 105, 18, 105, 14, 105, 201, 104, 218, 104, 110, 105, 251, 104, 62, 107, 58, 107, 61, 107, 152, 107, 150, 107, 188, 107, 239, 107, 46, 108, 47, 108, 44, 108, 47, 110, 56, 110, 84, 110, 33, 110, 50, 110, 103, 110, 74, 110, 32, 110, 37, 110, 35, 110, 27, 110, 91, 110, 88, 110, 36, 110, 86, 110, 110, 110, 45, 110, 38, 110, 111, 110, 52, 110, 77, 110, 58, 110, 44, 110, 67, 110, 29, 110, 62, 110, 203, 110, 137, 110, 25, 110, 78, 110, 99, 110, 68, 110, 114, 110, 105, 110, 95, 110, 25, 113, 26, 113, 38, 113, 48, 113, 33, 113, 54, 113, 110, 113, 28, 113, 76, 114, 132, 114, 128, 114, 54, 115, 37, 115, 52, 115, 41, 115, 58, 116, 42, 116, 51, 116, 34, 116, 37, 116, 53, 116, 54, 116, 52, 116, 47, 116, 27, 116, 38, 116, 40, 116, 37, 117, 38, 117, 107, 117, 106, 117, 226, 117, 219, 117, 227, 117, 217, 117, 216, 117, 222, 117, 224, 117, 123, 118, 124, 118, 150, 118, 147, 118, 180, 118, 220, 118, 79, 119, 237, 119, 93, 120, 108, 120, 111, 120, 13, 122, 8, 122, 11, 122, 5, 122, 0, 122, 152, 122, 151, 122, 150, 122, 229, 122, 227, 122, 73, 123, 86, 123, 70, 123, 80, 123, 82, 123, 84, 123, 77, 123, 75, 123, 79, 123, 81, 123, 159, 124, 165, 124, 94, 125, 80, 125, 104, 125, 85, 125, 43, 125, 110, 125, 114, 125, 97, 125, 102, 125, 98, 125, 112, 125, 115, 125, 132, 85, 212, 127, 213, 127, 11, 128, 82, 128, 133, 128, 85, 129, 84, 129, 75, 129, 81, 129, 78, 129, 57, 129, 70, 129, 62, 129, 76, 129, 83, 129, 116, 129, 18, 130, 28, 130, 233, 131, 3, 132, 248, 131, 13, 132, 224, 131, 197, 131, 11, 132, 193, 131, 239, 131, 241, 131, 244, 131, 87, 132, 10, 132, 240, 131, 12, 132, 204, 131, 253, 131, 242, 131, 202, 131, 56, 132, 14, 132, 4, 132, 220, 131, 7, 132, 212, 131, 223, 131, 91, 134, 223, 134, 217, 134, 237, 134, 212, 134, 219, 134, 228, 134, 208, 134, 222, 134, 87, 136, 193, 136, 194, 136, 177, 136, 131, 137, 150, 137, 59, 138, 96, 138, 85, 138, 94, 138, 60, 138, 65, 138, 84, 138, 91, 138, 80, 138, 70, 138, 52, 138, 58, 138, 54, 138, 86, 138, 97, 140, 130, 140, 175, 140, 188, 140, 179, 140, 189, 140, 193, 140, 187, 140, 192, 140, 180, 140, 183, 140, 182, 140, 191, 140, 184, 140, 138, 141, 133, 141, 129, 141, 206, 141, 221, 141, 203, 141, 218, 141, 209, 141, 204, 141, 219, 141, 198, 141, 251, 142, 248, 142, 252, 142, 156, 143, 46, 144, 53, 144, 49, 144, 56, 144, 50, 144, 54, 144, 2, 145, 245, 144, 9, 145, 254, 144, 99, 145, 101, 145, 207, 145, 20, 146, 21, 146, 35, 146, 9, 146, 30, 146, 13, 146, 16, 146, 7, 146, 17, 146, 148, 149, 143, 149, 139, 149, 145, 149, 147, 149, 146, 149, 142, 149, 138, 150, 142, 150, 139, 150, 125, 150, 133, 150, 134, 150, 141, 150, 114, 150, 132, 150, 193, 150, 197, 150, 196, 150, 198, 150, 199, 150, 239, 150, 242, 150, 204, 151, 5, 152, 6, 152, 8, 152, 231, 152, 234, 152, 239, 152, 233, 152, 242, 152, 237, 152, 174, 153, 173, 153, 195, 158, 205, 158, 209, 158, 130, 78, 173, 80, 181, 80, 178, 80, 179, 80, 197, 80, 190, 80, 172, 80, 183, 80, 187, 80, 175, 80, 199, 80, 127, 82, 119, 82, 125, 82, 223, 82, 230, 82, 228, 82, 226, 82, 227, 82, 47, 83, 223, 85, 232, 85, 211, 85, 230, 85, 206, 85, 220, 85, 199, 85, 209, 85, 227, 85, 228, 85, 239, 85, 218, 85, 225, 85, 197, 85, 198, 85, 229, 85, 201, 85, 18, 87, 19, 87, 94, 88, 81, 88, 88, 88, 87, 88, 90, 88, 84, 88, 107, 88, 76, 88, 109, 88, 74, 88, 98, 88, 82, 88, 75, 88, 103, 89, 193, 90, 201, 90, 204, 90, 190, 90, 189, 90, 188, 90, 179, 90, 194, 90, 178, 90, 105, 93, 111, 93, 76, 94, 121, 94, 201, 94, 200, 94, 18, 95, 89, 95, 172, 95, 174, 95, 26, 97, 15, 97, 72, 97, 31, 97, 243, 96, 27, 97, 249, 96, 1, 97, 8, 97, 78, 97, 76, 97, 68, 97, 77, 97, 62, 97, 52, 97, 39, 97, 13, 97, 6, 97, 55, 97, 33, 98, 34, 98, 19, 100, 62, 100, 30, 100, 42, 100, 45, 100, 61, 100, 44, 100, 15, 100, 28, 100, 20, 100, 13, 100, 54, 100, 22, 100, 23, 100, 6, 100, 108, 101, 159, 101, 176, 101, 151, 102, 137, 102, 135, 102, 136, 102, 150, 102, 132, 102, 152, 102, 141, 102, 3, 103, 148, 105, 109, 105, 90, 105, 119, 105, 96, 105, 84, 105, 117, 105, 48, 105, 130, 105, 74, 105, 104, 105, 107, 105, 94, 105, 83, 105, 121, 105, 134, 105, 93, 105, 99, 105, 91, 105, 71, 107, 114, 107, 192, 107, 191, 107, 211, 107, 253, 107, 162, 110, 175, 110, 211, 110, 182, 110, 194, 110, 144, 110, 157, 110, 199, 110, 197, 110, 165, 110, 152, 110, 188, 110, 186, 110, 171, 110, 209, 110, 150, 110, 156, 110, 196, 110, 212, 110, 170, 110, 167, 110, 180, 110, 78, 113, 89, 113, 105, 113, 100, 113, 73, 113, 103, 113, 92, 113, 108, 113, 102, 113, 76, 113, 101, 113, 94, 113, 70, 113, 104, 113, 86, 113, 58, 114, 82, 114, 55, 115, 69, 115, 63, 115, 62, 115, 111, 116, 90, 116, 85, 116, 95, 116, 94, 116, 65, 116, 63, 116, 89, 116, 91, 116, 92, 116, 118, 117, 120, 117, 0, 118, 240, 117, 1, 118, 242, 117, 241, 117, 250, 117, 255, 117, 244, 117, 243, 117, 222, 118, 223, 118, 91, 119, 107, 119, 102, 119, 94, 119, 99, 119, 121, 119, 106, 119, 108, 119, 92, 119, 101, 119, 104, 119, 98, 119, 238, 119, 142, 120, 176, 120, 151, 120, 152, 120, 140, 120, 137, 120, 124, 120, 145, 120, 147, 120, 127, 120, 122, 121, 127, 121, 129, 121, 44, 132, 189, 121, 28, 122, 26, 122, 32, 122, 20, 122, 31, 122, 30, 122, 159, 122, 160, 122, 119, 123, 192, 123, 96, 123, 110, 123, 103, 123, 177, 124, 179, 124, 181, 124, 147, 125, 121, 125, 145, 125, 129, 125, 143, 125, 91, 125, 110, 127, 105, 127, 106, 127, 114, 127, 169, 127, 168, 127, 164, 127, 86, 128, 88, 128, 134, 128, 132, 128, 113, 129, 112, 129, 120, 129, 101, 129, 110, 129, 115, 129, 107, 129, 121, 129, 122, 129, 102, 129, 5, 130, 71, 130, 130, 132, 119, 132, 61, 132, 49, 132, 117, 132, 102, 132, 107, 132, 73, 132, 108, 132, 91, 132, 60, 132, 53, 132, 97, 132, 99, 132, 105, 132, 109, 132, 70, 132, 94, 134, 92, 134, 95, 134, 249, 134, 19, 135, 8, 135, 7, 135, 0, 135, 254, 134, 251, 134, 2, 135, 3, 135, 6, 135, 10, 135, 89, 136, 223, 136, 212, 136, 217, 136, 220, 136, 216, 136, 221, 136, 225, 136, 202, 136, 213, 136, 210, 136, 156, 137, 227, 137, 107, 138, 114, 138, 115, 138, 102, 138, 105, 138, 112, 138, 135, 138, 124, 138, 99, 138, 160, 138, 113, 138, 133, 138, 109, 138, 98, 138, 110, 138, 108, 138, 121, 138, 123, 138, 62, 138, 104, 138, 98, 140, 138, 140, 137, 140, 202, 140, 199, 140, 200, 140, 196, 140, 178, 140, 195, 140, 194, 140, 197, 140, 225, 141, 223, 141, 232, 141, 239, 141, 243, 141, 250, 141, 234, 141, 228, 141, 230, 141, 178, 142, 3, 143, 9, 143, 254, 142, 10, 143, 159, 143, 178, 143, 75, 144, 74, 144, 83, 144, 66, 144, 84, 144, 60, 144, 85, 144, 80, 144, 71, 144, 79, 144, 78, 144, 77, 144, 81, 144, 62, 144, 65, 144, 18, 145, 23, 145, 108, 145, 106, 145, 105, 145, 201, 145, 55, 146, 87, 146, 56, 146, 61, 146, 64, 146, 62, 146, 91, 146, 75, 146, 100, 146, 81, 146, 52, 146, 73, 146, 77, 146, 69, 146, 57, 146, 63, 146, 90, 146, 152, 149, 152, 150, 148, 150, 149, 150, 205, 150, 203, 150, 201, 150, 202, 150, 247, 150, 251, 150, 249, 150, 246, 150, 86, 151, 116, 151, 118, 151, 16, 152, 17, 152, 19, 152, 10, 152, 18, 152, 12, 152, 252, 152, 244, 152, 253, 152, 254, 152, 179, 153, 177, 153, 180, 153, 225, 154, 233, 156, 130, 158, 14, 159, 19, 159, 32, 159, 231, 80, 238, 80, 229, 80, 214, 80, 237, 80, 218, 80, 213, 80, 207, 80, 209, 80, 241, 80, 206, 80, 233, 80, 98, 81, 243, 81, 131, 82, 130, 82, 49, 83, 173, 83, 254, 85, 0, 86, 27, 86, 23, 86, 253, 85, 20, 86, 6, 86, 9, 86, 13, 86, 14, 86, 247, 85, 22, 86, 31, 86, 8, 86, 16, 86, 246, 85, 24, 87, 22, 87, 117, 88, 126, 88, 131, 88, 147, 88, 138, 88, 121, 88, 133, 88, 125, 88, 253, 88, 37, 89, 34, 89, 36, 89, 106, 89, 105, 89, 225, 90, 230, 90, 233, 90, 215, 90, 214, 90, 216, 90, 227, 90, 117, 91, 222, 91, 231, 91, 225, 91, 229, 91, 230, 91, 232, 91, 226, 91, 228, 91, 223, 91, 13, 92, 98, 92, 132, 93, 135, 93, 91, 94, 99, 94, 85, 94, 87, 94, 84, 94, 211, 94, 214, 94, 10, 95, 70, 95, 112, 95, 185, 95, 71, 97, 63, 97, 75, 97, 119, 97, 98, 97, 99, 97, 95, 97, 90, 97, 88, 97, 117, 97, 42, 98, 135, 100, 88, 100, 84, 100, 164, 100, 120, 100, 95, 100, 122, 100, 81, 100, 103, 100, 52, 100, 109, 100, 123, 100, 114, 101, 161, 101, 215, 101, 214, 101, 162, 102, 168, 102, 157, 102, 156, 105, 168, 105, 149, 105, 193, 105, 174, 105, 211, 105, 203, 105, 155, 105, 183, 105, 187, 105, 171, 105, 180, 105, 208, 105, 205, 105, 173, 105, 204, 105, 166, 105, 195, 105, 163, 105, 73, 107, 76, 107, 51, 108, 51, 111, 20, 111, 254, 110, 19, 111, 244, 110, 41, 111, 62, 111, 32, 111, 44, 111, 15, 111, 2, 111, 34, 111, 255, 110, 239, 110, 6, 111, 49, 111, 56, 111, 50, 111, 35, 111, 21, 111, 43, 111, 47, 111, 136, 111, 42, 111, 236, 110, 1, 111, 242, 110, 204, 110, 247, 110, 148, 113, 153, 113, 125, 113, 138, 113, 132, 113, 146, 113, 62, 114, 146, 114, 150, 114, 68, 115, 80, 115, 100, 116, 99, 116, 106, 116, 112, 116, 109, 116, 4, 117, 145, 117, 39, 118, 13, 118, 11, 118, 9, 118, 19, 118, 225, 118, 227, 118, 132, 119, 125, 119, 127, 119, 97, 119, 193, 120, 159, 120, 167, 120, 179, 120, 169, 120, 163, 120, 142, 121, 143, 121, 141, 121, 46, 122, 49, 122, 170, 122, 169, 122, 237, 122, 239, 122, 161, 123, 149, 123, 139, 123, 117, 123, 151, 123, 157, 123, 148, 123, 143, 123, 184, 123, 135, 123, 132, 123, 185, 124, 189, 124, 190, 124, 187, 125, 176, 125, 156, 125, 189, 125, 190, 125, 160, 125, 202, 125, 180, 125, 178, 125, 177, 125, 186, 125, 162, 125, 191, 125, 181, 125, 184, 125, 173, 125, 210, 125, 199, 125, 172, 125, 112, 127, 224, 127, 225, 127, 223, 127, 94, 128, 90, 128, 135, 128, 80, 129, 128, 129, 143, 129, 136, 129, 138, 129, 127, 129, 130, 129, 231, 129, 250, 129, 7, 130, 20, 130, 30, 130, 75, 130, 201, 132, 191, 132, 198, 132, 196, 132, 153, 132, 158, 132, 178, 132, 156, 132, 203, 132, 184, 132, 192, 132, 211, 132, 144, 132, 188, 132, 209, 132, 202, 132, 63, 135, 28, 135, 59, 135, 34, 135, 37, 135, 52, 135, 24, 135, 85, 135, 55, 135, 41, 135, 243, 136, 2, 137, 244, 136, 249, 136, 248, 136, 253, 136, 232, 136, 26, 137, 239, 136, 166, 138, 140, 138, 158, 138, 163, 138, 141, 138, 161, 138, 147, 138, 164, 138, 170, 138, 165, 138, 168, 138, 152, 138, 145, 138, 154, 138, 167, 138, 106, 140, 141, 140, 140, 140, 211, 140, 209, 140, 210, 140, 107, 141, 153, 141, 149, 141, 252, 141, 20, 143, 18, 143, 21, 143, 19, 143, 163, 143, 96, 144, 88, 144, 92, 144, 99, 144, 89, 144, 94, 144, 98, 144, 93, 144, 91, 144, 25, 145, 24, 145, 30, 145, 117, 145, 120, 145, 119, 145, 116, 145, 120, 146, 128, 146, 133, 146, 152, 146, 150, 146, 123, 146, 147, 146, 156, 146, 168, 146, 124, 146, 145, 146, 161, 149, 168, 149, 169, 149, 163, 149, 165, 149, 164, 149, 153, 150, 156, 150, 155, 150, 204, 150, 210, 150, 0, 151, 124, 151, 133, 151, 246, 151, 23, 152, 24, 152, 175, 152, 177, 152, 3, 153, 5, 153, 12, 153, 9, 153, 193, 153, 175, 154, 176, 154, 230, 154, 65, 155, 66, 155, 244, 156, 246, 156, 243, 156, 188, 158, 59, 159, 74, 159, 4, 81, 0, 81, 251, 80, 245, 80, 249, 80, 2, 81, 8, 81, 9, 81, 5, 81, 220, 81, 135, 82, 136, 82, 137, 82, 141, 82, 138, 82, 240, 82, 178, 83, 46, 86, 59, 86, 57, 86, 50, 86, 63, 86, 52, 86, 41, 86, 83, 86, 78, 86, 87, 86, 116, 86, 54, 86, 47, 86, 48, 86, 128, 88, 159, 88, 158, 88, 179, 88, 156, 88, 174, 88, 169, 88, 166, 88, 109, 89, 9, 91, 251, 90, 11, 91, 245, 90, 12, 91, 8, 91, 238, 91, 236, 91, 233, 91, 235, 91, 100, 92, 101, 92, 157, 93, 148, 93, 98, 94, 95, 94, 97, 94, 226, 94, 218, 94, 223, 94, 221, 94, 227, 94, 224, 94, 72, 95, 113, 95, 183, 95, 181, 95, 118, 97, 103, 97, 110, 97, 93, 97, 85, 97, 130, 97, 124, 97, 112, 97, 107, 97, 126, 97, 167, 97, 144, 97, 171, 97, 142, 97, 172, 97, 154, 97, 164, 97, 148, 97, 174, 97, 46, 98, 105, 100, 111, 100, 121, 100, 158, 100, 178, 100, 136, 100, 144, 100, 176, 100, 165, 100, 147, 100, 149, 100, 169, 100, 146, 100, 174, 100, 173, 100, 171, 100, 154, 100, 172, 100, 153, 100, 162, 100, 179, 100, 117, 101, 119, 101, 120, 101, 174, 102, 171, 102, 180, 102, 177, 102, 35, 106, 31, 106, 232, 105, 1, 106, 30, 106, 25, 106, 253, 105, 33, 106, 19, 106, 10, 106, 243, 105, 2, 106, 5, 106, 237, 105, 17, 106, 80, 107, 78, 107, 164, 107, 197, 107, 198, 107, 63, 111, 124, 111, 132, 111, 81, 111, 102, 111, 84, 111, 134, 111, 109, 111, 91, 111, 120, 111, 110, 111, 142, 111, 122, 111, 112, 111, 100, 111, 151, 111, 88, 111, 213, 110, 111, 111, 96, 111, 95, 111, 159, 113, 172, 113, 177, 113, 168, 113, 86, 114, 155, 114, 78, 115, 87, 115, 105, 116, 139, 116, 131, 116, 126, 116, 128, 116, 127, 117, 32, 118, 41, 118, 31, 118, 36, 118, 38, 118, 33, 118, 34, 118, 154, 118, 186, 118, 228, 118, 142, 119, 135, 119, 140, 119, 145, 119, 139, 119, 203, 120, 197, 120, 186, 120, 202, 120, 190, 120, 213, 120, 188, 120, 208, 120, 63, 122, 60, 122, 64, 122, 61, 122, 55, 122, 59, 122, 175, 122, 174, 122, 173, 123, 177, 123, 196, 123, 180, 123, 198, 123, 199, 123, 193, 123, 160, 123, 204, 123, 202, 124, 224, 125, 244, 125, 239, 125, 251, 125, 216, 125, 236, 125, 221, 125, 232, 125, 227, 125, 218, 125, 222, 125, 233, 125, 158, 125, 217, 125, 242, 125, 249, 125, 117, 127, 119, 127, 175, 127, 233, 127, 38, 128, 155, 129, 156, 129, 157, 129, 160, 129, 154, 129, 152, 129, 23, 133, 61, 133, 26, 133, 238, 132, 44, 133, 45, 133, 19, 133, 17, 133, 35, 133, 33, 133, 20, 133, 236, 132, 37, 133, 255, 132, 6, 133, 130, 135, 116, 135, 118, 135, 96, 135, 102, 135, 120, 135, 104, 135, 89, 135, 87, 135, 76, 135, 83, 135, 91, 136, 93, 136, 16, 137, 7, 137, 18, 137, 19, 137, 21, 137, 10, 137, 188, 138, 210, 138, 199, 138, 196, 138, 149, 138, 203, 138, 248, 138, 178, 138, 201, 138, 194, 138, 191, 138, 176, 138, 214, 138, 205, 138, 182, 138, 185, 138, 219, 138, 76, 140, 78, 140, 108, 140, 224, 140, 222, 140, 230, 140, 228, 140, 236, 140, 237, 140, 226, 140, 227, 140, 220, 140, 234, 140, 225, 140, 109, 141, 159, 141, 163, 141, 43, 142, 16, 142, 29, 142, 34, 142, 15, 142, 41, 142, 31, 142, 33, 142, 30, 142, 186, 142, 29, 143, 27, 143, 31, 143, 41, 143, 38, 143, 42, 143, 28, 143, 30, 143, 37, 143, 105, 144, 110, 144, 104, 144, 109, 144, 119, 144, 48, 145, 45, 145, 39, 145, 49, 145, 135, 145, 137, 145, 139, 145, 131, 145, 197, 146, 187, 146, 183, 146, 234, 146, 172, 146, 228, 146, 193, 146, 179, 146, 188, 146, 210, 146, 199, 146, 240, 146, 178, 146, 173, 149, 177, 149, 4, 151, 6, 151, 7, 151, 9, 151, 96, 151, 141, 151, 139, 151, 143, 151, 33, 152, 43, 152, 28, 152, 179, 152, 10, 153, 19, 153, 18, 153, 24, 153, 221, 153, 208, 153, 223, 153, 219, 153, 209, 153, 213, 153, 210, 153, 217, 153, 183, 154, 238, 154, 239, 154, 39, 155, 69, 155, 68, 155, 119, 155, 111, 155, 6, 157, 9, 157, 3, 157, 169, 158, 190, 158, 206, 158, 168, 88, 82, 159, 18, 81, 24, 81, 20, 81, 16, 81, 21, 81, 128, 81, 170, 81, 221, 81, 145, 82, 147, 82, 243, 82, 89, 86, 107, 86, 121, 86, 105, 86, 100, 86, 120, 86, 106, 86, 104, 86, 101, 86, 113, 86, 111, 86, 108, 86, 98, 86, 118, 86, 193, 88, 190, 88, 199, 88, 197, 88, 110, 89, 29, 91, 52, 91, 120, 91, 240, 91, 14, 92, 74, 95, 178, 97, 145, 97, 169, 97, 138, 97, 205, 97, 182, 97, 190, 97, 202, 97, 200, 97, 48, 98, 197, 100, 193, 100, 203, 100, 187, 100, 188, 100, 218, 100, 196, 100, 199, 100, 194, 100, 205, 100, 191, 100, 210, 100, 212, 100, 190, 100, 116, 101, 198, 102, 201, 102, 185, 102, 196, 102, 199, 102, 184, 102, 61, 106, 56, 106, 58, 106, 89, 106, 107, 106, 88, 106, 57, 106, 68, 106, 98, 106, 97, 106, 75, 106, 71, 106, 53, 106, 95, 106, 72, 106, 89, 107, 119, 107, 5, 108, 194, 111, 177, 111, 161, 111, 195, 111, 164, 111, 193, 111, 167, 111, 179, 111, 192, 111, 185, 111, 182, 111, 166, 111, 160, 111, 180, 111, 190, 113, 201, 113, 208, 113, 210, 113, 200, 113, 213, 113, 185, 113, 206, 113, 217, 113, 220, 113, 195, 113, 196, 113, 104, 115, 156, 116, 163, 116, 152, 116, 159, 116, 158, 116, 226, 116, 12, 117, 13, 117, 52, 118, 56, 118, 58, 118, 231, 118, 229, 118, 160, 119, 158, 119, 159, 119, 165, 119, 232, 120, 218, 120, 236, 120, 231, 120, 166, 121, 77, 122, 78, 122, 70, 122, 76, 122, 75, 122, 186, 122, 217, 123, 17, 124, 201, 123, 228, 123, 219, 123, 225, 123, 233, 123, 230, 123, 213, 124, 214, 124, 10, 126, 17, 126, 8, 126, 27, 126, 35, 126, 30, 126, 29, 126, 9, 126, 16, 126, 121, 127, 178, 127, 240, 127, 241, 127, 238, 127, 40, 128, 179, 129, 169, 129, 168, 129, 251, 129, 8, 130, 88, 130, 89, 130, 74, 133, 89, 133, 72, 133, 104, 133, 105, 133, 67, 133, 73, 133, 109, 133, 106, 133, 94, 133, 131, 135, 159, 135, 158, 135, 162, 135, 141, 135, 97, 136, 42, 137, 50, 137, 37, 137, 43, 137, 33, 137, 170, 137, 166, 137, 230, 138, 250, 138, 235, 138, 241, 138, 0, 139, 220, 138, 231, 138, 238, 138, 254, 138, 1, 139, 2, 139, 247, 138, 237, 138, 243, 138, 246, 138, 252, 138, 107, 140, 109, 140, 147, 140, 244, 140, 68, 142, 49, 142, 52, 142, 66, 142, 57, 142, 53, 142, 59, 143, 47, 143, 56, 143, 51, 143, 168, 143, 166, 143, 117, 144, 116, 144, 120, 144, 114, 144, 124, 144, 122, 144, 52, 145, 146, 145, 32, 147, 54, 147, 248, 146, 51, 147, 47, 147, 34, 147, 252, 146, 43, 147, 4, 147, 26, 147, 16, 147, 38, 147, 33, 147, 21, 147, 46, 147, 25, 147, 187, 149, 167, 150, 168, 150, 170, 150, 213, 150, 14, 151, 17, 151, 22, 151, 13, 151, 19, 151, 15, 151, 91, 151, 92, 151, 102, 151, 152, 151, 48, 152, 56, 152, 59, 152, 55, 152, 45, 152, 57, 152, 36, 152, 16, 153, 40, 153, 30, 153, 27, 153, 33, 153, 26, 153, 237, 153, 226, 153, 241, 153, 184, 154, 188, 154, 251, 154, 237, 154, 40, 155, 145, 155, 21, 157, 35, 157, 38, 157, 40, 157, 18, 157, 27, 157, 216, 158, 212, 158, 141, 159, 156, 159, 42, 81, 31, 81, 33, 81, 50, 81, 245, 82, 142, 86, 128, 86, 144, 86, 133, 86, 135, 86, 143, 86, 213, 88, 211, 88, 209, 88, 206, 88, 48, 91, 42, 91, 36, 91, 122, 91, 55, 92, 104, 92, 188, 93, 186, 93, 189, 93, 184, 93, 107, 94, 76, 95, 189, 95, 201, 97, 194, 97, 199, 97, 230, 97, 203, 97, 50, 98, 52, 98, 206, 100, 202, 100, 216, 100, 224, 100, 240, 100, 230, 100, 236, 100, 241, 100, 226, 100, 237, 100, 130, 101, 131, 101, 217, 102, 214, 102, 128, 106, 148, 106, 132, 106, 162, 106, 156, 106, 219, 106, 163, 106, 126, 106, 151, 106, 144, 106, 160, 106, 92, 107, 174, 107, 218, 107, 8, 108, 216, 111, 241, 111, 223, 111, 224, 111, 219, 111, 228, 111, 235, 111, 239, 111, 128, 111, 236, 111, 225, 111, 233, 111, 213, 111, 238, 111, 240, 111, 231, 113, 223, 113, 238, 113, 230, 113, 229, 113, 237, 113, 236, 113, 244, 113, 224, 113, 53, 114, 70, 114, 112, 115, 114, 115, 169, 116, 176, 116, 166, 116, 168, 116, 70, 118, 66, 118, 76, 118, 234, 118, 179, 119, 170, 119, 176, 119, 172, 119, 167, 119, 173, 119, 239, 119, 247, 120, 250, 120, 244, 120, 239, 120, 1, 121, 167, 121, 170, 121, 87, 122, 191, 122, 7, 124, 13, 124, 254, 123, 247, 123, 12, 124, 224, 123, 224, 124, 220, 124, 222, 124, 226, 124, 223, 124, 217, 124, 221, 124, 46, 126, 62, 126, 70, 126, 55, 126, 50, 126, 67, 126, 43, 126, 61, 126, 49, 126, 69, 126, 65, 126, 52, 126, 57, 126, 72, 126, 53, 126, 63, 126, 47, 126, 68, 127, 243, 127, 252, 127, 113, 128, 114, 128, 112, 128, 111, 128, 115, 128, 198, 129, 195, 129, 186, 129, 194, 129, 192, 129, 191, 129, 189, 129, 201, 129, 190, 129, 232, 129, 9, 130, 113, 130, 170, 133, 132, 133, 126, 133, 156, 133, 145, 133, 148, 133, 175, 133, 155, 133, 135, 133, 168, 133, 138, 133, 103, 134, 192, 135, 209, 135, 179, 135, 210, 135, 198, 135, 171, 135, 187, 135, 186, 135, 200, 135, 203, 135, 59, 137, 54, 137, 68, 137, 56, 137, 61, 137, 172, 137, 14, 139, 23, 139, 25, 139, 27, 139, 10, 139, 32, 139, 29, 139, 4, 139, 16, 139, 65, 140, 63, 140, 115, 140, 250, 140, 253, 140, 252, 140, 248, 140, 251, 140, 168, 141, 73, 142, 75, 142, 72, 142, 74, 142, 68, 143, 62, 143, 66, 143, 69, 143, 63, 143, 127, 144, 125, 144, 132, 144, 129, 144, 130, 144, 128, 144, 57, 145, 163, 145, 158, 145, 156, 145, 77, 147, 130, 147, 40, 147, 117, 147, 74, 147, 101, 147, 75, 147, 24, 147, 126, 147, 108, 147, 91, 147, 112, 147, 90, 147, 84, 147, 202, 149, 203, 149, 204, 149, 200, 149, 198, 149, 177, 150, 184, 150, 214, 150, 28, 151, 30, 151, 160, 151, 211, 151, 70, 152, 182, 152, 53, 153, 1, 154, 255, 153, 174, 155, 171, 155, 170, 155, 173, 155, 59, 157, 63, 157, 139, 158, 207, 158, 222, 158, 220, 158, 221, 158, 219, 158, 62, 159, 75, 159, 226, 83, 149, 86, 174, 86, 217, 88, 216, 88, 56, 91, 93, 95, 227, 97, 51, 98, 244, 100, 242, 100, 254, 100, 6, 101, 250, 100, 251, 100, 247, 100, 183, 101, 220, 102, 38, 103, 179, 106, 172, 106, 195, 106, 187, 106, 184, 106, 194, 106, 174, 106, 175, 106, 95, 107, 120, 107, 175, 107, 9, 112, 11, 112, 254, 111, 6, 112, 250, 111, 17, 112, 15, 112, 251, 113, 252, 113, 254, 113, 248, 113, 119, 115, 117, 115, 167, 116, 191, 116, 21, 117, 86, 118, 88, 118, 82, 118, 189, 119, 191, 119, 187, 119, 188, 119, 14, 121, 174, 121, 97, 122, 98, 122, 96, 122, 196, 122, 197, 122, 43, 124, 39, 124, 42, 124, 30, 124, 35, 124, 33, 124, 231, 124, 84, 126, 85, 126, 94, 126, 90, 126, 97, 126, 82, 126, 89, 126, 72, 127, 249, 127, 251, 127, 119, 128, 118, 128, 205, 129, 207, 129, 10, 130, 207, 133, 169, 133, 205, 133, 208, 133, 201, 133, 176, 133, 186, 133, 185, 133, 166, 133, 239, 135, 236, 135, 242, 135, 224, 135, 134, 137, 178, 137, 244, 137, 40, 139, 57, 139, 44, 139, 43, 139, 80, 140, 5, 141, 89, 142, 99, 142, 102, 142, 100, 142, 95, 142, 85, 142, 192, 142, 73, 143, 77, 143, 135, 144, 131, 144, 136, 144, 171, 145, 172, 145, 208, 145, 148, 147, 138, 147, 150, 147, 162, 147, 179, 147, 174, 147, 172, 147, 176, 147, 152, 147, 154, 147, 151, 147, 212, 149, 214, 149, 208, 149, 213, 149, 226, 150, 220, 150, 217, 150, 219, 150, 222, 150, 36, 151, 163, 151, 166, 151, 173, 151, 249, 151, 77, 152, 79, 152, 76, 152, 78, 152, 83, 152, 186, 152, 62, 153, 63, 153, 61, 153, 46, 153, 165, 153, 14, 154, 193, 154, 3, 155, 6, 155, 79, 155, 78, 155, 77, 155, 202, 155, 201, 155, 253, 155, 200, 155], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 281828);
	        allocate([192, 155, 81, 157, 93, 157, 96, 157, 224, 158, 21, 159, 44, 159, 51, 81, 165, 86, 222, 88, 223, 88, 226, 88, 245, 91, 144, 159, 236, 94, 242, 97, 247, 97, 246, 97, 245, 97, 0, 101, 15, 101, 224, 102, 221, 102, 229, 106, 221, 106, 218, 106, 211, 106, 27, 112, 31, 112, 40, 112, 26, 112, 29, 112, 21, 112, 24, 112, 6, 114, 13, 114, 88, 114, 162, 114, 120, 115, 122, 115, 189, 116, 202, 116, 227, 116, 135, 117, 134, 117, 95, 118, 97, 118, 199, 119, 25, 121, 177, 121, 107, 122, 105, 122, 62, 124, 63, 124, 56, 124, 61, 124, 55, 124, 64, 124, 107, 126, 109, 126, 121, 126, 105, 126, 106, 126, 133, 127, 115, 126, 182, 127, 185, 127, 184, 127, 216, 129, 233, 133, 221, 133, 234, 133, 213, 133, 228, 133, 229, 133, 247, 133, 251, 135, 5, 136, 13, 136, 249, 135, 254, 135, 96, 137, 95, 137, 86, 137, 94, 137, 65, 139, 92, 139, 88, 139, 73, 139, 90, 139, 78, 139, 79, 139, 70, 139, 89, 139, 8, 141, 10, 141, 124, 142, 114, 142, 135, 142, 118, 142, 108, 142, 122, 142, 116, 142, 84, 143, 78, 143, 173, 143, 138, 144, 139, 144, 177, 145, 174, 145, 225, 147, 209, 147, 223, 147, 195, 147, 200, 147, 220, 147, 221, 147, 214, 147, 226, 147, 205, 147, 216, 147, 228, 147, 215, 147, 232, 147, 220, 149, 180, 150, 227, 150, 42, 151, 39, 151, 97, 151, 220, 151, 251, 151, 94, 152, 88, 152, 91, 152, 188, 152, 69, 153, 73, 153, 22, 154, 25, 154, 13, 155, 232, 155, 231, 155, 214, 155, 219, 155, 137, 157, 97, 157, 114, 157, 106, 157, 108, 157, 146, 158, 151, 158, 147, 158, 180, 158, 248, 82, 168, 86, 183, 86, 182, 86, 180, 86, 188, 86, 228, 88, 64, 91, 67, 91, 125, 91, 246, 91, 201, 93, 248, 97, 250, 97, 24, 101, 20, 101, 25, 101, 230, 102, 39, 103, 236, 106, 62, 112, 48, 112, 50, 112, 16, 114, 123, 115, 207, 116, 98, 118, 101, 118, 38, 121, 42, 121, 44, 121, 43, 121, 199, 122, 246, 122, 76, 124, 67, 124, 77, 124, 239, 124, 240, 124, 174, 143, 125, 126, 124, 126, 130, 126, 76, 127, 0, 128, 218, 129, 102, 130, 251, 133, 249, 133, 17, 134, 250, 133, 6, 134, 11, 134, 7, 134, 10, 134, 20, 136, 21, 136, 100, 137, 186, 137, 248, 137, 112, 139, 108, 139, 102, 139, 111, 139, 95, 139, 107, 139, 15, 141, 13, 141, 137, 142, 129, 142, 133, 142, 130, 142, 180, 145, 203, 145, 24, 148, 3, 148, 253, 147, 225, 149, 48, 151, 196, 152, 82, 153, 81, 153, 168, 153, 43, 154, 48, 154, 55, 154, 53, 154, 19, 156, 13, 156, 121, 158, 181, 158, 232, 158, 47, 159, 95, 159, 99, 159, 97, 159, 55, 81, 56, 81, 193, 86, 192, 86, 194, 86, 20, 89, 108, 92, 205, 93, 252, 97, 254, 97, 29, 101, 28, 101, 149, 101, 233, 102, 251, 106, 4, 107, 250, 106, 178, 107, 76, 112, 27, 114, 167, 114, 214, 116, 212, 116, 105, 118, 211, 119, 80, 124, 143, 126, 140, 126, 188, 127, 23, 134, 45, 134, 26, 134, 35, 136, 34, 136, 33, 136, 31, 136, 106, 137, 108, 137, 189, 137, 116, 139, 119, 139, 125, 139, 19, 141, 138, 142, 141, 142, 139, 142, 95, 143, 175, 143, 186, 145, 46, 148, 51, 148, 53, 148, 58, 148, 56, 148, 50, 148, 43, 148, 226, 149, 56, 151, 57, 151, 50, 151, 255, 151, 103, 152, 101, 152, 87, 153, 69, 154, 67, 154, 64, 154, 62, 154, 207, 154, 84, 155, 81, 155, 45, 156, 37, 156, 175, 157, 180, 157, 194, 157, 184, 157, 157, 158, 239, 158, 25, 159, 92, 159, 102, 159, 103, 159, 60, 81, 59, 81, 200, 86, 202, 86, 201, 86, 127, 91, 212, 93, 210, 93, 78, 95, 255, 97, 36, 101, 10, 107, 97, 107, 81, 112, 88, 112, 128, 115, 228, 116, 138, 117, 110, 118, 108, 118, 179, 121, 96, 124, 95, 124, 126, 128, 125, 128, 223, 129, 114, 137, 111, 137, 252, 137, 128, 139, 22, 141, 23, 141, 145, 142, 147, 142, 97, 143, 72, 145, 68, 148, 81, 148, 82, 148, 61, 151, 62, 151, 195, 151, 193, 151, 107, 152, 85, 153, 85, 154, 77, 154, 210, 154, 26, 155, 73, 156, 49, 156, 62, 156, 59, 156, 211, 157, 215, 157, 52, 159, 108, 159, 106, 159, 148, 159, 204, 86, 214, 93, 0, 98, 35, 101, 43, 101, 42, 101, 236, 102, 16, 107, 218, 116, 202, 122, 100, 124, 99, 124, 101, 124, 147, 126, 150, 126, 148, 126, 226, 129, 56, 134, 63, 134, 49, 136, 138, 139, 144, 144, 143, 144, 99, 148, 96, 148, 100, 148, 104, 151, 111, 152, 92, 153, 90, 154, 91, 154, 87, 154, 211, 154, 212, 154, 209, 154, 84, 156, 87, 156, 86, 156, 229, 157, 159, 158, 244, 158, 209, 86, 233, 88, 44, 101, 94, 112, 113, 118, 114, 118, 215, 119, 80, 127, 136, 127, 54, 136, 57, 136, 98, 136, 147, 139, 146, 139, 150, 139, 119, 130, 27, 141, 192, 145, 106, 148, 66, 151, 72, 151, 68, 151, 198, 151, 112, 152, 95, 154, 34, 155, 88, 155, 95, 156, 249, 157, 250, 157, 124, 158, 125, 158, 7, 159, 119, 159, 114, 159, 243, 94, 22, 107, 99, 112, 108, 124, 110, 124, 59, 136, 192, 137, 161, 142, 193, 145, 114, 148, 112, 148, 113, 152, 94, 153, 214, 154, 35, 155, 204, 158, 100, 112, 218, 119, 154, 139, 119, 148, 201, 151, 98, 154, 101, 154, 156, 126, 156, 139, 170, 142, 197, 145, 125, 148, 126, 148, 124, 148, 119, 156, 120, 156, 247, 158, 84, 140, 127, 148, 26, 158, 40, 114, 106, 154, 49, 155, 27, 158, 30, 158, 114, 124, 96, 36, 97, 36, 98, 36, 99, 36, 100, 36, 101, 36, 102, 36, 103, 36, 104, 36, 105, 36, 116, 36, 117, 36, 118, 36, 119, 36, 120, 36, 121, 36, 122, 36, 123, 36, 124, 36, 125, 36, 112, 33, 113, 33, 114, 33, 115, 33, 116, 33, 117, 33, 118, 33, 119, 33, 120, 33, 121, 33, 54, 78, 63, 78, 133, 78, 160, 78, 130, 81, 150, 81, 171, 81, 249, 82, 56, 83, 105, 83, 182, 83, 10, 89, 128, 91, 219, 93, 122, 94, 127, 94, 244, 94, 80, 95, 97, 95, 52, 101, 224, 101, 146, 117, 118, 118, 181, 143, 182, 150, 168, 0, 198, 2, 253, 48, 254, 48, 157, 48, 158, 48, 0, 0, 0, 0, 5, 48, 6, 48, 7, 48, 252, 48, 59, 255, 61, 255, 61, 39, 65, 48, 66, 48, 67, 48, 68, 48, 69, 48, 70, 48, 71, 48, 72, 48, 73, 48, 74, 48, 75, 48, 76, 48, 77, 48, 78, 48, 79, 48, 80, 48, 81, 48, 82, 48, 83, 48, 84, 48, 85, 48, 86, 48, 87, 48, 88, 48, 89, 48, 90, 48, 91, 48, 92, 48, 93, 48, 94, 48, 95, 48, 96, 48, 97, 48, 98, 48, 99, 48, 100, 48, 101, 48, 102, 48, 103, 48, 104, 48, 105, 48, 106, 48, 107, 48, 108, 48, 109, 48, 110, 48, 111, 48, 112, 48, 113, 48, 114, 48, 115, 48, 116, 48, 117, 48, 118, 48, 119, 48, 120, 48, 121, 48, 122, 48, 123, 48, 124, 48, 125, 48, 126, 48, 127, 48, 128, 48, 129, 48, 130, 48, 131, 48, 132, 48, 133, 48, 134, 48, 135, 48, 136, 48, 137, 48, 138, 48, 139, 48, 140, 48, 141, 48, 142, 48, 143, 48, 144, 48, 145, 48, 146, 48, 147, 48, 161, 48, 162, 48, 163, 48, 164, 48, 165, 48, 166, 48, 167, 48, 168, 48, 169, 48, 170, 48, 171, 48, 172, 48, 173, 48, 174, 48, 175, 48, 176, 48, 177, 48, 178, 48, 179, 48, 180, 48, 181, 48, 182, 48, 183, 48, 184, 48, 185, 48, 186, 48, 187, 48, 188, 48, 189, 48, 190, 48, 191, 48, 192, 48, 193, 48, 194, 48, 195, 48, 196, 48, 197, 48, 198, 48, 199, 48, 200, 48, 201, 48, 202, 48, 203, 48, 204, 48, 205, 48, 206, 48, 207, 48, 208, 48, 209, 48, 210, 48, 211, 48, 212, 48, 213, 48, 214, 48, 215, 48, 216, 48, 217, 48, 218, 48, 219, 48, 220, 48, 221, 48, 222, 48, 223, 48, 224, 48, 225, 48, 226, 48, 227, 48, 228, 48, 229, 48, 230, 48, 231, 48, 232, 48, 233, 48, 234, 48, 235, 48, 236, 48, 237, 48, 238, 48, 239, 48, 240, 48, 241, 48, 242, 48, 243, 48, 244, 48, 245, 48, 246, 48, 16, 4, 17, 4, 18, 4, 19, 4, 20, 4, 21, 4, 1, 4, 22, 4, 23, 4, 24, 4, 25, 4, 26, 4, 27, 4, 28, 4, 29, 4, 30, 4, 31, 4, 32, 4, 33, 4, 34, 4, 35, 4, 36, 4, 37, 4, 38, 4, 39, 4, 40, 4, 41, 4, 42, 4, 43, 4, 44, 4, 45, 4, 46, 4, 47, 4, 48, 4, 49, 4, 50, 4, 51, 4, 52, 4, 53, 4, 81, 4, 54, 4, 55, 4, 56, 4, 57, 4, 58, 4, 59, 4, 60, 4, 61, 4, 62, 4, 63, 4, 64, 4, 65, 4, 66, 4, 67, 4, 68, 4, 69, 4, 70, 4, 71, 4, 72, 4, 73, 4, 74, 4, 75, 4, 76, 4, 77, 4, 78, 4, 79, 4, 231, 33, 184, 33, 185, 33, 207, 49, 204, 0, 90, 78, 138, 0, 2, 82, 145, 68, 176, 159, 136, 81, 177, 159, 7, 118, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 226, 255, 228, 255, 7, 255, 2, 255, 49, 50, 22, 33, 33, 33, 155, 48, 156, 48, 128, 46, 132, 46, 134, 46, 135, 46, 136, 46, 138, 46, 140, 46, 141, 46, 149, 46, 156, 46, 157, 46, 165, 46, 167, 46, 170, 46, 172, 46, 174, 46, 182, 46, 188, 46, 190, 46, 198, 46, 202, 46, 204, 46, 205, 46, 207, 46, 214, 46, 215, 46, 222, 46, 227, 46, 0, 0, 0, 0, 0, 0, 131, 2, 80, 2, 91, 2, 84, 2, 117, 2, 83, 1, 248, 0, 75, 1, 138, 2, 106, 2, 66, 78, 92, 78, 245, 81, 26, 83, 130, 83, 7, 78, 12, 78, 71, 78, 141, 78, 215, 86, 12, 250, 110, 92, 115, 95, 15, 78, 135, 81, 14, 78, 46, 78, 147, 78, 194, 78, 201, 78, 200, 78, 152, 81, 252, 82, 108, 83, 185, 83, 32, 87, 3, 89, 44, 89, 16, 92, 255, 93, 225, 101, 179, 107, 204, 107, 20, 108, 63, 114, 49, 78, 60, 78, 232, 78, 220, 78, 233, 78, 225, 78, 221, 78, 218, 78, 12, 82, 28, 83, 76, 83, 34, 87, 35, 87, 23, 89, 47, 89, 129, 91, 132, 91, 18, 92, 59, 92, 116, 92, 115, 92, 4, 94, 128, 94, 130, 94, 201, 95, 9, 98, 80, 98, 21, 108, 54, 108, 67, 108, 63, 108, 59, 108, 174, 114, 176, 114, 138, 115, 184, 121, 138, 128, 30, 150, 14, 79, 24, 79, 44, 79, 245, 78, 20, 79, 241, 78, 0, 79, 247, 78, 8, 79, 29, 79, 2, 79, 5, 79, 34, 79, 19, 79, 4, 79, 244, 78, 18, 79, 177, 81, 19, 82, 9, 82, 16, 82, 166, 82, 34, 83, 31, 83, 77, 83, 138, 83, 7, 84, 225, 86, 223, 86, 46, 87, 42, 87, 52, 87, 60, 89, 128, 89, 124, 89, 133, 89, 123, 89, 126, 89, 119, 89, 127, 89, 86, 91, 21, 92, 37, 92, 124, 92, 122, 92, 123, 92, 126, 92, 223, 93, 117, 94, 132, 94, 2, 95, 26, 95, 116, 95, 213, 95, 212, 95, 207, 95, 92, 98, 94, 98, 100, 98, 97, 98, 102, 98, 98, 98, 89, 98, 96, 98, 90, 98, 101, 98, 239, 101, 238, 101, 62, 103, 57, 103, 56, 103, 59, 103, 58, 103, 63, 103, 60, 103, 51, 103, 24, 108, 70, 108, 82, 108, 92, 108, 79, 108, 74, 108, 84, 108, 75, 108, 76, 108, 113, 112, 94, 114, 180, 114, 181, 114, 142, 115, 42, 117, 127, 118, 117, 122, 81, 127, 120, 130, 124, 130, 128, 130, 125, 130, 127, 130, 77, 134, 126, 137, 153, 144, 151, 144, 152, 144, 155, 144, 148, 144, 34, 150, 36, 150, 32, 150, 35, 150, 86, 79, 59, 79, 98, 79, 73, 79, 83, 79, 100, 79, 62, 79, 103, 79, 82, 79, 95, 79, 65, 79, 88, 79, 45, 79, 51, 79, 63, 79, 97, 79, 143, 81, 185, 81, 28, 82, 30, 82, 33, 82, 173, 82, 174, 82, 9, 83, 99, 83, 114, 83, 142, 83, 143, 83, 48, 84, 55, 84, 42, 84, 84, 84, 69, 84, 25, 84, 28, 84, 37, 84, 24, 84, 61, 84, 79, 84, 65, 84, 40, 84, 36, 84, 71, 84, 238, 86, 231, 86, 229, 86, 65, 87, 69, 87, 76, 87, 73, 87, 75, 87, 82, 87, 6, 89, 64, 89, 166, 89, 152, 89, 160, 89, 151, 89, 142, 89, 162, 89, 144, 89, 143, 89, 167, 89, 161, 89, 142, 91, 146, 91, 40, 92, 42, 92, 141, 92, 143, 92, 136, 92, 139, 92, 137, 92, 146, 92, 138, 92, 134, 92, 147, 92, 149, 92, 224, 93, 10, 94, 14, 94, 139, 94, 137, 94, 140, 94, 136, 94, 141, 94, 5, 95, 29, 95, 120, 95, 118, 95, 210, 95, 209, 95, 208, 95, 237, 95, 232, 95, 238, 95, 243, 95, 225, 95, 228, 95, 227, 95, 250, 95, 239, 95, 247, 95, 251, 95, 0, 96, 244, 95, 58, 98, 131, 98, 140, 98, 142, 98, 143, 98, 148, 98, 135, 98, 113, 98, 123, 98, 122, 98, 112, 98, 129, 98, 136, 98, 119, 98, 125, 98, 114, 98, 116, 98, 55, 101, 240, 101, 244, 101, 243, 101, 242, 101, 245, 101, 69, 103, 71, 103, 89, 103, 85, 103, 76, 103, 72, 103, 93, 103, 77, 103, 90, 103, 75, 103, 208, 107, 25, 108, 26, 108, 120, 108, 103, 108, 107, 108, 132, 108, 139, 108, 143, 108, 113, 108, 111, 108, 105, 108, 154, 108, 109, 108, 135, 108, 149, 108, 156, 108, 102, 108, 115, 108, 101, 108, 123, 108, 142, 108, 116, 112, 122, 112, 99, 114, 191, 114, 189, 114, 195, 114, 198, 114, 193, 114, 186, 114, 197, 114, 149, 115, 151, 115, 147, 115, 148, 115, 146, 115, 58, 117, 57, 117, 148, 117, 149, 117, 129, 118, 61, 121, 52, 128, 149, 128, 153, 128, 144, 128, 146, 128, 156, 128, 144, 130, 143, 130, 133, 130, 142, 130, 145, 130, 147, 130, 138, 130, 131, 130, 132, 130, 120, 140, 201, 143, 191, 143, 159, 144, 161, 144, 165, 144, 158, 144, 167, 144, 160, 144, 48, 150, 40, 150, 47, 150, 45, 150, 51, 78, 152, 79, 124, 79, 133, 79, 125, 79, 128, 79, 135, 79, 118, 79, 116, 79, 137, 79, 132, 79, 119, 79, 76, 79, 151, 79, 106, 79, 154, 79, 121, 79, 129, 79, 120, 79, 144, 79, 156, 79, 148, 79, 158, 79, 146, 79, 130, 79, 149, 79, 107, 79, 110, 79, 158, 81, 188, 81, 190, 81, 53, 82, 50, 82, 51, 82, 70, 82, 49, 82, 188, 82, 10, 83, 11, 83, 60, 83, 146, 83, 148, 83, 135, 84, 127, 84, 129, 84, 145, 84, 130, 84, 136, 84, 107, 84, 122, 84, 126, 84, 101, 84, 108, 84, 116, 84, 102, 84, 141, 84, 111, 84, 97, 84, 96, 84, 152, 84, 99, 84, 103, 84, 100, 84, 247, 86, 249, 86, 111, 87, 114, 87, 109, 87, 107, 87, 113, 87, 112, 87, 118, 87, 128, 87, 117, 87, 123, 87, 115, 87, 116, 87, 98, 87, 104, 87, 125, 87, 12, 89, 69, 89, 181, 89, 186, 89, 207, 89, 206, 89, 178, 89, 204, 89, 193, 89, 182, 89, 188, 89, 195, 89, 214, 89, 177, 89, 189, 89, 192, 89, 200, 89, 180, 89, 199, 89, 98, 91, 101, 91, 147, 91, 149, 91, 68, 92, 71, 92, 174, 92, 164, 92, 160, 92, 181, 92, 175, 92, 168, 92, 172, 92, 159, 92, 163, 92, 173, 92, 162, 92, 170, 92, 167, 92, 157, 92, 165, 92, 182, 92, 176, 92, 166, 92, 23, 94, 20, 94, 25, 94, 40, 95, 34, 95, 35, 95, 36, 95, 84, 95, 130, 95, 126, 95, 125, 95, 222, 95, 229, 95, 45, 96, 38, 96, 25, 96, 50, 96, 11, 96, 52, 96, 10, 96, 23, 96, 51, 96, 26, 96, 30, 96, 44, 96, 34, 96, 13, 96, 16, 96, 46, 96, 19, 96, 17, 96, 12, 96, 9, 96, 28, 96, 20, 98, 61, 98, 173, 98, 180, 98, 209, 98, 190, 98, 170, 98, 182, 98, 202, 98, 174, 98, 179, 98, 175, 98, 187, 98, 169, 98, 176, 98, 184, 98, 61, 101, 168, 101, 187, 101, 9, 102, 252, 101, 4, 102, 18, 102, 8, 102, 251, 101, 3, 102, 11, 102, 13, 102, 5, 102, 253, 101, 17, 102, 16, 102, 246, 102, 10, 103, 133, 103, 108, 103, 142, 103, 146, 103, 118, 103, 123, 103, 152, 103, 134, 103, 132, 103, 116, 103, 141, 103, 140, 103, 122, 103, 159, 103, 145, 103, 153, 103, 131, 103, 125, 103, 129, 103, 120, 103, 121, 103, 148, 103, 37, 107, 128, 107, 126, 107, 222, 107, 29, 108, 147, 108, 236, 108, 235, 108, 238, 108, 217, 108, 182, 108, 212, 108, 173, 108, 231, 108, 183, 108, 208, 108, 194, 108, 186, 108, 195, 108, 198, 108, 237, 108, 242, 108, 210, 108, 221, 108, 180, 108, 138, 108, 157, 108, 128, 108, 222, 108, 192, 108, 48, 109, 205, 108, 199, 108, 176, 108, 249, 108, 207, 108, 233, 108, 209, 108, 148, 112, 152, 112, 133, 112, 147, 112, 134, 112, 132, 112, 145, 112, 150, 112, 130, 112, 154, 112, 131, 112, 106, 114, 214, 114, 203, 114, 216, 114, 201, 114, 220, 114, 210, 114, 212, 114, 218, 114, 204, 114, 209, 114, 164, 115, 161, 115, 173, 115, 166, 115, 162, 115, 160, 115, 172, 115, 157, 115, 221, 116, 232, 116, 63, 117, 64, 117, 62, 117, 140, 117, 152, 117, 175, 118, 243, 118, 241, 118, 240, 118, 245, 118, 248, 119, 252, 119, 249, 119, 251, 119, 250, 119, 247, 119, 66, 121, 63, 121, 197, 121, 120, 122, 123, 122, 251, 122, 117, 124, 253, 124, 53, 128, 143, 128, 174, 128, 163, 128, 184, 128, 181, 128, 173, 128, 32, 130, 160, 130, 192, 130, 171, 130, 154, 130, 152, 130, 155, 130, 181, 130, 167, 130, 174, 130, 188, 130, 158, 130, 186, 130, 180, 130, 168, 130, 161, 130, 169, 130, 194, 130, 164, 130, 195, 130, 182, 130, 162, 130, 112, 134, 111, 134, 109, 134, 110, 134, 86, 140, 210, 143, 203, 143, 211, 143, 205, 143, 214, 143, 213, 143, 215, 143, 178, 144, 180, 144, 175, 144, 179, 144, 176, 144, 57, 150, 61, 150, 60, 150, 58, 150, 67, 150, 205, 79, 197, 79, 211, 79, 178, 79, 201, 79, 203, 79, 193, 79, 212, 79, 220, 79, 217, 79, 187, 79, 179, 79, 219, 79, 199, 79, 214, 79, 186, 79, 192, 79, 185, 79, 236, 79, 68, 82, 73, 82, 192, 82, 194, 82, 61, 83, 124, 83, 151, 83, 150, 83, 153, 83, 152, 83, 186, 84, 161, 84, 173, 84, 165, 84, 207, 84, 195, 84, 13, 131, 183, 84, 174, 84, 214, 84, 182, 84, 197, 84, 198, 84, 160, 84, 112, 84, 188, 84, 162, 84, 190, 84, 114, 84, 222, 84, 176, 84, 181, 87, 158, 87, 159, 87, 164, 87, 140, 87, 151, 87, 157, 87, 155, 87, 148, 87, 152, 87, 143, 87, 153, 87, 165, 87, 154, 87, 149, 87, 244, 88, 13, 89, 83, 89, 225, 89, 222, 89, 238, 89, 0, 90, 241, 89, 221, 89, 250, 89, 253, 89, 252, 89, 246, 89, 228, 89, 242, 89, 247, 89, 219, 89, 233, 89, 243, 89, 245, 89, 224, 89, 254, 89, 244, 89, 237, 89, 168, 91, 76, 92, 208, 92, 216, 92, 204, 92, 215, 92, 203, 92, 219, 92, 222, 92, 218, 92, 201, 92, 199, 92, 202, 92, 214, 92, 211, 92, 212, 92, 207, 92, 200, 92, 198, 92, 206, 92, 223, 92, 248, 92, 249, 93, 33, 94, 34, 94, 35, 94, 32, 94, 36, 94, 176, 94, 164, 94, 162, 94, 155, 94, 163, 94, 165, 94, 7, 95, 46, 95, 86, 95, 134, 95, 55, 96, 57, 96, 84, 96, 114, 96, 94, 96, 69, 96, 83, 96, 71, 96, 73, 96, 91, 96, 76, 96, 64, 96, 66, 96, 95, 96, 36, 96, 68, 96, 88, 96, 102, 96, 110, 96, 66, 98, 67, 98, 207, 98, 13, 99, 11, 99, 245, 98, 14, 99, 3, 99, 235, 98, 249, 98, 15, 99, 12, 99, 248, 98, 246, 98, 0, 99, 19, 99, 20, 99, 250, 98, 21, 99, 251, 98, 240, 98, 65, 101, 67, 101, 170, 101, 191, 101, 54, 102, 33, 102, 50, 102, 53, 102, 28, 102, 38, 102, 34, 102, 51, 102, 43, 102, 58, 102, 29, 102, 52, 102, 57, 102, 46, 102, 15, 103, 16, 103, 193, 103, 242, 103, 200, 103, 186, 103, 220, 103, 187, 103, 248, 103, 216, 103, 192, 103, 183, 103, 197, 103, 235, 103, 228, 103, 223, 103, 181, 103, 205, 103, 179, 103, 247, 103, 246, 103, 238, 103, 227, 103, 194, 103, 185, 103, 206, 103, 231, 103, 240, 103, 178, 103, 252, 103, 198, 103, 237, 103, 204, 103, 174, 103, 230, 103, 219, 103, 250, 103, 201, 103, 202, 103, 195, 103, 234, 103, 203, 103, 40, 107, 130, 107, 132, 107, 182, 107, 214, 107, 216, 107, 224, 107, 32, 108, 33, 108, 40, 109, 52, 109, 45, 109, 31, 109, 60, 109, 63, 109, 18, 109, 10, 109, 218, 108, 51, 109, 4, 109, 25, 109, 58, 109, 26, 109, 17, 109, 0, 109, 29, 109, 66, 109, 1, 109, 24, 109, 55, 109, 3, 109, 15, 109, 64, 109, 7, 109, 32, 109, 44, 109, 8, 109, 34, 109, 9, 109, 16, 109, 183, 112, 159, 112, 190, 112, 177, 112, 176, 112, 161, 112, 180, 112, 181, 112, 169, 112, 65, 114, 73, 114, 74, 114, 108, 114, 112, 114, 115, 114, 110, 114, 202, 114, 228, 114, 232, 114, 235, 114, 223, 114, 234, 114, 230, 114, 227, 114, 133, 115, 204, 115, 194, 115, 200, 115, 197, 115, 185, 115, 182, 115, 181, 115, 180, 115, 235, 115, 191, 115, 199, 115, 190, 115, 195, 115, 198, 115, 184, 115, 203, 115, 236, 116, 238, 116, 46, 117, 71, 117, 72, 117, 167, 117, 170, 117, 121, 118, 196, 118, 8, 119, 3, 119, 4, 119, 5, 119, 10, 119, 247, 118, 251, 118, 250, 118, 231, 119, 232, 119, 6, 120, 17, 120, 18, 120, 5, 120, 16, 120, 15, 120, 14, 120, 9, 120, 3, 120, 19, 120, 74, 121, 76, 121, 75, 121, 69, 121, 68, 121, 213, 121, 205, 121, 207, 121, 214, 121, 206, 121, 128, 122, 126, 122, 209, 122, 0, 123, 1, 123, 122, 124, 120, 124, 121, 124, 127, 124, 128, 124, 129, 124, 3, 125, 8, 125, 1, 125, 88, 127, 145, 127, 141, 127, 190, 127, 7, 128, 14, 128, 15, 128, 20, 128, 55, 128, 216, 128, 199, 128, 224, 128, 209, 128, 200, 128, 194, 128, 208, 128, 197, 128, 227, 128, 217, 128, 220, 128, 202, 128, 213, 128, 201, 128, 207, 128, 215, 128, 230, 128, 205, 128, 255, 129, 33, 130, 148, 130, 217, 130, 254, 130, 249, 130, 7, 131, 232, 130, 0, 131, 213, 130, 58, 131, 235, 130, 214, 130, 244, 130, 236, 130, 225, 130, 242, 130, 245, 130, 12, 131, 251, 130, 246, 130, 240, 130, 234, 130, 228, 130, 224, 130, 250, 130, 243, 130, 237, 130, 119, 134, 116, 134, 124, 134, 115, 134, 65, 136, 78, 136, 103, 136, 106, 136, 105, 136, 211, 137, 4, 138, 7, 138, 114, 141, 227, 143, 225, 143, 238, 143, 224, 143, 241, 144, 189, 144, 191, 144, 213, 144, 197, 144, 190, 144, 199, 144, 203, 144, 200, 144, 212, 145, 211, 145, 84, 150, 79, 150, 81, 150, 83, 150, 74, 150, 78, 150, 30, 80, 5, 80, 7, 80, 19, 80, 34, 80, 48, 80, 27, 80, 245, 79, 244, 79, 51, 80, 55, 80, 44, 80, 246, 79, 247, 79, 23, 80, 28, 80, 32, 80, 39, 80, 53, 80, 47, 80, 49, 80, 14, 80, 90, 81, 148, 81, 147, 81, 202, 81, 196, 81, 197, 81, 200, 81, 206, 81, 97, 82, 90, 82, 82, 82, 94, 82, 95, 82, 85, 82, 98, 82, 205, 82, 14, 83, 158, 83, 38, 85, 226, 84, 23, 85, 18, 85, 231, 84, 243, 84, 228, 84, 26, 85, 255, 84, 4, 85, 8, 85, 235, 84, 17, 85, 5, 85, 241, 84, 10, 85, 251, 84, 247, 84, 248, 84, 224, 84, 14, 85, 3, 85, 11, 85, 1, 87, 2, 87, 204, 87, 50, 88, 213, 87, 210, 87, 186, 87, 198, 87, 189, 87, 188, 87, 184, 87, 182, 87, 191, 87, 199, 87, 208, 87, 185, 87, 193, 87, 14, 89, 74, 89, 25, 90, 22, 90, 45, 90, 46, 90, 21, 90, 15, 90, 23, 90, 10, 90, 30, 90, 51, 90, 108, 91, 167, 91, 173, 91, 172, 91, 3, 92, 86, 92, 84, 92, 236, 92, 255, 92, 238, 92, 241, 92, 247, 92, 0, 93, 249, 92, 41, 94, 40, 94, 168, 94, 174, 94, 170, 94, 172, 94, 51, 95, 48, 95, 103, 95, 93, 96, 90, 96, 103, 96, 65, 96, 162, 96, 136, 96, 128, 96, 146, 96, 129, 96, 157, 96, 131, 96, 149, 96, 155, 96, 151, 96, 135, 96, 156, 96, 142, 96, 25, 98, 70, 98, 242, 98, 16, 99, 86, 99, 44, 99, 68, 99, 69, 99, 54, 99, 67, 99, 228, 99, 57, 99, 75, 99, 74, 99, 60, 99, 41, 99, 65, 99, 52, 99, 88, 99, 84, 99, 89, 99, 45, 99, 71, 99, 51, 99, 90, 99, 81, 99, 56, 99, 87, 99, 64, 99, 72, 99, 74, 101, 70, 101, 198, 101, 195, 101, 196, 101, 194, 101, 74, 102, 95, 102, 71, 102, 81, 102, 18, 103, 19, 103, 31, 104, 26, 104, 73, 104, 50, 104, 51, 104, 59, 104, 75, 104, 79, 104, 22, 104, 49, 104, 28, 104, 53, 104, 43, 104, 45, 104, 47, 104, 78, 104, 68, 104, 52, 104, 29, 104, 18, 104, 20, 104, 38, 104, 40, 104, 46, 104, 77, 104, 58, 104, 37, 104, 32, 104, 44, 107, 47, 107, 45, 107, 49, 107, 52, 107, 109, 107, 130, 128, 136, 107, 230, 107, 228, 107, 232, 107, 227, 107, 226, 107, 231, 107, 37, 108, 122, 109, 99, 109, 100, 109, 118, 109, 13, 109, 97, 109, 146, 109, 88, 109, 98, 109, 109, 109, 111, 109, 145, 109, 141, 109, 239, 109, 127, 109, 134, 109, 94, 109, 103, 109, 96, 109, 151, 109, 112, 109, 124, 109, 95, 109, 130, 109, 152, 109, 47, 109, 104, 109, 139, 109, 126, 109, 128, 109, 132, 109, 22, 109, 131, 109, 123, 109, 125, 109, 117, 109, 144, 109, 220, 112, 211, 112, 209, 112, 221, 112, 203, 112, 57, 127, 226, 112, 215, 112, 210, 112, 222, 112, 224, 112, 212, 112, 205, 112, 197, 112, 198, 112, 199, 112, 218, 112, 206, 112, 225, 112, 66, 114, 120, 114, 119, 114, 118, 114, 0, 115, 250, 114, 244, 114, 254, 114, 246, 114, 243, 114, 251, 114, 1, 115, 211, 115, 217, 115, 229, 115, 214, 115, 188, 115, 231, 115, 227, 115, 233, 115, 220, 115, 210, 115, 219, 115, 212, 115, 221, 115, 218, 115, 215, 115, 216, 115, 232, 115, 222, 116, 223, 116, 244, 116, 245, 116, 33, 117, 91, 117, 95, 117, 176, 117, 193, 117, 187, 117, 196, 117, 192, 117, 191, 117, 182, 117, 186, 117, 138, 118, 201, 118, 29, 119, 27, 119, 16, 119, 19, 119, 18, 119, 35, 119, 17, 119, 21, 119, 25, 119, 26, 119, 34, 119, 39, 119, 35, 120, 44, 120, 34, 120, 53, 120, 47, 120, 40, 120, 46, 120, 43, 120, 33, 120, 41, 120, 51, 120, 42, 120, 49, 120, 84, 121, 91, 121, 79, 121, 92, 121, 83, 121, 82, 121, 81, 121, 235, 121, 236, 121, 224, 121, 238, 121, 237, 121, 234, 121, 220, 121, 222, 121, 221, 121, 134, 122, 137, 122, 133, 122, 139, 122, 140, 122, 138, 122, 135, 122, 216, 122, 16, 123, 4, 123, 19, 123, 5, 123, 15, 123, 8, 123, 10, 123, 14, 123, 9, 123, 18, 123, 132, 124, 145, 124, 138, 124, 140, 124, 136, 124, 141, 124, 133, 124, 30, 125, 29, 125, 17, 125, 14, 125, 24, 125, 22, 125, 19, 125, 31, 125, 18, 125, 15, 125, 12, 125, 92, 127, 97, 127, 94, 127, 96, 127, 93, 127, 91, 127, 150, 127, 146, 127, 195, 127, 194, 127, 192, 127, 22, 128, 62, 128, 57, 128, 250, 128, 242, 128, 249, 128, 245, 128, 1, 129, 251, 128, 0, 129, 1, 130, 47, 130, 37, 130, 51, 131, 45, 131, 68, 131, 25, 131, 81, 131, 37, 131, 86, 131, 63, 131, 65, 131, 38, 131, 28, 131, 34, 131, 66, 131, 78, 131, 27, 131, 42, 131, 8, 131, 60, 131, 77, 131, 22, 131, 36, 131, 32, 131, 55, 131, 47, 131, 41, 131, 71, 131, 69, 131, 76, 131, 83, 131, 30, 131, 44, 131, 75, 131, 39, 131, 72, 131, 83, 134, 82, 134, 162, 134, 168, 134, 150, 134, 141, 134, 145, 134, 158, 134, 135, 134, 151, 134, 134, 134, 139, 134, 154, 134, 133, 134, 165, 134, 153, 134, 161, 134, 167, 134, 149, 134, 152, 134, 142, 134, 157, 134, 144, 134, 148, 134, 67, 136, 68, 136, 109, 136, 117, 136, 118, 136, 114, 136, 128, 136, 113, 136, 127, 136, 111, 136, 131, 136, 126, 136, 116, 136, 124, 136, 18, 138, 71, 140, 87, 140, 123, 140, 164, 140, 163, 140, 118, 141, 120, 141, 181, 141, 183, 141, 182, 141, 209, 142, 211, 142, 254, 143, 245, 143, 2, 144, 255, 143, 251, 143, 4, 144, 252, 143, 246, 143, 214, 144, 224, 144, 217, 144, 218, 144, 227, 144, 223, 144, 229, 144, 216, 144, 219, 144, 215, 144, 220, 144, 228, 144, 80, 145, 78, 145, 79, 145, 213, 145, 226, 145, 218, 145, 92, 150, 95, 150, 188, 150, 227, 152, 223, 154, 47, 155, 127, 78, 112, 80, 106, 80, 97, 80, 94, 80, 96, 80, 83, 80, 75, 80, 93, 80, 114, 80, 72, 80, 77, 80, 65, 80, 91, 80, 74, 80, 98, 80, 21, 80, 69, 80, 95, 80, 105, 80, 107, 80, 99, 80, 100, 80, 70, 80, 64, 80, 110, 80, 115, 80, 87, 80, 81, 80, 208, 81, 107, 82, 109, 82, 108, 82, 110, 82, 214, 82, 211, 82, 45, 83, 156, 83, 117, 85, 118, 85, 60, 85, 77, 85, 80, 85, 52, 85, 42, 85, 81, 85, 98, 85, 54, 85, 53, 85, 48, 85, 82, 85, 69, 85, 12, 85, 50, 85, 101, 85, 78, 85, 57, 85, 72, 85, 45, 85, 59, 85, 64, 85, 75, 85, 10, 87, 7, 87, 251, 87, 20, 88, 226, 87, 246, 87, 220, 87, 244, 87, 0, 88, 237, 87, 253, 87, 8, 88, 248, 87, 11, 88, 243, 87, 207, 87, 7, 88, 238, 87, 227, 87, 242, 87, 229, 87, 236, 87, 225, 87, 14, 88, 252, 87, 16, 88, 231, 87, 1, 88, 12, 88, 241, 87, 233, 87, 240, 87, 13, 88, 4, 88, 92, 89, 96, 90, 88, 90, 85, 90, 103, 90, 94, 90, 56, 90, 53, 90, 109, 90, 80, 90, 95, 90, 101, 90, 108, 90, 83, 90, 100, 90, 87, 90, 67, 90, 93, 90, 82, 90, 68, 90, 91, 90, 72, 90, 142, 90, 62, 90, 77, 90, 57, 90, 76, 90, 112, 90, 105, 90, 71, 90, 81, 90, 86, 90, 66, 90, 92, 90, 114, 91, 110, 91, 193, 91, 192, 91, 89, 92, 30, 93, 11, 93, 29, 93, 26, 93, 32, 93, 12, 93, 40, 93, 13, 93, 38, 93, 37, 93, 15, 93, 48, 93, 18, 93, 35, 93, 31, 93, 46, 93, 62, 94, 52, 94, 177, 94, 180, 94, 185, 94, 178, 94, 179, 94, 54, 95, 56, 95, 155, 95, 150, 95, 159, 95, 138, 96, 144, 96, 134, 96, 190, 96, 176, 96, 186, 96, 211, 96, 212, 96, 207, 96, 228, 96, 217, 96, 221, 96, 200, 96, 177, 96, 219, 96, 183, 96, 202, 96, 191, 96, 195, 96, 205, 96, 192, 96, 50, 99, 101, 99, 138, 99, 130, 99, 125, 99, 189, 99, 158, 99, 173, 99, 157, 99, 151, 99, 171, 99, 142, 99, 111, 99, 135, 99, 144, 99, 110, 99, 175, 99, 117, 99, 156, 99, 109, 99, 174, 99, 124, 99, 164, 99, 59, 99, 159, 99, 120, 99, 133, 99, 129, 99, 145, 99, 141, 99, 112, 99, 83, 101, 205, 101, 101, 102, 97, 102, 91, 102, 89, 102, 92, 102, 98, 102, 24, 103, 121, 104, 135, 104, 144, 104, 156, 104, 109, 104, 110, 104, 174, 104, 171, 104, 86, 105, 111, 104, 163, 104, 172, 104, 169, 104, 117, 104, 116, 104, 178, 104, 143, 104, 119, 104, 146, 104, 124, 104, 107, 104, 114, 104, 170, 104, 128, 104, 113, 104, 126, 104, 155, 104, 150, 104, 139, 104, 160, 104, 137, 104, 164, 104, 120, 104, 123, 104, 145, 104, 140, 104, 138, 104, 125, 104, 54, 107, 51, 107, 55, 107, 56, 107, 145, 107, 143, 107, 141, 107, 142, 107, 140, 107, 42, 108, 192, 109, 171, 109, 180, 109, 179, 109, 116, 110, 172, 109, 233, 109, 226, 109, 183, 109, 246, 109, 212, 109, 0, 110, 200, 109, 224, 109, 223, 109, 214, 109, 190, 109, 229, 109, 220, 109, 221, 109, 219, 109, 244, 109, 202, 109, 189, 109, 237, 109, 240, 109, 186, 109, 213, 109, 194, 109, 207, 109, 201, 109, 208, 109, 242, 109, 211, 109, 253, 109, 215, 109, 205, 109, 227, 109, 187, 109, 250, 112, 13, 113, 247, 112, 23, 113, 244, 112, 12, 113, 240, 112, 4, 113, 243, 112, 16, 113, 252, 112, 255, 112, 6, 113, 19, 113, 0, 113, 248, 112, 246, 112, 11, 113, 2, 113, 14, 113, 126, 114, 123, 114, 124, 114, 127, 114, 29, 115, 23, 115, 7, 115, 17, 115, 24, 115, 10, 115, 8, 115, 255, 114, 15, 115, 30, 115, 136, 115, 246, 115, 248, 115, 245, 115, 4, 116, 1, 116, 253, 115, 7, 116, 0, 116, 250, 115, 252, 115, 255, 115, 12, 116, 11, 116, 244, 115, 8, 116, 100, 117, 99, 117, 206, 117, 210, 117, 207, 117, 203, 117, 204, 117, 209, 117, 208, 117, 143, 118, 137, 118, 211, 118, 57, 119, 47, 119, 45, 119, 49, 119, 50, 119, 52, 119, 51, 119, 61, 119, 37, 119, 59, 119, 53, 119, 72, 120, 82, 120, 73, 120, 77, 120, 74, 120, 76, 120, 38, 120, 69, 120, 80, 120, 100, 121, 103, 121, 105, 121, 106, 121, 99, 121, 107, 121, 97, 121, 187, 121, 250, 121, 248, 121, 246, 121, 247, 121, 143, 122, 148, 122, 144, 122, 53, 123, 71, 123, 52, 123, 37, 123, 48, 123, 34, 123, 36, 123, 51, 123, 24, 123, 42, 123, 29, 123, 49, 123, 43, 123, 45, 123, 47, 123, 50, 123, 56, 123, 26, 123, 35, 123, 148, 124, 152, 124, 150, 124, 163, 124, 53, 125, 61, 125, 56, 125, 54, 125, 58, 125, 69, 125, 44, 125, 41, 125, 65, 125, 71, 125, 62, 125, 63, 125, 74, 125, 59, 125, 40, 125, 99, 127, 149, 127, 156, 127, 157, 127, 155, 127, 202, 127, 203, 127, 205, 127, 208, 127, 209, 127, 199, 127, 207, 127, 201, 127, 31, 128, 30, 128, 27, 128, 71, 128, 67, 128, 72, 128, 24, 129, 37, 129, 25, 129, 27, 129, 45, 129, 31, 129, 44, 129, 30, 129, 33, 129, 21, 129, 39, 129, 29, 129, 34, 129, 17, 130, 56, 130, 51, 130, 58, 130, 52, 130, 50, 130, 116, 130, 144, 131, 163, 131, 168, 131, 141, 131, 122, 131, 115, 131, 164, 131, 116, 131, 143, 131, 129, 131, 149, 131, 153, 131, 117, 131, 148, 131, 169, 131, 125, 131, 131, 131, 140, 131, 157, 131, 155, 131, 170, 131, 139, 131, 126, 131, 165, 131, 175, 131, 136, 131, 151, 131, 176, 131, 127, 131, 166, 131, 135, 131, 174, 131, 118, 131, 154, 131, 89, 134, 86, 134, 191, 134, 183, 134, 194, 134, 193, 134, 197, 134, 186, 134, 176, 134, 200, 134, 185, 134, 179, 134, 184, 134, 204, 134, 180, 134, 187, 134, 188, 134, 195, 134, 189, 134, 190, 134, 82, 136, 137, 136, 149, 136, 168, 136, 162, 136, 170, 136, 154, 136, 145, 136, 161, 136, 159, 136, 152, 136, 167, 136, 153, 136, 155, 136, 151, 136, 164, 136, 172, 136, 140, 136, 147, 136, 142, 136, 130, 137, 214, 137, 217, 137, 213, 137, 48, 138, 39, 138, 44, 138, 30, 138, 57, 140, 59, 140, 92, 140, 93, 140, 125, 140, 165, 140, 125, 141, 123, 141, 121, 141, 188, 141, 194, 141, 185, 141, 191, 141, 193, 141, 216, 142, 222, 142, 221, 142, 220, 142, 215, 142, 224, 142, 225, 142, 36, 144, 11, 144, 17, 144, 28, 144, 12, 144, 33, 144, 239, 144, 234, 144, 240, 144, 244, 144, 242, 144, 243, 144, 212, 144, 235, 144, 236, 144, 233, 144, 86, 145, 88, 145, 90, 145, 83, 145, 85, 145, 236, 145, 244, 145, 241, 145, 243, 145, 248, 145, 228, 145, 249, 145, 234, 145, 235, 145, 247, 145, 232, 145, 238, 145, 122, 149, 134, 149, 136, 149, 124, 150, 109, 150, 107, 150, 113, 150, 111, 150, 191, 150, 106, 151, 4, 152, 229, 152, 151, 153, 155, 80, 149, 80, 148, 80, 158, 80, 139, 80, 163, 80, 131, 80, 140, 80, 142, 80, 157, 80, 104, 80, 156, 80, 146, 80, 130, 80, 135, 80, 95, 81, 212, 81, 18, 83, 17, 83, 164, 83, 167, 83, 145, 85, 168, 85, 165, 85, 173, 85, 119, 85, 69, 86, 162, 85, 147, 85, 136, 85, 143, 85, 181, 85, 129, 85, 163, 85, 146, 85, 164, 85, 125, 85, 140, 85, 166, 85, 127, 85, 149, 85, 161, 85, 142, 85, 12, 87, 41, 88, 55, 88, 25, 88, 30, 88, 39, 88, 35, 88, 40, 88, 245, 87, 72, 88, 37, 88, 28, 88, 27, 88, 51, 88, 63, 88, 54, 88, 46, 88, 57, 88, 56, 88, 45, 88, 44, 88, 59, 88, 97, 89, 175, 90, 148, 90, 159, 90, 122, 90, 162, 90, 158, 90, 120, 90, 166, 90, 124, 90, 165, 90, 172, 90, 149, 90, 174, 90, 55, 90, 132, 90, 138, 90, 151, 90, 131, 90, 139, 90, 169, 90, 123, 90, 125, 90, 140, 90, 156, 90, 143, 90, 147, 90, 157, 90, 234, 91, 205, 91, 203, 91, 212, 91, 209, 91, 202, 91, 206, 91, 12, 92, 48, 92, 55, 93, 67, 93, 107, 93, 65, 93, 75, 93, 63, 93, 53, 93, 81, 93, 78, 93, 85, 93, 51, 93, 58, 93, 82, 93, 61, 93, 49, 93, 89, 93, 66, 93, 57, 93, 73, 93, 56, 93, 60, 93, 50, 93, 54, 93, 64, 93, 69, 93, 68, 94, 65, 94, 88, 95, 166, 95, 165, 95, 171, 95, 201, 96, 185, 96, 204, 96, 226, 96, 206, 96, 196, 96, 20, 97, 242, 96, 10, 97, 22, 97, 5, 97, 245, 96, 19, 97, 248, 96, 252, 96, 254, 96, 193, 96, 3, 97, 24, 97, 29, 97, 16, 97, 255, 96, 4, 97, 11, 97, 74, 98, 148, 99, 177, 99, 176, 99, 206, 99, 229, 99, 232, 99, 239, 99, 195, 99, 157, 100, 243, 99, 202, 99, 224, 99, 246, 99, 213, 99, 242, 99, 245, 99, 97, 100, 223, 99, 190, 99, 221, 99, 220, 99, 196, 99, 216, 99, 211, 99, 194, 99, 199, 99, 204, 99, 203, 99, 200, 99, 240, 99, 215, 99, 217, 99, 50, 101, 103, 101, 106, 101, 100, 101, 92, 101, 104, 101, 101, 101, 140, 101, 157, 101, 158, 101, 174, 101, 208, 101, 210, 101, 124, 102, 108, 102, 123, 102, 128, 102, 113, 102, 121, 102, 106, 102, 114, 102, 1, 103, 12, 105, 211, 104, 4, 105, 220, 104, 42, 105, 236, 104, 234, 104, 241, 104, 15, 105, 214, 104, 247, 104, 235, 104, 228, 104, 246, 104, 19, 105, 16, 105, 243, 104, 225, 104, 7, 105, 204, 104, 8, 105, 112, 105, 180, 104, 17, 105, 239, 104, 198, 104, 20, 105, 248, 104, 208, 104, 253, 104, 252, 104, 232, 104, 11, 105, 10, 105, 23, 105, 206, 104, 200, 104, 221, 104, 222, 104, 230, 104, 244, 104, 209, 104, 6, 105, 212, 104, 233, 104, 21, 105, 37, 105, 199, 104, 57, 107, 59, 107, 63, 107, 60, 107, 148, 107, 151, 107, 153, 107, 149, 107, 189, 107, 240, 107, 242, 107, 243, 107, 48, 108, 252, 109, 70, 110, 71, 110, 31, 110, 73, 110, 136, 110, 60, 110, 61, 110, 69, 110, 98, 110, 43, 110, 63, 110, 65, 110, 93, 110, 115, 110, 28, 110, 51, 110, 75, 110, 64, 110, 81, 110, 59, 110, 3, 110, 46, 110, 94, 110, 104, 110, 92, 110, 97, 110, 49, 110, 40, 110, 96, 110, 113, 110, 107, 110, 57, 110, 34, 110, 48, 110, 83, 110, 101, 110, 39, 110, 120, 110, 100, 110, 119, 110, 85, 110, 121, 110, 82, 110, 102, 110, 53, 110, 54, 110, 90, 110, 32, 113, 30, 113, 47, 113, 251, 112, 46, 113, 49, 113, 35, 113, 37, 113, 34, 113, 50, 113, 31, 113, 40, 113, 58, 113, 27, 113, 75, 114, 90, 114, 136, 114, 137, 114, 134, 114, 133, 114, 139, 114, 18, 115, 11, 115, 48, 115, 34, 115, 49, 115, 51, 115, 39, 115, 50, 115, 45, 115, 38, 115, 35, 115, 53, 115, 12, 115, 46, 116, 44, 116, 48, 116, 43, 116, 22, 116, 26, 116, 33, 116, 45, 116, 49, 116, 36, 116, 35, 116, 29, 116, 41, 116, 32, 116, 50, 116, 251, 116, 47, 117, 111, 117, 108, 117, 231, 117, 218, 117, 225, 117, 230, 117, 221, 117, 223, 117, 228, 117, 215, 117, 149, 118, 146, 118, 218, 118, 70, 119, 71, 119, 68, 119, 77, 119, 69, 119, 74, 119, 78, 119, 75, 119, 76, 119, 222, 119, 236, 119, 96, 120, 100, 120, 101, 120, 92, 120, 109, 120, 113, 120, 106, 120, 110, 120, 112, 120, 105, 120, 104, 120, 94, 120, 98, 120, 116, 121, 115, 121, 114, 121, 112, 121, 2, 122, 10, 122, 3, 122, 12, 122, 4, 122, 153, 122, 230, 122, 228, 122, 74, 123, 59, 123, 68, 123, 72, 123, 76, 123, 78, 123, 64, 123, 88, 123, 69, 123, 162, 124, 158, 124, 168, 124, 161, 124, 88, 125, 111, 125, 99, 125, 83, 125, 86, 125, 103, 125, 106, 125, 79, 125, 109, 125, 92, 125, 107, 125, 82, 125, 84, 125, 105, 125, 81, 125, 95, 125, 78, 125, 62, 127, 63, 127, 101, 127, 102, 127, 162, 127, 160, 127, 161, 127, 215, 127, 81, 128, 79, 128, 80, 128, 254, 128, 212, 128, 67, 129, 74, 129, 82, 129, 79, 129, 71, 129, 61, 129, 77, 129, 58, 129, 230, 129, 238, 129, 247, 129, 248, 129, 249, 129, 4, 130, 60, 130, 61, 130, 63, 130, 117, 130, 59, 131, 207, 131, 249, 131, 35, 132, 192, 131, 232, 131, 18, 132, 231, 131, 228, 131, 252, 131, 246, 131, 16, 132, 198, 131, 200, 131, 235, 131, 227, 131, 191, 131, 1, 132, 221, 131, 229, 131, 216, 131, 255, 131, 225, 131, 203, 131, 206, 131, 214, 131, 245, 131, 201, 131, 9, 132, 15, 132, 222, 131, 17, 132, 6, 132, 194, 131, 243, 131, 213, 131, 250, 131, 199, 131, 209, 131, 234, 131, 19, 132, 195, 131, 236, 131, 238, 131, 196, 131, 251, 131, 215, 131, 226, 131, 27, 132, 219, 131, 254, 131, 216, 134, 226, 134, 230, 134, 211, 134, 227, 134, 218, 134, 234, 134, 221, 134, 235, 134, 220, 134, 236, 134, 233, 134, 215, 134, 232, 134, 209, 134, 72, 136, 86, 136, 85, 136, 186, 136, 215, 136, 185, 136, 184, 136, 192, 136, 190, 136, 182, 136, 188, 136, 183, 136, 189, 136, 178, 136, 1, 137, 201, 136, 149, 137, 152, 137, 151, 137, 221, 137, 218, 137, 219, 137, 78, 138, 77, 138, 57, 138, 89, 138, 64, 138, 87, 138, 88, 138, 68, 138, 69, 138, 82, 138, 72, 138, 81, 138, 74, 138, 76, 138, 79, 138, 95, 140, 129, 140, 128, 140, 186, 140, 190, 140, 176, 140, 185, 140, 181, 140, 132, 141, 128, 141, 137, 141, 216, 141, 211, 141, 205, 141, 199, 141, 214, 141, 220, 141, 207, 141, 213, 141, 217, 141, 200, 141, 215, 141, 197, 141, 239, 142, 247, 142, 250, 142, 249, 142, 230, 142, 238, 142, 229, 142, 245, 142, 231, 142, 232, 142, 246, 142, 235, 142, 241, 142, 236, 142, 244, 142, 233, 142, 45, 144, 52, 144, 47, 144, 6, 145, 44, 145, 4, 145, 255, 144, 252, 144, 8, 145, 249, 144, 251, 144, 1, 145, 0, 145, 7, 145, 5, 145, 3, 145, 97, 145, 100, 145, 95, 145, 98, 145, 96, 145, 1, 146, 10, 146, 37, 146, 3, 146, 26, 146, 38, 146, 15, 146, 12, 146, 0, 146, 18, 146, 255, 145, 253, 145, 6, 146, 4, 146, 39, 146, 2, 146, 28, 146, 36, 146, 25, 146, 23, 146, 5, 146, 22, 146, 123, 149, 141, 149, 140, 149, 144, 149, 135, 150, 126, 150, 136, 150, 137, 150, 131, 150, 128, 150, 194, 150, 200, 150, 195, 150, 241, 150, 240, 150, 108, 151, 112, 151, 110, 151, 7, 152, 169, 152, 235, 152, 230, 156, 249, 158, 131, 78, 132, 78, 182, 78, 189, 80, 191, 80, 198, 80, 174, 80, 196, 80, 202, 80, 180, 80, 200, 80, 194, 80, 176, 80, 193, 80, 186, 80, 177, 80, 203, 80, 201, 80, 182, 80, 184, 80, 215, 81, 122, 82, 120, 82, 123, 82, 124, 82, 195, 85, 219, 85, 204, 85, 208, 85, 203, 85, 202, 85, 221, 85, 192, 85, 212, 85, 196, 85, 233, 85, 191, 85, 210, 85, 141, 85, 207, 85, 213, 85, 226, 85, 214, 85, 200, 85, 242, 85, 205, 85, 217, 85, 194, 85, 20, 87, 83, 88, 104, 88, 100, 88, 79, 88, 77, 88, 73, 88, 111, 88, 85, 88, 78, 88, 93, 88, 89, 88, 101, 88, 91, 88, 61, 88, 99, 88, 113, 88, 252, 88, 199, 90, 196, 90, 203, 90, 186, 90, 184, 90, 177, 90, 181, 90, 176, 90, 191, 90, 200, 90, 187, 90, 198, 90, 183, 90, 192, 90, 202, 90, 180, 90, 182, 90, 205, 90, 185, 90, 144, 90, 214, 91, 216, 91, 217, 91, 31, 92, 51, 92, 113, 93, 99, 93, 74, 93, 101, 93, 114, 93, 108, 93, 94, 93, 104, 93, 103, 93, 98, 93, 240, 93, 79, 94, 78, 94, 74, 94, 77, 94, 75, 94, 197, 94, 204, 94, 198, 94, 203, 94, 199, 94, 64, 95, 175, 95, 173, 95, 247, 96, 73, 97, 74, 97, 43, 97, 69, 97, 54, 97, 50, 97, 46, 97, 70, 97, 47, 97, 79, 97, 41, 97, 64, 97, 32, 98, 104, 145, 35, 98, 37, 98, 36, 98, 197, 99, 241, 99, 235, 99, 16, 100, 18, 100, 9, 100, 32, 100, 36, 100, 51, 100, 67, 100, 31, 100, 21, 100, 24, 100, 57, 100, 55, 100, 34, 100, 35, 100, 12, 100, 38, 100, 48, 100, 40, 100, 65, 100, 53, 100, 47, 100, 10, 100, 26, 100, 64, 100, 37, 100, 39, 100, 11, 100, 231, 99, 27, 100, 46, 100, 33, 100, 14, 100, 111, 101, 146, 101, 211, 101, 134, 102, 140, 102, 149, 102, 144, 102, 139, 102, 138, 102, 153, 102, 148, 102, 120, 102, 32, 103, 102, 105, 95, 105, 56, 105, 78, 105, 98, 105, 113, 105, 63, 105, 69, 105, 106, 105, 57, 105, 66, 105, 87, 105, 89, 105, 122, 105, 72, 105, 73, 105, 53, 105, 108, 105, 51, 105, 61, 105, 101, 105, 240, 104, 120, 105, 52, 105, 105, 105, 64, 105, 111, 105, 68, 105, 118, 105, 88, 105, 65, 105, 116, 105, 76, 105, 59, 105, 75, 105, 55, 105, 92, 105, 79, 105, 81, 105, 50, 105, 82, 105, 47, 105, 123, 105, 60, 105, 70, 107, 69, 107, 67, 107, 66, 107, 72, 107, 65, 107, 155, 107, 13, 250, 251, 107, 252, 107, 249, 107, 247, 107, 248, 107, 155, 110, 214, 110, 200, 110, 143, 110, 192, 110, 159, 110, 147, 110, 148, 110, 160, 110, 177, 110, 185, 110, 198, 110, 210, 110, 189, 110, 193, 110, 158, 110, 201, 110, 183, 110, 176, 110, 205, 110, 166, 110, 207, 110, 178, 110, 190, 110, 195, 110, 220, 110, 216, 110, 153, 110, 146, 110, 142, 110, 141, 110, 164, 110, 161, 110, 191, 110, 179, 110, 208, 110, 202, 110, 151, 110, 174, 110, 163, 110, 71, 113, 84, 113, 82, 113, 99, 113, 96, 113, 65, 113, 93, 113, 98, 113, 114, 113, 120, 113, 106, 113, 97, 113, 66, 113, 88, 113, 67, 113, 75, 113, 112, 113, 95, 113, 80, 113, 83, 113, 68, 113, 77, 113, 90, 113, 79, 114, 141, 114, 140, 114, 145, 114, 144, 114, 142, 114, 60, 115, 66, 115, 59, 115, 58, 115, 64, 115, 74, 115, 73, 115, 68, 116, 74, 116, 75, 116, 82, 116, 81, 116, 87, 116, 64, 116, 79, 116, 80, 116, 78, 116, 66, 116, 70, 116, 77, 116, 84, 116, 225, 116, 255, 116, 254, 116, 253, 116, 29, 117, 121, 117, 119, 117, 131, 105, 239, 117, 15, 118, 3, 118, 247, 117, 254, 117, 252, 117, 249, 117, 248, 117, 16, 118, 251, 117, 246, 117, 237, 117, 245, 117, 253, 117, 153, 118, 181, 118, 221, 118, 85, 119, 95, 119, 96, 119, 82, 119, 86, 119, 90, 119, 105, 119, 103, 119, 84, 119, 89, 119, 109, 119, 224, 119, 135, 120, 154, 120, 148, 120, 143, 120, 132, 120, 149, 120, 133, 120, 134, 120, 161, 120, 131, 120, 121, 120, 153, 120, 128, 120, 150, 120, 123, 120, 124, 121, 130, 121, 125, 121, 121, 121, 17, 122, 24, 122, 25, 122, 18, 122, 23, 122, 21, 122, 34, 122, 19, 122, 27, 122, 16, 122, 163, 122, 162, 122, 158, 122, 235, 122, 102, 123, 100, 123, 109, 123, 116, 123, 105, 123, 114, 123, 101, 123, 115, 123, 113, 123, 112, 123, 97, 123, 120, 123, 118, 123, 99, 123, 178, 124, 180, 124, 175, 124, 136, 125, 134, 125, 128, 125, 141, 125, 127, 125, 133, 125, 122, 125, 142, 125, 123, 125, 131, 125, 124, 125, 140, 125, 148, 125, 132, 125, 125, 125, 146, 125, 109, 127, 107, 127, 103, 127, 104, 127, 108, 127, 166, 127, 165, 127, 167, 127, 219, 127, 220, 127, 33, 128, 100, 129, 96, 129, 119, 129, 92, 129, 105, 129, 91, 129, 98, 129, 114, 129, 33, 103, 94, 129, 118, 129, 103, 129, 111, 129, 68, 129, 97, 129, 29, 130, 73, 130, 68, 130, 64, 130, 66, 130, 69, 130, 241, 132, 63, 132, 86, 132, 118, 132, 121, 132, 143, 132, 141, 132, 101, 132, 81, 132, 64, 132, 134, 132, 103, 132, 48, 132, 77, 132, 125, 132, 90, 132, 89, 132, 116, 132, 115, 132, 93, 132, 7, 133, 94, 132, 55, 132, 58, 132, 52, 132, 122, 132, 67, 132, 120, 132, 50, 132, 69, 132, 41, 132, 217, 131, 75, 132, 47, 132, 66, 132, 45, 132, 95, 132, 112, 132, 57, 132, 78, 132, 76, 132, 82, 132, 111, 132, 197, 132, 142, 132, 59, 132, 71, 132, 54, 132, 51, 132, 104, 132, 126, 132, 68, 132, 43, 132, 96, 132, 84, 132, 110, 132, 80, 132, 11, 135, 4, 135, 247, 134, 12, 135, 250, 134, 214, 134, 245, 134, 77, 135, 248, 134, 14, 135, 9, 135, 1, 135, 246, 134, 13, 135, 5, 135, 214, 136, 203, 136, 205, 136, 206, 136, 222, 136, 219, 136, 218, 136, 204, 136, 208, 136, 133, 137, 155, 137, 223, 137, 229, 137, 228, 137, 225, 137, 224, 137, 226, 137, 220, 137, 230, 137, 118, 138, 134, 138, 127, 138, 97, 138, 63, 138, 119, 138, 130, 138, 132, 138, 117, 138, 131, 138, 129, 138, 116, 138, 122, 138, 60, 140, 75, 140, 74, 140, 101, 140, 100, 140, 102, 140, 134, 140, 132, 140, 133, 140, 204, 140, 104, 141, 105, 141, 145, 141, 140, 141, 142, 141, 143, 141, 141, 141, 147, 141, 148, 141, 144, 141, 146, 141, 240, 141, 224, 141, 236, 141, 241, 141, 238, 141, 208, 141, 233, 141, 227, 141, 226, 141, 231, 141, 242, 141, 235, 141, 244, 141, 6, 143, 255, 142, 1, 143, 0, 143, 5, 143, 7, 143, 8, 143, 2, 143, 11, 143, 82, 144, 63, 144, 68, 144, 73, 144, 61, 144, 16, 145, 13, 145, 15, 145, 17, 145, 22, 145, 20, 145, 11, 145, 14, 145, 110, 145, 111, 145, 72, 146, 82, 146, 48, 146, 58, 146, 102, 146, 51, 146, 101, 146, 94, 146, 131, 146, 46, 146, 74, 146, 70, 146, 109, 146, 108, 146, 79, 146, 96, 146, 103, 146, 111, 146, 54, 146, 97, 146, 112, 146, 49, 146, 84, 146, 99, 146, 80, 146, 114, 146, 78, 146, 83, 146, 76, 146, 86, 146, 50, 146, 159, 149, 156, 149, 158, 149, 155, 149, 146, 150, 147, 150, 145, 150, 151, 150, 206, 150, 250, 150, 253, 150, 248, 150, 245, 150, 115, 151, 119, 151, 120, 151, 114, 151, 15, 152, 13, 152, 14, 152, 172, 152, 246, 152, 249, 152, 175, 153, 178, 153, 176, 153, 181, 153, 173, 154, 171, 154, 91, 155, 234, 156, 237, 156, 231, 156, 128, 158, 253, 158, 230, 80, 212, 80, 215, 80, 232, 80, 243, 80, 219, 80, 234, 80, 221, 80, 228, 80, 211, 80, 236, 80, 240, 80, 239, 80, 227, 80, 224, 80, 216, 81, 128, 82, 129, 82, 233, 82, 235, 82, 48, 83, 172, 83, 39, 86, 21, 86, 12, 86, 18, 86, 252, 85, 15, 86, 28, 86, 1, 86, 19, 86, 2, 86, 250, 85, 29, 86, 4, 86, 255, 85, 249, 85, 137, 88, 124, 88, 144, 88, 152, 88, 134, 88, 129, 88, 127, 88, 116, 88, 139, 88, 122, 88, 135, 88, 145, 88, 142, 88, 118, 88, 130, 88, 136, 88, 123, 88, 148, 88, 143, 88, 254, 88, 107, 89, 220, 90, 238, 90, 229, 90, 213, 90, 234, 90, 218, 90, 237, 90, 235, 90, 243, 90, 226, 90, 224, 90, 219, 90, 236, 90, 222, 90, 221, 90, 217, 90, 232, 90, 223, 90, 119, 91, 224, 91, 227, 91, 99, 92, 130, 93, 128, 93, 125, 93, 134, 93, 122, 93, 129, 93, 119, 93, 138, 93, 137, 93, 136, 93, 126, 93, 124, 93, 141, 93, 121, 93, 127, 93, 88, 94, 89, 94, 83, 94, 216, 94, 209, 94, 215, 94, 206, 94, 220, 94, 213, 94, 217, 94, 210, 94, 212, 94, 68, 95, 67, 95, 111, 95, 182, 95, 44, 97, 40, 97, 65, 97, 94, 97, 113, 97, 115, 97, 82, 97, 83, 97, 114, 97, 108, 97, 128, 97, 116, 97, 84, 97, 122, 97, 91, 97, 101, 97, 59, 97, 106, 97, 97, 97, 86, 97, 41, 98, 39, 98, 43, 98, 43, 100, 77, 100, 91, 100, 93, 100, 116, 100, 118, 100, 114, 100, 115, 100, 125, 100, 117, 100, 102, 100, 166, 100, 78, 100, 130, 100, 94, 100, 92, 100, 75, 100, 83, 100, 96, 100, 80, 100, 127, 100, 63, 100, 108, 100, 107, 100, 89, 100, 101, 100, 119, 100, 115, 101, 160, 101, 161, 102, 160, 102, 159, 102, 5, 103, 4, 103, 34, 103, 177, 105, 182, 105, 201, 105, 160, 105, 206, 105, 150, 105, 176, 105, 172, 105, 188, 105, 145, 105, 153, 105, 142, 105, 167, 105, 141, 105, 169, 105, 190, 105, 175, 105, 191, 105, 196, 105, 189, 105, 164, 105, 212, 105, 185, 105, 202, 105, 154, 105, 207, 105, 179, 105, 147, 105, 170, 105, 161, 105, 158, 105, 217, 105, 151, 105, 144, 105, 194, 105, 181, 105, 165, 105, 198, 105, 74, 107, 77, 107, 75, 107, 158, 107, 159, 107, 160, 107, 195, 107, 196, 107, 254, 107, 206, 110, 245, 110, 241, 110, 3, 111, 37, 111, 248, 110, 55, 111, 251, 110, 46, 111, 9, 111, 78, 111, 25, 111, 26, 111, 39, 111, 24, 111, 59, 111, 18, 111, 237, 110, 10, 111, 54, 111, 115, 111, 249, 110, 238, 110, 45, 111, 64, 111, 48, 111, 60, 111, 53, 111, 235, 110, 7, 111, 14, 111, 67, 111, 5, 111, 253, 110, 246, 110, 57, 111, 28, 111, 252, 110, 58, 111, 31, 111, 13, 111, 30, 111, 8, 111, 33, 111, 135, 113, 144, 113, 137, 113, 128, 113, 133, 113, 130, 113, 143, 113, 123, 113, 134, 113, 129, 113, 151, 113, 68, 114, 83, 114, 151, 114, 149, 114, 147, 114, 67, 115, 77, 115, 81, 115, 76, 115, 98, 116, 115, 116, 113, 116, 117, 116, 114, 116, 103, 116, 110, 116, 0, 117, 2, 117, 3, 117, 125, 117, 144, 117, 22, 118, 8, 118, 12, 118, 21, 118, 17, 118, 10, 118, 20, 118, 184, 118, 129, 119, 124, 119, 133, 119, 130, 119, 110, 119, 128, 119, 111, 119, 126, 119, 131, 119, 178, 120, 170, 120, 180, 120, 173, 120, 168, 120, 126, 120, 171, 120, 158, 120, 165, 120, 160, 120, 172, 120, 162, 120, 164, 120, 152, 121, 138, 121, 139, 121, 150, 121, 149, 121, 148, 121, 147, 121, 151, 121, 136, 121, 146, 121, 144, 121, 43, 122, 74, 122, 48, 122, 47, 122, 40, 122, 38, 122, 168, 122, 171, 122, 172, 122, 238, 122, 136, 123, 156, 123, 138, 123, 145, 123, 144, 123, 150, 123, 141, 123, 140, 123, 155, 123, 142, 123, 133, 123, 152, 123, 132, 82, 153, 123, 164, 123, 130, 123, 187, 124, 191, 124, 188, 124, 186, 124, 167, 125, 183, 125, 194, 125, 163, 125, 170, 125, 193, 125, 192, 125, 197, 125, 157, 125, 206, 125, 196, 125, 198, 125, 203, 125, 204, 125, 175, 125, 185, 125, 150, 125, 188, 125, 159, 125, 166, 125, 174, 125, 169, 125, 161, 125, 201, 125, 115, 127, 226, 127, 227, 127, 229, 127, 222, 127, 36, 128, 93, 128, 92, 128, 137, 129, 134, 129, 131, 129, 135, 129, 141, 129, 140, 129, 139, 129, 21, 130, 151, 132, 164, 132, 161, 132, 159, 132, 186, 132, 206, 132, 194, 132, 172, 132, 174, 132, 171, 132, 185, 132, 180, 132, 193, 132, 205, 132, 170, 132, 154, 132, 177, 132, 208, 132, 157, 132, 167, 132, 187, 132, 162, 132, 148, 132, 199, 132, 204, 132, 155, 132, 169, 132, 175, 132, 168, 132, 214, 132, 152, 132, 182, 132, 207, 132, 160, 132, 215, 132, 212, 132, 210, 132, 219, 132, 176, 132, 145, 132, 97, 134, 51, 135, 35, 135, 40, 135, 107, 135, 64, 135], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 292068);
	        allocate([46, 135, 30, 135, 33, 135, 25, 135, 27, 135, 67, 135, 44, 135, 65, 135, 62, 135, 70, 135, 32, 135, 50, 135, 42, 135, 45, 135, 60, 135, 18, 135, 58, 135, 49, 135, 53, 135, 66, 135, 38, 135, 39, 135, 56, 135, 36, 135, 26, 135, 48, 135, 17, 135, 247, 136, 231, 136, 241, 136, 242, 136, 250, 136, 254, 136, 238, 136, 252, 136, 246, 136, 251, 136, 240, 136, 236, 136, 235, 136, 157, 137, 161, 137, 159, 137, 158, 137, 233, 137, 235, 137, 232, 137, 171, 138, 153, 138, 139, 138, 146, 138, 143, 138, 150, 138, 61, 140, 104, 140, 105, 140, 213, 140, 207, 140, 215, 140, 150, 141, 9, 142, 2, 142, 255, 141, 13, 142, 253, 141, 10, 142, 3, 142, 7, 142, 6, 142, 5, 142, 254, 141, 0, 142, 4, 142, 16, 143, 17, 143, 14, 143, 13, 143, 35, 145, 28, 145, 32, 145, 34, 145, 31, 145, 29, 145, 26, 145, 36, 145, 33, 145, 27, 145, 122, 145, 114, 145, 121, 145, 115, 145, 165, 146, 164, 146, 118, 146, 155, 146, 122, 146, 160, 146, 148, 146, 170, 146, 141, 146, 166, 146, 154, 146, 171, 146, 121, 146, 151, 146, 127, 146, 163, 146, 238, 146, 142, 146, 130, 146, 149, 146, 162, 146, 125, 146, 136, 146, 161, 146, 138, 146, 134, 146, 140, 146, 153, 146, 167, 146, 126, 146, 135, 146, 169, 146, 157, 146, 139, 146, 45, 146, 158, 150, 161, 150, 255, 150, 88, 151, 125, 151, 122, 151, 126, 151, 131, 151, 128, 151, 130, 151, 123, 151, 132, 151, 129, 151, 127, 151, 206, 151, 205, 151, 22, 152, 173, 152, 174, 152, 2, 153, 0, 153, 7, 153, 157, 153, 156, 153, 195, 153, 185, 153, 187, 153, 186, 153, 194, 153, 189, 153, 199, 153, 177, 154, 227, 154, 231, 154, 62, 155, 63, 155, 96, 155, 97, 155, 95, 155, 241, 156, 242, 156, 245, 156, 167, 158, 255, 80, 3, 81, 48, 81, 248, 80, 6, 81, 7, 81, 246, 80, 254, 80, 11, 81, 12, 81, 253, 80, 10, 81, 139, 82, 140, 82, 241, 82, 239, 82, 72, 86, 66, 86, 76, 86, 53, 86, 65, 86, 74, 86, 73, 86, 70, 86, 88, 86, 90, 86, 64, 86, 51, 86, 61, 86, 44, 86, 62, 86, 56, 86, 42, 86, 58, 86, 26, 87, 171, 88, 157, 88, 177, 88, 160, 88, 163, 88, 175, 88, 172, 88, 165, 88, 161, 88, 255, 88, 255, 90, 244, 90, 253, 90, 247, 90, 246, 90, 3, 91, 248, 90, 2, 91, 249, 90, 1, 91, 7, 91, 5, 91, 15, 91, 103, 92, 153, 93, 151, 93, 159, 93, 146, 93, 162, 93, 147, 93, 149, 93, 160, 93, 156, 93, 161, 93, 154, 93, 158, 93, 105, 94, 93, 94, 96, 94, 92, 94, 243, 125, 219, 94, 222, 94, 225, 94, 73, 95, 178, 95, 139, 97, 131, 97, 121, 97, 177, 97, 176, 97, 162, 97, 137, 97, 155, 97, 147, 97, 175, 97, 173, 97, 159, 97, 146, 97, 170, 97, 161, 97, 141, 97, 102, 97, 179, 97, 45, 98, 110, 100, 112, 100, 150, 100, 160, 100, 133, 100, 151, 100, 156, 100, 143, 100, 139, 100, 138, 100, 140, 100, 163, 100, 159, 100, 104, 100, 177, 100, 152, 100, 118, 101, 122, 101, 121, 101, 123, 101, 178, 101, 179, 101, 181, 102, 176, 102, 169, 102, 178, 102, 183, 102, 170, 102, 175, 102, 0, 106, 6, 106, 23, 106, 229, 105, 248, 105, 21, 106, 241, 105, 228, 105, 32, 106, 255, 105, 236, 105, 226, 105, 27, 106, 29, 106, 254, 105, 39, 106, 242, 105, 238, 105, 20, 106, 247, 105, 231, 105, 64, 106, 8, 106, 230, 105, 251, 105, 13, 106, 252, 105, 235, 105, 9, 106, 4, 106, 24, 106, 37, 106, 15, 106, 246, 105, 38, 106, 7, 106, 244, 105, 22, 106, 81, 107, 165, 107, 163, 107, 162, 107, 166, 107, 1, 108, 0, 108, 255, 107, 2, 108, 65, 111, 38, 111, 126, 111, 135, 111, 198, 111, 146, 111, 141, 111, 137, 111, 140, 111, 98, 111, 79, 111, 133, 111, 90, 111, 150, 111, 118, 111, 108, 111, 130, 111, 85, 111, 114, 111, 82, 111, 80, 111, 87, 111, 148, 111, 147, 111, 93, 111, 0, 111, 97, 111, 107, 111, 125, 111, 103, 111, 144, 111, 83, 111, 139, 111, 105, 111, 127, 111, 149, 111, 99, 111, 119, 111, 106, 111, 123, 111, 178, 113, 175, 113, 155, 113, 176, 113, 160, 113, 154, 113, 169, 113, 181, 113, 157, 113, 165, 113, 158, 113, 164, 113, 161, 113, 170, 113, 156, 113, 167, 113, 179, 113, 152, 114, 154, 114, 88, 115, 82, 115, 94, 115, 95, 115, 96, 115, 93, 115, 91, 115, 97, 115, 90, 115, 89, 115, 98, 115, 135, 116, 137, 116, 138, 116, 134, 116, 129, 116, 125, 116, 133, 116, 136, 116, 124, 116, 121, 116, 8, 117, 7, 117, 126, 117, 37, 118, 30, 118, 25, 118, 29, 118, 28, 118, 35, 118, 26, 118, 40, 118, 27, 118, 156, 118, 157, 118, 158, 118, 155, 118, 141, 119, 143, 119, 137, 119, 136, 119, 205, 120, 187, 120, 207, 120, 204, 120, 209, 120, 206, 120, 212, 120, 200, 120, 195, 120, 196, 120, 201, 120, 154, 121, 161, 121, 160, 121, 156, 121, 162, 121, 155, 121, 118, 107, 57, 122, 178, 122, 180, 122, 179, 122, 183, 123, 203, 123, 190, 123, 172, 123, 206, 123, 175, 123, 185, 123, 202, 123, 181, 123, 197, 124, 200, 124, 204, 124, 203, 124, 247, 125, 219, 125, 234, 125, 231, 125, 215, 125, 225, 125, 3, 126, 250, 125, 230, 125, 246, 125, 241, 125, 240, 125, 238, 125, 223, 125, 118, 127, 172, 127, 176, 127, 173, 127, 237, 127, 235, 127, 234, 127, 236, 127, 230, 127, 232, 127, 100, 128, 103, 128, 163, 129, 159, 129, 158, 129, 149, 129, 162, 129, 153, 129, 151, 129, 22, 130, 79, 130, 83, 130, 82, 130, 80, 130, 78, 130, 81, 130, 36, 133, 59, 133, 15, 133, 0, 133, 41, 133, 14, 133, 9, 133, 13, 133, 31, 133, 10, 133, 39, 133, 28, 133, 251, 132, 43, 133, 250, 132, 8, 133, 12, 133, 244, 132, 42, 133, 242, 132, 21, 133, 247, 132, 235, 132, 243, 132, 252, 132, 18, 133, 234, 132, 233, 132, 22, 133, 254, 132, 40, 133, 29, 133, 46, 133, 2, 133, 253, 132, 30, 133, 246, 132, 49, 133, 38, 133, 231, 132, 232, 132, 240, 132, 239, 132, 249, 132, 24, 133, 32, 133, 48, 133, 11, 133, 25, 133, 47, 133, 98, 134, 86, 135, 99, 135, 100, 135, 119, 135, 225, 135, 115, 135, 88, 135, 84, 135, 91, 135, 82, 135, 97, 135, 90, 135, 81, 135, 94, 135, 109, 135, 106, 135, 80, 135, 78, 135, 95, 135, 93, 135, 111, 135, 108, 135, 122, 135, 110, 135, 92, 135, 101, 135, 79, 135, 123, 135, 117, 135, 98, 135, 103, 135, 105, 135, 90, 136, 5, 137, 12, 137, 20, 137, 11, 137, 23, 137, 24, 137, 25, 137, 6, 137, 22, 137, 17, 137, 14, 137, 9, 137, 162, 137, 164, 137, 163, 137, 237, 137, 240, 137, 236, 137, 207, 138, 198, 138, 184, 138, 211, 138, 209, 138, 212, 138, 213, 138, 187, 138, 215, 138, 190, 138, 192, 138, 197, 138, 216, 138, 195, 138, 186, 138, 189, 138, 217, 138, 62, 140, 77, 140, 143, 140, 229, 140, 223, 140, 217, 140, 232, 140, 218, 140, 221, 140, 231, 140, 160, 141, 156, 141, 161, 141, 155, 141, 32, 142, 35, 142, 37, 142, 36, 142, 46, 142, 21, 142, 27, 142, 22, 142, 17, 142, 25, 142, 38, 142, 39, 142, 20, 142, 18, 142, 24, 142, 19, 142, 28, 142, 23, 142, 26, 142, 44, 143, 36, 143, 24, 143, 26, 143, 32, 143, 35, 143, 22, 143, 23, 143, 115, 144, 112, 144, 111, 144, 103, 144, 107, 144, 47, 145, 43, 145, 41, 145, 42, 145, 50, 145, 38, 145, 46, 145, 133, 145, 134, 145, 138, 145, 129, 145, 130, 145, 132, 145, 128, 145, 208, 146, 195, 146, 196, 146, 192, 146, 217, 146, 182, 146, 207, 146, 241, 146, 223, 146, 216, 146, 233, 146, 215, 146, 221, 146, 204, 146, 239, 146, 194, 146, 232, 146, 202, 146, 200, 146, 206, 146, 230, 146, 205, 146, 213, 146, 201, 146, 224, 146, 222, 146, 231, 146, 209, 146, 211, 146, 181, 146, 225, 146, 198, 146, 180, 146, 124, 149, 172, 149, 171, 149, 174, 149, 176, 149, 164, 150, 162, 150, 211, 150, 5, 151, 8, 151, 2, 151, 90, 151, 138, 151, 142, 151, 136, 151, 208, 151, 207, 151, 30, 152, 29, 152, 38, 152, 41, 152, 40, 152, 32, 152, 27, 152, 39, 152, 178, 152, 8, 153, 250, 152, 17, 153, 20, 153, 22, 153, 23, 153, 21, 153, 220, 153, 205, 153, 207, 153, 211, 153, 212, 153, 206, 153, 201, 153, 214, 153, 216, 153, 203, 153, 215, 153, 204, 153, 179, 154, 236, 154, 235, 154, 243, 154, 242, 154, 241, 154, 70, 155, 67, 155, 103, 155, 116, 155, 113, 155, 102, 155, 118, 155, 117, 155, 112, 155, 104, 155, 100, 155, 108, 155, 252, 156, 250, 156, 253, 156, 255, 156, 247, 156, 7, 157, 0, 157, 249, 156, 251, 156, 8, 157, 5, 157, 4, 157, 131, 158, 211, 158, 15, 159, 16, 159, 28, 81, 19, 81, 23, 81, 26, 81, 17, 81, 222, 81, 52, 83, 225, 83, 112, 86, 96, 86, 110, 86, 115, 86, 102, 86, 99, 86, 109, 86, 114, 86, 94, 86, 119, 86, 28, 87, 27, 87, 200, 88, 189, 88, 201, 88, 191, 88, 186, 88, 194, 88, 188, 88, 198, 88, 23, 91, 25, 91, 27, 91, 33, 91, 20, 91, 19, 91, 16, 91, 22, 91, 40, 91, 26, 91, 32, 91, 30, 91, 239, 91, 172, 93, 177, 93, 169, 93, 167, 93, 181, 93, 176, 93, 174, 93, 170, 93, 168, 93, 178, 93, 173, 93, 175, 93, 180, 93, 103, 94, 104, 94, 102, 94, 111, 94, 233, 94, 231, 94, 230, 94, 232, 94, 229, 94, 75, 95, 188, 95, 157, 97, 168, 97, 150, 97, 197, 97, 180, 97, 198, 97, 193, 97, 204, 97, 186, 97, 191, 97, 184, 97, 140, 97, 215, 100, 214, 100, 208, 100, 207, 100, 201, 100, 189, 100, 137, 100, 195, 100, 219, 100, 243, 100, 217, 100, 51, 101, 127, 101, 124, 101, 162, 101, 200, 102, 190, 102, 192, 102, 202, 102, 203, 102, 207, 102, 189, 102, 187, 102, 186, 102, 204, 102, 35, 103, 52, 106, 102, 106, 73, 106, 103, 106, 50, 106, 104, 106, 62, 106, 93, 106, 109, 106, 118, 106, 91, 106, 81, 106, 40, 106, 90, 106, 59, 106, 63, 106, 65, 106, 106, 106, 100, 106, 80, 106, 79, 106, 84, 106, 111, 106, 105, 106, 96, 106, 60, 106, 94, 106, 86, 106, 85, 106, 77, 106, 78, 106, 70, 106, 85, 107, 84, 107, 86, 107, 167, 107, 170, 107, 171, 107, 200, 107, 199, 107, 4, 108, 3, 108, 6, 108, 173, 111, 203, 111, 163, 111, 199, 111, 188, 111, 206, 111, 200, 111, 94, 111, 196, 111, 189, 111, 158, 111, 202, 111, 168, 111, 4, 112, 165, 111, 174, 111, 186, 111, 172, 111, 170, 111, 207, 111, 191, 111, 184, 111, 162, 111, 201, 111, 171, 111, 205, 111, 175, 111, 178, 111, 176, 111, 197, 113, 194, 113, 191, 113, 184, 113, 214, 113, 192, 113, 193, 113, 203, 113, 212, 113, 202, 113, 199, 113, 207, 113, 189, 113, 216, 113, 188, 113, 198, 113, 218, 113, 219, 113, 157, 114, 158, 114, 105, 115, 102, 115, 103, 115, 108, 115, 101, 115, 107, 115, 106, 115, 127, 116, 154, 116, 160, 116, 148, 116, 146, 116, 149, 116, 161, 116, 11, 117, 128, 117, 47, 118, 45, 118, 49, 118, 61, 118, 51, 118, 60, 118, 53, 118, 50, 118, 48, 118, 187, 118, 230, 118, 154, 119, 157, 119, 161, 119, 156, 119, 155, 119, 162, 119, 163, 119, 149, 119, 153, 119, 151, 119, 221, 120, 233, 120, 229, 120, 234, 120, 222, 120, 227, 120, 219, 120, 225, 120, 226, 120, 237, 120, 223, 120, 224, 120, 164, 121, 68, 122, 72, 122, 71, 122, 182, 122, 184, 122, 181, 122, 177, 122, 183, 122, 222, 123, 227, 123, 231, 123, 221, 123, 213, 123, 229, 123, 218, 123, 232, 123, 249, 123, 212, 123, 234, 123, 226, 123, 220, 123, 235, 123, 216, 123, 223, 123, 210, 124, 212, 124, 215, 124, 208, 124, 209, 124, 18, 126, 33, 126, 23, 126, 12, 126, 31, 126, 32, 126, 19, 126, 14, 126, 28, 126, 21, 126, 26, 126, 34, 126, 11, 126, 15, 126, 22, 126, 13, 126, 20, 126, 37, 126, 36, 126, 67, 127, 123, 127, 124, 127, 122, 127, 177, 127, 239, 127, 42, 128, 41, 128, 108, 128, 177, 129, 166, 129, 174, 129, 185, 129, 181, 129, 171, 129, 176, 129, 172, 129, 180, 129, 178, 129, 183, 129, 167, 129, 242, 129, 85, 130, 86, 130, 87, 130, 86, 133, 69, 133, 107, 133, 77, 133, 83, 133, 97, 133, 88, 133, 64, 133, 70, 133, 100, 133, 65, 133, 98, 133, 68, 133, 81, 133, 71, 133, 99, 133, 62, 133, 91, 133, 113, 133, 78, 133, 110, 133, 117, 133, 85, 133, 103, 133, 96, 133, 140, 133, 102, 133, 93, 133, 84, 133, 101, 133, 108, 133, 99, 134, 101, 134, 100, 134, 155, 135, 143, 135, 151, 135, 147, 135, 146, 135, 136, 135, 129, 135, 150, 135, 152, 135, 121, 135, 135, 135, 163, 135, 133, 135, 144, 135, 145, 135, 157, 135, 132, 135, 148, 135, 156, 135, 154, 135, 137, 135, 30, 137, 38, 137, 48, 137, 45, 137, 46, 137, 39, 137, 49, 137, 34, 137, 41, 137, 35, 137, 47, 137, 44, 137, 31, 137, 241, 137, 224, 138, 226, 138, 242, 138, 244, 138, 245, 138, 221, 138, 20, 139, 228, 138, 223, 138, 240, 138, 200, 138, 222, 138, 225, 138, 232, 138, 255, 138, 239, 138, 251, 138, 145, 140, 146, 140, 144, 140, 245, 140, 238, 140, 241, 140, 240, 140, 243, 140, 108, 141, 110, 141, 165, 141, 167, 141, 51, 142, 62, 142, 56, 142, 64, 142, 69, 142, 54, 142, 60, 142, 61, 142, 65, 142, 48, 142, 63, 142, 189, 142, 54, 143, 46, 143, 53, 143, 50, 143, 57, 143, 55, 143, 52, 143, 118, 144, 121, 144, 123, 144, 134, 144, 250, 144, 51, 145, 53, 145, 54, 145, 147, 145, 144, 145, 145, 145, 141, 145, 143, 145, 39, 147, 30, 147, 8, 147, 31, 147, 6, 147, 15, 147, 122, 147, 56, 147, 60, 147, 27, 147, 35, 147, 18, 147, 1, 147, 70, 147, 45, 147, 14, 147, 13, 147, 203, 146, 29, 147, 250, 146, 37, 147, 19, 147, 249, 146, 247, 146, 52, 147, 2, 147, 36, 147, 255, 146, 41, 147, 57, 147, 53, 147, 42, 147, 20, 147, 12, 147, 11, 147, 254, 146, 9, 147, 0, 147, 251, 146, 22, 147, 188, 149, 205, 149, 190, 149, 185, 149, 186, 149, 182, 149, 191, 149, 181, 149, 189, 149, 169, 150, 212, 150, 11, 151, 18, 151, 16, 151, 153, 151, 151, 151, 148, 151, 240, 151, 248, 151, 53, 152, 47, 152, 50, 152, 36, 153, 31, 153, 39, 153, 41, 153, 158, 153, 238, 153, 236, 153, 229, 153, 228, 153, 240, 153, 227, 153, 234, 153, 233, 153, 231, 153, 185, 154, 191, 154, 180, 154, 187, 154, 246, 154, 250, 154, 249, 154, 247, 154, 51, 155, 128, 155, 133, 155, 135, 155, 124, 155, 126, 155, 123, 155, 130, 155, 147, 155, 146, 155, 144, 155, 122, 155, 149, 155, 125, 155, 136, 155, 37, 157, 23, 157, 32, 157, 30, 157, 20, 157, 41, 157, 29, 157, 24, 157, 34, 157, 16, 157, 25, 157, 31, 157, 136, 158, 134, 158, 135, 158, 174, 158, 173, 158, 213, 158, 214, 158, 250, 158, 18, 159, 61, 159, 38, 81, 37, 81, 34, 81, 36, 81, 32, 81, 41, 81, 244, 82, 147, 86, 140, 86, 141, 86, 134, 86, 132, 86, 131, 86, 126, 86, 130, 86, 127, 86, 129, 86, 214, 88, 212, 88, 207, 88, 210, 88, 45, 91, 37, 91, 50, 91, 35, 91, 44, 91, 39, 91, 38, 91, 47, 91, 46, 91, 123, 91, 241, 91, 242, 91, 183, 93, 108, 94, 106, 94, 190, 95, 187, 95, 195, 97, 181, 97, 188, 97, 231, 97, 224, 97, 229, 97, 228, 97, 232, 97, 222, 97, 239, 100, 233, 100, 227, 100, 235, 100, 228, 100, 232, 100, 129, 101, 128, 101, 182, 101, 218, 101, 210, 102, 141, 106, 150, 106, 129, 106, 165, 106, 137, 106, 159, 106, 155, 106, 161, 106, 158, 106, 135, 106, 147, 106, 142, 106, 149, 106, 131, 106, 168, 106, 164, 106, 145, 106, 127, 106, 166, 106, 154, 106, 133, 106, 140, 106, 146, 106, 91, 107, 173, 107, 9, 108, 204, 111, 169, 111, 244, 111, 212, 111, 227, 111, 220, 111, 237, 111, 231, 111, 230, 111, 222, 111, 242, 111, 221, 111, 226, 111, 232, 111, 225, 113, 241, 113, 232, 113, 242, 113, 228, 113, 240, 113, 226, 113, 115, 115, 110, 115, 111, 115, 151, 116, 178, 116, 171, 116, 144, 116, 170, 116, 173, 116, 177, 116, 165, 116, 175, 116, 16, 117, 17, 117, 18, 117, 15, 117, 132, 117, 67, 118, 72, 118, 73, 118, 71, 118, 164, 118, 233, 118, 181, 119, 171, 119, 178, 119, 183, 119, 182, 119, 180, 119, 177, 119, 168, 119, 240, 119, 243, 120, 253, 120, 2, 121, 251, 120, 252, 120, 242, 120, 5, 121, 249, 120, 254, 120, 4, 121, 171, 121, 168, 121, 92, 122, 91, 122, 86, 122, 88, 122, 84, 122, 90, 122, 190, 122, 192, 122, 193, 122, 5, 124, 15, 124, 242, 123, 0, 124, 255, 123, 251, 123, 14, 124, 244, 123, 11, 124, 243, 123, 2, 124, 9, 124, 3, 124, 1, 124, 248, 123, 253, 123, 6, 124, 240, 123, 241, 123, 16, 124, 10, 124, 232, 124, 45, 126, 60, 126, 66, 126, 51, 126, 72, 152, 56, 126, 42, 126, 73, 126, 64, 126, 71, 126, 41, 126, 76, 126, 48, 126, 59, 126, 54, 126, 68, 126, 58, 126, 69, 127, 127, 127, 126, 127, 125, 127, 244, 127, 242, 127, 44, 128, 187, 129, 196, 129, 204, 129, 202, 129, 197, 129, 199, 129, 188, 129, 233, 129, 91, 130, 90, 130, 92, 130, 131, 133, 128, 133, 143, 133, 167, 133, 149, 133, 160, 133, 139, 133, 163, 133, 123, 133, 164, 133, 154, 133, 158, 133, 119, 133, 124, 133, 137, 133, 161, 133, 122, 133, 120, 133, 87, 133, 142, 133, 150, 133, 134, 133, 141, 133, 153, 133, 157, 133, 129, 133, 162, 133, 130, 133, 136, 133, 133, 133, 121, 133, 118, 133, 152, 133, 144, 133, 159, 133, 104, 134, 190, 135, 170, 135, 173, 135, 197, 135, 176, 135, 172, 135, 185, 135, 181, 135, 188, 135, 174, 135, 201, 135, 195, 135, 194, 135, 204, 135, 183, 135, 175, 135, 196, 135, 202, 135, 180, 135, 182, 135, 191, 135, 184, 135, 189, 135, 222, 135, 178, 135, 53, 137, 51, 137, 60, 137, 62, 137, 65, 137, 82, 137, 55, 137, 66, 137, 173, 137, 175, 137, 174, 137, 242, 137, 243, 137, 30, 139, 24, 139, 22, 139, 17, 139, 5, 139, 11, 139, 34, 139, 15, 139, 18, 139, 21, 139, 7, 139, 13, 139, 8, 139, 6, 139, 28, 139, 19, 139, 26, 139, 79, 140, 112, 140, 114, 140, 113, 140, 111, 140, 149, 140, 148, 140, 249, 140, 111, 141, 78, 142, 77, 142, 83, 142, 80, 142, 76, 142, 71, 142, 67, 143, 64, 143, 133, 144, 126, 144, 56, 145, 154, 145, 162, 145, 155, 145, 153, 145, 159, 145, 161, 145, 157, 145, 160, 145, 161, 147, 131, 147, 175, 147, 100, 147, 86, 147, 71, 147, 124, 147, 88, 147, 92, 147, 118, 147, 73, 147, 80, 147, 81, 147, 96, 147, 109, 147, 143, 147, 76, 147, 106, 147, 121, 147, 87, 147, 85, 147, 82, 147, 79, 147, 113, 147, 119, 147, 123, 147, 97, 147, 94, 147, 99, 147, 103, 147, 128, 147, 78, 147, 89, 147, 199, 149, 192, 149, 201, 149, 195, 149, 197, 149, 183, 149, 174, 150, 176, 150, 172, 150, 32, 151, 31, 151, 24, 151, 29, 151, 25, 151, 154, 151, 161, 151, 156, 151, 158, 151, 157, 151, 213, 151, 212, 151, 241, 151, 65, 152, 68, 152, 74, 152, 73, 152, 69, 152, 67, 152, 37, 153, 43, 153, 44, 153, 42, 153, 51, 153, 50, 153, 47, 153, 45, 153, 49, 153, 48, 153, 152, 153, 163, 153, 161, 153, 2, 154, 250, 153, 244, 153, 247, 153, 249, 153, 248, 153, 246, 153, 251, 153, 253, 153, 254, 153, 252, 153, 3, 154, 190, 154, 254, 154, 253, 154, 1, 155, 252, 154, 72, 155, 154, 155, 168, 155, 158, 155, 155, 155, 166, 155, 161, 155, 165, 155, 164, 155, 134, 155, 162, 155, 160, 155, 175, 155, 51, 157, 65, 157, 103, 157, 54, 157, 46, 157, 47, 157, 49, 157, 56, 157, 48, 157, 69, 157, 66, 157, 67, 157, 62, 157, 55, 157, 64, 157, 61, 157, 245, 127, 45, 157, 138, 158, 137, 158, 141, 158, 176, 158, 200, 158, 218, 158, 251, 158, 255, 158, 36, 159, 35, 159, 34, 159, 84, 159, 160, 159, 49, 81, 45, 81, 46, 81, 152, 86, 156, 86, 151, 86, 154, 86, 157, 86, 153, 86, 112, 89, 60, 91, 105, 92, 106, 92, 192, 93, 109, 94, 110, 94, 216, 97, 223, 97, 237, 97, 238, 97, 241, 97, 234, 97, 240, 97, 235, 97, 214, 97, 233, 97, 255, 100, 4, 101, 253, 100, 248, 100, 1, 101, 3, 101, 252, 100, 148, 101, 219, 101, 218, 102, 219, 102, 216, 102, 197, 106, 185, 106, 189, 106, 225, 106, 198, 106, 186, 106, 182, 106, 183, 106, 199, 106, 180, 106, 173, 106, 94, 107, 201, 107, 11, 108, 7, 112, 12, 112, 13, 112, 1, 112, 5, 112, 20, 112, 14, 112, 255, 111, 0, 112, 251, 111, 38, 112, 252, 111, 247, 111, 10, 112, 1, 114, 255, 113, 249, 113, 3, 114, 253, 113, 118, 115, 184, 116, 192, 116, 181, 116, 193, 116, 190, 116, 182, 116, 187, 116, 194, 116, 20, 117, 19, 117, 92, 118, 100, 118, 89, 118, 80, 118, 83, 118, 87, 118, 90, 118, 166, 118, 189, 118, 236, 118, 194, 119, 186, 119, 255, 120, 12, 121, 19, 121, 20, 121, 9, 121, 16, 121, 18, 121, 17, 121, 173, 121, 172, 121, 95, 122, 28, 124, 41, 124, 25, 124, 32, 124, 31, 124, 45, 124, 29, 124, 38, 124, 40, 124, 34, 124, 37, 124, 48, 124, 92, 126, 80, 126, 86, 126, 99, 126, 88, 126, 98, 126, 95, 126, 81, 126, 96, 126, 87, 126, 83, 126, 181, 127, 179, 127, 247, 127, 248, 127, 117, 128, 209, 129, 210, 129, 208, 129, 95, 130, 94, 130, 180, 133, 198, 133, 192, 133, 195, 133, 194, 133, 179, 133, 181, 133, 189, 133, 199, 133, 196, 133, 191, 133, 203, 133, 206, 133, 200, 133, 197, 133, 177, 133, 182, 133, 210, 133, 36, 134, 184, 133, 183, 133, 190, 133, 105, 134, 231, 135, 230, 135, 226, 135, 219, 135, 235, 135, 234, 135, 229, 135, 223, 135, 243, 135, 228, 135, 212, 135, 220, 135, 211, 135, 237, 135, 216, 135, 227, 135, 164, 135, 215, 135, 217, 135, 1, 136, 244, 135, 232, 135, 221, 135, 83, 137, 75, 137, 79, 137, 76, 137, 70, 137, 80, 137, 81, 137, 73, 137, 42, 139, 39, 139, 35, 139, 51, 139, 48, 139, 53, 139, 71, 139, 47, 139, 60, 139, 62, 139, 49, 139, 37, 139, 55, 139, 38, 139, 54, 139, 46, 139, 36, 139, 59, 139, 61, 139, 58, 139, 66, 140, 117, 140, 153, 140, 152, 140, 151, 140, 254, 140, 4, 141, 2, 141, 0, 141, 92, 142, 98, 142, 96, 142, 87, 142, 86, 142, 94, 142, 101, 142, 103, 142, 91, 142, 90, 142, 97, 142, 93, 142, 105, 142, 84, 142, 70, 143, 71, 143, 72, 143, 75, 143, 40, 145, 58, 145, 59, 145, 62, 145, 168, 145, 165, 145, 167, 145, 175, 145, 170, 145, 181, 147, 140, 147, 146, 147, 183, 147, 155, 147, 157, 147, 137, 147, 167, 147, 142, 147, 170, 147, 158, 147, 166, 147, 149, 147, 136, 147, 153, 147, 159, 147, 141, 147, 177, 147, 145, 147, 178, 147, 164, 147, 168, 147, 180, 147, 163, 147, 165, 147, 210, 149, 211, 149, 209, 149, 179, 150, 215, 150, 218, 150, 194, 93, 223, 150, 216, 150, 221, 150, 35, 151, 34, 151, 37, 151, 172, 151, 174, 151, 168, 151, 171, 151, 164, 151, 170, 151, 162, 151, 165, 151, 215, 151, 217, 151, 214, 151, 216, 151, 250, 151, 80, 152, 81, 152, 82, 152, 184, 152, 65, 153, 60, 153, 58, 153, 15, 154, 11, 154, 9, 154, 13, 154, 4, 154, 17, 154, 10, 154, 5, 154, 7, 154, 6, 154, 192, 154, 220, 154, 8, 155, 4, 155, 5, 155, 41, 155, 53, 155, 74, 155, 76, 155, 75, 155, 199, 155, 198, 155, 195, 155, 191, 155, 193, 155, 181, 155, 184, 155, 211, 155, 182, 155, 196, 155, 185, 155, 189, 155, 92, 157, 83, 157, 79, 157, 74, 157, 91, 157, 75, 157, 89, 157, 86, 157, 76, 157, 87, 157, 82, 157, 84, 157, 95, 157, 88, 157, 90, 157, 142, 158, 140, 158, 223, 158, 1, 159, 0, 159, 22, 159, 37, 159, 43, 159, 42, 159, 41, 159, 40, 159, 76, 159, 85, 159, 52, 81, 53, 81, 150, 82, 247, 82, 180, 83, 171, 86, 173, 86, 166, 86, 167, 86, 170, 86, 172, 86, 218, 88, 221, 88, 219, 88, 18, 89, 61, 91, 62, 91, 63, 91, 195, 93, 112, 94, 191, 95, 251, 97, 7, 101, 16, 101, 13, 101, 9, 101, 12, 101, 14, 101, 132, 101, 222, 101, 221, 101, 222, 102, 231, 106, 224, 106, 204, 106, 209, 106, 217, 106, 203, 106, 223, 106, 220, 106, 208, 106, 235, 106, 207, 106, 205, 106, 222, 106, 96, 107, 176, 107, 12, 108, 25, 112, 39, 112, 32, 112, 22, 112, 43, 112, 33, 112, 34, 112, 35, 112, 41, 112, 23, 112, 36, 112, 28, 112, 42, 112, 12, 114, 10, 114, 7, 114, 2, 114, 5, 114, 165, 114, 166, 114, 164, 114, 163, 114, 161, 114, 203, 116, 197, 116, 183, 116, 195, 116, 22, 117, 96, 118, 201, 119, 202, 119, 196, 119, 241, 119, 29, 121, 27, 121, 33, 121, 28, 121, 23, 121, 30, 121, 176, 121, 103, 122, 104, 122, 51, 124, 60, 124, 57, 124, 44, 124, 59, 124, 236, 124, 234, 124, 118, 126, 117, 126, 120, 126, 112, 126, 119, 126, 111, 126, 122, 126, 114, 126, 116, 126, 104, 126, 75, 127, 74, 127, 131, 127, 134, 127, 183, 127, 253, 127, 254, 127, 120, 128, 215, 129, 213, 129, 100, 130, 97, 130, 99, 130, 235, 133, 241, 133, 237, 133, 217, 133, 225, 133, 232, 133, 218, 133, 215, 133, 236, 133, 242, 133, 248, 133, 216, 133, 223, 133, 227, 133, 220, 133, 209, 133, 240, 133, 230, 133, 239, 133, 222, 133, 226, 133, 0, 136, 250, 135, 3, 136, 246, 135, 247, 135, 9, 136, 12, 136, 11, 136, 6, 136, 252, 135, 8, 136, 255, 135, 10, 136, 2, 136, 98, 137, 90, 137, 91, 137, 87, 137, 97, 137, 92, 137, 88, 137, 93, 137, 89, 137, 136, 137, 183, 137, 182, 137, 246, 137, 80, 139, 72, 139, 74, 139, 64, 139, 83, 139, 86, 139, 84, 139, 75, 139, 85, 139, 81, 139, 66, 139, 82, 139, 87, 139, 67, 140, 119, 140, 118, 140, 154, 140, 6, 141, 7, 141, 9, 141, 172, 141, 170, 141, 173, 141, 171, 141, 109, 142, 120, 142, 115, 142, 106, 142, 111, 142, 123, 142, 194, 142, 82, 143, 81, 143, 79, 143, 80, 143, 83, 143, 180, 143, 64, 145, 63, 145, 176, 145, 173, 145, 222, 147, 199, 147, 207, 147, 194, 147, 218, 147, 208, 147, 249, 147, 236, 147, 204, 147, 217, 147, 169, 147, 230, 147, 202, 147, 212, 147, 238, 147, 227, 147, 213, 147, 196, 147, 206, 147, 192, 147, 210, 147, 231, 147, 125, 149, 218, 149, 219, 149, 225, 150, 41, 151, 43, 151, 44, 151, 40, 151, 38, 151, 179, 151, 183, 151, 182, 151, 221, 151, 222, 151, 223, 151, 92, 152, 89, 152, 93, 152, 87, 152, 191, 152, 189, 152, 187, 152, 190, 152, 72, 153, 71, 153, 67, 153, 166, 153, 167, 153, 26, 154, 21, 154, 37, 154, 29, 154, 36, 154, 27, 154, 34, 154, 32, 154, 39, 154, 35, 154, 30, 154, 28, 154, 20, 154, 194, 154, 11, 155, 10, 155, 14, 155, 12, 155, 55, 155, 234, 155, 235, 155, 224, 155, 222, 155, 228, 155, 230, 155, 226, 155, 240, 155, 212, 155, 215, 155, 236, 155, 220, 155, 217, 155, 229, 155, 213, 155, 225, 155, 218, 155, 119, 157, 129, 157, 138, 157, 132, 157, 136, 157, 113, 157, 128, 157, 120, 157, 134, 157, 139, 157, 140, 157, 125, 157, 107, 157, 116, 157, 117, 157, 112, 157, 105, 157, 133, 157, 115, 157, 123, 157, 130, 157, 111, 157, 121, 157, 127, 157, 135, 157, 104, 157, 148, 158, 145, 158, 192, 158, 252, 158, 45, 159, 64, 159, 65, 159, 77, 159, 86, 159, 87, 159, 88, 159, 55, 83, 178, 86, 181, 86, 179, 86, 227, 88, 69, 91, 198, 93, 199, 93, 238, 94, 239, 94, 192, 95, 193, 95, 249, 97, 23, 101, 22, 101, 21, 101, 19, 101, 223, 101, 232, 102, 227, 102, 228, 102, 243, 106, 240, 106, 234, 106, 232, 106, 249, 106, 241, 106, 238, 106, 239, 106, 60, 112, 53, 112, 47, 112, 55, 112, 52, 112, 49, 112, 66, 112, 56, 112, 63, 112, 58, 112, 57, 112, 64, 112, 59, 112, 51, 112, 65, 112, 19, 114, 20, 114, 168, 114, 125, 115, 124, 115, 186, 116, 171, 118, 170, 118, 190, 118, 237, 118, 204, 119, 206, 119, 207, 119, 205, 119, 242, 119, 37, 121, 35, 121, 39, 121, 40, 121, 36, 121, 41, 121, 178, 121, 110, 122, 108, 122, 109, 122, 247, 122, 73, 124, 72, 124, 74, 124, 71, 124, 69, 124, 238, 124, 123, 126, 126, 126, 129, 126, 128, 126, 186, 127, 255, 127, 121, 128, 219, 129, 217, 129, 11, 130, 104, 130, 105, 130, 34, 134, 255, 133, 1, 134, 254, 133, 27, 134, 0, 134, 246, 133, 4, 134, 9, 134, 5, 134, 12, 134, 253, 133, 25, 136, 16, 136, 17, 136, 23, 136, 19, 136, 22, 136, 99, 137, 102, 137, 185, 137, 247, 137, 96, 139, 106, 139, 93, 139, 104, 139, 99, 139, 101, 139, 103, 139, 109, 139, 174, 141, 134, 142, 136, 142, 132, 142, 89, 143, 86, 143, 87, 143, 85, 143, 88, 143, 90, 143, 141, 144, 67, 145, 65, 145, 183, 145, 181, 145, 178, 145, 179, 145, 11, 148, 19, 148, 251, 147, 32, 148, 15, 148, 20, 148, 254, 147, 21, 148, 16, 148, 40, 148, 25, 148, 13, 148, 245, 147, 0, 148, 247, 147, 7, 148, 14, 148, 22, 148, 18, 148, 250, 147, 9, 148, 248, 147, 10, 148, 255, 147, 252, 147, 12, 148, 246, 147, 17, 148, 6, 148, 222, 149, 224, 149, 223, 149, 46, 151, 47, 151, 185, 151, 187, 151, 253, 151, 254, 151, 96, 152, 98, 152, 99, 152, 95, 152, 193, 152, 194, 152, 80, 153, 78, 153, 89, 153, 76, 153, 75, 153, 83, 153, 50, 154, 52, 154, 49, 154, 44, 154, 42, 154, 54, 154, 41, 154, 46, 154, 56, 154, 45, 154, 199, 154, 202, 154, 198, 154, 16, 155, 18, 155, 17, 155, 11, 156, 8, 156, 247, 155, 5, 156, 18, 156, 248, 155, 64, 156, 7, 156, 14, 156, 6, 156, 23, 156, 20, 156, 9, 156, 159, 157, 153, 157, 164, 157, 157, 157, 146, 157, 152, 157, 144, 157, 155, 157, 160, 157, 148, 157, 156, 157, 170, 157, 151, 157, 161, 157, 154, 157, 162, 157, 168, 157, 158, 157, 163, 157, 191, 157, 169, 157, 150, 157, 166, 157, 167, 157, 153, 158, 155, 158, 154, 158, 229, 158, 228, 158, 231, 158, 230, 158, 48, 159, 46, 159, 91, 159, 96, 159, 94, 159, 93, 159, 89, 159, 145, 159, 58, 81, 57, 81, 152, 82, 151, 82, 195, 86, 189, 86, 190, 86, 72, 91, 71, 91, 203, 93, 207, 93, 241, 94, 253, 97, 27, 101, 2, 107, 252, 106, 3, 107, 248, 106, 0, 107, 67, 112, 68, 112, 74, 112, 72, 112, 73, 112, 69, 112, 70, 112, 29, 114, 26, 114, 25, 114, 126, 115, 23, 117, 106, 118, 208, 119, 45, 121, 49, 121, 47, 121, 84, 124, 83, 124, 242, 124, 138, 126, 135, 126, 136, 126, 139, 126, 134, 126, 141, 126, 77, 127, 187, 127, 48, 128, 221, 129, 24, 134, 42, 134, 38, 134, 31, 134, 35, 134, 28, 134, 25, 134, 39, 134, 46, 134, 33, 134, 32, 134, 41, 134, 30, 134, 37, 134, 41, 136, 29, 136, 27, 136, 32, 136, 36, 136, 28, 136, 43, 136, 74, 136, 109, 137, 105, 137, 110, 137, 107, 137, 250, 137, 121, 139, 120, 139, 69, 139, 122, 139, 123, 139, 16, 141, 20, 141, 175, 141, 142, 142, 140, 142, 94, 143, 91, 143, 93, 143, 70, 145, 68, 145, 69, 145, 185, 145, 63, 148, 59, 148, 54, 148, 41, 148, 61, 148, 60, 148, 48, 148, 57, 148, 42, 148, 55, 148, 44, 148, 64, 148, 49, 148, 229, 149, 228, 149, 227, 149, 53, 151, 58, 151, 191, 151, 225, 151, 100, 152, 201, 152, 198, 152, 192, 152, 88, 153, 86, 153, 57, 154, 61, 154, 70, 154, 68, 154, 66, 154, 65, 154, 58, 154, 63, 154, 205, 154, 21, 155, 23, 155, 24, 155, 22, 155, 58, 155, 82, 155, 43, 156, 29, 156, 28, 156, 44, 156, 35, 156, 40, 156, 41, 156, 36, 156, 33, 156, 183, 157, 182, 157, 188, 157, 193, 157, 199, 157, 202, 157, 207, 157, 190, 157, 197, 157, 195, 157, 187, 157, 181, 157, 206, 157, 185, 157, 186, 157, 172, 157, 200, 157, 177, 157, 173, 157, 204, 157, 179, 157, 205, 157, 178, 157, 122, 158, 156, 158, 235, 158, 238, 158, 237, 158, 27, 159, 24, 159, 26, 159, 49, 159, 78, 159, 101, 159, 100, 159, 146, 159, 185, 78, 198, 86, 197, 86, 203, 86, 113, 89, 75, 91, 76, 91, 213, 93, 209, 93, 242, 94, 33, 101, 32, 101, 38, 101, 34, 101, 11, 107, 8, 107, 9, 107, 13, 108, 85, 112, 86, 112, 87, 112, 82, 112, 30, 114, 31, 114, 169, 114, 127, 115, 216, 116, 213, 116, 217, 116, 215, 116, 109, 118, 173, 118, 53, 121, 180, 121, 112, 122, 113, 122, 87, 124, 92, 124, 89, 124, 91, 124, 90, 124, 244, 124, 241, 124, 145, 126, 79, 127, 135, 127, 222, 129, 107, 130, 52, 134, 53, 134, 51, 134, 44, 134, 50, 134, 54, 134, 44, 136, 40, 136, 38, 136, 42, 136, 37, 136, 113, 137, 191, 137, 190, 137, 251, 137, 126, 139, 132, 139, 130, 139, 134, 139, 133, 139, 127, 139, 21, 141, 149, 142, 148, 142, 154, 142, 146, 142, 144, 142, 150, 142, 151, 142, 96, 143, 98, 143, 71, 145, 76, 148, 80, 148, 74, 148, 75, 148, 79, 148, 71, 148, 69, 148, 72, 148, 73, 148, 70, 148, 63, 151, 227, 151, 106, 152, 105, 152, 203, 152, 84, 153, 91, 153, 78, 154, 83, 154, 84, 154, 76, 154, 79, 154, 72, 154, 74, 154, 73, 154, 82, 154, 80, 154, 208, 154, 25, 155, 43, 155, 59, 155, 86, 155, 85, 155, 70, 156, 72, 156, 63, 156, 68, 156, 57, 156, 51, 156, 65, 156, 60, 156, 55, 156, 52, 156, 50, 156, 61, 156, 54, 156, 219, 157, 210, 157, 222, 157, 218, 157, 203, 157, 208, 157, 220, 157, 209, 157, 223, 157, 233, 157, 217, 157, 216, 157, 214, 157, 245, 157, 213, 157, 221, 157, 182, 158, 240, 158, 53, 159, 51, 159, 50, 159, 66, 159, 107, 159, 149, 159, 162, 159, 61, 81, 153, 82, 232, 88, 231, 88, 114, 89, 77, 91, 216, 93, 47, 136, 79, 95, 1, 98, 3, 98, 4, 98, 41, 101, 37, 101, 150, 101, 235, 102, 17, 107, 18, 107, 15, 107, 202, 107, 91, 112, 90, 112, 34, 114, 130, 115, 129, 115, 131, 115, 112, 118, 212, 119, 103, 124, 102, 124, 149, 126, 108, 130, 58, 134, 64, 134, 57, 134, 60, 134, 49, 134, 59, 134, 62, 134, 48, 136, 50, 136, 46, 136, 51, 136, 118, 137, 116, 137, 115, 137, 254, 137, 140, 139, 142, 139, 139, 139, 136, 139, 69, 140, 25, 141, 152, 142, 100, 143, 99, 143, 188, 145, 98, 148, 85, 148, 93, 148, 87, 148, 94, 148, 196, 151, 197, 151, 0, 152, 86, 154, 89, 154, 30, 155, 31, 155, 32, 155, 82, 156, 88, 156, 80, 156, 74, 156, 77, 156, 75, 156, 85, 156, 89, 156, 76, 156, 78, 156, 251, 157, 247, 157, 239, 157, 227, 157, 235, 157, 248, 157, 228, 157, 246, 157, 225, 157, 238, 157, 230, 157, 242, 157, 240, 157, 226, 157, 236, 157, 244, 157, 243, 157, 232, 157, 237, 157, 194, 158, 208, 158, 242, 158, 243, 158, 6, 159, 28, 159, 56, 159, 55, 159, 54, 159, 67, 159, 79, 159, 113, 159, 112, 159, 110, 159, 111, 159, 211, 86, 205, 86, 78, 91, 109, 92, 45, 101, 237, 102, 238, 102, 19, 107, 95, 112, 97, 112, 93, 112, 96, 112, 35, 114, 219, 116, 229, 116, 213, 119, 56, 121, 183, 121, 182, 121, 106, 124, 151, 126, 137, 127, 109, 130, 67, 134, 56, 136, 55, 136, 53, 136, 75, 136, 148, 139, 149, 139, 158, 142, 159, 142, 160, 142, 157, 142, 190, 145, 189, 145, 194, 145, 107, 148, 104, 148, 105, 148, 229, 150, 70, 151, 67, 151, 71, 151, 199, 151, 229, 151, 94, 154, 213, 154, 89, 155, 99, 156, 103, 156, 102, 156, 98, 156, 94, 156, 96, 156, 2, 158, 254, 157, 7, 158, 3, 158, 6, 158, 5, 158, 0, 158, 1, 158, 9, 158, 255, 157, 253, 157, 4, 158, 160, 158, 30, 159, 70, 159, 116, 159, 117, 159, 118, 159, 212, 86, 46, 101, 184, 101, 24, 107, 25, 107, 23, 107, 26, 107, 98, 112, 38, 114, 170, 114, 216, 119, 217, 119, 57, 121, 105, 124, 107, 124, 246, 124, 154, 126, 152, 126, 155, 126, 153, 126, 224, 129, 225, 129, 70, 134, 71, 134, 72, 134, 121, 137, 122, 137, 124, 137, 123, 137, 255, 137, 152, 139, 153, 139, 165, 142, 164, 142, 163, 142, 110, 148, 109, 148, 111, 148, 113, 148, 115, 148, 73, 151, 114, 152, 95, 153, 104, 156, 110, 156, 109, 156, 11, 158, 13, 158, 16, 158, 15, 158, 18, 158, 17, 158, 161, 158, 245, 158, 9, 159, 71, 159, 120, 159, 123, 159, 122, 159, 121, 159, 30, 87, 102, 112, 111, 124, 60, 136, 178, 141, 166, 142, 195, 145, 116, 148, 120, 148, 118, 148, 117, 148, 96, 154, 116, 156, 115, 156, 113, 156, 117, 156, 20, 158, 19, 158, 246, 158, 10, 159, 164, 159, 104, 112, 101, 112, 247, 124, 106, 134, 62, 136, 61, 136, 63, 136, 158, 139, 156, 140, 169, 142, 201, 142, 75, 151, 115, 152, 116, 152, 204, 152, 97, 153, 171, 153, 100, 154, 102, 154, 103, 154, 36, 155, 21, 158, 23, 158, 72, 159, 7, 98, 30, 107, 39, 114, 76, 134, 168, 142, 130, 148, 128, 148, 129, 148, 105, 154, 104, 154, 46, 155, 25, 158, 41, 114, 75, 134, 159, 139, 131, 148, 121, 156, 183, 158, 117, 118, 107, 154, 122, 156, 29, 158, 105, 112, 106, 112, 164, 158, 126, 159, 73, 159, 152, 159, 129, 120, 185, 146, 207, 136, 187, 88, 82, 96, 167, 124, 250, 90, 84, 37, 102, 37, 87, 37, 96, 37, 108, 37, 99, 37, 90, 37, 105, 37, 93, 37, 82, 37, 100, 37, 85, 37, 94, 37, 106, 37, 97, 37, 88, 37, 103, 37, 91, 37, 83, 37, 101, 37, 86, 37, 95, 37, 107, 37, 98, 37, 89, 37, 104, 37, 92, 37, 81, 37, 80, 37, 109, 37, 110, 37, 112, 37, 111, 37, 147, 37, 0, 0, 0, 0, 0, 0, 0, 48, 1, 48, 2, 48, 183, 0, 37, 32, 38, 32, 168, 0, 3, 48, 173, 0, 21, 32, 37, 34, 60, 255, 60, 34, 24, 32, 25, 32, 28, 32, 29, 32, 20, 48, 21, 48, 8, 48, 9, 48, 10, 48, 11, 48, 12, 48, 13, 48, 14, 48, 15, 48, 16, 48, 17, 48, 177, 0, 215, 0, 247, 0, 96, 34, 100, 34, 101, 34, 30, 34, 52, 34, 176, 0, 50, 32, 51, 32, 3, 33, 43, 33, 224, 255, 225, 255, 229, 255, 66, 38, 64, 38, 32, 34, 165, 34, 18, 35, 2, 34, 7, 34, 97, 34, 82, 34, 167, 0, 59, 32, 6, 38, 5, 38, 203, 37, 207, 37, 206, 37, 199, 37, 198, 37, 161, 37, 160, 37, 179, 37, 178, 37, 189, 37, 188, 37, 146, 33, 144, 33, 145, 33, 147, 33, 148, 33, 19, 48, 106, 34, 107, 34, 26, 34, 61, 34, 29, 34, 53, 34, 43, 34, 44, 34, 8, 34, 11, 34, 134, 34, 135, 34, 130, 34, 131, 34, 42, 34, 41, 34, 39, 34, 40, 34, 226, 255, 210, 33, 212, 33, 0, 34, 3, 34, 180, 0, 94, 255, 199, 2, 216, 2, 221, 2, 218, 2, 217, 2, 184, 0, 219, 2, 161, 0, 191, 0, 208, 2, 46, 34, 17, 34, 15, 34, 164, 0, 9, 33, 48, 32, 193, 37, 192, 37, 183, 37, 182, 37, 100, 38, 96, 38, 97, 38, 101, 38, 103, 38, 99, 38, 153, 34, 200, 37, 163, 37, 208, 37, 209, 37, 146, 37, 164, 37, 165, 37, 168, 37, 167, 37, 166, 37, 169, 37, 104, 38, 15, 38, 14, 38, 28, 38, 30, 38, 182, 0, 32, 32, 33, 32, 149, 33, 151, 33, 153, 33, 150, 33, 152, 33, 109, 38, 105, 38, 106, 38, 108, 38, 127, 50, 28, 50, 22, 33, 199, 51, 34, 33, 194, 51, 216, 51, 33, 33, 172, 32, 174, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1, 255, 2, 255, 3, 255, 4, 255, 5, 255, 6, 255, 7, 255, 8, 255, 9, 255, 10, 255, 11, 255, 12, 255, 13, 255, 14, 255, 15, 255, 16, 255, 17, 255, 18, 255, 19, 255, 20, 255, 21, 255, 22, 255, 23, 255, 24, 255, 25, 255, 26, 255, 27, 255, 28, 255, 29, 255, 30, 255, 31, 255, 32, 255, 33, 255, 34, 255, 35, 255, 36, 255, 37, 255, 38, 255, 39, 255, 40, 255, 41, 255, 42, 255, 43, 255, 44, 255, 45, 255, 46, 255, 47, 255, 48, 255, 49, 255, 50, 255, 51, 255, 52, 255, 53, 255, 54, 255, 55, 255, 56, 255, 57, 255, 58, 255, 59, 255, 230, 255, 61, 255, 62, 255, 63, 255, 64, 255, 65, 255, 66, 255, 67, 255, 68, 255, 69, 255, 70, 255, 71, 255, 72, 255, 73, 255, 74, 255, 75, 255, 76, 255, 77, 255, 78, 255, 79, 255, 80, 255, 81, 255, 82, 255, 83, 255, 84, 255, 85, 255, 86, 255, 87, 255, 88, 255, 89, 255, 90, 255, 91, 255, 92, 255, 93, 255, 227, 255, 49, 49, 50, 49, 51, 49, 52, 49, 53, 49, 54, 49, 55, 49, 56, 49, 57, 49, 58, 49, 59, 49, 60, 49, 61, 49, 62, 49, 63, 49, 64, 49, 65, 49, 66, 49, 67, 49, 68, 49, 69, 49, 70, 49, 71, 49, 72, 49, 73, 49, 74, 49, 75, 49, 76, 49, 77, 49, 78, 49, 79, 49, 80, 49, 81, 49, 82, 49, 83, 49, 84, 49, 85, 49, 86, 49, 87, 49, 88, 49, 89, 49, 90, 49, 91, 49, 92, 49, 93, 49, 94, 49, 95, 49, 96, 49, 97, 49, 98, 49, 99, 49, 100, 49, 101, 49, 102, 49, 103, 49, 104, 49, 105, 49, 106, 49, 107, 49, 108, 49, 109, 49, 110, 49, 111, 49, 112, 49, 113, 49, 114, 49, 115, 49, 116, 49, 117, 49, 118, 49, 119, 49, 120, 49, 121, 49, 122, 49, 123, 49, 124, 49, 125, 49, 126, 49, 127, 49, 128, 49, 129, 49, 130, 49, 131, 49, 132, 49, 133, 49, 134, 49, 135, 49, 136, 49, 137, 49, 138, 49, 139, 49, 140, 49, 141, 49, 142, 49, 112, 33, 113, 33, 114, 33, 115, 33, 116, 33, 117, 33, 118, 33, 119, 33, 120, 33, 121, 33, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 96, 33, 97, 33, 98, 33, 99, 33, 100, 33, 101, 33, 102, 33, 103, 33, 104, 33, 105, 33, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 145, 3, 146, 3, 147, 3, 148, 3, 149, 3, 150, 3, 151, 3, 152, 3, 153, 3, 154, 3, 155, 3, 156, 3, 157, 3, 158, 3, 159, 3, 160, 3, 161, 3, 163, 3, 164, 3, 165, 3, 166, 3, 167, 3, 168, 3, 169, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 177, 3, 178, 3, 179, 3, 180, 3, 181, 3, 182, 3, 183, 3, 184, 3, 185, 3, 186, 3, 187, 3, 188, 3, 189, 3, 190, 3, 191, 3, 192, 3, 193, 3, 195, 3, 196, 3, 197, 3, 198, 3, 199, 3, 200, 3, 201, 3, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 37, 2, 37, 12, 37, 16, 37, 24, 37, 20, 37, 28, 37, 44, 37, 36, 37, 52, 37, 60, 37, 1, 37, 3, 37, 15, 37, 19, 37, 27, 37, 23, 37, 35, 37, 51, 37, 43, 37, 59, 37, 75, 37, 32, 37, 47, 37, 40, 37, 55, 37, 63, 37, 29, 37, 48, 37, 37, 37, 56, 37, 66, 37, 18, 37, 17, 37, 26, 37, 25, 37, 22, 37, 21, 37, 14, 37, 13, 37, 30, 37, 31, 37, 33, 37, 34, 37, 38, 37, 39, 37, 41, 37, 42, 37, 45, 37, 46, 37, 49, 37, 50, 37, 53, 37, 54, 37, 57, 37, 58, 37, 61, 37, 62, 37, 64, 37, 65, 37, 67, 37, 68, 37, 69, 37, 70, 37, 71, 37, 72, 37, 73, 37, 74, 37, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 149, 51, 150, 51, 151, 51, 19, 33, 152, 51, 196, 51, 163, 51, 164, 51, 165, 51, 166, 51, 153, 51, 154, 51, 155, 51, 156, 51, 157, 51, 158, 51, 159, 51, 160, 51, 161, 51, 162, 51, 202, 51, 141, 51, 142, 51, 143, 51, 207, 51, 136, 51, 137, 51, 200, 51, 167, 51, 168, 51, 176, 51, 177, 51, 178, 51, 179, 51, 180, 51, 181, 51, 182, 51, 183, 51, 184, 51, 185, 51, 128, 51, 129, 51, 130, 51, 131, 51, 132, 51, 186, 51, 187, 51, 188, 51, 189, 51, 190, 51, 191, 51, 144, 51, 145, 51, 146, 51, 147, 51, 148, 51, 38, 33, 192, 51, 193, 51, 138, 51, 139, 51, 140, 51, 214, 51, 197, 51, 173, 51, 174, 51, 175, 51, 219, 51, 169, 51, 170, 51, 171, 51, 172, 51, 221, 51, 208, 51, 211, 51, 195, 51, 201, 51, 220, 51, 198, 51, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 198, 0, 208, 0, 170, 0, 38, 1, 0, 0, 50, 1, 0, 0, 63, 1, 65, 1, 216, 0, 82, 1, 186, 0, 222, 0, 102, 1, 74, 1, 0, 0, 96, 50, 97, 50, 98, 50, 99, 50, 100, 50, 101, 50, 102, 50, 103, 50, 104, 50, 105, 50, 106, 50, 107, 50, 108, 50, 109, 50, 110, 50, 111, 50, 112, 50, 113, 50, 114, 50, 115, 50, 116, 50, 117, 50, 118, 50, 119, 50, 120, 50, 121, 50, 122, 50, 123, 50, 208, 36, 209, 36, 210, 36, 211, 36, 212, 36, 213, 36, 214, 36, 215, 36, 216, 36, 217, 36, 218, 36, 219, 36, 220, 36, 221, 36, 222, 36, 223, 36, 224, 36, 225, 36, 226, 36, 227, 36, 228, 36, 229, 36, 230, 36, 231, 36, 232, 36, 233, 36, 96, 36, 97, 36, 98, 36, 99, 36, 100, 36, 101, 36, 102, 36, 103, 36, 104, 36, 105, 36, 106, 36, 107, 36, 108, 36, 109, 36, 110, 36, 189, 0, 83, 33, 84, 33, 188, 0, 190, 0, 91, 33, 92, 33, 93, 33, 94, 33, 230, 0, 17, 1, 240, 0, 39, 1, 49, 1, 51, 1, 56, 1, 64, 1, 66, 1, 248, 0, 83, 1, 223, 0, 254, 0, 103, 1, 75, 1, 73, 1, 0, 50, 1, 50, 2, 50, 3, 50, 4, 50, 5, 50, 6, 50, 7, 50, 8, 50, 9, 50, 10, 50, 11, 50, 12, 50, 13, 50, 14, 50, 15, 50, 16, 50, 17, 50, 18, 50, 19, 50, 20, 50, 21, 50, 22, 50, 23, 50, 24, 50, 25, 50, 26, 50, 27, 50, 156, 36, 157, 36, 158, 36, 159, 36, 160, 36, 161, 36, 162, 36, 163, 36, 164, 36, 165, 36, 166, 36, 167, 36, 168, 36, 169, 36, 170, 36, 171, 36, 172, 36, 173, 36, 174, 36, 175, 36, 176, 36, 177, 36, 178, 36, 179, 36, 180, 36, 181, 36, 116, 36, 117, 36, 118, 36, 119, 36, 120, 36, 121, 36, 122, 36, 123, 36, 124, 36, 125, 36, 126, 36, 127, 36, 128, 36, 129, 36, 130, 36, 185, 0, 178, 0, 179, 0, 116, 32, 127, 32, 129, 32, 130, 32, 131, 32, 132, 32, 65, 48, 66, 48, 67, 48, 68, 48, 69, 48, 70, 48, 71, 48, 72, 48, 73, 48, 74, 48, 75, 48, 76, 48, 77, 48, 78, 48, 79, 48, 80, 48, 81, 48, 82, 48, 83, 48, 84, 48, 85, 48, 86, 48, 87, 48, 88, 48, 89, 48, 90, 48, 91, 48, 92, 48, 93, 48, 94, 48, 95, 48, 96, 48, 97, 48, 98, 48, 99, 48, 100, 48, 101, 48, 102, 48, 103, 48, 104, 48, 105, 48, 106, 48, 107, 48, 108, 48, 109, 48, 110, 48, 111, 48, 112, 48, 113, 48, 114, 48, 115, 48, 116, 48, 117, 48, 118, 48, 119, 48, 120, 48, 121, 48, 122, 48, 123, 48, 124, 48, 125, 48, 126, 48, 127, 48, 128, 48, 129, 48, 130, 48, 131, 48, 132, 48, 133, 48, 134, 48, 135, 48, 136, 48, 137, 48, 138, 48, 139, 48, 140, 48, 141, 48, 142, 48, 143, 48, 144, 48, 145, 48, 146, 48, 147, 48, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 161, 48, 162, 48, 163, 48, 164, 48, 165, 48, 166, 48, 167, 48, 168, 48, 169, 48, 170, 48, 171, 48, 172, 48, 173, 48, 174, 48, 175, 48, 176, 48, 177, 48, 178, 48, 179, 48, 180, 48, 181, 48, 182, 48, 183, 48, 184, 48, 185, 48, 186, 48, 187, 48, 188, 48, 189, 48, 190, 48, 191, 48, 192, 48, 193, 48, 194, 48, 195, 48, 196, 48, 197, 48, 198, 48, 199, 48, 200, 48, 201, 48, 202, 48, 203, 48, 204, 48, 205, 48, 206, 48, 207, 48, 208, 48, 209, 48, 210, 48, 211, 48, 212, 48, 213, 48, 214, 48, 215, 48, 216, 48, 217, 48, 218, 48, 219, 48, 220, 48, 221, 48, 222, 48, 223, 48, 224, 48, 225, 48, 226, 48, 227, 48, 228, 48, 229, 48, 230, 48, 231, 48, 232, 48, 233, 48, 234, 48, 235, 48, 236, 48, 237, 48, 238, 48, 239, 48, 240, 48, 241, 48, 242, 48, 243, 48, 244, 48, 245, 48, 246, 48, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 16, 4, 17, 4, 18, 4, 19, 4, 20, 4, 21, 4, 1, 4, 22, 4, 23, 4, 24, 4, 25, 4, 26, 4, 27, 4, 28, 4, 29, 4, 30, 4, 31, 4, 32, 4, 33, 4, 34, 4, 35, 4, 36, 4, 37, 4, 38, 4, 39, 4, 40, 4, 41, 4, 42, 4, 43, 4, 44, 4, 45, 4, 46, 4, 47, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 48, 4, 49, 4, 50, 4, 51, 4, 52, 4, 53, 4, 81, 4, 54, 4, 55, 4, 56, 4, 57, 4, 58, 4, 59, 4, 60, 4, 61, 4, 62, 4, 63, 4, 64, 4, 65, 4, 66, 4, 67, 4, 68, 4, 69, 4, 70, 4, 71, 4, 72, 4, 73, 4, 74, 4, 75, 4, 76, 4, 77, 4, 78, 4, 79, 4, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 172, 1, 172, 4, 172, 7, 172, 8, 172, 9, 172, 10, 172, 16, 172, 17, 172, 18, 172, 19, 172, 20, 172, 21, 172, 22, 172, 23, 172, 25, 172, 26, 172, 27, 172, 28, 172, 29, 172, 32, 172, 36, 172, 44, 172, 45, 172, 47, 172, 48, 172, 49, 172, 56, 172, 57, 172, 60, 172, 64, 172, 75, 172, 77, 172, 84, 172, 88, 172, 92, 172, 112, 172, 113, 172, 116, 172, 119, 172, 120, 172, 122, 172, 128, 172, 129, 172, 131, 172, 132, 172, 133, 172, 134, 172, 137, 172, 138, 172, 139, 172, 140, 172, 144, 172, 148, 172, 156, 172, 157, 172, 159, 172, 160, 172, 161, 172, 168, 172, 169, 172, 170, 172, 172, 172, 175, 172, 176, 172, 184, 172, 185, 172, 187, 172, 188, 172, 189, 172, 193, 172, 196, 172, 200, 172, 204, 172, 213, 172, 215, 172, 224, 172, 225, 172, 228, 172, 231, 172, 232, 172, 234, 172, 236, 172, 239, 172, 240, 172, 241, 172, 243, 172, 245, 172, 246, 172, 252, 172, 253, 172, 0, 173, 4, 173, 6, 173, 12, 173, 13, 173, 15, 173, 17, 173, 24, 173, 28, 173, 32, 173, 41, 173, 44, 173, 45, 173, 52, 173, 53, 173, 56, 173, 60, 173, 68, 173, 69, 173, 71, 173, 73, 173, 80, 173, 84, 173, 88, 173, 97, 173, 99, 173, 108, 173, 109, 173, 112, 173, 115, 173, 116, 173, 117, 173, 118, 173, 123, 173, 124, 173, 125, 173, 127, 173, 129, 173, 130, 173, 136, 173, 137, 173, 140, 173, 144, 173, 156, 173, 157, 173, 164, 173, 183, 173, 192, 173, 193, 173, 196, 173, 200, 173, 208, 173, 209, 173, 211, 173, 220, 173, 224, 173, 228, 173, 248, 173, 249, 173, 252, 173, 255, 173, 0, 174, 1, 174, 8, 174, 9, 174, 11, 174, 13, 174, 20, 174, 48, 174, 49, 174, 52, 174, 55, 174, 56, 174, 58, 174, 64, 174, 65, 174, 67, 174, 69, 174, 70, 174, 74, 174, 76, 174, 77, 174, 78, 174, 80, 174, 84, 174, 86, 174, 92, 174, 93, 174, 95, 174, 96, 174, 97, 174, 101, 174, 104, 174, 105, 174, 108, 174, 112, 174, 120, 174, 121, 174, 123, 174, 124, 174, 125, 174, 132, 174, 133, 174, 140, 174, 188, 174, 189, 174, 190, 174, 192, 174, 196, 174, 204, 174, 205, 174, 207, 174, 208, 174, 209, 174, 216, 174, 217, 174, 220, 174, 232, 174, 235, 174, 237, 174, 244, 174, 248, 174, 252, 174, 7, 175, 8, 175], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 302308);
	        allocate([13, 175, 16, 175, 44, 175, 45, 175, 48, 175, 50, 175, 52, 175, 60, 175, 61, 175, 63, 175, 65, 175, 66, 175, 67, 175, 72, 175, 73, 175, 80, 175, 92, 175, 93, 175, 100, 175, 101, 175, 121, 175, 128, 175, 132, 175, 136, 175, 144, 175, 145, 175, 149, 175, 156, 175, 184, 175, 185, 175, 188, 175, 192, 175, 199, 175, 200, 175, 201, 175, 203, 175, 205, 175, 206, 175, 212, 175, 220, 175, 232, 175, 233, 175, 240, 175, 241, 175, 244, 175, 248, 175, 0, 176, 1, 176, 4, 176, 12, 176, 16, 176, 20, 176, 28, 176, 29, 176, 40, 176, 68, 176, 69, 176, 72, 176, 74, 176, 76, 176, 78, 176, 83, 176, 84, 176, 85, 176, 87, 176, 89, 176, 93, 176, 124, 176, 125, 176, 128, 176, 132, 176, 140, 176, 141, 176, 143, 176, 145, 176, 152, 176, 153, 176, 154, 176, 156, 176, 159, 176, 160, 176, 161, 176, 162, 176, 168, 176, 169, 176, 171, 176, 172, 176, 173, 176, 174, 176, 175, 176, 177, 176, 179, 176, 180, 176, 181, 176, 184, 176, 188, 176, 196, 176, 197, 176, 199, 176, 200, 176, 201, 176, 208, 176, 209, 176, 212, 176, 216, 176, 224, 176, 229, 176, 8, 177, 9, 177, 11, 177, 12, 177, 16, 177, 18, 177, 19, 177, 24, 177, 25, 177, 27, 177, 28, 177, 29, 177, 35, 177, 36, 177, 37, 177, 40, 177, 44, 177, 52, 177, 53, 177, 55, 177, 56, 177, 57, 177, 64, 177, 65, 177, 68, 177, 72, 177, 80, 177, 81, 177, 84, 177, 85, 177, 88, 177, 92, 177, 96, 177, 120, 177, 121, 177, 124, 177, 128, 177, 130, 177, 136, 177, 137, 177, 139, 177, 141, 177, 146, 177, 147, 177, 148, 177, 152, 177, 156, 177, 168, 177, 204, 177, 208, 177, 212, 177, 220, 177, 221, 177, 223, 177, 232, 177, 233, 177, 236, 177, 240, 177, 249, 177, 251, 177, 253, 177, 4, 178, 5, 178, 8, 178, 11, 178, 12, 178, 20, 178, 21, 178, 23, 178, 25, 178, 32, 178, 52, 178, 60, 178, 88, 178, 92, 178, 96, 178, 104, 178, 105, 178, 116, 178, 117, 178, 124, 178, 132, 178, 133, 178, 137, 178, 144, 178, 145, 178, 148, 178, 152, 178, 153, 178, 154, 178, 160, 178, 161, 178, 163, 178, 165, 178, 166, 178, 170, 178, 172, 178, 176, 178, 180, 178, 200, 178, 201, 178, 204, 178, 208, 178, 210, 178, 216, 178, 217, 178, 219, 178, 221, 178, 226, 178, 228, 178, 229, 178, 230, 178, 232, 178, 235, 178, 236, 178, 237, 178, 238, 178, 239, 178, 243, 178, 244, 178, 245, 178, 247, 178, 248, 178, 249, 178, 250, 178, 251, 178, 255, 178, 0, 179, 1, 179, 4, 179, 8, 179, 16, 179, 17, 179, 19, 179, 20, 179, 21, 179, 28, 179, 84, 179, 85, 179, 86, 179, 88, 179, 91, 179, 92, 179, 94, 179, 95, 179, 100, 179, 101, 179, 103, 179, 105, 179, 107, 179, 110, 179, 112, 179, 113, 179, 116, 179, 120, 179, 128, 179, 129, 179, 131, 179, 132, 179, 133, 179, 140, 179, 144, 179, 148, 179, 160, 179, 161, 179, 168, 179, 172, 179, 196, 179, 197, 179, 200, 179, 203, 179, 204, 179, 206, 179, 208, 179, 212, 179, 213, 179, 215, 179, 217, 179, 219, 179, 221, 179, 224, 179, 228, 179, 232, 179, 252, 179, 16, 180, 24, 180, 28, 180, 32, 180, 40, 180, 41, 180, 43, 180, 52, 180, 80, 180, 81, 180, 84, 180, 88, 180, 96, 180, 97, 180, 99, 180, 101, 180, 108, 180, 128, 180, 136, 180, 157, 180, 164, 180, 168, 180, 172, 180, 181, 180, 183, 180, 185, 180, 192, 180, 196, 180, 200, 180, 208, 180, 213, 180, 220, 180, 221, 180, 224, 180, 227, 180, 228, 180, 230, 180, 236, 180, 237, 180, 239, 180, 241, 180, 248, 180, 20, 181, 21, 181, 24, 181, 27, 181, 28, 181, 36, 181, 37, 181, 39, 181, 40, 181, 41, 181, 42, 181, 48, 181, 49, 181, 52, 181, 56, 181, 64, 181, 65, 181, 67, 181, 68, 181, 69, 181, 75, 181, 76, 181, 77, 181, 80, 181, 84, 181, 92, 181, 93, 181, 95, 181, 96, 181, 97, 181, 160, 181, 161, 181, 164, 181, 168, 181, 170, 181, 171, 181, 176, 181, 177, 181, 179, 181, 180, 181, 181, 181, 187, 181, 188, 181, 189, 181, 192, 181, 196, 181, 204, 181, 205, 181, 207, 181, 208, 181, 209, 181, 216, 181, 236, 181, 16, 182, 17, 182, 20, 182, 24, 182, 37, 182, 44, 182, 52, 182, 72, 182, 100, 182, 104, 182, 156, 182, 157, 182, 160, 182, 164, 182, 171, 182, 172, 182, 177, 182, 212, 182, 240, 182, 244, 182, 248, 182, 0, 183, 1, 183, 5, 183, 40, 183, 41, 183, 44, 183, 47, 183, 48, 183, 56, 183, 57, 183, 59, 183, 68, 183, 72, 183, 76, 183, 84, 183, 85, 183, 96, 183, 100, 183, 104, 183, 112, 183, 113, 183, 115, 183, 117, 183, 124, 183, 125, 183, 128, 183, 132, 183, 140, 183, 141, 183, 143, 183, 144, 183, 145, 183, 146, 183, 150, 183, 151, 183, 152, 183, 153, 183, 156, 183, 160, 183, 168, 183, 169, 183, 171, 183, 172, 183, 173, 183, 180, 183, 181, 183, 184, 183, 199, 183, 201, 183, 236, 183, 237, 183, 240, 183, 244, 183, 252, 183, 253, 183, 255, 183, 0, 184, 1, 184, 7, 184, 8, 184, 9, 184, 12, 184, 16, 184, 24, 184, 25, 184, 27, 184, 29, 184, 36, 184, 37, 184, 40, 184, 44, 184, 52, 184, 53, 184, 55, 184, 56, 184, 57, 184, 64, 184, 68, 184, 81, 184, 83, 184, 92, 184, 93, 184, 96, 184, 100, 184, 108, 184, 109, 184, 111, 184, 113, 184, 120, 184, 124, 184, 141, 184, 168, 184, 176, 184, 180, 184, 184, 184, 192, 184, 193, 184, 195, 184, 197, 184, 204, 184, 208, 184, 212, 184, 221, 184, 223, 184, 225, 184, 232, 184, 233, 184, 236, 184, 240, 184, 248, 184, 249, 184, 251, 184, 253, 184, 4, 185, 24, 185, 32, 185, 60, 185, 61, 185, 64, 185, 68, 185, 76, 185, 79, 185, 81, 185, 88, 185, 89, 185, 92, 185, 96, 185, 104, 185, 105, 185, 107, 185, 109, 185, 116, 185, 117, 185, 120, 185, 124, 185, 132, 185, 133, 185, 135, 185, 137, 185, 138, 185, 141, 185, 142, 185, 172, 185, 173, 185, 176, 185, 180, 185, 188, 185, 189, 185, 191, 185, 193, 185, 200, 185, 201, 185, 204, 185, 206, 185, 207, 185, 208, 185, 209, 185, 210, 185, 216, 185, 217, 185, 219, 185, 221, 185, 222, 185, 225, 185, 227, 185, 228, 185, 229, 185, 232, 185, 236, 185, 244, 185, 245, 185, 247, 185, 248, 185, 249, 185, 250, 185, 0, 186, 1, 186, 8, 186, 21, 186, 56, 186, 57, 186, 60, 186, 64, 186, 66, 186, 72, 186, 73, 186, 75, 186, 77, 186, 78, 186, 83, 186, 84, 186, 85, 186, 88, 186, 92, 186, 100, 186, 101, 186, 103, 186, 104, 186, 105, 186, 112, 186, 113, 186, 116, 186, 120, 186, 131, 186, 132, 186, 133, 186, 135, 186, 140, 186, 168, 186, 169, 186, 171, 186, 172, 186, 176, 186, 178, 186, 184, 186, 185, 186, 187, 186, 189, 186, 196, 186, 200, 186, 216, 186, 217, 186, 252, 186, 0, 187, 4, 187, 13, 187, 15, 187, 17, 187, 24, 187, 28, 187, 32, 187, 41, 187, 43, 187, 52, 187, 53, 187, 54, 187, 56, 187, 59, 187, 60, 187, 61, 187, 62, 187, 68, 187, 69, 187, 71, 187, 73, 187, 77, 187, 79, 187, 80, 187, 84, 187, 88, 187, 97, 187, 99, 187, 108, 187, 136, 187, 140, 187, 144, 187, 164, 187, 168, 187, 172, 187, 180, 187, 183, 187, 192, 187, 196, 187, 200, 187, 208, 187, 211, 187, 248, 187, 249, 187, 252, 187, 255, 187, 0, 188, 2, 188, 8, 188, 9, 188, 11, 188, 12, 188, 13, 188, 15, 188, 17, 188, 20, 188, 21, 188, 22, 188, 23, 188, 24, 188, 27, 188, 28, 188, 29, 188, 30, 188, 31, 188, 36, 188, 37, 188, 39, 188, 41, 188, 45, 188, 48, 188, 49, 188, 52, 188, 56, 188, 64, 188, 65, 188, 67, 188, 68, 188, 69, 188, 73, 188, 76, 188, 77, 188, 80, 188, 93, 188, 132, 188, 133, 188, 136, 188, 139, 188, 140, 188, 142, 188, 148, 188, 149, 188, 151, 188, 153, 188, 154, 188, 160, 188, 161, 188, 164, 188, 167, 188, 168, 188, 176, 188, 177, 188, 179, 188, 180, 188, 181, 188, 188, 188, 189, 188, 192, 188, 196, 188, 205, 188, 207, 188, 208, 188, 209, 188, 213, 188, 216, 188, 220, 188, 244, 188, 245, 188, 246, 188, 248, 188, 252, 188, 4, 189, 5, 189, 7, 189, 9, 189, 16, 189, 20, 189, 36, 189, 44, 189, 64, 189, 72, 189, 73, 189, 76, 189, 80, 189, 88, 189, 89, 189, 100, 189, 104, 189, 128, 189, 129, 189, 132, 189, 135, 189, 136, 189, 137, 189, 138, 189, 144, 189, 145, 189, 147, 189, 149, 189, 153, 189, 154, 189, 156, 189, 164, 189, 176, 189, 184, 189, 212, 189, 213, 189, 216, 189, 220, 189, 233, 189, 240, 189, 244, 189, 248, 189, 0, 190, 3, 190, 5, 190, 12, 190, 13, 190, 16, 190, 20, 190, 28, 190, 29, 190, 31, 190, 68, 190, 69, 190, 72, 190, 76, 190, 78, 190, 84, 190, 85, 190, 87, 190, 89, 190, 90, 190, 91, 190, 96, 190, 97, 190, 100, 190, 104, 190, 106, 190, 112, 190, 113, 190, 115, 190, 116, 190, 117, 190, 123, 190, 124, 190, 125, 190, 128, 190, 132, 190, 140, 190, 141, 190, 143, 190, 144, 190, 145, 190, 152, 190, 153, 190, 168, 190, 208, 190, 209, 190, 212, 190, 215, 190, 216, 190, 224, 190, 227, 190, 228, 190, 229, 190, 236, 190, 1, 191, 8, 191, 9, 191, 24, 191, 25, 191, 27, 191, 28, 191, 29, 191, 64, 191, 65, 191, 68, 191, 72, 191, 80, 191, 81, 191, 85, 191, 148, 191, 176, 191, 197, 191, 204, 191, 205, 191, 208, 191, 212, 191, 220, 191, 223, 191, 225, 191, 60, 192, 81, 192, 88, 192, 92, 192, 96, 192, 104, 192, 105, 192, 144, 192, 145, 192, 148, 192, 152, 192, 160, 192, 161, 192, 163, 192, 165, 192, 172, 192, 173, 192, 175, 192, 176, 192, 179, 192, 180, 192, 181, 192, 182, 192, 188, 192, 189, 192, 191, 192, 192, 192, 193, 192, 197, 192, 200, 192, 201, 192, 204, 192, 208, 192, 216, 192, 217, 192, 219, 192, 220, 192, 221, 192, 228, 192, 229, 192, 232, 192, 236, 192, 244, 192, 245, 192, 247, 192, 249, 192, 0, 193, 4, 193, 8, 193, 16, 193, 21, 193, 28, 193, 29, 193, 30, 193, 31, 193, 32, 193, 35, 193, 36, 193, 38, 193, 39, 193, 44, 193, 45, 193, 47, 193, 48, 193, 49, 193, 54, 193, 56, 193, 57, 193, 60, 193, 64, 193, 72, 193, 73, 193, 75, 193, 76, 193, 77, 193, 84, 193, 85, 193, 88, 193, 92, 193, 100, 193, 101, 193, 103, 193, 104, 193, 105, 193, 112, 193, 116, 193, 120, 193, 133, 193, 140, 193, 141, 193, 142, 193, 144, 193, 148, 193, 150, 193, 156, 193, 157, 193, 159, 193, 161, 193, 165, 193, 168, 193, 169, 193, 172, 193, 176, 193, 189, 193, 196, 193, 200, 193, 204, 193, 212, 193, 215, 193, 216, 193, 224, 193, 228, 193, 232, 193, 240, 193, 241, 193, 243, 193, 252, 193, 253, 193, 0, 194, 4, 194, 12, 194, 13, 194, 15, 194, 17, 194, 24, 194, 25, 194, 28, 194, 31, 194, 32, 194, 40, 194, 41, 194, 43, 194, 45, 194, 47, 194, 49, 194, 50, 194, 52, 194, 72, 194, 80, 194, 81, 194, 84, 194, 88, 194, 96, 194, 101, 194, 108, 194, 109, 194, 112, 194, 116, 194, 124, 194, 125, 194, 127, 194, 129, 194, 136, 194, 137, 194, 144, 194, 152, 194, 155, 194, 157, 194, 164, 194, 165, 194, 168, 194, 172, 194, 173, 194, 180, 194, 181, 194, 183, 194, 185, 194, 220, 194, 221, 194, 224, 194, 227, 194, 228, 194, 235, 194, 236, 194, 237, 194, 239, 194, 241, 194, 246, 194, 248, 194, 249, 194, 251, 194, 252, 194, 0, 195, 8, 195, 9, 195, 12, 195, 13, 195, 19, 195, 20, 195, 21, 195, 24, 195, 28, 195, 36, 195, 37, 195, 40, 195, 41, 195, 69, 195, 104, 195, 105, 195, 108, 195, 112, 195, 114, 195, 120, 195, 121, 195, 124, 195, 125, 195, 132, 195, 136, 195, 140, 195, 192, 195, 216, 195, 217, 195, 220, 195, 223, 195, 224, 195, 226, 195, 232, 195, 233, 195, 237, 195, 244, 195, 245, 195, 248, 195, 8, 196, 16, 196, 36, 196, 44, 196, 48, 196, 52, 196, 60, 196, 61, 196, 72, 196, 100, 196, 101, 196, 104, 196, 108, 196, 116, 196, 117, 196, 121, 196, 128, 196, 148, 196, 156, 196, 184, 196, 188, 196, 233, 196, 240, 196, 241, 196, 244, 196, 248, 196, 250, 196, 255, 196, 0, 197, 1, 197, 12, 197, 16, 197, 20, 197, 28, 197, 40, 197, 41, 197, 44, 197, 48, 197, 56, 197, 57, 197, 59, 197, 61, 197, 68, 197, 69, 197, 72, 197, 73, 197, 74, 197, 76, 197, 77, 197, 78, 197, 83, 197, 84, 197, 85, 197, 87, 197, 88, 197, 89, 197, 93, 197, 94, 197, 96, 197, 97, 197, 100, 197, 104, 197, 112, 197, 113, 197, 115, 197, 116, 197, 117, 197, 124, 197, 125, 197, 128, 197, 132, 197, 135, 197, 140, 197, 141, 197, 143, 197, 145, 197, 149, 197, 151, 197, 152, 197, 156, 197, 160, 197, 169, 197, 180, 197, 181, 197, 184, 197, 185, 197, 187, 197, 188, 197, 189, 197, 190, 197, 196, 197, 197, 197, 198, 197, 199, 197, 200, 197, 201, 197, 202, 197, 204, 197, 206, 197, 208, 197, 209, 197, 212, 197, 216, 197, 224, 197, 225, 197, 227, 197, 229, 197, 236, 197, 237, 197, 238, 197, 240, 197, 244, 197, 246, 197, 247, 197, 252, 197, 253, 197, 254, 197, 255, 197, 0, 198, 1, 198, 5, 198, 6, 198, 7, 198, 8, 198, 12, 198, 16, 198, 24, 198, 25, 198, 27, 198, 28, 198, 36, 198, 37, 198, 40, 198, 44, 198, 45, 198, 46, 198, 48, 198, 51, 198, 52, 198, 53, 198, 55, 198, 57, 198, 59, 198, 64, 198, 65, 198, 68, 198, 72, 198, 80, 198, 81, 198, 83, 198, 84, 198, 85, 198, 92, 198, 93, 198, 96, 198, 108, 198, 111, 198, 113, 198, 120, 198, 121, 198, 124, 198, 128, 198, 136, 198, 137, 198, 139, 198, 141, 198, 148, 198, 149, 198, 152, 198, 156, 198, 164, 198, 165, 198, 167, 198, 169, 198, 176, 198, 177, 198, 180, 198, 184, 198, 185, 198, 186, 198, 192, 198, 193, 198, 195, 198, 197, 198, 204, 198, 205, 198, 208, 198, 212, 198, 220, 198, 221, 198, 224, 198, 225, 198, 232, 198, 233, 198, 236, 198, 240, 198, 248, 198, 249, 198, 253, 198, 4, 199, 5, 199, 8, 199, 12, 199, 20, 199, 21, 199, 23, 199, 25, 199, 32, 199, 33, 199, 36, 199, 40, 199, 48, 199, 49, 199, 51, 199, 53, 199, 55, 199, 60, 199, 61, 199, 64, 199, 68, 199, 74, 199, 76, 199, 77, 199, 79, 199, 81, 199, 82, 199, 83, 199, 84, 199, 85, 199, 86, 199, 87, 199, 88, 199, 92, 199, 96, 199, 104, 199, 107, 199, 116, 199, 117, 199, 120, 199, 124, 199, 125, 199, 126, 199, 131, 199, 132, 199, 133, 199, 135, 199, 136, 199, 137, 199, 138, 199, 142, 199, 144, 199, 145, 199, 148, 199, 150, 199, 151, 199, 152, 199, 154, 199, 160, 199, 161, 199, 163, 199, 164, 199, 165, 199, 166, 199, 172, 199, 173, 199, 176, 199, 180, 199, 188, 199, 189, 199, 191, 199, 192, 199, 193, 199, 200, 199, 201, 199, 204, 199, 206, 199, 208, 199, 216, 199, 221, 199, 228, 199, 232, 199, 236, 199, 0, 200, 1, 200, 4, 200, 8, 200, 10, 200, 16, 200, 17, 200, 19, 200, 21, 200, 22, 200, 28, 200, 29, 200, 32, 200, 36, 200, 44, 200, 45, 200, 47, 200, 49, 200, 56, 200, 60, 200, 64, 200, 72, 200, 73, 200, 76, 200, 77, 200, 84, 200, 112, 200, 113, 200, 116, 200, 120, 200, 122, 200, 128, 200, 129, 200, 131, 200, 133, 200, 134, 200, 135, 200, 139, 200, 140, 200, 141, 200, 148, 200, 157, 200, 159, 200, 161, 200, 168, 200, 188, 200, 189, 200, 196, 200, 200, 200, 204, 200, 212, 200, 213, 200, 215, 200, 217, 200, 224, 200, 225, 200, 228, 200, 245, 200, 252, 200, 253, 200, 0, 201, 4, 201, 5, 201, 6, 201, 12, 201, 13, 201, 15, 201, 17, 201, 24, 201, 44, 201, 52, 201, 80, 201, 81, 201, 84, 201, 88, 201, 96, 201, 97, 201, 99, 201, 108, 201, 112, 201, 116, 201, 124, 201, 136, 201, 137, 201, 140, 201, 144, 201, 152, 201, 153, 201, 155, 201, 157, 201, 192, 201, 193, 201, 196, 201, 199, 201, 200, 201, 202, 201, 208, 201, 209, 201, 211, 201, 213, 201, 214, 201, 217, 201, 218, 201, 220, 201, 221, 201, 224, 201, 226, 201, 228, 201, 231, 201, 236, 201, 237, 201, 239, 201, 240, 201, 241, 201, 248, 201, 249, 201, 252, 201, 0, 202, 8, 202, 9, 202, 11, 202, 12, 202, 13, 202, 20, 202, 24, 202, 41, 202, 76, 202, 77, 202, 80, 202, 84, 202, 92, 202, 93, 202, 95, 202, 96, 202, 97, 202, 104, 202, 125, 202, 132, 202, 152, 202, 188, 202, 189, 202, 192, 202, 196, 202, 204, 202, 205, 202, 207, 202, 209, 202, 211, 202, 216, 202, 217, 202, 224, 202, 236, 202, 244, 202, 8, 203, 16, 203, 20, 203, 24, 203, 32, 203, 33, 203, 65, 203, 72, 203, 73, 203, 76, 203, 80, 203, 88, 203, 89, 203, 93, 203, 100, 203, 120, 203, 121, 203, 156, 203, 184, 203, 212, 203, 228, 203, 231, 203, 233, 203, 12, 204, 13, 204, 16, 204, 20, 204, 28, 204, 29, 204, 33, 204, 34, 204, 39, 204, 40, 204, 41, 204, 44, 204, 46, 204, 48, 204, 56, 204, 57, 204, 59, 204, 60, 204, 61, 204, 62, 204, 68, 204, 69, 204, 72, 204, 76, 204, 84, 204, 85, 204, 87, 204, 88, 204, 89, 204, 96, 204, 100, 204, 102, 204, 104, 204, 112, 204, 117, 204, 152, 204, 153, 204, 156, 204, 160, 204, 168, 204, 169, 204, 171, 204, 172, 204, 173, 204, 180, 204, 181, 204, 184, 204, 188, 204, 196, 204, 197, 204, 199, 204, 201, 204, 208, 204, 212, 204, 228, 204, 236, 204, 240, 204, 1, 205, 8, 205, 9, 205, 12, 205, 16, 205, 24, 205, 25, 205, 27, 205, 29, 205, 36, 205, 40, 205, 44, 205, 57, 205, 92, 205, 96, 205, 100, 205, 108, 205, 109, 205, 111, 205, 113, 205, 120, 205, 136, 205, 148, 205, 149, 205, 152, 205, 156, 205, 164, 205, 165, 205, 167, 205, 169, 205, 176, 205, 196, 205, 204, 205, 208, 205, 232, 205, 236, 205, 240, 205, 248, 205, 249, 205, 251, 205, 253, 205, 4, 206, 8, 206, 12, 206, 20, 206, 25, 206, 32, 206, 33, 206, 36, 206, 40, 206, 48, 206, 49, 206, 51, 206, 53, 206, 88, 206, 89, 206, 92, 206, 95, 206, 96, 206, 97, 206, 104, 206, 105, 206, 107, 206, 109, 206, 116, 206, 117, 206, 120, 206, 124, 206, 132, 206, 133, 206, 135, 206, 137, 206, 144, 206, 145, 206, 148, 206, 152, 206, 160, 206, 161, 206, 163, 206, 164, 206, 165, 206, 172, 206, 173, 206, 193, 206, 228, 206, 229, 206, 232, 206, 235, 206, 236, 206, 244, 206, 245, 206, 247, 206, 248, 206, 249, 206, 0, 207, 1, 207, 4, 207, 8, 207, 16, 207, 17, 207, 19, 207, 21, 207, 28, 207, 32, 207, 36, 207, 44, 207, 45, 207, 47, 207, 48, 207, 49, 207, 56, 207, 84, 207, 85, 207, 88, 207, 92, 207, 100, 207, 101, 207, 103, 207, 105, 207, 112, 207, 113, 207, 116, 207, 120, 207, 128, 207, 133, 207, 140, 207, 161, 207, 168, 207, 176, 207, 196, 207, 224, 207, 225, 207, 228, 207, 232, 207, 240, 207, 241, 207, 243, 207, 245, 207, 252, 207, 0, 208, 4, 208, 17, 208, 24, 208, 45, 208, 52, 208, 53, 208, 56, 208, 60, 208, 68, 208, 69, 208, 71, 208, 73, 208, 80, 208, 84, 208, 88, 208, 96, 208, 108, 208, 109, 208, 112, 208, 116, 208, 124, 208, 125, 208, 129, 208, 164, 208, 165, 208, 168, 208, 172, 208, 180, 208, 181, 208, 183, 208, 185, 208, 192, 208, 193, 208, 196, 208, 200, 208, 201, 208, 208, 208, 209, 208, 211, 208, 212, 208, 213, 208, 220, 208, 221, 208, 224, 208, 228, 208, 236, 208, 237, 208, 239, 208, 240, 208, 241, 208, 248, 208, 13, 209, 48, 209, 49, 209, 52, 209, 56, 209, 58, 209, 64, 209, 65, 209, 67, 209, 68, 209, 69, 209, 76, 209, 77, 209, 80, 209, 84, 209, 92, 209, 93, 209, 95, 209, 97, 209, 104, 209, 108, 209, 124, 209, 132, 209, 136, 209, 160, 209, 161, 209, 164, 209, 168, 209, 176, 209, 177, 209, 179, 209, 181, 209, 186, 209, 188, 209, 192, 209, 216, 209, 244, 209, 248, 209, 7, 210, 9, 210, 16, 210, 44, 210, 45, 210, 48, 210, 52, 210, 60, 210, 61, 210, 63, 210, 65, 210, 72, 210, 92, 210, 100, 210, 128, 210, 129, 210, 132, 210, 136, 210, 144, 210, 145, 210, 149, 210, 156, 210, 160, 210, 164, 210, 172, 210, 177, 210, 184, 210, 185, 210, 188, 210, 191, 210, 192, 210, 194, 210, 200, 210, 201, 210, 203, 210, 212, 210, 216, 210, 220, 210, 228, 210, 229, 210, 240, 210, 241, 210, 244, 210, 248, 210, 0, 211, 1, 211, 3, 211, 5, 211, 12, 211, 13, 211, 14, 211, 16, 211, 20, 211, 22, 211, 28, 211, 29, 211, 31, 211, 32, 211, 33, 211, 37, 211, 40, 211, 41, 211, 44, 211, 48, 211, 56, 211, 57, 211, 59, 211, 60, 211, 61, 211, 68, 211, 69, 211, 124, 211, 125, 211, 128, 211, 132, 211, 140, 211, 141, 211, 143, 211, 144, 211, 145, 211, 152, 211, 153, 211, 156, 211, 160, 211, 168, 211, 169, 211, 171, 211, 173, 211, 180, 211, 184, 211, 188, 211, 196, 211, 197, 211, 200, 211, 201, 211, 208, 211, 216, 211, 225, 211, 227, 211, 236, 211, 237, 211, 240, 211, 244, 211, 252, 211, 253, 211, 255, 211, 1, 212, 8, 212, 29, 212, 64, 212, 68, 212, 92, 212, 96, 212, 100, 212, 109, 212, 111, 212, 120, 212, 121, 212, 124, 212, 127, 212, 128, 212, 130, 212, 136, 212, 137, 212, 139, 212, 141, 212, 148, 212, 169, 212, 204, 212, 208, 212, 212, 212, 220, 212, 223, 212, 232, 212, 236, 212, 240, 212, 248, 212, 251, 212, 253, 212, 4, 213, 8, 213, 12, 213, 20, 213, 21, 213, 23, 213, 60, 213, 61, 213, 64, 213, 68, 213, 76, 213, 77, 213, 79, 213, 81, 213, 88, 213, 89, 213, 92, 213, 96, 213, 101, 213, 104, 213, 105, 213, 107, 213, 109, 213, 116, 213, 117, 213, 120, 213, 124, 213, 132, 213, 133, 213, 135, 213, 136, 213, 137, 213, 144, 213, 165, 213, 200, 213, 201, 213, 204, 213, 208, 213, 210, 213, 216, 213, 217, 213, 219, 213, 221, 213, 228, 213, 229, 213, 232, 213, 236, 213, 244, 213, 245, 213, 247, 213, 249, 213, 0, 214, 1, 214, 4, 214, 8, 214, 16, 214, 17, 214, 19, 214, 20, 214, 21, 214, 28, 214, 32, 214, 36, 214, 45, 214, 56, 214, 57, 214, 60, 214, 64, 214, 69, 214, 72, 214, 73, 214, 75, 214, 77, 214, 81, 214, 84, 214, 85, 214, 88, 214, 92, 214, 103, 214, 105, 214, 112, 214, 113, 214, 116, 214, 131, 214, 133, 214, 140, 214, 141, 214, 144, 214, 148, 214, 157, 214, 159, 214, 161, 214, 168, 214, 172, 214, 176, 214, 185, 214, 187, 214, 196, 214, 197, 214, 200, 214, 204, 214, 209, 214, 212, 214, 215, 214, 217, 214, 224, 214, 228, 214, 232, 214, 240, 214, 245, 214, 252, 214, 253, 214, 0, 215, 4, 215, 17, 215, 24, 215, 25, 215, 28, 215, 32, 215, 40, 215, 41, 215, 43, 215, 45, 215, 52, 215, 53, 215, 56, 215, 60, 215, 68, 215, 71, 215, 73, 215, 80, 215, 81, 215, 84, 215, 86, 215, 87, 215, 88, 215, 89, 215, 96, 215, 97, 215, 99, 215, 101, 215, 105, 215, 108, 215, 112, 215, 116, 215, 124, 215, 125, 215, 129, 215, 136, 215, 137, 215, 140, 215, 144, 215, 152, 215, 153, 215, 155, 215, 157, 215, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 61, 79, 115, 79, 71, 80, 249, 80, 160, 82, 239, 83, 117, 84, 229, 84, 9, 86, 193, 90, 182, 91, 135, 102, 182, 103, 183, 103, 239, 103, 76, 107, 194, 115, 194, 117, 60, 122, 219, 130, 4, 131, 87, 136, 136, 136, 54, 138, 200, 140, 207, 141, 251, 142, 230, 143, 213, 153, 59, 82, 116, 83, 4, 84, 106, 96, 100, 97, 188, 107, 207, 115, 26, 129, 186, 137, 210, 137, 163, 149, 131, 79, 10, 82, 190, 88, 120, 89, 230, 89, 114, 94, 121, 94, 199, 97, 192, 99, 70, 103, 236, 103, 127, 104, 151, 111, 78, 118, 11, 119, 245, 120, 8, 122, 255, 122, 33, 124, 157, 128, 110, 130, 113, 130, 235, 138, 147, 149, 107, 78, 157, 85, 247, 102, 52, 110, 163, 120, 237, 122, 91, 132, 16, 137, 78, 135, 168, 151, 216, 82, 78, 87, 42, 88, 76, 93, 31, 97, 190, 97, 33, 98, 98, 101, 209, 103, 68, 106, 27, 110, 24, 117, 179, 117, 227, 118, 176, 119, 58, 125, 175, 144, 81, 148, 82, 148, 149, 159, 35, 83, 172, 92, 50, 117, 219, 128, 64, 146, 152, 149, 91, 82, 8, 88, 220, 89, 161, 92, 23, 93, 183, 94, 58, 95, 74, 95, 119, 97, 95, 108, 122, 117, 134, 117, 224, 124, 115, 125, 177, 125, 140, 127, 84, 129, 33, 130, 145, 133, 65, 137, 27, 139, 252, 146, 77, 150, 71, 156, 203, 78, 247, 78, 11, 80, 241, 81, 79, 88, 55, 97, 62, 97, 104, 97, 57, 101, 234, 105, 17, 111, 165, 117, 134, 118, 214, 118, 135, 123, 165, 130, 203, 132, 0, 249, 167, 147, 139, 149, 128, 85, 162, 91, 81, 87, 1, 249, 179, 124, 185, 127, 181, 145, 40, 80, 187, 83, 69, 92, 232, 93, 210, 98, 110, 99, 218, 100, 231, 100, 32, 110, 172, 112, 91, 121, 221, 141, 30, 142, 2, 249, 125, 144, 69, 146, 248, 146, 126, 78, 246, 78, 101, 80, 254, 93, 250, 94, 6, 97, 87, 105, 113, 129, 84, 134, 71, 142, 117, 147, 43, 154, 94, 78, 145, 80, 112, 103, 64, 104, 9, 81, 141, 82, 146, 82, 162, 106, 188, 119, 16, 146, 212, 158, 171, 82, 47, 96, 242, 143, 72, 80, 169, 97, 237, 99, 202, 100, 60, 104, 132, 106, 192, 111, 136, 129, 161, 137, 148, 150, 5, 88, 125, 114, 172, 114, 4, 117, 121, 125, 109, 126, 169, 128, 139, 137, 116, 139, 99, 144, 81, 157, 137, 98, 122, 108, 84, 111, 80, 125, 58, 127, 35, 138, 124, 81, 74, 97, 157, 123, 25, 139, 87, 146, 140, 147, 172, 78, 211, 79, 30, 80, 190, 80, 6, 81, 193, 82, 205, 82, 127, 83, 112, 87, 131, 88, 154, 94, 145, 95, 118, 97, 172, 97, 206, 100, 108, 101, 111, 102, 187, 102, 244, 102, 151, 104, 135, 109, 133, 112, 241, 112, 159, 116, 165, 116, 202, 116, 217, 117, 108, 120, 236, 120, 223, 122, 246, 122, 69, 125, 147, 125, 21, 128, 63, 128, 27, 129, 150, 131, 102, 139, 21, 143, 21, 144, 225, 147, 3, 152, 56, 152, 90, 154, 232, 155, 194, 79, 83, 85, 58, 88, 81, 89, 99, 91, 70, 92, 184, 96, 18, 98, 66, 104, 176, 104, 232, 104, 170, 110, 76, 117, 120, 118, 206, 120, 61, 122, 251, 124, 107, 126, 124, 126, 8, 138, 161, 138, 63, 140, 142, 150, 196, 157, 228, 83, 233, 83, 74, 84, 113, 84, 250, 86, 209, 89, 100, 91, 59, 92, 171, 94, 247, 98, 55, 101, 69, 101, 114, 101, 160, 102, 175, 103, 193, 105, 189, 108, 252, 117, 144, 118, 126, 119, 63, 122, 148, 127, 3, 128, 161, 128, 143, 129, 230, 130, 253, 130, 240, 131, 193, 133, 49, 136, 180, 136, 165, 138, 3, 249, 156, 143, 46, 147, 199, 150, 103, 152, 216, 154, 19, 159, 237, 84, 155, 101, 242, 102, 143, 104, 64, 122, 55, 140, 96, 157, 240, 86, 100, 87, 17, 93, 6, 102, 177, 104, 205, 104, 254, 110, 40, 116, 158, 136, 228, 155, 104, 108, 4, 249, 168, 154, 155, 79, 108, 81, 113, 81, 159, 82, 84, 91, 229, 93, 80, 96, 109, 96, 241, 98, 167, 99, 59, 101, 217, 115, 122, 122, 163, 134, 162, 140, 143, 151, 50, 78, 225, 91, 8, 98, 156, 103, 220, 116, 209, 121, 211, 131, 135, 138, 178, 138, 232, 141, 78, 144, 75, 147, 70, 152, 211, 94, 232, 105, 255, 133, 237, 144, 5, 249, 160, 81, 152, 91, 236, 91, 99, 97, 250, 104, 62, 107, 76, 112, 47, 116, 216, 116, 161, 123, 80, 127, 197, 131, 192, 137, 171, 140, 220, 149, 40, 153, 46, 82, 93, 96, 236, 98, 2, 144, 138, 79, 73, 81, 33, 83, 217, 88, 227, 94, 224, 102, 56, 109, 154, 112, 194, 114, 214, 115, 80, 123, 241, 128, 91, 148, 102, 83, 155, 99, 107, 127, 86, 78, 128, 80, 74, 88, 222, 88, 42, 96, 39, 97, 208, 98, 208, 105, 65, 155, 143, 91, 24, 125, 177, 128, 95, 143, 164, 78, 209, 80, 172, 84, 172, 85, 12, 91, 160, 93, 231, 93, 42, 101, 78, 101, 33, 104, 75, 106, 225, 114, 142, 118, 239, 119, 94, 125, 249, 127, 160, 129, 78, 133, 223, 134, 3, 143, 78, 143, 202, 144, 3, 153, 85, 154, 171, 155, 24, 78, 69, 78, 93, 78, 199, 78, 241, 79, 119, 81, 254, 82, 64, 83, 227, 83, 229, 83, 142, 84, 20, 86, 117, 87, 162, 87, 199, 91, 135, 93, 208, 94, 252, 97, 216, 98, 81, 101, 184, 103, 233, 103, 203, 105, 80, 107, 198, 107, 236, 107, 66, 108, 157, 110, 120, 112, 215, 114, 150, 115, 3, 116, 191, 119, 233, 119, 118, 122, 127, 125, 9, 128, 252, 129, 5, 130, 10, 130, 223, 130, 98, 136, 51, 139, 252, 140, 192, 142, 17, 144, 177, 144, 100, 146, 182, 146, 210, 153, 69, 154, 233, 156, 215, 157, 156, 159, 11, 87, 64, 92, 202, 131, 160, 151, 171, 151, 180, 158, 27, 84, 152, 122, 164, 127, 217, 136, 205, 142, 225, 144, 0, 88, 72, 92, 152, 99, 159, 122, 174, 91, 19, 95, 121, 122, 174, 122, 142, 130, 172, 142, 38, 80, 56, 82, 248, 82, 119, 83, 8, 87, 243, 98, 114, 99, 10, 107, 195, 109, 55, 119, 165, 83, 87, 115, 104, 133, 118, 142, 213, 149, 58, 103, 195, 106, 112, 111, 109, 138, 204, 142, 75, 153, 6, 249, 119, 102, 120, 107, 180, 140, 60, 155, 7, 249, 235, 83, 45, 87, 78, 89, 198, 99, 251, 105, 234, 115, 69, 120, 186, 122, 197, 122, 254, 124, 117, 132, 143, 137, 115, 141, 53, 144, 168, 149, 251, 82, 71, 87, 71, 117, 96, 123, 204, 131, 30, 146, 8, 249, 88, 106, 75, 81, 75, 82, 135, 82, 31, 98, 216, 104, 117, 105, 153, 150, 197, 80, 164, 82, 228, 82, 195, 97, 164, 101, 57, 104, 255, 105, 126, 116, 75, 123, 185, 130, 235, 131, 178, 137, 57, 139, 209, 143, 73, 153, 9, 249, 202, 78, 151, 89, 210, 100, 17, 102, 142, 106, 52, 116, 129, 121, 189, 121, 169, 130, 126, 136, 127, 136, 95, 137, 10, 249, 38, 147, 11, 79, 202, 83, 37, 96, 113, 98, 114, 108, 26, 125, 102, 125, 152, 78, 98, 81, 220, 119, 175, 128, 1, 79, 14, 79, 118, 81, 128, 81, 220, 85, 104, 86, 59, 87, 250, 87, 252, 87, 20, 89, 71, 89, 147, 89, 196, 91, 144, 92, 14, 93, 241, 93, 126, 94, 204, 95, 128, 98, 215, 101, 227, 101, 30, 103, 31, 103, 94, 103, 203, 104, 196, 104, 95, 106, 58, 107, 35, 108, 125, 108, 130, 108, 199, 109, 152, 115, 38, 116, 42, 116, 130, 116, 163, 116, 120, 117, 127, 117, 129, 120, 239, 120, 65, 121, 71, 121, 72, 121, 122, 121, 149, 123, 0, 125, 186, 125, 136, 127, 6, 128, 45, 128, 140, 128, 24, 138, 79, 139, 72, 140, 119, 141, 33, 147, 36, 147, 226, 152, 81, 153, 14, 154, 15, 154, 101, 154, 146, 158, 202, 125, 118, 79, 9, 84, 238, 98, 84, 104, 209, 145, 171, 85, 58, 81, 11, 249, 12, 249, 28, 90, 230, 97, 13, 249, 207, 98, 255, 98, 14, 249, 15, 249, 16, 249, 17, 249, 18, 249, 19, 249, 163, 144, 20, 249, 21, 249, 22, 249, 23, 249, 24, 249, 254, 138, 25, 249, 26, 249, 27, 249, 28, 249, 150, 102, 29, 249, 86, 113, 30, 249, 31, 249, 227, 150, 32, 249, 79, 99, 122, 99, 87, 83, 33, 249, 143, 103, 96, 105, 115, 110, 34, 249, 55, 117, 35, 249, 36, 249, 37, 249, 13, 125, 38, 249, 39, 249, 114, 136, 202, 86, 24, 90, 40, 249, 41, 249, 42, 249, 43, 249, 44, 249, 67, 78, 45, 249, 103, 81, 72, 89, 240, 103, 16, 128, 46, 249, 115, 89, 116, 94, 154, 100, 202, 121, 245, 95, 108, 96, 200, 98, 123, 99, 231, 91, 215, 91, 170, 82, 47, 249, 116, 89, 41, 95, 18, 96, 48, 249, 49, 249, 50, 249, 89, 116, 51, 249, 52, 249, 53, 249, 54, 249, 55, 249, 56, 249, 209, 153, 57, 249, 58, 249, 59, 249, 60, 249, 61, 249, 62, 249, 63, 249, 64, 249, 65, 249, 66, 249, 67, 249, 195, 111, 68, 249, 69, 249, 191, 129, 178, 143, 241, 96, 70, 249, 71, 249, 102, 129, 72, 249, 73, 249, 63, 92, 74, 249, 75, 249, 76, 249, 77, 249, 78, 249, 79, 249, 80, 249, 81, 249, 233, 90, 37, 138, 123, 103, 16, 125, 82, 249, 83, 249, 84, 249, 85, 249, 86, 249, 87, 249, 253, 128, 88, 249, 89, 249, 60, 92, 229, 108, 63, 83, 186, 110, 26, 89, 54, 131, 57, 78, 182, 78, 70, 79, 174, 85, 24, 87, 199, 88, 86, 95, 183, 101, 230, 101, 128, 106, 181, 107, 77, 110, 237, 119, 239, 122, 30, 124, 222, 125, 203, 134, 146, 136, 50, 145, 91, 147, 187, 100, 190, 111, 122, 115, 184, 117, 84, 144, 86, 85, 77, 87, 186, 97, 212, 100, 199, 102, 225, 109, 91, 110, 109, 111, 185, 111, 240, 117, 67, 128, 189, 129, 65, 133, 131, 137, 199, 138, 90, 139, 31, 147, 147, 108, 83, 117, 84, 123, 15, 142, 93, 144, 16, 85, 2, 88, 88, 88, 98, 94, 7, 98, 158, 100, 224, 104, 118, 117, 214, 124, 179, 135, 232, 158, 227, 78, 136, 87, 110, 87, 39, 89, 13, 92, 177, 92, 54, 94, 133, 95, 52, 98, 225, 100, 179, 115, 250, 129, 139, 136, 184, 140, 138, 150, 219, 158, 133, 91, 183, 95, 179, 96, 18, 80, 0, 82, 48, 82, 22, 87, 53, 88, 87, 88, 14, 92, 96, 92, 246, 92, 139, 93, 166, 94, 146, 95, 188, 96, 17, 99, 137, 99, 23, 100, 67, 104, 249, 104, 194, 106, 216, 109, 33, 110, 212, 110, 228, 111, 254, 113, 220, 118, 121, 119, 177, 121, 59, 122, 4, 132, 169, 137, 237, 140, 243, 141, 72, 142, 3, 144, 20, 144, 83, 144, 253, 144, 77, 147, 118, 150, 220, 151, 210, 107, 6, 112, 88, 114, 162, 114, 104, 115, 99, 119, 191, 121, 228, 123, 155, 126, 128, 139, 169, 88, 199, 96, 102, 101, 253, 101, 190, 102, 140, 108, 30, 113, 201, 113, 90, 140, 19, 152, 109, 78, 129, 122, 221, 78, 172, 81, 205, 81, 213, 82, 12, 84, 167, 97, 113, 103, 80, 104, 223, 104, 30, 109, 124, 111, 188, 117, 179, 119, 229, 122, 244, 128, 99, 132, 133, 146, 92, 81, 151, 101, 92, 103, 147, 103, 216, 117, 199, 122, 115, 131, 90, 249, 70, 140, 23, 144, 45, 152, 111, 92, 192, 129, 154, 130, 65, 144, 111, 144, 13, 146, 151, 95, 157, 93, 89, 106, 200, 113, 123, 118, 73, 123, 228, 133, 4, 139, 39, 145, 48, 154, 135, 85, 246, 97, 91, 249, 105, 118, 133, 127, 63, 134, 186, 135, 248, 136, 143, 144, 92, 249, 27, 109, 217, 112, 222, 115, 97, 125, 61, 132, 93, 249, 106, 145, 241, 153, 94, 249, 130, 78, 117, 83, 4, 107, 18, 107, 62, 112, 27, 114, 45, 134, 30, 158, 76, 82, 163, 143, 80, 93, 229, 100, 44, 101, 22, 107, 235, 111, 67, 124, 156, 126, 205, 133, 100, 137, 189, 137, 201, 98, 216, 129, 31, 136, 202, 94, 23, 103, 106, 109, 252, 114, 5, 116, 111, 116, 130, 135, 222, 144, 134, 79, 13, 93, 160, 95, 10, 132, 183, 81, 160, 99, 101, 117, 174, 78, 6, 80, 105, 81, 201, 81, 129, 104, 17, 106, 174, 124, 177, 124, 231, 124, 111, 130, 210, 138, 27, 143, 207, 145, 182, 79, 55, 81, 245, 82, 66, 84, 236, 94, 110, 97, 62, 98, 197, 101, 218, 106, 254, 111, 42, 121, 220, 133, 35, 136, 173, 149, 98, 154, 106, 154, 151, 158, 206, 158, 155, 82, 198, 102, 119, 107, 29, 112, 43, 121, 98, 143, 66, 151, 144, 97, 0, 98, 35, 101, 35, 111, 73, 113, 137, 116, 244, 125, 111, 128, 238, 132, 38, 143, 35, 144, 74, 147, 189, 81, 23, 82, 163, 82, 12, 109, 200, 112, 194, 136, 201, 94, 130, 101, 174, 107, 194, 111, 62, 124, 117, 115, 228, 78, 54, 79, 249, 86, 95, 249, 186, 92, 186, 93, 28, 96, 178, 115, 45, 123, 154, 127, 206, 127, 70, 128, 30, 144, 52, 146, 246, 150, 72, 151, 24, 152, 97, 159, 139, 79, 167, 111, 174, 121, 180, 145, 183, 150, 222, 82, 96, 249, 136, 100, 196, 100, 211, 106, 94, 111, 24, 112, 16, 114, 231, 118, 1, 128, 6, 134, 92, 134, 239, 141, 5, 143, 50, 151, 111, 155, 250, 157, 117, 158, 140, 120, 127, 121, 160, 125, 201, 131, 4, 147, 127, 158, 147, 158, 214, 138, 223, 88, 4, 95, 39, 103, 39, 112, 207, 116, 96, 124, 126, 128, 33, 81, 40, 112, 98, 114, 202, 120, 194, 140, 218, 140, 244, 140, 247, 150, 134, 78, 218, 80, 238, 91, 214, 94, 153, 101, 206, 113, 66, 118, 173, 119, 74, 128, 252, 132, 124, 144, 39, 155, 141, 159, 216, 88, 65, 90, 98, 92, 19, 106, 218, 109, 15, 111, 59, 118, 47, 125, 55, 126, 30, 133, 56, 137, 228, 147, 75, 150, 137, 82, 210, 101, 243, 103, 180, 105, 65, 109, 156, 110, 15, 112, 9, 116, 96, 116, 89, 117, 36, 118, 107, 120, 44, 139, 94, 152, 109, 81, 46, 98, 120, 150, 150, 79, 43, 80, 25, 93, 234, 109, 184, 125, 42, 143, 139, 95, 68, 97, 23, 104, 97, 249, 134, 150, 210, 82, 139, 128, 220, 81, 204, 81, 94, 105, 28, 122, 190, 125, 241, 131, 117, 150, 218, 79, 41, 82, 152, 83, 15, 84, 14, 85, 101, 92, 167, 96, 78, 103, 168, 104, 108, 109, 129, 114, 248, 114, 6, 116, 131, 116, 98, 249, 226, 117, 108, 124, 121, 127, 184, 127, 137, 131, 207, 136, 225, 136, 204, 145, 208, 145, 226, 150, 201, 155, 29, 84, 126, 111, 208, 113, 152, 116, 250, 133, 170, 142, 163, 150, 87, 156, 159, 158, 151, 103, 203, 109, 51, 116, 232, 129, 22, 151, 44, 120, 203, 122, 32, 123, 146, 124, 105, 100, 106, 116, 242, 117, 188, 120, 232, 120, 172, 153, 84, 155, 187, 158, 222, 91, 85, 94, 32, 111, 156, 129, 171, 131, 136, 144, 7, 78, 77, 83, 41, 90, 210, 93, 78, 95, 98, 97, 61, 99, 105, 102, 252, 102, 255, 110, 43, 111, 99, 112, 158, 119, 44, 132, 19, 133, 59, 136, 19, 143, 69, 153, 59, 156, 28, 85, 185, 98, 43, 103, 171, 108, 9, 131, 106, 137, 122, 151, 161, 78, 132, 89, 216, 95, 217, 95, 27, 103, 178, 125, 84, 127, 146, 130, 43, 131, 189, 131, 30, 143, 153, 144, 203, 87, 185, 89, 146, 90, 208, 91, 39, 102, 154, 103, 133, 104, 207, 107, 100, 113, 117, 127, 183, 140, 227, 140, 129, 144, 69, 155, 8, 129, 138, 140, 76, 150, 64, 154, 165, 158, 95, 91, 19, 108, 27, 115, 242, 118, 223, 118, 12, 132, 170, 81, 147, 137, 77, 81, 149, 81, 201, 82, 201, 104, 148, 108, 4, 119, 32, 119, 191, 125, 236, 125, 98, 151, 181, 158, 197, 110, 17, 133, 165, 81, 13, 84, 125, 84, 14, 102, 157, 102, 39, 105, 159, 110, 191, 118, 145, 119, 23, 131, 194, 132, 159, 135, 105, 145, 152, 146, 244, 156, 130, 136, 174, 79, 146, 81, 223, 82, 198, 89, 61, 94, 85, 97, 120, 100, 121, 100, 174, 102, 208, 103, 33, 106, 205, 107, 219, 107, 95, 114, 97, 114, 65, 116, 56, 119, 219, 119, 23, 128, 188, 130, 5, 131, 0, 139, 40, 139, 140, 140, 40, 103, 144, 108, 103, 114, 238, 118, 102, 119, 70, 122, 169, 157, 127, 107, 146, 108, 34, 89, 38, 103, 153, 132, 111, 83, 147, 88, 153, 89, 223, 94, 207, 99, 52, 102, 115, 103, 58, 110, 43, 115, 215, 122, 215, 130, 40, 147, 217, 82, 235, 93, 174, 97, 203, 97, 10, 98, 199, 98, 171, 100, 224, 101, 89, 105, 102, 107, 203, 107, 33, 113, 247, 115, 93, 117, 70, 126, 30, 130, 2, 131, 106, 133, 163, 138, 191, 140, 39, 151, 97, 157, 168, 88, 216, 158, 17, 80, 14, 82, 59, 84, 79, 85, 135, 101, 118, 108, 10, 125, 11, 125, 94, 128, 138, 134, 128, 149, 239, 150, 255, 82, 149, 108, 105, 114, 115, 84, 154, 90, 62, 92, 75, 93, 76, 95, 174, 95, 42, 103, 182, 104, 99, 105, 60, 110, 68, 110, 9, 119, 115, 124, 142, 127, 135, 133, 14, 139, 247, 143, 97, 151, 244, 158, 183, 92, 182, 96, 13, 97, 171, 97, 79, 101, 251, 101, 252, 101, 17, 108, 239, 108, 159, 115, 201, 115, 225, 125, 148, 149, 198, 91, 28, 135, 16, 139, 93, 82, 90, 83, 205, 98, 15, 100, 178, 100, 52, 103, 56, 106, 202, 108, 192, 115, 158, 116, 148, 123, 149, 124, 27, 126, 138, 129, 54, 130, 132, 133, 235, 143, 249, 150, 193, 153, 52, 79, 74, 83, 205, 83, 219, 83, 204, 98, 44, 100, 0, 101, 145, 101, 195, 105, 238, 108, 88, 111, 237, 115, 84, 117, 34, 118, 228, 118, 252, 118, 208, 120, 251, 120, 44, 121, 70, 125, 44, 130, 224, 135, 212, 143, 18, 152, 239, 152, 195, 82, 212, 98, 165, 100, 36, 110, 81, 111, 124, 118, 203, 141, 177, 145, 98, 146, 238, 154, 67, 155, 35, 80, 141, 80, 74, 87, 168, 89, 40, 92, 71, 94, 119, 95, 63, 98, 62, 101, 185, 101, 193, 101, 9, 102, 139, 103, 156, 105, 194, 110, 197, 120, 33, 125, 170, 128, 128, 129, 43, 130, 179, 130, 161, 132, 140, 134, 42, 138, 23, 139, 166, 144, 50, 150, 144, 159, 13, 80, 243, 79, 99, 249, 249, 87, 152, 95, 220, 98, 146, 99, 111, 103, 67, 110, 25, 113, 195, 118, 204, 128, 218, 128, 244, 136, 245, 136, 25, 137, 224, 140, 41, 143, 77, 145, 106, 150, 47, 79, 112, 79, 27, 94, 207, 103, 34, 104, 125, 118, 126, 118, 68, 155, 97, 94, 10, 106, 105, 113, 212, 113, 106, 117, 100, 249, 65, 126, 67, 133, 233, 133, 220, 152, 16, 79, 79, 123, 112, 127, 165, 149, 225, 81, 6, 94, 181, 104, 62, 108, 78, 108, 219, 108, 175, 114, 196, 123, 3, 131, 213, 108, 58, 116, 251, 80, 136, 82, 193, 88, 216, 100, 151, 106, 167, 116, 86, 118, 167, 120, 23, 134, 226, 149, 57, 151, 101, 249, 94, 83, 1, 95, 138, 139, 168, 143, 175, 143, 138, 144, 37, 82, 165, 119, 73, 156, 8, 159, 25, 78, 2, 80, 117, 81, 91, 92, 119, 94, 30, 102, 58, 102, 196, 103, 197, 104, 179, 112, 1, 117, 197, 117, 201, 121, 221, 122, 39, 143, 32, 153, 8, 154, 221, 79, 33, 88, 49, 88, 246, 91, 110, 102, 101, 107, 17, 109, 122, 110, 125, 111, 228, 115, 43, 117, 233, 131, 220, 136, 19, 137, 92, 139, 20, 143, 15, 79, 213, 80, 16, 83, 92, 83, 147, 91, 169, 95, 13, 103, 143, 121, 121, 129, 47, 131, 20, 133, 7, 137, 134, 137, 57, 143, 59, 143, 165, 153, 18, 156, 44, 103, 118, 78, 248, 79, 73, 89, 1, 92, 239, 92, 240, 92, 103, 99, 210, 104, 253, 112, 162, 113, 43, 116, 43, 126, 236, 132, 2, 135, 34, 144, 210, 146, 243, 156, 13, 78, 216, 78, 239, 79, 133, 80, 86, 82, 111, 82, 38, 84, 144, 84, 224, 87, 43, 89, 102, 90, 90, 91, 117, 91, 204, 91, 156, 94, 102, 249, 118, 98, 119, 101, 167, 101, 110, 109, 165, 110, 54, 114, 38, 123, 63, 124, 54, 127, 80, 129, 81, 129, 154, 129, 64, 130, 153, 130, 169, 131, 3, 138, 160, 140, 230, 140, 251, 140, 116, 141, 186, 141, 232, 144, 220, 145, 28, 150, 68, 150, 217, 153, 231, 156, 23, 83, 6, 82, 41, 84, 116, 86, 179, 88, 84, 89, 110, 89, 255, 95, 164, 97, 110, 98, 16, 102, 126, 108, 26, 113, 198, 118, 137, 124, 222, 124, 27, 125, 172, 130, 193, 140, 240, 150, 103, 249, 91, 79, 23, 95, 127, 95, 194, 98, 41, 93, 11, 103, 218, 104, 124, 120, 67, 126, 108, 157, 21, 78, 153, 80, 21, 83, 42, 83, 81, 83, 131, 89, 98, 90, 135, 94, 178, 96, 138, 97, 73, 98, 121, 98, 144, 101, 135, 103, 167, 105, 212, 107, 214, 107, 215, 107, 216, 107, 184, 108, 104, 249, 53, 116, 250, 117, 18, 120, 145, 120, 213, 121, 216, 121, 131, 124, 203, 125, 225, 127, 165, 128, 62, 129, 194, 129, 242, 131, 26, 135, 232, 136, 185, 138, 108, 139, 187, 140, 25, 145, 94, 151, 219, 152, 59, 159, 172, 86, 42, 91, 108, 95, 140, 101, 179, 106, 175, 107, 92, 109, 241, 111, 21, 112, 93, 114, 173, 115, 167, 140, 211, 140, 59, 152, 145, 97, 55, 108, 88, 128, 1, 154, 77, 78, 139, 78, 155, 78, 213, 78, 58, 79, 60, 79, 127, 79, 223, 79, 255, 80, 242, 83, 248, 83, 6, 85, 227, 85, 219, 86, 235, 88, 98, 89, 17, 90, 235, 91, 250, 91, 4, 92, 243, 93, 43, 94, 153, 95, 29, 96, 104, 99, 156, 101, 175, 101, 246, 103, 251, 103, 173, 104, 123, 107, 153, 108, 215, 108, 35, 110, 9, 112, 69, 115, 2, 120, 62, 121, 64, 121, 96, 121, 193, 121, 233, 123, 23, 125, 114, 125, 134, 128, 13, 130, 142, 131, 209, 132, 199, 134, 223, 136, 80, 138, 94, 138, 29, 139, 220, 140, 102, 141, 173, 143, 170, 144, 252, 152, 223, 153, 157, 158, 74, 82, 105, 249, 20, 103, 106, 249, 152, 80, 42, 82, 113, 92, 99, 101, 85, 108, 202, 115, 35, 117, 157, 117, 151, 123, 156, 132, 120, 145, 48, 151, 119, 78, 146, 100, 186, 107, 94, 113, 169, 133, 9, 78, 107, 249, 73, 103, 238, 104, 23, 110, 159, 130, 24, 133, 107, 136, 247, 99, 129, 111, 18, 146, 175, 152, 10, 78, 183, 80, 207, 80, 31, 81, 70, 85, 170, 85, 23, 86, 64, 91, 25, 92, 224, 92, 56, 94, 138, 94, 160, 94, 194, 94, 243, 96, 81, 104, 97, 106, 88, 110, 61, 114, 64, 114, 192, 114, 248, 118, 101, 121, 177, 123, 212, 127, 243, 136, 244, 137, 115, 138, 97, 140, 222, 140, 28, 151, 94, 88, 189, 116, 253, 140, 199, 85, 108, 249, 97, 122, 34, 125, 114, 130, 114, 114, 31, 117, 37, 117, 109, 249, 25, 123, 133, 88, 251, 88, 188, 93, 143, 94, 182, 94, 144, 95, 85, 96, 146, 98, 127, 99, 77, 101, 145, 102, 217, 102, 248, 102, 22, 104, 242, 104, 128, 114, 94, 116, 110, 123, 110, 125, 214, 125, 114, 127, 229, 128, 18, 130, 175, 133, 127, 137, 147, 138, 29, 144, 228, 146, 205, 158, 32, 159, 21, 89, 109, 89, 45, 94, 220, 96, 20, 102, 115, 102, 144, 103, 80, 108, 197, 109, 95, 111, 243, 119, 169, 120, 198, 132, 203, 145, 43, 147, 217, 78, 202, 80, 72, 81, 132, 85, 11, 91, 163, 91, 71, 98, 126, 101, 203, 101, 50, 110, 125, 113, 1, 116, 68, 116, 135, 116, 191, 116, 108, 118, 170, 121, 218, 125, 85, 126, 168, 127, 122, 129, 179, 129, 57, 130, 26, 134, 236, 135, 117, 138, 227, 141, 120, 144, 145, 146, 37, 148, 77, 153, 174, 155, 104, 83, 81, 92, 84, 105, 196, 108, 41, 109, 43, 110, 12, 130, 155, 133, 59, 137, 45, 138, 170, 138, 234, 150, 103, 159, 97, 82, 185, 102, 178, 107, 150, 126, 254, 135, 13, 141, 131, 149, 93, 150, 29, 101, 137, 109, 238, 113, 110, 249, 206, 87, 211, 89, 172, 91, 39, 96, 250, 96, 16, 98, 31, 102, 95, 102, 41, 115, 249, 115, 219, 118, 1, 119, 108, 123, 86, 128, 114, 128, 101, 129, 160, 138, 146, 145, 22, 78, 226, 82, 114, 107, 23, 109, 5, 122, 57, 123, 48, 125, 111, 249, 176, 140, 236, 83, 47, 86, 81, 88, 181, 91, 15, 92, 17, 92, 226, 93, 64, 98, 131, 99, 20, 100, 45, 102, 179, 104, 188, 108, 136, 109, 175, 110, 31, 112, 164, 112, 210, 113, 38, 117, 143, 117, 142, 117, 25, 118, 17, 123, 224, 123, 43, 124, 32, 125, 57, 125, 44, 133, 109, 133, 7, 134, 52, 138, 13, 144, 97, 144, 181, 144, 183, 146, 246, 151, 55, 154, 215, 79, 108, 92, 95, 103, 145, 109, 159, 124, 140, 126, 22, 139, 22, 141, 31, 144, 107, 91, 253, 93, 13, 100, 192, 132, 92, 144, 225, 152, 135, 115, 139, 91, 154, 96, 126, 103, 222, 109, 31, 138, 166, 138, 1, 144, 12, 152, 55, 82, 112, 249, 81, 112, 142, 120, 150, 147, 112, 136, 215, 145, 238, 79, 215, 83, 253, 85, 218, 86, 130, 87, 253, 88, 194, 90, 136, 91, 171, 92, 192, 92, 37, 94, 1, 97, 13, 98, 75, 98, 136, 99, 28, 100, 54, 101, 120, 101, 57, 106, 138, 107, 52, 108, 25, 109, 49, 111, 231, 113, 233, 114, 120, 115, 7, 116, 178, 116, 38, 118, 97, 119, 192, 121, 87, 122, 234, 122, 185, 124, 143, 125, 172, 125, 97, 126, 158, 127, 41, 129, 49, 131, 144, 132, 218, 132, 234, 133, 150, 136, 176, 138, 144, 139, 56, 143, 66, 144, 131, 144, 108, 145, 150, 146, 185, 146, 139, 150, 167, 150, 168, 150, 214, 150, 0, 151, 8, 152, 150, 153, 211, 154, 26, 155, 212, 83, 126, 88, 25, 89, 112, 91, 191, 91, 209, 109, 90, 111, 159, 113, 33, 116, 185, 116, 133, 128, 253, 131, 225, 93, 135, 95, 170, 95, 66, 96, 236, 101, 18, 104, 111, 105, 83, 106, 137, 107, 53, 109, 243, 109, 227, 115, 254, 118, 172, 119, 77, 123, 20, 125, 35, 129, 28, 130, 64, 131, 244, 132, 99, 133, 98, 138, 196, 138, 135, 145, 30, 147, 6, 152, 180, 153, 12, 98, 83, 136, 240, 143, 101, 146, 7, 93, 39, 93, 105, 93, 95, 116, 157, 129, 104, 135, 213, 111, 254, 98, 210, 127, 54, 137, 114, 137, 30, 78, 88, 78, 231, 80, 221, 82, 71, 83, 127, 98, 7, 102, 105, 126, 5, 136, 94, 150, 141, 79, 25, 83, 54, 86, 203, 89, 164, 90, 56, 92, 78, 92, 77, 92, 2, 94, 17, 95, 67, 96, 189, 101, 47, 102, 66, 102, 190, 103, 244, 103, 28, 115, 226, 119, 58, 121, 197, 127, 148, 132, 205, 132, 150, 137, 102, 138, 105, 138, 225, 138, 85, 140, 122, 140, 244, 87, 212, 91, 15, 95, 111, 96, 237, 98, 13, 105, 150, 107, 92, 110, 132, 113, 210, 123, 85, 135, 88, 139, 254, 142, 223, 152, 254, 152, 56, 79, 129, 79, 225, 79, 123, 84, 32, 90, 184, 91, 60, 97, 176, 101, 104, 102, 252, 113, 51, 117, 94, 121, 51, 125, 78, 129, 227, 129, 152, 131, 170, 133, 206, 133, 3, 135, 10, 138, 171, 142, 155, 143, 113, 249, 197, 143, 49, 89, 164, 91, 230, 91, 137, 96, 233, 91, 11, 92, 195, 95, 129, 108, 114, 249, 241, 109, 11, 112, 26, 117, 175, 130, 246, 138, 192, 78, 65, 83, 115, 249, 217, 150, 15, 108, 158, 78, 196, 79, 82, 81, 94, 85, 37, 90, 232, 92, 17, 98, 89, 114, 189, 130, 170, 131, 254, 134, 89, 136, 29, 138, 63, 150, 197, 150, 19, 153, 9, 157, 93, 157, 10, 88, 179, 92, 189, 93, 68, 94, 225, 96, 21, 97, 225, 99, 2, 106, 37, 110, 2, 145, 84, 147, 78, 152, 16, 156, 119, 159, 137, 91, 184, 92, 9, 99, 79, 102, 72, 104, 60, 119, 193, 150, 141, 151, 84, 152, 159, 155, 161, 101, 1, 139, 203, 142, 188, 149, 53, 85, 169, 92, 214, 93, 181, 94, 151, 102, 76, 118, 244, 131, 199, 149, 211, 88, 188, 98, 206, 114, 40, 157, 240, 78, 46, 89, 15, 96, 59, 102, 131, 107, 231, 121, 38, 157, 147, 83, 192, 84, 195, 87, 22, 93, 27, 97, 214, 102, 175, 109, 141, 120, 126, 130, 152, 150, 68, 151, 132, 83, 124, 98, 150, 99, 178, 109, 10, 126, 75, 129, 77, 152, 251, 106, 76, 127, 175, 157, 26, 158, 95, 78, 59, 80, 182, 81, 28, 89, 249, 96, 246, 99, 48, 105, 58, 114, 54, 128, 116, 249, 206, 145, 49, 95, 117, 249, 118, 249, 4, 125, 229, 130, 111, 132, 187, 132, 229, 133, 141, 142, 119, 249, 111, 79, 120, 249, 121, 249, 228, 88, 67, 91, 89, 96, 218, 99, 24, 101, 109, 101, 152, 102, 122, 249, 74, 105, 35, 106, 11, 109, 1, 112, 108, 113, 210, 117, 13, 118, 179, 121, 112, 122, 123, 249, 138, 127, 124, 249, 68, 137, 125, 249, 147, 139, 192, 145, 125, 150, 126, 249, 10, 153, 4, 87, 161, 95, 188, 101, 1, 111, 0, 118, 166, 121, 158, 138, 173, 153, 90, 155, 108, 159, 4, 81, 182, 97, 145, 98, 141, 106, 198, 129, 67, 80, 48, 88, 102, 95, 9, 113, 0, 138, 250, 138, 124, 91, 22, 134, 250, 79, 60, 81, 180, 86, 68, 89, 169, 99, 249, 109, 170, 93, 109, 105, 134, 81, 136, 78, 89, 79, 127, 249, 128, 249, 129, 249, 130, 89, 130, 249, 131, 249, 95, 107, 93, 108, 132, 249, 181, 116, 22, 121, 133, 249, 7, 130, 69, 130, 57, 131, 63, 143, 93, 143, 134, 249, 24, 153, 135, 249, 136, 249, 137, 249, 166, 78, 138, 249, 223, 87, 121, 95, 19, 102, 139, 249, 140, 249, 171, 117, 121, 126, 111, 139, 141, 249, 6, 144, 91, 154, 165, 86, 39, 88, 248, 89, 31, 90, 180, 91, 142, 249, 246, 94, 143, 249, 144, 249, 80, 99, 59, 99, 145, 249, 61, 105, 135, 108, 191, 108, 142, 109, 147, 109, 245, 109, 20, 111, 146, 249, 223, 112, 54, 113, 89, 113, 147, 249, 195, 113, 213, 113, 148, 249, 79, 120, 111, 120, 149, 249, 117, 123, 227, 125, 150, 249, 47, 126, 151, 249, 77, 136, 223, 142, 152, 249, 153, 249, 154, 249, 91, 146, 155, 249, 246, 156, 156, 249, 157, 249, 158, 249, 133, 96, 133, 109, 159, 249, 177, 113, 160, 249, 161, 249, 177, 149, 173, 83, 162, 249, 163, 249, 164, 249, 211, 103, 165, 249, 142, 112, 48, 113, 48, 116, 118, 130, 210, 130, 166, 249, 187, 149, 229, 154, 125, 158, 196, 102, 167, 249, 193, 113, 73, 132, 168, 249, 169, 249, 75, 88, 170, 249, 171, 249, 184, 93, 113, 95, 172, 249, 32, 102, 142, 102, 121, 105, 174, 105, 56, 108, 243, 108, 54, 110, 65, 111, 218, 111, 27, 112, 47, 112, 80, 113, 223, 113, 112, 115, 173, 249, 91, 116, 174, 249, 212, 116, 200, 118, 78, 122, 147, 126, 175, 249, 176, 249, 241, 130, 96, 138, 206, 143, 177, 249, 72, 147, 178, 249, 25, 151, 179, 249, 180, 249, 66, 78, 42, 80, 181, 249, 8, 82, 225, 83, 243, 102, 109, 108, 202, 111, 10, 115, 127, 119, 98, 122, 174, 130, 221, 133, 2, 134, 182, 249, 212, 136, 99, 138, 125, 139, 107, 140, 183, 249, 179, 146, 184, 249, 19, 151, 16, 152, 148, 78, 13, 79, 201, 79, 178, 80, 72, 83, 62, 84, 51, 84, 218, 85, 98, 88, 186, 88, 103, 89, 27, 90, 228, 91, 159, 96, 185, 249, 202, 97, 86, 101, 255, 101, 100, 102, 167, 104, 90, 108, 179, 111, 207, 112, 172, 113, 82, 115, 125, 123, 8, 135, 164, 138, 50, 156, 7, 159, 75, 92, 131, 108, 68, 115, 137, 115, 58, 146, 171, 110, 101, 116, 31, 118, 105, 122, 21, 126, 10, 134, 64, 81, 197, 88, 193, 100, 238, 116, 21, 117, 112, 118, 193, 127, 149, 144, 205, 150, 84, 153, 38, 110, 230, 116, 169, 122, 170, 122, 229, 129, 217, 134, 120, 135, 27, 138, 73, 90, 140, 91, 155, 91, 161, 104, 0, 105, 99, 109, 169, 115, 19, 116, 44, 116, 151, 120, 233, 125, 235, 127, 24, 129, 85, 129, 158, 131, 76, 140, 46, 150, 17, 152, 240, 102, 128, 95, 250, 101, 137, 103, 106, 108, 139, 115, 45, 80, 3, 90, 106, 107, 238, 119, 22, 89, 108, 93, 205, 93, 37, 115, 79, 117, 186, 249, 187, 249], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 312548);
	        allocate([229, 80, 249, 81, 47, 88, 45, 89, 150, 89, 218, 89, 229, 91, 188, 249, 189, 249, 162, 93, 215, 98, 22, 100, 147, 100, 254, 100, 190, 249, 220, 102, 191, 249, 72, 106, 192, 249, 255, 113, 100, 116, 193, 249, 136, 122, 175, 122, 71, 126, 94, 126, 0, 128, 112, 129, 194, 249, 239, 135, 129, 137, 32, 139, 89, 144, 195, 249, 128, 144, 82, 153, 126, 97, 50, 107, 116, 109, 31, 126, 37, 137, 177, 143, 209, 79, 173, 80, 151, 81, 199, 82, 199, 87, 137, 88, 185, 91, 184, 94, 66, 97, 149, 105, 140, 109, 103, 110, 182, 110, 148, 113, 98, 116, 40, 117, 44, 117, 115, 128, 56, 131, 201, 132, 10, 142, 148, 147, 222, 147, 196, 249, 142, 78, 81, 79, 118, 80, 42, 81, 200, 83, 203, 83, 243, 83, 135, 91, 211, 91, 36, 92, 26, 97, 130, 97, 244, 101, 91, 114, 151, 115, 64, 116, 194, 118, 80, 121, 145, 121, 185, 121, 6, 125, 189, 127, 139, 130, 213, 133, 94, 134, 194, 143, 71, 144, 245, 144, 234, 145, 133, 150, 232, 150, 233, 150, 214, 82, 103, 95, 237, 101, 49, 102, 47, 104, 92, 113, 54, 122, 193, 144, 10, 152, 145, 78, 197, 249, 82, 106, 158, 107, 144, 111, 137, 113, 24, 128, 184, 130, 83, 133, 75, 144, 149, 150, 242, 150, 251, 151, 26, 133, 49, 155, 144, 78, 138, 113, 196, 150, 67, 81, 159, 83, 225, 84, 19, 87, 18, 87, 163, 87, 155, 90, 196, 90, 195, 91, 40, 96, 63, 97, 244, 99, 133, 108, 57, 109, 114, 110, 144, 110, 48, 114, 63, 115, 87, 116, 209, 130, 129, 136, 69, 143, 96, 144, 198, 249, 98, 150, 88, 152, 27, 157, 8, 103, 138, 141, 94, 146, 77, 79, 73, 80, 222, 80, 113, 83, 13, 87, 212, 89, 1, 90, 9, 92, 112, 97, 144, 102, 45, 110, 50, 114, 75, 116, 239, 125, 195, 128, 14, 132, 102, 132, 63, 133, 95, 135, 91, 136, 24, 137, 2, 139, 85, 144, 203, 151, 79, 155, 115, 78, 145, 79, 18, 81, 106, 81, 199, 249, 47, 85, 169, 85, 122, 91, 165, 91, 124, 94, 125, 94, 190, 94, 160, 96, 223, 96, 8, 97, 9, 97, 196, 99, 56, 101, 9, 103, 200, 249, 212, 103, 218, 103, 201, 249, 97, 105, 98, 105, 185, 108, 39, 109, 202, 249, 56, 110, 203, 249, 225, 111, 54, 115, 55, 115, 204, 249, 92, 116, 49, 117, 205, 249, 82, 118, 206, 249, 207, 249, 173, 125, 254, 129, 56, 132, 213, 136, 152, 138, 219, 138, 237, 138, 48, 142, 66, 142, 74, 144, 62, 144, 122, 144, 73, 145, 201, 145, 110, 147, 208, 249, 209, 249, 9, 88, 210, 249, 211, 107, 137, 128, 178, 128, 211, 249, 212, 249, 65, 81, 107, 89, 57, 92, 213, 249, 214, 249, 100, 111, 167, 115, 228, 128, 7, 141, 215, 249, 23, 146, 143, 149, 216, 249, 217, 249, 218, 249, 219, 249, 127, 128, 14, 98, 28, 112, 104, 125, 141, 135, 220, 249, 160, 87, 105, 96, 71, 97, 183, 107, 190, 138, 128, 146, 177, 150, 89, 78, 31, 84, 235, 109, 45, 133, 112, 150, 243, 151, 238, 152, 214, 99, 227, 108, 145, 144, 221, 81, 201, 97, 186, 129, 249, 157, 157, 79, 26, 80, 0, 81, 156, 91, 15, 97, 255, 97, 236, 100, 5, 105, 197, 107, 145, 117, 227, 119, 169, 127, 100, 130, 143, 133, 251, 135, 99, 136, 188, 138, 112, 139, 171, 145, 140, 78, 229, 78, 10, 79, 221, 249, 222, 249, 55, 89, 232, 89, 223, 249, 242, 93, 27, 95, 91, 95, 33, 96, 224, 249, 225, 249, 226, 249, 227, 249, 62, 114, 229, 115, 228, 249, 112, 117, 205, 117, 229, 249, 251, 121, 230, 249, 12, 128, 51, 128, 132, 128, 225, 130, 81, 131, 231, 249, 232, 249, 189, 140, 179, 140, 135, 144, 233, 249, 234, 249, 244, 152, 12, 153, 235, 249, 236, 249, 55, 112, 202, 118, 202, 127, 204, 127, 252, 127, 26, 139, 186, 78, 193, 78, 3, 82, 112, 83, 237, 249, 189, 84, 224, 86, 251, 89, 197, 91, 21, 95, 205, 95, 110, 110, 238, 249, 239, 249, 106, 125, 53, 131, 240, 249, 147, 134, 141, 138, 241, 249, 109, 151, 119, 151, 242, 249, 243, 249, 0, 78, 90, 79, 126, 79, 249, 88, 229, 101, 162, 110, 56, 144, 176, 147, 185, 153, 251, 78, 236, 88, 138, 89, 217, 89, 65, 96, 244, 249, 245, 249, 20, 122, 246, 249, 79, 131, 195, 140, 101, 81, 68, 83, 247, 249, 248, 249, 249, 249, 205, 78, 105, 82, 85, 91, 191, 130, 212, 78, 58, 82, 168, 84, 201, 89, 255, 89, 80, 91, 87, 91, 92, 91, 99, 96, 72, 97, 203, 110, 153, 112, 110, 113, 134, 115, 247, 116, 181, 117, 193, 120, 43, 125, 5, 128, 234, 129, 40, 131, 23, 133, 201, 133, 238, 138, 199, 140, 204, 150, 92, 79, 250, 82, 188, 86, 171, 101, 40, 102, 124, 112, 184, 112, 53, 114, 189, 125, 141, 130, 76, 145, 192, 150, 114, 157, 113, 91, 231, 104, 152, 107, 122, 111, 222, 118, 145, 92, 171, 102, 91, 111, 180, 123, 42, 124, 54, 136, 220, 150, 8, 78, 215, 78, 32, 83, 52, 88, 187, 88, 239, 88, 108, 89, 7, 92, 51, 94, 132, 94, 53, 95, 140, 99, 178, 102, 86, 103, 31, 106, 163, 106, 12, 107, 63, 111, 70, 114, 250, 249, 80, 115, 139, 116, 224, 122, 167, 124, 120, 129, 223, 129, 231, 129, 138, 131, 108, 132, 35, 133, 148, 133, 207, 133, 221, 136, 19, 141, 172, 145, 119, 149, 156, 150, 141, 81, 201, 84, 40, 87, 176, 91, 77, 98, 80, 103, 61, 104, 147, 104, 61, 110, 211, 110, 125, 112, 33, 126, 193, 136, 161, 140, 9, 143, 75, 159, 78, 159, 45, 114, 143, 123, 205, 138, 26, 147, 71, 79, 78, 79, 50, 81, 128, 84, 208, 89, 149, 94, 181, 98, 117, 103, 110, 105, 23, 106, 174, 108, 26, 110, 217, 114, 42, 115, 189, 117, 184, 123, 53, 125, 231, 130, 249, 131, 87, 132, 247, 133, 91, 138, 175, 140, 135, 142, 25, 144, 184, 144, 206, 150, 95, 159, 227, 82, 10, 84, 225, 90, 194, 91, 88, 100, 117, 101, 244, 110, 196, 114, 251, 249, 132, 118, 77, 122, 27, 123, 77, 124, 62, 126, 223, 127, 123, 131, 43, 139, 202, 140, 100, 141, 225, 141, 95, 142, 234, 143, 249, 143, 105, 144, 209, 147, 67, 79, 122, 79, 179, 80, 104, 81, 120, 81, 77, 82, 106, 82, 97, 88, 124, 88, 96, 89, 8, 92, 85, 92, 219, 94, 155, 96, 48, 98, 19, 104, 191, 107, 8, 108, 177, 111, 78, 113, 32, 116, 48, 117, 56, 117, 81, 117, 114, 118, 76, 123, 139, 123, 173, 123, 198, 123, 143, 126, 110, 138, 62, 143, 73, 143, 63, 146, 147, 146, 34, 147, 43, 148, 251, 150, 90, 152, 107, 152, 30, 153, 7, 82, 42, 98, 152, 98, 89, 109, 100, 118, 202, 122, 192, 123, 118, 125, 96, 83, 190, 92, 151, 94, 56, 111, 185, 112, 152, 124, 17, 151, 142, 155, 222, 158, 165, 99, 122, 100, 118, 135, 1, 78, 149, 78, 173, 78, 92, 80, 117, 80, 72, 84, 195, 89, 154, 91, 64, 94, 173, 94, 247, 94, 129, 95, 197, 96, 58, 99, 63, 101, 116, 101, 204, 101, 118, 102, 120, 102, 254, 103, 104, 105, 137, 106, 99, 107, 64, 108, 192, 109, 232, 109, 31, 110, 94, 110, 30, 112, 161, 112, 142, 115, 253, 115, 58, 117, 91, 119, 135, 120, 142, 121, 11, 122, 125, 122, 190, 124, 142, 125, 71, 130, 2, 138, 234, 138, 158, 140, 45, 145, 74, 145, 216, 145, 102, 146, 204, 146, 32, 147, 6, 151, 86, 151, 92, 151, 2, 152, 14, 159, 54, 82, 145, 82, 124, 85, 36, 88, 29, 94, 31, 95, 140, 96, 208, 99, 175, 104, 223, 111, 109, 121, 44, 123, 205, 129, 186, 133, 253, 136, 248, 138, 68, 142, 141, 145, 100, 150, 155, 150, 61, 151, 76, 152, 74, 159, 206, 79, 70, 81, 203, 81, 169, 82, 50, 86, 20, 95, 107, 95, 170, 99, 205, 100, 233, 101, 65, 102, 250, 102, 249, 102, 29, 103, 157, 104, 215, 104, 253, 105, 21, 111, 110, 111, 103, 113, 229, 113, 42, 114, 170, 116, 58, 119, 86, 121, 90, 121, 223, 121, 32, 122, 149, 122, 151, 124, 223, 124, 68, 125, 112, 126, 135, 128, 251, 133, 164, 134, 84, 138, 191, 138, 153, 141, 129, 142, 32, 144, 109, 144, 227, 145, 59, 150, 213, 150, 229, 156, 207, 101, 7, 124, 179, 141, 195, 147, 88, 91, 10, 92, 82, 83, 217, 98, 29, 115, 39, 80, 151, 91, 158, 95, 176, 96, 107, 97, 213, 104, 217, 109, 46, 116, 46, 122, 66, 125, 156, 125, 49, 126, 107, 129, 42, 142, 53, 142, 126, 147, 24, 148, 80, 79, 80, 87, 230, 93, 167, 94, 43, 99, 106, 127, 59, 78, 79, 79, 143, 79, 90, 80, 221, 89, 196, 128, 106, 84, 104, 84, 254, 85, 79, 89, 153, 91, 222, 93, 218, 94, 93, 102, 49, 103, 241, 103, 42, 104, 232, 108, 50, 109, 74, 110, 141, 111, 183, 112, 224, 115, 135, 117, 76, 124, 2, 125, 44, 125, 162, 125, 31, 130, 219, 134, 59, 138, 133, 138, 112, 141, 138, 142, 51, 143, 49, 144, 78, 145, 82, 145, 68, 148, 208, 153, 249, 122, 165, 124, 202, 79, 1, 81, 198, 81, 200, 87, 239, 91, 251, 92, 89, 102, 61, 106, 90, 109, 150, 110, 236, 111, 12, 113, 111, 117, 227, 122, 34, 136, 33, 144, 117, 144, 203, 150, 255, 153, 1, 131, 45, 78, 242, 78, 70, 136, 205, 145, 125, 83, 219, 106, 107, 105, 65, 108, 122, 132, 158, 88, 142, 97, 254, 102, 239, 98, 221, 112, 17, 117, 199, 117, 82, 126, 184, 132, 73, 139, 8, 141, 75, 78, 234, 83, 171, 84, 48, 87, 64, 87, 215, 95, 1, 99, 7, 99, 111, 100, 47, 101, 232, 101, 122, 102, 157, 103, 179, 103, 98, 107, 96, 108, 154, 108, 44, 111, 229, 119, 37, 120, 73, 121, 87, 121, 25, 125, 162, 128, 2, 129, 243, 129, 157, 130, 183, 130, 24, 135, 140, 138, 252, 249, 4, 141, 190, 141, 114, 144, 244, 118, 25, 122, 55, 122, 84, 126, 119, 128, 7, 85, 212, 85, 117, 88, 47, 99, 34, 100, 73, 102, 75, 102, 109, 104, 155, 105, 132, 107, 37, 109, 177, 110, 205, 115, 104, 116, 161, 116, 91, 117, 185, 117, 225, 118, 30, 119, 139, 119, 230, 121, 9, 126, 29, 126, 251, 129, 47, 133, 151, 136, 58, 138, 209, 140, 235, 142, 176, 143, 50, 144, 173, 147, 99, 150, 115, 150, 7, 151, 132, 79, 241, 83, 234, 89, 201, 90, 25, 94, 78, 104, 198, 116, 190, 117, 233, 121, 146, 122, 163, 129, 237, 134, 234, 140, 204, 141, 237, 143, 159, 101, 21, 103, 253, 249, 247, 87, 87, 111, 221, 125, 47, 143, 246, 147, 198, 150, 181, 95, 242, 97, 132, 111, 20, 78, 152, 79, 31, 80, 201, 83, 223, 85, 111, 93, 238, 93, 33, 107, 100, 107, 203, 120, 154, 123, 254, 249, 73, 142, 202, 142, 110, 144, 73, 99, 62, 100, 64, 119, 132, 122, 47, 147, 127, 148, 106, 159, 176, 100, 175, 111, 230, 113, 168, 116, 218, 116, 196, 122, 18, 124, 130, 126, 178, 124, 152, 126, 154, 139, 10, 141, 125, 148, 16, 153, 76, 153, 57, 82, 223, 91, 230, 100, 45, 103, 46, 125, 237, 80, 195, 83, 121, 88, 88, 97, 89, 97, 250, 97, 172, 101, 217, 122, 146, 139, 150, 139, 9, 80, 33, 80, 117, 82, 49, 85, 60, 90, 224, 94, 112, 95, 52, 97, 94, 101, 12, 102, 54, 102, 162, 102, 205, 105, 196, 110, 50, 111, 22, 115, 33, 118, 147, 122, 57, 129, 89, 130, 214, 131, 188, 132, 181, 80, 240, 87, 192, 91, 232, 91, 105, 95, 161, 99, 38, 120, 181, 125, 220, 131, 33, 133, 199, 145, 245, 145, 138, 81, 245, 103, 86, 123, 172, 140, 196, 81, 187, 89, 189, 96, 85, 134, 28, 80, 255, 249, 84, 82, 58, 92, 125, 97, 26, 98, 211, 98, 242, 100, 165, 101, 204, 110, 32, 118, 10, 129, 96, 142, 95, 150, 187, 150, 223, 78, 67, 83, 152, 85, 41, 89, 221, 93, 197, 100, 201, 108, 250, 109, 148, 115, 127, 122, 27, 130, 166, 133, 228, 140, 16, 142, 119, 144, 231, 145, 225, 149, 33, 150, 198, 151, 248, 81, 242, 84, 134, 85, 185, 95, 164, 100, 136, 111, 180, 125, 31, 143, 77, 143, 53, 148, 201, 80, 22, 92, 190, 108, 251, 109, 27, 117, 187, 119, 61, 124, 100, 124, 121, 138, 194, 138, 30, 88, 190, 89, 22, 94, 119, 99, 82, 114, 138, 117, 107, 119, 220, 138, 188, 140, 18, 143, 243, 94, 116, 102, 248, 109, 125, 128, 193, 131, 203, 138, 81, 151, 214, 155, 0, 250, 67, 82, 255, 102, 149, 109, 239, 110, 224, 125, 230, 138, 46, 144, 94, 144, 212, 154, 29, 82, 127, 82, 232, 84, 148, 97, 132, 98, 219, 98, 162, 104, 18, 105, 90, 105, 53, 106, 146, 112, 38, 113, 93, 120, 1, 121, 14, 121, 210, 121, 13, 122, 150, 128, 120, 130, 213, 130, 73, 131, 73, 133, 130, 140, 133, 141, 98, 145, 139, 145, 174, 145, 195, 79, 209, 86, 237, 113, 215, 119, 0, 135, 248, 137, 248, 91, 214, 95, 81, 103, 168, 144, 226, 83, 90, 88, 245, 91, 164, 96, 129, 97, 96, 100, 61, 126, 112, 128, 37, 133, 131, 146, 174, 100, 172, 80, 20, 93, 0, 103, 156, 88, 189, 98, 168, 99, 14, 105, 120, 105, 30, 106, 107, 110, 186, 118, 203, 121, 187, 130, 41, 132, 207, 138, 168, 141, 253, 143, 18, 145, 75, 145, 156, 145, 16, 147, 24, 147, 154, 147, 219, 150, 54, 154, 13, 156, 17, 78, 92, 117, 93, 121, 250, 122, 81, 123, 201, 123, 46, 126, 196, 132, 89, 142, 116, 142, 248, 142, 16, 144, 37, 102, 63, 105, 67, 116, 250, 81, 46, 103, 220, 158, 69, 81, 224, 95, 150, 108, 242, 135, 93, 136, 119, 136, 180, 96, 181, 129, 3, 132, 5, 141, 214, 83, 57, 84, 52, 86, 54, 90, 49, 92, 138, 112, 224, 127, 90, 128, 6, 129, 237, 129, 163, 141, 137, 145, 95, 154, 242, 157, 116, 80, 196, 78, 160, 83, 251, 96, 44, 110, 100, 92, 136, 79, 36, 80, 228, 85, 217, 92, 95, 94, 101, 96, 148, 104, 187, 108, 196, 109, 190, 113, 212, 117, 244, 117, 97, 118, 26, 122, 73, 122, 199, 125, 251, 125, 110, 127, 244, 129, 169, 134, 28, 143, 201, 150, 179, 153, 82, 159, 71, 82, 197, 82, 237, 152, 170, 137, 3, 78, 210, 103, 6, 111, 181, 79, 226, 91, 149, 103, 136, 108, 120, 109, 27, 116, 39, 120, 221, 145, 124, 147, 196, 135, 228, 121, 49, 122, 235, 95, 214, 78, 164, 84, 62, 85, 174, 88, 165, 89, 240, 96, 83, 98, 214, 98, 54, 103, 85, 105, 53, 130, 64, 150, 177, 153, 221, 153, 44, 80, 83, 83, 68, 85, 124, 87, 1, 250, 88, 98, 2, 250, 226, 100, 107, 102, 221, 103, 193, 111, 239, 111, 34, 116, 56, 116, 23, 138, 56, 148, 81, 84, 6, 86, 102, 87, 72, 95, 154, 97, 78, 107, 88, 112, 173, 112, 187, 125, 149, 138, 106, 89, 43, 129, 162, 99, 8, 119, 61, 128, 170, 140, 84, 88, 45, 100, 187, 105, 149, 91, 17, 94, 111, 110, 3, 250, 105, 133, 76, 81, 240, 83, 42, 89, 32, 96, 75, 97, 134, 107, 112, 108, 240, 108, 30, 123, 206, 128, 212, 130, 198, 141, 176, 144, 177, 152, 4, 250, 199, 100, 164, 111, 145, 100, 4, 101, 78, 81, 16, 84, 31, 87, 14, 138, 95, 97, 118, 104, 5, 250, 219, 117, 82, 123, 113, 125, 26, 144, 6, 88, 204, 105, 127, 129, 42, 137, 0, 144, 57, 152, 120, 80, 87, 89, 172, 89, 149, 98, 15, 144, 42, 155, 93, 97, 121, 114, 214, 149, 97, 87, 70, 90, 244, 93, 138, 98, 173, 100, 250, 100, 119, 103, 226, 108, 62, 109, 44, 114, 54, 116, 52, 120, 119, 127, 173, 130, 219, 141, 23, 152, 36, 82, 66, 87, 127, 103, 72, 114, 227, 116, 169, 140, 166, 143, 17, 146, 42, 150, 107, 81, 237, 83, 76, 99, 105, 79, 4, 85, 150, 96, 87, 101, 155, 108, 127, 109, 76, 114, 253, 114, 23, 122, 135, 137, 157, 140, 109, 95, 142, 111, 249, 112, 168, 129, 14, 97, 191, 79, 79, 80, 65, 98, 71, 114, 199, 123, 232, 125, 233, 127, 77, 144, 173, 151, 25, 154, 182, 140, 106, 87, 115, 94, 176, 103, 13, 132, 85, 138, 32, 84, 22, 91, 99, 94, 226, 94, 10, 95, 131, 101, 186, 128, 61, 133, 137, 149, 91, 150, 72, 79, 5, 83, 13, 83, 15, 83, 134, 84, 250, 84, 3, 87, 3, 94, 22, 96, 155, 98, 177, 98, 85, 99, 6, 250, 225, 108, 102, 109, 177, 117, 50, 120, 222, 128, 47, 129, 222, 130, 97, 132, 178, 132, 141, 136, 18, 137, 11, 144, 234, 146, 253, 152, 145, 155, 69, 94, 180, 102, 221, 102, 17, 112, 6, 114, 7, 250, 245, 79, 125, 82, 106, 95, 83, 97, 83, 103, 25, 106, 2, 111, 226, 116, 104, 121, 104, 136, 121, 140, 199, 152, 196, 152, 67, 154, 193, 84, 31, 122, 83, 105, 247, 138, 74, 140, 168, 152, 174, 153, 124, 95, 171, 98, 178, 117, 174, 118, 171, 136, 127, 144, 66, 150, 57, 83, 60, 95, 197, 95, 204, 108, 204, 115, 98, 117, 139, 117, 70, 123, 254, 130, 157, 153, 79, 78, 60, 144, 11, 78, 85, 79, 166, 83, 15, 89, 200, 94, 48, 102, 179, 108, 85, 116, 119, 131, 102, 135, 192, 140, 80, 144, 30, 151, 21, 156, 209, 88, 120, 91, 80, 134, 20, 139, 180, 157, 210, 91, 104, 96, 141, 96, 241, 101, 87, 108, 34, 111, 163, 111, 26, 112, 85, 127, 240, 127, 145, 149, 146, 149, 80, 150, 211, 151, 114, 82, 68, 143, 253, 81, 43, 84, 184, 84, 99, 85, 138, 85, 187, 106, 181, 109, 216, 125, 102, 130, 156, 146, 119, 150, 121, 158, 8, 84, 200, 84, 210, 118, 228, 134, 164, 149, 212, 149, 92, 150, 162, 78, 9, 79, 238, 89, 230, 90, 247, 93, 82, 96, 151, 98, 109, 103, 65, 104, 134, 108, 47, 110, 56, 127, 155, 128, 42, 130, 8, 250, 9, 250, 5, 152, 165, 78, 85, 80, 179, 84, 147, 87, 90, 89, 105, 91, 179, 91, 200, 97, 119, 105, 119, 109, 35, 112, 249, 135, 227, 137, 114, 138, 231, 138, 130, 144, 237, 153, 184, 154, 190, 82, 56, 104, 22, 80, 120, 94, 79, 103, 71, 131, 76, 136, 171, 78, 17, 84, 174, 86, 230, 115, 21, 145, 255, 151, 9, 153, 87, 153, 153, 153, 83, 86, 159, 88, 91, 134, 49, 138, 178, 97, 246, 106, 123, 115, 210, 142, 71, 107, 170, 150, 87, 154, 85, 89, 0, 114, 107, 141, 105, 151, 212, 79, 244, 92, 38, 95, 248, 97, 91, 102, 235, 108, 171, 112, 132, 115, 185, 115, 254, 115, 41, 119, 77, 119, 67, 125, 98, 125, 35, 126, 55, 130, 82, 136, 10, 250, 226, 140, 73, 146, 111, 152, 81, 91, 116, 122, 64, 136, 1, 152, 204, 90, 224, 79, 84, 83, 62, 89, 253, 92, 62, 99, 121, 109, 249, 114, 5, 129, 7, 129, 162, 131, 207, 146, 48, 152, 168, 78, 68, 81, 17, 82, 139, 87, 98, 95, 194, 108, 206, 110, 5, 112, 80, 112, 175, 112, 146, 113, 233, 115, 105, 116, 74, 131, 162, 135, 97, 136, 8, 144, 162, 144, 163, 147, 168, 153, 110, 81, 87, 95, 224, 96, 103, 97, 179, 102, 89, 133, 74, 142, 175, 145, 139, 151, 78, 78, 146, 78, 124, 84, 213, 88, 250, 88, 125, 89, 181, 92, 39, 95, 54, 98, 72, 98, 10, 102, 103, 102, 235, 107, 105, 109, 207, 109, 86, 110, 248, 110, 148, 111, 224, 111, 233, 111, 93, 112, 208, 114, 37, 116, 90, 116, 224, 116, 147, 118, 92, 121, 202, 124, 30, 126, 225, 128, 166, 130, 107, 132, 191, 132, 78, 134, 95, 134, 116, 135, 119, 139, 106, 140, 172, 147, 0, 152, 101, 152, 209, 96, 22, 98, 119, 145, 90, 90, 15, 102, 247, 109, 62, 110, 63, 116, 66, 155, 253, 95, 218, 96, 15, 123, 196, 84, 24, 95, 94, 108, 211, 108, 42, 109, 216, 112, 5, 125, 121, 134, 12, 138, 59, 157, 22, 83, 140, 84, 5, 91, 58, 106, 107, 112, 117, 117, 141, 121, 190, 121, 177, 130, 239, 131, 113, 138, 65, 139, 168, 140, 116, 151, 11, 250, 244, 100, 43, 101, 186, 120, 187, 120, 107, 122, 56, 78, 154, 85, 80, 89, 166, 91, 123, 94, 163, 96, 219, 99, 97, 107, 101, 102, 83, 104, 25, 110, 101, 113, 176, 116, 8, 125, 132, 144, 105, 154, 37, 156, 59, 109, 209, 110, 62, 115, 65, 140, 202, 149, 240, 81, 76, 94, 168, 95, 77, 96, 246, 96, 48, 97, 76, 97, 67, 102, 68, 102, 165, 105, 193, 108, 95, 110, 201, 110, 98, 111, 76, 113, 156, 116, 135, 118, 193, 123, 39, 124, 82, 131, 87, 135, 81, 144, 141, 150, 195, 158, 47, 83, 222, 86, 251, 94, 138, 95, 98, 96, 148, 96, 247, 97, 102, 102, 3, 103, 156, 106, 238, 109, 174, 111, 112, 112, 106, 115, 106, 126, 190, 129, 52, 131, 212, 134, 168, 138, 196, 140, 131, 82, 114, 115, 150, 91, 107, 106, 4, 148, 238, 84, 134, 86, 93, 91, 72, 101, 133, 101, 201, 102, 159, 104, 141, 109, 198, 109, 59, 114, 180, 128, 117, 145, 77, 154, 175, 79, 25, 80, 154, 83, 14, 84, 60, 84, 137, 85, 197, 85, 63, 94, 140, 95, 61, 103, 102, 113, 221, 115, 5, 144, 219, 82, 243, 82, 100, 88, 206, 88, 4, 113, 143, 113, 251, 113, 176, 133, 19, 138, 136, 102, 168, 133, 167, 85, 132, 102, 74, 113, 49, 132, 73, 83, 153, 85, 193, 107, 89, 95, 189, 95, 238, 99, 137, 102, 71, 113, 241, 138, 29, 143, 190, 158, 17, 79, 58, 100, 203, 112, 102, 117, 103, 134, 100, 96, 78, 139, 248, 157, 71, 81, 246, 81, 8, 83, 54, 109, 248, 128, 209, 158, 21, 102, 35, 107, 152, 112, 213, 117, 3, 84, 121, 92, 7, 125, 22, 138, 32, 107, 61, 107, 70, 107, 56, 84, 112, 96, 61, 109, 213, 127, 8, 130, 214, 80, 222, 81, 156, 85, 107, 86, 205, 86, 236, 89, 9, 91, 12, 94, 153, 97, 152, 97, 49, 98, 94, 102, 230, 102, 153, 113, 185, 113, 186, 113, 167, 114, 167, 121, 0, 122, 178, 127, 112, 138, 0, 0, 0, 0, 0, 0, 1, 0, 160, 0, 167, 0, 168, 0, 169, 0, 175, 0, 176, 0, 178, 0, 183, 0, 184, 0, 198, 0, 215, 0, 216, 0, 230, 0, 247, 0, 248, 0, 0, 1, 1, 1, 2, 1, 3, 1, 4, 1, 5, 1, 6, 1, 7, 1, 8, 1, 9, 1, 10, 1, 11, 1, 12, 1, 13, 1, 14, 1, 15, 1, 16, 1, 17, 1, 18, 1, 19, 1, 22, 1, 23, 1, 24, 1, 25, 1, 26, 1, 27, 1, 28, 1, 29, 1, 30, 1, 31, 1, 32, 1, 33, 1, 34, 1, 35, 1, 36, 1, 37, 1, 38, 1, 39, 1, 40, 1, 41, 1, 42, 1, 43, 1, 46, 1, 47, 1, 48, 1, 49, 1, 52, 1, 53, 1, 54, 1, 55, 1, 56, 1, 57, 1, 58, 1, 59, 1, 60, 1, 61, 1, 62, 1, 65, 1, 66, 1, 67, 1, 68, 1, 69, 1, 70, 1, 71, 1, 72, 1, 74, 1, 75, 1, 76, 1, 77, 1, 80, 1, 81, 1, 82, 1, 83, 1, 84, 1, 85, 1, 86, 1, 87, 1, 88, 1, 89, 1, 90, 1, 91, 1, 92, 1, 93, 1, 94, 1, 95, 1, 96, 1, 97, 1, 98, 1, 99, 1, 100, 1, 101, 1, 102, 1, 103, 1, 104, 1, 105, 1, 106, 1, 107, 1, 108, 1, 109, 1, 110, 1, 111, 1, 112, 1, 113, 1, 114, 1, 115, 1, 116, 1, 117, 1, 118, 1, 119, 1, 120, 1, 121, 1, 122, 1, 123, 1, 124, 1, 125, 1, 126, 1, 146, 1, 160, 1, 161, 1, 175, 1, 176, 1, 24, 2, 25, 2, 26, 2, 27, 2, 198, 2, 199, 2, 216, 2, 217, 2, 219, 2, 220, 2, 221, 2, 0, 3, 1, 3, 3, 3, 9, 3, 35, 3, 122, 3, 132, 3, 133, 3, 134, 3, 136, 3, 137, 3, 138, 3, 140, 3, 142, 3, 143, 3, 144, 3, 145, 3, 146, 3, 147, 3, 148, 3, 149, 3, 150, 3, 151, 3, 152, 3, 153, 3, 154, 3, 155, 3, 156, 3, 157, 3, 158, 3, 159, 3, 160, 3, 161, 3, 163, 3, 164, 3, 165, 3, 166, 3, 167, 3, 168, 3, 169, 3, 170, 3, 171, 3, 172, 3, 173, 3, 174, 3, 175, 3, 176, 3, 177, 3, 178, 3, 179, 3, 180, 3, 181, 3, 182, 3, 183, 3, 184, 3, 185, 3, 186, 3, 187, 3, 188, 3, 189, 3, 190, 3, 191, 3, 192, 3, 193, 3, 194, 3, 195, 3, 196, 3, 197, 3, 198, 3, 199, 3, 200, 3, 201, 3, 202, 3, 203, 3, 204, 3, 205, 3, 206, 3, 1, 4, 2, 4, 3, 4, 4, 4, 5, 4, 6, 4, 7, 4, 8, 4, 9, 4, 10, 4, 11, 4, 12, 4, 14, 4, 15, 4, 16, 4, 17, 4, 18, 4, 19, 4, 20, 4, 21, 4, 22, 4, 23, 4, 24, 4, 25, 4, 26, 4, 27, 4, 28, 4, 29, 4, 30, 4, 31, 4, 32, 4, 33, 4, 34, 4, 35, 4, 36, 4, 37, 4, 38, 4, 39, 4, 40, 4, 41, 4, 42, 4, 43, 4, 44, 4, 45, 4, 46, 4, 47, 4, 48, 4, 49, 4, 50, 4, 51, 4, 52, 4, 53, 4, 54, 4, 55, 4, 56, 4, 57, 4, 58, 4, 59, 4, 60, 4, 61, 4, 62, 4, 63, 4, 64, 4, 65, 4, 66, 4, 67, 4, 68, 4, 69, 4, 70, 4, 71, 4, 72, 4, 73, 4, 74, 4, 75, 4, 76, 4, 77, 4, 78, 4, 79, 4, 81, 4, 82, 4, 83, 4, 84, 4, 85, 4, 86, 4, 87, 4, 88, 4, 89, 4, 90, 4, 91, 4, 92, 4, 94, 4, 95, 4, 144, 4, 145, 4, 176, 5, 177, 5, 178, 5, 179, 5, 180, 5, 181, 5, 182, 5, 183, 5, 184, 5, 185, 5, 187, 5, 188, 5, 189, 5, 190, 5, 191, 5, 192, 5, 193, 5, 194, 5, 195, 5, 208, 5, 209, 5, 210, 5, 211, 5, 212, 5, 213, 5, 214, 5, 215, 5, 216, 5, 217, 5, 218, 5, 219, 5, 220, 5, 221, 5, 222, 5, 223, 5, 224, 5, 225, 5, 226, 5, 227, 5, 228, 5, 229, 5, 230, 5, 231, 5, 232, 5, 233, 5, 234, 5, 240, 5, 241, 5, 242, 5, 243, 5, 244, 5, 12, 6, 27, 6, 31, 6, 33, 6, 34, 6, 35, 6, 36, 6, 37, 6, 38, 6, 39, 6, 40, 6, 41, 6, 42, 6, 43, 6, 44, 6, 45, 6, 46, 6, 47, 6, 48, 6, 49, 6, 50, 6, 51, 6, 52, 6, 53, 6, 54, 6, 55, 6, 56, 6, 57, 6, 58, 6, 64, 6, 65, 6, 66, 6, 67, 6, 68, 6, 69, 6, 70, 6, 71, 6, 72, 6, 73, 6, 74, 6, 75, 6, 76, 6, 77, 6, 78, 6, 79, 6, 80, 6, 81, 6, 82, 6, 121, 6, 126, 6, 134, 6, 136, 6, 145, 6, 152, 6, 169, 6, 175, 6, 186, 6, 190, 6, 193, 6, 210, 6, 1, 14, 2, 14, 3, 14, 4, 14, 5, 14, 6, 14, 7, 14, 8, 14, 9, 14, 10, 14, 11, 14, 12, 14, 13, 14, 14, 14, 15, 14, 16, 14, 17, 14, 18, 14, 19, 14, 20, 14, 21, 14, 22, 14, 23, 14, 24, 14, 25, 14, 26, 14, 27, 14, 28, 14, 29, 14, 30, 14, 31, 14, 32, 14, 33, 14, 34, 14, 35, 14, 36, 14, 37, 14, 38, 14, 39, 14, 40, 14, 41, 14, 42, 14, 43, 14, 44, 14, 45, 14, 46, 14, 47, 14, 48, 14, 49, 14, 50, 14, 51, 14, 52, 14, 53, 14, 54, 14, 55, 14, 56, 14, 57, 14, 58, 14, 63, 14, 64, 14, 65, 14, 66, 14, 67, 14, 68, 14, 69, 14, 70, 14, 71, 14, 72, 14, 73, 14, 74, 14, 75, 14, 76, 14, 77, 14, 78, 14, 79, 14, 80, 14, 81, 14, 82, 14, 83, 14, 84, 14, 85, 14, 86, 14, 87, 14, 88, 14, 89, 14, 90, 14, 91, 14, 2, 30, 3, 30, 10, 30, 11, 30, 30, 30, 31, 30, 64, 30, 65, 30, 86, 30, 87, 30, 96, 30, 97, 30, 106, 30, 107, 30, 128, 30, 129, 30, 130, 30, 131, 30, 132, 30, 133, 30, 242, 30, 243, 30, 12, 32, 13, 32, 14, 32, 15, 32, 19, 32, 20, 32, 21, 32, 23, 32, 24, 32, 25, 32, 26, 32, 28, 32, 29, 32, 30, 32, 32, 32, 33, 32, 34, 32, 38, 32, 48, 32, 57, 32, 58, 32, 170, 32, 171, 32, 172, 32, 175, 32, 22, 33, 34, 33, 25, 34, 26, 34, 72, 34, 100, 34, 101, 34, 32, 35, 33, 35, 0, 37, 2, 37, 12, 37, 16, 37, 20, 37, 24, 37, 28, 37, 36, 37, 44, 37, 52, 37, 60, 37, 80, 37, 81, 37, 82, 37, 83, 37, 84, 37, 85, 37, 86, 37, 87, 37, 88, 37, 89, 37, 90, 37, 91, 37, 92, 37, 93, 37, 94, 37, 95, 37, 96, 37, 97, 37, 98, 37, 99, 37, 100, 37, 101, 37, 102, 37, 103, 37, 104, 37, 105, 37, 106, 37, 107, 37, 108, 37, 128, 37, 132, 37, 136, 37, 140, 37, 144, 37, 145, 37, 146, 37, 147, 37, 160, 37, 0, 0, 2, 0, 0, 192, 3, 0, 0, 192, 4, 0, 0, 192, 5, 0, 0, 192, 6, 0, 0, 192, 7, 0, 0, 192, 8, 0, 0, 192, 9, 0, 0, 192, 10, 0, 0, 192, 11, 0, 0, 192, 12, 0, 0, 192, 13, 0, 0, 192, 14, 0, 0, 192, 15, 0, 0, 192, 16, 0, 0, 192, 17, 0, 0, 192, 18, 0, 0, 192, 19, 0, 0, 192, 20, 0, 0, 192, 21, 0, 0, 192, 22, 0, 0, 192, 23, 0, 0, 192, 24, 0, 0, 192, 25, 0, 0, 192, 26, 0, 0, 192, 27, 0, 0, 192, 28, 0, 0, 192, 29, 0, 0, 192, 30, 0, 0, 192, 31, 0, 0, 192, 0, 0, 0, 179, 1, 0, 0, 195, 2, 0, 0, 195, 3, 0, 0, 195, 4, 0, 0, 195, 5, 0, 0, 195, 6, 0, 0, 195, 7, 0, 0, 195, 8, 0, 0, 195, 9, 0, 0, 195, 10, 0, 0, 195, 11, 0, 0, 195, 12, 0, 0, 195, 13, 0, 0, 211, 14, 0, 0, 195, 15, 0, 0, 195, 0, 0, 12, 187, 1, 0, 12, 195, 2, 0, 12, 195, 3, 0, 12, 195, 4, 0, 12, 211, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 255, 255, 255, 255, 255, 255, 255, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 255, 255, 255, 255, 255, 255, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 0, 0, 0, 0, 0, 0, 0, 0, 1, 2, 4, 7, 3, 6, 5, 0, 0, 0, 0, 0, 0, 0, 0, 105, 110, 102, 105, 110, 105, 116, 121, 0, 0, 0, 0, 0, 0, 0, 0, 110, 97, 110, 0, 0, 0, 0, 0, 95, 112, 137, 0, 255, 9, 47, 15, 10, 0, 0, 0, 100, 0, 0, 0, 232, 3, 0, 0, 16, 39, 0, 0, 160, 134, 1, 0, 64, 66, 15, 0, 128, 150, 152, 0, 0, 225, 245, 5, 17, 0, 10, 0, 17, 17, 17, 0, 0, 0, 0, 5, 0, 0, 0, 0, 0, 0, 9, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 17, 0, 15, 10, 17, 17, 17, 3, 10, 7, 0, 1, 19, 9, 11, 11, 0, 0, 9, 6, 11, 0, 0, 11, 0, 6, 17, 0, 0, 0, 17, 17, 17, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 17, 0, 10, 10, 17, 17, 17, 0, 10, 0, 0, 2, 0, 9, 11, 0, 0, 0, 9, 0, 11, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12, 0, 0, 0, 0, 12, 0, 0, 0, 0, 9, 12, 0, 0, 0, 0, 0, 12, 0, 0, 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 13, 0, 0, 0, 4, 13, 0, 0, 0, 0, 9, 14, 0, 0, 0, 0, 0, 14, 0, 0, 14, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 16, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 15, 0, 0, 0, 0, 15, 0, 0, 0, 0, 9, 16, 0, 0, 0, 0, 0, 16, 0, 0, 16, 0, 0, 18, 0, 0, 0, 18, 18, 18, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 18, 0, 0, 0, 18, 18, 18, 0, 0, 0, 0, 0, 0, 9, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 10, 0, 0, 0, 0, 10, 0, 0, 0, 0, 9, 11, 0, 0, 0, 0, 0, 11, 0, 0, 11, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 12, 0, 0, 0, 0, 12, 0, 0, 0, 0, 9, 12, 0, 0, 0, 0, 0, 12, 0, 0, 12, 0, 0, 45, 43, 32, 32, 32, 48, 88, 48, 120, 0, 0, 0, 0, 0, 0, 0, 40, 110, 117, 108, 108, 41, 0, 0, 45, 48, 88, 43, 48, 88, 32, 48, 88, 45, 48, 120, 43, 48, 120, 32, 48, 120, 0, 0, 0, 0, 0, 0, 105, 110, 102, 0, 0, 0, 0, 0, 73, 78, 70, 0, 0, 0, 0, 0, 110, 97, 110, 0, 0, 0, 0, 0, 78, 65, 78, 0, 0, 0, 0, 0, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 65, 66, 67, 68, 69, 70, 46, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 194, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 255, 255, 255, 255, 255, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE + 322788);
	        var tempDoublePtr = Runtime.alignMemory(allocate(12, "i8", ALLOC_STATIC), 8);
	        assert(tempDoublePtr % 8 == 0);
	        function copyTempFloat(ptr) {
	            HEAP8[tempDoublePtr] = HEAP8[ptr];
	            HEAP8[tempDoublePtr + 1] = HEAP8[ptr + 1];
	            HEAP8[tempDoublePtr + 2] = HEAP8[ptr + 2];
	            HEAP8[tempDoublePtr + 3] = HEAP8[ptr + 3]
	        }

	        function copyTempDouble(ptr) {
	            HEAP8[tempDoublePtr] = HEAP8[ptr];
	            HEAP8[tempDoublePtr + 1] = HEAP8[ptr + 1];
	            HEAP8[tempDoublePtr + 2] = HEAP8[ptr + 2];
	            HEAP8[tempDoublePtr + 3] = HEAP8[ptr + 3];
	            HEAP8[tempDoublePtr + 4] = HEAP8[ptr + 4];
	            HEAP8[tempDoublePtr + 5] = HEAP8[ptr + 5];
	            HEAP8[tempDoublePtr + 6] = HEAP8[ptr + 6];
	            HEAP8[tempDoublePtr + 7] = HEAP8[ptr + 7]
	        }

	        Module["_i64Subtract"] = _i64Subtract;
	        function ___assert_fail(condition, filename, line, func) {
	            ABORT = true;
	            throw"Assertion failed: " + Pointer_stringify(condition) + ", at: " + [filename ? Pointer_stringify(filename) : "unknown filename", line, func ? Pointer_stringify(func) : "unknown function"] + " at " + stackTrace()
	        }

	        Module["_bitshift64Ashr"] = _bitshift64Ashr;
	        var ERRNO_CODES = {
	            EPERM: 1,
	            ENOENT: 2,
	            ESRCH: 3,
	            EINTR: 4,
	            EIO: 5,
	            ENXIO: 6,
	            E2BIG: 7,
	            ENOEXEC: 8,
	            EBADF: 9,
	            ECHILD: 10,
	            EAGAIN: 11,
	            EWOULDBLOCK: 11,
	            ENOMEM: 12,
	            EACCES: 13,
	            EFAULT: 14,
	            ENOTBLK: 15,
	            EBUSY: 16,
	            EEXIST: 17,
	            EXDEV: 18,
	            ENODEV: 19,
	            ENOTDIR: 20,
	            EISDIR: 21,
	            EINVAL: 22,
	            ENFILE: 23,
	            EMFILE: 24,
	            ENOTTY: 25,
	            ETXTBSY: 26,
	            EFBIG: 27,
	            ENOSPC: 28,
	            ESPIPE: 29,
	            EROFS: 30,
	            EMLINK: 31,
	            EPIPE: 32,
	            EDOM: 33,
	            ERANGE: 34,
	            ENOMSG: 42,
	            EIDRM: 43,
	            ECHRNG: 44,
	            EL2NSYNC: 45,
	            EL3HLT: 46,
	            EL3RST: 47,
	            ELNRNG: 48,
	            EUNATCH: 49,
	            ENOCSI: 50,
	            EL2HLT: 51,
	            EDEADLK: 35,
	            ENOLCK: 37,
	            EBADE: 52,
	            EBADR: 53,
	            EXFULL: 54,
	            ENOANO: 55,
	            EBADRQC: 56,
	            EBADSLT: 57,
	            EDEADLOCK: 35,
	            EBFONT: 59,
	            ENOSTR: 60,
	            ENODATA: 61,
	            ETIME: 62,
	            ENOSR: 63,
	            ENONET: 64,
	            ENOPKG: 65,
	            EREMOTE: 66,
	            ENOLINK: 67,
	            EADV: 68,
	            ESRMNT: 69,
	            ECOMM: 70,
	            EPROTO: 71,
	            EMULTIHOP: 72,
	            EDOTDOT: 73,
	            EBADMSG: 74,
	            ENOTUNIQ: 76,
	            EBADFD: 77,
	            EREMCHG: 78,
	            ELIBACC: 79,
	            ELIBBAD: 80,
	            ELIBSCN: 81,
	            ELIBMAX: 82,
	            ELIBEXEC: 83,
	            ENOSYS: 38,
	            ENOTEMPTY: 39,
	            ENAMETOOLONG: 36,
	            ELOOP: 40,
	            EOPNOTSUPP: 95,
	            EPFNOSUPPORT: 96,
	            ECONNRESET: 104,
	            ENOBUFS: 105,
	            EAFNOSUPPORT: 97,
	            EPROTOTYPE: 91,
	            ENOTSOCK: 88,
	            ENOPROTOOPT: 92,
	            ESHUTDOWN: 108,
	            ECONNREFUSED: 111,
	            EADDRINUSE: 98,
	            ECONNABORTED: 103,
	            ENETUNREACH: 101,
	            ENETDOWN: 100,
	            ETIMEDOUT: 110,
	            EHOSTDOWN: 112,
	            EHOSTUNREACH: 113,
	            EINPROGRESS: 115,
	            EALREADY: 114,
	            EDESTADDRREQ: 89,
	            EMSGSIZE: 90,
	            EPROTONOSUPPORT: 93,
	            ESOCKTNOSUPPORT: 94,
	            EADDRNOTAVAIL: 99,
	            ENETRESET: 102,
	            EISCONN: 106,
	            ENOTCONN: 107,
	            ETOOMANYREFS: 109,
	            EUSERS: 87,
	            EDQUOT: 122,
	            ESTALE: 116,
	            ENOTSUP: 95,
	            ENOMEDIUM: 123,
	            EILSEQ: 84,
	            EOVERFLOW: 75,
	            ECANCELED: 125,
	            ENOTRECOVERABLE: 131,
	            EOWNERDEAD: 130,
	            ESTRPIPE: 86
	        };
	        var ERRNO_MESSAGES = {
	            0: "Success",
	            1: "Not super-user",
	            2: "No such file or directory",
	            3: "No such process",
	            4: "Interrupted system call",
	            5: "I/O error",
	            6: "No such device or address",
	            7: "Arg list too long",
	            8: "Exec format error",
	            9: "Bad file number",
	            10: "No children",
	            11: "No more processes",
	            12: "Not enough core",
	            13: "Permission denied",
	            14: "Bad address",
	            15: "Block device required",
	            16: "Mount device busy",
	            17: "File exists",
	            18: "Cross-device link",
	            19: "No such device",
	            20: "Not a directory",
	            21: "Is a directory",
	            22: "Invalid argument",
	            23: "Too many open files in system",
	            24: "Too many open files",
	            25: "Not a typewriter",
	            26: "Text file busy",
	            27: "File too large",
	            28: "No space left on device",
	            29: "Illegal seek",
	            30: "Read only file system",
	            31: "Too many links",
	            32: "Broken pipe",
	            33: "Math arg out of domain of func",
	            34: "Math result not representable",
	            35: "File locking deadlock error",
	            36: "File or path name too long",
	            37: "No record locks available",
	            38: "Function not implemented",
	            39: "Directory not empty",
	            40: "Too many symbolic links",
	            42: "No message of desired type",
	            43: "Identifier removed",
	            44: "Channel number out of range",
	            45: "Level 2 not synchronized",
	            46: "Level 3 halted",
	            47: "Level 3 reset",
	            48: "Link number out of range",
	            49: "Protocol driver not attached",
	            50: "No CSI structure available",
	            51: "Level 2 halted",
	            52: "Invalid exchange",
	            53: "Invalid request descriptor",
	            54: "Exchange full",
	            55: "No anode",
	            56: "Invalid request code",
	            57: "Invalid slot",
	            59: "Bad font file fmt",
	            60: "Device not a stream",
	            61: "No data (for no delay io)",
	            62: "Timer expired",
	            63: "Out of streams resources",
	            64: "Machine is not on the network",
	            65: "Package not installed",
	            66: "The object is remote",
	            67: "The link has been severed",
	            68: "Advertise error",
	            69: "Srmount error",
	            70: "Communication error on send",
	            71: "Protocol error",
	            72: "Multihop attempted",
	            73: "Cross mount point (not really error)",
	            74: "Trying to read unreadable message",
	            75: "Value too large for defined data type",
	            76: "Given log. name not unique",
	            77: "f.d. invalid for this operation",
	            78: "Remote address changed",
	            79: "Can   access a needed shared lib",
	            80: "Accessing a corrupted shared lib",
	            81: ".lib section in a.out corrupted",
	            82: "Attempting to link in too many libs",
	            83: "Attempting to exec a shared library",
	            84: "Illegal byte sequence",
	            86: "Streams pipe error",
	            87: "Too many users",
	            88: "Socket operation on non-socket",
	            89: "Destination address required",
	            90: "Message too long",
	            91: "Protocol wrong type for socket",
	            92: "Protocol not available",
	            93: "Unknown protocol",
	            94: "Socket type not supported",
	            95: "Not supported",
	            96: "Protocol family not supported",
	            97: "Address family not supported by protocol family",
	            98: "Address already in use",
	            99: "Address not available",
	            100: "Network interface is not configured",
	            101: "Network is unreachable",
	            102: "Connection reset by network",
	            103: "Connection aborted",
	            104: "Connection reset by peer",
	            105: "No buffer space available",
	            106: "Socket is already connected",
	            107: "Socket is not connected",
	            108: "Can't send after socket shutdown",
	            109: "Too many references",
	            110: "Connection timed out",
	            111: "Connection refused",
	            112: "Host is down",
	            113: "Host is unreachable",
	            114: "Socket already connected",
	            115: "Connection already in progress",
	            116: "Stale file handle",
	            122: "Quota exceeded",
	            123: "No medium (in tape drive)",
	            125: "Operation canceled",
	            130: "Previous owner died",
	            131: "State not recoverable"
	        };
	        var ___errno_state = 0;

	        function ___setErrNo(value) {
	            HEAP32[___errno_state >> 2] = value;
	            return value
	        }

	        var PATH = {
	            splitPath: (function (filename) {
	                var splitPathRe = /^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/;
	                return splitPathRe.exec(filename).slice(1)
	            }), normalizeArray: (function (parts, allowAboveRoot) {
	                var up = 0;
	                for (var i = parts.length - 1; i >= 0; i--) {
	                    var last = parts[i];
	                    if (last === ".") {
	                        parts.splice(i, 1)
	                    } else if (last === "..") {
	                        parts.splice(i, 1);
	                        up++
	                    } else if (up) {
	                        parts.splice(i, 1);
	                        up--
	                    }
	                }
	                if (allowAboveRoot) {
	                    for (; up--; up) {
	                        parts.unshift("..")
	                    }
	                }
	                return parts
	            }), normalize: (function (path) {
	                var isAbsolute = path.charAt(0) === "/", trailingSlash = path.substr(-1) === "/";
	                path = PATH.normalizeArray(path.split("/").filter((function (p) {
	                    return !!p
	                })), !isAbsolute).join("/");
	                if (!path && !isAbsolute) {
	                    path = "."
	                }
	                if (path && trailingSlash) {
	                    path += "/"
	                }
	                return (isAbsolute ? "/" : "") + path
	            }), dirname: (function (path) {
	                var result = PATH.splitPath(path), root = result[0], dir = result[1];
	                if (!root && !dir) {
	                    return "."
	                }
	                if (dir) {
	                    dir = dir.substr(0, dir.length - 1)
	                }
	                return root + dir
	            }), basename: (function (path) {
	                if (path === "/")return "/";
	                var lastSlash = path.lastIndexOf("/");
	                if (lastSlash === -1)return path;
	                return path.substr(lastSlash + 1)
	            }), extname: (function (path) {
	                return PATH.splitPath(path)[3]
	            }), join: (function () {
	                var paths = Array.prototype.slice.call(arguments, 0);
	                return PATH.normalize(paths.join("/"))
	            }), join2: (function (l, r) {
	                return PATH.normalize(l + "/" + r)
	            }), resolve: (function () {
	                var resolvedPath = "", resolvedAbsolute = false;
	                for (var i = arguments.length - 1; i >= -1 && !resolvedAbsolute; i--) {
	                    var path = i >= 0 ? arguments[i] : FS.cwd();
	                    if (typeof path !== "string") {
	                        throw new TypeError("Arguments to path.resolve must be strings")
	                    } else if (!path) {
	                        return ""
	                    }
	                    resolvedPath = path + "/" + resolvedPath;
	                    resolvedAbsolute = path.charAt(0) === "/"
	                }
	                resolvedPath = PATH.normalizeArray(resolvedPath.split("/").filter((function (p) {
	                    return !!p
	                })), !resolvedAbsolute).join("/");
	                return (resolvedAbsolute ? "/" : "") + resolvedPath || "."
	            }), relative: (function (from, to) {
	                from = PATH.resolve(from).substr(1);
	                to = PATH.resolve(to).substr(1);
	                function trim(arr) {
	                    var start = 0;
	                    for (; start < arr.length; start++) {
	                        if (arr[start] !== "")break
	                    }
	                    var end = arr.length - 1;
	                    for (; end >= 0; end--) {
	                        if (arr[end] !== "")break
	                    }
	                    if (start > end)return [];
	                    return arr.slice(start, end - start + 1)
	                }

	                var fromParts = trim(from.split("/"));
	                var toParts = trim(to.split("/"));
	                var length = Math.min(fromParts.length, toParts.length);
	                var samePartsLength = length;
	                for (var i = 0; i < length; i++) {
	                    if (fromParts[i] !== toParts[i]) {
	                        samePartsLength = i;
	                        break
	                    }
	                }
	                var outputParts = [];
	                for (var i = samePartsLength; i < fromParts.length; i++) {
	                    outputParts.push("..")
	                }
	                outputParts = outputParts.concat(toParts.slice(samePartsLength));
	                return outputParts.join("/")
	            })
	        };
	        var TTY = {
	            ttys: [], init: (function () {
	            }), shutdown: (function () {
	            }), register: (function (dev, ops) {
	                TTY.ttys[dev] = {input: [], output: [], ops: ops};
	                FS.registerDevice(dev, TTY.stream_ops)
	            }), stream_ops: {
	                open: (function (stream) {
	                    var tty = TTY.ttys[stream.node.rdev];
	                    if (!tty) {
	                        throw new FS.ErrnoError(ERRNO_CODES.ENODEV)
	                    }
	                    stream.tty = tty;
	                    stream.seekable = false
	                }), close: (function (stream) {
	                    stream.tty.ops.flush(stream.tty)
	                }), flush: (function (stream) {
	                    stream.tty.ops.flush(stream.tty)
	                }), read: (function (stream, buffer, offset, length, pos) {
	                    if (!stream.tty || !stream.tty.ops.get_char) {
	                        throw new FS.ErrnoError(ERRNO_CODES.ENXIO)
	                    }
	                    var bytesRead = 0;
	                    for (var i = 0; i < length; i++) {
	                        var result;
	                        try {
	                            result = stream.tty.ops.get_char(stream.tty)
	                        } catch (e) {
	                            throw new FS.ErrnoError(ERRNO_CODES.EIO)
	                        }
	                        if (result === undefined && bytesRead === 0) {
	                            throw new FS.ErrnoError(ERRNO_CODES.EAGAIN)
	                        }
	                        if (result === null || result === undefined)break;
	                        bytesRead++;
	                        buffer[offset + i] = result
	                    }
	                    if (bytesRead) {
	                        stream.node.timestamp = Date.now()
	                    }
	                    return bytesRead
	                }), write: (function (stream, buffer, offset, length, pos) {
	                    if (!stream.tty || !stream.tty.ops.put_char) {
	                        throw new FS.ErrnoError(ERRNO_CODES.ENXIO)
	                    }
	                    for (var i = 0; i < length; i++) {
	                        try {
	                            stream.tty.ops.put_char(stream.tty, buffer[offset + i])
	                        } catch (e) {
	                            throw new FS.ErrnoError(ERRNO_CODES.EIO)
	                        }
	                    }
	                    if (length) {
	                        stream.node.timestamp = Date.now()
	                    }
	                    return i
	                })
	            }, default_tty_ops: {
	                get_char: (function (tty) {
	                    if (!tty.input.length) {
	                        var result = null;
	                        if (typeof window != "undefined" && typeof window.prompt == "function") {
	                            result = window.prompt("Input: ");
	                            if (result !== null) {
	                                result += "\n"
	                            }
	                        } else if (typeof readline == "function") {
	                            result = readline();
	                            if (result !== null) {
	                                result += "\n"
	                            }
	                        }
	                        if (!result) {
	                            return null
	                        }
	                        tty.input = intArrayFromString(result, true)
	                    }
	                    return tty.input.shift()
	                }), flush: (function (tty) {
	                    if (tty.output && tty.output.length > 0) {
	                        Module["print"](tty.output.join(""));
	                        tty.output = []
	                    }
	                }), put_char: (function (tty, val) {
	                    if (val === null || val === 10) {
	                        Module["print"](tty.output.join(""));
	                        tty.output = []
	                    } else {
	                        tty.output.push(TTY.utf8.processCChar(val))
	                    }
	                })
	            }, default_tty1_ops: {
	                put_char: (function (tty, val) {
	                    if (val === null || val === 10) {
	                        Module["printErr"](tty.output.join(""));
	                        tty.output = []
	                    } else {
	                        tty.output.push(TTY.utf8.processCChar(val))
	                    }
	                }), flush: (function (tty) {
	                    if (tty.output && tty.output.length > 0) {
	                        Module["printErr"](tty.output.join(""));
	                        tty.output = []
	                    }
	                })
	            }
	        };
	        var MEMFS = {
	            ops_table: null, mount: (function (mount) {
	                return MEMFS.createNode(null, "/", 16384 | 511, 0)
	            }), createNode: (function (parent, name, mode, dev) {
	                if (FS.isBlkdev(mode) || FS.isFIFO(mode)) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EPERM)
	                }
	                if (!MEMFS.ops_table) {
	                    MEMFS.ops_table = {
	                        dir: {
	                            node: {
	                                getattr: MEMFS.node_ops.getattr,
	                                setattr: MEMFS.node_ops.setattr,
	                                lookup: MEMFS.node_ops.lookup,
	                                mknod: MEMFS.node_ops.mknod,
	                                rename: MEMFS.node_ops.rename,
	                                unlink: MEMFS.node_ops.unlink,
	                                rmdir: MEMFS.node_ops.rmdir,
	                                readdir: MEMFS.node_ops.readdir,
	                                symlink: MEMFS.node_ops.symlink
	                            }, stream: {llseek: MEMFS.stream_ops.llseek}
	                        },
	                        file: {
	                            node: {getattr: MEMFS.node_ops.getattr, setattr: MEMFS.node_ops.setattr},
	                            stream: {
	                                llseek: MEMFS.stream_ops.llseek,
	                                read: MEMFS.stream_ops.read,
	                                write: MEMFS.stream_ops.write,
	                                allocate: MEMFS.stream_ops.allocate,
	                                mmap: MEMFS.stream_ops.mmap
	                            }
	                        },
	                        link: {
	                            node: {
	                                getattr: MEMFS.node_ops.getattr,
	                                setattr: MEMFS.node_ops.setattr,
	                                readlink: MEMFS.node_ops.readlink
	                            }, stream: {}
	                        },
	                        chrdev: {
	                            node: {getattr: MEMFS.node_ops.getattr, setattr: MEMFS.node_ops.setattr},
	                            stream: FS.chrdev_stream_ops
	                        }
	                    }
	                }
	                var node = FS.createNode(parent, name, mode, dev);
	                if (FS.isDir(node.mode)) {
	                    node.node_ops = MEMFS.ops_table.dir.node;
	                    node.stream_ops = MEMFS.ops_table.dir.stream;
	                    node.contents = {}
	                } else if (FS.isFile(node.mode)) {
	                    node.node_ops = MEMFS.ops_table.file.node;
	                    node.stream_ops = MEMFS.ops_table.file.stream;
	                    node.usedBytes = 0;
	                    node.contents = null
	                } else if (FS.isLink(node.mode)) {
	                    node.node_ops = MEMFS.ops_table.link.node;
	                    node.stream_ops = MEMFS.ops_table.link.stream
	                } else if (FS.isChrdev(node.mode)) {
	                    node.node_ops = MEMFS.ops_table.chrdev.node;
	                    node.stream_ops = MEMFS.ops_table.chrdev.stream
	                }
	                node.timestamp = Date.now();
	                if (parent) {
	                    parent.contents[name] = node
	                }
	                return node
	            }), getFileDataAsRegularArray: (function (node) {
	                if (node.contents && node.contents.subarray) {
	                    var arr = [];
	                    for (var i = 0; i < node.usedBytes; ++i)arr.push(node.contents[i]);
	                    return arr
	                }
	                return node.contents
	            }), getFileDataAsTypedArray: (function (node) {
	                if (!node.contents)return new Uint8Array;
	                if (node.contents.subarray)return node.contents.subarray(0, node.usedBytes);
	                return new Uint8Array(node.contents)
	            }), expandFileStorage: (function (node, newCapacity) {
	                if (node.contents && node.contents.subarray && newCapacity > node.contents.length) {
	                    node.contents = MEMFS.getFileDataAsRegularArray(node);
	                    node.usedBytes = node.contents.length
	                }
	                if (!node.contents || node.contents.subarray) {
	                    var prevCapacity = node.contents ? node.contents.buffer.byteLength : 0;
	                    if (prevCapacity >= newCapacity)return;
	                    var CAPACITY_DOUBLING_MAX = 1024 * 1024;
	                    newCapacity = Math.max(newCapacity, prevCapacity * (prevCapacity < CAPACITY_DOUBLING_MAX ? 2 : 1.125) | 0);
	                    if (prevCapacity != 0)newCapacity = Math.max(newCapacity, 256);
	                    var oldContents = node.contents;
	                    node.contents = new Uint8Array(newCapacity);
	                    if (node.usedBytes > 0)node.contents.set(oldContents.subarray(0, node.usedBytes), 0);
	                    return
	                }
	                if (!node.contents && newCapacity > 0)node.contents = [];
	                while (node.contents.length < newCapacity)node.contents.push(0)
	            }), resizeFileStorage: (function (node, newSize) {
	                if (node.usedBytes == newSize)return;
	                if (newSize == 0) {
	                    node.contents = null;
	                    node.usedBytes = 0;
	                    return
	                }
	                if (!node.contents || node.contents.subarray) {
	                    var oldContents = node.contents;
	                    node.contents = new Uint8Array(new ArrayBuffer(newSize));
	                    if (oldContents) {
	                        node.contents.set(oldContents.subarray(0, Math.min(newSize, node.usedBytes)))
	                    }
	                    node.usedBytes = newSize;
	                    return
	                }
	                if (!node.contents)node.contents = [];
	                if (node.contents.length > newSize)node.contents.length = newSize; else while (node.contents.length < newSize)node.contents.push(0);
	                node.usedBytes = newSize
	            }), node_ops: {
	                getattr: (function (node) {
	                    var attr = {};
	                    attr.dev = FS.isChrdev(node.mode) ? node.id : 1;
	                    attr.ino = node.id;
	                    attr.mode = node.mode;
	                    attr.nlink = 1;
	                    attr.uid = 0;
	                    attr.gid = 0;
	                    attr.rdev = node.rdev;
	                    if (FS.isDir(node.mode)) {
	                        attr.size = 4096
	                    } else if (FS.isFile(node.mode)) {
	                        attr.size = node.usedBytes
	                    } else if (FS.isLink(node.mode)) {
	                        attr.size = node.link.length
	                    } else {
	                        attr.size = 0
	                    }
	                    attr.atime = new Date(node.timestamp);
	                    attr.mtime = new Date(node.timestamp);
	                    attr.ctime = new Date(node.timestamp);
	                    attr.blksize = 4096;
	                    attr.blocks = Math.ceil(attr.size / attr.blksize);
	                    return attr
	                }), setattr: (function (node, attr) {
	                    if (attr.mode !== undefined) {
	                        node.mode = attr.mode
	                    }
	                    if (attr.timestamp !== undefined) {
	                        node.timestamp = attr.timestamp
	                    }
	                    if (attr.size !== undefined) {
	                        MEMFS.resizeFileStorage(node, attr.size)
	                    }
	                }), lookup: (function (parent, name) {
	                    throw FS.genericErrors[ERRNO_CODES.ENOENT]
	                }), mknod: (function (parent, name, mode, dev) {
	                    return MEMFS.createNode(parent, name, mode, dev)
	                }), rename: (function (old_node, new_dir, new_name) {
	                    if (FS.isDir(old_node.mode)) {
	                        var new_node;
	                        try {
	                            new_node = FS.lookupNode(new_dir, new_name)
	                        } catch (e) {
	                        }
	                        if (new_node) {
	                            for (var i in new_node.contents) {
	                                throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY)
	                            }
	                        }
	                    }
	                    delete old_node.parent.contents[old_node.name];
	                    old_node.name = new_name;
	                    new_dir.contents[new_name] = old_node;
	                    old_node.parent = new_dir
	                }), unlink: (function (parent, name) {
	                    delete parent.contents[name]
	                }), rmdir: (function (parent, name) {
	                    var node = FS.lookupNode(parent, name);
	                    for (var i in node.contents) {
	                        throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY)
	                    }
	                    delete parent.contents[name]
	                }), readdir: (function (node) {
	                    var entries = [".", ".."];
	                    for (var key in node.contents) {
	                        if (!node.contents.hasOwnProperty(key)) {
	                            continue
	                        }
	                        entries.push(key)
	                    }
	                    return entries
	                }), symlink: (function (parent, newname, oldpath) {
	                    var node = MEMFS.createNode(parent, newname, 511 | 40960, 0);
	                    node.link = oldpath;
	                    return node
	                }), readlink: (function (node) {
	                    if (!FS.isLink(node.mode)) {
	                        throw new FS.ErrnoError(ERRNO_CODES.EINVAL)
	                    }
	                    return node.link
	                })
	            }, stream_ops: {
	                read: (function (stream, buffer, offset, length, position) {
	                    var contents = stream.node.contents;
	                    if (position >= stream.node.usedBytes)return 0;
	                    var size = Math.min(stream.node.usedBytes - position, length);
	                    assert(size >= 0);
	                    if (size > 8 && contents.subarray) {
	                        buffer.set(contents.subarray(position, position + size), offset)
	                    } else {
	                        for (var i = 0; i < size; i++)buffer[offset + i] = contents[position + i]
	                    }
	                    return size
	                }), write: (function (stream, buffer, offset, length, position, canOwn) {
	                    if (!length)return 0;
	                    var node = stream.node;
	                    node.timestamp = Date.now();
	                    if (buffer.subarray && (!node.contents || node.contents.subarray)) {
	                        if (canOwn) {
	                            node.contents = buffer.subarray(offset, offset + length);
	                            node.usedBytes = length;
	                            return length
	                        } else if (node.usedBytes === 0 && position === 0) {
	                            node.contents = new Uint8Array(buffer.subarray(offset, offset + length));
	                            node.usedBytes = length;
	                            return length
	                        } else if (position + length <= node.usedBytes) {
	                            node.contents.set(buffer.subarray(offset, offset + length), position);
	                            return length
	                        }
	                    }
	                    MEMFS.expandFileStorage(node, position + length);
	                    if (node.contents.subarray && buffer.subarray)node.contents.set(buffer.subarray(offset, offset + length), position); else for (var i = 0; i < length; i++) {
	                        node.contents[position + i] = buffer[offset + i]
	                    }
	                    node.usedBytes = Math.max(node.usedBytes, position + length);
	                    return length
	                }), llseek: (function (stream, offset, whence) {
	                    var position = offset;
	                    if (whence === 1) {
	                        position += stream.position
	                    } else if (whence === 2) {
	                        if (FS.isFile(stream.node.mode)) {
	                            position += stream.node.usedBytes
	                        }
	                    }
	                    if (position < 0) {
	                        throw new FS.ErrnoError(ERRNO_CODES.EINVAL)
	                    }
	                    return position
	                }), allocate: (function (stream, offset, length) {
	                    MEMFS.expandFileStorage(stream.node, offset + length);
	                    stream.node.usedBytes = Math.max(stream.node.usedBytes, offset + length)
	                }), mmap: (function (stream, buffer, offset, length, position, prot, flags) {
	                    if (!FS.isFile(stream.node.mode)) {
	                        throw new FS.ErrnoError(ERRNO_CODES.ENODEV)
	                    }
	                    var ptr;
	                    var allocated;
	                    var contents = stream.node.contents;
	                    if (!(flags & 2) && (contents.buffer === buffer || contents.buffer === buffer.buffer)) {
	                        allocated = false;
	                        ptr = contents.byteOffset
	                    } else {
	                        if (position > 0 || position + length < stream.node.usedBytes) {
	                            if (contents.subarray) {
	                                contents = contents.subarray(position, position + length)
	                            } else {
	                                contents = Array.prototype.slice.call(contents, position, position + length)
	                            }
	                        }
	                        allocated = true;
	                        ptr = _malloc(length);
	                        if (!ptr) {
	                            throw new FS.ErrnoError(ERRNO_CODES.ENOMEM)
	                        }
	                        buffer.set(contents, ptr)
	                    }
	                    return {ptr: ptr, allocated: allocated}
	                })
	            }
	        };
	        var IDBFS = {
	            dbs: {}, indexedDB: (function () {
	                if (typeof indexedDB !== "undefined")return indexedDB;
	                var ret = null;
	                if (typeof window === "object")ret = window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
	                assert(ret, "IDBFS used, but indexedDB not supported");
	                return ret
	            }), DB_VERSION: 21, DB_STORE_NAME: "FILE_DATA", mount: (function (mount) {
	                return MEMFS.mount.apply(null, arguments)
	            }), syncfs: (function (mount, populate, callback) {
	                IDBFS.getLocalSet(mount, (function (err, local) {
	                    if (err)return callback(err);
	                    IDBFS.getRemoteSet(mount, (function (err, remote) {
	                        if (err)return callback(err);
	                        var src = populate ? remote : local;
	                        var dst = populate ? local : remote;
	                        IDBFS.reconcile(src, dst, callback)
	                    }))
	                }))
	            }), getDB: (function (name, callback) {
	                var db = IDBFS.dbs[name];
	                if (db) {
	                    return callback(null, db)
	                }
	                var req;
	                try {
	                    req = IDBFS.indexedDB().open(name, IDBFS.DB_VERSION)
	                } catch (e) {
	                    return callback(e)
	                }
	                req.onupgradeneeded = (function (e) {
	                    var db = e.target.result;
	                    var transaction = e.target.transaction;
	                    var fileStore;
	                    if (db.objectStoreNames.contains(IDBFS.DB_STORE_NAME)) {
	                        fileStore = transaction.objectStore(IDBFS.DB_STORE_NAME)
	                    } else {
	                        fileStore = db.createObjectStore(IDBFS.DB_STORE_NAME)
	                    }
	                    fileStore.createIndex("timestamp", "timestamp", {unique: false})
	                });
	                req.onsuccess = (function () {
	                    db = req.result;
	                    IDBFS.dbs[name] = db;
	                    callback(null, db)
	                });
	                req.onerror = (function () {
	                    callback(this.error)
	                })
	            }), getLocalSet: (function (mount, callback) {
	                var entries = {};

	                function isRealDir(p) {
	                    return p !== "." && p !== ".."
	                }

	                function toAbsolute(root) {
	                    return (function (p) {
	                        return PATH.join2(root, p)
	                    })
	                }

	                var check = FS.readdir(mount.mountpoint).filter(isRealDir).map(toAbsolute(mount.mountpoint));
	                while (check.length) {
	                    var path = check.pop();
	                    var stat;
	                    try {
	                        stat = FS.stat(path)
	                    } catch (e) {
	                        return callback(e)
	                    }
	                    if (FS.isDir(stat.mode)) {
	                        check.push.apply(check, FS.readdir(path).filter(isRealDir).map(toAbsolute(path)))
	                    }
	                    entries[path] = {timestamp: stat.mtime}
	                }
	                return callback(null, {type: "local", entries: entries})
	            }), getRemoteSet: (function (mount, callback) {
	                var entries = {};
	                IDBFS.getDB(mount.mountpoint, (function (err, db) {
	                    if (err)return callback(err);
	                    var transaction = db.transaction([IDBFS.DB_STORE_NAME], "readonly");
	                    transaction.onerror = (function () {
	                        callback(this.error)
	                    });
	                    var store = transaction.objectStore(IDBFS.DB_STORE_NAME);
	                    var index = store.index("timestamp");
	                    index.openKeyCursor().onsuccess = (function (event) {
	                        var cursor = event.target.result;
	                        if (!cursor) {
	                            return callback(null, {type: "remote", db: db, entries: entries})
	                        }
	                        entries[cursor.primaryKey] = {timestamp: cursor.key};
	                        cursor.continue()
	                    })
	                }))
	            }), loadLocalEntry: (function (path, callback) {
	                var stat, node;
	                try {
	                    var lookup = FS.lookupPath(path);
	                    node = lookup.node;
	                    stat = FS.stat(path)
	                } catch (e) {
	                    return callback(e)
	                }
	                if (FS.isDir(stat.mode)) {
	                    return callback(null, {timestamp: stat.mtime, mode: stat.mode})
	                } else if (FS.isFile(stat.mode)) {
	                    node.contents = MEMFS.getFileDataAsTypedArray(node);
	                    return callback(null, {timestamp: stat.mtime, mode: stat.mode, contents: node.contents})
	                } else {
	                    return callback(new Error("node type not supported"))
	                }
	            }), storeLocalEntry: (function (path, entry, callback) {
	                try {
	                    if (FS.isDir(entry.mode)) {
	                        FS.mkdir(path, entry.mode)
	                    } else if (FS.isFile(entry.mode)) {
	                        FS.writeFile(path, entry.contents, {encoding: "binary", canOwn: true})
	                    } else {
	                        return callback(new Error("node type not supported"))
	                    }
	                    FS.chmod(path, entry.mode);
	                    FS.utime(path, entry.timestamp, entry.timestamp)
	                } catch (e) {
	                    return callback(e)
	                }
	                callback(null)
	            }), removeLocalEntry: (function (path, callback) {
	                try {
	                    var lookup = FS.lookupPath(path);
	                    var stat = FS.stat(path);
	                    if (FS.isDir(stat.mode)) {
	                        FS.rmdir(path)
	                    } else if (FS.isFile(stat.mode)) {
	                        FS.unlink(path)
	                    }
	                } catch (e) {
	                    return callback(e)
	                }
	                callback(null)
	            }), loadRemoteEntry: (function (store, path, callback) {
	                var req = store.get(path);
	                req.onsuccess = (function (event) {
	                    callback(null, event.target.result)
	                });
	                req.onerror = (function () {
	                    callback(this.error)
	                })
	            }), storeRemoteEntry: (function (store, path, entry, callback) {
	                var req = store.put(entry, path);
	                req.onsuccess = (function () {
	                    callback(null)
	                });
	                req.onerror = (function () {
	                    callback(this.error)
	                })
	            }), removeRemoteEntry: (function (store, path, callback) {
	                var req = store.delete(path);
	                req.onsuccess = (function () {
	                    callback(null)
	                });
	                req.onerror = (function () {
	                    callback(this.error)
	                })
	            }), reconcile: (function (src, dst, callback) {
	                var total = 0;
	                var create = [];
	                Object.keys(src.entries).forEach((function (key) {
	                    var e = src.entries[key];
	                    var e2 = dst.entries[key];
	                    if (!e2 || e.timestamp > e2.timestamp) {
	                        create.push(key);
	                        total++
	                    }
	                }));
	                var remove = [];
	                Object.keys(dst.entries).forEach((function (key) {
	                    var e = dst.entries[key];
	                    var e2 = src.entries[key];
	                    if (!e2) {
	                        remove.push(key);
	                        total++
	                    }
	                }));
	                if (!total) {
	                    return callback(null)
	                }
	                var errored = false;
	                var completed = 0;
	                var db = src.type === "remote" ? src.db : dst.db;
	                var transaction = db.transaction([IDBFS.DB_STORE_NAME], "readwrite");
	                var store = transaction.objectStore(IDBFS.DB_STORE_NAME);

	                function done(err) {
	                    if (err) {
	                        if (!done.errored) {
	                            done.errored = true;
	                            return callback(err)
	                        }
	                        return
	                    }
	                    if (++completed >= total) {
	                        return callback(null)
	                    }
	                }

	                transaction.onerror = (function () {
	                    done(this.error)
	                });
	                create.sort().forEach((function (path) {
	                    if (dst.type === "local") {
	                        IDBFS.loadRemoteEntry(store, path, (function (err, entry) {
	                            if (err)return done(err);
	                            IDBFS.storeLocalEntry(path, entry, done)
	                        }))
	                    } else {
	                        IDBFS.loadLocalEntry(path, (function (err, entry) {
	                            if (err)return done(err);
	                            IDBFS.storeRemoteEntry(store, path, entry, done)
	                        }))
	                    }
	                }));
	                remove.sort().reverse().forEach((function (path) {
	                    if (dst.type === "local") {
	                        IDBFS.removeLocalEntry(path, done)
	                    } else {
	                        IDBFS.removeRemoteEntry(store, path, done)
	                    }
	                }))
	            })
	        };
	        var NODEFS = {
	            isWindows: false,
	            staticInit: (function () {
	                NODEFS.isWindows = !!process.platform.match(/^win/)
	            }),
	            mount: (function (mount) {
	                assert(false);
	                return NODEFS.createNode(null, "/", NODEFS.getMode(mount.opts.root), 0)
	            }),
	            createNode: (function (parent, name, mode, dev) {
	                if (!FS.isDir(mode) && !FS.isFile(mode) && !FS.isLink(mode)) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EINVAL)
	                }
	                var node = FS.createNode(parent, name, mode);
	                node.node_ops = NODEFS.node_ops;
	                node.stream_ops = NODEFS.stream_ops;
	                return node
	            }),
	            getMode: (function (path) {
	                var stat;
	                try {
	                    stat = fs.lstatSync(path);
	                    if (NODEFS.isWindows) {
	                        stat.mode = stat.mode | (stat.mode & 146) >> 1
	                    }
	                } catch (e) {
	                    if (!e.code)throw e;
	                    throw new FS.ErrnoError(ERRNO_CODES[e.code])
	                }
	                return stat.mode
	            }),
	            realPath: (function (node) {
	                var parts = [];
	                while (node.parent !== node) {
	                    parts.push(node.name);
	                    node = node.parent
	                }
	                parts.push(node.mount.opts.root);
	                parts.reverse();
	                return PATH.join.apply(null, parts)
	            }),
	            flagsToPermissionStringMap: {
	                0: "r",
	                1: "r+",
	                2: "r+",
	                64: "r",
	                65: "r+",
	                66: "r+",
	                129: "rx+",
	                193: "rx+",
	                514: "w+",
	                577: "w",
	                578: "w+",
	                705: "wx",
	                706: "wx+",
	                1024: "a",
	                1025: "a",
	                1026: "a+",
	                1089: "a",
	                1090: "a+",
	                1153: "ax",
	                1154: "ax+",
	                1217: "ax",
	                1218: "ax+",
	                4096: "rs",
	                4098: "rs+"
	            },
	            flagsToPermissionString: (function (flags) {
	                if (flags in NODEFS.flagsToPermissionStringMap) {
	                    return NODEFS.flagsToPermissionStringMap[flags]
	                } else {
	                    return flags
	                }
	            }),
	            node_ops: {
	                getattr: (function (node) {
	                    var path = NODEFS.realPath(node);
	                    var stat;
	                    try {
	                        stat = fs.lstatSync(path)
	                    } catch (e) {
	                        if (!e.code)throw e;
	                        throw new FS.ErrnoError(ERRNO_CODES[e.code])
	                    }
	                    if (NODEFS.isWindows && !stat.blksize) {
	                        stat.blksize = 4096
	                    }
	                    if (NODEFS.isWindows && !stat.blocks) {
	                        stat.blocks = (stat.size + stat.blksize - 1) / stat.blksize | 0
	                    }
	                    return {
	                        dev: stat.dev,
	                        ino: stat.ino,
	                        mode: stat.mode,
	                        nlink: stat.nlink,
	                        uid: stat.uid,
	                        gid: stat.gid,
	                        rdev: stat.rdev,
	                        size: stat.size,
	                        atime: stat.atime,
	                        mtime: stat.mtime,
	                        ctime: stat.ctime,
	                        blksize: stat.blksize,
	                        blocks: stat.blocks
	                    }
	                }), setattr: (function (node, attr) {
	                    var path = NODEFS.realPath(node);
	                    try {
	                        if (attr.mode !== undefined) {
	                            fs.chmodSync(path, attr.mode);
	                            node.mode = attr.mode
	                        }
	                        if (attr.timestamp !== undefined) {
	                            var date = new Date(attr.timestamp);
	                            fs.utimesSync(path, date, date)
	                        }
	                        if (attr.size !== undefined) {
	                            fs.truncateSync(path, attr.size)
	                        }
	                    } catch (e) {
	                        if (!e.code)throw e;
	                        throw new FS.ErrnoError(ERRNO_CODES[e.code])
	                    }
	                }), lookup: (function (parent, name) {
	                    var path = PATH.join2(NODEFS.realPath(parent), name);
	                    var mode = NODEFS.getMode(path);
	                    return NODEFS.createNode(parent, name, mode)
	                }), mknod: (function (parent, name, mode, dev) {
	                    var node = NODEFS.createNode(parent, name, mode, dev);
	                    var path = NODEFS.realPath(node);
	                    try {
	                        if (FS.isDir(node.mode)) {
	                            fs.mkdirSync(path, node.mode)
	                        } else {
	                            fs.writeFileSync(path, "", {mode: node.mode})
	                        }
	                    } catch (e) {
	                        if (!e.code)throw e;
	                        throw new FS.ErrnoError(ERRNO_CODES[e.code])
	                    }
	                    return node
	                }), rename: (function (oldNode, newDir, newName) {
	                    var oldPath = NODEFS.realPath(oldNode);
	                    var newPath = PATH.join2(NODEFS.realPath(newDir), newName);
	                    try {
	                        fs.renameSync(oldPath, newPath)
	                    } catch (e) {
	                        if (!e.code)throw e;
	                        throw new FS.ErrnoError(ERRNO_CODES[e.code])
	                    }
	                }), unlink: (function (parent, name) {
	                    var path = PATH.join2(NODEFS.realPath(parent), name);
	                    try {
	                        fs.unlinkSync(path)
	                    } catch (e) {
	                        if (!e.code)throw e;
	                        throw new FS.ErrnoError(ERRNO_CODES[e.code])
	                    }
	                }), rmdir: (function (parent, name) {
	                    var path = PATH.join2(NODEFS.realPath(parent), name);
	                    try {
	                        fs.rmdirSync(path)
	                    } catch (e) {
	                        if (!e.code)throw e;
	                        throw new FS.ErrnoError(ERRNO_CODES[e.code])
	                    }
	                }), readdir: (function (node) {
	                    var path = NODEFS.realPath(node);
	                    try {
	                        return fs.readdirSync(path)
	                    } catch (e) {
	                        if (!e.code)throw e;
	                        throw new FS.ErrnoError(ERRNO_CODES[e.code])
	                    }
	                }), symlink: (function (parent, newName, oldPath) {
	                    var newPath = PATH.join2(NODEFS.realPath(parent), newName);
	                    try {
	                        fs.symlinkSync(oldPath, newPath)
	                    } catch (e) {
	                        if (!e.code)throw e;
	                        throw new FS.ErrnoError(ERRNO_CODES[e.code])
	                    }
	                }), readlink: (function (node) {
	                    var path = NODEFS.realPath(node);
	                    try {
	                        return fs.readlinkSync(path)
	                    } catch (e) {
	                        if (!e.code)throw e;
	                        throw new FS.ErrnoError(ERRNO_CODES[e.code])
	                    }
	                })
	            },
	            stream_ops: {
	                open: (function (stream) {
	                    var path = NODEFS.realPath(stream.node);
	                    try {
	                        if (FS.isFile(stream.node.mode)) {
	                            stream.nfd = fs.openSync(path, NODEFS.flagsToPermissionString(stream.flags))
	                        }
	                    } catch (e) {
	                        if (!e.code)throw e;
	                        throw new FS.ErrnoError(ERRNO_CODES[e.code])
	                    }
	                }), close: (function (stream) {
	                    try {
	                        if (FS.isFile(stream.node.mode) && stream.nfd) {
	                            fs.closeSync(stream.nfd)
	                        }
	                    } catch (e) {
	                        if (!e.code)throw e;
	                        throw new FS.ErrnoError(ERRNO_CODES[e.code])
	                    }
	                }), read: (function (stream, buffer, offset, length, position) {
	                    if (length === 0)return 0;
	                    var nbuffer = new Buffer(length);
	                    var res;
	                    try {
	                        res = fs.readSync(stream.nfd, nbuffer, 0, length, position)
	                    } catch (e) {
	                        throw new FS.ErrnoError(ERRNO_CODES[e.code])
	                    }
	                    if (res > 0) {
	                        for (var i = 0; i < res; i++) {
	                            buffer[offset + i] = nbuffer[i]
	                        }
	                    }
	                    return res
	                }), write: (function (stream, buffer, offset, length, position) {
	                    var nbuffer = new Buffer(buffer.subarray(offset, offset + length));
	                    var res;
	                    try {
	                        res = fs.writeSync(stream.nfd, nbuffer, 0, length, position)
	                    } catch (e) {
	                        throw new FS.ErrnoError(ERRNO_CODES[e.code])
	                    }
	                    return res
	                }), llseek: (function (stream, offset, whence) {
	                    var position = offset;
	                    if (whence === 1) {
	                        position += stream.position
	                    } else if (whence === 2) {
	                        if (FS.isFile(stream.node.mode)) {
	                            try {
	                                var stat = fs.fstatSync(stream.nfd);
	                                position += stat.size
	                            } catch (e) {
	                                throw new FS.ErrnoError(ERRNO_CODES[e.code])
	                            }
	                        }
	                    }
	                    if (position < 0) {
	                        throw new FS.ErrnoError(ERRNO_CODES.EINVAL)
	                    }
	                    return position
	                })
	            }
	        };
	        var _stdin = allocate(1, "i32*", ALLOC_STATIC);
	        var _stdout = allocate(1, "i32*", ALLOC_STATIC);
	        var _stderr = allocate(1, "i32*", ALLOC_STATIC);

	        function _fflush(stream) {
	        }

	        var FS = {
	            root: null,
	            mounts: [],
	            devices: [null],
	            streams: [],
	            nextInode: 1,
	            nameTable: null,
	            currentPath: "/",
	            initialized: false,
	            ignorePermissions: true,
	            trackingDelegate: {},
	            tracking: {openFlags: {READ: 1, WRITE: 2}},
	            ErrnoError: null,
	            genericErrors: {},
	            handleFSError: (function (e) {
	                if (!(e instanceof FS.ErrnoError))throw e + " : " + stackTrace();
	                return ___setErrNo(e.errno)
	            }),
	            lookupPath: (function (path, opts) {
	                path = PATH.resolve(FS.cwd(), path);
	                opts = opts || {};
	                if (!path)return {path: "", node: null};
	                var defaults = {follow_mount: true, recurse_count: 0};
	                for (var key in defaults) {
	                    if (opts[key] === undefined) {
	                        opts[key] = defaults[key]
	                    }
	                }
	                if (opts.recurse_count > 8) {
	                    throw new FS.ErrnoError(ERRNO_CODES.ELOOP)
	                }
	                var parts = PATH.normalizeArray(path.split("/").filter((function (p) {
	                    return !!p
	                })), false);
	                var current = FS.root;
	                var current_path = "/";
	                for (var i = 0; i < parts.length; i++) {
	                    var islast = i === parts.length - 1;
	                    if (islast && opts.parent) {
	                        break
	                    }
	                    current = FS.lookupNode(current, parts[i]);
	                    current_path = PATH.join2(current_path, parts[i]);
	                    if (FS.isMountpoint(current)) {
	                        if (!islast || islast && opts.follow_mount) {
	                            current = current.mounted.root
	                        }
	                    }
	                    if (!islast || opts.follow) {
	                        var count = 0;
	                        while (FS.isLink(current.mode)) {
	                            var link = FS.readlink(current_path);
	                            current_path = PATH.resolve(PATH.dirname(current_path), link);
	                            var lookup = FS.lookupPath(current_path, {recurse_count: opts.recurse_count});
	                            current = lookup.node;
	                            if (count++ > 40) {
	                                throw new FS.ErrnoError(ERRNO_CODES.ELOOP)
	                            }
	                        }
	                    }
	                }
	                return {path: current_path, node: current}
	            }),
	            getPath: (function (node) {
	                var path;
	                while (true) {
	                    if (FS.isRoot(node)) {
	                        var mount = node.mount.mountpoint;
	                        if (!path)return mount;
	                        return mount[mount.length - 1] !== "/" ? mount + "/" + path : mount + path
	                    }
	                    path = path ? node.name + "/" + path : node.name;
	                    node = node.parent
	                }
	            }),
	            hashName: (function (parentid, name) {
	                var hash = 0;
	                for (var i = 0; i < name.length; i++) {
	                    hash = (hash << 5) - hash + name.charCodeAt(i) | 0
	                }
	                return (parentid + hash >>> 0) % FS.nameTable.length
	            }),
	            hashAddNode: (function (node) {
	                var hash = FS.hashName(node.parent.id, node.name);
	                node.name_next = FS.nameTable[hash];
	                FS.nameTable[hash] = node
	            }),
	            hashRemoveNode: (function (node) {
	                var hash = FS.hashName(node.parent.id, node.name);
	                if (FS.nameTable[hash] === node) {
	                    FS.nameTable[hash] = node.name_next
	                } else {
	                    var current = FS.nameTable[hash];
	                    while (current) {
	                        if (current.name_next === node) {
	                            current.name_next = node.name_next;
	                            break
	                        }
	                        current = current.name_next
	                    }
	                }
	            }),
	            lookupNode: (function (parent, name) {
	                var err = FS.mayLookup(parent);
	                if (err) {
	                    throw new FS.ErrnoError(err, parent)
	                }
	                var hash = FS.hashName(parent.id, name);
	                for (var node = FS.nameTable[hash]; node; node = node.name_next) {
	                    var nodeName = node.name;
	                    if (node.parent.id === parent.id && nodeName === name) {
	                        return node
	                    }
	                }
	                return FS.lookup(parent, name)
	            }),
	            createNode: (function (parent, name, mode, rdev) {
	                if (!FS.FSNode) {
	                    FS.FSNode = (function (parent, name, mode, rdev) {
	                        if (!parent) {
	                            parent = this
	                        }
	                        this.parent = parent;
	                        this.mount = parent.mount;
	                        this.mounted = null;
	                        this.id = FS.nextInode++;
	                        this.name = name;
	                        this.mode = mode;
	                        this.node_ops = {};
	                        this.stream_ops = {};
	                        this.rdev = rdev
	                    });
	                    FS.FSNode.prototype = {};
	                    var readMode = 292 | 73;
	                    var writeMode = 146;
	                    Object.defineProperties(FS.FSNode.prototype, {
	                        read: {
	                            get: (function () {
	                                return (this.mode & readMode) === readMode
	                            }), set: (function (val) {
	                                val ? this.mode |= readMode : this.mode &= ~readMode
	                            })
	                        }, write: {
	                            get: (function () {
	                                return (this.mode & writeMode) === writeMode
	                            }), set: (function (val) {
	                                val ? this.mode |= writeMode : this.mode &= ~writeMode
	                            })
	                        }, isFolder: {
	                            get: (function () {
	                                return FS.isDir(this.mode)
	                            })
	                        }, isDevice: {
	                            get: (function () {
	                                return FS.isChrdev(this.mode)
	                            })
	                        }
	                    })
	                }
	                var node = new FS.FSNode(parent, name, mode, rdev);
	                FS.hashAddNode(node);
	                return node
	            }),
	            destroyNode: (function (node) {
	                FS.hashRemoveNode(node)
	            }),
	            isRoot: (function (node) {
	                return node === node.parent
	            }),
	            isMountpoint: (function (node) {
	                return !!node.mounted
	            }),
	            isFile: (function (mode) {
	                return (mode & 61440) === 32768
	            }),
	            isDir: (function (mode) {
	                return (mode & 61440) === 16384
	            }),
	            isLink: (function (mode) {
	                return (mode & 61440) === 40960
	            }),
	            isChrdev: (function (mode) {
	                return (mode & 61440) === 8192
	            }),
	            isBlkdev: (function (mode) {
	                return (mode & 61440) === 24576
	            }),
	            isFIFO: (function (mode) {
	                return (mode & 61440) === 4096
	            }),
	            isSocket: (function (mode) {
	                return (mode & 49152) === 49152
	            }),
	            flagModes: {
	                "r": 0,
	                "rs": 1052672,
	                "r+": 2,
	                "w": 577,
	                "wx": 705,
	                "xw": 705,
	                "w+": 578,
	                "wx+": 706,
	                "xw+": 706,
	                "a": 1089,
	                "ax": 1217,
	                "xa": 1217,
	                "a+": 1090,
	                "ax+": 1218,
	                "xa+": 1218
	            },
	            modeStringToFlags: (function (str) {
	                var flags = FS.flagModes[str];
	                if (typeof flags === "undefined") {
	                    throw new Error("Unknown file open mode: " + str)
	                }
	                return flags
	            }),
	            flagsToPermissionString: (function (flag) {
	                var accmode = flag & 2097155;
	                var perms = ["r", "w", "rw"][accmode];
	                if (flag & 512) {
	                    perms += "w"
	                }
	                return perms
	            }),
	            nodePermissions: (function (node, perms) {
	                if (FS.ignorePermissions) {
	                    return 0
	                }
	                if (perms.indexOf("r") !== -1 && !(node.mode & 292)) {
	                    return ERRNO_CODES.EACCES
	                } else if (perms.indexOf("w") !== -1 && !(node.mode & 146)) {
	                    return ERRNO_CODES.EACCES
	                } else if (perms.indexOf("x") !== -1 && !(node.mode & 73)) {
	                    return ERRNO_CODES.EACCES
	                }
	                return 0
	            }),
	            mayLookup: (function (dir) {
	                var err = FS.nodePermissions(dir, "x");
	                if (err)return err;
	                if (!dir.node_ops.lookup)return ERRNO_CODES.EACCES;
	                return 0
	            }),
	            mayCreate: (function (dir, name) {
	                try {
	                    var node = FS.lookupNode(dir, name);
	                    return ERRNO_CODES.EEXIST
	                } catch (e) {
	                }
	                return FS.nodePermissions(dir, "wx")
	            }),
	            mayDelete: (function (dir, name, isdir) {
	                var node;
	                try {
	                    node = FS.lookupNode(dir, name)
	                } catch (e) {
	                    return e.errno
	                }
	                var err = FS.nodePermissions(dir, "wx");
	                if (err) {
	                    return err
	                }
	                if (isdir) {
	                    if (!FS.isDir(node.mode)) {
	                        return ERRNO_CODES.ENOTDIR
	                    }
	                    if (FS.isRoot(node) || FS.getPath(node) === FS.cwd()) {
	                        return ERRNO_CODES.EBUSY
	                    }
	                } else {
	                    if (FS.isDir(node.mode)) {
	                        return ERRNO_CODES.EISDIR
	                    }
	                }
	                return 0
	            }),
	            mayOpen: (function (node, flags) {
	                if (!node) {
	                    return ERRNO_CODES.ENOENT
	                }
	                if (FS.isLink(node.mode)) {
	                    return ERRNO_CODES.ELOOP
	                } else if (FS.isDir(node.mode)) {
	                    if ((flags & 2097155) !== 0 || flags & 512) {
	                        return ERRNO_CODES.EISDIR
	                    }
	                }
	                return FS.nodePermissions(node, FS.flagsToPermissionString(flags))
	            }),
	            MAX_OPEN_FDS: 4096,
	            nextfd: (function (fd_start, fd_end) {
	                fd_start = fd_start || 0;
	                fd_end = fd_end || FS.MAX_OPEN_FDS;
	                for (var fd = fd_start; fd <= fd_end; fd++) {
	                    if (!FS.streams[fd]) {
	                        return fd
	                    }
	                }
	                throw new FS.ErrnoError(ERRNO_CODES.EMFILE)
	            }),
	            getStream: (function (fd) {
	                return FS.streams[fd]
	            }),
	            createStream: (function (stream, fd_start, fd_end) {
	                if (!FS.FSStream) {
	                    FS.FSStream = (function () {
	                    });
	                    FS.FSStream.prototype = {};
	                    Object.defineProperties(FS.FSStream.prototype, {
	                        object: {
	                            get: (function () {
	                                return this.node
	                            }), set: (function (val) {
	                                this.node = val
	                            })
	                        }, isRead: {
	                            get: (function () {
	                                return (this.flags & 2097155) !== 1
	                            })
	                        }, isWrite: {
	                            get: (function () {
	                                return (this.flags & 2097155) !== 0
	                            })
	                        }, isAppend: {
	                            get: (function () {
	                                return this.flags & 1024
	                            })
	                        }
	                    })
	                }
	                var newStream = new FS.FSStream;
	                for (var p in stream) {
	                    newStream[p] = stream[p]
	                }
	                stream = newStream;
	                var fd = FS.nextfd(fd_start, fd_end);
	                stream.fd = fd;
	                FS.streams[fd] = stream;
	                return stream
	            }),
	            closeStream: (function (fd) {
	                FS.streams[fd] = null
	            }),
	            getStreamFromPtr: (function (ptr) {
	                return FS.streams[ptr - 1]
	            }),
	            getPtrForStream: (function (stream) {
	                return stream ? stream.fd + 1 : 0
	            }),
	            chrdev_stream_ops: {
	                open: (function (stream) {
	                    var device = FS.getDevice(stream.node.rdev);
	                    stream.stream_ops = device.stream_ops;
	                    if (stream.stream_ops.open) {
	                        stream.stream_ops.open(stream)
	                    }
	                }), llseek: (function () {
	                    throw new FS.ErrnoError(ERRNO_CODES.ESPIPE)
	                })
	            },
	            major: (function (dev) {
	                return dev >> 8
	            }),
	            minor: (function (dev) {
	                return dev & 255
	            }),
	            makedev: (function (ma, mi) {
	                return ma << 8 | mi
	            }),
	            registerDevice: (function (dev, ops) {
	                FS.devices[dev] = {stream_ops: ops}
	            }),
	            getDevice: (function (dev) {
	                return FS.devices[dev]
	            }),
	            getMounts: (function (mount) {
	                var mounts = [];
	                var check = [mount];
	                while (check.length) {
	                    var m = check.pop();
	                    mounts.push(m);
	                    check.push.apply(check, m.mounts)
	                }
	                return mounts
	            }),
	            syncfs: (function (populate, callback) {
	                if (typeof populate === "function") {
	                    callback = populate;
	                    populate = false
	                }
	                var mounts = FS.getMounts(FS.root.mount);
	                var completed = 0;

	                function done(err) {
	                    if (err) {
	                        if (!done.errored) {
	                            done.errored = true;
	                            return callback(err)
	                        }
	                        return
	                    }
	                    if (++completed >= mounts.length) {
	                        callback(null)
	                    }
	                }

	                mounts.forEach((function (mount) {
	                    if (!mount.type.syncfs) {
	                        return done(null)
	                    }
	                    mount.type.syncfs(mount, populate, done)
	                }))
	            }),
	            mount: (function (type, opts, mountpoint) {
	                var root = mountpoint === "/";
	                var pseudo = !mountpoint;
	                var node;
	                if (root && FS.root) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EBUSY)
	                } else if (!root && !pseudo) {
	                    var lookup = FS.lookupPath(mountpoint, {follow_mount: false});
	                    mountpoint = lookup.path;
	                    node = lookup.node;
	                    if (FS.isMountpoint(node)) {
	                        throw new FS.ErrnoError(ERRNO_CODES.EBUSY)
	                    }
	                    if (!FS.isDir(node.mode)) {
	                        throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR)
	                    }
	                }
	                var mount = {type: type, opts: opts, mountpoint: mountpoint, mounts: []};
	                var mountRoot = type.mount(mount);
	                mountRoot.mount = mount;
	                mount.root = mountRoot;
	                if (root) {
	                    FS.root = mountRoot
	                } else if (node) {
	                    node.mounted = mount;
	                    if (node.mount) {
	                        node.mount.mounts.push(mount)
	                    }
	                }
	                return mountRoot
	            }),
	            unmount: (function (mountpoint) {
	                var lookup = FS.lookupPath(mountpoint, {follow_mount: false});
	                if (!FS.isMountpoint(lookup.node)) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EINVAL)
	                }
	                var node = lookup.node;
	                var mount = node.mounted;
	                var mounts = FS.getMounts(mount);
	                Object.keys(FS.nameTable).forEach((function (hash) {
	                    var current = FS.nameTable[hash];
	                    while (current) {
	                        var next = current.name_next;
	                        if (mounts.indexOf(current.mount) !== -1) {
	                            FS.destroyNode(current)
	                        }
	                        current = next
	                    }
	                }));
	                node.mounted = null;
	                var idx = node.mount.mounts.indexOf(mount);
	                assert(idx !== -1);
	                node.mount.mounts.splice(idx, 1)
	            }),
	            lookup: (function (parent, name) {
	                return parent.node_ops.lookup(parent, name)
	            }),
	            mknod: (function (path, mode, dev) {
	                var lookup = FS.lookupPath(path, {parent: true});
	                var parent = lookup.node;
	                var name = PATH.basename(path);
	                if (!name || name === "." || name === "..") {
	                    throw new FS.ErrnoError(ERRNO_CODES.EINVAL)
	                }
	                var err = FS.mayCreate(parent, name);
	                if (err) {
	                    throw new FS.ErrnoError(err)
	                }
	                if (!parent.node_ops.mknod) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EPERM)
	                }
	                return parent.node_ops.mknod(parent, name, mode, dev)
	            }),
	            create: (function (path, mode) {
	                mode = mode !== undefined ? mode : 438;
	                mode &= 4095;
	                mode |= 32768;
	                return FS.mknod(path, mode, 0)
	            }),
	            mkdir: (function (path, mode) {
	                mode = mode !== undefined ? mode : 511;
	                mode &= 511 | 512;
	                mode |= 16384;
	                return FS.mknod(path, mode, 0)
	            }),
	            mkdev: (function (path, mode, dev) {
	                if (typeof dev === "undefined") {
	                    dev = mode;
	                    mode = 438
	                }
	                mode |= 8192;
	                return FS.mknod(path, mode, dev)
	            }),
	            symlink: (function (oldpath, newpath) {
	                if (!PATH.resolve(oldpath)) {
	                    throw new FS.ErrnoError(ERRNO_CODES.ENOENT)
	                }
	                var lookup = FS.lookupPath(newpath, {parent: true});
	                var parent = lookup.node;
	                if (!parent) {
	                    throw new FS.ErrnoError(ERRNO_CODES.ENOENT)
	                }
	                var newname = PATH.basename(newpath);
	                var err = FS.mayCreate(parent, newname);
	                if (err) {
	                    throw new FS.ErrnoError(err)
	                }
	                if (!parent.node_ops.symlink) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EPERM)
	                }
	                return parent.node_ops.symlink(parent, newname, oldpath)
	            }),
	            rename: (function (old_path, new_path) {
	                var old_dirname = PATH.dirname(old_path);
	                var new_dirname = PATH.dirname(new_path);
	                var old_name = PATH.basename(old_path);
	                var new_name = PATH.basename(new_path);
	                var lookup, old_dir, new_dir;
	                try {
	                    lookup = FS.lookupPath(old_path, {parent: true});
	                    old_dir = lookup.node;
	                    lookup = FS.lookupPath(new_path, {parent: true});
	                    new_dir = lookup.node
	                } catch (e) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EBUSY)
	                }
	                if (!old_dir || !new_dir)throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
	                if (old_dir.mount !== new_dir.mount) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EXDEV)
	                }
	                var old_node = FS.lookupNode(old_dir, old_name);
	                var relative = PATH.relative(old_path, new_dirname);
	                if (relative.charAt(0) !== ".") {
	                    throw new FS.ErrnoError(ERRNO_CODES.EINVAL)
	                }
	                relative = PATH.relative(new_path, old_dirname);
	                if (relative.charAt(0) !== ".") {
	                    throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY)
	                }
	                var new_node;
	                try {
	                    new_node = FS.lookupNode(new_dir, new_name)
	                } catch (e) {
	                }
	                if (old_node === new_node) {
	                    return
	                }
	                var isdir = FS.isDir(old_node.mode);
	                var err = FS.mayDelete(old_dir, old_name, isdir);
	                if (err) {
	                    throw new FS.ErrnoError(err)
	                }
	                err = new_node ? FS.mayDelete(new_dir, new_name, isdir) : FS.mayCreate(new_dir, new_name);
	                if (err) {
	                    throw new FS.ErrnoError(err)
	                }
	                if (!old_dir.node_ops.rename) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EPERM)
	                }
	                if (FS.isMountpoint(old_node) || new_node && FS.isMountpoint(new_node)) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EBUSY)
	                }
	                if (new_dir !== old_dir) {
	                    err = FS.nodePermissions(old_dir, "w");
	                    if (err) {
	                        throw new FS.ErrnoError(err)
	                    }
	                }
	                try {
	                    if (FS.trackingDelegate["willMovePath"]) {
	                        FS.trackingDelegate["willMovePath"](old_path, new_path)
	                    }
	                } catch (e) {
	                    console.log("FS.trackingDelegate['willMovePath']('" + old_path + "', '" + new_path + "') threw an exception: " + e.message)
	                }
	                FS.hashRemoveNode(old_node);
	                try {
	                    old_dir.node_ops.rename(old_node, new_dir, new_name)
	                } catch (e) {
	                    throw e
	                } finally {
	                    FS.hashAddNode(old_node)
	                }
	                try {
	                    if (FS.trackingDelegate["onMovePath"])FS.trackingDelegate["onMovePath"](old_path, new_path)
	                } catch (e) {
	                    console.log("FS.trackingDelegate['onMovePath']('" + old_path + "', '" + new_path + "') threw an exception: " + e.message)
	                }
	            }),
	            rmdir: (function (path) {
	                var lookup = FS.lookupPath(path, {parent: true});
	                var parent = lookup.node;
	                var name = PATH.basename(path);
	                var node = FS.lookupNode(parent, name);
	                var err = FS.mayDelete(parent, name, true);
	                if (err) {
	                    throw new FS.ErrnoError(err)
	                }
	                if (!parent.node_ops.rmdir) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EPERM)
	                }
	                if (FS.isMountpoint(node)) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EBUSY)
	                }
	                try {
	                    if (FS.trackingDelegate["willDeletePath"]) {
	                        FS.trackingDelegate["willDeletePath"](path)
	                    }
	                } catch (e) {
	                    console.log("FS.trackingDelegate['willDeletePath']('" + path + "') threw an exception: " + e.message)
	                }
	                parent.node_ops.rmdir(parent, name);
	                FS.destroyNode(node);
	                try {
	                    if (FS.trackingDelegate["onDeletePath"])FS.trackingDelegate["onDeletePath"](path)
	                } catch (e) {
	                    console.log("FS.trackingDelegate['onDeletePath']('" + path + "') threw an exception: " + e.message)
	                }
	            }),
	            readdir: (function (path) {
	                var lookup = FS.lookupPath(path, {follow: true});
	                var node = lookup.node;
	                if (!node.node_ops.readdir) {
	                    throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR)
	                }
	                return node.node_ops.readdir(node)
	            }),
	            unlink: (function (path) {
	                var lookup = FS.lookupPath(path, {parent: true});
	                var parent = lookup.node;
	                var name = PATH.basename(path);
	                var node = FS.lookupNode(parent, name);
	                var err = FS.mayDelete(parent, name, false);
	                if (err) {
	                    if (err === ERRNO_CODES.EISDIR)err = ERRNO_CODES.EPERM;
	                    throw new FS.ErrnoError(err)
	                }
	                if (!parent.node_ops.unlink) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EPERM)
	                }
	                if (FS.isMountpoint(node)) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EBUSY)
	                }
	                try {
	                    if (FS.trackingDelegate["willDeletePath"]) {
	                        FS.trackingDelegate["willDeletePath"](path)
	                    }
	                } catch (e) {
	                    console.log("FS.trackingDelegate['willDeletePath']('" + path + "') threw an exception: " + e.message)
	                }
	                parent.node_ops.unlink(parent, name);
	                FS.destroyNode(node);
	                try {
	                    if (FS.trackingDelegate["onDeletePath"])FS.trackingDelegate["onDeletePath"](path)
	                } catch (e) {
	                    console.log("FS.trackingDelegate['onDeletePath']('" + path + "') threw an exception: " + e.message)
	                }
	            }),
	            readlink: (function (path) {
	                var lookup = FS.lookupPath(path);
	                var link = lookup.node;
	                if (!link) {
	                    throw new FS.ErrnoError(ERRNO_CODES.ENOENT)
	                }
	                if (!link.node_ops.readlink) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EINVAL)
	                }
	                return link.node_ops.readlink(link)
	            }),
	            stat: (function (path, dontFollow) {
	                var lookup = FS.lookupPath(path, {follow: !dontFollow});
	                var node = lookup.node;
	                if (!node) {
	                    throw new FS.ErrnoError(ERRNO_CODES.ENOENT)
	                }
	                if (!node.node_ops.getattr) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EPERM)
	                }
	                return node.node_ops.getattr(node)
	            }),
	            lstat: (function (path) {
	                return FS.stat(path, true)
	            }),
	            chmod: (function (path, mode, dontFollow) {
	                var node;
	                if (typeof path === "string") {
	                    var lookup = FS.lookupPath(path, {follow: !dontFollow});
	                    node = lookup.node
	                } else {
	                    node = path
	                }
	                if (!node.node_ops.setattr) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EPERM)
	                }
	                node.node_ops.setattr(node, {mode: mode & 4095 | node.mode & ~4095, timestamp: Date.now()})
	            }),
	            lchmod: (function (path, mode) {
	                FS.chmod(path, mode, true)
	            }),
	            fchmod: (function (fd, mode) {
	                var stream = FS.getStream(fd);
	                if (!stream) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EBADF)
	                }
	                FS.chmod(stream.node, mode)
	            }),
	            chown: (function (path, uid, gid, dontFollow) {
	                var node;
	                if (typeof path === "string") {
	                    var lookup = FS.lookupPath(path, {follow: !dontFollow});
	                    node = lookup.node
	                } else {
	                    node = path
	                }
	                if (!node.node_ops.setattr) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EPERM)
	                }
	                node.node_ops.setattr(node, {timestamp: Date.now()})
	            }),
	            lchown: (function (path, uid, gid) {
	                FS.chown(path, uid, gid, true)
	            }),
	            fchown: (function (fd, uid, gid) {
	                var stream = FS.getStream(fd);
	                if (!stream) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EBADF)
	                }
	                FS.chown(stream.node, uid, gid)
	            }),
	            truncate: (function (path, len) {
	                if (len < 0) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EINVAL)
	                }
	                var node;
	                if (typeof path === "string") {
	                    var lookup = FS.lookupPath(path, {follow: true});
	                    node = lookup.node
	                } else {
	                    node = path
	                }
	                if (!node.node_ops.setattr) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EPERM)
	                }
	                if (FS.isDir(node.mode)) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EISDIR)
	                }
	                if (!FS.isFile(node.mode)) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EINVAL)
	                }
	                var err = FS.nodePermissions(node, "w");
	                if (err) {
	                    throw new FS.ErrnoError(err)
	                }
	                node.node_ops.setattr(node, {size: len, timestamp: Date.now()})
	            }),
	            ftruncate: (function (fd, len) {
	                var stream = FS.getStream(fd);
	                if (!stream) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EBADF)
	                }
	                if ((stream.flags & 2097155) === 0) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EINVAL)
	                }
	                FS.truncate(stream.node, len)
	            }),
	            utime: (function (path, atime, mtime) {
	                var lookup = FS.lookupPath(path, {follow: true});
	                var node = lookup.node;
	                node.node_ops.setattr(node, {timestamp: Math.max(atime, mtime)})
	            }),
	            open: (function (path, flags, mode, fd_start, fd_end) {
	                if (path === "") {
	                    throw new FS.ErrnoError(ERRNO_CODES.ENOENT)
	                }
	                flags = typeof flags === "string" ? FS.modeStringToFlags(flags) : flags;
	                mode = typeof mode === "undefined" ? 438 : mode;
	                if (flags & 64) {
	                    mode = mode & 4095 | 32768
	                } else {
	                    mode = 0
	                }
	                var node;
	                if (typeof path === "object") {
	                    node = path
	                } else {
	                    path = PATH.normalize(path);
	                    try {
	                        var lookup = FS.lookupPath(path, {follow: !(flags & 131072)});
	                        node = lookup.node
	                    } catch (e) {
	                    }
	                }
	                var created = false;
	                if (flags & 64) {
	                    if (node) {
	                        if (flags & 128) {
	                            throw new FS.ErrnoError(ERRNO_CODES.EEXIST)
	                        }
	                    } else {
	                        node = FS.mknod(path, mode, 0);
	                        created = true
	                    }
	                }
	                if (!node) {
	                    throw new FS.ErrnoError(ERRNO_CODES.ENOENT)
	                }
	                if (FS.isChrdev(node.mode)) {
	                    flags &= ~512
	                }
	                if (!created) {
	                    var err = FS.mayOpen(node, flags);
	                    if (err) {
	                        throw new FS.ErrnoError(err)
	                    }
	                }
	                if (flags & 512) {
	                    FS.truncate(node, 0)
	                }
	                flags &= ~(128 | 512);
	                var stream = FS.createStream({
	                    node: node,
	                    path: FS.getPath(node),
	                    flags: flags,
	                    seekable: true,
	                    position: 0,
	                    stream_ops: node.stream_ops,
	                    ungotten: [],
	                    error: false
	                }, fd_start, fd_end);
	                if (stream.stream_ops.open) {
	                    stream.stream_ops.open(stream)
	                }
	                if (Module["logReadFiles"] && !(flags & 1)) {
	                    if (!FS.readFiles)FS.readFiles = {};
	                    if (!(path in FS.readFiles)) {
	                        FS.readFiles[path] = 1;
	                        Module["printErr"]("read file: " + path)
	                    }
	                }
	                try {
	                    if (FS.trackingDelegate["onOpenFile"]) {
	                        var trackingFlags = 0;
	                        if ((flags & 2097155) !== 1) {
	                            trackingFlags |= FS.tracking.openFlags.READ
	                        }
	                        if ((flags & 2097155) !== 0) {
	                            trackingFlags |= FS.tracking.openFlags.WRITE
	                        }
	                        FS.trackingDelegate["onOpenFile"](path, trackingFlags)
	                    }
	                } catch (e) {
	                    console.log("FS.trackingDelegate['onOpenFile']('" + path + "', flags) threw an exception: " + e.message)
	                }
	                return stream
	            }),
	            close: (function (stream) {
	                try {
	                    if (stream.stream_ops.close) {
	                        stream.stream_ops.close(stream)
	                    }
	                } catch (e) {
	                    throw e
	                } finally {
	                    FS.closeStream(stream.fd)
	                }
	            }),
	            llseek: (function (stream, offset, whence) {
	                if (!stream.seekable || !stream.stream_ops.llseek) {
	                    throw new FS.ErrnoError(ERRNO_CODES.ESPIPE)
	                }
	                stream.position = stream.stream_ops.llseek(stream, offset, whence);
	                stream.ungotten = [];
	                return stream.position
	            }),
	            read: (function (stream, buffer, offset, length, position) {
	                if (length < 0 || position < 0) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EINVAL)
	                }
	                if ((stream.flags & 2097155) === 1) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EBADF)
	                }
	                if (FS.isDir(stream.node.mode)) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EISDIR)
	                }
	                if (!stream.stream_ops.read) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EINVAL)
	                }
	                var seeking = true;
	                if (typeof position === "undefined") {
	                    position = stream.position;
	                    seeking = false
	                } else if (!stream.seekable) {
	                    throw new FS.ErrnoError(ERRNO_CODES.ESPIPE)
	                }
	                var bytesRead = stream.stream_ops.read(stream, buffer, offset, length, position);
	                if (!seeking)stream.position += bytesRead;
	                return bytesRead
	            }),
	            write: (function (stream, buffer, offset, length, position, canOwn) {
	                if (length < 0 || position < 0) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EINVAL)
	                }
	                if ((stream.flags & 2097155) === 0) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EBADF)
	                }
	                if (FS.isDir(stream.node.mode)) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EISDIR)
	                }
	                if (!stream.stream_ops.write) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EINVAL)
	                }
	                if (stream.flags & 1024) {
	                    FS.llseek(stream, 0, 2)
	                }
	                var seeking = true;
	                if (typeof position === "undefined") {
	                    position = stream.position;
	                    seeking = false
	                } else if (!stream.seekable) {
	                    throw new FS.ErrnoError(ERRNO_CODES.ESPIPE)
	                }
	                var bytesWritten = stream.stream_ops.write(stream, buffer, offset, length, position, canOwn);
	                if (!seeking)stream.position += bytesWritten;
	                try {
	                    if (stream.path && FS.trackingDelegate["onWriteToFile"])FS.trackingDelegate["onWriteToFile"](stream.path)
	                } catch (e) {
	                    console.log("FS.trackingDelegate['onWriteToFile']('" + path + "') threw an exception: " + e.message)
	                }
	                return bytesWritten
	            }),
	            allocate: (function (stream, offset, length) {
	                if (offset < 0 || length <= 0) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EINVAL)
	                }
	                if ((stream.flags & 2097155) === 0) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EBADF)
	                }
	                if (!FS.isFile(stream.node.mode) && !FS.isDir(node.mode)) {
	                    throw new FS.ErrnoError(ERRNO_CODES.ENODEV)
	                }
	                if (!stream.stream_ops.allocate) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP)
	                }
	                stream.stream_ops.allocate(stream, offset, length)
	            }),
	            mmap: (function (stream, buffer, offset, length, position, prot, flags) {
	                if ((stream.flags & 2097155) === 1) {
	                    throw new FS.ErrnoError(ERRNO_CODES.EACCES)
	                }
	                if (!stream.stream_ops.mmap) {
	                    throw new FS.ErrnoError(ERRNO_CODES.ENODEV)
	                }
	                return stream.stream_ops.mmap(stream, buffer, offset, length, position, prot, flags)
	            }),
	            ioctl: (function (stream, cmd, arg) {
	                if (!stream.stream_ops.ioctl) {
	                    throw new FS.ErrnoError(ERRNO_CODES.ENOTTY)
	                }
	                return stream.stream_ops.ioctl(stream, cmd, arg)
	            }),
	            readFile: (function (path, opts) {
	                opts = opts || {};
	                opts.flags = opts.flags || "r";
	                opts.encoding = opts.encoding || "binary";
	                if (opts.encoding !== "utf8" && opts.encoding !== "binary") {
	                    throw new Error('Invalid encoding type "' + opts.encoding + '"')
	                }
	                var ret;
	                var stream = FS.open(path, opts.flags);
	                var stat = FS.stat(path);
	                var length = stat.size;
	                var buf = new Uint8Array(length);
	                FS.read(stream, buf, 0, length, 0);
	                if (opts.encoding === "utf8") {
	                    ret = "";
	                    var utf8 = new Runtime.UTF8Processor;
	                    for (var i = 0; i < length; i++) {
	                        ret += utf8.processCChar(buf[i])
	                    }
	                } else if (opts.encoding === "binary") {
	                    ret = buf
	                }
	                FS.close(stream);
	                return ret
	            }),
	            writeFile: (function (path, data, opts) {
	                opts = opts || {};
	                opts.flags = opts.flags || "w";
	                opts.encoding = opts.encoding || "utf8";
	                if (opts.encoding !== "utf8" && opts.encoding !== "binary") {
	                    throw new Error('Invalid encoding type "' + opts.encoding + '"')
	                }
	                var stream = FS.open(path, opts.flags, opts.mode);
	                if (opts.encoding === "utf8") {
	                    var utf8 = new Runtime.UTF8Processor;
	                    var buf = new Uint8Array(utf8.processJSString(data));
	                    FS.write(stream, buf, 0, buf.length, 0, opts.canOwn)
	                } else if (opts.encoding === "binary") {
	                    FS.write(stream, data, 0, data.length, 0, opts.canOwn)
	                }
	                FS.close(stream)
	            }),
	            cwd: (function () {
	                return FS.currentPath
	            }),
	            chdir: (function (path) {
	                var lookup = FS.lookupPath(path, {follow: true});
	                if (!FS.isDir(lookup.node.mode)) {
	                    throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR)
	                }
	                var err = FS.nodePermissions(lookup.node, "x");
	                if (err) {
	                    throw new FS.ErrnoError(err)
	                }
	                FS.currentPath = lookup.path
	            }),
	            createDefaultDirectories: (function () {
	                FS.mkdir("/tmp");
	                FS.mkdir("/home");
	                FS.mkdir("/home/web_user")
	            }),
	            createDefaultDevices: (function () {
	                FS.mkdir("/dev");
	                FS.registerDevice(FS.makedev(1, 3), {
	                    read: (function () {
	                        return 0
	                    }), write: (function () {
	                        return 0
	                    })
	                });
	                FS.mkdev("/dev/null", FS.makedev(1, 3));
	                TTY.register(FS.makedev(5, 0), TTY.default_tty_ops);
	                TTY.register(FS.makedev(6, 0), TTY.default_tty1_ops);
	                FS.mkdev("/dev/tty", FS.makedev(5, 0));
	                FS.mkdev("/dev/tty1", FS.makedev(6, 0));
	                var random_device;
	                if (typeof crypto !== "undefined") {
	                    var randomBuffer = new Uint8Array(1);
	                    random_device = (function () {
	                        crypto.getRandomValues(randomBuffer);
	                        return randomBuffer[0]
	                    })
	                } else {
	                    random_device = (function () {
	                        return Math.random() * 256 | 0
	                    })
	                }
	                FS.createDevice("/dev", "random", random_device);
	                FS.createDevice("/dev", "urandom", random_device);
	                FS.mkdir("/dev/shm");
	                FS.mkdir("/dev/shm/tmp")
	            }),
	            createStandardStreams: (function () {
	                if (Module["stdin"]) {
	                    FS.createDevice("/dev", "stdin", Module["stdin"])
	                } else {
	                    FS.symlink("/dev/tty", "/dev/stdin")
	                }
	                if (Module["stdout"]) {
	                    FS.createDevice("/dev", "stdout", null, Module["stdout"])
	                } else {
	                    FS.symlink("/dev/tty", "/dev/stdout")
	                }
	                if (Module["stderr"]) {
	                    FS.createDevice("/dev", "stderr", null, Module["stderr"])
	                } else {
	                    FS.symlink("/dev/tty1", "/dev/stderr")
	                }
	                var stdin = FS.open("/dev/stdin", "r");
	                HEAP32[_stdin >> 2] = FS.getPtrForStream(stdin);
	                assert(stdin.fd === 0, "invalid handle for stdin (" + stdin.fd + ")");
	                var stdout = FS.open("/dev/stdout", "w");
	                HEAP32[_stdout >> 2] = FS.getPtrForStream(stdout);
	                assert(stdout.fd === 1, "invalid handle for stdout (" + stdout.fd + ")");
	                var stderr = FS.open("/dev/stderr", "w");
	                HEAP32[_stderr >> 2] = FS.getPtrForStream(stderr);
	                assert(stderr.fd === 2, "invalid handle for stderr (" + stderr.fd + ")")
	            }),
	            ensureErrnoError: (function () {
	                if (FS.ErrnoError)return;
	                FS.ErrnoError = function ErrnoError(errno, node) {
	                    this.node = node;
	                    this.setErrno = (function (errno) {
	                        this.errno = errno;
	                        for (var key in ERRNO_CODES) {
	                            if (ERRNO_CODES[key] === errno) {
	                                this.code = key;
	                                break
	                            }
	                        }
	                    });
	                    this.setErrno(errno);
	                    this.message = ERRNO_MESSAGES[errno]
	                };
	                FS.ErrnoError.prototype = new Error;
	                FS.ErrnoError.prototype.constructor = FS.ErrnoError;
	                [ERRNO_CODES.ENOENT].forEach((function (code) {
	                    FS.genericErrors[code] = new FS.ErrnoError(code);
	                    FS.genericErrors[code].stack = "<generic error, no stack>"
	                }))
	            }),
	            staticInit: (function () {
	                FS.ensureErrnoError();
	                FS.nameTable = new Array(4096);
	                FS.mount(MEMFS, {}, "/");
	                FS.createDefaultDirectories();
	                FS.createDefaultDevices()
	            }),
	            init: (function (input, output, error) {
	                assert(!FS.init.initialized, "FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)");
	                FS.init.initialized = true;
	                FS.ensureErrnoError();
	                Module["stdin"] = input || Module["stdin"];
	                Module["stdout"] = output || Module["stdout"];
	                Module["stderr"] = error || Module["stderr"];
	                FS.createStandardStreams()
	            }),
	            quit: (function () {
	                FS.init.initialized = false;
	                for (var i = 0; i < FS.streams.length; i++) {
	                    var stream = FS.streams[i];
	                    if (!stream) {
	                        continue
	                    }
	                    FS.close(stream)
	                }
	            }),
	            getMode: (function (canRead, canWrite) {
	                var mode = 0;
	                if (canRead)mode |= 292 | 73;
	                if (canWrite)mode |= 146;
	                return mode
	            }),
	            joinPath: (function (parts, forceRelative) {
	                var path = PATH.join.apply(null, parts);
	                if (forceRelative && path[0] == "/")path = path.substr(1);
	                return path
	            }),
	            absolutePath: (function (relative, base) {
	                return PATH.resolve(base, relative)
	            }),
	            standardizePath: (function (path) {
	                return PATH.normalize(path)
	            }),
	            findObject: (function (path, dontResolveLastLink) {
	                var ret = FS.analyzePath(path, dontResolveLastLink);
	                if (ret.exists) {
	                    return ret.object
	                } else {
	                    ___setErrNo(ret.error);
	                    return null
	                }
	            }),
	            analyzePath: (function (path, dontResolveLastLink) {
	                try {
	                    var lookup = FS.lookupPath(path, {follow: !dontResolveLastLink});
	                    path = lookup.path
	                } catch (e) {
	                }
	                var ret = {
	                    isRoot: false,
	                    exists: false,
	                    error: 0,
	                    name: null,
	                    path: null,
	                    object: null,
	                    parentExists: false,
	                    parentPath: null,
	                    parentObject: null
	                };
	                try {
	                    var lookup = FS.lookupPath(path, {parent: true});
	                    ret.parentExists = true;
	                    ret.parentPath = lookup.path;
	                    ret.parentObject = lookup.node;
	                    ret.name = PATH.basename(path);
	                    lookup = FS.lookupPath(path, {follow: !dontResolveLastLink});
	                    ret.exists = true;
	                    ret.path = lookup.path;
	                    ret.object = lookup.node;
	                    ret.name = lookup.node.name;
	                    ret.isRoot = lookup.path === "/"
	                } catch (e) {
	                    ret.error = e.errno
	                }
	                return ret
	            }),
	            createFolder: (function (parent, name, canRead, canWrite) {
	                var path = PATH.join2(typeof parent === "string" ? parent : FS.getPath(parent), name);
	                var mode = FS.getMode(canRead, canWrite);
	                return FS.mkdir(path, mode)
	            }),
	            createPath: (function (parent, path, canRead, canWrite) {
	                parent = typeof parent === "string" ? parent : FS.getPath(parent);
	                var parts = path.split("/").reverse();
	                while (parts.length) {
	                    var part = parts.pop();
	                    if (!part)continue;
	                    var current = PATH.join2(parent, part);
	                    try {
	                        FS.mkdir(current)
	                    } catch (e) {
	                    }
	                    parent = current
	                }
	                return current
	            }),
	            createFile: (function (parent, name, properties, canRead, canWrite) {
	                var path = PATH.join2(typeof parent === "string" ? parent : FS.getPath(parent), name);
	                var mode = FS.getMode(canRead, canWrite);
	                return FS.create(path, mode)
	            }),
	            createDataFile: (function (parent, name, data, canRead, canWrite, canOwn) {
	                var path = name ? PATH.join2(typeof parent === "string" ? parent : FS.getPath(parent), name) : parent;
	                var mode = FS.getMode(canRead, canWrite);
	                var node = FS.create(path, mode);
	                if (data) {
	                    if (typeof data === "string") {
	                        var arr = new Array(data.length);
	                        for (var i = 0, len = data.length; i < len; ++i)arr[i] = data.charCodeAt(i);
	                        data = arr
	                    }
	                    FS.chmod(node, mode | 146);
	                    var stream = FS.open(node, "w");
	                    FS.write(stream, data, 0, data.length, 0, canOwn);
	                    FS.close(stream);
	                    FS.chmod(node, mode)
	                }
	                return node
	            }),
	            createDevice: (function (parent, name, input, output) {
	                var path = PATH.join2(typeof parent === "string" ? parent : FS.getPath(parent), name);
	                var mode = FS.getMode(!!input, !!output);
	                if (!FS.createDevice.major)FS.createDevice.major = 64;
	                var dev = FS.makedev(FS.createDevice.major++, 0);
	                FS.registerDevice(dev, {
	                    open: (function (stream) {
	                        stream.seekable = false
	                    }), close: (function (stream) {
	                        if (output && output.buffer && output.buffer.length) {
	                            output(10)
	                        }
	                    }), read: (function (stream, buffer, offset, length, pos) {
	                        var bytesRead = 0;
	                        for (var i = 0; i < length; i++) {
	                            var result;
	                            try {
	                                result = input()
	                            } catch (e) {
	                                throw new FS.ErrnoError(ERRNO_CODES.EIO)
	                            }
	                            if (result === undefined && bytesRead === 0) {
	                                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN)
	                            }
	                            if (result === null || result === undefined)break;
	                            bytesRead++;
	                            buffer[offset + i] = result
	                        }
	                        if (bytesRead) {
	                            stream.node.timestamp = Date.now()
	                        }
	                        return bytesRead
	                    }), write: (function (stream, buffer, offset, length, pos) {
	                        for (var i = 0; i < length; i++) {
	                            try {
	                                output(buffer[offset + i])
	                            } catch (e) {
	                                throw new FS.ErrnoError(ERRNO_CODES.EIO)
	                            }
	                        }
	                        if (length) {
	                            stream.node.timestamp = Date.now()
	                        }
	                        return i
	                    })
	                });
	                return FS.mkdev(path, mode, dev)
	            }),
	            createLink: (function (parent, name, target, canRead, canWrite) {
	                var path = PATH.join2(typeof parent === "string" ? parent : FS.getPath(parent), name);
	                return FS.symlink(target, path)
	            }),
	            forceLoadFile: (function (obj) {
	                if (obj.isDevice || obj.isFolder || obj.link || obj.contents)return true;
	                var success = true;
	                if (typeof XMLHttpRequest !== "undefined") {
	                    throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.")
	                } else if (Module["read"]) {
	                    try {
	                        obj.contents = intArrayFromString(Module["read"](obj.url), true);
	                        obj.usedBytes = obj.contents.length
	                    } catch (e) {
	                        success = false
	                    }
	                } else {
	                    throw new Error("Cannot load without read() or XMLHttpRequest.")
	                }
	                if (!success)___setErrNo(ERRNO_CODES.EIO);
	                return success
	            }),
	            createLazyFile: (function (parent, name, url, canRead, canWrite) {
	                function LazyUint8Array() {
	                    this.lengthKnown = false;
	                    this.chunks = []
	                }

	                LazyUint8Array.prototype.get = function LazyUint8Array_get(idx) {
	                    if (idx > this.length - 1 || idx < 0) {
	                        return undefined
	                    }
	                    var chunkOffset = idx % this.chunkSize;
	                    var chunkNum = idx / this.chunkSize | 0;
	                    return this.getter(chunkNum)[chunkOffset]
	                };
	                LazyUint8Array.prototype.setDataGetter = function LazyUint8Array_setDataGetter(getter) {
	                    this.getter = getter
	                };
	                LazyUint8Array.prototype.cacheLength = function LazyUint8Array_cacheLength() {
	                    var xhr = new XMLHttpRequest;
	                    xhr.open("HEAD", url, false);
	                    xhr.send(null);
	                    if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304))throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
	                    var datalength = Number(xhr.getResponseHeader("Content-length"));
	                    var header;
	                    var hasByteServing = (header = xhr.getResponseHeader("Accept-Ranges")) && header === "bytes";
	                    var chunkSize = 1024 * 1024;
	                    if (!hasByteServing)chunkSize = datalength;
	                    var doXHR = (function (from, to) {
	                        if (from > to)throw new Error("invalid range (" + from + ", " + to + ") or no bytes requested!");
	                        if (to > datalength - 1)throw new Error("only " + datalength + " bytes available! programmer error!");
	                        var xhr = new XMLHttpRequest;
	                        xhr.open("GET", url, false);
	                        if (datalength !== chunkSize)xhr.setRequestHeader("Range", "bytes=" + from + "-" + to);
	                        if (typeof Uint8Array != "undefined")xhr.responseType = "arraybuffer";
	                        if (xhr.overrideMimeType) {
	                            xhr.overrideMimeType("text/plain; charset=x-user-defined")
	                        }
	                        xhr.send(null);
	                        if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304))throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
	                        if (xhr.response !== undefined) {
	                            return new Uint8Array(xhr.response || [])
	                        } else {
	                            return intArrayFromString(xhr.responseText || "", true)
	                        }
	                    });
	                    var lazyArray = this;
	                    lazyArray.setDataGetter((function (chunkNum) {
	                        var start = chunkNum * chunkSize;
	                        var end = (chunkNum + 1) * chunkSize - 1;
	                        end = Math.min(end, datalength - 1);
	                        if (typeof lazyArray.chunks[chunkNum] === "undefined") {
	                            lazyArray.chunks[chunkNum] = doXHR(start, end)
	                        }
	                        if (typeof lazyArray.chunks[chunkNum] === "undefined")throw new Error("doXHR failed!");
	                        return lazyArray.chunks[chunkNum]
	                    }));
	                    this._length = datalength;
	                    this._chunkSize = chunkSize;
	                    this.lengthKnown = true
	                };
	                if (typeof XMLHttpRequest !== "undefined") {
	                    throw"Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc";
	                    var lazyArray = new LazyUint8Array;
	                    Object.defineProperty(lazyArray, "length", {
	                        get: (function () {
	                            if (!this.lengthKnown) {
	                                this.cacheLength()
	                            }
	                            return this._length
	                        })
	                    });
	                    Object.defineProperty(lazyArray, "chunkSize", {
	                        get: (function () {
	                            if (!this.lengthKnown) {
	                                this.cacheLength()
	                            }
	                            return this._chunkSize
	                        })
	                    });
	                    var properties = {isDevice: false, contents: lazyArray}
	                } else {
	                    var properties = {isDevice: false, url: url}
	                }
	                var node = FS.createFile(parent, name, properties, canRead, canWrite);
	                if (properties.contents) {
	                    node.contents = properties.contents
	                } else if (properties.url) {
	                    node.contents = null;
	                    node.url = properties.url
	                }
	                Object.defineProperty(node, "usedBytes", {
	                    get: (function () {
	                        return this.contents.length
	                    })
	                });
	                var stream_ops = {};
	                var keys = Object.keys(node.stream_ops);
	                keys.forEach((function (key) {
	                    var fn = node.stream_ops[key];
	                    stream_ops[key] = function forceLoadLazyFile() {
	                        if (!FS.forceLoadFile(node)) {
	                            throw new FS.ErrnoError(ERRNO_CODES.EIO)
	                        }
	                        return fn.apply(null, arguments)
	                    }
	                }));
	                stream_ops.read = function stream_ops_read(stream, buffer, offset, length, position) {
	                    if (!FS.forceLoadFile(node)) {
	                        throw new FS.ErrnoError(ERRNO_CODES.EIO)
	                    }
	                    var contents = stream.node.contents;
	                    if (position >= contents.length)return 0;
	                    var size = Math.min(contents.length - position, length);
	                    assert(size >= 0);
	                    if (contents.slice) {
	                        for (var i = 0; i < size; i++) {
	                            buffer[offset + i] = contents[position + i]
	                        }
	                    } else {
	                        for (var i = 0; i < size; i++) {
	                            buffer[offset + i] = contents.get(position + i)
	                        }
	                    }
	                    return size
	                };
	                node.stream_ops = stream_ops;
	                return node
	            }),
	            createPreloadedFile: (function (parent, name, url, canRead, canWrite, onload, onerror, dontCreateFile, canOwn) {
	                Browser.init();
	                var fullname = name ? PATH.resolve(PATH.join2(parent, name)) : parent;

	                function processData(byteArray) {
	                    function finish(byteArray) {
	                        if (!dontCreateFile) {
	                            FS.createDataFile(parent, name, byteArray, canRead, canWrite, canOwn)
	                        }
	                        if (onload)onload();
	                        removeRunDependency("cp " + fullname)
	                    }

	                    var handled = false;
	                    Module["preloadPlugins"].forEach((function (plugin) {
	                        if (handled)return;
	                        if (plugin["canHandle"](fullname)) {
	                            plugin["handle"](byteArray, fullname, finish, (function () {
	                                if (onerror)onerror();
	                                removeRunDependency("cp " + fullname)
	                            }));
	                            handled = true
	                        }
	                    }));
	                    if (!handled)finish(byteArray)
	                }

	                addRunDependency("cp " + fullname);
	                if (typeof url == "string") {
	                    Browser.asyncLoad(url, (function (byteArray) {
	                        processData(byteArray)
	                    }), onerror)
	                } else {
	                    processData(url)
	                }
	            }),
	            indexedDB: (function () {
	                return window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB
	            }),
	            DB_NAME: (function () {
	                return "EM_FS_" + window.location.pathname
	            }),
	            DB_VERSION: 20,
	            DB_STORE_NAME: "FILE_DATA",
	            saveFilesToDB: (function (paths, onload, onerror) {
	                onload = onload || (function () {
	                    });
	                onerror = onerror || (function () {
	                    });
	                var indexedDB = FS.indexedDB();
	                try {
	                    var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION)
	                } catch (e) {
	                    return onerror(e)
	                }
	                openRequest.onupgradeneeded = function openRequest_onupgradeneeded() {
	                    console.log("creating db");
	                    var db = openRequest.result;
	                    db.createObjectStore(FS.DB_STORE_NAME)
	                };
	                openRequest.onsuccess = function openRequest_onsuccess() {
	                    var db = openRequest.result;
	                    var transaction = db.transaction([FS.DB_STORE_NAME], "readwrite");
	                    var files = transaction.objectStore(FS.DB_STORE_NAME);
	                    var ok = 0, fail = 0, total = paths.length;

	                    function finish() {
	                        if (fail == 0)onload(); else onerror()
	                    }

	                    paths.forEach((function (path) {
	                        var putRequest = files.put(FS.analyzePath(path).object.contents, path);
	                        putRequest.onsuccess = function putRequest_onsuccess() {
	                            ok++;
	                            if (ok + fail == total)finish()
	                        };
	                        putRequest.onerror = function putRequest_onerror() {
	                            fail++;
	                            if (ok + fail == total)finish()
	                        }
	                    }));
	                    transaction.onerror = onerror
	                };
	                openRequest.onerror = onerror
	            }),
	            loadFilesFromDB: (function (paths, onload, onerror) {
	                onload = onload || (function () {
	                    });
	                onerror = onerror || (function () {
	                    });
	                var indexedDB = FS.indexedDB();
	                try {
	                    var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION)
	                } catch (e) {
	                    return onerror(e)
	                }
	                openRequest.onupgradeneeded = onerror;
	                openRequest.onsuccess = function openRequest_onsuccess() {
	                    var db = openRequest.result;
	                    try {
	                        var transaction = db.transaction([FS.DB_STORE_NAME], "readonly")
	                    } catch (e) {
	                        onerror(e);
	                        return
	                    }
	                    var files = transaction.objectStore(FS.DB_STORE_NAME);
	                    var ok = 0, fail = 0, total = paths.length;

	                    function finish() {
	                        if (fail == 0)onload(); else onerror()
	                    }

	                    paths.forEach((function (path) {
	                        var getRequest = files.get(path);
	                        getRequest.onsuccess = function getRequest_onsuccess() {
	                            if (FS.analyzePath(path).exists) {
	                                FS.unlink(path)
	                            }
	                            FS.createDataFile(PATH.dirname(path), PATH.basename(path), getRequest.result, true, true, true);
	                            ok++;
	                            if (ok + fail == total)finish()
	                        };
	                        getRequest.onerror = function getRequest_onerror() {
	                            fail++;
	                            if (ok + fail == total)finish()
	                        }
	                    }));
	                    transaction.onerror = onerror
	                };
	                openRequest.onerror = onerror
	            })
	        };

	        function _mkport() {
	            throw"TODO"
	        }

	        var SOCKFS = {
	            mount: (function (mount) {
	                Module["websocket"] = Module["websocket"] && "object" === typeof Module["websocket"] ? Module["websocket"] : {};
	                Module["websocket"]._callbacks = {};
	                Module["websocket"]["on"] = (function (event, callback) {
	                    if ("function" === typeof callback) {
	                        this._callbacks[event] = callback
	                    }
	                    return this
	                });
	                Module["websocket"].emit = (function (event, param) {
	                    if ("function" === typeof this._callbacks[event]) {
	                        this._callbacks[event].call(this, param)
	                    }
	                });
	                return FS.createNode(null, "/", 16384 | 511, 0)
	            }), createSocket: (function (family, type, protocol) {
	                var streaming = type == 1;
	                if (protocol) {
	                    assert(streaming == (protocol == 6))
	                }
	                var sock = {
	                    family: family,
	                    type: type,
	                    protocol: protocol,
	                    server: null,
	                    error: null,
	                    peers: {},
	                    pending: [],
	                    recv_queue: [],
	                    sock_ops: SOCKFS.websocket_sock_ops
	                };
	                var name = SOCKFS.nextname();
	                var node = FS.createNode(SOCKFS.root, name, 49152, 0);
	                node.sock = sock;
	                var stream = FS.createStream({
	                    path: name,
	                    node: node,
	                    flags: FS.modeStringToFlags("r+"),
	                    seekable: false,
	                    stream_ops: SOCKFS.stream_ops
	                });
	                sock.stream = stream;
	                return sock
	            }), getSocket: (function (fd) {
	                var stream = FS.getStream(fd);
	                if (!stream || !FS.isSocket(stream.node.mode)) {
	                    return null
	                }
	                return stream.node.sock
	            }), stream_ops: {
	                poll: (function (stream) {
	                    var sock = stream.node.sock;
	                    return sock.sock_ops.poll(sock)
	                }), ioctl: (function (stream, request, varargs) {
	                    var sock = stream.node.sock;
	                    return sock.sock_ops.ioctl(sock, request, varargs)
	                }), read: (function (stream, buffer, offset, length, position) {
	                    var sock = stream.node.sock;
	                    var msg = sock.sock_ops.recvmsg(sock, length);
	                    if (!msg) {
	                        return 0
	                    }
	                    buffer.set(msg.buffer, offset);
	                    return msg.buffer.length
	                }), write: (function (stream, buffer, offset, length, position) {
	                    var sock = stream.node.sock;
	                    return sock.sock_ops.sendmsg(sock, buffer, offset, length)
	                }), close: (function (stream) {
	                    var sock = stream.node.sock;
	                    sock.sock_ops.close(sock)
	                })
	            }, nextname: (function () {
	                if (!SOCKFS.nextname.current) {
	                    SOCKFS.nextname.current = 0
	                }
	                return "socket[" + SOCKFS.nextname.current++ + "]"
	            }), websocket_sock_ops: {
	                createPeer: (function (sock, addr, port) {
	                    var ws;
	                    if (typeof addr === "object") {
	                        ws = addr;
	                        addr = null;
	                        port = null
	                    }
	                    if (ws) {
	                        if (ws._socket) {
	                            addr = ws._socket.remoteAddress;
	                            port = ws._socket.remotePort
	                        } else {
	                            var result = /ws[s]?:\/\/([^:]+):(\d+)/.exec(ws.url);
	                            if (!result) {
	                                throw new Error("WebSocket URL must be in the format ws(s)://address:port")
	                            }
	                            addr = result[1];
	                            port = parseInt(result[2], 10)
	                        }
	                    } else {
	                        try {
	                            var runtimeConfig = Module["websocket"] && "object" === typeof Module["websocket"];
	                            var url = "ws:#".replace("#", "//");
	                            if (runtimeConfig) {
	                                if ("string" === typeof Module["websocket"]["url"]) {
	                                    url = Module["websocket"]["url"]
	                                }
	                            }
	                            if (url === "ws://" || url === "wss://") {
	                                var parts = addr.split("/");
	                                url = url + parts[0] + ":" + port + "/" + parts.slice(1).join("/")
	                            }
	                            var subProtocols = "binary";
	                            if (runtimeConfig) {
	                                if ("string" === typeof Module["websocket"]["subprotocol"]) {
	                                    subProtocols = Module["websocket"]["subprotocol"]
	                                }
	                            }
	                            subProtocols = subProtocols.replace(/^ +| +$/g, "").split(/ *, */);
	                            var opts = subProtocols;
	                            var WebSocket = window["WebSocket"];
	                            ws = new WebSocket(url, opts);
	                            ws.binaryType = "arraybuffer"
	                        } catch (e) {
	                            throw new FS.ErrnoError(ERRNO_CODES.EHOSTUNREACH)
	                        }
	                    }
	                    var peer = {addr: addr, port: port, socket: ws, dgram_send_queue: []};
	                    SOCKFS.websocket_sock_ops.addPeer(sock, peer);
	                    SOCKFS.websocket_sock_ops.handlePeerEvents(sock, peer);
	                    if (sock.type === 2 && typeof sock.sport !== "undefined") {
	                        peer.dgram_send_queue.push(new Uint8Array([255, 255, 255, 255, "p".charCodeAt(0), "o".charCodeAt(0), "r".charCodeAt(0), "t".charCodeAt(0), (sock.sport & 65280) >> 8, sock.sport & 255]))
	                    }
	                    return peer
	                }), getPeer: (function (sock, addr, port) {
	                    return sock.peers[addr + ":" + port]
	                }), addPeer: (function (sock, peer) {
	                    sock.peers[peer.addr + ":" + peer.port] = peer
	                }), removePeer: (function (sock, peer) {
	                    delete sock.peers[peer.addr + ":" + peer.port]
	                }), handlePeerEvents: (function (sock, peer) {
	                    var first = true;
	                    var handleOpen = (function () {
	                        Module["websocket"].emit("open", sock.stream.fd);
	                        try {
	                            var queued = peer.dgram_send_queue.shift();
	                            while (queued) {
	                                peer.socket.send(queued);
	                                queued = peer.dgram_send_queue.shift()
	                            }
	                        } catch (e) {
	                            peer.socket.close()
	                        }
	                    });

	                    function handleMessage(data) {
	                        assert(typeof data !== "string" && data.byteLength !== undefined);
	                        data = new Uint8Array(data);
	                        var wasfirst = first;
	                        first = false;
	                        if (wasfirst && data.length === 10 && data[0] === 255 && data[1] === 255 && data[2] === 255 && data[3] === 255 && data[4] === "p".charCodeAt(0) && data[5] === "o".charCodeAt(0) && data[6] === "r".charCodeAt(0) && data[7] === "t".charCodeAt(0)) {
	                            var newport = data[8] << 8 | data[9];
	                            SOCKFS.websocket_sock_ops.removePeer(sock, peer);
	                            peer.port = newport;
	                            SOCKFS.websocket_sock_ops.addPeer(sock, peer);
	                            return
	                        }
	                        sock.recv_queue.push({addr: peer.addr, port: peer.port, data: data});
	                        Module["websocket"].emit("message", sock.stream.fd)
	                    }

	                    {
	                        peer.socket.onopen = handleOpen;
	                        peer.socket.onclose = (function () {
	                            Module["websocket"].emit("close", sock.stream.fd)
	                        });
	                        peer.socket.onmessage = function peer_socket_onmessage(event) {
	                            handleMessage(event.data)
	                        };
	                        peer.socket.onerror = (function (error) {
	                            sock.error = ERRNO_CODES.ECONNREFUSED;
	                            Module["websocket"].emit("error", [sock.stream.fd, sock.error, "ECONNREFUSED: Connection refused"])
	                        })
	                    }
	                }), poll: (function (sock) {
	                    if (sock.type === 1 && sock.server) {
	                        return sock.pending.length ? 64 | 1 : 0
	                    }
	                    var mask = 0;
	                    var dest = sock.type === 1 ? SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport) : null;
	                    if (sock.recv_queue.length || !dest || dest && dest.socket.readyState === dest.socket.CLOSING || dest && dest.socket.readyState === dest.socket.CLOSED) {
	                        mask |= 64 | 1
	                    }
	                    if (!dest || dest && dest.socket.readyState === dest.socket.OPEN) {
	                        mask |= 4
	                    }
	                    if (dest && dest.socket.readyState === dest.socket.CLOSING || dest && dest.socket.readyState === dest.socket.CLOSED) {
	                        mask |= 16
	                    }
	                    return mask
	                }), ioctl: (function (sock, request, arg) {
	                    switch (request) {
	                        case 21531:
	                            var bytes = 0;
	                            if (sock.recv_queue.length) {
	                                bytes = sock.recv_queue[0].data.length
	                            }
	                            HEAP32[arg >> 2] = bytes;
	                            return 0;
	                        default:
	                            return ERRNO_CODES.EINVAL
	                    }
	                }), close: (function (sock) {
	                    if (sock.server) {
	                        try {
	                            sock.server.close()
	                        } catch (e) {
	                        }
	                        sock.server = null
	                    }
	                    var peers = Object.keys(sock.peers);
	                    for (var i = 0; i < peers.length; i++) {
	                        var peer = sock.peers[peers[i]];
	                        try {
	                            peer.socket.close()
	                        } catch (e) {
	                        }
	                        SOCKFS.websocket_sock_ops.removePeer(sock, peer)
	                    }
	                    return 0
	                }), bind: (function (sock, addr, port) {
	                    if (typeof sock.saddr !== "undefined" || typeof sock.sport !== "undefined") {
	                        throw new FS.ErrnoError(ERRNO_CODES.EINVAL)
	                    }
	                    sock.saddr = addr;
	                    sock.sport = port || _mkport();
	                    if (sock.type === 2) {
	                        if (sock.server) {
	                            sock.server.close();
	                            sock.server = null
	                        }
	                        try {
	                            sock.sock_ops.listen(sock, 0)
	                        } catch (e) {
	                            if (!(e instanceof FS.ErrnoError))throw e;
	                            if (e.errno !== ERRNO_CODES.EOPNOTSUPP)throw e
	                        }
	                    }
	                }), connect: (function (sock, addr, port) {
	                    if (sock.server) {
	                        throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP)
	                    }
	                    if (typeof sock.daddr !== "undefined" && typeof sock.dport !== "undefined") {
	                        var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
	                        if (dest) {
	                            if (dest.socket.readyState === dest.socket.CONNECTING) {
	                                throw new FS.ErrnoError(ERRNO_CODES.EALREADY)
	                            } else {
	                                throw new FS.ErrnoError(ERRNO_CODES.EISCONN)
	                            }
	                        }
	                    }
	                    var peer = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
	                    sock.daddr = peer.addr;
	                    sock.dport = peer.port;
	                    throw new FS.ErrnoError(ERRNO_CODES.EINPROGRESS)
	                }), listen: (function (sock, backlog) {
	                    if (true) {
	                        throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP)
	                    }
	                    if (sock.server) {
	                        throw new FS.ErrnoError(ERRNO_CODES.EINVAL)
	                    }
	                    var WebSocketServer = undefined;
	                    var host = sock.saddr;
	                    sock.server = new WebSocketServer({host: host, port: sock.sport});
	                    Module["websocket"].emit("listen", sock.stream.fd);
	                    sock.server.on("connection", (function (ws) {
	                        if (sock.type === 1) {
	                            var newsock = SOCKFS.createSocket(sock.family, sock.type, sock.protocol);
	                            var peer = SOCKFS.websocket_sock_ops.createPeer(newsock, ws);
	                            newsock.daddr = peer.addr;
	                            newsock.dport = peer.port;
	                            sock.pending.push(newsock);
	                            Module["websocket"].emit("connection", newsock.stream.fd)
	                        } else {
	                            SOCKFS.websocket_sock_ops.createPeer(sock, ws);
	                            Module["websocket"].emit("connection", sock.stream.fd)
	                        }
	                    }));
	                    sock.server.on("closed", (function () {
	                        Module["websocket"].emit("close", sock.stream.fd);
	                        sock.server = null
	                    }));
	                    sock.server.on("error", (function (error) {
	                        sock.error = ERRNO_CODES.EHOSTUNREACH;
	                        Module["websocket"].emit("error", [sock.stream.fd, sock.error, "EHOSTUNREACH: Host is unreachable"])
	                    }))
	                }), accept: (function (listensock) {
	                    if (!listensock.server) {
	                        throw new FS.ErrnoError(ERRNO_CODES.EINVAL)
	                    }
	                    var newsock = listensock.pending.shift();
	                    newsock.stream.flags = listensock.stream.flags;
	                    return newsock
	                }), getname: (function (sock, peer) {
	                    var addr, port;
	                    if (peer) {
	                        if (sock.daddr === undefined || sock.dport === undefined) {
	                            throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN)
	                        }
	                        addr = sock.daddr;
	                        port = sock.dport
	                    } else {
	                        addr = sock.saddr || 0;
	                        port = sock.sport || 0
	                    }
	                    return {addr: addr, port: port}
	                }), sendmsg: (function (sock, buffer, offset, length, addr, port) {
	                    if (sock.type === 2) {
	                        if (addr === undefined || port === undefined) {
	                            addr = sock.daddr;
	                            port = sock.dport
	                        }
	                        if (addr === undefined || port === undefined) {
	                            throw new FS.ErrnoError(ERRNO_CODES.EDESTADDRREQ)
	                        }
	                    } else {
	                        addr = sock.daddr;
	                        port = sock.dport
	                    }
	                    var dest = SOCKFS.websocket_sock_ops.getPeer(sock, addr, port);
	                    if (sock.type === 1) {
	                        if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
	                            throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN)
	                        } else if (dest.socket.readyState === dest.socket.CONNECTING) {
	                            throw new FS.ErrnoError(ERRNO_CODES.EAGAIN)
	                        }
	                    }
	                    var data;
	                    if (buffer instanceof Array || buffer instanceof ArrayBuffer) {
	                        data = buffer.slice(offset, offset + length)
	                    } else {
	                        data = buffer.buffer.slice(buffer.byteOffset + offset, buffer.byteOffset + offset + length)
	                    }
	                    if (sock.type === 2) {
	                        if (!dest || dest.socket.readyState !== dest.socket.OPEN) {
	                            if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
	                                dest = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port)
	                            }
	                            dest.dgram_send_queue.push(data);
	                            return length
	                        }
	                    }
	                    try {
	                        dest.socket.send(data);
	                        return length
	                    } catch (e) {
	                        throw new FS.ErrnoError(ERRNO_CODES.EINVAL)
	                    }
	                }), recvmsg: (function (sock, length) {
	                    if (sock.type === 1 && sock.server) {
	                        throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN)
	                    }
	                    var queued = sock.recv_queue.shift();
	                    if (!queued) {
	                        if (sock.type === 1) {
	                            var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
	                            if (!dest) {
	                                throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN)
	                            } else if (dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
	                                return null
	                            } else {
	                                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN)
	                            }
	                        } else {
	                            throw new FS.ErrnoError(ERRNO_CODES.EAGAIN)
	                        }
	                    }
	                    var queuedLength = queued.data.byteLength || queued.data.length;
	                    var queuedOffset = queued.data.byteOffset || 0;
	                    var queuedBuffer = queued.data.buffer || queued.data;
	                    var bytesRead = Math.min(length, queuedLength);
	                    var res = {
	                        buffer: new Uint8Array(queuedBuffer, queuedOffset, bytesRead),
	                        addr: queued.addr,
	                        port: queued.port
	                    };
	                    if (sock.type === 1 && bytesRead < queuedLength) {
	                        var bytesRemaining = queuedLength - bytesRead;
	                        queued.data = new Uint8Array(queuedBuffer, queuedOffset + bytesRead, bytesRemaining);
	                        sock.recv_queue.unshift(queued)
	                    }
	                    return res
	                })
	            }
	        };

	        function _recv(fd, buf, len, flags) {
	            var sock = SOCKFS.getSocket(fd);
	            if (!sock) {
	                ___setErrNo(ERRNO_CODES.EBADF);
	                return -1
	            }
	            return _read(fd, buf, len)
	        }

	        function _pread(fildes, buf, nbyte, offset) {
	            var stream = FS.getStream(fildes);
	            if (!stream) {
	                ___setErrNo(ERRNO_CODES.EBADF);
	                return -1
	            }
	            try {
	                var slab = HEAP8;
	                return FS.read(stream, slab, buf, nbyte, offset)
	            } catch (e) {
	                FS.handleFSError(e);
	                return -1
	            }
	        }

	        function _read(fildes, buf, nbyte) {
	            var stream = FS.getStream(fildes);
	            if (!stream) {
	                ___setErrNo(ERRNO_CODES.EBADF);
	                return -1
	            }
	            try {
	                var slab = HEAP8;
	                return FS.read(stream, slab, buf, nbyte)
	            } catch (e) {
	                FS.handleFSError(e);
	                return -1
	            }
	        }

	        function _fread(ptr, size, nitems, stream) {
	            var bytesToRead = nitems * size;
	            if (bytesToRead == 0) {
	                return 0
	            }
	            var bytesRead = 0;
	            var streamObj = FS.getStreamFromPtr(stream);
	            if (!streamObj) {
	                ___setErrNo(ERRNO_CODES.EBADF);
	                return 0
	            }
	            while (streamObj.ungotten.length && bytesToRead > 0) {
	                HEAP8[ptr++ >> 0] = streamObj.ungotten.pop();
	                bytesToRead--;
	                bytesRead++
	            }
	            var err = _read(streamObj.fd, ptr, bytesToRead);
	            if (err == -1) {
	                if (streamObj)streamObj.error = true;
	                return 0
	            }
	            bytesRead += err;
	            if (bytesRead < bytesToRead)streamObj.eof = true;
	            return bytesRead / size | 0
	        }

	        function _close(fildes) {
	            var stream = FS.getStream(fildes);
	            if (!stream) {
	                ___setErrNo(ERRNO_CODES.EBADF);
	                return -1
	            }
	            try {
	                FS.close(stream);
	                return 0
	            } catch (e) {
	                FS.handleFSError(e);
	                return -1
	            }
	        }

	        function _fsync(fildes) {
	            var stream = FS.getStream(fildes);
	            if (stream) {
	                return 0
	            } else {
	                ___setErrNo(ERRNO_CODES.EBADF);
	                return -1
	            }
	        }

	        function _fileno(stream) {
	            stream = FS.getStreamFromPtr(stream);
	            if (!stream)return -1;
	            return stream.fd
	        }

	        function _fclose(stream) {
	            var fd = _fileno(stream);
	            _fsync(fd);
	            return _close(fd)
	        }

	        Module["_strlen"] = _strlen;
	        Module["_strcat"] = _strcat;
	        function _strerror_r(errnum, strerrbuf, buflen) {
	            if (errnum in ERRNO_MESSAGES) {
	                if (ERRNO_MESSAGES[errnum].length > buflen - 1) {
	                    return ___setErrNo(ERRNO_CODES.ERANGE)
	                } else {
	                    var msg = ERRNO_MESSAGES[errnum];
	                    writeAsciiToMemory(msg, strerrbuf);
	                    return 0
	                }
	            } else {
	                return ___setErrNo(ERRNO_CODES.EINVAL)
	            }
	        }

	        function _strerror(errnum) {
	            if (!_strerror.buffer)_strerror.buffer = _malloc(256);
	            _strerror_r(errnum, _strerror.buffer, 256);
	            return _strerror.buffer
	        }

	        Module["_bitshift64Shl"] = _bitshift64Shl;
	        function _send(fd, buf, len, flags) {
	            var sock = SOCKFS.getSocket(fd);
	            if (!sock) {
	                ___setErrNo(ERRNO_CODES.EBADF);
	                return -1
	            }
	            return _write(fd, buf, len)
	        }

	        function _pwrite(fildes, buf, nbyte, offset) {
	            var stream = FS.getStream(fildes);
	            if (!stream) {
	                ___setErrNo(ERRNO_CODES.EBADF);
	                return -1
	            }
	            try {
	                var slab = HEAP8;
	                return FS.write(stream, slab, buf, nbyte, offset)
	            } catch (e) {
	                FS.handleFSError(e);
	                return -1
	            }
	        }

	        function _write(fildes, buf, nbyte) {
	            var stream = FS.getStream(fildes);
	            if (!stream) {
	                ___setErrNo(ERRNO_CODES.EBADF);
	                return -1
	            }
	            try {
	                var slab = HEAP8;
	                return FS.write(stream, slab, buf, nbyte)
	            } catch (e) {
	                FS.handleFSError(e);
	                return -1
	            }
	        }

	        function _fwrite(ptr, size, nitems, stream) {
	            var bytesToWrite = nitems * size;
	            if (bytesToWrite == 0)return 0;
	            var fd = _fileno(stream);
	            var bytesWritten = _write(fd, ptr, bytesToWrite);
	            if (bytesWritten == -1) {
	                var streamObj = FS.getStreamFromPtr(stream);
	                if (streamObj)streamObj.error = true;
	                return 0
	            } else {
	                return bytesWritten / size | 0
	            }
	        }

	        function _abort() {
	            Module["abort"]()
	        }

	        function __reallyNegative(x) {
	            return x < 0 || x === 0 && 1 / x === -Infinity
	        }

	        function __formatString(format, varargs) {
	            var textIndex = format;
	            var argIndex = 0;

	            function getNextArg(type) {
	                var ret;
	                if (type === "double") {
	                    ret = (HEAP32[tempDoublePtr >> 2] = HEAP32[varargs + argIndex >> 2], HEAP32[tempDoublePtr + 4 >> 2] = HEAP32[varargs + (argIndex + 4) >> 2], +HEAPF64[tempDoublePtr >> 3])
	                } else if (type == "i64") {
	                    ret = [HEAP32[varargs + argIndex >> 2], HEAP32[varargs + (argIndex + 4) >> 2]]
	                } else {
	                    type = "i32";
	                    ret = HEAP32[varargs + argIndex >> 2]
	                }
	                argIndex += Runtime.getNativeFieldSize(type);
	                return ret
	            }

	            var ret = [];
	            var curr, next, currArg;
	            while (1) {
	                var startTextIndex = textIndex;
	                curr = HEAP8[textIndex >> 0];
	                if (curr === 0)break;
	                next = HEAP8[textIndex + 1 >> 0];
	                if (curr == 37) {
	                    var flagAlwaysSigned = false;
	                    var flagLeftAlign = false;
	                    var flagAlternative = false;
	                    var flagZeroPad = false;
	                    var flagPadSign = false;
	                    flagsLoop:while (1) {
	                        switch (next) {
	                            case 43:
	                                flagAlwaysSigned = true;
	                                break;
	                            case 45:
	                                flagLeftAlign = true;
	                                break;
	                            case 35:
	                                flagAlternative = true;
	                                break;
	                            case 48:
	                                if (flagZeroPad) {
	                                    break flagsLoop
	                                } else {
	                                    flagZeroPad = true;
	                                    break
	                                }
	                                ;
	                            case 32:
	                                flagPadSign = true;
	                                break;
	                            default:
	                                break flagsLoop
	                        }
	                        textIndex++;
	                        next = HEAP8[textIndex + 1 >> 0]
	                    }
	                    var width = 0;
	                    if (next == 42) {
	                        width = getNextArg("i32");
	                        textIndex++;
	                        next = HEAP8[textIndex + 1 >> 0]
	                    } else {
	                        while (next >= 48 && next <= 57) {
	                            width = width * 10 + (next - 48);
	                            textIndex++;
	                            next = HEAP8[textIndex + 1 >> 0]
	                        }
	                    }
	                    var precisionSet = false, precision = -1;
	                    if (next == 46) {
	                        precision = 0;
	                        precisionSet = true;
	                        textIndex++;
	                        next = HEAP8[textIndex + 1 >> 0];
	                        if (next == 42) {
	                            precision = getNextArg("i32");
	                            textIndex++
	                        } else {
	                            while (1) {
	                                var precisionChr = HEAP8[textIndex + 1 >> 0];
	                                if (precisionChr < 48 || precisionChr > 57)break;
	                                precision = precision * 10 + (precisionChr - 48);
	                                textIndex++
	                            }
	                        }
	                        next = HEAP8[textIndex + 1 >> 0]
	                    }
	                    if (precision < 0) {
	                        precision = 6;
	                        precisionSet = false
	                    }
	                    var argSize;
	                    switch (String.fromCharCode(next)) {
	                        case"h":
	                            var nextNext = HEAP8[textIndex + 2 >> 0];
	                            if (nextNext == 104) {
	                                textIndex++;
	                                argSize = 1
	                            } else {
	                                argSize = 2
	                            }
	                            break;
	                        case"l":
	                            var nextNext = HEAP8[textIndex + 2 >> 0];
	                            if (nextNext == 108) {
	                                textIndex++;
	                                argSize = 8
	                            } else {
	                                argSize = 4
	                            }
	                            break;
	                        case"L":
	                        case"q":
	                        case"j":
	                            argSize = 8;
	                            break;
	                        case"z":
	                        case"t":
	                        case"I":
	                            argSize = 4;
	                            break;
	                        default:
	                            argSize = null
	                    }
	                    if (argSize)textIndex++;
	                    next = HEAP8[textIndex + 1 >> 0];
	                    switch (String.fromCharCode(next)) {
	                        case"d":
	                        case"i":
	                        case"u":
	                        case"o":
	                        case"x":
	                        case"X":
	                        case"p":
	                        {
	                            var signed = next == 100 || next == 105;
	                            argSize = argSize || 4;
	                            var currArg = getNextArg("i" + argSize * 8);
	                            var origArg = currArg;
	                            var argText;
	                            if (argSize == 8) {
	                                currArg = Runtime.makeBigInt(currArg[0], currArg[1], next == 117)
	                            }
	                            if (argSize <= 4) {
	                                var limit = Math.pow(256, argSize) - 1;
	                                currArg = (signed ? reSign : unSign)(currArg & limit, argSize * 8)
	                            }
	                            var currAbsArg = Math.abs(currArg);
	                            var prefix = "";
	                            if (next == 100 || next == 105) {
	                                if (argSize == 8 && i64Math)argText = i64Math.stringify(origArg[0], origArg[1], null); else argText = reSign(currArg, 8 * argSize, 1).toString(10)
	                            } else if (next == 117) {
	                                if (argSize == 8 && i64Math)argText = i64Math.stringify(origArg[0], origArg[1], true); else argText = unSign(currArg, 8 * argSize, 1).toString(10);
	                                currArg = Math.abs(currArg)
	                            } else if (next == 111) {
	                                argText = (flagAlternative ? "0" : "") + currAbsArg.toString(8)
	                            } else if (next == 120 || next == 88) {
	                                prefix = flagAlternative && currArg != 0 ? "0x" : "";
	                                if (argSize == 8 && i64Math) {
	                                    if (origArg[1]) {
	                                        argText = (origArg[1] >>> 0).toString(16);
	                                        var lower = (origArg[0] >>> 0).toString(16);
	                                        while (lower.length < 8)lower = "0" + lower;
	                                        argText += lower
	                                    } else {
	                                        argText = (origArg[0] >>> 0).toString(16)
	                                    }
	                                } else if (currArg < 0) {
	                                    currArg = -currArg;
	                                    argText = (currAbsArg - 1).toString(16);
	                                    var buffer = [];
	                                    for (var i = 0; i < argText.length; i++) {
	                                        buffer.push((15 - parseInt(argText[i], 16)).toString(16))
	                                    }
	                                    argText = buffer.join("");
	                                    while (argText.length < argSize * 2)argText = "f" + argText
	                                } else {
	                                    argText = currAbsArg.toString(16)
	                                }
	                                if (next == 88) {
	                                    prefix = prefix.toUpperCase();
	                                    argText = argText.toUpperCase()
	                                }
	                            } else if (next == 112) {
	                                if (currAbsArg === 0) {
	                                    argText = "(nil)"
	                                } else {
	                                    prefix = "0x";
	                                    argText = currAbsArg.toString(16)
	                                }
	                            }
	                            if (precisionSet) {
	                                while (argText.length < precision) {
	                                    argText = "0" + argText
	                                }
	                            }
	                            if (currArg >= 0) {
	                                if (flagAlwaysSigned) {
	                                    prefix = "+" + prefix
	                                } else if (flagPadSign) {
	                                    prefix = " " + prefix
	                                }
	                            }
	                            if (argText.charAt(0) == "-") {
	                                prefix = "-" + prefix;
	                                argText = argText.substr(1)
	                            }
	                            while (prefix.length + argText.length < width) {
	                                if (flagLeftAlign) {
	                                    argText += " "
	                                } else {
	                                    if (flagZeroPad) {
	                                        argText = "0" + argText
	                                    } else {
	                                        prefix = " " + prefix
	                                    }
	                                }
	                            }
	                            argText = prefix + argText;
	                            argText.split("").forEach((function (chr) {
	                                ret.push(chr.charCodeAt(0))
	                            }));
	                            break
	                        }
	                            ;
	                        case"f":
	                        case"F":
	                        case"e":
	                        case"E":
	                        case"g":
	                        case"G":
	                        {
	                            var currArg = getNextArg("double");
	                            var argText;
	                            if (isNaN(currArg)) {
	                                argText = "nan";
	                                flagZeroPad = false
	                            } else if (!isFinite(currArg)) {
	                                argText = (currArg < 0 ? "-" : "") + "inf";
	                                flagZeroPad = false
	                            } else {
	                                var isGeneral = false;
	                                var effectivePrecision = Math.min(precision, 20);
	                                if (next == 103 || next == 71) {
	                                    isGeneral = true;
	                                    precision = precision || 1;
	                                    var exponent = parseInt(currArg.toExponential(effectivePrecision).split("e")[1], 10);
	                                    if (precision > exponent && exponent >= -4) {
	                                        next = (next == 103 ? "f" : "F").charCodeAt(0);
	                                        precision -= exponent + 1
	                                    } else {
	                                        next = (next == 103 ? "e" : "E").charCodeAt(0);
	                                        precision--
	                                    }
	                                    effectivePrecision = Math.min(precision, 20)
	                                }
	                                if (next == 101 || next == 69) {
	                                    argText = currArg.toExponential(effectivePrecision);
	                                    if (/[eE][-+]\d$/.test(argText)) {
	                                        argText = argText.slice(0, -1) + "0" + argText.slice(-1)
	                                    }
	                                } else if (next == 102 || next == 70) {
	                                    argText = currArg.toFixed(effectivePrecision);
	                                    if (currArg === 0 && __reallyNegative(currArg)) {
	                                        argText = "-" + argText
	                                    }
	                                }
	                                var parts = argText.split("e");
	                                if (isGeneral && !flagAlternative) {
	                                    while (parts[0].length > 1 && parts[0].indexOf(".") != -1 && (parts[0].slice(-1) == "0" || parts[0].slice(-1) == ".")) {
	                                        parts[0] = parts[0].slice(0, -1)
	                                    }
	                                } else {
	                                    if (flagAlternative && argText.indexOf(".") == -1)parts[0] += ".";
	                                    while (precision > effectivePrecision++)parts[0] += "0"
	                                }
	                                argText = parts[0] + (parts.length > 1 ? "e" + parts[1] : "");
	                                if (next == 69)argText = argText.toUpperCase();
	                                if (currArg >= 0) {
	                                    if (flagAlwaysSigned) {
	                                        argText = "+" + argText
	                                    } else if (flagPadSign) {
	                                        argText = " " + argText
	                                    }
	                                }
	                            }
	                            while (argText.length < width) {
	                                if (flagLeftAlign) {
	                                    argText += " "
	                                } else {
	                                    if (flagZeroPad && (argText[0] == "-" || argText[0] == "+")) {
	                                        argText = argText[0] + "0" + argText.slice(1)
	                                    } else {
	                                        argText = (flagZeroPad ? "0" : " ") + argText
	                                    }
	                                }
	                            }
	                            if (next < 97)argText = argText.toUpperCase();
	                            argText.split("").forEach((function (chr) {
	                                ret.push(chr.charCodeAt(0))
	                            }));
	                            break
	                        }
	                            ;
	                        case"s":
	                        {
	                            var arg = getNextArg("i8*");
	                            var argLength = arg ? _strlen(arg) : "(null)".length;
	                            if (precisionSet)argLength = Math.min(argLength, precision);
	                            if (!flagLeftAlign) {
	                                while (argLength < width--) {
	                                    ret.push(32)
	                                }
	                            }
	                            if (arg) {
	                                for (var i = 0; i < argLength; i++) {
	                                    ret.push(HEAPU8[arg++ >> 0])
	                                }
	                            } else {
	                                ret = ret.concat(intArrayFromString("(null)".substr(0, argLength), true))
	                            }
	                            if (flagLeftAlign) {
	                                while (argLength < width--) {
	                                    ret.push(32)
	                                }
	                            }
	                            break
	                        }
	                            ;
	                        case"c":
	                        {
	                            if (flagLeftAlign)ret.push(getNextArg("i8"));
	                            while (--width > 0) {
	                                ret.push(32)
	                            }
	                            if (!flagLeftAlign)ret.push(getNextArg("i8"));
	                            break
	                        }
	                            ;
	                        case"n":
	                        {
	                            var ptr = getNextArg("i32*");
	                            HEAP32[ptr >> 2] = ret.length;
	                            break
	                        }
	                            ;
	                        case"%":
	                        {
	                            ret.push(curr);
	                            break
	                        }
	                            ;
	                        default:
	                        {
	                            for (var i = startTextIndex; i < textIndex + 2; i++) {
	                                ret.push(HEAP8[i >> 0])
	                            }
	                        }
	                    }
	                    textIndex += 2
	                } else {
	                    ret.push(curr);
	                    textIndex += 1
	                }
	            }
	            return ret
	        }

	        function _fprintf(stream, format, varargs) {
	            var result = __formatString(format, varargs);
	            var stack = Runtime.stackSave();
	            var ret = _fwrite(allocate(result, "i8", ALLOC_STACK), 1, result.length, stream);
	            Runtime.stackRestore(stack);
	            return ret
	        }

	        function _printf(format, varargs) {
	            var stdout = HEAP32[_stdout >> 2];
	            return _fprintf(stdout, format, varargs)
	        }

	        function _fgetc(stream) {
	            var streamObj = FS.getStreamFromPtr(stream);
	            if (!streamObj)return -1;
	            if (streamObj.eof || streamObj.error)return -1;
	            var ret = _fread(_fgetc.ret, 1, 1, stream);
	            if (ret == 0) {
	                return -1
	            } else if (ret == -1) {
	                streamObj.error = true;
	                return -1
	            } else {
	                return HEAPU8[_fgetc.ret >> 0]
	            }
	        }

	        function _fgets(s, n, stream) {
	            var streamObj = FS.getStreamFromPtr(stream);
	            if (!streamObj)return 0;
	            if (streamObj.error || streamObj.eof)return 0;
	            var byte_;
	            for (var i = 0; i < n - 1 && byte_ != 10; i++) {
	                byte_ = _fgetc(stream);
	                if (byte_ == -1) {
	                    if (streamObj.error || streamObj.eof && i == 0)return 0; else if (streamObj.eof)break
	                }
	                HEAP8[s + i >> 0] = byte_
	            }
	            HEAP8[s + i >> 0] = 0;
	            return s
	        }

	        function _open(path, oflag, varargs) {
	            var mode = HEAP32[varargs >> 2];
	            path = Pointer_stringify(path);
	            try {
	                var stream = FS.open(path, oflag, mode);
	                return stream.fd
	            } catch (e) {
	                FS.handleFSError(e);
	                return -1
	            }
	        }

	        function _fopen(filename, mode) {
	            var flags;
	            mode = Pointer_stringify(mode);
	            if (mode[0] == "r") {
	                if (mode.indexOf("+") != -1) {
	                    flags = 2
	                } else {
	                    flags = 0
	                }
	            } else if (mode[0] == "w") {
	                if (mode.indexOf("+") != -1) {
	                    flags = 2
	                } else {
	                    flags = 1
	                }
	                flags |= 64;
	                flags |= 512
	            } else if (mode[0] == "a") {
	                if (mode.indexOf("+") != -1) {
	                    flags = 2
	                } else {
	                    flags = 1
	                }
	                flags |= 64;
	                flags |= 1024
	            } else {
	                ___setErrNo(ERRNO_CODES.EINVAL);
	                return 0
	            }
	            var fd = _open(filename, flags, allocate([511, 0, 0, 0], "i32", ALLOC_STACK));
	            return fd === -1 ? 0 : FS.getPtrForStream(FS.getStream(fd))
	        }

	        Module["_strncpy"] = _strncpy;
	        function _fputc(c, stream) {
	            var chr = unSign(c & 255);
	            HEAP8[_fputc.ret >> 0] = chr;
	            var fd = _fileno(stream);
	            var ret = _write(fd, _fputc.ret, 1);
	            if (ret == -1) {
	                var streamObj = FS.getStreamFromPtr(stream);
	                if (streamObj)streamObj.error = true;
	                return -1
	            } else {
	                return chr
	            }
	        }

	        Module["_i64Add"] = _i64Add;
	        var _fabs = Math_abs;
	        var _floor = Math_floor;
	        Module["_memset"] = _memset;
	        function _mmap(start, num, prot, flags, fd, offset) {
	            var MAP_PRIVATE = 2;
	            var ptr;
	            var allocated = false;
	            if (!_mmap.mappings)_mmap.mappings = {};
	            if (fd == -1) {
	                ptr = _malloc(num);
	                if (!ptr)return -1;
	                _memset(ptr, 0, num);
	                allocated = true
	            } else {
	                var info = FS.getStream(fd);
	                if (!info)return -1;
	                try {
	                    var res = FS.mmap(info, HEAPU8, start, num, offset, prot, flags);
	                    ptr = res.ptr;
	                    allocated = res.allocated
	                } catch (e) {
	                    FS.handleFSError(e);
	                    return -1
	                }
	            }
	            _mmap.mappings[ptr] = {malloc: ptr, num: num, allocated: allocated};
	            return ptr
	        }

	        function __exit(status) {
	            Module["exit"](status)
	        }

	        function _exit(status) {
	            __exit(status)
	        }

	        function _emscripten_set_main_loop_timing(mode, value) {
	            Browser.mainLoop.timingMode = mode;
	            Browser.mainLoop.timingValue = value;
	            if (!Browser.mainLoop.func) {
	                return 1
	            }
	            if (mode == 0) {
	                Browser.mainLoop.scheduler = function Browser_mainLoop_scheduler() {
	                    setTimeout(Browser.mainLoop.runner, value)
	                };
	                Browser.mainLoop.method = "timeout"
	            } else if (mode == 1) {
	                Browser.mainLoop.scheduler = function Browser_mainLoop_scheduler() {
	                    Browser.requestAnimationFrame(Browser.mainLoop.runner)
	                };
	                Browser.mainLoop.method = "rAF"
	            }
	            return 0
	        }

	        function _emscripten_set_main_loop(func, fps, simulateInfiniteLoop, arg) {
	            Module["noExitRuntime"] = true;
	            assert(!Browser.mainLoop.func, "emscripten_set_main_loop: there can only be one main loop function at once: call emscripten_cancel_main_loop to cancel the previous one before setting a new one with different parameters.");
	            Browser.mainLoop.func = func;
	            Browser.mainLoop.arg = arg;
	            var thisMainLoopId = Browser.mainLoop.currentlyRunningMainloop;
	            Browser.mainLoop.runner = function Browser_mainLoop_runner() {
	                if (ABORT)return;
	                if (Browser.mainLoop.queue.length > 0) {
	                    var start = Date.now();
	                    var blocker = Browser.mainLoop.queue.shift();
	                    blocker.func(blocker.arg);
	                    if (Browser.mainLoop.remainingBlockers) {
	                        var remaining = Browser.mainLoop.remainingBlockers;
	                        var next = remaining % 1 == 0 ? remaining - 1 : Math.floor(remaining);
	                        if (blocker.counted) {
	                            Browser.mainLoop.remainingBlockers = next
	                        } else {
	                            next = next + .5;
	                            Browser.mainLoop.remainingBlockers = (8 * remaining + next) / 9
	                        }
	                    }
	                    console.log('main loop blocker "' + blocker.name + '" took ' + (Date.now() - start) + " ms");
	                    Browser.mainLoop.updateStatus();
	                    setTimeout(Browser.mainLoop.runner, 0);
	                    return
	                }
	                if (thisMainLoopId < Browser.mainLoop.currentlyRunningMainloop)return;
	                Browser.mainLoop.currentFrameNumber = Browser.mainLoop.currentFrameNumber + 1 | 0;
	                if (Browser.mainLoop.timingMode == 1 && Browser.mainLoop.timingValue > 1 && Browser.mainLoop.currentFrameNumber % Browser.mainLoop.timingValue != 0) {
	                    Browser.mainLoop.scheduler();
	                    return
	                }
	                if (Browser.mainLoop.method === "timeout" && Module.ctx) {
	                    Module.printErr("Looks like you are rendering without using requestAnimationFrame for the main loop. You should use 0 for the frame rate in emscripten_set_main_loop in order to use requestAnimationFrame, as that can greatly improve your frame rates!");
	                    Browser.mainLoop.method = ""
	                }
	                Browser.mainLoop.runIter((function () {
	                    if (typeof arg !== "undefined") {
	                        Runtime.dynCall("vi", func, [arg])
	                    } else {
	                        Runtime.dynCall("v", func)
	                    }
	                }));
	                if (thisMainLoopId < Browser.mainLoop.currentlyRunningMainloop)return;
	                if (typeof SDL === "object" && SDL.audio && SDL.audio.queueNewAudioData)SDL.audio.queueNewAudioData();
	                Browser.mainLoop.scheduler()
	            };
	            if (fps && fps > 0)_emscripten_set_main_loop_timing(0, 1e3 / fps); else _emscripten_set_main_loop_timing(1, 1);
	            Browser.mainLoop.scheduler();
	            if (simulateInfiniteLoop) {
	                throw"SimulateInfiniteLoop"
	            }
	        }

	        var Browser = {
	            mainLoop: {
	                scheduler: null,
	                method: "",
	                currentlyRunningMainloop: 0,
	                func: null,
	                arg: 0,
	                timingMode: 0,
	                timingValue: 0,
	                currentFrameNumber: 0,
	                queue: [],
	                pause: (function () {
	                    Browser.mainLoop.scheduler = null;
	                    Browser.mainLoop.currentlyRunningMainloop++
	                }),
	                resume: (function () {
	                    Browser.mainLoop.currentlyRunningMainloop++;
	                    var timingMode = Browser.mainLoop.timingMode;
	                    var timingValue = Browser.mainLoop.timingValue;
	                    var func = Browser.mainLoop.func;
	                    Browser.mainLoop.func = null;
	                    _emscripten_set_main_loop(func, 0, false, Browser.mainLoop.arg);
	                    _emscripten_set_main_loop_timing(timingMode, timingValue)
	                }),
	                updateStatus: (function () {
	                    if (Module["setStatus"]) {
	                        var message = Module["statusMessage"] || "Please wait...";
	                        var remaining = Browser.mainLoop.remainingBlockers;
	                        var expected = Browser.mainLoop.expectedBlockers;
	                        if (remaining) {
	                            if (remaining < expected) {
	                                Module["setStatus"](message + " (" + (expected - remaining) + "/" + expected + ")")
	                            } else {
	                                Module["setStatus"](message)
	                            }
	                        } else {
	                            Module["setStatus"]("")
	                        }
	                    }
	                }),
	                runIter: (function (func) {
	                    if (ABORT)return;
	                    if (Module["preMainLoop"]) {
	                        var preRet = Module["preMainLoop"]();
	                        if (preRet === false) {
	                            return
	                        }
	                    }
	                    try {
	                        func()
	                    } catch (e) {
	                        if (e instanceof ExitStatus) {
	                            return
	                        } else {
	                            if (e && typeof e === "object" && e.stack)Module.printErr("exception thrown: " + [e, e.stack]);
	                            throw e
	                        }
	                    }
	                    if (Module["postMainLoop"])Module["postMainLoop"]()
	                })
	            },
	            isFullScreen: false,
	            pointerLock: false,
	            moduleContextCreatedCallbacks: [],
	            workers: [],
	            init: (function () {
	                if (!Module["preloadPlugins"])Module["preloadPlugins"] = [];
	                if (Browser.initted)return;
	                Browser.initted = true;
	                try {
	                    new Blob;
	                    Browser.hasBlobConstructor = true
	                } catch (e) {
	                    Browser.hasBlobConstructor = false;
	                    console.log("warning: no blob constructor, cannot create blobs with mimetypes")
	                }
	                Browser.BlobBuilder = typeof MozBlobBuilder != "undefined" ? MozBlobBuilder : typeof WebKitBlobBuilder != "undefined" ? WebKitBlobBuilder : !Browser.hasBlobConstructor ? console.log("warning: no BlobBuilder") : null;
	                Browser.URLObject = typeof window != "undefined" ? window.URL ? window.URL : window.webkitURL : undefined;
	                if (!Module.noImageDecoding && typeof Browser.URLObject === "undefined") {
	                    console.log("warning: Browser does not support creating object URLs. Built-in browser image decoding will not be available.");
	                    Module.noImageDecoding = true
	                }
	                var imagePlugin = {};
	                imagePlugin["canHandle"] = function imagePlugin_canHandle(name) {
	                    return !Module.noImageDecoding && /\.(jpg|jpeg|png|bmp)$/i.test(name)
	                };
	                imagePlugin["handle"] = function imagePlugin_handle(byteArray, name, onload, onerror) {
	                    var b = null;
	                    if (Browser.hasBlobConstructor) {
	                        try {
	                            b = new Blob([byteArray], {type: Browser.getMimetype(name)});
	                            if (b.size !== byteArray.length) {
	                                b = new Blob([(new Uint8Array(byteArray)).buffer], {type: Browser.getMimetype(name)})
	                            }
	                        } catch (e) {
	                            Runtime.warnOnce("Blob constructor present but fails: " + e + "; falling back to blob builder")
	                        }
	                    }
	                    if (!b) {
	                        var bb = new Browser.BlobBuilder;
	                        bb.append((new Uint8Array(byteArray)).buffer);
	                        b = bb.getBlob()
	                    }
	                    var url = Browser.URLObject.createObjectURL(b);
	                    var img = new Image;
	                    img.onload = function img_onload() {
	                        assert(img.complete, "Image " + name + " could not be decoded");
	                        var canvas = document.createElement("canvas");
	                        canvas.width = img.width;
	                        canvas.height = img.height;
	                        var ctx = canvas.getContext("2d");
	                        ctx.drawImage(img, 0, 0);
	                        Module["preloadedImages"][name] = canvas;
	                        Browser.URLObject.revokeObjectURL(url);
	                        if (onload)onload(byteArray)
	                    };
	                    img.onerror = function img_onerror(event) {
	                        console.log("Image " + url + " could not be decoded");
	                        if (onerror)onerror()
	                    };
	                    img.src = url
	                };
	                Module["preloadPlugins"].push(imagePlugin);
	                var audioPlugin = {};
	                audioPlugin["canHandle"] = function audioPlugin_canHandle(name) {
	                    return !Module.noAudioDecoding && name.substr(-4) in {".ogg": 1, ".wav": 1, ".mp3": 1}
	                };
	                audioPlugin["handle"] = function audioPlugin_handle(byteArray, name, onload, onerror) {
	                    var done = false;

	                    function finish(audio) {
	                        if (done)return;
	                        done = true;
	                        Module["preloadedAudios"][name] = audio;
	                        if (onload)onload(byteArray)
	                    }

	                    function fail() {
	                        if (done)return;
	                        done = true;
	                        Module["preloadedAudios"][name] = new Audio;
	                        if (onerror)onerror()
	                    }

	                    if (Browser.hasBlobConstructor) {
	                        try {
	                            var b = new Blob([byteArray], {type: Browser.getMimetype(name)})
	                        } catch (e) {
	                            return fail()
	                        }
	                        var url = Browser.URLObject.createObjectURL(b);
	                        var audio = new Audio;
	                        audio.addEventListener("canplaythrough", (function () {
	                            finish(audio)
	                        }), false);
	                        audio.onerror = function audio_onerror(event) {
	                            if (done)return;
	                            console.log("warning: browser could not fully decode audio " + name + ", trying slower base64 approach");
	                            function encode64(data) {
	                                var BASE = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
	                                var PAD = "=";
	                                var ret = "";
	                                var leftchar = 0;
	                                var leftbits = 0;
	                                for (var i = 0; i < data.length; i++) {
	                                    leftchar = leftchar << 8 | data[i];
	                                    leftbits += 8;
	                                    while (leftbits >= 6) {
	                                        var curr = leftchar >> leftbits - 6 & 63;
	                                        leftbits -= 6;
	                                        ret += BASE[curr]
	                                    }
	                                }
	                                if (leftbits == 2) {
	                                    ret += BASE[(leftchar & 3) << 4];
	                                    ret += PAD + PAD
	                                } else if (leftbits == 4) {
	                                    ret += BASE[(leftchar & 15) << 2];
	                                    ret += PAD
	                                }
	                                return ret
	                            }

	                            audio.src = "data:audio/x-" + name.substr(-3) + ";base64," + encode64(byteArray);
	                            finish(audio)
	                        };
	                        audio.src = url;
	                        Browser.safeSetTimeout((function () {
	                            finish(audio)
	                        }), 1e4)
	                    } else {
	                        return fail()
	                    }
	                };
	                Module["preloadPlugins"].push(audioPlugin);
	                var canvas = Module["canvas"];

	                function pointerLockChange() {
	                    Browser.pointerLock = document["pointerLockElement"] === canvas || document["mozPointerLockElement"] === canvas || document["webkitPointerLockElement"] === canvas || document["msPointerLockElement"] === canvas
	                }

	                if (canvas) {
	                    canvas.requestPointerLock = canvas["requestPointerLock"] || canvas["mozRequestPointerLock"] || canvas["webkitRequestPointerLock"] || canvas["msRequestPointerLock"] || (function () {
	                        });
	                    canvas.exitPointerLock = document["exitPointerLock"] || document["mozExitPointerLock"] || document["webkitExitPointerLock"] || document["msExitPointerLock"] || (function () {
	                        });
	                    canvas.exitPointerLock = canvas.exitPointerLock.bind(document);
	                    document.addEventListener("pointerlockchange", pointerLockChange, false);
	                    document.addEventListener("mozpointerlockchange", pointerLockChange, false);
	                    document.addEventListener("webkitpointerlockchange", pointerLockChange, false);
	                    document.addEventListener("mspointerlockchange", pointerLockChange, false);
	                    if (Module["elementPointerLock"]) {
	                        canvas.addEventListener("click", (function (ev) {
	                            if (!Browser.pointerLock && canvas.requestPointerLock) {
	                                canvas.requestPointerLock();
	                                ev.preventDefault()
	                            }
	                        }), false)
	                    }
	                }
	            }),
	            createContext: (function (canvas, useWebGL, setInModule, webGLContextAttributes) {
	                if (useWebGL && Module.ctx && canvas == Module.canvas)return Module.ctx;
	                var ctx;
	                var contextHandle;
	                if (useWebGL) {
	                    var contextAttributes = {antialias: false, alpha: false};
	                    if (webGLContextAttributes) {
	                        for (var attribute in webGLContextAttributes) {
	                            contextAttributes[attribute] = webGLContextAttributes[attribute]
	                        }
	                    }
	                    contextHandle = GL.createContext(canvas, contextAttributes);
	                    if (contextHandle) {
	                        ctx = GL.getContext(contextHandle).GLctx
	                    }
	                    canvas.style.backgroundColor = "black"
	                } else {
	                    ctx = canvas.getContext("2d")
	                }
	                if (!ctx)return null;
	                if (setInModule) {
	                    if (!useWebGL)assert(typeof GLctx === "undefined", "cannot set in module if GLctx is used, but we are a non-GL context that would replace it");
	                    Module.ctx = ctx;
	                    if (useWebGL)GL.makeContextCurrent(contextHandle);
	                    Module.useWebGL = useWebGL;
	                    Browser.moduleContextCreatedCallbacks.forEach((function (callback) {
	                        callback()
	                    }));
	                    Browser.init()
	                }
	                return ctx
	            }),
	            destroyContext: (function (canvas, useWebGL, setInModule) {
	            }),
	            fullScreenHandlersInstalled: false,
	            lockPointer: undefined,
	            resizeCanvas: undefined,
	            requestFullScreen: (function (lockPointer, resizeCanvas) {
	                Browser.lockPointer = lockPointer;
	                Browser.resizeCanvas = resizeCanvas;
	                if (typeof Browser.lockPointer === "undefined")Browser.lockPointer = true;
	                if (typeof Browser.resizeCanvas === "undefined")Browser.resizeCanvas = false;
	                var canvas = Module["canvas"];

	                function fullScreenChange() {
	                    Browser.isFullScreen = false;
	                    var canvasContainer = canvas.parentNode;
	                    if ((document["webkitFullScreenElement"] || document["webkitFullscreenElement"] || document["mozFullScreenElement"] || document["mozFullscreenElement"] || document["fullScreenElement"] || document["fullscreenElement"] || document["msFullScreenElement"] || document["msFullscreenElement"] || document["webkitCurrentFullScreenElement"]) === canvasContainer) {
	                        canvas.cancelFullScreen = document["cancelFullScreen"] || document["mozCancelFullScreen"] || document["webkitCancelFullScreen"] || document["msExitFullscreen"] || document["exitFullscreen"] || (function () {
	                            });
	                        canvas.cancelFullScreen = canvas.cancelFullScreen.bind(document);
	                        if (Browser.lockPointer)canvas.requestPointerLock();
	                        Browser.isFullScreen = true;
	                        if (Browser.resizeCanvas)Browser.setFullScreenCanvasSize()
	                    } else {
	                        canvasContainer.parentNode.insertBefore(canvas, canvasContainer);
	                        canvasContainer.parentNode.removeChild(canvasContainer);
	                        if (Browser.resizeCanvas)Browser.setWindowedCanvasSize()
	                    }
	                    if (Module["onFullScreen"])Module["onFullScreen"](Browser.isFullScreen);
	                    Browser.updateCanvasDimensions(canvas)
	                }

	                if (!Browser.fullScreenHandlersInstalled) {
	                    Browser.fullScreenHandlersInstalled = true;
	                    document.addEventListener("fullscreenchange", fullScreenChange, false);
	                    document.addEventListener("mozfullscreenchange", fullScreenChange, false);
	                    document.addEventListener("webkitfullscreenchange", fullScreenChange, false);
	                    document.addEventListener("MSFullscreenChange", fullScreenChange, false)
	                }
	                var canvasContainer = document.createElement("div");
	                canvas.parentNode.insertBefore(canvasContainer, canvas);
	                canvasContainer.appendChild(canvas);
	                canvasContainer.requestFullScreen = canvasContainer["requestFullScreen"] || canvasContainer["mozRequestFullScreen"] || canvasContainer["msRequestFullscreen"] || (canvasContainer["webkitRequestFullScreen"] ? (function () {
	                        canvasContainer["webkitRequestFullScreen"](Element["ALLOW_KEYBOARD_INPUT"])
	                    }) : null);
	                canvasContainer.requestFullScreen()
	            }),
	            nextRAF: 0,
	            fakeRequestAnimationFrame: (function (func) {
	                var now = Date.now();
	                if (Browser.nextRAF === 0) {
	                    Browser.nextRAF = now + 1e3 / 60
	                } else {
	                    while (now + 2 >= Browser.nextRAF) {
	                        Browser.nextRAF += 1e3 / 60
	                    }
	                }
	                var delay = Math.max(Browser.nextRAF - now, 0);
	                setTimeout(func, delay)
	            }),
	            requestAnimationFrame: function requestAnimationFrame(func) {
	                if (typeof window === "undefined") {
	                    Browser.fakeRequestAnimationFrame(func)
	                } else {
	                    if (!window.requestAnimationFrame) {
	                        window.requestAnimationFrame = window["requestAnimationFrame"] || window["mozRequestAnimationFrame"] || window["webkitRequestAnimationFrame"] || window["msRequestAnimationFrame"] || window["oRequestAnimationFrame"] || Browser.fakeRequestAnimationFrame
	                    }
	                    window.requestAnimationFrame(func)
	                }
	            },
	            safeCallback: (function (func) {
	                return (function () {
	                    if (!ABORT)return func.apply(null, arguments)
	                })
	            }),
	            safeRequestAnimationFrame: (function (func) {
	                return Browser.requestAnimationFrame((function () {
	                    if (!ABORT)func()
	                }))
	            }),
	            safeSetTimeout: (function (func, timeout) {
	                Module["noExitRuntime"] = true;
	                return setTimeout((function () {
	                    if (!ABORT)func()
	                }), timeout)
	            }),
	            safeSetInterval: (function (func, timeout) {
	                Module["noExitRuntime"] = true;
	                return setInterval((function () {
	                    if (!ABORT)func()
	                }), timeout)
	            }),
	            getMimetype: (function (name) {
	                return {
	                    "jpg": "image/jpeg",
	                    "jpeg": "image/jpeg",
	                    "png": "image/png",
	                    "bmp": "image/bmp",
	                    "ogg": "audio/ogg",
	                    "wav": "audio/wav",
	                    "mp3": "audio/mpeg"
	                }[name.substr(name.lastIndexOf(".") + 1)]
	            }),
	            getUserMedia: (function (func) {
	                if (!window.getUserMedia) {
	                    window.getUserMedia = navigator["getUserMedia"] || navigator["mozGetUserMedia"]
	                }
	                window.getUserMedia(func)
	            }),
	            getMovementX: (function (event) {
	                return event["movementX"] || event["mozMovementX"] || event["webkitMovementX"] || 0
	            }),
	            getMovementY: (function (event) {
	                return event["movementY"] || event["mozMovementY"] || event["webkitMovementY"] || 0
	            }),
	            getMouseWheelDelta: (function (event) {
	                var delta = 0;
	                switch (event.type) {
	                    case"DOMMouseScroll":
	                        delta = event.detail;
	                        break;
	                    case"mousewheel":
	                        delta = event.wheelDelta;
	                        break;
	                    case"wheel":
	                        delta = event["deltaY"];
	                        break;
	                    default:
	                        throw"unrecognized mouse wheel event: " + event.type
	                }
	                return delta
	            }),
	            mouseX: 0,
	            mouseY: 0,
	            mouseMovementX: 0,
	            mouseMovementY: 0,
	            touches: {},
	            lastTouches: {},
	            calculateMouseEvent: (function (event) {
	                if (Browser.pointerLock) {
	                    if (event.type != "mousemove" && "mozMovementX" in event) {
	                        Browser.mouseMovementX = Browser.mouseMovementY = 0
	                    } else {
	                        Browser.mouseMovementX = Browser.getMovementX(event);
	                        Browser.mouseMovementY = Browser.getMovementY(event)
	                    }
	                    if (typeof SDL != "undefined") {
	                        Browser.mouseX = SDL.mouseX + Browser.mouseMovementX;
	                        Browser.mouseY = SDL.mouseY + Browser.mouseMovementY
	                    } else {
	                        Browser.mouseX += Browser.mouseMovementX;
	                        Browser.mouseY += Browser.mouseMovementY
	                    }
	                } else {
	                    var rect = Module["canvas"].getBoundingClientRect();
	                    var cw = Module["canvas"].width;
	                    var ch = Module["canvas"].height;
	                    var scrollX = typeof window.scrollX !== "undefined" ? window.scrollX : window.pageXOffset;
	                    var scrollY = typeof window.scrollY !== "undefined" ? window.scrollY : window.pageYOffset;
	                    if (event.type === "touchstart" || event.type === "touchend" || event.type === "touchmove") {
	                        var touch = event.touch;
	                        if (touch === undefined) {
	                            return
	                        }
	                        var adjustedX = touch.pageX - (scrollX + rect.left);
	                        var adjustedY = touch.pageY - (scrollY + rect.top);
	                        adjustedX = adjustedX * (cw / rect.width);
	                        adjustedY = adjustedY * (ch / rect.height);
	                        var coords = {x: adjustedX, y: adjustedY};
	                        if (event.type === "touchstart") {
	                            Browser.lastTouches[touch.identifier] = coords;
	                            Browser.touches[touch.identifier] = coords
	                        } else if (event.type === "touchend" || event.type === "touchmove") {
	                            Browser.lastTouches[touch.identifier] = Browser.touches[touch.identifier];
	                            Browser.touches[touch.identifier] = {x: adjustedX, y: adjustedY}
	                        }
	                        return
	                    }
	                    var x = event.pageX - (scrollX + rect.left);
	                    var y = event.pageY - (scrollY + rect.top);
	                    x = x * (cw / rect.width);
	                    y = y * (ch / rect.height);
	                    Browser.mouseMovementX = x - Browser.mouseX;
	                    Browser.mouseMovementY = y - Browser.mouseY;
	                    Browser.mouseX = x;
	                    Browser.mouseY = y
	                }
	            }),
	            xhrLoad: (function (url, onload, onerror) {
	                var xhr = new XMLHttpRequest;
	                xhr.open("GET", url, true);
	                xhr.responseType = "arraybuffer";
	                xhr.onload = function xhr_onload() {
	                    if (xhr.status == 200 || xhr.status == 0 && xhr.response) {
	                        onload(xhr.response)
	                    } else {
	                        onerror()
	                    }
	                };
	                xhr.onerror = onerror;
	                xhr.send(null)
	            }),
	            asyncLoad: (function (url, onload, onerror, noRunDep) {
	                Browser.xhrLoad(url, (function (arrayBuffer) {
	                    assert(arrayBuffer, 'Loading data file "' + url + '" failed (no arrayBuffer).');
	                    onload(new Uint8Array(arrayBuffer));
	                    if (!noRunDep)removeRunDependency("al " + url)
	                }), (function (event) {
	                    if (onerror) {
	                        onerror()
	                    } else {
	                        throw'Loading data file "' + url + '" failed.'
	                    }
	                }));
	                if (!noRunDep)addRunDependency("al " + url)
	            }),
	            resizeListeners: [],
	            updateResizeListeners: (function () {
	                var canvas = Module["canvas"];
	                Browser.resizeListeners.forEach((function (listener) {
	                    listener(canvas.width, canvas.height)
	                }))
	            }),
	            setCanvasSize: (function (width, height, noUpdates) {
	                var canvas = Module["canvas"];
	                Browser.updateCanvasDimensions(canvas, width, height);
	                if (!noUpdates)Browser.updateResizeListeners()
	            }),
	            windowedWidth: 0,
	            windowedHeight: 0,
	            setFullScreenCanvasSize: (function () {
	                if (typeof SDL != "undefined") {
	                    var flags = HEAPU32[SDL.screen + Runtime.QUANTUM_SIZE * 0 >> 2];
	                    flags = flags | 8388608;
	                    HEAP32[SDL.screen + Runtime.QUANTUM_SIZE * 0 >> 2] = flags
	                }
	                Browser.updateResizeListeners()
	            }),
	            setWindowedCanvasSize: (function () {
	                if (typeof SDL != "undefined") {
	                    var flags = HEAPU32[SDL.screen + Runtime.QUANTUM_SIZE * 0 >> 2];
	                    flags = flags & ~8388608;
	                    HEAP32[SDL.screen + Runtime.QUANTUM_SIZE * 0 >> 2] = flags
	                }
	                Browser.updateResizeListeners()
	            }),
	            updateCanvasDimensions: (function (canvas, wNative, hNative) {
	                if (wNative && hNative) {
	                    canvas.widthNative = wNative;
	                    canvas.heightNative = hNative
	                } else {
	                    wNative = canvas.widthNative;
	                    hNative = canvas.heightNative
	                }
	                var w = wNative;
	                var h = hNative;
	                if (Module["forcedAspectRatio"] && Module["forcedAspectRatio"] > 0) {
	                    if (w / h < Module["forcedAspectRatio"]) {
	                        w = Math.round(h * Module["forcedAspectRatio"])
	                    } else {
	                        h = Math.round(w / Module["forcedAspectRatio"])
	                    }
	                }
	                if ((document["webkitFullScreenElement"] || document["webkitFullscreenElement"] || document["mozFullScreenElement"] || document["mozFullscreenElement"] || document["fullScreenElement"] || document["fullscreenElement"] || document["msFullScreenElement"] || document["msFullscreenElement"] || document["webkitCurrentFullScreenElement"]) === canvas.parentNode && typeof screen != "undefined") {
	                    var factor = Math.min(screen.width / w, screen.height / h);
	                    w = Math.round(w * factor);
	                    h = Math.round(h * factor)
	                }
	                if (Browser.resizeCanvas) {
	                    if (canvas.width != w)canvas.width = w;
	                    if (canvas.height != h)canvas.height = h;
	                    if (typeof canvas.style != "undefined") {
	                        canvas.style.removeProperty("width");
	                        canvas.style.removeProperty("height")
	                    }
	                } else {
	                    if (canvas.width != wNative)canvas.width = wNative;
	                    if (canvas.height != hNative)canvas.height = hNative;
	                    if (typeof canvas.style != "undefined") {
	                        if (w != wNative || h != hNative) {
	                            canvas.style.setProperty("width", w + "px", "important");
	                            canvas.style.setProperty("height", h + "px", "important")
	                        } else {
	                            canvas.style.removeProperty("width");
	                            canvas.style.removeProperty("height")
	                        }
	                    }
	                }
	            }),
	            wgetRequests: {},
	            nextWgetRequestHandle: 0,
	            getNextWgetRequestHandle: (function () {
	                var handle = Browser.nextWgetRequestHandle;
	                Browser.nextWgetRequestHandle++;
	                return handle
	            })
	        };

	        function _munmap(start, num) {
	            if (!_mmap.mappings)_mmap.mappings = {};
	            var info = _mmap.mappings[start];
	            if (!info)return 0;
	            if (num == info.num) {
	                _mmap.mappings[start] = null;
	                if (info.allocated) {
	                    _free(info.malloc)
	                }
	            }
	            return 0
	        }

	        function _stat(path, buf, dontResolveLastLink) {
	            path = typeof path !== "string" ? Pointer_stringify(path) : path;
	            try {
	                var stat = dontResolveLastLink ? FS.lstat(path) : FS.stat(path);
	                HEAP32[buf >> 2] = stat.dev;
	                HEAP32[buf + 4 >> 2] = 0;
	                HEAP32[buf + 8 >> 2] = stat.ino;
	                HEAP32[buf + 12 >> 2] = stat.mode;
	                HEAP32[buf + 16 >> 2] = stat.nlink;
	                HEAP32[buf + 20 >> 2] = stat.uid;
	                HEAP32[buf + 24 >> 2] = stat.gid;
	                HEAP32[buf + 28 >> 2] = stat.rdev;
	                HEAP32[buf + 32 >> 2] = 0;
	                HEAP32[buf + 36 >> 2] = stat.size;
	                HEAP32[buf + 40 >> 2] = 4096;
	                HEAP32[buf + 44 >> 2] = stat.blocks;
	                HEAP32[buf + 48 >> 2] = stat.atime.getTime() / 1e3 | 0;
	                HEAP32[buf + 52 >> 2] = 0;
	                HEAP32[buf + 56 >> 2] = stat.mtime.getTime() / 1e3 | 0;
	                HEAP32[buf + 60 >> 2] = 0;
	                HEAP32[buf + 64 >> 2] = stat.ctime.getTime() / 1e3 | 0;
	                HEAP32[buf + 68 >> 2] = 0;
	                HEAP32[buf + 72 >> 2] = stat.ino;
	                return 0
	            } catch (e) {
	                if (e.node && PATH.normalize(path) !== PATH.normalize(FS.getPath(e.node))) {
	                    e.setErrno(ERRNO_CODES.ENOTDIR)
	                }
	                FS.handleFSError(e);
	                return -1
	            }
	        }

	        function _sysconf(name) {
	            switch (name) {
	                case 30:
	                    return PAGE_SIZE;
	                case 132:
	                case 133:
	                case 12:
	                case 137:
	                case 138:
	                case 15:
	                case 235:
	                case 16:
	                case 17:
	                case 18:
	                case 19:
	                case 20:
	                case 149:
	                case 13:
	                case 10:
	                case 236:
	                case 153:
	                case 9:
	                case 21:
	                case 22:
	                case 159:
	                case 154:
	                case 14:
	                case 77:
	                case 78:
	                case 139:
	                case 80:
	                case 81:
	                case 79:
	                case 82:
	                case 68:
	                case 67:
	                case 164:
	                case 11:
	                case 29:
	                case 47:
	                case 48:
	                case 95:
	                case 52:
	                case 51:
	                case 46:
	                    return 200809;
	                case 27:
	                case 246:
	                case 127:
	                case 128:
	                case 23:
	                case 24:
	                case 160:
	                case 161:
	                case 181:
	                case 182:
	                case 242:
	                case 183:
	                case 184:
	                case 243:
	                case 244:
	                case 245:
	                case 165:
	                case 178:
	                case 179:
	                case 49:
	                case 50:
	                case 168:
	                case 169:
	                case 175:
	                case 170:
	                case 171:
	                case 172:
	                case 97:
	                case 76:
	                case 32:
	                case 173:
	                case 35:
	                    return -1;
	                case 176:
	                case 177:
	                case 7:
	                case 155:
	                case 8:
	                case 157:
	                case 125:
	                case 126:
	                case 92:
	                case 93:
	                case 129:
	                case 130:
	                case 131:
	                case 94:
	                case 91:
	                    return 1;
	                case 74:
	                case 60:
	                case 69:
	                case 70:
	                case 4:
	                    return 1024;
	                case 31:
	                case 42:
	                case 72:
	                    return 32;
	                case 87:
	                case 26:
	                case 33:
	                    return 2147483647;
	                case 34:
	                case 1:
	                    return 47839;
	                case 38:
	                case 36:
	                    return 99;
	                case 43:
	                case 37:
	                    return 2048;
	                case 0:
	                    return 2097152;
	                case 3:
	                    return 65536;
	                case 28:
	                    return 32768;
	                case 44:
	                    return 32767;
	                case 75:
	                    return 16384;
	                case 39:
	                    return 1e3;
	                case 89:
	                    return 700;
	                case 71:
	                    return 256;
	                case 40:
	                    return 255;
	                case 2:
	                    return 100;
	                case 180:
	                    return 64;
	                case 25:
	                    return 20;
	                case 5:
	                    return 16;
	                case 6:
	                    return 6;
	                case 73:
	                    return 4;
	                case 84:
	                {
	                    if (typeof navigator === "object")return navigator["hardwareConcurrency"] || 1;
	                    return 1
	                }
	            }
	            ___setErrNo(ERRNO_CODES.EINVAL);
	            return -1
	        }

	        Module["_bitshift64Lshr"] = _bitshift64Lshr;
	        var _BDtoILow = true;

	        function _ferror(stream) {
	            stream = FS.getStreamFromPtr(stream);
	            return Number(stream && stream.error)
	        }

	        var _BDtoIHigh = true;

	        function _getcwd(buf, size) {
	            if (size == 0) {
	                ___setErrNo(ERRNO_CODES.EINVAL);
	                return 0
	            }
	            var cwd = FS.cwd();
	            if (size < cwd.length + 1) {
	                ___setErrNo(ERRNO_CODES.ERANGE);
	                return 0
	            } else {
	                writeAsciiToMemory(cwd, buf);
	                return buf
	            }
	        }

	        var _environ = allocate(1, "i32*", ALLOC_STATIC);
	        var ___environ = _environ;

	        function ___buildEnvironment(env) {
	            var MAX_ENV_VALUES = 64;
	            var TOTAL_ENV_SIZE = 1024;
	            var poolPtr;
	            var envPtr;
	            if (!___buildEnvironment.called) {
	                ___buildEnvironment.called = true;
	                ENV["USER"] = "web_user";
	                ENV["PATH"] = "/";
	                ENV["PWD"] = "/";
	                ENV["HOME"] = "/home/web_user";
	                ENV["LANG"] = "C";
	                ENV["_"] = Module["thisProgram"];
	                poolPtr = allocate(TOTAL_ENV_SIZE, "i8", ALLOC_STATIC);
	                envPtr = allocate(MAX_ENV_VALUES * 4, "i8*", ALLOC_STATIC);
	                HEAP32[envPtr >> 2] = poolPtr;
	                HEAP32[_environ >> 2] = envPtr
	            } else {
	                envPtr = HEAP32[_environ >> 2];
	                poolPtr = HEAP32[envPtr >> 2]
	            }
	            var strings = [];
	            var totalSize = 0;
	            for (var key in env) {
	                if (typeof env[key] === "string") {
	                    var line = key + "=" + env[key];
	                    strings.push(line);
	                    totalSize += line.length
	                }
	            }
	            if (totalSize > TOTAL_ENV_SIZE) {
	                throw new Error("Environment size exceeded TOTAL_ENV_SIZE!")
	            }
	            var ptrSize = 4;
	            for (var i = 0; i < strings.length; i++) {
	                var line = strings[i];
	                writeAsciiToMemory(line, poolPtr);
	                HEAP32[envPtr + i * ptrSize >> 2] = poolPtr;
	                poolPtr += line.length + 1
	            }
	            HEAP32[envPtr + strings.length * ptrSize >> 2] = 0
	        }

	        var ENV = {};

	        function _getenv(name) {
	            if (name === 0)return 0;
	            name = Pointer_stringify(name);
	            if (!ENV.hasOwnProperty(name))return 0;
	            if (_getenv.ret)_free(_getenv.ret);
	            _getenv.ret = allocate(intArrayFromString(ENV[name]), "i8", ALLOC_NORMAL);
	            return _getenv.ret
	        }

	        var _labs = Math_abs;

	        function _gettimeofday(ptr) {
	            var now = Date.now();
	            HEAP32[ptr >> 2] = now / 1e3 | 0;
	            HEAP32[ptr + 4 >> 2] = now % 1e3 * 1e3 | 0;
	            return 0
	        }

	        function _vfprintf(s, f, va_arg) {
	            return _fprintf(s, f, HEAP32[va_arg >> 2])
	        }

	        function _emscripten_memcpy_big(dest, src, num) {
	            HEAPU8.set(HEAPU8.subarray(src, src + num), dest);
	            return dest
	        }

	        Module["_memcpy"] = _memcpy;
	        var _llvm_pow_f64 = Math_pow;

	        function _sbrk(bytes) {
	            var self = _sbrk;
	            if (!self.called) {
	                DYNAMICTOP = alignMemoryPage(DYNAMICTOP);
	                self.called = true;
	                assert(Runtime.dynamicAlloc);
	                self.alloc = Runtime.dynamicAlloc;
	                Runtime.dynamicAlloc = (function () {
	                    abort("cannot dynamically allocate, sbrk now has control")
	                })
	            }
	            var ret = DYNAMICTOP;
	            if (bytes != 0)self.alloc(bytes);
	            return ret
	        }

	        Module["_memmove"] = _memmove;
	        function ___errno_location() {
	            return ___errno_state
	        }

	        var _BItoD = true;
	        Module["_strcpy"] = _strcpy;
	        function _time(ptr) {
	            var ret = Date.now() / 1e3 | 0;
	            if (ptr) {
	                HEAP32[ptr >> 2] = ret
	            }
	            return ret
	        }

	        var ctlz_i8 = allocate([8, 7, 6, 6, 5, 5, 5, 5, 4, 4, 4, 4, 4, 4, 4, 4, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 3, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 2, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], "i8", ALLOC_STATIC);
	        Module["_llvm_ctlz_i32"] = _llvm_ctlz_i32;
	        function _llvm_ctlz_i64(l, h) {
	            var ret = _llvm_ctlz_i32(h);
	            if (ret == 32)ret += _llvm_ctlz_i32(l);
	            return (asm["setTempRet0"](0), ret) | 0
	        }

	        FS.staticInit();
	        __ATINIT__.unshift({
	            func: (function () {
	                if (!Module["noFSInit"] && !FS.init.initialized)FS.init()
	            })
	        });
	        __ATMAIN__.push({
	            func: (function () {
	                FS.ignorePermissions = false
	            })
	        });
	        __ATEXIT__.push({
	            func: (function () {
	                FS.quit()
	            })
	        });
	        Module["FS_createFolder"] = FS.createFolder;
	        Module["FS_createPath"] = FS.createPath;
	        Module["FS_createDataFile"] = FS.createDataFile;
	        Module["FS_createPreloadedFile"] = FS.createPreloadedFile;
	        Module["FS_createLazyFile"] = FS.createLazyFile;
	        Module["FS_createLink"] = FS.createLink;
	        Module["FS_createDevice"] = FS.createDevice;
	        ___errno_state = Runtime.staticAlloc(4);
	        HEAP32[___errno_state >> 2] = 0;
	        __ATINIT__.unshift({
	            func: (function () {
	                TTY.init()
	            })
	        });
	        __ATEXIT__.push({
	            func: (function () {
	                TTY.shutdown()
	            })
	        });
	        TTY.utf8 = new Runtime.UTF8Processor;
	        
	        __ATINIT__.push({
	            func: (function () {
	                SOCKFS.root = FS.mount(SOCKFS, {}, null)
	            })
	        });
	        _fgetc.ret = allocate([0], "i8", ALLOC_STATIC);
	        _fputc.ret = allocate([0], "i8", ALLOC_STATIC);
	        Module["requestFullScreen"] = function Module_requestFullScreen(lockPointer, resizeCanvas) {
	            Browser.requestFullScreen(lockPointer, resizeCanvas)
	        };
	        Module["requestAnimationFrame"] = function Module_requestAnimationFrame(func) {
	            Browser.requestAnimationFrame(func)
	        };
	        Module["setCanvasSize"] = function Module_setCanvasSize(width, height, noUpdates) {
	            Browser.setCanvasSize(width, height, noUpdates)
	        };
	        Module["pauseMainLoop"] = function Module_pauseMainLoop() {
	            Browser.mainLoop.pause()
	        };
	        Module["resumeMainLoop"] = function Module_resumeMainLoop() {
	            Browser.mainLoop.resume()
	        };
	        Module["getUserMedia"] = function Module_getUserMedia() {
	            Browser.getUserMedia()
	        };
	        ___buildEnvironment(ENV);
	        STACK_BASE = STACKTOP = Runtime.alignMemory(STATICTOP);
	        staticSealed = true;
	        STACK_MAX = STACK_BASE + TOTAL_STACK;
	        DYNAMIC_BASE = DYNAMICTOP = Runtime.alignMemory(STACK_MAX);
	        assert(DYNAMIC_BASE < TOTAL_MEMORY, "TOTAL_MEMORY not big enough for stack");
	        var cttz_i8 = allocate([8, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 4, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 5, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 4, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 6, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 4, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 5, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 4, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 7, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 4, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 5, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 4, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 6, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 4, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 5, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0, 4, 0, 1, 0, 2, 0, 1, 0, 3, 0, 1, 0, 2, 0, 1, 0], "i8", ALLOC_DYNAMIC);

	        function invoke_iiiiiiii(index, a1, a2, a3, a4, a5, a6, a7) {
	            try {
	                return Module["dynCall_iiiiiiii"](index, a1, a2, a3, a4, a5, a6, a7)
	            } catch (e) {
	                if (typeof e !== "number" && e !== "longjmp")throw e;
	                asm["setThrew"](1, 0)
	            }
	        }

	        function invoke_iiii(index, a1, a2, a3) {
	            try {
	                return Module["dynCall_iiii"](index, a1, a2, a3)
	            } catch (e) {
	                if (typeof e !== "number" && e !== "longjmp")throw e;
	                asm["setThrew"](1, 0)
	            }
	        }

	        function invoke_viiiiiii(index, a1, a2, a3, a4, a5, a6, a7) {
	            try {
	                Module["dynCall_viiiiiii"](index, a1, a2, a3, a4, a5, a6, a7)
	            } catch (e) {
	                if (typeof e !== "number" && e !== "longjmp")throw e;
	                asm["setThrew"](1, 0)
	            }
	        }

	        function invoke_viiiii(index, a1, a2, a3, a4, a5) {
	            try {
	                Module["dynCall_viiiii"](index, a1, a2, a3, a4, a5)
	            } catch (e) {
	                if (typeof e !== "number" && e !== "longjmp")throw e;
	                asm["setThrew"](1, 0)
	            }
	        }

	        function invoke_i(index) {
	            try {
	                return Module["dynCall_i"](index)
	            } catch (e) {
	                if (typeof e !== "number" && e !== "longjmp")throw e;
	                asm["setThrew"](1, 0)
	            }
	        }

	        function invoke_vi(index, a1) {
	            try {
	                Module["dynCall_vi"](index, a1)
	            } catch (e) {
	                if (typeof e !== "number" && e !== "longjmp")throw e;
	                asm["setThrew"](1, 0)
	            }
	        }

	        function invoke_vii(index, a1, a2) {
	            try {
	                Module["dynCall_vii"](index, a1, a2)
	            } catch (e) {
	                if (typeof e !== "number" && e !== "longjmp")throw e;
	                asm["setThrew"](1, 0)
	            }
	        }

	        function invoke_iiiiiii(index, a1, a2, a3, a4, a5, a6) {
	            try {
	                return Module["dynCall_iiiiiii"](index, a1, a2, a3, a4, a5, a6)
	            } catch (e) {
	                if (typeof e !== "number" && e !== "longjmp")throw e;
	                asm["setThrew"](1, 0)
	            }
	        }

	        function invoke_ii(index, a1) {
	            try {
	                return Module["dynCall_ii"](index, a1)
	            } catch (e) {
	                if (typeof e !== "number" && e !== "longjmp")throw e;
	                asm["setThrew"](1, 0)
	            }
	        }

	        function invoke_viii(index, a1, a2, a3) {
	            try {
	                Module["dynCall_viii"](index, a1, a2, a3)
	            } catch (e) {
	                if (typeof e !== "number" && e !== "longjmp")throw e;
	                asm["setThrew"](1, 0)
	            }
	        }

	        function invoke_viiiiiiiii(index, a1, a2, a3, a4, a5, a6, a7, a8, a9) {
	            try {
	                Module["dynCall_viiiiiiiii"](index, a1, a2, a3, a4, a5, a6, a7, a8, a9)
	            } catch (e) {
	                if (typeof e !== "number" && e !== "longjmp")throw e;
	                asm["setThrew"](1, 0)
	            }
	        }

	        function invoke_iiiii(index, a1, a2, a3, a4) {
	            try {
	                return Module["dynCall_iiiii"](index, a1, a2, a3, a4)
	            } catch (e) {
	                if (typeof e !== "number" && e !== "longjmp")throw e;
	                asm["setThrew"](1, 0)
	            }
	        }

	        function invoke_viiiiii(index, a1, a2, a3, a4, a5, a6) {
	            try {
	                Module["dynCall_viiiiii"](index, a1, a2, a3, a4, a5, a6)
	            } catch (e) {
	                if (typeof e !== "number" && e !== "longjmp")throw e;
	                asm["setThrew"](1, 0)
	            }
	        }

	        function invoke_iii(index, a1, a2) {
	            try {
	                return Module["dynCall_iii"](index, a1, a2)
	            } catch (e) {
	                if (typeof e !== "number" && e !== "longjmp")throw e;
	                asm["setThrew"](1, 0)
	            }
	        }

	        function invoke_iiiiii(index, a1, a2, a3, a4, a5) {
	            try {
	                return Module["dynCall_iiiiii"](index, a1, a2, a3, a4, a5)
	            } catch (e) {
	                if (typeof e !== "number" && e !== "longjmp")throw e;
	                asm["setThrew"](1, 0)
	            }
	        }

	        function invoke_viiii(index, a1, a2, a3, a4) {
	            try {
	                Module["dynCall_viiii"](index, a1, a2, a3, a4)
	            } catch (e) {
	                if (typeof e !== "number" && e !== "longjmp")throw e;
	                asm["setThrew"](1, 0)
	            }
	        }

	        Module.asmGlobalArg = {
	            "Math": Math,
	            "Int8Array": Int8Array,
	            "Int16Array": Int16Array,
	            "Int32Array": Int32Array,
	            "Uint8Array": Uint8Array,
	            "Uint16Array": Uint16Array,
	            "Uint32Array": Uint32Array,
	            "Float32Array": Float32Array,
	            "Float64Array": Float64Array
	        };
	        Module.asmLibraryArg = {
	            "abort": abort,
	            "assert": assert,
	            "min": Math_min,
	            "invoke_iiiiiiii": invoke_iiiiiiii,
	            "invoke_iiii": invoke_iiii,
	            "invoke_viiiiiii": invoke_viiiiiii,
	            "invoke_viiiii": invoke_viiiii,
	            "invoke_i": invoke_i,
	            "invoke_vi": invoke_vi,
	            "invoke_vii": invoke_vii,
	            "invoke_iiiiiii": invoke_iiiiiii,
	            "invoke_ii": invoke_ii,
	            "invoke_viii": invoke_viii,
	            "invoke_viiiiiiiii": invoke_viiiiiiiii,
	            "invoke_iiiii": invoke_iiiii,
	            "invoke_viiiiii": invoke_viiiiii,
	            "invoke_iii": invoke_iii,
	            "invoke_iiiiii": invoke_iiiiii,
	            "invoke_viiii": invoke_viiii,
	            "_fabs": _fabs,
	            "_llvm_pow_f64": _llvm_pow_f64,
	            "_send": _send,
	            "_getcwd": _getcwd,
	            "_fread": _fread,
	            "__reallyNegative": __reallyNegative,
	            "_vfprintf": _vfprintf,
	            "_emscripten_set_main_loop_timing": _emscripten_set_main_loop_timing,
	            "___assert_fail": ___assert_fail,
	            "_floor": _floor,
	            "_fflush": _fflush,
	            "_llvm_ctlz_i64": _llvm_ctlz_i64,
	            "_pwrite": _pwrite,
	            "_strerror_r": _strerror_r,
	            "_fprintf": _fprintf,
	            "_open": _open,
	            "_sbrk": _sbrk,
	            "_emscripten_memcpy_big": _emscripten_memcpy_big,
	            "_fileno": _fileno,
	            "__formatString": __formatString,
	            "__exit": __exit,
	            "_close": _close,
	            "_ferror": _ferror,
	            "_munmap": _munmap,
	            "___buildEnvironment": ___buildEnvironment,
	            "_pread": _pread,
	            "_printf": _printf,
	            "_fclose": _fclose,
	            "_write": _write,
	            "_fsync": _fsync,
	            "___errno_location": ___errno_location,
	            "_stat": _stat,
	            "_recv": _recv,
	            "_fgetc": _fgetc,
	            "_getenv": _getenv,
	            "_sysconf": _sysconf,
	            "_read": _read,
	            "_fputc": _fputc,
	            "_emscripten_set_main_loop": _emscripten_set_main_loop,
	            "_abort": _abort,
	            "_fwrite": _fwrite,
	            "_time": _time,
	            "_mkport": _mkport,
	            "_strerror": _strerror,
	            "_gettimeofday": _gettimeofday,
	            "_fgets": _fgets,
	            "_mmap": _mmap,
	            "_fopen": _fopen,
	            "_exit": _exit,
	            "_labs": _labs,
	            "___setErrNo": ___setErrNo,
	            "STACKTOP": STACKTOP,
	            "STACK_MAX": STACK_MAX,
	            "tempDoublePtr": tempDoublePtr,
	            "ABORT": ABORT,
	            "cttz_i8": cttz_i8,
	            "ctlz_i8": ctlz_i8,
	            "NaN": NaN,
	            "Infinity": Infinity,
	            "_stderr": _stderr,
	            "_stdin": _stdin,
	            "_stdout": _stdout
	        };// EMSCRIPTEN_START_ASM
	        var asm = (function (global, env, buffer) {
	            "use asm";
	            var a = new global.Int8Array(buffer);
	            var b = new global.Int16Array(buffer);
	            var c = new global.Int32Array(buffer);
	            var d = new global.Uint8Array(buffer);
	            var e = new global.Uint16Array(buffer);
	            var f = new global.Uint32Array(buffer);
	            var g = new global.Float32Array(buffer);
	            var h = new global.Float64Array(buffer);
	            var i = env.STACKTOP | 0;
	            var j = env.STACK_MAX | 0;
	            var k = env.tempDoublePtr | 0;
	            var l = env.ABORT | 0;
	            var m = env.cttz_i8 | 0;
	            var n = env.ctlz_i8 | 0;
	            var o = env._stderr | 0;
	            var p = env._stdin | 0;
	            var q = env._stdout | 0;
	            var r = 0;
	            var s = 0;
	            var t = 0;
	            var u = 0;
	            var v = +env.NaN, w = +env.Infinity;
	            var x = 0, y = 0, z = 0, A = 0, B = 0.0, C = 0, D = 0, E = 0, F = 0.0;
	            var G = 0;
	            var H = 0;
	            var I = 0;
	            var J = 0;
	            var K = 0;
	            var L = 0;
	            var M = 0;
	            var N = 0;
	            var O = 0;
	            var P = 0;
	            var Q = global.Math.floor;
	            var R = global.Math.abs;
	            var S = global.Math.sqrt;
	            var T = global.Math.pow;
	            var U = global.Math.cos;
	            var V = global.Math.sin;
	            var W = global.Math.tan;
	            var X = global.Math.acos;
	            var Y = global.Math.asin;
	            var Z = global.Math.atan;
	            var _ = global.Math.atan2;
	            var $ = global.Math.exp;
	            var aa = global.Math.log;
	            var ba = global.Math.ceil;
	            var ca = global.Math.imul;
	            var da = env.abort;
	            var ea = env.assert;
	            var fa = env.min;
	            var ga = env.invoke_iiiiiiii;
	            var ha = env.invoke_iiii;
	            var ia = env.invoke_viiiiiii;
	            var ja = env.invoke_viiiii;
	            var ka = env.invoke_i;
	            var la = env.invoke_vi;
	            var ma = env.invoke_vii;
	            var na = env.invoke_iiiiiii;
	            var oa = env.invoke_ii;
	            var pa = env.invoke_viii;
	            var qa = env.invoke_viiiiiiiii;
	            var ra = env.invoke_iiiii;
	            var sa = env.invoke_viiiiii;
	            var ta = env.invoke_iii;
	            var ua = env.invoke_iiiiii;
	            var va = env.invoke_viiii;
	            var wa = env._fabs;
	            var xa = env._llvm_pow_f64;
	            var ya = env._send;
	            var za = env._getcwd;
	            var Aa = env._fread;
	            var Ba = env.__reallyNegative;
	            var Ca = env._vfprintf;
	            var Da = env._emscripten_set_main_loop_timing;
	            var Ea = env.___assert_fail;
	            var Fa = env._floor;
	            var Ga = env._fflush;
	            var Ha = env._llvm_ctlz_i64;
	            var Ia = env._pwrite;
	            var Ja = env._strerror_r;
	            var Ka = env._fprintf;
	            var La = env._open;
	            var Ma = env._sbrk;
	            var Na = env._emscripten_memcpy_big;
	            var Oa = env._fileno;
	            var Pa = env.__formatString;
	            var Qa = env.__exit;
	            var Ra = env._close;
	            var Sa = env._ferror;
	            var Ta = env._munmap;
	            var Ua = env.___buildEnvironment;
	            var Va = env._pread;
	            var Wa = env._printf;
	            var Xa = env._fclose;
	            var Ya = env._write;
	            var Za = env._fsync;
	            var _a = env.___errno_location;
	            var $a = env._stat;
	            var ab = env._recv;
	            var bb = env._fgetc;
	            var cb = env._getenv;
	            var db = env._sysconf;
	            var eb = env._read;
	            var fb = env._fputc;
	            var gb = env._emscripten_set_main_loop;
	            var hb = env._abort;
	            var ib = env._fwrite;
	            var jb = env._time;
	            var kb = env._mkport;
	            var lb = env._strerror;
	            var mb = env._gettimeofday;
	            var nb = env._fgets;
	            var ob = env._mmap;
	            var pb = env._fopen;
	            var qb = env._exit;
	            var rb = env._labs;
	            var sb = env.___setErrNo;
	            var tb = 0.0;
	// EMSCRIPTEN_START_FUNCS
	            function Vo(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                b = i;
	                i = i + 32 | 0;
	                e = b + 20 | 0;
	                f = b + 16 | 0;
	                g = b + 12 | 0;
	                h = b + 8 | 0;
	                j = b + 4 | 0;
	                k = b;
	                c[f >> 2] = a;
	                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 47 : 0) {
	                    a = (c[f >> 2] | 0) + 200 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 2;
	                    a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 2;
	                    a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 2;
	                    c[g >> 2] = Po(c[f >> 2] | 0) | 0;
	                    if (!(c[g >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        l = c[e >> 2] | 0;
	                        i = b;
	                        return l | 0
	                    }
	                    Fo(c[f >> 2] | 0) | 0;
	                    if (9 <= (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)m = 10; else if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13 ? 32 > (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) : 0)m = 11; else m = 10;
	                    if ((m | 0) == 10)if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 62)m = 11; else me(c[f >> 2] | 0);
	                    a:do if ((m | 0) == 11 ? (zo(c[f >> 2] | 0, 73, 95624, 0, 0), (c[(c[f >> 2] | 0) + 288 >> 2] | 0) != 0) : 0) {
	                        while (1) {
	                            n = c[f >> 2] | 0;
	                            if (!(d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0))break;
	                            a = (d[c[(c[n + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 62;
	                            me(c[f >> 2] | 0);
	                            if (!a)break a
	                        }
	                        me(n)
	                    } while (0);
	                    do if ((c[(c[f >> 2] | 0) + 248 >> 2] | 0) > 0) {
	                        if (((qy(c[g >> 2] | 0, 94240) | 0) == 0 ? (qy(c[g >> 2] | 0, 95648) | 0) == 0 : 0) ? (qy(c[g >> 2] | 0, 95656) | 0) == 0 : 0)break;
	                        n = (c[f >> 2] | 0) + 248 | 0;
	                        c[n >> 2] = (c[n >> 2] | 0) + -1;
	                        c[e >> 2] = 0;
	                        l = c[e >> 2] | 0;
	                        i = b;
	                        return l | 0
	                    } while (0);
	                    c[j >> 2] = (c[(c[f >> 2] | 0) + 188 >> 2] | 0) - 1;
	                    while (1) {
	                        if ((c[j >> 2] | 0) < 0)break;
	                        if (qy(c[g >> 2] | 0, c[(c[(c[f >> 2] | 0) + 196 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) | 0)break;
	                        c[j >> 2] = (c[j >> 2] | 0) + -1
	                    }
	                    n = c[f >> 2] | 0;
	                    m = c[g >> 2] | 0;
	                    if ((c[j >> 2] | 0) < 0) {
	                        zo(n, 76, 95664, m, 0);
	                        c[e >> 2] = 0;
	                        l = c[e >> 2] | 0;
	                        i = b;
	                        return l | 0
	                    }
	                    ip(n, m);
	                    if (((qy(c[g >> 2] | 0, c[(c[f >> 2] | 0) + 184 >> 2] | 0) | 0) == 0 ? (c[(c[f >> 2] | 0) + 184 >> 2] | 0) != 0 : 0) ? (qy(c[(c[f >> 2] | 0) + 184 >> 2] | 0, c[g >> 2] | 0) | 0) == 0 : 0)zo(c[f >> 2] | 0, 76, 95696, c[g >> 2] | 0, c[(c[f >> 2] | 0) + 184 >> 2] | 0);
	                    c[h >> 2] = c[(c[f >> 2] | 0) + 184 >> 2];
	                    if ((c[h >> 2] | 0) != 0 ? (qy(c[h >> 2] | 0, c[g >> 2] | 0) | 0) != 0 : 0) {
	                        if ((c[c[f >> 2] >> 2] | 0) != 0 ? (c[(c[c[f >> 2] >> 2] | 0) + 60 >> 2] | 0) != 0 : 0)Ab[c[(c[c[f >> 2] >> 2] | 0) + 60 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0, c[g >> 2] | 0);
	                        jp(c[f >> 2] | 0) | 0;
	                        Co(c[f >> 2] | 0) | 0;
	                        c[k >> 2] = 1
	                    } else c[k >> 2] = 0;
	                    c[e >> 2] = c[k >> 2];
	                    l = c[e >> 2] | 0;
	                    i = b;
	                    return l | 0
	                }
	                zo(c[f >> 2] | 0, 74, 95584, 0, 0);
	                c[e >> 2] = 0;
	                l = c[e >> 2] | 0;
	                i = b;
	                return l | 0
	            }

	            function Wo(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 112 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                j = e + 12 | 0;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                if (!(65 <= (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) <= 90 : 0))k = 3;
	                do if ((k | 0) == 3) {
	                    if (97 <= (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) <= 122 : 0)break;
	                    if ((d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) != 95 ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) != 58 : 0) {
	                        c[f >> 2] = 0;
	                        l = c[f >> 2] | 0;
	                        i = e;
	                        return l | 0
	                    }
	                } while (0);
	                a:while (1) {
	                    if ((c[h >> 2] | 0) >= 100)break;
	                    if (!(65 <= (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + (1 + (c[h >> 2] | 0)) >> 0] | 0 | 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + (1 + (c[h >> 2] | 0)) >> 0] | 0 | 0) <= 90 : 0))k = 11;
	                    do if ((k | 0) == 11) {
	                        k = 0;
	                        if (97 <= (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + (1 + (c[h >> 2] | 0)) >> 0] | 0 | 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + (1 + (c[h >> 2] | 0)) >> 0] | 0 | 0) <= 122 : 0)break;
	                        if (48 <= (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + (1 + (c[h >> 2] | 0)) >> 0] | 0 | 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + (1 + (c[h >> 2] | 0)) >> 0] | 0 | 0) <= 57 : 0)break;
	                        if (((d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + (1 + (c[h >> 2] | 0)) >> 0] | 0 | 0) != 58 ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + (1 + (c[h >> 2] | 0)) >> 0] | 0 | 0) != 45 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + (1 + (c[h >> 2] | 0)) >> 0] | 0 | 0) != 95 : 0)break a
	                    } while (0);
	                    if ((d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + (1 + (c[h >> 2] | 0)) >> 0] | 0 | 0) >= 65 ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + (1 + (c[h >> 2] | 0)) >> 0] | 0 | 0) <= 90 : 0)a[j + (c[h >> 2] | 0) >> 0] = (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + (1 + (c[h >> 2] | 0)) >> 0] | 0) + 32; else a[j + (c[h >> 2] | 0) >> 0] = a[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + (1 + (c[h >> 2] | 0)) >> 0] | 0;
	                    c[h >> 2] = (c[h >> 2] | 0) + 1
	                }
	                c[f >> 2] = AP(c[(c[g >> 2] | 0) + 296 >> 2] | 0, j, c[h >> 2] | 0) | 0;
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function Xo(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 1024 | 0;
	                f = e + 12 | 0;
	                g = e + 16 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[f >> 2] = b;
	                c[h >> 2] = 0;
	                if (((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)le(c[(c[f >> 2] | 0) + 36 >> 2] | 0);
	                c[j >> 2] = ap(c[f >> 2] | 0, k) | 0;
	                a:while (1) {
	                    if (!(9 <= (c[j >> 2] | 0) & (c[j >> 2] | 0) <= 10 | (c[j >> 2] | 0) == 13 | 32 <= (c[j >> 2] | 0)))break;
	                    do if ((c[j >> 2] | 0) == 60 ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 47 : 0) {
	                        b = c[f >> 2] | 0;
	                        if (c[(c[f >> 2] | 0) + 288 >> 2] | 0) {
	                            l = c[b + 184 >> 2] | 0;
	                            m = (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 | 0;
	                            if (!(uy(l, m, xy(c[(c[f >> 2] | 0) + 184 >> 2] | 0) | 0) | 0))break a;
	                            zo(c[f >> 2] | 0, 76, 95912, c[(c[f >> 2] | 0) + 184 >> 2] | 0, 0);
	                            break
	                        }
	                        if ((d[(c[(c[b + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) >= 65 ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) <= 90 : 0)break a;
	                        if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) >= 97 ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) <= 122 : 0)break a
	                    } while (0);
	                    if ((c[k >> 2] | 0) == 1) {
	                        b = c[j >> 2] & 255;
	                        m = c[h >> 2] | 0;
	                        c[h >> 2] = m + 1;
	                        a[g + m >> 0] = b
	                    } else {
	                        b = qe(c[k >> 2] | 0, g + (c[h >> 2] | 0) | 0, c[j >> 2] | 0) | 0;
	                        c[h >> 2] = (c[h >> 2] | 0) + b
	                    }
	                    if ((c[h >> 2] | 0) >= 1e3) {
	                        b = c[c[f >> 2] >> 2] | 0;
	                        if (!(c[(c[c[f >> 2] >> 2] | 0) + 100 >> 2] | 0)) {
	                            if (c[b + 68 >> 2] | 0)Db[c[(c[c[f >> 2] >> 2] | 0) + 68 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0, g, c[h >> 2] | 0)
	                        } else Db[c[b + 100 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0, g, c[h >> 2] | 0);
	                        c[h >> 2] = 0
	                    }
	                    if ((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0;
	                    b = c[(c[f >> 2] | 0) + 36 >> 2] | 0;
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                        m = b + 28 | 0;
	                        c[m >> 2] = (c[m >> 2] | 0) + 1;
	                        c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                    } else {
	                        m = b + 32 | 0;
	                        c[m >> 2] = (c[m >> 2] | 0) + 1
	                    }
	                    c[(c[f >> 2] | 0) + 176 >> 2] = 0;
	                    m = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[m >> 2] = (c[m >> 2] | 0) + (c[k >> 2] | 0);
	                    m = (c[f >> 2] | 0) + 200 | 0;
	                    c[m >> 2] = (c[m >> 2] | 0) + 1;
	                    c[j >> 2] = ap(c[f >> 2] | 0, k) | 0
	                }
	                do if (!(9 <= (c[j >> 2] | 0) & (c[j >> 2] | 0) <= 10 | (c[j >> 2] | 0) == 13 | 32 <= (c[j >> 2] | 0))) {
	                    if ((c[j >> 2] | 0) == 0 ? (c[(c[f >> 2] | 0) + 292 >> 2] | 0) != 0 : 0)break;
	                    Ao(c[f >> 2] | 0, 9, 95944, c[j >> 2] | 0);
	                    if ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) >>> 0 < (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) >>> 0)me(c[f >> 2] | 0)
	                } while (0);
	                if (!(c[h >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                if (!(c[c[f >> 2] >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                if (c[(c[f >> 2] | 0) + 212 >> 2] | 0) {
	                    i = e;
	                    return
	                }
	                j = c[c[f >> 2] >> 2] | 0;
	                if (c[(c[c[f >> 2] >> 2] | 0) + 100 >> 2] | 0) {
	                    Db[c[j + 100 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0, g, c[h >> 2] | 0);
	                    i = e;
	                    return
	                }
	                if (!(c[j + 68 >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                Db[c[(c[c[f >> 2] >> 2] | 0) + 68 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0, g, c[h >> 2] | 0);
	                i = e;
	                return
	            }

	            function Yo(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 32 | 0;
	                g = e + 28 | 0;
	                h = e + 36 | 0;
	                j = e + 24 | 0;
	                k = e + 20 | 0;
	                l = e + 16 | 0;
	                m = e + 12 | 0;
	                n = e + 8 | 0;
	                o = e + 4 | 0;
	                p = e;
	                c[f >> 2] = b;
	                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 38) {
	                    i = e;
	                    return
	                }
	                if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 35) {
	                    c[m >> 2] = 0;
	                    c[k >> 2] = io(c[f >> 2] | 0) | 0;
	                    if (!(c[k >> 2] | 0)) {
	                        i = e;
	                        return
	                    }
	                    b = c[k >> 2] | 0;
	                    do if ((c[k >> 2] | 0) >>> 0 >= 128) {
	                        q = c[k >> 2] | 0;
	                        if (b >>> 0 < 2048) {
	                            r = c[m >> 2] | 0;
	                            c[m >> 2] = r + 1;
	                            a[h + r >> 0] = q >>> 6 & 31 | 192;
	                            c[l >> 2] = 0;
	                            break
	                        }
	                        r = c[k >> 2] | 0;
	                        if (q >>> 0 < 65536) {
	                            q = c[m >> 2] | 0;
	                            c[m >> 2] = q + 1;
	                            a[h + q >> 0] = r >>> 12 & 15 | 224;
	                            c[l >> 2] = 6;
	                            break
	                        } else {
	                            q = c[m >> 2] | 0;
	                            c[m >> 2] = q + 1;
	                            a[h + q >> 0] = r >>> 18 & 7 | 240;
	                            c[l >> 2] = 12;
	                            break
	                        }
	                    } else {
	                        r = c[m >> 2] | 0;
	                        c[m >> 2] = r + 1;
	                        a[h + r >> 0] = b;
	                        c[l >> 2] = -6
	                    } while (0);
	                    while (1) {
	                        if ((c[l >> 2] | 0) < 0)break;
	                        b = ((c[k >> 2] | 0) >>> (c[l >> 2] | 0) & 63 | 128) & 255;
	                        r = c[m >> 2] | 0;
	                        c[m >> 2] = r + 1;
	                        a[h + r >> 0] = b;
	                        c[l >> 2] = (c[l >> 2] | 0) - 6
	                    }
	                    a[h + (c[m >> 2] | 0) >> 0] = 0;
	                    ep(c[f >> 2] | 0) | 0;
	                    if (!(c[c[f >> 2] >> 2] | 0)) {
	                        i = e;
	                        return
	                    }
	                    if (!(c[(c[c[f >> 2] >> 2] | 0) + 68 >> 2] | 0)) {
	                        i = e;
	                        return
	                    }
	                    Db[c[(c[c[f >> 2] >> 2] | 0) + 68 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0, h, c[m >> 2] | 0);
	                    i = e;
	                    return
	                }
	                c[g >> 2] = ho(c[f >> 2] | 0, j) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    ep(c[f >> 2] | 0) | 0;
	                    if (!(c[c[f >> 2] >> 2] | 0)) {
	                        i = e;
	                        return
	                    }
	                    if (!(c[(c[c[f >> 2] >> 2] | 0) + 68 >> 2] | 0)) {
	                        i = e;
	                        return
	                    }
	                    Db[c[(c[c[f >> 2] >> 2] | 0) + 68 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0, 95904, 1);
	                    i = e;
	                    return
	                }
	                if ((c[g >> 2] | 0) != 0 ? (c[c[g >> 2] >> 2] | 0) >>> 0 > 0 : 0) {
	                    c[p >> 2] = 0;
	                    c[n >> 2] = c[c[g >> 2] >> 2];
	                    g = c[n >> 2] | 0;
	                    do if ((c[n >> 2] | 0) >>> 0 >= 128) {
	                        m = c[n >> 2] | 0;
	                        if (g >>> 0 < 2048) {
	                            l = c[p >> 2] | 0;
	                            c[p >> 2] = l + 1;
	                            a[h + l >> 0] = m >>> 6 & 31 | 192;
	                            c[o >> 2] = 0;
	                            break
	                        }
	                        l = c[n >> 2] | 0;
	                        if (m >>> 0 < 65536) {
	                            m = c[p >> 2] | 0;
	                            c[p >> 2] = m + 1;
	                            a[h + m >> 0] = l >>> 12 & 15 | 224;
	                            c[o >> 2] = 6;
	                            break
	                        } else {
	                            m = c[p >> 2] | 0;
	                            c[p >> 2] = m + 1;
	                            a[h + m >> 0] = l >>> 18 & 7 | 240;
	                            c[o >> 2] = 12;
	                            break
	                        }
	                    } else {
	                        l = c[p >> 2] | 0;
	                        c[p >> 2] = l + 1;
	                        a[h + l >> 0] = g;
	                        c[o >> 2] = -6
	                    } while (0);
	                    while (1) {
	                        if ((c[o >> 2] | 0) < 0)break;
	                        g = ((c[n >> 2] | 0) >>> (c[o >> 2] | 0) & 63 | 128) & 255;
	                        l = c[p >> 2] | 0;
	                        c[p >> 2] = l + 1;
	                        a[h + l >> 0] = g;
	                        c[o >> 2] = (c[o >> 2] | 0) - 6
	                    }
	                    a[h + (c[p >> 2] | 0) >> 0] = 0;
	                    ep(c[f >> 2] | 0) | 0;
	                    if (!(c[c[f >> 2] >> 2] | 0)) {
	                        i = e;
	                        return
	                    }
	                    if (!(c[(c[c[f >> 2] >> 2] | 0) + 68 >> 2] | 0)) {
	                        i = e;
	                        return
	                    }
	                    Db[c[(c[c[f >> 2] >> 2] | 0) + 68 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0, h, c[p >> 2] | 0);
	                    i = e;
	                    return
	                }
	                ep(c[f >> 2] | 0) | 0;
	                if (!(c[c[f >> 2] >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                if (!(c[(c[c[f >> 2] >> 2] | 0) + 68 >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                Db[c[(c[c[f >> 2] >> 2] | 0) + 68 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0, 95904, 1);
	                p = c[(c[c[f >> 2] >> 2] | 0) + 68 >> 2] | 0;
	                h = c[(c[f >> 2] | 0) + 4 >> 2] | 0;
	                f = c[j >> 2] | 0;
	                o = xy(c[j >> 2] | 0) | 0;
	                Db[p & 511](h, f, o);
	                i = e;
	                return
	            }

	            function Zo(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 1040 | 0;
	                f = e + 16 | 0;
	                g = e + 20 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[f >> 2] = b;
	                c[h >> 2] = 0;
	                c[l >> 2] = 0;
	                if (((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)le(c[(c[f >> 2] | 0) + 36 >> 2] | 0);
	                c[j >> 2] = ap(c[f >> 2] | 0, k) | 0;
	                while (1) {
	                    if ((c[j >> 2] | 0) == 60 ? (c[(c[f >> 2] | 0) + 176 >> 2] | 0) != 60 : 0)break;
	                    if ((c[j >> 2] | 0) != 38) {
	                        if (!(c[j >> 2] | 0))break
	                    } else if (!((c[j >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 176 >> 2] | 0) == 38 : 0))break;
	                    b = c[j >> 2] | 0;
	                    if ((c[j >> 2] | 0) < 256)if (9 <= (b | 0) & (c[j >> 2] | 0) <= 10 | (c[j >> 2] | 0) == 13 | 32 <= (c[j >> 2] | 0))m = 16; else m = 15; else if ((!(256 <= (b | 0) & (c[j >> 2] | 0) <= 55295) ? !(57344 <= (c[j >> 2] | 0) & (c[j >> 2] | 0) <= 65533) : 0) ? !(65536 <= (c[j >> 2] | 0) & (c[j >> 2] | 0) <= 1114111) : 0)m = 15; else m = 16;
	                    do if ((m | 0) == 15) {
	                        m = 0;
	                        Ao(c[f >> 2] | 0, 9, 95944, c[j >> 2] | 0)
	                    } else if ((m | 0) == 16) {
	                        m = 0;
	                        if ((c[k >> 2] | 0) == 1) {
	                            b = c[j >> 2] & 255;
	                            n = c[h >> 2] | 0;
	                            c[h >> 2] = n + 1;
	                            a[g + n >> 0] = b;
	                            break
	                        } else {
	                            b = qe(c[k >> 2] | 0, g + (c[h >> 2] | 0) | 0, c[j >> 2] | 0) | 0;
	                            c[h >> 2] = (c[h >> 2] | 0) + b;
	                            break
	                        }
	                    } while (0);
	                    if ((c[h >> 2] | 0) >= 1e3) {
	                        do if ((c[c[f >> 2] >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 212 >> 2] | 0) == 0 : 0) {
	                            b = (kp(c[f >> 2] | 0, g, c[h >> 2] | 0) | 0) != 0;
	                            n = c[f >> 2] | 0;
	                            if (!b) {
	                                ep(n) | 0;
	                                if (!(c[(c[c[f >> 2] >> 2] | 0) + 68 >> 2] | 0))break;
	                                Db[c[(c[c[f >> 2] >> 2] | 0) + 68 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0, g, c[h >> 2] | 0);
	                                break
	                            }
	                            b = c[c[f >> 2] >> 2] | 0;
	                            if (c[n + 208 >> 2] | 0) {
	                                if (!(c[b + 68 >> 2] | 0))break;
	                                Db[c[(c[c[f >> 2] >> 2] | 0) + 68 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0, g, c[h >> 2] | 0);
	                                break
	                            } else {
	                                if (!(c[b + 72 >> 2] | 0))break;
	                                Db[c[(c[c[f >> 2] >> 2] | 0) + 72 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0, g, c[h >> 2] | 0);
	                                break
	                            }
	                        } while (0);
	                        c[h >> 2] = 0
	                    }
	                    b = c[(c[f >> 2] | 0) + 36 >> 2] | 0;
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                        n = b + 28 | 0;
	                        c[n >> 2] = (c[n >> 2] | 0) + 1;
	                        c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                    } else {
	                        n = b + 32 | 0;
	                        c[n >> 2] = (c[n >> 2] | 0) + 1
	                    }
	                    c[(c[f >> 2] | 0) + 176 >> 2] = 0;
	                    n = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[n >> 2] = (c[n >> 2] | 0) + (c[k >> 2] | 0);
	                    n = (c[f >> 2] | 0) + 200 | 0;
	                    c[n >> 2] = (c[n >> 2] | 0) + 1;
	                    c[l >> 2] = (c[l >> 2] | 0) + 1;
	                    if ((c[l >> 2] | 0) > 100) {
	                        c[l >> 2] = 0;
	                        if (((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)le(c[(c[f >> 2] | 0) + 36 >> 2] | 0);
	                        if ((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0
	                    }
	                    c[j >> 2] = ap(c[f >> 2] | 0, k) | 0;
	                    if (c[j >> 2] | 0)continue;
	                    if (((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)le(c[(c[f >> 2] | 0) + 36 >> 2] | 0);
	                    if ((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0;
	                    c[j >> 2] = ap(c[f >> 2] | 0, k) | 0
	                }
	                if (!(c[h >> 2] | 0)) {
	                    if (c[j >> 2] | 0) {
	                        i = e;
	                        return
	                    }
	                    c[(c[f >> 2] | 0) + 172 >> 2] = -1;
	                    i = e;
	                    return
	                }
	                a[g + (c[h >> 2] | 0) >> 0] = 0;
	                if (!(c[c[f >> 2] >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                if (c[(c[f >> 2] | 0) + 212 >> 2] | 0) {
	                    i = e;
	                    return
	                }
	                j = (kp(c[f >> 2] | 0, g, c[h >> 2] | 0) | 0) != 0;
	                k = c[f >> 2] | 0;
	                if (!j) {
	                    ep(k) | 0;
	                    if (!(c[(c[c[f >> 2] >> 2] | 0) + 68 >> 2] | 0)) {
	                        i = e;
	                        return
	                    }
	                    Db[c[(c[c[f >> 2] >> 2] | 0) + 68 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0, g, c[h >> 2] | 0);
	                    i = e;
	                    return
	                }
	                j = c[c[f >> 2] >> 2] | 0;
	                if (c[k + 208 >> 2] | 0) {
	                    if (!(c[j + 68 >> 2] | 0)) {
	                        i = e;
	                        return
	                    }
	                    Db[c[(c[c[f >> 2] >> 2] | 0) + 68 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0, g, c[h >> 2] | 0);
	                    i = e;
	                    return
	                } else {
	                    if (!(c[j + 72 >> 2] | 0)) {
	                        i = e;
	                        return
	                    }
	                    Db[c[(c[c[f >> 2] >> 2] | 0) + 72 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0, g, c[h >> 2] | 0);
	                    i = e;
	                    return
	                }
	            }

	            function _o(a) {
	                a = a | 0;
	                var b = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b;
	                c[e >> 2] = a;
	                if ((c[(c[e >> 2] | 0) + 52 >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 68 >> 2] | 0) != 0 : 0) {
	                    c[(c[(c[e >> 2] | 0) + 448 >> 2] | 0) + 12 >> 2] = (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 36 >> 2] | 0) + ((c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0));
	                    c[(c[(c[e >> 2] | 0) + 448 >> 2] | 0) + 16 >> 2] = c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2];
	                    c[c[(c[e >> 2] | 0) + 448 >> 2] >> 2] = c[(c[e >> 2] | 0) + 52 >> 2];
	                    De(c[e >> 2] | 0, c[(c[e >> 2] | 0) + 448 >> 2] | 0);
	                    jp(c[e >> 2] | 0) | 0
	                }
	                if (9 <= (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                    i = b;
	                    return
	                }
	                if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 13) {
	                    i = b;
	                    return
	                }
	                if (32 <= (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0)) {
	                    i = b;
	                    return
	                }
	                Do(c[e >> 2] | 0);
	                i = b;
	                return
	            }

	            function $o(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 32 | 0;
	                g = e + 28 | 0;
	                h = e + 24 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[f >> 2] = b;
	                c[j + 0 >> 2] = 0;
	                c[j + 4 >> 2] = 0;
	                c[j + 8 >> 2] = 0;
	                c[j + 12 >> 2] = 0;
	                c[j + 16 >> 2] = 0;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) {
	                    if ((c[(c[f >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                        i = e;
	                        return
	                    }
	                    if (c[(c[f >> 2] | 0) + 68 >> 2] | 0) {
	                        c[j + 4 >> 2] = (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 36 >> 2] | 0) + ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0));
	                        c[j + 8 >> 2] = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2]
	                    }
	                    c[k >> 2] = Bo(c[f >> 2] | 0) | 0;
	                    c[g >> 2] = c[(c[f >> 2] | 0) + 184 >> 2];
	                    if ((c[k >> 2] | 0) == -1 | (c[g >> 2] | 0) == 0) {
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) != 62) {
	                            i = e;
	                            return
	                        }
	                        me(c[f >> 2] | 0);
	                        i = e;
	                        return
	                    }
	                    c[h >> 2] = bo(c[g >> 2] | 0) | 0;
	                    if (!(c[h >> 2] | 0))zo(c[f >> 2] | 0, 801, 94576, c[g >> 2] | 0, 0);
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) == 47 ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0) == 62 : 0) {
	                        k = (c[f >> 2] | 0) + 200 | 0;
	                        c[k >> 2] = (c[k >> 2] | 0) + 2;
	                        k = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                        c[k >> 2] = (c[k >> 2] | 0) + 2;
	                        k = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                        c[k >> 2] = (c[k >> 2] | 0) + 2;
	                        if ((c[c[f >> 2] >> 2] | 0) != 0 ? (c[(c[c[f >> 2] >> 2] | 0) + 60 >> 2] | 0) != 0 : 0)Ab[c[(c[c[f >> 2] >> 2] | 0) + 60 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0, c[g >> 2] | 0);
	                        Co(c[f >> 2] | 0) | 0;
	                        i = e;
	                        return
	                    }
	                    k = c[f >> 2] | 0;
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) != 62) {
	                        zo(k, 73, 94592, c[g >> 2] | 0, 0);
	                        if (qy(c[g >> 2] | 0, c[(c[f >> 2] | 0) + 184 >> 2] | 0) | 0) {
	                            Re(c[f >> 2] | 0) | 0;
	                            Co(c[f >> 2] | 0) | 0
	                        }
	                        if (c[(c[f >> 2] | 0) + 68 >> 2] | 0)dp(c[f >> 2] | 0, j) | 0;
	                        _o(c[f >> 2] | 0);
	                        i = e;
	                        return
	                    }
	                    me(k);
	                    if ((c[h >> 2] | 0) != 0 ? (a[(c[h >> 2] | 0) + 7 >> 0] | 0) != 0 : 0) {
	                        if ((c[c[f >> 2] >> 2] | 0) != 0 ? (c[(c[c[f >> 2] >> 2] | 0) + 60 >> 2] | 0) != 0 : 0)Ab[c[(c[c[f >> 2] >> 2] | 0) + 60 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0, c[g >> 2] | 0);
	                        Co(c[f >> 2] | 0) | 0;
	                        i = e;
	                        return
	                    }
	                    if (!(c[(c[f >> 2] | 0) + 68 >> 2] | 0)) {
	                        i = e;
	                        return
	                    }
	                    dp(c[f >> 2] | 0, j) | 0;
	                    i = e;
	                    return
	                }
	                zo(c[f >> 2] | 0, 1, 97568, 0, 0);
	                i = e;
	                return
	            }

	            function ap(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                f = i;
	                i = i + 208 | 0;
	                g = f;
	                h = f + 40 | 0;
	                j = f + 36 | 0;
	                k = f + 32 | 0;
	                l = f + 28 | 0;
	                m = f + 194 | 0;
	                n = f + 24 | 0;
	                o = f + 20 | 0;
	                p = f + 16 | 0;
	                q = f + 44 | 0;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                if ((c[(c[j >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                    c[h >> 2] = 0;
	                    r = c[h >> 2] | 0;
	                    i = f;
	                    return r | 0
	                }
	                if (c[(c[j >> 2] | 0) + 176 >> 2] | 0) {
	                    c[c[k >> 2] >> 2] = 0;
	                    c[h >> 2] = c[(c[j >> 2] | 0) + 176 >> 2];
	                    r = c[h >> 2] | 0;
	                    i = f;
	                    return r | 0
	                }
	                if ((c[(c[j >> 2] | 0) + 256 >> 2] | 0) != 1) {
	                    c[c[k >> 2] >> 2] = 1;
	                    e = c[j >> 2] | 0;
	                    if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) < 128) {
	                        c[h >> 2] = d[c[(c[e + 36 >> 2] | 0) + 16 >> 2] >> 0];
	                        r = c[h >> 2] | 0;
	                        i = f;
	                        return r | 0
	                    }
	                    c[o >> 2] = lp(e) | 0;
	                    e = c[j >> 2] | 0;
	                    do if (c[o >> 2] | 0) {
	                        if (c[(c[e + 36 >> 2] | 0) + 44 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 44 >> 2] | 0);
	                        c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 44 >> 2] = c[o >> 2];
	                        c[p >> 2] = Dd(c[o >> 2] | 0) | 0;
	                        b = c[j >> 2] | 0;
	                        if (c[p >> 2] | 0) {
	                            se(b, c[p >> 2] | 0) | 0;
	                            break
	                        } else {
	                            zo(b, 81, 96008, c[o >> 2] | 0, 0);
	                            break
	                        }
	                    } else re(e, 10) | 0; while (0);
	                    c[(c[j >> 2] | 0) + 256 >> 2] = 1;
	                    c[h >> 2] = ne(c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                    r = c[h >> 2] | 0;
	                    i = f;
	                    return r | 0
	                }
	                c[l >> 2] = c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                a[m >> 0] = a[c[l >> 2] >> 0] | 0;
	                if (!((d[m >> 0] | 0) & 128)) {
	                    if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) >>> 0 < (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) >>> 0 : 0) {
	                        Ao(c[j >> 2] | 0, 9, 95976, 0);
	                        c[c[k >> 2] >> 2] = 1;
	                        c[h >> 2] = 32;
	                        r = c[h >> 2] | 0;
	                        i = f;
	                        return r | 0
	                    }
	                    c[c[k >> 2] >> 2] = 1;
	                    c[h >> 2] = d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0];
	                    r = c[h >> 2] | 0;
	                    i = f;
	                    return r | 0
	                }
	                if (!(d[(c[l >> 2] | 0) + 1 >> 0] | 0)) {
	                    ke(c[(c[j >> 2] | 0) + 36 >> 2] | 0, 250) | 0;
	                    c[l >> 2] = c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2]
	                }
	                a:do if (((d[(c[l >> 2] | 0) + 1 >> 0] | 0) & 192 | 0) == 128) {
	                    do if (((d[m >> 0] | 0) & 224 | 0) == 224) {
	                        if (!(d[(c[l >> 2] | 0) + 2 >> 0] | 0)) {
	                            ke(c[(c[j >> 2] | 0) + 36 >> 2] | 0, 250) | 0;
	                            c[l >> 2] = c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2]
	                        }
	                        if (((d[(c[l >> 2] | 0) + 2 >> 0] | 0) & 192 | 0) != 128)break a;
	                        if (((d[m >> 0] | 0) & 240 | 0) != 240) {
	                            c[c[k >> 2] >> 2] = 3;
	                            c[n >> 2] = ((d[c[l >> 2] >> 0] | 0) & 15) << 12;
	                            c[n >> 2] = c[n >> 2] | ((d[(c[l >> 2] | 0) + 1 >> 0] | 0) & 63) << 6;
	                            c[n >> 2] = c[n >> 2] | (d[(c[l >> 2] | 0) + 2 >> 0] | 0) & 63;
	                            break
	                        }
	                        if (!(d[(c[l >> 2] | 0) + 3 >> 0] | 0)) {
	                            ke(c[(c[j >> 2] | 0) + 36 >> 2] | 0, 250) | 0;
	                            c[l >> 2] = c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2]
	                        }
	                        if (((d[m >> 0] | 0) & 248 | 0) != 240)break a;
	                        if (((d[(c[l >> 2] | 0) + 3 >> 0] | 0) & 192 | 0) != 128)break a;
	                        c[c[k >> 2] >> 2] = 4;
	                        c[n >> 2] = ((d[c[l >> 2] >> 0] | 0) & 7) << 18;
	                        c[n >> 2] = c[n >> 2] | ((d[(c[l >> 2] | 0) + 1 >> 0] | 0) & 63) << 12;
	                        c[n >> 2] = c[n >> 2] | ((d[(c[l >> 2] | 0) + 2 >> 0] | 0) & 63) << 6;
	                        c[n >> 2] = c[n >> 2] | (d[(c[l >> 2] | 0) + 3 >> 0] | 0) & 63
	                    } else {
	                        c[c[k >> 2] >> 2] = 2;
	                        c[n >> 2] = ((d[c[l >> 2] >> 0] | 0) & 31) << 6;
	                        c[n >> 2] = c[n >> 2] | (d[(c[l >> 2] | 0) + 1 >> 0] | 0) & 63
	                    } while (0);
	                    e = c[n >> 2] | 0;
	                    if ((c[n >> 2] | 0) >>> 0 < 256) {
	                        if (!(9 <= e >>> 0 & (c[n >> 2] | 0) >>> 0 <= 10 | (c[n >> 2] | 0) == 13 | 32 <= (c[n >> 2] | 0) >>> 0))s = 27
	                    } else if ((!(256 <= e >>> 0 & (c[n >> 2] | 0) >>> 0 <= 55295) ? !(57344 <= (c[n >> 2] | 0) >>> 0 & (c[n >> 2] | 0) >>> 0 <= 65533) : 0) ? !(65536 <= (c[n >> 2] | 0) >>> 0 & (c[n >> 2] | 0) >>> 0 <= 1114111) : 0)s = 27;
	                    if ((s | 0) == 27)Ao(c[j >> 2] | 0, 9, 95976, c[n >> 2] | 0);
	                    c[h >> 2] = c[n >> 2];
	                    r = c[h >> 2] | 0;
	                    i = f;
	                    return r | 0
	                } while (0);
	                n = d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                if (((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) >= 4) {
	                    s = d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0;
	                    l = d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0;
	                    m = d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0;
	                    c[g >> 2] = n;
	                    c[g + 4 >> 2] = s;
	                    c[g + 8 >> 2] = l;
	                    c[g + 12 >> 2] = m;
	                    JT(q, 149, 96032, g) | 0
	                } else {
	                    c[g >> 2] = n;
	                    JT(q, 149, 96072, g) | 0
	                }
	                zo(c[j >> 2] | 0, 81, 96088, q, 0);
	                c[(c[j >> 2] | 0) + 256 >> 2] = 10;
	                c[c[k >> 2] >> 2] = 1;
	                c[h >> 2] = d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0];
	                r = c[h >> 2] | 0;
	                i = f;
	                return r | 0
	            }

	            function bp(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                if ((((((WS(d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) | 0) == 83 ? (WS(d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0) | 0) == 89 : 0) ? (WS(d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0) | 0) == 83 : 0) ? (WS(d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0) | 0) == 84 : 0) ? (WS(d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0) | 0) == 69 : 0) ? (WS(d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0) | 0) == 77 : 0) {
	                    b = (c[f >> 2] | 0) + 200 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 6;
	                    b = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 6;
	                    b = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 6;
	                    do if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13)zo(c[f >> 2] | 0, 65, 97056, 0, 0)
	                    } while (0);
	                    Fo(c[f >> 2] | 0) | 0;
	                    c[h >> 2] = mp(c[f >> 2] | 0) | 0;
	                    if (c[h >> 2] | 0) {
	                        j = c[h >> 2] | 0;
	                        i = e;
	                        return j | 0
	                    }
	                    zo(c[f >> 2] | 0, 70, 97088, 0, 0);
	                    j = c[h >> 2] | 0;
	                    i = e;
	                    return j | 0
	                }
	                if ((WS(d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) | 0) != 80) {
	                    j = c[h >> 2] | 0;
	                    i = e;
	                    return j | 0
	                }
	                if ((WS(d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0) | 0) != 85) {
	                    j = c[h >> 2] | 0;
	                    i = e;
	                    return j | 0
	                }
	                if ((WS(d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0) | 0) != 66) {
	                    j = c[h >> 2] | 0;
	                    i = e;
	                    return j | 0
	                }
	                if ((WS(d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0) | 0) != 76) {
	                    j = c[h >> 2] | 0;
	                    i = e;
	                    return j | 0
	                }
	                if ((WS(d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0) | 0) != 73) {
	                    j = c[h >> 2] | 0;
	                    i = e;
	                    return j | 0
	                }
	                if ((WS(d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0) | 0) != 67) {
	                    j = c[h >> 2] | 0;
	                    i = e;
	                    return j | 0
	                }
	                b = (c[f >> 2] | 0) + 200 | 0;
	                c[b >> 2] = (c[b >> 2] | 0) + 6;
	                b = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                c[b >> 2] = (c[b >> 2] | 0) + 6;
	                b = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                c[b >> 2] = (c[b >> 2] | 0) + 6;
	                do if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32) {
	                    if (9 <= (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13)zo(c[f >> 2] | 0, 65, 97128, 0, 0)
	                } while (0);
	                Fo(c[f >> 2] | 0) | 0;
	                b = np(c[f >> 2] | 0) | 0;
	                c[c[g >> 2] >> 2] = b;
	                if (!(c[c[g >> 2] >> 2] | 0))zo(c[f >> 2] | 0, 71, 97160, 0, 0);
	                Fo(c[f >> 2] | 0) | 0;
	                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 34 ? (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 39 : 0) {
	                    j = c[h >> 2] | 0;
	                    i = e;
	                    return j | 0
	                }
	                c[h >> 2] = mp(c[f >> 2] | 0) | 0;
	                j = c[h >> 2] | 0;
	                i = e;
	                return j | 0
	            }

	            function cp(b, e, f, g, h, j) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                var k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0;
	                k = i;
	                i = i + 48 | 0;
	                l = k + 36 | 0;
	                m = k + 32 | 0;
	                n = k + 43 | 0;
	                o = k + 42 | 0;
	                p = k + 41 | 0;
	                q = k + 28 | 0;
	                r = k + 24 | 0;
	                s = k + 20 | 0;
	                t = k + 16 | 0;
	                u = k + 12 | 0;
	                v = k + 8 | 0;
	                w = k + 4 | 0;
	                x = k;
	                y = k + 40 | 0;
	                c[m >> 2] = b;
	                a[n >> 0] = e;
	                a[o >> 0] = f;
	                a[p >> 0] = g;
	                c[q >> 2] = h;
	                c[r >> 2] = j;
	                c[w >> 2] = 0;
	                c[x >> 2] = 0;
	                a[y >> 0] = 0;
	                c[u >> 2] = c[(c[m >> 2] | 0) + 36 >> 2];
	                if (!(c[u >> 2] | 0)) {
	                    c[l >> 2] = -1;
	                    z = c[l >> 2] | 0;
	                    i = k;
	                    return z | 0
	                }
	                c[s >> 2] = (c[(c[u >> 2] | 0) + 16 >> 2] | 0) - (c[(c[u >> 2] | 0) + 12 >> 2] | 0);
	                if ((c[s >> 2] | 0) < 0) {
	                    c[l >> 2] = -1;
	                    z = c[l >> 2] | 0;
	                    i = k;
	                    return z | 0
	                }
	                if ((c[(c[m >> 2] | 0) + 204 >> 2] | 0) > (c[s >> 2] | 0))c[s >> 2] = c[(c[m >> 2] | 0) + 204 >> 2];
	                j = c[u >> 2] | 0;
	                if (!(c[c[u >> 2] >> 2] | 0)) {
	                    c[v >> 2] = c[j + 12 >> 2];
	                    c[t >> 2] = c[(c[u >> 2] | 0) + 24 >> 2]
	                } else {
	                    c[v >> 2] = Vy(c[(c[j >> 2] | 0) + 16 >> 2] | 0) | 0;
	                    c[t >> 2] = _y(c[(c[c[u >> 2] >> 2] | 0) + 16 >> 2] | 0) | 0
	                }
	                if (!(a[p >> 0] | 0)) {
	                    if (a[o >> 0] | 0)c[t >> 2] = (c[t >> 2] | 0) + -1
	                } else c[t >> 2] = (c[t >> 2] | 0) - 2;
	                a:while (1) {
	                    A = (c[w >> 2] | 0) != 0;
	                    if ((c[s >> 2] | 0) >= (c[t >> 2] | 0)) {
	                        B = 45;
	                        break
	                    }
	                    if (((((!A ? !((c[q >> 2] | 0) != 0 ? 1 : ((c[s >> 2] | 0) + 4 | 0) >= (c[t >> 2] | 0)) : 0) ? (d[(c[v >> 2] | 0) + (c[s >> 2] | 0) >> 0] | 0) == 60 : 0) ? (d[(c[v >> 2] | 0) + ((c[s >> 2] | 0) + 1) >> 0] | 0) == 33 : 0) ? (d[(c[v >> 2] | 0) + ((c[s >> 2] | 0) + 2) >> 0] | 0) == 45 : 0) ? (d[(c[v >> 2] | 0) + ((c[s >> 2] | 0) + 3) >> 0] | 0) == 45 : 0) {
	                        c[w >> 2] = 1;
	                        c[s >> 2] = (c[s >> 2] | 0) + 2
	                    }
	                    do if (c[r >> 2] | 0) {
	                        if ((d[(c[v >> 2] | 0) + (c[s >> 2] | 0) >> 0] | 0) != 34 ? (d[(c[v >> 2] | 0) + (c[s >> 2] | 0) >> 0] | 0) != 39 : 0)if (c[x >> 2] | 0)break; else {
	                            B = 30;
	                            break
	                        }
	                        j = a[(c[v >> 2] | 0) + (c[s >> 2] | 0) >> 0] | 0;
	                        if (!(c[x >> 2] | 0)) {
	                            a[y >> 0] = j;
	                            c[x >> 2] = 1;
	                            break
	                        }
	                        if ((j & 255 | 0) == (a[y >> 0] | 0))c[x >> 2] = 0; else B = 30
	                    } else B = 30; while (0);
	                    do if ((B | 0) == 30) {
	                        B = 0;
	                        j = c[s >> 2] | 0;
	                        if (c[w >> 2] | 0) {
	                            if ((j + 3 | 0) > (c[t >> 2] | 0)) {
	                                B = 32;
	                                break a
	                            }
	                            if ((d[(c[v >> 2] | 0) + (c[s >> 2] | 0) >> 0] | 0) != 45)break;
	                            if ((d[(c[v >> 2] | 0) + ((c[s >> 2] | 0) + 1) >> 0] | 0) != 45)break;
	                            if ((d[(c[v >> 2] | 0) + ((c[s >> 2] | 0) + 2) >> 0] | 0) != 62)break;
	                            c[w >> 2] = 0;
	                            c[s >> 2] = (c[s >> 2] | 0) + 2;
	                            break
	                        }
	                        if ((d[(c[v >> 2] | 0) + j >> 0] | 0) == (d[n >> 0] | 0))if (d[p >> 0] | 0) {
	                            if ((d[(c[v >> 2] | 0) + ((c[s >> 2] | 0) + 1) >> 0] | 0) != (d[o >> 0] | 0))break;
	                            if ((d[(c[v >> 2] | 0) + ((c[s >> 2] | 0) + 2) >> 0] | 0) != (d[p >> 0] | 0))break; else {
	                                B = 43;
	                                break a
	                            }
	                        } else {
	                            if (!(d[o >> 0] | 0)) {
	                                B = 43;
	                                break a
	                            }
	                            if ((d[(c[v >> 2] | 0) + ((c[s >> 2] | 0) + 1) >> 0] | 0) != (d[o >> 0] | 0))break; else {
	                                B = 43;
	                                break a
	                            }
	                        }
	                    } while (0);
	                    c[s >> 2] = (c[s >> 2] | 0) + 1
	                }
	                if ((B | 0) == 32) {
	                    c[l >> 2] = -1;
	                    z = c[l >> 2] | 0;
	                    i = k;
	                    return z | 0
	                } else if ((B | 0) == 43) {
	                    c[(c[m >> 2] | 0) + 204 >> 2] = 0;
	                    c[l >> 2] = (c[s >> 2] | 0) - ((c[(c[u >> 2] | 0) + 16 >> 2] | 0) - (c[(c[u >> 2] | 0) + 12 >> 2] | 0));
	                    z = c[l >> 2] | 0;
	                    i = k;
	                    return z | 0
	                } else if ((B | 0) == 45) {
	                    if (!(A | (c[x >> 2] | 0) != 0))c[(c[m >> 2] | 0) + 204 >> 2] = c[s >> 2];
	                    c[l >> 2] = -1;
	                    z = c[l >> 2] | 0;
	                    i = k;
	                    return z | 0
	                }
	                return 0
	            }

	            function dp(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[(c[f >> 2] | 0) + 452 >> 2] | 0) >= (c[(c[f >> 2] | 0) + 456 >> 2] | 0)) {
	                    if (!(c[(c[f >> 2] | 0) + 456 >> 2] | 0))c[(c[f >> 2] | 0) + 456 >> 2] = 5;
	                    b = (c[f >> 2] | 0) + 456 | 0;
	                    c[b >> 2] = c[b >> 2] << 1;
	                    b = Hb[c[135760 >> 2] & 511](c[(c[f >> 2] | 0) + 460 >> 2] | 0, (c[(c[f >> 2] | 0) + 456 >> 2] | 0) * 20 | 0) | 0;
	                    c[(c[f >> 2] | 0) + 460 >> 2] = b;
	                    if (!(c[(c[f >> 2] | 0) + 460 >> 2] | 0)) {
	                        xo(c[f >> 2] | 0, 0);
	                        c[e >> 2] = 0;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                }
	                b = (c[(c[f >> 2] | 0) + 460 >> 2] | 0) + ((c[(c[f >> 2] | 0) + 452 >> 2] | 0) * 20 | 0) | 0;
	                a = c[g >> 2] | 0;
	                c[b + 0 >> 2] = c[a + 0 >> 2];
	                c[b + 4 >> 2] = c[a + 4 >> 2];
	                c[b + 8 >> 2] = c[a + 8 >> 2];
	                c[b + 12 >> 2] = c[a + 12 >> 2];
	                c[b + 16 >> 2] = c[a + 16 >> 2];
	                c[(c[f >> 2] | 0) + 448 >> 2] = (c[(c[f >> 2] | 0) + 460 >> 2] | 0) + ((c[(c[f >> 2] | 0) + 452 >> 2] | 0) * 20 | 0);
	                a = (c[f >> 2] | 0) + 452 | 0;
	                f = c[a >> 2] | 0;
	                c[a >> 2] = f + 1;
	                c[e >> 2] = f;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function ep(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = -1;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                c[f >> 2] = c[(c[e >> 2] | 0) + 184 >> 2];
	                if (!(c[f >> 2] | 0)) {
	                    Qo(c[e >> 2] | 0, 96176);
	                    Ro(c[e >> 2] | 0, 96176);
	                    Uo(c[e >> 2] | 0, 96176) | 0;
	                    if ((c[c[e >> 2] >> 2] | 0) != 0 ? (c[(c[c[e >> 2] >> 2] | 0) + 56 >> 2] | 0) != 0 : 0)Db[c[(c[c[e >> 2] >> 2] | 0) + 56 >> 2] & 511](c[(c[e >> 2] | 0) + 4 >> 2] | 0, 96176, 0);
	                    c[d >> 2] = 1;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                if (!(c[23702] | 0)) {
	                    c[d >> 2] = 0;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                c[g >> 2] = 0;
	                while (1) {
	                    if (!(c[96184 + (c[g >> 2] << 2) >> 2] | 0)) {
	                        j = 18;
	                        break
	                    }
	                    if (qy(c[f >> 2] | 0, c[96184 + (c[g >> 2] << 2) >> 2] | 0) | 0)break;
	                    c[g >> 2] = (c[g >> 2] | 0) + 1
	                }
	                if ((j | 0) == 18) {
	                    c[d >> 2] = 0;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                Qo(c[e >> 2] | 0, 96176);
	                Ro(c[e >> 2] | 0, 96176);
	                Uo(c[e >> 2] | 0, 96176) | 0;
	                if ((c[c[e >> 2] >> 2] | 0) != 0 ? (c[(c[c[e >> 2] >> 2] | 0) + 56 >> 2] | 0) != 0 : 0)Db[c[(c[c[e >> 2] >> 2] | 0) + 56 >> 2] & 511](c[(c[e >> 2] | 0) + 4 >> 2] | 0, 96176, 0);
	                c[d >> 2] = 1;
	                h = c[d >> 2] | 0;
	                i = b;
	                return h | 0
	            }

	            function fp(a, b, e) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f + 36 | 0;
	                h = f + 32 | 0;
	                j = f + 28 | 0;
	                k = f + 24 | 0;
	                l = f + 20 | 0;
	                m = f + 16 | 0;
	                n = f + 12 | 0;
	                o = f + 8 | 0;
	                p = f + 4 | 0;
	                q = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[p >> 2] = 0;
	                c[n >> 2] = c[(c[h >> 2] | 0) + 36 >> 2];
	                if (!(c[n >> 2] | 0)) {
	                    c[g >> 2] = -1;
	                    r = c[g >> 2] | 0;
	                    i = f;
	                    return r | 0
	                }
	                c[l >> 2] = (c[(c[n >> 2] | 0) + 16 >> 2] | 0) - (c[(c[n >> 2] | 0) + 12 >> 2] | 0);
	                if ((c[l >> 2] | 0) < 0) {
	                    c[g >> 2] = -1;
	                    r = c[g >> 2] | 0;
	                    i = f;
	                    return r | 0
	                }
	                if ((c[(c[h >> 2] | 0) + 204 >> 2] | 0) > (c[l >> 2] | 0))c[l >> 2] = c[(c[h >> 2] | 0) + 204 >> 2];
	                e = c[n >> 2] | 0;
	                if (!(c[c[n >> 2] >> 2] | 0)) {
	                    c[o >> 2] = c[e + 12 >> 2];
	                    c[m >> 2] = c[(c[n >> 2] | 0) + 24 >> 2]
	                } else {
	                    c[o >> 2] = Vy(c[(c[e >> 2] | 0) + 16 >> 2] | 0) | 0;
	                    c[m >> 2] = _y(c[(c[c[n >> 2] >> 2] | 0) + 16 >> 2] | 0) | 0
	                }
	                a:while (1) {
	                    if ((c[l >> 2] | 0) >= (c[m >> 2] | 0)) {
	                        s = 31;
	                        break
	                    }
	                    if ((((((c[p >> 2] | 0) == 0 ? ((c[l >> 2] | 0) + 4 | 0) < (c[m >> 2] | 0) : 0) ? (d[(c[o >> 2] | 0) + (c[l >> 2] | 0) >> 0] | 0 | 0) == 60 : 0) ? (d[(c[o >> 2] | 0) + ((c[l >> 2] | 0) + 1) >> 0] | 0 | 0) == 33 : 0) ? (d[(c[o >> 2] | 0) + ((c[l >> 2] | 0) + 2) >> 0] | 0 | 0) == 45 : 0) ? (d[(c[o >> 2] | 0) + ((c[l >> 2] | 0) + 3) >> 0] | 0 | 0) == 45 : 0) {
	                        c[p >> 2] = 1;
	                        c[l >> 2] = (c[l >> 2] | 0) + 2
	                    }
	                    b:do if (c[p >> 2] | 0) {
	                        if (((c[l >> 2] | 0) + 3 | 0) > (c[m >> 2] | 0)) {
	                            s = 20;
	                            break a
	                        }
	                        if (((d[(c[o >> 2] | 0) + (c[l >> 2] | 0) >> 0] | 0 | 0) == 45 ? (d[(c[o >> 2] | 0) + ((c[l >> 2] | 0) + 1) >> 0] | 0 | 0) == 45 : 0) ? (d[(c[o >> 2] | 0) + ((c[l >> 2] | 0) + 2) >> 0] | 0 | 0) == 62 : 0) {
	                            c[p >> 2] = 0;
	                            c[l >> 2] = (c[l >> 2] | 0) + 2
	                        }
	                    } else {
	                        c[q >> 2] = 0;
	                        while (1) {
	                            if ((c[q >> 2] | 0) >= (c[k >> 2] | 0))break b;
	                            if ((d[(c[o >> 2] | 0) + (c[l >> 2] | 0) >> 0] | 0 | 0) == (d[(c[j >> 2] | 0) + (c[q >> 2] | 0) >> 0] | 0 | 0)) {
	                                s = 28;
	                                break a
	                            }
	                            c[q >> 2] = (c[q >> 2] | 0) + 1
	                        }
	                    } while (0);
	                    c[l >> 2] = (c[l >> 2] | 0) + 1
	                }
	                if ((s | 0) == 20) {
	                    c[g >> 2] = -1;
	                    r = c[g >> 2] | 0;
	                    i = f;
	                    return r | 0
	                } else if ((s | 0) == 28) {
	                    c[(c[h >> 2] | 0) + 204 >> 2] = 0;
	                    c[g >> 2] = (c[l >> 2] | 0) - ((c[(c[n >> 2] | 0) + 16 >> 2] | 0) - (c[(c[n >> 2] | 0) + 12 >> 2] | 0));
	                    r = c[g >> 2] | 0;
	                    i = f;
	                    return r | 0
	                } else if ((s | 0) == 31) {
	                    c[(c[h >> 2] | 0) + 204 >> 2] = c[l >> 2];
	                    c[g >> 2] = -1;
	                    r = c[g >> 2] | 0;
	                    i = f;
	                    return r | 0
	                }
	                return 0
	            }

	            function gp(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    i = e;
	                    return
	                }
	                if (c[(c[f >> 2] | 0) + 360 >> 2] & 2097152) {
	                    i = e;
	                    return
	                }
	                if (!((c[g >> 2] | 0) != 0 ? (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 44 >> 2] | 0) == 0 : 0)) {
	                    i = e;
	                    return
	                }
	                while (1) {
	                    if ((d[c[g >> 2] >> 0] | 0 | 0) != 32 ? (d[c[g >> 2] >> 0] | 0 | 0) != 9 : 0)break;
	                    c[g >> 2] = (c[g >> 2] | 0) + 1
	                }
	                if (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 44 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 44 >> 2] | 0);
	                b = my(c[g >> 2] | 0) | 0;
	                c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 44 >> 2] = b;
	                c[h >> 2] = wd(c[g >> 2] | 0) | 0;
	                do if ((c[h >> 2] | 0) == -1) {
	                    c[j >> 2] = Dd(c[g >> 2] | 0) | 0;
	                    b = c[f >> 2] | 0;
	                    if (c[j >> 2] | 0) {
	                        se(b, c[j >> 2] | 0) | 0;
	                        c[(c[f >> 2] | 0) + 256 >> 2] = 1;
	                        break
	                    } else {
	                        zo(b, 32, 94872, c[g >> 2] | 0, 0);
	                        break
	                    }
	                } else {
	                    if (((c[h >> 2] | 0) == 2 | (c[h >> 2] | 0) == 3 | (c[h >> 2] | 0) == 4 | (c[h >> 2] | 0) == 5 ? (c[c[(c[f >> 2] | 0) + 36 >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[c[(c[f >> 2] | 0) + 36 >> 2] >> 2] | 0) + 12 >> 2] | 0) == 0 : 0)zo(c[f >> 2] | 0, 81, 94832, 0, 0); else re(c[f >> 2] | 0, c[h >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 256 >> 2] = 1
	                } while (0);
	                if (!(c[c[(c[f >> 2] | 0) + 36 >> 2] >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                if (!(c[(c[c[(c[f >> 2] | 0) + 36 >> 2] >> 2] | 0) + 12 >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                if (!(c[(c[c[(c[f >> 2] | 0) + 36 >> 2] >> 2] | 0) + 20 >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                if (!(c[(c[c[(c[f >> 2] | 0) + 36 >> 2] >> 2] | 0) + 16 >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                c[l >> 2] = (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0);
	                Ty(c[(c[c[(c[f >> 2] | 0) + 36 >> 2] >> 2] | 0) + 16 >> 2] | 0, c[l >> 2] | 0) | 0;
	                c[k >> 2] = Fd(c[c[(c[f >> 2] | 0) + 36 >> 2] >> 2] | 0, 1) | 0;
	                if ((c[k >> 2] | 0) < 0)zo(c[f >> 2] | 0, 81, 94912, 0, 0);
	                iz(c[(c[c[(c[f >> 2] | 0) + 36 >> 2] >> 2] | 0) + 16 >> 2] | 0, c[(c[f >> 2] | 0) + 36 >> 2] | 0) | 0;
	                i = e;
	                return
	            }

	            function hp(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                a = c[e >> 2] | 0;
	                do if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 34) {
	                    me(a);
	                    c[f >> 2] = op(c[e >> 2] | 0, 34) | 0;
	                    g = c[e >> 2] | 0;
	                    if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 34) {
	                        zo(g, 40, 97944, 0, 0);
	                        break
	                    } else {
	                        me(g);
	                        break
	                    }
	                } else {
	                    g = c[e >> 2] | 0;
	                    if ((d[c[(c[a + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 39) {
	                        c[f >> 2] = op(g, 0) | 0;
	                        if (c[f >> 2] | 0)break;
	                        zo(c[e >> 2] | 0, 41, 97992, 0, 0);
	                        break
	                    }
	                    me(g);
	                    c[f >> 2] = op(c[e >> 2] | 0, 39) | 0;
	                    g = c[e >> 2] | 0;
	                    if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 39) {
	                        zo(g, 40, 97968, 0, 0);
	                        break
	                    } else {
	                        me(g);
	                        break
	                    }
	                } while (0);
	                i = b;
	                return c[f >> 2] | 0
	            }

	            function ip(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[f >> 2] = b;
	                c[g >> 2] = d;
	                c[k >> 2] = pp(c[g >> 2] | 0) | 0;
	                c[j >> 2] = (c[(c[f >> 2] | 0) + 188 >> 2] | 0) - 1;
	                while (1) {
	                    if ((c[j >> 2] | 0) < 0)break;
	                    if (qy(c[g >> 2] | 0, c[(c[(c[f >> 2] | 0) + 196 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) | 0)break;
	                    d = pp(c[(c[(c[f >> 2] | 0) + 196 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) | 0;
	                    if ((d | 0) > (c[k >> 2] | 0)) {
	                        l = 15;
	                        break
	                    }
	                    c[j >> 2] = (c[j >> 2] | 0) + -1
	                }
	                if ((l | 0) == 15) {
	                    i = e;
	                    return
	                }
	                if ((c[j >> 2] | 0) < 0) {
	                    i = e;
	                    return
	                }
	                while (1) {
	                    if (!((qy(c[g >> 2] | 0, c[(c[f >> 2] | 0) + 184 >> 2] | 0) | 0) != 0 ^ 1))break;
	                    c[h >> 2] = bo(c[(c[f >> 2] | 0) + 184 >> 2] | 0) | 0;
	                    if ((c[h >> 2] | 0) != 0 ? (a[(c[h >> 2] | 0) + 5 >> 0] | 0) == 3 : 0)zo(c[f >> 2] | 0, 76, 95696, c[g >> 2] | 0, c[(c[f >> 2] | 0) + 184 >> 2] | 0);
	                    if ((c[c[f >> 2] >> 2] | 0) != 0 ? (c[(c[c[f >> 2] >> 2] | 0) + 60 >> 2] | 0) != 0 : 0)Ab[c[(c[c[f >> 2] >> 2] | 0) + 60 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0, c[(c[f >> 2] | 0) + 184 >> 2] | 0);
	                    Co(c[f >> 2] | 0) | 0
	                }
	                i = e;
	                return
	            }

	            function jp(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                if ((c[(c[e >> 2] | 0) + 452 >> 2] | 0) <= 0) {
	                    c[d >> 2] = 0;
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                }
	                a = (c[e >> 2] | 0) + 452 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + -1;
	                if ((c[(c[e >> 2] | 0) + 452 >> 2] | 0) < 0) {
	                    c[d >> 2] = 0;
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                }
	                a = c[e >> 2] | 0;
	                if ((c[(c[e >> 2] | 0) + 452 >> 2] | 0) > 0)c[(c[e >> 2] | 0) + 448 >> 2] = (c[(c[e >> 2] | 0) + 460 >> 2] | 0) + (((c[a + 452 >> 2] | 0) - 1 | 0) * 20 | 0); else c[a + 448 >> 2] = 0;
	                c[d >> 2] = (c[(c[e >> 2] | 0) + 460 >> 2] | 0) + ((c[(c[e >> 2] | 0) + 452 >> 2] | 0) * 20 | 0);
	                f = c[d >> 2] | 0;
	                i = b;
	                return f | 0
	            }

	            function kp(a, b, e) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 28 | 0;
	                h = f + 24 | 0;
	                j = f + 20 | 0;
	                k = f + 16 | 0;
	                l = f + 12 | 0;
	                m = f + 8 | 0;
	                n = f + 4 | 0;
	                o = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[m >> 2] = 0;
	                a:while (1) {
	                    if ((c[m >> 2] | 0) >= (c[k >> 2] | 0))break;
	                    do if ((d[(c[j >> 2] | 0) + (c[m >> 2] | 0) >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[(c[j >> 2] | 0) + (c[m >> 2] | 0) >> 0] | 0 | 0) ? (d[(c[j >> 2] | 0) + (c[m >> 2] | 0) >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[(c[j >> 2] | 0) + (c[m >> 2] | 0) >> 0] | 0 | 0) != 13) {
	                            p = 7;
	                            break a
	                        }
	                    } while (0);
	                    c[m >> 2] = (c[m >> 2] | 0) + 1
	                }
	                if ((p | 0) == 7) {
	                    c[g >> 2] = 0;
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                if (!(d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0)) {
	                    c[g >> 2] = 1;
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                if ((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 60) {
	                    c[g >> 2] = 0;
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                if (!(c[(c[h >> 2] | 0) + 184 >> 2] | 0)) {
	                    c[g >> 2] = 1;
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                if (qy(c[(c[h >> 2] | 0) + 184 >> 2] | 0, 94240) | 0) {
	                    c[g >> 2] = 1;
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                if (qy(c[(c[h >> 2] | 0) + 184 >> 2] | 0, 95656) | 0) {
	                    c[g >> 2] = 1;
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                do if ((((qy(c[(c[h >> 2] | 0) + 184 >> 2] | 0, 95648) | 0) != 0 ? (c[(c[h >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (c[o >> 2] = Nh(c[(c[h >> 2] | 0) + 8 >> 2] | 0) | 0, (c[o >> 2] | 0) != 0) : 0) ? (c[(c[o >> 2] | 0) + 52 >> 2] | 0) != 0 : 0) {
	                    if ((ty(c[(c[o >> 2] | 0) + 52 >> 2] | 0, 96272) | 0) != 0 ? (ty(c[(c[o >> 2] | 0) + 52 >> 2] | 0, 96304) | 0) != 0 : 0)break;
	                    c[g >> 2] = 1;
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                } while (0);
	                if (!(c[(c[h >> 2] | 0) + 52 >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                c[n >> 2] = Bi(c[(c[h >> 2] | 0) + 52 >> 2] | 0) | 0;
	                while (1) {
	                    if (c[n >> 2] | 0)r = (c[(c[n >> 2] | 0) + 4 >> 2] | 0) == 8; else r = 0;
	                    s = c[n >> 2] | 0;
	                    if (!r)break;
	                    c[n >> 2] = c[s + 28 >> 2]
	                }
	                b:do if (!s) {
	                    if ((c[(c[(c[h >> 2] | 0) + 52 >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[(c[h >> 2] | 0) + 52 >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) {
	                        c[g >> 2] = 0;
	                        q = c[g >> 2] | 0;
	                        i = f;
	                        return q | 0
	                    }
	                    c[l >> 2] = 0;
	                    while (1) {
	                        if ((c[l >> 2] | 0) >>> 0 >= 53)break b;
	                        if (qy(c[(c[h >> 2] | 0) + 184 >> 2] | 0, c[96328 + (c[l >> 2] << 2) >> 2] | 0) | 0)break;
	                        c[l >> 2] = (c[l >> 2] | 0) + 1
	                    }
	                    c[g >> 2] = 0;
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                } else {
	                    if (hj(c[n >> 2] | 0) | 0) {
	                        c[g >> 2] = 0;
	                        q = c[g >> 2] | 0;
	                        i = f;
	                        return q | 0
	                    }
	                    c[l >> 2] = 0;
	                    while (1) {
	                        if ((c[l >> 2] | 0) >>> 0 >= 53)break b;
	                        if (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, c[96328 + (c[l >> 2] << 2) >> 2] | 0) | 0)break;
	                        c[l >> 2] = (c[l >> 2] | 0) + 1
	                    }
	                    c[g >> 2] = 0;
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                } while (0);
	                c[g >> 2] = 1;
	                q = c[g >> 2] | 0;
	                i = f;
	                return q | 0
	            }

	            function lp(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                b = i;
	                i = i + 32 | 0;
	                e = b + 16 | 0;
	                f = b + 12 | 0;
	                g = b + 8 | 0;
	                h = b + 4 | 0;
	                j = b;
	                c[f >> 2] = a;
	                if (((((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 44 >> 2] | 0) == 0 : 0) ? (c[c[(c[f >> 2] | 0) + 36 >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[c[(c[f >> 2] | 0) + 36 >> 2] >> 2] | 0) + 12 >> 2] | 0) == 0 : 0) {
	                    if ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) {
	                        c[g >> 2] = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                        c[j >> 2] = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2];
	                        if (d[c[j >> 2] >> 0] | 0) {
	                            c[e >> 2] = 0;
	                            k = c[e >> 2] | 0;
	                            i = b;
	                            return k | 0
	                        }
	                        c[h >> 2] = yy(c[g >> 2] | 0, 96136) | 0;
	                        if (!(c[h >> 2] | 0)) {
	                            c[e >> 2] = 0;
	                            k = c[e >> 2] | 0;
	                            i = b;
	                            return k | 0
	                        }
	                        c[h >> 2] = yy(c[h >> 2] | 0, 96152) | 0;
	                        if (!(c[h >> 2] | 0)) {
	                            c[e >> 2] = 0;
	                            k = c[e >> 2] | 0;
	                            i = b;
	                            return k | 0
	                        }
	                        c[h >> 2] = yy(c[h >> 2] | 0, 96160) | 0;
	                        if (!(c[h >> 2] | 0)) {
	                            c[e >> 2] = 0;
	                            k = c[e >> 2] | 0;
	                            i = b;
	                            return k | 0
	                        }
	                        c[h >> 2] = (c[h >> 2] | 0) + 8;
	                        c[g >> 2] = c[h >> 2];
	                        while (1) {
	                            if ((d[c[h >> 2] >> 0] | 0 | 0) >= 65 ? (d[c[h >> 2] >> 0] | 0 | 0) <= 90 : 0)l = 1; else m = 21;
	                            do if ((m | 0) == 21) {
	                                m = 0;
	                                if ((d[c[h >> 2] >> 0] | 0 | 0) >= 97 ? (d[c[h >> 2] >> 0] | 0 | 0) <= 122 : 0) {
	                                    l = 1;
	                                    break
	                                }
	                                if ((d[c[h >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[h >> 2] >> 0] | 0 | 0) <= 57 : 0) {
	                                    l = 1;
	                                    break
	                                }
	                                if ((d[c[h >> 2] >> 0] | 0 | 0) != 45 ? (d[c[h >> 2] >> 0] | 0 | 0) != 95 : 0) {
	                                    if ((d[c[h >> 2] >> 0] | 0 | 0) == 58) {
	                                        l = 1;
	                                        break
	                                    }
	                                    l = (d[c[h >> 2] >> 0] | 0 | 0) == 47
	                                } else l = 1
	                            } while (0);
	                            n = c[h >> 2] | 0;
	                            if (!l)break;
	                            c[h >> 2] = n + 1
	                        }
	                        if ((n | 0) == (c[g >> 2] | 0)) {
	                            c[e >> 2] = 0;
	                            k = c[e >> 2] | 0;
	                            i = b;
	                            return k | 0
	                        } else {
	                            c[e >> 2] = ly(c[g >> 2] | 0, (c[h >> 2] | 0) - (c[g >> 2] | 0) | 0) | 0;
	                            k = c[e >> 2] | 0;
	                            i = b;
	                            return k | 0
	                        }
	                    }
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = b;
	                    return k | 0
	                }
	                c[e >> 2] = 0;
	                k = c[e >> 2] | 0;
	                i = b;
	                return k | 0
	            }

	            function mp(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                c[g >> 2] = 0;
	                a = c[e >> 2] | 0;
	                if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 34) {
	                    me(a);
	                    c[f >> 2] = c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                    while (1) {
	                        if (9 <= (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)h = 7; else if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13 ? 32 > (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) : 0)j = 0; else h = 7;
	                        if ((h | 0) == 7) {
	                            h = 0;
	                            j = (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 34
	                        }
	                        k = c[e >> 2] | 0;
	                        if (!j)break;
	                        me(k)
	                    }
	                    if (!(9 <= (d[c[(c[k + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0))h = 12;
	                    if (((h | 0) == 12 ? (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13 : 0) ? 32 > (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) : 0) {
	                        zo(c[e >> 2] | 0, 44, 97280, 0, 0);
	                        l = c[g >> 2] | 0;
	                        i = b;
	                        return l | 0
	                    }
	                    c[g >> 2] = ly(c[f >> 2] | 0, (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[f >> 2] | 0) | 0) | 0;
	                    me(c[e >> 2] | 0);
	                    l = c[g >> 2] | 0;
	                    i = b;
	                    return l | 0
	                }
	                k = c[e >> 2] | 0;
	                if ((d[c[(c[a + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 39) {
	                    zo(k, 43, 97312, 0, 0);
	                    l = c[g >> 2] | 0;
	                    i = b;
	                    return l | 0
	                }
	                me(k);
	                c[f >> 2] = c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                while (1) {
	                    if (9 <= (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)h = 22; else if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13 ? 32 > (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) : 0)m = 0; else h = 22;
	                    if ((h | 0) == 22) {
	                        h = 0;
	                        m = (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 39
	                    }
	                    n = c[e >> 2] | 0;
	                    if (!m)break;
	                    me(n)
	                }
	                if (!(9 <= (d[c[(c[n + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0))h = 27;
	                if (((h | 0) == 27 ? (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13 : 0) ? 32 > (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) : 0) {
	                    zo(c[e >> 2] | 0, 44, 97280, 0, 0);
	                    l = c[g >> 2] | 0;
	                    i = b;
	                    return l | 0
	                }
	                c[g >> 2] = ly(c[f >> 2] | 0, (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[f >> 2] | 0) | 0) | 0;
	                me(c[e >> 2] | 0);
	                l = c[g >> 2] | 0;
	                i = b;
	                return l | 0
	            }

	            function np(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = b;
	                c[h >> 2] = 0;
	                b = c[f >> 2] | 0;
	                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) == 34) {
	                    me(b);
	                    c[g >> 2] = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                    while (1) {
	                        j = c[f >> 2] | 0;
	                        if (!(a[198696 + (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) >> 0] | 0))break;
	                        me(j)
	                    }
	                    if ((d[c[(c[j + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) != 34) {
	                        zo(c[f >> 2] | 0, 44, 97216, 0, 0);
	                        k = c[h >> 2] | 0;
	                        i = e;
	                        return k | 0
	                    } else {
	                        c[h >> 2] = ly(c[g >> 2] | 0, (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[g >> 2] | 0) | 0) | 0;
	                        me(c[f >> 2] | 0);
	                        k = c[h >> 2] | 0;
	                        i = e;
	                        return k | 0
	                    }
	                }
	                j = c[f >> 2] | 0;
	                if ((d[c[(c[b + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) != 39) {
	                    zo(j, 43, 97248, 0, 0);
	                    k = c[h >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                me(j);
	                c[g >> 2] = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                while (1) {
	                    if (d[198696 + (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) >> 0] | 0)l = (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) != 39; else l = 0;
	                    m = c[f >> 2] | 0;
	                    if (!l)break;
	                    me(m)
	                }
	                if ((d[c[(c[m + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) != 39) {
	                    zo(c[f >> 2] | 0, 44, 97216, 0, 0);
	                    k = c[h >> 2] | 0;
	                    i = e;
	                    return k | 0
	                } else {
	                    c[h >> 2] = ly(c[g >> 2] | 0, (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[g >> 2] | 0) | 0) | 0;
	                    me(c[f >> 2] | 0);
	                    k = c[h >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                return 0
	            }

	            function op(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0, J = 0, K = 0;
	                f = i;
	                i = i + 112 | 0;
	                g = f + 96 | 0;
	                h = f + 92 | 0;
	                j = f + 100 | 0;
	                k = f + 88 | 0;
	                l = f + 84 | 0;
	                m = f + 80 | 0;
	                n = f + 76 | 0;
	                o = f + 72 | 0;
	                p = f + 68 | 0;
	                q = f + 64 | 0;
	                r = f + 60 | 0;
	                s = f + 56 | 0;
	                t = f + 52 | 0;
	                u = f + 48 | 0;
	                v = f + 44 | 0;
	                w = f + 40 | 0;
	                x = f + 36 | 0;
	                y = f + 32 | 0;
	                z = f + 28 | 0;
	                A = f + 24 | 0;
	                B = f + 20 | 0;
	                C = f + 16 | 0;
	                D = f + 12 | 0;
	                E = f + 8 | 0;
	                F = f + 4 | 0;
	                G = f;
	                c[h >> 2] = b;
	                a[j >> 0] = e;
	                c[k >> 2] = 0;
	                c[l >> 2] = 0;
	                c[m >> 2] = 0;
	                c[n >> 2] = 0;
	                c[o >> 2] = 0;
	                c[l >> 2] = 100;
	                c[k >> 2] = Cb[c[135752 >> 2] & 511](c[l >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    xo(c[h >> 2] | 0, 97424);
	                    c[g >> 2] = 0;
	                    H = c[g >> 2] | 0;
	                    i = f;
	                    return H | 0
	                }
	                c[m >> 2] = c[k >> 2];
	                a:while (1) {
	                    if (!(d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0)) {
	                        I = 68;
	                        break
	                    }
	                    if ((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == (d[j >> 0] | 0 | 0)) {
	                        I = 68;
	                        break
	                    }
	                    if ((d[j >> 0] | 0 | 0) == 0 ? (d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 62 : 0) {
	                        I = 68;
	                        break
	                    }
	                    if (!(d[j >> 0] | 0)) {
	                        if ((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 32) {
	                            I = 68;
	                            break
	                        }
	                        if (9 <= (d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            I = 68;
	                            break
	                        }
	                        if ((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 13) {
	                            I = 68;
	                            break
	                        }
	                    }
	                    if ((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 38) {
	                        if (((c[m >> 2] | 0) - (c[k >> 2] | 0) | 0) > ((c[l >> 2] | 0) - 100 | 0)) {
	                            c[F >> 2] = (c[m >> 2] | 0) - (c[k >> 2] | 0);
	                            c[l >> 2] = c[l >> 2] << 1;
	                            c[G >> 2] = Hb[c[135760 >> 2] & 511](c[k >> 2] | 0, c[l >> 2] | 0) | 0;
	                            if (!(c[G >> 2] | 0)) {
	                                I = 56;
	                                break
	                            }
	                            c[k >> 2] = c[G >> 2];
	                            c[m >> 2] = (c[k >> 2] | 0) + (c[F >> 2] | 0)
	                        }
	                        c[C >> 2] = ap(c[h >> 2] | 0, E) | 0;
	                        e = c[C >> 2] | 0;
	                        do if ((c[C >> 2] | 0) >>> 0 >= 128) {
	                            b = c[C >> 2] | 0;
	                            if (e >>> 0 < 2048) {
	                                J = c[m >> 2] | 0;
	                                c[m >> 2] = J + 1;
	                                a[J >> 0] = b >>> 6 & 31 | 192;
	                                c[D >> 2] = 0;
	                                break
	                            }
	                            J = c[C >> 2] | 0;
	                            if (b >>> 0 < 65536) {
	                                b = c[m >> 2] | 0;
	                                c[m >> 2] = b + 1;
	                                a[b >> 0] = J >>> 12 & 15 | 224;
	                                c[D >> 2] = 6;
	                                break
	                            } else {
	                                b = c[m >> 2] | 0;
	                                c[m >> 2] = b + 1;
	                                a[b >> 0] = J >>> 18 & 7 | 240;
	                                c[D >> 2] = 12;
	                                break
	                            }
	                        } else {
	                            J = c[m >> 2] | 0;
	                            c[m >> 2] = J + 1;
	                            a[J >> 0] = e;
	                            c[D >> 2] = -6
	                        } while (0);
	                        while (1) {
	                            if ((c[D >> 2] | 0) < 0)break;
	                            e = ((c[C >> 2] | 0) >>> (c[D >> 2] | 0) & 63 | 128) & 255;
	                            J = c[m >> 2] | 0;
	                            c[m >> 2] = J + 1;
	                            a[J >> 0] = e;
	                            c[D >> 2] = (c[D >> 2] | 0) - 6
	                        }
	                        me(c[h >> 2] | 0);
	                        continue
	                    }
	                    e = c[h >> 2] | 0;
	                    if ((d[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 35) {
	                        c[q >> 2] = io(e) | 0;
	                        J = c[q >> 2] | 0;
	                        do if ((c[q >> 2] | 0) >>> 0 >= 128) {
	                            b = c[q >> 2] | 0;
	                            if (J >>> 0 < 2048) {
	                                K = c[m >> 2] | 0;
	                                c[m >> 2] = K + 1;
	                                a[K >> 0] = b >>> 6 & 31 | 192;
	                                c[r >> 2] = 0;
	                                break
	                            }
	                            K = c[q >> 2] | 0;
	                            if (b >>> 0 < 65536) {
	                                b = c[m >> 2] | 0;
	                                c[m >> 2] = b + 1;
	                                a[b >> 0] = K >>> 12 & 15 | 224;
	                                c[r >> 2] = 6;
	                                break
	                            } else {
	                                b = c[m >> 2] | 0;
	                                c[m >> 2] = b + 1;
	                                a[b >> 0] = K >>> 18 & 7 | 240;
	                                c[r >> 2] = 12;
	                                break
	                            }
	                        } else {
	                            K = c[m >> 2] | 0;
	                            c[m >> 2] = K + 1;
	                            a[K >> 0] = J;
	                            c[r >> 2] = -6
	                        } while (0);
	                        while (1) {
	                            if ((c[r >> 2] | 0) < 0)break;
	                            J = ((c[q >> 2] | 0) >>> (c[r >> 2] | 0) & 63 | 128) & 255;
	                            K = c[m >> 2] | 0;
	                            c[m >> 2] = K + 1;
	                            a[K >> 0] = J;
	                            c[r >> 2] = (c[r >> 2] | 0) - 6
	                        }
	                        if (((c[m >> 2] | 0) - (c[k >> 2] | 0) | 0) <= ((c[l >> 2] | 0) - 100 | 0))continue;
	                        c[s >> 2] = (c[m >> 2] | 0) - (c[k >> 2] | 0);
	                        c[l >> 2] = c[l >> 2] << 1;
	                        c[t >> 2] = Hb[c[135760 >> 2] & 511](c[k >> 2] | 0, c[l >> 2] | 0) | 0;
	                        if (!(c[t >> 2] | 0)) {
	                            I = 26;
	                            break
	                        }
	                        c[k >> 2] = c[t >> 2];
	                        c[m >> 2] = (c[k >> 2] | 0) + (c[s >> 2] | 0);
	                        continue
	                    }
	                    c[p >> 2] = ho(e, n) | 0;
	                    if (!(c[n >> 2] | 0)) {
	                        J = c[m >> 2] | 0;
	                        c[m >> 2] = J + 1;
	                        a[J >> 0] = 38;
	                        if (((c[m >> 2] | 0) - (c[k >> 2] | 0) | 0) <= ((c[l >> 2] | 0) - 100 | 0))continue;
	                        c[u >> 2] = (c[m >> 2] | 0) - (c[k >> 2] | 0);
	                        c[l >> 2] = c[l >> 2] << 1;
	                        c[v >> 2] = Hb[c[135760 >> 2] & 511](c[k >> 2] | 0, c[l >> 2] | 0) | 0;
	                        if (!(c[v >> 2] | 0)) {
	                            I = 31;
	                            break
	                        }
	                        c[k >> 2] = c[v >> 2];
	                        c[m >> 2] = (c[k >> 2] | 0) + (c[u >> 2] | 0);
	                        continue
	                    }
	                    J = c[m >> 2] | 0;
	                    if (!(c[p >> 2] | 0)) {
	                        c[m >> 2] = J + 1;
	                        a[J >> 0] = 38;
	                        c[o >> 2] = c[n >> 2];
	                        while (1) {
	                            if (!(d[c[o >> 2] >> 0] | 0))continue a;
	                            if (((c[m >> 2] | 0) - (c[k >> 2] | 0) | 0) > ((c[l >> 2] | 0) - 100 | 0)) {
	                                c[w >> 2] = (c[m >> 2] | 0) - (c[k >> 2] | 0);
	                                c[l >> 2] = c[l >> 2] << 1;
	                                c[x >> 2] = Hb[c[135760 >> 2] & 511](c[k >> 2] | 0, c[l >> 2] | 0) | 0;
	                                if (!(c[x >> 2] | 0)) {
	                                    I = 38;
	                                    break a
	                                }
	                                c[k >> 2] = c[x >> 2];
	                                c[m >> 2] = (c[k >> 2] | 0) + (c[w >> 2] | 0)
	                            }
	                            K = c[o >> 2] | 0;
	                            c[o >> 2] = K + 1;
	                            b = a[K >> 0] | 0;
	                            K = c[m >> 2] | 0;
	                            c[m >> 2] = K + 1;
	                            a[K >> 0] = b
	                        }
	                    }
	                    if ((J - (c[k >> 2] | 0) | 0) > ((c[l >> 2] | 0) - 100 | 0)) {
	                        c[A >> 2] = (c[m >> 2] | 0) - (c[k >> 2] | 0);
	                        c[l >> 2] = c[l >> 2] << 1;
	                        c[B >> 2] = Hb[c[135760 >> 2] & 511](c[k >> 2] | 0, c[l >> 2] | 0) | 0;
	                        if (!(c[B >> 2] | 0)) {
	                            I = 43;
	                            break
	                        }
	                        c[k >> 2] = c[B >> 2];
	                        c[m >> 2] = (c[k >> 2] | 0) + (c[A >> 2] | 0)
	                    }
	                    c[y >> 2] = c[c[p >> 2] >> 2];
	                    e = c[y >> 2] | 0;
	                    do if ((c[y >> 2] | 0) >>> 0 >= 128) {
	                        b = c[y >> 2] | 0;
	                        if (e >>> 0 < 2048) {
	                            K = c[m >> 2] | 0;
	                            c[m >> 2] = K + 1;
	                            a[K >> 0] = b >>> 6 & 31 | 192;
	                            c[z >> 2] = 0;
	                            break
	                        }
	                        K = c[y >> 2] | 0;
	                        if (b >>> 0 < 65536) {
	                            b = c[m >> 2] | 0;
	                            c[m >> 2] = b + 1;
	                            a[b >> 0] = K >>> 12 & 15 | 224;
	                            c[z >> 2] = 6;
	                            break
	                        } else {
	                            b = c[m >> 2] | 0;
	                            c[m >> 2] = b + 1;
	                            a[b >> 0] = K >>> 18 & 7 | 240;
	                            c[z >> 2] = 12;
	                            break
	                        }
	                    } else {
	                        K = c[m >> 2] | 0;
	                        c[m >> 2] = K + 1;
	                        a[K >> 0] = e;
	                        c[z >> 2] = -6
	                    } while (0);
	                    while (1) {
	                        if ((c[z >> 2] | 0) < 0)continue a;
	                        e = ((c[y >> 2] | 0) >>> (c[z >> 2] | 0) & 63 | 128) & 255;
	                        J = c[m >> 2] | 0;
	                        c[m >> 2] = J + 1;
	                        a[J >> 0] = e;
	                        c[z >> 2] = (c[z >> 2] | 0) - 6
	                    }
	                }
	                if ((I | 0) == 26) {
	                    xo(c[h >> 2] | 0, 98024);
	                    zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    c[g >> 2] = 0;
	                    H = c[g >> 2] | 0;
	                    i = f;
	                    return H | 0
	                } else if ((I | 0) == 31) {
	                    xo(c[h >> 2] | 0, 98024);
	                    zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    c[g >> 2] = 0;
	                    H = c[g >> 2] | 0;
	                    i = f;
	                    return H | 0
	                } else if ((I | 0) == 38) {
	                    xo(c[h >> 2] | 0, 98024);
	                    zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    c[g >> 2] = 0;
	                    H = c[g >> 2] | 0;
	                    i = f;
	                    return H | 0
	                } else if ((I | 0) == 43) {
	                    xo(c[h >> 2] | 0, 98024);
	                    zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    c[g >> 2] = 0;
	                    H = c[g >> 2] | 0;
	                    i = f;
	                    return H | 0
	                } else if ((I | 0) == 56) {
	                    xo(c[h >> 2] | 0, 98024);
	                    zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    c[g >> 2] = 0;
	                    H = c[g >> 2] | 0;
	                    i = f;
	                    return H | 0
	                } else if ((I | 0) == 68) {
	                    a[c[m >> 2] >> 0] = 0;
	                    c[g >> 2] = c[k >> 2];
	                    H = c[g >> 2] | 0;
	                    i = f;
	                    return H | 0
	                }
	                return 0
	            }

	            function pp(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                c[e >> 2] = 0;
	                while (1) {
	                    if (c[95744 + (c[e >> 2] << 3) >> 2] | 0)f = (qy(c[95744 + (c[e >> 2] << 3) >> 2] | 0, c[d >> 2] | 0) | 0) != 0 ^ 1; else f = 0;
	                    g = c[e >> 2] | 0;
	                    if (!f)break;
	                    c[e >> 2] = g + 1
	                }
	                i = b;
	                return c[95748 + (g << 3) >> 2] | 0
	            }

	            function qp(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                b = i;
	                i = i + 32 | 0;
	                e = b + 28 | 0;
	                f = b + 24 | 0;
	                g = b + 20 | 0;
	                h = b + 16 | 0;
	                j = b + 12 | 0;
	                k = b + 8 | 0;
	                l = b + 4 | 0;
	                m = b;
	                c[f >> 2] = a;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    n = c[e >> 2] | 0;
	                    i = b;
	                    return n | 0
	                }
	                c[g >> 2] = c[(c[f >> 2] | 0) + 12 >> 2];
	                while (1) {
	                    if (!(c[g >> 2] | 0)) {
	                        o = 11;
	                        break
	                    }
	                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 ? (c[(c[g >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                        if (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 120888) | 0) {
	                            o = 11;
	                            break
	                        }
	                        if (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 120896) | 0) {
	                            o = 22;
	                            break
	                        }
	                        if (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 120904) | 0)break
	                    }
	                    c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2]
	                }
	                a:do if ((o | 0) == 11) {
	                    if (!(c[g >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        n = c[e >> 2] | 0;
	                        i = b;
	                        return n | 0
	                    }
	                    c[g >> 2] = c[(c[g >> 2] | 0) + 12 >> 2];
	                    while (1) {
	                        if (!(c[g >> 2] | 0))break;
	                        if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 ? (c[(c[g >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                            if (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 120896) | 0)break;
	                            if (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 120904) | 0)break a
	                        }
	                        c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2]
	                    }
	                    if (!(c[g >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        n = c[e >> 2] | 0;
	                        i = b;
	                        return n | 0
	                    } else o = 22
	                } while (0);
	                if ((o | 0) == 22)c[g >> 2] = c[(c[g >> 2] | 0) + 12 >> 2];
	                b:while (1) {
	                    if (!(c[g >> 2] | 0)) {
	                        o = 41;
	                        break
	                    }
	                    c:do if (((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 ? (c[(c[g >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 120904) | 0) != 0 : 0) {
	                        c[k >> 2] = c[(c[g >> 2] | 0) + 44 >> 2];
	                        c[h >> 2] = 0;
	                        c[l >> 2] = 0;
	                        while (1) {
	                            if (!(c[k >> 2] | 0))break c;
	                            if (((c[(c[k >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[(c[(c[k >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) == 3 : 0) ? (c[(c[(c[k >> 2] | 0) + 12 >> 2] | 0) + 24 >> 2] | 0) == 0 : 0) {
	                                c[m >> 2] = c[(c[(c[k >> 2] | 0) + 12 >> 2] | 0) + 40 >> 2];
	                                if ((ty(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 120912) | 0) == 0 ? (ty(c[m >> 2] | 0, 120928) | 0) == 0 : 0)c[l >> 2] = 1; else o = 35;
	                                if (((o | 0) == 35 ? (o = 0, (c[m >> 2] | 0) != 0) : 0) ? (ty(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 120944) | 0) == 0 : 0)c[h >> 2] = c[m >> 2];
	                                if ((c[l >> 2] | 0) != 0 & (c[h >> 2] | 0) != 0)break b
	                            }
	                            c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                        }
	                    } while (0);
	                    c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2]
	                }
	                if ((o | 0) == 41) {
	                    c[e >> 2] = 0;
	                    n = c[e >> 2] | 0;
	                    i = b;
	                    return n | 0
	                }
	                c[j >> 2] = wy(c[h >> 2] | 0, 120952) | 0;
	                if (!(c[j >> 2] | 0))c[j >> 2] = wy(c[h >> 2] | 0, 120968) | 0;
	                if (!(c[j >> 2] | 0))c[j >> 2] = wy(c[h >> 2] | 0, 120984) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    c[j >> 2] = wy(c[h >> 2] | 0, 121e3) | 0;
	                    if (!(c[j >> 2] | 0))c[j >> 2] = wy(c[h >> 2] | 0, 121016) | 0;
	                    if (!(c[j >> 2] | 0))c[j >> 2] = wy(c[h >> 2] | 0, 121032) | 0;
	                    if (c[j >> 2] | 0)c[j >> 2] = (c[j >> 2] | 0) + 9
	                } else c[j >> 2] = (c[j >> 2] | 0) + 8;
	                d:do if (c[j >> 2] | 0)while (1) {
	                    if ((d[c[j >> 2] >> 0] | 0 | 0) != 32 ? (d[c[j >> 2] >> 0] | 0 | 0) != 9 : 0)break d;
	                    c[j >> 2] = (c[j >> 2] | 0) + 1
	                } while (0);
	                c[e >> 2] = c[j >> 2];
	                n = c[e >> 2] | 0;
	                i = b;
	                return n | 0
	            }

	            function rp(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                e = i;
	                i = i + 144 | 0;
	                f = e;
	                g = e + 40 | 0;
	                h = e + 36 | 0;
	                j = e + 32 | 0;
	                k = e + 28 | 0;
	                l = e + 24 | 0;
	                m = e + 20 | 0;
	                n = e + 16 | 0;
	                o = e + 44 | 0;
	                p = e + 12 | 0;
	                q = e + 8 | 0;
	                r = e + 4 | 0;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[l >> 2] = 0;
	                c[m >> 2] = 0;
	                c[n >> 2] = 0;
	                a[o >> 0] = 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[g >> 2] = -1;
	                    s = c[g >> 2] | 0;
	                    i = e;
	                    return s | 0
	                }
	                if (!(ty(c[j >> 2] | 0, 120888) | 0)) {
	                    c[g >> 2] = -1;
	                    s = c[g >> 2] | 0;
	                    i = e;
	                    return s | 0
	                }
	                if (c[j >> 2] | 0) {
	                    c[f >> 2] = c[j >> 2];
	                    JT(o, 100, 121048, f) | 0;
	                    a[o + 99 >> 0] = 0
	                }
	                c[k >> 2] = c[(c[h >> 2] | 0) + 12 >> 2];
	                while (1) {
	                    if (!(c[k >> 2] | 0)) {
	                        t = 15;
	                        break
	                    }
	                    if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 1 ? (c[(c[k >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                        if (!(ty(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 120888) | 0)) {
	                            t = 15;
	                            break
	                        }
	                        if (!(ty(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 120896) | 0)) {
	                            t = 27;
	                            break
	                        }
	                        if (!(ty(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 120904) | 0)) {
	                            t = 29;
	                            break
	                        }
	                    }
	                    c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                }
	                do if ((t | 0) == 15) {
	                    if (!(c[k >> 2] | 0)) {
	                        c[g >> 2] = -1;
	                        s = c[g >> 2] | 0;
	                        i = e;
	                        return s | 0
	                    }
	                    c[k >> 2] = c[(c[k >> 2] | 0) + 12 >> 2];
	                    while (1) {
	                        if (!(c[k >> 2] | 0))break;
	                        if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 1 ? (c[(c[k >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                            if (!(ty(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 120896) | 0))break;
	                            if (!(ty(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 120904) | 0)) {
	                                t = 23;
	                                break
	                            }
	                        }
	                        c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                    }
	                    if ((t | 0) == 23) {
	                        c[m >> 2] = c[(c[k >> 2] | 0) + 20 >> 2];
	                        t = 29;
	                        break
	                    }
	                    if (!(c[k >> 2] | 0)) {
	                        c[g >> 2] = -1;
	                        s = c[g >> 2] | 0;
	                        i = e;
	                        return s | 0
	                    } else t = 27
	                } while (0);
	                if ((t | 0) == 27 ? (c[m >> 2] = c[k >> 2], (c[(c[k >> 2] | 0) + 12 >> 2] | 0) != 0) : 0) {
	                    c[k >> 2] = c[(c[k >> 2] | 0) + 12 >> 2];
	                    t = 29
	                }
	                a:do if ((t | 0) == 29) {
	                    while (1) {
	                        t = 0;
	                        if (!(c[k >> 2] | 0))break a;
	                        if (((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 1 ? (c[(c[k >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (ty(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 120904) | 0) == 0 : 0) {
	                            c[p >> 2] = c[(c[k >> 2] | 0) + 44 >> 2];
	                            c[n >> 2] = 0;
	                            c[q >> 2] = 0;
	                            while (1) {
	                                if (!(c[p >> 2] | 0))break;
	                                if (((c[(c[p >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[(c[(c[p >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) == 3 : 0) ? (c[(c[(c[p >> 2] | 0) + 12 >> 2] | 0) + 24 >> 2] | 0) == 0 : 0) {
	                                    c[r >> 2] = c[(c[(c[p >> 2] | 0) + 12 >> 2] | 0) + 40 >> 2];
	                                    if ((ty(c[(c[p >> 2] | 0) + 8 >> 2] | 0, 120912) | 0) == 0 ? (ty(c[r >> 2] | 0, 120928) | 0) == 0 : 0)c[q >> 2] = 1; else t = 41;
	                                    if (((t | 0) == 41 ? (t = 0, (c[r >> 2] | 0) != 0) : 0) ? (ty(c[(c[p >> 2] | 0) + 8 >> 2] | 0, 120944) | 0) == 0 : 0)c[n >> 2] = c[r >> 2];
	                                    if ((c[q >> 2] | 0) != 0 & (c[n >> 2] | 0) != 0)break
	                                }
	                                c[p >> 2] = c[(c[p >> 2] | 0) + 24 >> 2]
	                            }
	                            if ((c[q >> 2] | 0) != 0 & (c[n >> 2] | 0) != 0)break
	                        }
	                        c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2];
	                        t = 29
	                    }
	                    c[l >> 2] = c[k >> 2]
	                } while (0);
	                k = c[j >> 2] | 0;
	                do if (!(c[l >> 2] | 0)) {
	                    if ((k | 0) != 0 & (c[m >> 2] | 0) != 0) {
	                        c[l >> 2] = ji(c[h >> 2] | 0, 0, 120904, 0) | 0;
	                        t = c[m >> 2] | 0;
	                        if (!(c[(c[m >> 2] | 0) + 12 >> 2] | 0))zi(t, c[l >> 2] | 0) | 0; else wi(c[t + 12 >> 2] | 0, c[l >> 2] | 0) | 0;
	                        $h(c[l >> 2] | 0, 120912, 120928) | 0;
	                        $h(c[l >> 2] | 0, 120944, o) | 0
	                    }
	                } else {
	                    if (!k) {
	                        Qh(c[l >> 2] | 0);
	                        Rh(c[l >> 2] | 0);
	                        break
	                    }
	                    if (!(yy(c[n >> 2] | 0, c[j >> 2] | 0) | 0))gj(c[l >> 2] | 0, 120944, o) | 0
	                } while (0);
	                c[g >> 2] = 0;
	                s = c[g >> 2] | 0;
	                i = e;
	                return s | 0
	            }

	            function sp(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                while (1) {
	                    if (!(c[121072 + (c[f >> 2] << 2) >> 2] | 0)) {
	                        g = 6;
	                        break
	                    }
	                    if (!(ty(c[121072 + (c[f >> 2] << 2) >> 2] | 0, c[e >> 2] | 0) | 0)) {
	                        g = 4;
	                        break
	                    }
	                    c[f >> 2] = (c[f >> 2] | 0) + 1
	                }
	                if ((g | 0) == 4) {
	                    c[d >> 2] = 1;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                } else if ((g | 0) == 6) {
	                    c[d >> 2] = 0;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                return 0
	            }

	            function tp(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                g = i;
	                i = i + 48 | 0;
	                h = g + 36 | 0;
	                j = g + 32 | 0;
	                k = g + 28 | 0;
	                l = g + 24 | 0;
	                m = g + 20 | 0;
	                n = g + 16 | 0;
	                o = g + 12 | 0;
	                p = g + 8 | 0;
	                q = g + 4 | 0;
	                r = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[p >> 2] = 0;
	                Rf();
	                if (((c[m >> 2] | 0) != 0 ? (c[r >> 2] = wd(c[m >> 2] | 0) | 0, (c[r >> 2] | 0) != 1) : 0) ? (c[p >> 2] = Dd(c[m >> 2] | 0) | 0, (c[p >> 2] | 0) == 0) : 0)Cp(1403, 0, c[m >> 2] | 0);
	                if (!(c[p >> 2] | 0))c[p >> 2] = Dd(121128) | 0;
	                if (!(c[p >> 2] | 0))c[p >> 2] = Dd(121136) | 0;
	                c[o >> 2] = Fk(c[j >> 2] | 0, c[p >> 2] | 0) | 0;
	                if (!(c[o >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    s = c[h >> 2] | 0;
	                    i = g;
	                    return s | 0
	                } else {
	                    up(c[o >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0);
	                    c[q >> 2] = zk(c[o >> 2] | 0) | 0;
	                    c[h >> 2] = c[q >> 2];
	                    s = c[h >> 2] | 0;
	                    i = g;
	                    return s | 0
	                }
	                return 0
	            }

	            function up(b, e, f, g, h) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                j = i;
	                i = i + 32 | 0;
	                k = j + 24 | 0;
	                l = j + 20 | 0;
	                m = j + 16 | 0;
	                n = j + 12 | 0;
	                o = j + 8 | 0;
	                p = j + 4 | 0;
	                q = j;
	                c[k >> 2] = b;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                c[n >> 2] = g;
	                c[o >> 2] = h;
	                Rf();
	                if ((c[m >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0) {
	                    i = j;
	                    return
	                }
	                if ((c[(c[m >> 2] | 0) + 4 >> 2] | 0) == 14) {
	                    i = j;
	                    return
	                }
	                if ((c[(c[m >> 2] | 0) + 4 >> 2] | 0) != 13 ? (c[(c[m >> 2] | 0) + 4 >> 2] | 0) != 9 : 0) {
	                    if ((c[(c[m >> 2] | 0) + 4 >> 2] | 0) == 2) {
	                        Dp(c[k >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0);
	                        i = j;
	                        return
	                    }
	                    h = c[m >> 2] | 0;
	                    if ((c[(c[m >> 2] | 0) + 4 >> 2] | 0) == 3) {
	                        if (!(c[h + 40 >> 2] | 0)) {
	                            i = j;
	                            return
	                        }
	                        if (!((c[(c[m >> 2] | 0) + 8 >> 2] | 0) != 75104 ? (c[(c[m >> 2] | 0) + 8 >> 2] | 0) == 75112 : 0))r = 12;
	                        do if ((r | 0) == 12) {
	                            if (c[(c[m >> 2] | 0) + 20 >> 2] | 0) {
	                                if (!(ty(c[(c[(c[m >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0, 121144) | 0))break;
	                                if (!(ty(c[(c[(c[m >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0, 121152) | 0))break
	                            }
	                            c[q >> 2] = cd(c[l >> 2] | 0, c[(c[m >> 2] | 0) + 40 >> 2] | 0) | 0;
	                            if (!(c[q >> 2] | 0)) {
	                                i = j;
	                                return
	                            }
	                            Qk(c[k >> 2] | 0, c[q >> 2] | 0) | 0;
	                            zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                            i = j;
	                            return
	                        } while (0);
	                        Qk(c[k >> 2] | 0, c[(c[m >> 2] | 0) + 40 >> 2] | 0) | 0;
	                        i = j;
	                        return
	                    }
	                    q = c[m >> 2] | 0;
	                    if ((c[h + 4 >> 2] | 0) == 8) {
	                        if (!(c[q + 40 >> 2] | 0)) {
	                            i = j;
	                            return
	                        }
	                        Qk(c[k >> 2] | 0, 121160) | 0;
	                        Qk(c[k >> 2] | 0, c[(c[m >> 2] | 0) + 40 >> 2] | 0) | 0;
	                        Qk(c[k >> 2] | 0, 121168) | 0;
	                        i = j;
	                        return
	                    }
	                    h = c[m >> 2] | 0;
	                    if ((c[q + 4 >> 2] | 0) == 7) {
	                        if (!(c[h + 8 >> 2] | 0)) {
	                            i = j;
	                            return
	                        }
	                        Qk(c[k >> 2] | 0, 121176) | 0;
	                        Qk(c[k >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        if (c[(c[m >> 2] | 0) + 40 >> 2] | 0) {
	                            Qk(c[k >> 2] | 0, 121184) | 0;
	                            Qk(c[k >> 2] | 0, c[(c[m >> 2] | 0) + 40 >> 2] | 0) | 0
	                        }
	                        Qk(c[k >> 2] | 0, 121192) | 0;
	                        i = j;
	                        return
	                    }
	                    if ((c[h + 4 >> 2] | 0) == 5) {
	                        Qk(c[k >> 2] | 0, 121200) | 0;
	                        Qk(c[k >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        Qk(c[k >> 2] | 0, 121208) | 0;
	                        i = j;
	                        return
	                    }
	                    h = c[m >> 2] | 0;
	                    if ((c[(c[m >> 2] | 0) + 4 >> 2] | 0) == 4) {
	                        if (!(c[h + 40 >> 2] | 0)) {
	                            i = j;
	                            return
	                        }
	                        Qk(c[k >> 2] | 0, c[(c[m >> 2] | 0) + 40 >> 2] | 0) | 0;
	                        i = j;
	                        return
	                    }
	                    if (!(c[h + 36 >> 2] | 0))c[p >> 2] = bo(c[(c[m >> 2] | 0) + 8 >> 2] | 0) | 0; else c[p >> 2] = 0;
	                    Qk(c[k >> 2] | 0, 121216) | 0;
	                    if ((c[(c[m >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                        Qk(c[k >> 2] | 0, c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0;
	                        Qk(c[k >> 2] | 0, 121224) | 0
	                    }
	                    Qk(c[k >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0) | 0;
	                    if (c[(c[m >> 2] | 0) + 48 >> 2] | 0)qR(c[k >> 2] | 0, c[(c[m >> 2] | 0) + 48 >> 2] | 0);
	                    if (c[(c[m >> 2] | 0) + 44 >> 2] | 0)Ep(c[k >> 2] | 0, c[l >> 2] | 0, c[(c[m >> 2] | 0) + 44 >> 2] | 0, c[n >> 2] | 0);
	                    if ((c[p >> 2] | 0) != 0 ? (a[(c[p >> 2] | 0) + 7 >> 0] | 0) != 0 : 0) {
	                        Qk(c[k >> 2] | 0, 121192) | 0;
	                        if (!(c[o >> 2] | 0)) {
	                            i = j;
	                            return
	                        }
	                        if (a[(c[p >> 2] | 0) + 10 >> 0] | 0) {
	                            i = j;
	                            return
	                        }
	                        if (!(c[(c[m >> 2] | 0) + 24 >> 2] | 0)) {
	                            i = j;
	                            return
	                        }
	                        if ((c[(c[(c[m >> 2] | 0) + 24 >> 2] | 0) + 4 >> 2] | 0) == 3) {
	                            i = j;
	                            return
	                        }
	                        if ((c[(c[(c[m >> 2] | 0) + 24 >> 2] | 0) + 4 >> 2] | 0) == 5) {
	                            i = j;
	                            return
	                        }
	                        if (!(c[(c[m >> 2] | 0) + 20 >> 2] | 0)) {
	                            i = j;
	                            return
	                        }
	                        if (!(c[(c[(c[m >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0)) {
	                            i = j;
	                            return
	                        }
	                        if ((d[c[(c[(c[m >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] >> 0] | 0) == 112) {
	                            i = j;
	                            return
	                        }
	                        Qk(c[k >> 2] | 0, 121232) | 0;
	                        i = j;
	                        return
	                    }
	                    if (!((c[(c[m >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[m >> 2] | 0) + 40 >> 2] | 0) != 0 : 0))r = 54;
	                    if ((r | 0) == 54 ? (c[(c[m >> 2] | 0) + 12 >> 2] | 0) == 0 : 0) {
	                        do if (c[p >> 2] | 0) {
	                            if (!(a[(c[p >> 2] | 0) + 6 >> 0] | 0)) {
	                                r = 60;
	                                break
	                            }
	                            if (!(py(c[c[p >> 2] >> 2] | 0, 120888) | 0)) {
	                                r = 60;
	                                break
	                            }
	                            if (!(py(c[c[p >> 2] >> 2] | 0, 121240) | 0)) {
	                                r = 60;
	                                break
	                            }
	                            Qk(c[k >> 2] | 0, 121192) | 0
	                        } else r = 60; while (0);
	                        if ((r | 0) == 60) {
	                            Qk(c[k >> 2] | 0, 121248) | 0;
	                            do if (c[(c[m >> 2] | 0) + 36 >> 2] | 0) {
	                                if (!(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0))break;
	                                Qk(c[k >> 2] | 0, c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0;
	                                Qk(c[k >> 2] | 0, 121224) | 0
	                            } while (0);
	                            Qk(c[k >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0) | 0;
	                            Qk(c[k >> 2] | 0, 121192) | 0
	                        }
	                        if (!(c[o >> 2] | 0)) {
	                            i = j;
	                            return
	                        }
	                        if (!((c[p >> 2] | 0) != 0 ? (c[(c[m >> 2] | 0) + 24 >> 2] | 0) != 0 : 0)) {
	                            i = j;
	                            return
	                        }
	                        if (a[(c[p >> 2] | 0) + 10 >> 0] | 0) {
	                            i = j;
	                            return
	                        }
	                        if ((c[(c[(c[m >> 2] | 0) + 24 >> 2] | 0) + 4 >> 2] | 0) == 3) {
	                            i = j;
	                            return
	                        }
	                        if ((c[(c[(c[m >> 2] | 0) + 24 >> 2] | 0) + 4 >> 2] | 0) == 5) {
	                            i = j;
	                            return
	                        }
	                        if (!(c[(c[m >> 2] | 0) + 20 >> 2] | 0)) {
	                            i = j;
	                            return
	                        }
	                        if (!(c[(c[(c[m >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0)) {
	                            i = j;
	                            return
	                        }
	                        if ((d[c[(c[(c[m >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] >> 0] | 0) == 112) {
	                            i = j;
	                            return
	                        }
	                        Qk(c[k >> 2] | 0, 121232) | 0;
	                        i = j;
	                        return
	                    }
	                    Qk(c[k >> 2] | 0, 121192) | 0;
	                    if ((c[(c[m >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[m >> 2] | 0) + 40 >> 2] | 0) != 0 : 0)Qk(c[k >> 2] | 0, c[(c[m >> 2] | 0) + 40 >> 2] | 0) | 0;
	                    do if (c[(c[m >> 2] | 0) + 12 >> 2] | 0) {
	                        do if ((c[o >> 2] | 0) != 0 & (c[p >> 2] | 0) != 0) {
	                            if (a[(c[p >> 2] | 0) + 10 >> 0] | 0)break;
	                            if ((c[(c[(c[m >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) == 3)break;
	                            if ((c[(c[(c[m >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) == 5)break;
	                            if ((c[(c[m >> 2] | 0) + 12 >> 2] | 0) == (c[(c[m >> 2] | 0) + 16 >> 2] | 0))break;
	                            if (!(c[(c[m >> 2] | 0) + 8 >> 2] | 0))break;
	                            if ((d[c[(c[m >> 2] | 0) + 8 >> 2] >> 0] | 0) == 112)break;
	                            Qk(c[k >> 2] | 0, 121232) | 0
	                        } while (0);
	                        Fp(c[k >> 2] | 0, c[l >> 2] | 0, c[(c[m >> 2] | 0) + 12 >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0);
	                        if (!((c[o >> 2] | 0) != 0 & (c[p >> 2] | 0) != 0))break;
	                        if (a[(c[p >> 2] | 0) + 10 >> 0] | 0)break;
	                        if ((c[(c[(c[m >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) == 3)break;
	                        if ((c[(c[(c[m >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) == 5)break;
	                        if ((c[(c[m >> 2] | 0) + 12 >> 2] | 0) == (c[(c[m >> 2] | 0) + 16 >> 2] | 0))break;
	                        if (!(c[(c[m >> 2] | 0) + 8 >> 2] | 0))break;
	                        if ((d[c[(c[m >> 2] | 0) + 8 >> 2] >> 0] | 0) == 112)break;
	                        Qk(c[k >> 2] | 0, 121232) | 0
	                    } while (0);
	                    Qk(c[k >> 2] | 0, 121256) | 0;
	                    do if (c[(c[m >> 2] | 0) + 36 >> 2] | 0) {
	                        if (!(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0))break;
	                        Qk(c[k >> 2] | 0, c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0;
	                        Qk(c[k >> 2] | 0, 121224) | 0
	                    } while (0);
	                    Qk(c[k >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0) | 0;
	                    Qk(c[k >> 2] | 0, 121192) | 0;
	                    if (!((c[o >> 2] | 0) != 0 & (c[p >> 2] | 0) != 0)) {
	                        i = j;
	                        return
	                    }
	                    if (a[(c[p >> 2] | 0) + 10 >> 0] | 0) {
	                        i = j;
	                        return
	                    }
	                    if (!(c[(c[m >> 2] | 0) + 24 >> 2] | 0)) {
	                        i = j;
	                        return
	                    }
	                    if ((c[(c[(c[m >> 2] | 0) + 24 >> 2] | 0) + 4 >> 2] | 0) == 3) {
	                        i = j;
	                        return
	                    }
	                    if ((c[(c[(c[m >> 2] | 0) + 24 >> 2] | 0) + 4 >> 2] | 0) == 5) {
	                        i = j;
	                        return
	                    }
	                    if (!(c[(c[m >> 2] | 0) + 20 >> 2] | 0)) {
	                        i = j;
	                        return
	                    }
	                    if (!(c[(c[(c[m >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0)) {
	                        i = j;
	                        return
	                    }
	                    if ((d[c[(c[(c[m >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] >> 0] | 0) == 112) {
	                        i = j;
	                        return
	                    }
	                    Qk(c[k >> 2] | 0, 121232) | 0;
	                    i = j;
	                    return
	                }
	                xp(c[k >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0);
	                i = j;
	                return
	            }

	            function vp(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                tp(c[f >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0, 0, 1) | 0;
	                i = e;
	                return
	            }

	            function wp(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                Rf();
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) {
	                    i = f;
	                    return
	                }
	                c[l >> 2] = c[(c[h >> 2] | 0) + 4 >> 2];
	                c[(c[h >> 2] | 0) + 4 >> 2] = 13;
	                if (c[(c[h >> 2] | 0) + 44 >> 2] | 0)Gp(c[g >> 2] | 0, c[h >> 2] | 0, 0);
	                if (c[(c[h >> 2] | 0) + 12 >> 2] | 0)Fp(c[g >> 2] | 0, c[h >> 2] | 0, c[(c[h >> 2] | 0) + 12 >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0);
	                Qk(c[g >> 2] | 0, 121232) | 0;
	                c[(c[h >> 2] | 0) + 4 >> 2] = c[l >> 2];
	                i = f;
	                return
	            }

	            function xp(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                wp(c[f >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0, 1);
	                i = e;
	                return
	            }

	            function yp(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 12 | 0;
	                h = f + 8 | 0;
	                j = f + 4 | 0;
	                k = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                up(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, 1);
	                i = f;
	                return
	            }

	            function zp(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 28 | 0;
	                f = d + 24 | 0;
	                g = d + 20 | 0;
	                h = d + 16 | 0;
	                j = d + 12 | 0;
	                k = d + 8 | 0;
	                l = d + 4 | 0;
	                m = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[j >> 2] = 0;
	                Rf();
	                if ((c[g >> 2] | 0) == 0 | (c[f >> 2] | 0) == 0) {
	                    c[e >> 2] = -1;
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                c[k >> 2] = qp(c[g >> 2] | 0) | 0;
	                do if (c[k >> 2] | 0) {
	                    c[m >> 2] = wd(c[k >> 2] | 0) | 0;
	                    if ((c[m >> 2] | 0) == (c[(c[g >> 2] | 0) + 76 >> 2] | 0)) {
	                        c[j >> 2] = Dd(c[k >> 2] | 0) | 0;
	                        break
	                    }
	                    if ((c[(c[g >> 2] | 0) + 76 >> 2] | 0) != 1) {
	                        c[e >> 2] = -1;
	                        n = c[e >> 2] | 0;
	                        i = d;
	                        return n | 0
	                    } else {
	                        c[j >> 2] = Dd(c[k >> 2] | 0) | 0;
	                        if (c[j >> 2] | 0)break;
	                        Cp(1403, 0, c[k >> 2] | 0);
	                        break
	                    }
	                } while (0);
	                if (!(c[j >> 2] | 0))c[j >> 2] = Dd(121128) | 0;
	                if (!(c[j >> 2] | 0))c[j >> 2] = Dd(121136) | 0;
	                c[h >> 2] = Fk(c[f >> 2] | 0, c[j >> 2] | 0) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                } else {
	                    xp(c[h >> 2] | 0, c[g >> 2] | 0, 0);
	                    c[l >> 2] = zk(c[h >> 2] | 0) | 0;
	                    c[e >> 2] = c[l >> 2];
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                return 0
	            }

	            function Ap(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 28 | 0;
	                f = d + 24 | 0;
	                g = d + 20 | 0;
	                h = d + 16 | 0;
	                j = d + 12 | 0;
	                k = d + 8 | 0;
	                l = d + 4 | 0;
	                m = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[j >> 2] = 0;
	                if ((c[g >> 2] | 0) == 0 | (c[f >> 2] | 0) == 0) {
	                    c[e >> 2] = -1;
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                Rf();
	                c[k >> 2] = qp(c[g >> 2] | 0) | 0;
	                do if ((c[k >> 2] | 0) != 0 ? (c[m >> 2] = wd(c[k >> 2] | 0) | 0, (c[m >> 2] | 0) != (c[(c[g >> 2] | 0) + 76 >> 2] | 0)) : 0)if ((c[(c[g >> 2] | 0) + 76 >> 2] | 0) != 1) {
	                    c[e >> 2] = -1;
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                } else {
	                    c[j >> 2] = Dd(c[k >> 2] | 0) | 0;
	                    if (c[j >> 2] | 0)break;
	                    Cp(1403, 0, c[k >> 2] | 0);
	                    break
	                } while (0);
	                if (!(c[j >> 2] | 0))c[j >> 2] = Dd(121128) | 0;
	                if (!(c[j >> 2] | 0))c[j >> 2] = Dd(121136) | 0;
	                c[h >> 2] = Ek(c[f >> 2] | 0, c[j >> 2] | 0, c[(c[g >> 2] | 0) + 36 >> 2] | 0) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                } else {
	                    xp(c[h >> 2] | 0, c[g >> 2] | 0, 0);
	                    c[l >> 2] = zk(c[h >> 2] | 0) | 0;
	                    c[e >> 2] = c[l >> 2];
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                return 0
	            }

	            function Bp(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f + 32 | 0;
	                h = f + 28 | 0;
	                j = f + 24 | 0;
	                k = f + 20 | 0;
	                l = f + 16 | 0;
	                m = f + 12 | 0;
	                n = f + 8 | 0;
	                o = f + 4 | 0;
	                p = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[n >> 2] = 0;
	                if ((c[j >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) {
	                    c[g >> 2] = -1;
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                Rf();
	                if (c[k >> 2] | 0) {
	                    c[p >> 2] = wd(c[k >> 2] | 0) | 0;
	                    do if ((c[p >> 2] | 0) != (c[(c[j >> 2] | 0) + 76 >> 2] | 0))if ((c[(c[j >> 2] | 0) + 76 >> 2] | 0) != 1) {
	                        c[g >> 2] = -1;
	                        q = c[g >> 2] | 0;
	                        i = f;
	                        return q | 0
	                    } else {
	                        c[n >> 2] = Dd(c[k >> 2] | 0) | 0;
	                        if (c[n >> 2] | 0)break;
	                        Cp(1403, 0, c[k >> 2] | 0);
	                        break
	                    } while (0);
	                    rp(c[j >> 2] | 0, c[k >> 2] | 0) | 0
	                } else rp(c[j >> 2] | 0, 121264) | 0;
	                if (!(c[n >> 2] | 0))c[n >> 2] = Dd(121128) | 0;
	                if (!(c[n >> 2] | 0))c[n >> 2] = Dd(121136) | 0;
	                c[m >> 2] = Ek(c[h >> 2] | 0, c[n >> 2] | 0, 0) | 0;
	                if (!(c[m >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                } else {
	                    wp(c[m >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0);
	                    c[o >> 2] = zk(c[m >> 2] | 0) | 0;
	                    c[g >> 2] = c[o >> 2];
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                return 0
	            }

	            function Cp(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = 0;
	                d = c[f >> 2] | 0;
	                if ((d | 0) == 1402)c[j >> 2] = 121488; else if ((d | 0) == 1401)c[j >> 2] = 121432; else if ((d | 0) == 1400)c[j >> 2] = 121408; else if ((d | 0) == 1403)c[j >> 2] = 121464; else c[j >> 2] = 121512;
	                ce(7, c[f >> 2] | 0, c[g >> 2] | 0, c[j >> 2] | 0, c[h >> 2] | 0);
	                i = e;
	                return
	            }

	            function Dp(b, e, f, g) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h + 32 | 0;
	                k = h + 28 | 0;
	                l = h + 24 | 0;
	                m = h + 16 | 0;
	                n = h + 12 | 0;
	                o = h + 8 | 0;
	                p = h + 36 | 0;
	                q = h + 4 | 0;
	                r = h;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[l >> 2] = f;
	                c[h + 20 >> 2] = g;
	                if (!(c[l >> 2] | 0)) {
	                    i = h;
	                    return
	                }
	                Qk(c[j >> 2] | 0, 121184) | 0;
	                if ((c[(c[l >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                    Qk(c[j >> 2] | 0, c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0;
	                    Qk(c[j >> 2] | 0, 121224) | 0
	                }
	                Qk(c[j >> 2] | 0, c[(c[l >> 2] | 0) + 8 >> 2] | 0) | 0;
	                if (!(c[(c[l >> 2] | 0) + 12 >> 2] | 0)) {
	                    i = h;
	                    return
	                }
	                if (sp(c[(c[l >> 2] | 0) + 8 >> 2] | 0) | 0) {
	                    i = h;
	                    return
	                }
	                c[m >> 2] = _h(c[k >> 2] | 0, c[(c[l >> 2] | 0) + 12 >> 2] | 0, 0) | 0;
	                k = c[j >> 2] | 0;
	                if (!(c[m >> 2] | 0)) {
	                    Qk(k, 121400) | 0;
	                    i = h;
	                    return
	                }
	                Qk(k, 121328) | 0;
	                do if (((c[(c[l >> 2] | 0) + 36 >> 2] | 0) == 0 ? (c[(c[l >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) ? (c[(c[(c[l >> 2] | 0) + 20 >> 2] | 0) + 36 >> 2] | 0) == 0 : 0) {
	                    if (((ty(c[(c[l >> 2] | 0) + 8 >> 2] | 0, 121336) | 0) != 0 ? (ty(c[(c[l >> 2] | 0) + 8 >> 2] | 0, 121344) | 0) != 0 : 0) ? (ty(c[(c[l >> 2] | 0) + 8 >> 2] | 0, 121352) | 0) != 0 : 0) {
	                        if (ty(c[(c[l >> 2] | 0) + 8 >> 2] | 0, 121360) | 0) {
	                            s = 31;
	                            break
	                        }
	                        if (ty(c[(c[(c[l >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0, 121368) | 0) {
	                            s = 31;
	                            break
	                        }
	                    }
	                    c[n >> 2] = c[m >> 2];
	                    fz(c[(c[j >> 2] | 0) + 16 >> 2] | 0, 121376) | 0;
	                    a:while (1) {
	                        do if ((d[c[n >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[n >> 2] >> 0] | 0 | 0) ? (d[c[n >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[n >> 2] >> 0] | 0 | 0) != 13)break a
	                        } while (0);
	                        c[n >> 2] = (c[n >> 2] | 0) + 1
	                    }
	                    while (1) {
	                        c[q >> 2] = 0;
	                        c[r >> 2] = wy(c[n >> 2] | 0, 121160) | 0;
	                        if ((c[r >> 2] | 0) != 0 ? (c[q >> 2] = wy(c[n >> 2] | 0, 121168) | 0, (c[q >> 2] | 0) != 0) : 0)a[c[r >> 2] >> 0] = 0;
	                        c[o >> 2] = Fl(c[n >> 2] | 0, 121384) | 0;
	                        k = c[(c[j >> 2] | 0) + 16 >> 2] | 0;
	                        if (c[o >> 2] | 0) {
	                            ez(k, c[o >> 2] | 0) | 0;
	                            zb[c[135736 >> 2] & 511](c[o >> 2] | 0)
	                        } else ez(k, c[n >> 2] | 0) | 0;
	                        if (!(c[q >> 2] | 0))break;
	                        a[c[r >> 2] >> 0] = 60;
	                        c[q >> 2] = (c[q >> 2] | 0) + 3;
	                        a[p >> 0] = a[c[q >> 2] >> 0] | 0;
	                        a[c[q >> 2] >> 0] = 0;
	                        ez(c[(c[j >> 2] | 0) + 16 >> 2] | 0, c[r >> 2] | 0) | 0;
	                        a[c[q >> 2] >> 0] = a[p >> 0] | 0;
	                        c[n >> 2] = c[q >> 2]
	                    }
	                    fz(c[(c[j >> 2] | 0) + 16 >> 2] | 0, 121376) | 0
	                } else s = 31; while (0);
	                if ((s | 0) == 31)gz(c[(c[j >> 2] | 0) + 16 >> 2] | 0, c[m >> 2] | 0) | 0;
	                zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                i = h;
	                return
	            }

	            function Ep(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 12 | 0;
	                h = f + 8 | 0;
	                j = f + 4 | 0;
	                k = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                if (!((c[j >> 2] | 0) != 0 & (c[j >> 2] | 0) != 0)) {
	                    i = f;
	                    return
	                }
	                do {
	                    Dp(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0);
	                    c[j >> 2] = c[(c[j >> 2] | 0) + 24 >> 2]
	                } while ((c[j >> 2] | 0) != 0);
	                i = f;
	                return
	            }

	            function Fp(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 16 | 0;
	                j = g + 12 | 0;
	                k = g + 8 | 0;
	                l = g + 4 | 0;
	                m = g;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                if (!((c[k >> 2] | 0) != 0 & (c[k >> 2] | 0) != 0)) {
	                    i = g;
	                    return
	                }
	                do {
	                    up(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0);
	                    c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                } while ((c[k >> 2] | 0) != 0);
	                i = g;
	                return
	            }

	            function Gp(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[e + 4 >> 2] = d;
	                c[h >> 2] = c[(c[g >> 2] | 0) + 44 >> 2];
	                if (!(c[h >> 2] | 0)) {
	                    Cp(1402, c[g >> 2] | 0, 0);
	                    i = e;
	                    return
	                }
	                Qk(c[f >> 2] | 0, 121272) | 0;
	                Qk(c[f >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0) | 0;
	                if (c[(c[h >> 2] | 0) + 52 >> 2] | 0) {
	                    Qk(c[f >> 2] | 0, 121288) | 0;
	                    gz(c[(c[f >> 2] | 0) + 16 >> 2] | 0, c[(c[h >> 2] | 0) + 52 >> 2] | 0) | 0;
	                    if (c[(c[h >> 2] | 0) + 56 >> 2] | 0) {
	                        Qk(c[f >> 2] | 0, 121184) | 0;
	                        gz(c[(c[f >> 2] | 0) + 16 >> 2] | 0, c[(c[h >> 2] | 0) + 56 >> 2] | 0) | 0
	                    }
	                } else if (c[(c[h >> 2] | 0) + 56 >> 2] | 0) {
	                    Qk(c[f >> 2] | 0, 121304) | 0;
	                    gz(c[(c[f >> 2] | 0) + 16 >> 2] | 0, c[(c[h >> 2] | 0) + 56 >> 2] | 0) | 0
	                }
	                Qk(c[f >> 2] | 0, 121320) | 0;
	                i = e;
	                return
	            }

	            function Hp(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                if (!(c[g >> 2] | 0))c[g >> 2] = c[q >> 2];
	                if (!(c[h >> 2] | 0)) {
	                    Ka(c[g >> 2] | 0, 121688, f | 0) | 0;
	                    i = e;
	                    return
	                }
	                c[j >> 2] = 0;
	                while (1) {
	                    if ((c[j >> 2] | 0) >= 40)break;
	                    if (!(d[(c[h >> 2] | 0) + (c[j >> 2] | 0) >> 0] | 0)) {
	                        k = 18;
	                        break
	                    }
	                    do if ((d[(c[h >> 2] | 0) + (c[j >> 2] | 0) >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[(c[h >> 2] | 0) + (c[j >> 2] | 0) >> 0] | 0 | 0) ? (d[(c[h >> 2] | 0) + (c[j >> 2] | 0) >> 0] | 0 | 0) <= 10 : 0) {
	                            k = 12;
	                            break
	                        }
	                        if ((d[(c[h >> 2] | 0) + (c[j >> 2] | 0) >> 0] | 0 | 0) != 13)if ((d[(c[h >> 2] | 0) + (c[j >> 2] | 0) >> 0] | 0 | 0) >= 128) {
	                            b = c[g >> 2] | 0;
	                            c[f >> 2] = d[(c[h >> 2] | 0) + (c[j >> 2] | 0) >> 0];
	                            Ka(b | 0, 121696, f | 0) | 0;
	                            break
	                        } else {
	                            fb(d[(c[h >> 2] | 0) + (c[j >> 2] | 0) >> 0] | 0 | 0, c[g >> 2] | 0) | 0;
	                            break
	                        } else k = 12
	                    } else k = 12; while (0);
	                    if ((k | 0) == 12) {
	                        k = 0;
	                        fb(32, c[g >> 2] | 0) | 0
	                    }
	                    c[j >> 2] = (c[j >> 2] | 0) + 1
	                }
	                if ((k | 0) == 18) {
	                    i = e;
	                    return
	                }
	                Ka(c[g >> 2] | 0, 121704, f | 0) | 0;
	                i = e;
	                return
	            }

	            function Ip(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 160 | 0;
	                f = e + 148 | 0;
	                g = e + 144 | 0;
	                h = e + 140 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if (!(c[f >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                _p(j);
	                c[j >> 2] = c[f >> 2];
	                c[j + 108 >> 2] = c[h >> 2];
	                $p(j, c[g >> 2] | 0);
	                aq(j);
	                i = e;
	                return
	            }

	            function Jp(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 160 | 0;
	                e = d + 144 | 0;
	                f = d + 140 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                _p(g);
	                c[g >> 2] = c[e >> 2];
	                bq(g, c[f >> 2] | 0);
	                aq(g);
	                i = d;
	                return
	            }

	            function Kp(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 160 | 0;
	                f = e + 148 | 0;
	                g = e + 144 | 0;
	                h = e + 140 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if (!(c[f >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                _p(j);
	                c[j >> 2] = c[f >> 2];
	                c[j + 108 >> 2] = c[h >> 2];
	                dq(j, c[g >> 2] | 0);
	                aq(j);
	                i = e;
	                return
	            }

	            function Lp(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 160 | 0;
	                e = d + 144 | 0;
	                f = d + 140 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0))c[e >> 2] = c[q >> 2];
	                _p(g);
	                b = g + 136 | 0;
	                c[b >> 2] = c[b >> 2] | 1;
	                c[g >> 2] = c[e >> 2];
	                gq(g, c[f >> 2] | 0);
	                aq(g);
	                i = d;
	                return
	            }

	            function Mp(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 160 | 0;
	                e = d + 144 | 0;
	                f = d + 140 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0))c[e >> 2] = c[q >> 2];
	                _p(g);
	                b = g + 136 | 0;
	                c[b >> 2] = c[b >> 2] | 1;
	                c[g >> 2] = c[e >> 2];
	                hq(g, c[f >> 2] | 0);
	                aq(g);
	                i = d;
	                return
	            }

	            function Np(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                c[g >> 2] = 0;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                switch (c[(c[e >> 2] | 0) + 4 >> 2] | 0) {
	                    case 21:
	                    case 13:
	                    case 9:
	                    {
	                        c[g >> 2] = c[(c[e >> 2] | 0) + 12 >> 2];
	                        break
	                    }
	                    case 20:
	                    case 19:
	                    case 18:
	                    case 17:
	                    case 16:
	                    case 15:
	                    case 14:
	                    case 12:
	                    case 11:
	                    case 6:
	                    case 10:
	                    case 5:
	                    {
	                        c[f >> 2] = 1;
	                        break
	                    }
	                    case 1:
	                    {
	                        c[g >> 2] = c[(c[e >> 2] | 0) + 12 >> 2];
	                        break
	                    }
	                    case 2:
	                    {
	                        c[g >> 2] = c[(c[e >> 2] | 0) + 12 >> 2];
	                        break
	                    }
	                    case 8:
	                    case 7:
	                    case 4:
	                    case 3:
	                    {
	                        if (c[(c[e >> 2] | 0) + 40 >> 2] | 0)c[f >> 2] = xy(c[(c[e >> 2] | 0) + 40 >> 2] | 0) | 0;
	                        break
	                    }
	                    default:
	                    {
	                    }
	                }
	                while (1) {
	                    if (!(c[g >> 2] | 0))break;
	                    c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                    c[f >> 2] = (c[f >> 2] | 0) + 1
	                }
	                c[d >> 2] = c[f >> 2];
	                h = c[d >> 2] | 0;
	                i = b;
	                return h | 0
	            }

	            function Op(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if (!(c[g >> 2] | 0)) {
	                    Ka(c[f >> 2] | 0, 121712, e | 0) | 0;
	                    i = d;
	                    return
	                }
	                do switch (c[(c[g >> 2] | 0) + 4 >> 2] | 0) {
	                    case 4:
	                    {
	                        Ka(c[f >> 2] | 0, 121744, e | 0) | 0;
	                        break
	                    }
	                    case 8:
	                    {
	                        Ka(c[f >> 2] | 0, 121776, e | 0) | 0;
	                        break
	                    }
	                    case 12:
	                    {
	                        Ka(c[f >> 2] | 0, 121816, e | 0) | 0;
	                        break
	                    }
	                    case 10:
	                    {
	                        Ka(c[f >> 2] | 0, 121800, e | 0) | 0;
	                        break
	                    }
	                    case 3:
	                    {
	                        Ka(c[f >> 2] | 0, 121736, e | 0) | 0;
	                        break
	                    }
	                    case 13:
	                    {
	                        Ka(c[f >> 2] | 0, 121792, e | 0) | 0;
	                        break
	                    }
	                    case 11:
	                    {
	                        Ka(c[f >> 2] | 0, 121808, e | 0) | 0;
	                        break
	                    }
	                    case 18:
	                    {
	                        Ka(c[f >> 2] | 0, 121824, e | 0) | 0;
	                        break
	                    }
	                    case 6:
	                    {
	                        Ka(c[f >> 2] | 0, 121760, e | 0) | 0;
	                        break
	                    }
	                    case 2:
	                    {
	                        Ka(c[f >> 2] | 0, 121728, e | 0) | 0;
	                        break
	                    }
	                    case 7:
	                    {
	                        Ka(c[f >> 2] | 0, 121768, e | 0) | 0;
	                        break
	                    }
	                    case 1:
	                    {
	                        Ka(c[f >> 2] | 0, 121720, e | 0) | 0;
	                        break
	                    }
	                    case 5:
	                    {
	                        Ka(c[f >> 2] | 0, 121752, e | 0) | 0;
	                        break
	                    }
	                    case 9:
	                    {
	                        Ka(c[f >> 2] | 0, 121784, e | 0) | 0;
	                        break
	                    }
	                    default:
	                        Ka(c[f >> 2] | 0, 121832, e | 0) | 0
	                } while (0);
	                do if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 18) {
	                    b = c[f >> 2] | 0;
	                    if (c[(c[g >> 2] | 0) + 44 >> 2] | 0)Ka(b | 0, 121728, e | 0) | 0; else Ka(b | 0, 121720, e | 0) | 0;
	                    b = c[f >> 2] | 0;
	                    if (c[(c[g >> 2] | 0) + 48 >> 2] | 0) {
	                        Ka(b | 0, 121824, e | 0) | 0;
	                        break
	                    } else {
	                        Ka(b | 0, 121720, e | 0) | 0;
	                        break
	                    }
	                } while (0);
	                b = c[f >> 2] | 0;
	                c[e >> 2] = Np(c[g >> 2] | 0) | 0;
	                Ka(b | 0, 121840, e | 0) | 0;
	                a:do switch (c[(c[g >> 2] | 0) + 4 >> 2] | 0) {
	                    case 1:
	                    {
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            if ((c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                                b = c[f >> 2] | 0;
	                                c[e >> 2] = c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2];
	                                Ka(b | 0, 121848, e | 0) | 0
	                            }
	                            b = c[f >> 2] | 0;
	                            c[e >> 2] = c[(c[g >> 2] | 0) + 8 >> 2];
	                            Ka(b | 0, 121856, e | 0) | 0
	                        }
	                        break
	                    }
	                    case 6:
	                    {
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            b = c[f >> 2] | 0;
	                            c[e >> 2] = c[(c[g >> 2] | 0) + 8 >> 2];
	                            Ka(b | 0, 121856, e | 0) | 0
	                        }
	                        break
	                    }
	                    case 2:
	                    {
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            b = c[f >> 2] | 0;
	                            c[e >> 2] = c[(c[g >> 2] | 0) + 8 >> 2];
	                            Ka(b | 0, 121856, e | 0) | 0
	                        }
	                        break
	                    }
	                    case 5:
	                    {
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            b = c[f >> 2] | 0;
	                            c[e >> 2] = c[(c[g >> 2] | 0) + 8 >> 2];
	                            Ka(b | 0, 121856, e | 0) | 0
	                        }
	                        break
	                    }
	                    case 12:
	                    case 11:
	                    case 10:
	                    case 13:
	                    case 9:
	                    case 8:
	                    case 4:
	                        break;
	                    case 3:
	                    {
	                        if (c[(c[g >> 2] | 0) + 40 >> 2] | 0)Hp(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 40 >> 2] | 0);
	                        break
	                    }
	                    case 7:
	                    {
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            b = c[f >> 2] | 0;
	                            c[e >> 2] = c[(c[g >> 2] | 0) + 8 >> 2];
	                            Ka(b | 0, 121856, e | 0) | 0
	                        }
	                        break
	                    }
	                    case 18:
	                    {
	                        c[h >> 2] = c[g >> 2];
	                        b = c[f >> 2] | 0;
	                        a = c[h >> 2] | 0;
	                        if (!(c[(c[h >> 2] | 0) + 12 >> 2] | 0)) {
	                            c[e >> 2] = c[a + 8 >> 2];
	                            Ka(b | 0, 121864, e | 0) | 0;
	                            break a
	                        } else {
	                            j = c[(c[h >> 2] | 0) + 8 >> 2] | 0;
	                            c[e >> 2] = c[a + 12 >> 2];
	                            c[e + 4 >> 2] = j;
	                            Ka(b | 0, 121880, e | 0) | 0;
	                            break a
	                        }
	                        break
	                    }
	                    default:
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            b = c[f >> 2] | 0;
	                            c[e >> 2] = c[(c[g >> 2] | 0) + 8 >> 2];
	                            Ka(b | 0, 121856, e | 0) | 0
	                        }
	                } while (0);
	                Ka(c[f >> 2] | 0, 121896, e | 0) | 0;
	                i = d;
	                return
	            }

	            function Pp(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 24 | 0;
	                h = f + 20 | 0;
	                j = f + 12 | 0;
	                k = f + 4 | 0;
	                c[h >> 2] = a;
	                c[f + 16 >> 2] = b;
	                c[j >> 2] = d;
	                c[f + 8 >> 2] = e;
	                if (!(c[h >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    l = c[g >> 2] | 0;
	                    i = f;
	                    return l | 0
	                }
	                if (!(c[j >> 2] | 0)) {
	                    Ka(c[(c[h >> 2] | 0) + 20 >> 2] | 0, 121712, f | 0) | 0;
	                    c[g >> 2] = 0;
	                    l = c[g >> 2] | 0;
	                    i = f;
	                    return l | 0
	                }
	                do if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 9 ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 13 : 0) {
	                    if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) == 18) {
	                        Op(c[(c[h >> 2] | 0) + 20 >> 2] | 0, c[j >> 2] | 0);
	                        c[g >> 2] = 0;
	                        l = c[g >> 2] | 0;
	                        i = f;
	                        return l | 0
	                    }
	                    if (c[(c[j >> 2] | 0) + 12 >> 2] | 0) {
	                        c[k >> 2] = c[(c[j >> 2] | 0) + 12 >> 2];
	                        break
	                    }
	                    Op(c[(c[h >> 2] | 0) + 20 >> 2] | 0, c[j >> 2] | 0);
	                    c[g >> 2] = 0;
	                    l = c[g >> 2] | 0;
	                    i = f;
	                    return l | 0
	                } else m = 7; while (0);
	                if ((m | 0) == 7)c[k >> 2] = c[(c[j >> 2] | 0) + 12 >> 2];
	                while (1) {
	                    if (!(c[k >> 2] | 0))break;
	                    Op(c[(c[h >> 2] | 0) + 20 >> 2] | 0, c[k >> 2] | 0);
	                    c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                }
	                c[g >> 2] = 0;
	                l = c[g >> 2] | 0;
	                i = f;
	                return l | 0
	            }

	            function Qp(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f;
	                h = f + 24 | 0;
	                j = f + 20 | 0;
	                k = f + 12 | 0;
	                l = f + 4 | 0;
	                c[j >> 2] = a;
	                c[f + 16 >> 2] = b;
	                c[k >> 2] = d;
	                c[f + 8 >> 2] = e;
	                if (!(c[j >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    m = c[h >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                if (!(c[k >> 2] | 0)) {
	                    Ka(c[(c[j >> 2] | 0) + 20 >> 2] | 0, 121712, g | 0) | 0;
	                    c[h >> 2] = 0;
	                    m = c[h >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                c[l >> 2] = Xi(c[(c[k >> 2] | 0) + 32 >> 2] | 0, c[k >> 2] | 0) | 0;
	                k = c[(c[j >> 2] | 0) + 20 >> 2] | 0;
	                if (!(c[l >> 2] | 0))Ka(k | 0, 122072, g | 0) | 0; else {
	                    c[g >> 2] = c[l >> 2];
	                    Ka(k | 0, 122096, g | 0) | 0;
	                    zb[c[135736 >> 2] & 511](c[l >> 2] | 0)
	                }
	                c[h >> 2] = 0;
	                m = c[h >> 2] | 0;
	                i = f;
	                return m | 0
	            }

	            function Rp(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 8 | 0;
	                c[h >> 2] = a;
	                c[f + 12 >> 2] = b;
	                c[j >> 2] = d;
	                c[f + 4 >> 2] = e;
	                if (!(c[h >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    k = c[g >> 2] | 0;
	                    i = f;
	                    return k | 0
	                }
	                if (!(c[j >> 2] | 0)) {
	                    Ka(c[(c[h >> 2] | 0) + 20 >> 2] | 0, 121712, f | 0) | 0;
	                    c[g >> 2] = 0;
	                    k = c[g >> 2] | 0;
	                    i = f;
	                    return k | 0
	                }
	                do if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 9 ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 13 : 0) {
	                    e = c[(c[h >> 2] | 0) + 20 >> 2] | 0;
	                    d = c[j >> 2] | 0;
	                    if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) == 2) {
	                        Ip(e, d, 0);
	                        break
	                    } else {
	                        Kp(e, d, 0);
	                        break
	                    }
	                } else l = 7; while (0);
	                if ((l | 0) == 7)Lp(c[(c[h >> 2] | 0) + 20 >> 2] | 0, c[j >> 2] | 0);
	                c[g >> 2] = 0;
	                k = c[g >> 2] | 0;
	                i = f;
	                return k | 0
	            }

	            function Sp(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f;
	                h = f + 20 | 0;
	                j = f + 16 | 0;
	                k = f + 8 | 0;
	                c[j >> 2] = a;
	                c[f + 12 >> 2] = b;
	                c[k >> 2] = d;
	                c[f + 4 >> 2] = e;
	                if (!(c[j >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    l = c[h >> 2] | 0;
	                    i = f;
	                    return l | 0
	                }
	                e = c[j >> 2] | 0;
	                if (!(c[k >> 2] | 0)) {
	                    Ka(c[e + 20 >> 2] | 0, 121712, g | 0) | 0;
	                    c[h >> 2] = 0;
	                    l = c[h >> 2] | 0;
	                    i = f;
	                    return l | 0
	                }
	                d = c[(c[k >> 2] | 0) + 4 >> 2] | 0;
	                do if ((c[(c[e + 4 >> 2] | 0) + 4 >> 2] | 0) == 13) {
	                    b = c[(c[j >> 2] | 0) + 20 >> 2] | 0;
	                    if ((d | 0) == 13) {
	                        zp(b, c[k >> 2] | 0) | 0;
	                        break
	                    } else {
	                        vp(b, c[(c[j >> 2] | 0) + 4 >> 2] | 0, c[k >> 2] | 0);
	                        break
	                    }
	                } else {
	                    b = c[(c[j >> 2] | 0) + 20 >> 2] | 0;
	                    if ((d | 0) == 9) {
	                        FR(b, c[k >> 2] | 0) | 0;
	                        break
	                    } else {
	                        zR(b, c[(c[j >> 2] | 0) + 4 >> 2] | 0, c[k >> 2] | 0);
	                        break
	                    }
	                } while (0);
	                Ka(c[(c[j >> 2] | 0) + 20 >> 2] | 0, 121896, g | 0) | 0;
	                c[h >> 2] = 0;
	                l = c[h >> 2] | 0;
	                i = f;
	                return l | 0
	            }

	            function Tp(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 24 | 0;
	                h = f + 20 | 0;
	                j = f + 16 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[f + 12 >> 2] = d;
	                c[f + 8 >> 2] = e;
	                c[l >> 2] = 0;
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    c[g >> 2] = -1;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                if (c[(c[h >> 2] | 0) + 4 >> 2] | 0)c[l >> 2] = (c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 4 >> 2] | 0) == 13 & 1;
	                e = c[j >> 2] | 0;
	                if (c[l >> 2] | 0)c[k >> 2] = so(e, 0) | 0; else c[k >> 2] = gg(e, 0, 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[g >> 2] = -1;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                if ((c[(c[h >> 2] | 0) + 16 >> 2] | 0) == 1)Th(c[(c[h >> 2] | 0) + 4 >> 2] | 0);
	                c[(c[h >> 2] | 0) + 16 >> 2] = 1;
	                Nr(c[(c[h >> 2] | 0) + 12 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[c[h >> 2] >> 2] | 0);
	                c[(c[h >> 2] | 0) + 4 >> 2] = c[k >> 2];
	                c[(c[h >> 2] | 0) + 8 >> 2] = c[k >> 2];
	                e = Lr(c[k >> 2] | 0) | 0;
	                c[(c[h >> 2] | 0) + 12 >> 2] = e;
	                e = Jl(c[j >> 2] | 0) | 0;
	                c[c[h >> 2] >> 2] = e;
	                c[g >> 2] = 0;
	                m = c[g >> 2] | 0;
	                i = f;
	                return m | 0
	            }

	            function Up(b, d, e, f) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g;
	                j = g + 24 | 0;
	                k = g + 20 | 0;
	                l = g + 16 | 0;
	                m = g + 12 | 0;
	                n = g + 4 | 0;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[g + 8 >> 2] = f;
	                if (!(c[m >> 2] | 0)) {
	                    c[j >> 2] = -1;
	                    o = c[j >> 2] | 0;
	                    i = g;
	                    return o | 0
	                }
	                if ((c[l >> 2] | 0) != 0 ? (a[c[l >> 2] >> 0] | 0) != 0 : 0) {
	                    f = c[(c[m >> 2] | 0) + 4 >> 2] | 0;
	                    do if ((f | 0) == 9) {
	                        if ((JR(c[l >> 2] | 0, c[(c[k >> 2] | 0) + 4 >> 2] | 0) | 0) < -1) {
	                            e = c[33976] | 0;
	                            d = c[33980] | 0;
	                            c[h >> 2] = c[l >> 2];
	                            Db[e & 511](d, 122104, h);
	                            c[j >> 2] = -1;
	                            o = c[j >> 2] | 0;
	                            i = g;
	                            return o | 0
	                        }
	                    } else if ((f | 0) == 13) {
	                        if ((Ap(c[l >> 2] | 0, c[(c[k >> 2] | 0) + 4 >> 2] | 0) | 0) < 0) {
	                            d = c[33976] | 0;
	                            e = c[33980] | 0;
	                            c[h >> 2] = c[l >> 2];
	                            Db[d & 511](e, 122104, h);
	                            c[j >> 2] = -1;
	                            o = c[j >> 2] | 0;
	                            i = g;
	                            return o | 0
	                        }
	                    } else {
	                        c[n >> 2] = pb(c[l >> 2] | 0, 122128) | 0;
	                        if (c[n >> 2] | 0) {
	                            zR(c[n >> 2] | 0, c[(c[k >> 2] | 0) + 4 >> 2] | 0, c[m >> 2] | 0);
	                            Xa(c[n >> 2] | 0) | 0;
	                            break
	                        }
	                        e = c[33976] | 0;
	                        d = c[33980] | 0;
	                        c[h >> 2] = c[l >> 2];
	                        Db[e & 511](d, 122104, h);
	                        c[j >> 2] = -1;
	                        o = c[j >> 2] | 0;
	                        i = g;
	                        return o | 0
	                    } while (0);
	                    c[j >> 2] = 0;
	                    o = c[j >> 2] | 0;
	                    i = g;
	                    return o | 0
	                }
	                c[j >> 2] = -1;
	                o = c[j >> 2] | 0;
	                i = g;
	                return o | 0
	            }

	            function Vp(b, d, e, f) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g;
	                j = g + 20 | 0;
	                k = g + 16 | 0;
	                l = g + 12 | 0;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[g + 8 >> 2] = e;
	                c[g + 4 >> 2] = f;
	                if ((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                    if (!((c[l >> 2] | 0) != 0 ? (a[c[l >> 2] >> 0] | 0) != 0 : 0))c[l >> 2] = c[c[k >> 2] >> 2];
	                    if (!(c[l >> 2] | 0)) {
	                        c[j >> 2] = -1;
	                        m = c[j >> 2] | 0;
	                        i = g;
	                        return m | 0
	                    }
	                    f = c[(c[(c[k >> 2] | 0) + 4 >> 2] | 0) + 4 >> 2] | 0;
	                    if ((f | 0) == 9) {
	                        if ((JR(c[l >> 2] | 0, c[(c[k >> 2] | 0) + 4 >> 2] | 0) | 0) < 0) {
	                            e = c[33976] | 0;
	                            d = c[33980] | 0;
	                            c[h >> 2] = c[l >> 2];
	                            Db[e & 511](d, 122136, h)
	                        }
	                    } else if ((f | 0) == 13) {
	                        if ((Ap(c[l >> 2] | 0, c[(c[k >> 2] | 0) + 4 >> 2] | 0) | 0) < 0) {
	                            k = c[33976] | 0;
	                            f = c[33980] | 0;
	                            c[h >> 2] = c[l >> 2];
	                            Db[k & 511](f, 122136, h)
	                        }
	                    } else {
	                        Db[c[135904 >> 2] & 511](c[33980] | 0, 122160, h);
	                        c[j >> 2] = -1;
	                        m = c[j >> 2] | 0;
	                        i = g;
	                        return m | 0
	                    }
	                    c[j >> 2] = 0;
	                    m = c[j >> 2] | 0;
	                    i = g;
	                    return m | 0
	                }
	                c[j >> 2] = -1;
	                m = c[j >> 2] | 0;
	                i = g;
	                return m | 0
	            }

	            function Wp(b, d, e, f) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, p = 0;
	                g = i;
	                i = i + 96 | 0;
	                h = g + 88 | 0;
	                j = g + 84 | 0;
	                k = g + 80 | 0;
	                l = g + 8 | 0;
	                m = g + 4 | 0;
	                n = g;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[g + 76 >> 2] = e;
	                c[g + 72 >> 2] = f;
	                c[m >> 2] = -1;
	                if ((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                    c[l >> 2] = c[o >> 2];
	                    c[l + 4 >> 2] = 203;
	                    c[l + 8 >> 2] = 203;
	                    if ((c[k >> 2] | 0) != 0 ? (a[c[k >> 2] >> 0] | 0) != 0 : 0) {
	                        c[n >> 2] = Wf(0, c[k >> 2] | 0) | 0;
	                        if (c[n >> 2] | 0) {
	                            c[m >> 2] = dn(l, c[(c[j >> 2] | 0) + 4 >> 2] | 0, c[n >> 2] | 0) | 0;
	                            Ph(c[n >> 2] | 0)
	                        }
	                    } else c[m >> 2] = fn(l, c[(c[j >> 2] | 0) + 4 >> 2] | 0) | 0;
	                    c[h >> 2] = c[m >> 2];
	                    p = c[h >> 2] | 0;
	                    i = g;
	                    return p | 0
	                }
	                c[h >> 2] = -1;
	                p = c[h >> 2] | 0;
	                i = g;
	                return p | 0
	            }

	            function Xp(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f;
	                h = f + 32 | 0;
	                j = f + 28 | 0;
	                k = f + 20 | 0;
	                l = f + 12 | 0;
	                m = f + 8 | 0;
	                n = f + 4 | 0;
	                c[j >> 2] = a;
	                c[f + 24 >> 2] = b;
	                c[k >> 2] = d;
	                c[f + 16 >> 2] = e;
	                c[m >> 2] = 0;
	                if (!(c[j >> 2] | 0)) {
	                    c[h >> 2] = -1;
	                    o = c[h >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                if (!(c[k >> 2] | 0)) {
	                    c[h >> 2] = -1;
	                    o = c[h >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                c[l >> 2] = c[k >> 2];
	                while (1) {
	                    if (!(c[l >> 2] | 0))break;
	                    if ((c[(c[l >> 2] | 0) + 4 >> 2] | 0) != 9 ? (c[(c[l >> 2] | 0) + 4 >> 2] | 0) != 13 : 0) {
	                        if ((c[(c[l >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                            c[n >> 2] = 0;
	                            while (1) {
	                                if ((c[n >> 2] | 0) >= (c[m >> 2] | 0))break;
	                                Ka(c[(c[j >> 2] | 0) + 20 >> 2] | 0, 122232, g | 0) | 0;
	                                c[n >> 2] = (c[n >> 2] | 0) + 1
	                            }
	                            if ((c[(c[l >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                                e = c[(c[j >> 2] | 0) + 20 >> 2] | 0;
	                                c[g >> 2] = c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2];
	                                Ka(e | 0, 121848, g | 0) | 0
	                            }
	                            e = c[(c[j >> 2] | 0) + 20 >> 2] | 0;
	                            c[g >> 2] = c[(c[l >> 2] | 0) + 8 >> 2];
	                            Ka(e | 0, 122096, g | 0) | 0
	                        }
	                    } else Ka(c[(c[j >> 2] | 0) + 20 >> 2] | 0, 122224, g | 0) | 0;
	                    if ((c[(c[l >> 2] | 0) + 4 >> 2] | 0) != 9 ? (c[(c[l >> 2] | 0) + 4 >> 2] | 0) != 13 : 0) {
	                        if ((c[(c[l >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 4 >> 2] | 0) != 5 : 0) {
	                            c[l >> 2] = c[(c[l >> 2] | 0) + 12 >> 2];
	                            c[m >> 2] = (c[m >> 2] | 0) + 1;
	                            continue
	                        }
	                        if ((c[l >> 2] | 0) != (c[k >> 2] | 0) ? (c[(c[l >> 2] | 0) + 24 >> 2] | 0) != 0 : 0) {
	                            c[l >> 2] = c[(c[l >> 2] | 0) + 24 >> 2];
	                            continue
	                        }
	                        if ((c[l >> 2] | 0) == (c[k >> 2] | 0)) {
	                            c[l >> 2] = 0;
	                            continue
	                        }
	                        while (1) {
	                            if ((c[l >> 2] | 0) == (c[k >> 2] | 0))break;
	                            if (c[(c[l >> 2] | 0) + 20 >> 2] | 0) {
	                                c[l >> 2] = c[(c[l >> 2] | 0) + 20 >> 2];
	                                c[m >> 2] = (c[m >> 2] | 0) + -1
	                            }
	                            if ((c[l >> 2] | 0) != (c[k >> 2] | 0) ? (c[(c[l >> 2] | 0) + 24 >> 2] | 0) != 0 : 0) {
	                                p = 33;
	                                break
	                            }
	                            if (!(c[(c[l >> 2] | 0) + 20 >> 2] | 0)) {
	                                p = 35;
	                                break
	                            }
	                            if ((c[l >> 2] | 0) == (c[k >> 2] | 0)) {
	                                p = 37;
	                                break
	                            }
	                        }
	                        if ((p | 0) == 33) {
	                            p = 0;
	                            c[l >> 2] = c[(c[l >> 2] | 0) + 24 >> 2]
	                        } else if ((p | 0) == 35) {
	                            p = 0;
	                            c[l >> 2] = 0
	                        } else if ((p | 0) == 37) {
	                            p = 0;
	                            c[l >> 2] = 0
	                        }
	                        if ((c[l >> 2] | 0) != (c[k >> 2] | 0))continue;
	                        c[l >> 2] = 0;
	                        continue
	                    }
	                    c[l >> 2] = c[(c[l >> 2] | 0) + 12 >> 2]
	                }
	                c[h >> 2] = 0;
	                o = c[h >> 2] | 0;
	                i = f;
	                return o | 0
	            }

	            function Yp(b, d, e, f) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g;
	                j = g + 24 | 0;
	                k = g + 16 | 0;
	                l = g + 12 | 0;
	                m = g + 4 | 0;
	                c[g + 20 >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[g + 8 >> 2] = f;
	                if ((c[l >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0) {
	                    c[j >> 2] = -1;
	                    n = c[j >> 2] | 0;
	                    i = g;
	                    return n | 0
	                }
	                c[m >> 2] = Oi(c[l >> 2] | 0) | 0;
	                if (!(c[m >> 2] | 0)) {
	                    c[j >> 2] = -1;
	                    n = c[j >> 2] | 0;
	                    i = g;
	                    return n | 0
	                } else {
	                    l = c[k >> 2] | 0;
	                    c[h >> 2] = c[m >> 2];
	                    JT(l, 499, 121856, h) | 0;
	                    a[(c[k >> 2] | 0) + 499 >> 0] = 48;
	                    zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                    c[j >> 2] = 0;
	                    n = c[j >> 2] | 0;
	                    i = g;
	                    return n | 0
	                }
	                return 0
	            }

	            function Zp(b, d, e, f) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0;
	                g = i;
	                i = i + 2080 | 0;
	                h = g;
	                j = g + 72 | 0;
	                k = g + 68 | 0;
	                l = g + 64 | 0;
	                m = g + 60 | 0;
	                n = g + 1580 | 0;
	                o = g + 56 | 0;
	                p = g + 52 | 0;
	                r = g + 1480 | 0;
	                s = g + 1080 | 0;
	                t = g + 48 | 0;
	                u = g + 44 | 0;
	                v = g + 40 | 0;
	                w = g + 36 | 0;
	                x = g + 576 | 0;
	                y = g + 32 | 0;
	                z = g + 28 | 0;
	                A = g + 24 | 0;
	                B = g + 20 | 0;
	                C = g + 76 | 0;
	                D = g + 16 | 0;
	                E = g + 12 | 0;
	                F = g + 8 | 0;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                cU(n | 0, 0, 500) | 0;
	                a[n >> 0] = 47;
	                a[n + 1 >> 0] = 32;
	                a[n + 2 >> 0] = 62;
	                a[n + 3 >> 0] = 32;
	                c[o >> 2] = 0;
	                if ((c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0) {
	                    i = g;
	                    return
	                }
	                if (!(c[m >> 2] | 0))c[m >> 2] = c[q >> 2];
	                c[u >> 2] = Cb[c[135744 >> 2] & 511](28) | 0;
	                if (!(c[u >> 2] | 0)) {
	                    i = g;
	                    return
	                }
	                c[(c[u >> 2] | 0) + 16 >> 2] = 0;
	                c[(c[u >> 2] | 0) + 4 >> 2] = c[j >> 2];
	                c[(c[u >> 2] | 0) + 24 >> 2] = c[l >> 2];
	                c[(c[u >> 2] | 0) + 20 >> 2] = c[m >> 2];
	                m = my(c[k >> 2] | 0) | 0;
	                c[c[u >> 2] >> 2] = m;
	                c[(c[u >> 2] | 0) + 8 >> 2] = c[(c[u >> 2] | 0) + 4 >> 2];
	                m = Lr(c[(c[u >> 2] | 0) + 4 >> 2] | 0) | 0;
	                c[(c[u >> 2] | 0) + 12 >> 2] = m;
	                if (!(c[(c[u >> 2] | 0) + 12 >> 2] | 0)) {
	                    zb[c[135736 >> 2] & 511](c[u >> 2] | 0);
	                    i = g;
	                    return
	                }
	                while (1) {
	                    do if ((c[(c[u >> 2] | 0) + 8 >> 2] | 0) == (c[(c[u >> 2] | 0) + 4 >> 2] | 0)) {
	                        c[h >> 2] = 122248;
	                        JT(n, 500, 122240, h) | 0
	                    } else {
	                        if ((((c[(c[u >> 2] | 0) + 8 >> 2] | 0) != 0 ? (c[(c[(c[u >> 2] | 0) + 8 >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (c[(c[(c[u >> 2] | 0) + 8 >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[(c[(c[u >> 2] | 0) + 8 >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                            m = c[(c[(c[u >> 2] | 0) + 8 >> 2] | 0) + 8 >> 2] | 0;
	                            c[h >> 2] = c[(c[(c[(c[u >> 2] | 0) + 8 >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2];
	                            c[h + 4 >> 2] = m;
	                            JT(n, 500, 122256, h) | 0;
	                            break
	                        }
	                        if ((c[(c[u >> 2] | 0) + 8 >> 2] | 0) != 0 ? (c[(c[(c[u >> 2] | 0) + 8 >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                            c[h >> 2] = c[(c[(c[u >> 2] | 0) + 8 >> 2] | 0) + 8 >> 2];
	                            JT(n, 500, 122240, h) | 0;
	                            break
	                        }
	                        JT(n, 500, 122272, h) | 0
	                    } while (0);
	                    a[n + 499 >> 0] = 0;
	                    c[o >> 2] = Cb[c[(c[u >> 2] | 0) + 24 >> 2] & 511](n) | 0;
	                    if (!(c[o >> 2] | 0))break;
	                    c[p >> 2] = c[o >> 2];
	                    while (1) {
	                        if ((a[c[p >> 2] >> 0] | 0) != 32 ? (a[c[p >> 2] >> 0] | 0) != 9 : 0)break;
	                        c[p >> 2] = (c[p >> 2] | 0) + 1
	                    }
	                    c[t >> 2] = 0;
	                    while (1) {
	                        if ((a[c[p >> 2] >> 0] | 0) == 32)break;
	                        if ((a[c[p >> 2] >> 0] | 0) == 9)break;
	                        if ((a[c[p >> 2] >> 0] | 0) == 10)break;
	                        if ((a[c[p >> 2] >> 0] | 0) == 13)break;
	                        if (!(a[c[p >> 2] >> 0] | 0))break;
	                        m = c[p >> 2] | 0;
	                        c[p >> 2] = m + 1;
	                        k = a[m >> 0] | 0;
	                        m = c[t >> 2] | 0;
	                        c[t >> 2] = m + 1;
	                        a[r + m >> 0] = k
	                    }
	                    a[r + (c[t >> 2] | 0) >> 0] = 0;
	                    if (!(c[t >> 2] | 0))continue;
	                    while (1) {
	                        if ((a[c[p >> 2] >> 0] | 0) != 32 ? (a[c[p >> 2] >> 0] | 0) != 9 : 0)break;
	                        c[p >> 2] = (c[p >> 2] | 0) + 1
	                    }
	                    c[t >> 2] = 0;
	                    while (1) {
	                        if ((a[c[p >> 2] >> 0] | 0) == 10)break;
	                        if ((a[c[p >> 2] >> 0] | 0) == 13)break;
	                        if (!(a[c[p >> 2] >> 0] | 0))break;
	                        if (!(a[c[p >> 2] >> 0] | 0))break;
	                        k = c[p >> 2] | 0;
	                        c[p >> 2] = k + 1;
	                        m = a[k >> 0] | 0;
	                        k = c[t >> 2] | 0;
	                        c[t >> 2] = k + 1;
	                        a[s + k >> 0] = m
	                    }
	                    a[s + (c[t >> 2] | 0) >> 0] = 0;
	                    if (!(PT(r, 122280) | 0))break;
	                    if (!(PT(r, 122288) | 0))break;
	                    if (!(PT(r, 122296) | 0))break;
	                    a:do if (PT(r, 122304) | 0) {
	                        if (!(PT(r, 123880) | 0)) {
	                            Wp(c[u >> 2] | 0, s, 0, 0) | 0;
	                            break
	                        }
	                        if (!(PT(r, 123896) | 0)) {
	                            Tp(c[u >> 2] | 0, s, 0, 0) | 0;
	                            break
	                        }
	                        if (!(PT(r, 123904) | 0)) {
	                            iq(c[u >> 2] | 0, s, 0, 0) | 0;
	                            break
	                        }
	                        if (!(PT(r, 123912) | 0)) {
	                            Vp(c[u >> 2] | 0, s, 0, 0) | 0;
	                            break
	                        }
	                        if (!(PT(r, 123920) | 0))if (!(a[s >> 0] | 0)) {
	                            Db[c[135904 >> 2] & 511](c[33980] | 0, 123928, h);
	                            break
	                        } else {
	                            Up(c[u >> 2] | 0, s, c[(c[u >> 2] | 0) + 8 >> 2] | 0, 0) | 0;
	                            break
	                        }
	                        if (!(PT(r, 123976) | 0)) {
	                            jq(c[u >> 2] | 0, s, c[(c[u >> 2] | 0) + 8 >> 2] | 0, 0) | 0;
	                            break
	                        }
	                        if (!(PT(r, 123984) | 0))if (!(a[s >> 0] | 0)) {
	                            ul(c[(c[u >> 2] | 0) + 20 >> 2] | 0, 0);
	                            break
	                        } else {
	                            c[w >> 2] = 0;
	                            c[h >> 2] = w;
	                            bT(s, 123992, h) | 0;
	                            ul(c[(c[u >> 2] | 0) + 20 >> 2] | 0, c[w >> 2] | 0);
	                            break
	                        }
	                        if (!(PT(r, 124e3) | 0)) {
	                            if (Yp(c[u >> 2] | 0, x, c[(c[u >> 2] | 0) + 8 >> 2] | 0, 0) | 0)break;
	                            m = c[(c[u >> 2] | 0) + 20 >> 2] | 0;
	                            c[h >> 2] = x;
	                            Ka(m | 0, 122096, h | 0) | 0;
	                            break
	                        }
	                        if (!(PT(r, 124008) | 0)) {
	                            m = c[u >> 2] | 0;
	                            if (!(a[s >> 0] | 0)) {
	                                Xp(m, 0, c[(c[u >> 2] | 0) + 8 >> 2] | 0, 0) | 0;
	                                break
	                            }
	                            c[(c[(c[u >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[m + 8 >> 2];
	                            c[(c[(c[u >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[(c[u >> 2] | 0) + 8 >> 2];
	                            c[v >> 2] = Rs(s, c[(c[u >> 2] | 0) + 12 >> 2] | 0) | 0;
	                            if (c[v >> 2] | 0) {
	                                b:do switch (c[c[v >> 2] >> 2] | 0) {
	                                    case 8:
	                                    {
	                                        m = c[33976] | 0;
	                                        k = c[33980] | 0;
	                                        c[h >> 2] = s;
	                                        Db[m & 511](k, 122016, h);
	                                        break
	                                    }
	                                    case 9:
	                                    {
	                                        k = c[33976] | 0;
	                                        m = c[33980] | 0;
	                                        c[h >> 2] = s;
	                                        Db[k & 511](m, 122040, h);
	                                        break
	                                    }
	                                    case 3:
	                                    {
	                                        m = c[33976] | 0;
	                                        k = c[33980] | 0;
	                                        c[h >> 2] = s;
	                                        Db[m & 511](k, 121952, h);
	                                        break
	                                    }
	                                    case 4:
	                                    {
	                                        k = c[33976] | 0;
	                                        m = c[33980] | 0;
	                                        c[h >> 2] = s;
	                                        Db[k & 511](m, 121968, h);
	                                        break
	                                    }
	                                    case 7:
	                                    {
	                                        m = c[33976] | 0;
	                                        k = c[33980] | 0;
	                                        c[h >> 2] = s;
	                                        Db[m & 511](k, 122e3, h);
	                                        break
	                                    }
	                                    case 0:
	                                    {
	                                        k = c[33976] | 0;
	                                        m = c[33980] | 0;
	                                        c[h >> 2] = s;
	                                        Db[k & 511](m, 121904, h);
	                                        break
	                                    }
	                                    case 1:
	                                    {
	                                        if (!(c[(c[v >> 2] | 0) + 4 >> 2] | 0))break b;
	                                        c[y >> 2] = 0;
	                                        while (1) {
	                                            if ((c[y >> 2] | 0) >= (c[c[(c[v >> 2] | 0) + 4 >> 2] >> 2] | 0))break b;
	                                            Xp(c[u >> 2] | 0, 0, c[(c[(c[(c[v >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) + (c[y >> 2] << 2) >> 2] | 0, 0) | 0;
	                                            c[y >> 2] = (c[y >> 2] | 0) + 1
	                                        }
	                                        break
	                                    }
	                                    case 2:
	                                    {
	                                        m = c[33976] | 0;
	                                        k = c[33980] | 0;
	                                        c[h >> 2] = s;
	                                        Db[m & 511](k, 121928, h);
	                                        break
	                                    }
	                                    case 5:
	                                    {
	                                        k = c[33976] | 0;
	                                        m = c[33980] | 0;
	                                        c[h >> 2] = s;
	                                        Db[k & 511](m, 121984, h);
	                                        break
	                                    }
	                                    case 6:
	                                    {
	                                        m = c[33976] | 0;
	                                        k = c[33980] | 0;
	                                        c[h >> 2] = s;
	                                        Db[m & 511](k, 122e3, h);
	                                        break
	                                    }
	                                    default:
	                                    {
	                                    }
	                                } while (0);
	                                Qq(c[v >> 2] | 0)
	                            } else {
	                                k = c[33976] | 0;
	                                m = c[33980] | 0;
	                                c[h >> 2] = s;
	                                Db[k & 511](m, 121904, h)
	                            }
	                            c[(c[(c[u >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 0;
	                            break
	                        }
	                        if (!(PT(r, 124016) | 0)) {
	                            Qp(c[u >> 2] | 0, 0, c[(c[u >> 2] | 0) + 8 >> 2] | 0, 0) | 0;
	                            break
	                        }
	                        if (!(PT(r, 124024) | 0)) {
	                            kq(c[u >> 2] | 0, s, c[(c[u >> 2] | 0) + 8 >> 2] | 0, 0) | 0;
	                            break
	                        }
	                        if (!(PT(r, 124032) | 0))if (!(a[s >> 0] | 0)) {
	                            Db[c[135904 >> 2] & 511](c[33980] | 0, 124040, h);
	                            break
	                        } else {
	                            lq(c[u >> 2] | 0, s, 0, 0) | 0;
	                            break
	                        }
	                        if (!(PT(r, 124072) | 0)) {
	                            c[z >> 2] = Pi(c[(c[u >> 2] | 0) + 4 >> 2] | 0) | 0;
	                            mq(c[u >> 2] | 0, 0, c[z >> 2] | 0, 0) | 0;
	                            break
	                        }
	                        if (!(PT(r, 124088) | 0))if (!(a[s >> 0] | 0)) {
	                            Db[c[135904 >> 2] & 511](c[33980] | 0, 124096, h);
	                            break
	                        } else {
	                            c[(c[(c[u >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[(c[u >> 2] | 0) + 8 >> 2];
	                            c[v >> 2] = Rs(s, c[(c[u >> 2] | 0) + 12 >> 2] | 0) | 0;
	                            Rq(c[(c[u >> 2] | 0) + 20 >> 2] | 0, c[v >> 2] | 0, 0);
	                            Qq(c[v >> 2] | 0);
	                            break
	                        }
	                        if (!(PT(r, 124128) | 0)) {
	                            nq(c[u >> 2] | 0, s, c[(c[u >> 2] | 0) + 8 >> 2] | 0, 0) | 0;
	                            break
	                        }
	                        do if (PT(r, 124136) | 0) {
	                            if (!(PT(r, 124144) | 0))break;
	                            if (!(PT(r, 124152) | 0)) {
	                                m = c[u >> 2] | 0;
	                                if (!(a[s >> 0] | 0)) {
	                                    if (Yp(m, C, c[(c[u >> 2] | 0) + 8 >> 2] | 0, 0) | 0)break a;
	                                    k = c[(c[u >> 2] | 0) + 20 >> 2] | 0;
	                                    c[h >> 2] = C;
	                                    Ka(k | 0, 122096, h | 0) | 0;
	                                    break a
	                                }
	                                c[(c[(c[u >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[m + 8 >> 2];
	                                c[v >> 2] = Rs(s, c[(c[u >> 2] | 0) + 12 >> 2] | 0) | 0;
	                                if (c[v >> 2] | 0) {
	                                    c:do switch (c[c[v >> 2] >> 2] | 0) {
	                                        case 4:
	                                        {
	                                            m = c[33976] | 0;
	                                            k = c[33980] | 0;
	                                            c[h >> 2] = s;
	                                            Db[m & 511](k, 121968, h);
	                                            break
	                                        }
	                                        case 5:
	                                        {
	                                            k = c[33976] | 0;
	                                            m = c[33980] | 0;
	                                            c[h >> 2] = s;
	                                            Db[k & 511](m, 121984, h);
	                                            break
	                                        }
	                                        case 6:
	                                        {
	                                            m = c[33976] | 0;
	                                            k = c[33980] | 0;
	                                            c[h >> 2] = s;
	                                            Db[m & 511](k, 122e3, h);
	                                            break
	                                        }
	                                        case 7:
	                                        {
	                                            k = c[33976] | 0;
	                                            m = c[33980] | 0;
	                                            c[h >> 2] = s;
	                                            Db[k & 511](m, 122e3, h);
	                                            break
	                                        }
	                                        case 8:
	                                        {
	                                            m = c[33976] | 0;
	                                            k = c[33980] | 0;
	                                            c[h >> 2] = s;
	                                            Db[m & 511](k, 122016, h);
	                                            break
	                                        }
	                                        case 9:
	                                        {
	                                            k = c[33976] | 0;
	                                            m = c[33980] | 0;
	                                            c[h >> 2] = s;
	                                            Db[k & 511](m, 122040, h);
	                                            break
	                                        }
	                                        case 2:
	                                        {
	                                            m = c[33976] | 0;
	                                            k = c[33980] | 0;
	                                            c[h >> 2] = s;
	                                            Db[m & 511](k, 121928, h);
	                                            break
	                                        }
	                                        case 3:
	                                        {
	                                            k = c[33976] | 0;
	                                            m = c[33980] | 0;
	                                            c[h >> 2] = s;
	                                            Db[k & 511](m, 121952, h);
	                                            break
	                                        }
	                                        case 0:
	                                        {
	                                            m = c[33976] | 0;
	                                            k = c[33980] | 0;
	                                            c[h >> 2] = s;
	                                            Db[m & 511](k, 121904, h);
	                                            break
	                                        }
	                                        case 1:
	                                        {
	                                            if (!(c[(c[v >> 2] | 0) + 4 >> 2] | 0))break c;
	                                            c[D >> 2] = 0;
	                                            while (1) {
	                                                if ((c[D >> 2] | 0) >= (c[c[(c[v >> 2] | 0) + 4 >> 2] >> 2] | 0))break c;
	                                                if (!(Yp(c[u >> 2] | 0, C, c[(c[(c[(c[v >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) + (c[D >> 2] << 2) >> 2] | 0, 0) | 0)) {
	                                                    k = c[(c[u >> 2] | 0) + 20 >> 2] | 0;
	                                                    c[h >> 2] = C;
	                                                    Ka(k | 0, 122096, h | 0) | 0
	                                                }
	                                                c[D >> 2] = (c[D >> 2] | 0) + 1
	                                            }
	                                            break
	                                        }
	                                        default:
	                                        {
	                                        }
	                                    } while (0);
	                                    Qq(c[v >> 2] | 0)
	                                } else {
	                                    k = c[33976] | 0;
	                                    m = c[33980] | 0;
	                                    c[h >> 2] = s;
	                                    Db[k & 511](m, 121904, h)
	                                }
	                                c[(c[(c[u >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 0;
	                                break a
	                            }
	                            if (PT(r, 124160) | 0) {
	                                if (PT(r, 124248) | 0) {
	                                    m = c[33976] | 0;
	                                    k = c[33980] | 0;
	                                    c[h >> 2] = r;
	                                    Db[m & 511](k, 124272, h);
	                                    break a
	                                }
	                                k = c[u >> 2] | 0;
	                                if (!(a[s >> 0] | 0)) {
	                                    Sp(k, 0, c[(c[u >> 2] | 0) + 8 >> 2] | 0, 0) | 0;
	                                    break a
	                                }
	                                c[(c[(c[u >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[k + 8 >> 2];
	                                c[(c[(c[u >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[(c[u >> 2] | 0) + 8 >> 2];
	                                c[v >> 2] = Rs(s, c[(c[u >> 2] | 0) + 12 >> 2] | 0) | 0;
	                                if (c[v >> 2] | 0) {
	                                    d:do switch (c[c[v >> 2] >> 2] | 0) {
	                                        case 2:
	                                        {
	                                            k = c[33976] | 0;
	                                            m = c[33980] | 0;
	                                            c[h >> 2] = s;
	                                            Db[k & 511](m, 121928, h);
	                                            break
	                                        }
	                                        case 3:
	                                        {
	                                            m = c[33976] | 0;
	                                            k = c[33980] | 0;
	                                            c[h >> 2] = s;
	                                            Db[m & 511](k, 121952, h);
	                                            break
	                                        }
	                                        case 4:
	                                        {
	                                            k = c[33976] | 0;
	                                            m = c[33980] | 0;
	                                            c[h >> 2] = s;
	                                            Db[k & 511](m, 121968, h);
	                                            break
	                                        }
	                                        case 5:
	                                        {
	                                            m = c[33976] | 0;
	                                            k = c[33980] | 0;
	                                            c[h >> 2] = s;
	                                            Db[m & 511](k, 121984, h);
	                                            break
	                                        }
	                                        case 6:
	                                        {
	                                            k = c[33976] | 0;
	                                            m = c[33980] | 0;
	                                            c[h >> 2] = s;
	                                            Db[k & 511](m, 122e3, h);
	                                            break
	                                        }
	                                        case 7:
	                                        {
	                                            m = c[33976] | 0;
	                                            k = c[33980] | 0;
	                                            c[h >> 2] = s;
	                                            Db[m & 511](k, 122e3, h);
	                                            break
	                                        }
	                                        case 8:
	                                        {
	                                            k = c[33976] | 0;
	                                            m = c[33980] | 0;
	                                            c[h >> 2] = s;
	                                            Db[k & 511](m, 122016, h);
	                                            break
	                                        }
	                                        case 9:
	                                        {
	                                            m = c[33976] | 0;
	                                            k = c[33980] | 0;
	                                            c[h >> 2] = s;
	                                            Db[m & 511](k, 122040, h);
	                                            break
	                                        }
	                                        case 0:
	                                        {
	                                            k = c[33976] | 0;
	                                            m = c[33980] | 0;
	                                            c[h >> 2] = s;
	                                            Db[k & 511](m, 121904, h);
	                                            break
	                                        }
	                                        case 1:
	                                        {
	                                            if (!(c[(c[v >> 2] | 0) + 4 >> 2] | 0))break d;
	                                            c[F >> 2] = 0;
	                                            while (1) {
	                                                if ((c[F >> 2] | 0) >= (c[c[(c[v >> 2] | 0) + 4 >> 2] >> 2] | 0))break d;
	                                                if ((c[t >> 2] | 0) > 0)Ka(c[(c[u >> 2] | 0) + 20 >> 2] | 0, 124256, h | 0) | 0;
	                                                Sp(c[u >> 2] | 0, 0, c[(c[(c[(c[v >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) + (c[F >> 2] << 2) >> 2] | 0, 0) | 0;
	                                                c[F >> 2] = (c[F >> 2] | 0) + 1
	                                            }
	                                            break
	                                        }
	                                        default:
	                                        {
	                                        }
	                                    } while (0);
	                                    Qq(c[v >> 2] | 0)
	                                } else {
	                                    m = c[33976] | 0;
	                                    k = c[33980] | 0;
	                                    c[h >> 2] = s;
	                                    Db[m & 511](k, 121904, h)
	                                }
	                                c[(c[(c[u >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 0;
	                                break a
	                            }
	                            k = c[u >> 2] | 0;
	                            if (!(a[s >> 0] | 0)) {
	                                c[(c[u >> 2] | 0) + 8 >> 2] = c[k + 4 >> 2];
	                                break a
	                            }
	                            c[(c[(c[u >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[k + 8 >> 2];
	                            c[E >> 2] = ZT(s | 0) | 0;
	                            do if ((c[E >> 2] | 0) >= 2) {
	                                if ((a[s + ((c[E >> 2] | 0) - 1) >> 0] | 0) != 47)break;
	                                a[s + ((c[E >> 2] | 0) - 1) >> 0] = 0
	                            } while (0);
	                            c[v >> 2] = Rs(s, c[(c[u >> 2] | 0) + 12 >> 2] | 0) | 0;
	                            if (c[v >> 2] | 0) {
	                                e:do switch (c[c[v >> 2] >> 2] | 0) {
	                                    case 0:
	                                    {
	                                        k = c[33976] | 0;
	                                        m = c[33980] | 0;
	                                        c[h >> 2] = s;
	                                        Db[k & 511](m, 121904, h);
	                                        break
	                                    }
	                                    case 1:
	                                    {
	                                        if (!(c[(c[v >> 2] | 0) + 4 >> 2] | 0)) {
	                                            m = c[33976] | 0;
	                                            k = c[33980] | 0;
	                                            c[h >> 2] = s;
	                                            Db[m & 511](k, 124216, h);
	                                            break e
	                                        }
	                                        if ((c[c[(c[v >> 2] | 0) + 4 >> 2] >> 2] | 0) != 1) {
	                                            k = c[33976] | 0;
	                                            m = c[33980] | 0;
	                                            l = c[c[(c[v >> 2] | 0) + 4 >> 2] >> 2] | 0;
	                                            c[h >> 2] = s;
	                                            c[h + 4 >> 2] = l;
	                                            Db[k & 511](m, 124192, h);
	                                            break e
	                                        }
	                                        c[(c[u >> 2] | 0) + 8 >> 2] = c[c[(c[(c[v >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] >> 2];
	                                        if (!(c[(c[u >> 2] | 0) + 8 >> 2] | 0))break e;
	                                        if ((c[(c[(c[u >> 2] | 0) + 8 >> 2] | 0) + 4 >> 2] | 0) != 18)break e;
	                                        Db[c[135904 >> 2] & 511](c[33980] | 0, 124168, h);
	                                        c[(c[u >> 2] | 0) + 8 >> 2] = 0;
	                                        break
	                                    }
	                                    case 2:
	                                    {
	                                        m = c[33976] | 0;
	                                        k = c[33980] | 0;
	                                        c[h >> 2] = s;
	                                        Db[m & 511](k, 121928, h);
	                                        break
	                                    }
	                                    case 3:
	                                    {
	                                        k = c[33976] | 0;
	                                        m = c[33980] | 0;
	                                        c[h >> 2] = s;
	                                        Db[k & 511](m, 121952, h);
	                                        break
	                                    }
	                                    case 4:
	                                    {
	                                        m = c[33976] | 0;
	                                        k = c[33980] | 0;
	                                        c[h >> 2] = s;
	                                        Db[m & 511](k, 121968, h);
	                                        break
	                                    }
	                                    case 5:
	                                    {
	                                        k = c[33976] | 0;
	                                        m = c[33980] | 0;
	                                        c[h >> 2] = s;
	                                        Db[k & 511](m, 121984, h);
	                                        break
	                                    }
	                                    case 6:
	                                    {
	                                        m = c[33976] | 0;
	                                        k = c[33980] | 0;
	                                        c[h >> 2] = s;
	                                        Db[m & 511](k, 122e3, h);
	                                        break
	                                    }
	                                    case 7:
	                                    {
	                                        k = c[33976] | 0;
	                                        m = c[33980] | 0;
	                                        c[h >> 2] = s;
	                                        Db[k & 511](m, 122e3, h);
	                                        break
	                                    }
	                                    case 8:
	                                    {
	                                        m = c[33976] | 0;
	                                        k = c[33980] | 0;
	                                        c[h >> 2] = s;
	                                        Db[m & 511](k, 122016, h);
	                                        break
	                                    }
	                                    case 9:
	                                    {
	                                        k = c[33976] | 0;
	                                        m = c[33980] | 0;
	                                        c[h >> 2] = s;
	                                        Db[k & 511](m, 122040, h);
	                                        break
	                                    }
	                                    default:
	                                    {
	                                    }
	                                } while (0);
	                                Qq(c[v >> 2] | 0)
	                            } else {
	                                m = c[33976] | 0;
	                                k = c[33980] | 0;
	                                c[h >> 2] = s;
	                                Db[m & 511](k, 121904, h)
	                            }
	                            c[(c[(c[u >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 0;
	                            break a
	                        } while (0);
	                        c[A >> 2] = ((PT(r, 124144) | 0) != 0 ^ 1) & 1;
	                        if (!(a[s >> 0] | 0)) {
	                            k = c[u >> 2] | 0;
	                            m = c[(c[u >> 2] | 0) + 8 >> 2] | 0;
	                            if (c[A >> 2] | 0) {
	                                Rp(k, 0, m, 0) | 0;
	                                break
	                            } else {
	                                Pp(k, 0, m, 0) | 0;
	                                break
	                            }
	                        }
	                        c[(c[(c[u >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[(c[u >> 2] | 0) + 8 >> 2];
	                        c[(c[(c[u >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[(c[u >> 2] | 0) + 8 >> 2];
	                        c[v >> 2] = Rs(s, c[(c[u >> 2] | 0) + 12 >> 2] | 0) | 0;
	                        if (c[v >> 2] | 0) {
	                            f:do switch (c[c[v >> 2] >> 2] | 0) {
	                                case 1:
	                                {
	                                    if (!(c[(c[v >> 2] | 0) + 4 >> 2] | 0))break f;
	                                    c[B >> 2] = 0;
	                                    while (1) {
	                                        if ((c[B >> 2] | 0) >= (c[c[(c[v >> 2] | 0) + 4 >> 2] >> 2] | 0))break f;
	                                        m = c[u >> 2] | 0;
	                                        k = c[(c[(c[(c[v >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) + (c[B >> 2] << 2) >> 2] | 0;
	                                        if (c[A >> 2] | 0)Rp(m, 0, k, 0) | 0; else Pp(m, 0, k, 0) | 0;
	                                        c[B >> 2] = (c[B >> 2] | 0) + 1
	                                    }
	                                    break
	                                }
	                                case 7:
	                                {
	                                    k = c[33976] | 0;
	                                    m = c[33980] | 0;
	                                    c[h >> 2] = s;
	                                    Db[k & 511](m, 122e3, h);
	                                    break
	                                }
	                                case 8:
	                                {
	                                    m = c[33976] | 0;
	                                    k = c[33980] | 0;
	                                    c[h >> 2] = s;
	                                    Db[m & 511](k, 122016, h);
	                                    break
	                                }
	                                case 9:
	                                {
	                                    k = c[33976] | 0;
	                                    m = c[33980] | 0;
	                                    c[h >> 2] = s;
	                                    Db[k & 511](m, 122040, h);
	                                    break
	                                }
	                                case 0:
	                                {
	                                    m = c[33976] | 0;
	                                    k = c[33980] | 0;
	                                    c[h >> 2] = s;
	                                    Db[m & 511](k, 121904, h);
	                                    break
	                                }
	                                case 2:
	                                {
	                                    k = c[33976] | 0;
	                                    m = c[33980] | 0;
	                                    c[h >> 2] = s;
	                                    Db[k & 511](m, 121928, h);
	                                    break
	                                }
	                                case 3:
	                                {
	                                    m = c[33976] | 0;
	                                    k = c[33980] | 0;
	                                    c[h >> 2] = s;
	                                    Db[m & 511](k, 121952, h);
	                                    break
	                                }
	                                case 4:
	                                {
	                                    k = c[33976] | 0;
	                                    m = c[33980] | 0;
	                                    c[h >> 2] = s;
	                                    Db[k & 511](m, 121968, h);
	                                    break
	                                }
	                                case 5:
	                                {
	                                    m = c[33976] | 0;
	                                    k = c[33980] | 0;
	                                    c[h >> 2] = s;
	                                    Db[m & 511](k, 121984, h);
	                                    break
	                                }
	                                case 6:
	                                {
	                                    k = c[33976] | 0;
	                                    m = c[33980] | 0;
	                                    c[h >> 2] = s;
	                                    Db[k & 511](m, 122e3, h);
	                                    break
	                                }
	                                default:
	                                {
	                                }
	                            } while (0);
	                            Qq(c[v >> 2] | 0)
	                        } else {
	                            m = c[33976] | 0;
	                            k = c[33980] | 0;
	                            c[h >> 2] = s;
	                            Db[m & 511](k, 121904, h)
	                        }
	                        c[(c[(c[u >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 0
	                    } else {
	                        Ka(c[(c[u >> 2] | 0) + 20 >> 2] | 0, 122312, h | 0) | 0;
	                        Ka(c[(c[u >> 2] | 0) + 20 >> 2] | 0, 122360, h | 0) | 0;
	                        Ka(c[(c[u >> 2] | 0) + 20 >> 2] | 0, 122408, h | 0) | 0;
	                        Ka(c[(c[u >> 2] | 0) + 20 >> 2] | 0, 122440, h | 0) | 0;
	                        Ka(c[(c[u >> 2] | 0) + 20 >> 2] | 0, 122488, h | 0) | 0;
	                        Ka(c[(c[u >> 2] | 0) + 20 >> 2] | 0, 122544, h | 0) | 0;
	                        Ka(c[(c[u >> 2] | 0) + 20 >> 2] | 0, 122632, h | 0) | 0;
	                        Ka(c[(c[u >> 2] | 0) + 20 >> 2] | 0, 122712, h | 0) | 0;
	                        Ka(c[(c[u >> 2] | 0) + 20 >> 2] | 0, 122744, h | 0) | 0;
	                        Ka(c[(c[u >> 2] | 0) + 20 >> 2] | 0, 122784, h | 0) | 0;
	                        Ka(c[(c[u >> 2] | 0) + 20 >> 2] | 0, 122824, h | 0) | 0;
	                        Ka(c[(c[u >> 2] | 0) + 20 >> 2] | 0, 122872, h | 0) | 0;
	                        Ka(c[(c[u >> 2] | 0) + 20 >> 2] | 0, 122936, h | 0) | 0;
	                        Ka(c[(c[u >> 2] | 0) + 20 >> 2] | 0, 123024, h | 0) | 0;
	                        Ka(c[(c[u >> 2] | 0) + 20 >> 2] | 0, 123112, h | 0) | 0;
	                        Ka(c[(c[u >> 2] | 0) + 20 >> 2] | 0, 123192, h | 0) | 0;
	                        Ka(c[(c[u >> 2] | 0) + 20 >> 2] | 0, 123280, h | 0) | 0;
	                        Ka(c[(c[u >> 2] | 0) + 20 >> 2] | 0, 123344, h | 0) | 0;
	                        Ka(c[(c[u >> 2] | 0) + 20 >> 2] | 0, 123416, h | 0) | 0;
	                        Ka(c[(c[u >> 2] | 0) + 20 >> 2] | 0, 123472, h | 0) | 0;
	                        Ka(c[(c[u >> 2] | 0) + 20 >> 2] | 0, 123552, h | 0) | 0;
	                        Ka(c[(c[u >> 2] | 0) + 20 >> 2] | 0, 123584, h | 0) | 0;
	                        Ka(c[(c[u >> 2] | 0) + 20 >> 2] | 0, 123648, h | 0) | 0;
	                        Ka(c[(c[u >> 2] | 0) + 20 >> 2] | 0, 123704, h | 0) | 0;
	                        Ka(c[(c[u >> 2] | 0) + 20 >> 2] | 0, 123752, h | 0) | 0;
	                        Ka(c[(c[u >> 2] | 0) + 20 >> 2] | 0, 123824, h | 0) | 0
	                    } while (0);
	                    jT(c[o >> 2] | 0);
	                    c[o >> 2] = 0
	                }
	                Nr(c[(c[u >> 2] | 0) + 12 >> 2] | 0);
	                if (c[(c[u >> 2] | 0) + 16 >> 2] | 0)Th(c[(c[u >> 2] | 0) + 4 >> 2] | 0);
	                if (c[c[u >> 2] >> 2] | 0)zb[c[135736 >> 2] & 511](c[c[u >> 2] >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[u >> 2] | 0);
	                if (!(c[o >> 2] | 0)) {
	                    i = g;
	                    return
	                }
	                jT(c[o >> 2] | 0);
	                i = g;
	                return
	            }

	            function _p(b) {
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = b;
	                c[(c[e >> 2] | 0) + 108 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 124 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 128 >> 2] = 0;
	                c[c[e >> 2] >> 2] = c[q >> 2];
	                c[(c[e >> 2] | 0) + 112 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 116 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 120 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 132 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 136 >> 2] = 0;
	                c[f >> 2] = 0;
	                while (1) {
	                    if ((c[f >> 2] | 0) >= 100)break;
	                    a[(c[e >> 2] | 0) + 4 + (c[f >> 2] | 0) >> 0] = 32;
	                    c[f >> 2] = (c[f >> 2] | 0) + 1
	                }
	                a[(c[e >> 2] | 0) + 104 >> 0] = 0;
	                i = d;
	                return
	            }

	            function $p(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                oq(c[f >> 2] | 0);
	                b = (c[(c[f >> 2] | 0) + 124 >> 2] | 0) != 0;
	                if (!(c[g >> 2] | 0)) {
	                    if (b) {
	                        i = d;
	                        return
	                    }
	                    Ka(c[c[f >> 2] >> 2] | 0, 127816, e | 0) | 0;
	                    i = d;
	                    return
	                }
	                if (!b ? (Ka(c[c[f >> 2] >> 2] | 0, 127832, e | 0) | 0, pq(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0), Ka(c[c[f >> 2] >> 2] | 0, 121896, e | 0) | 0, (c[(c[g >> 2] | 0) + 12 >> 2] | 0) != 0) : 0) {
	                    e = (c[f >> 2] | 0) + 108 | 0;
	                    c[e >> 2] = (c[e >> 2] | 0) + 1;
	                    fq(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] | 0);
	                    e = (c[f >> 2] | 0) + 108 | 0;
	                    c[e >> 2] = (c[e >> 2] | 0) + -1
	                }
	                if (!(c[(c[g >> 2] | 0) + 8 >> 2] | 0))qq(c[f >> 2] | 0, 5015, 127848);
	                rq(c[f >> 2] | 0, c[g >> 2] | 0);
	                i = d;
	                return
	            }

	            function aq(a) {
	                a = a | 0;
	                var b = 0;
	                b = i;
	                i = i + 16 | 0;
	                c[b >> 2] = a;
	                i = b;
	                return
	            }

	            function bq(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                sq(c[f >> 2] | 0, c[g >> 2] | 0);
	                if ((c[(c[g >> 2] | 0) + 44 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 44 >> 2] | 0) + 48 >> 2] | 0) != 0 : 0) {
	                    c[h >> 2] = c[(c[(c[g >> 2] | 0) + 44 >> 2] | 0) + 48 >> 2];
	                    if (!(c[(c[f >> 2] | 0) + 124 >> 2] | 0))Ka(c[c[f >> 2] >> 2] | 0, 127472, e | 0) | 0;
	                    Wj(c[h >> 2] | 0, 259, c[f >> 2] | 0)
	                } else Ka(c[c[f >> 2] >> 2] | 0, 127504, e | 0) | 0;
	                if ((c[(c[g >> 2] | 0) + 48 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 48 >> 2] | 0) + 48 >> 2] | 0) != 0 : 0) {
	                    c[j >> 2] = c[(c[(c[g >> 2] | 0) + 48 >> 2] | 0) + 48 >> 2];
	                    if (!(c[(c[f >> 2] | 0) + 124 >> 2] | 0))Ka(c[c[f >> 2] >> 2] | 0, 127536, e | 0) | 0;
	                    Wj(c[j >> 2] | 0, 259, c[f >> 2] | 0);
	                    i = d;
	                    return
	                }
	                if (c[(c[f >> 2] | 0) + 124 >> 2] | 0) {
	                    i = d;
	                    return
	                }
	                Ka(c[c[f >> 2] >> 2] | 0, 127568, e | 0) | 0;
	                i = d;
	                return
	            }

	            function cq(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                while (1) {
	                    if (!(c[f >> 2] | 0))break;
	                    $p(c[e >> 2] | 0, c[f >> 2] | 0);
	                    c[f >> 2] = c[(c[f >> 2] | 0) + 24 >> 2]
	                }
	                i = d;
	                return
	            }

	            function dq(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    if (c[(c[f >> 2] | 0) + 124 >> 2] | 0) {
	                        i = d;
	                        return
	                    }
	                    oq(c[f >> 2] | 0);
	                    Ka(c[c[f >> 2] >> 2] | 0, 126040, e | 0) | 0;
	                    i = d;
	                    return
	                }
	                c[(c[f >> 2] | 0) + 116 >> 2] = c[g >> 2];
	                a:do switch (c[(c[g >> 2] | 0) + 4 >> 2] | 0) {
	                    case 1:
	                    {
	                        if (!(c[(c[f >> 2] | 0) + 124 >> 2] | 0)) {
	                            oq(c[f >> 2] | 0);
	                            Ka(c[c[f >> 2] >> 2] | 0, 126056, e | 0) | 0;
	                            if ((c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                                pq(c[f >> 2] | 0, c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0);
	                                Ka(c[c[f >> 2] >> 2] | 0, 126072, e | 0) | 0
	                            }
	                            pq(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0);
	                            Ka(c[c[f >> 2] >> 2] | 0, 121896, e | 0) | 0
	                        }
	                        break
	                    }
	                    case 4:
	                    {
	                        if (!(c[(c[f >> 2] | 0) + 124 >> 2] | 0)) {
	                            oq(c[f >> 2] | 0);
	                            Ka(c[c[f >> 2] >> 2] | 0, 126168, e | 0) | 0
	                        }
	                        break
	                    }
	                    case 15:
	                    {
	                        vq(c[f >> 2] | 0, c[g >> 2] | 0);
	                        i = d;
	                        return
	                    }
	                    case 13:
	                    case 9:
	                    {
	                        if (!(c[(c[f >> 2] | 0) + 124 >> 2] | 0))oq(c[f >> 2] | 0);
	                        Ka(c[c[f >> 2] >> 2] | 0, 126232, e | 0) | 0;
	                        rq(c[f >> 2] | 0, c[g >> 2] | 0);
	                        i = d;
	                        return
	                    }
	                    case 11:
	                    {
	                        if (!(c[(c[f >> 2] | 0) + 124 >> 2] | 0)) {
	                            oq(c[f >> 2] | 0);
	                            Ka(c[c[f >> 2] >> 2] | 0, 126280, e | 0) | 0
	                        }
	                        break
	                    }
	                    case 2:
	                    {
	                        if (!(c[(c[f >> 2] | 0) + 124 >> 2] | 0))oq(c[f >> 2] | 0);
	                        Ka(c[c[f >> 2] >> 2] | 0, 126080, e | 0) | 0;
	                        rq(c[f >> 2] | 0, c[g >> 2] | 0);
	                        i = d;
	                        return
	                    }
	                    case 16:
	                    {
	                        wq(c[f >> 2] | 0, c[g >> 2] | 0);
	                        i = d;
	                        return
	                    }
	                    case 5:
	                    {
	                        if (!(c[(c[f >> 2] | 0) + 124 >> 2] | 0)) {
	                            oq(c[f >> 2] | 0);
	                            b = c[c[f >> 2] >> 2] | 0;
	                            c[e >> 2] = c[(c[g >> 2] | 0) + 8 >> 2];
	                            Ka(b | 0, 126184, e | 0) | 0
	                        }
	                        break
	                    }
	                    case 17:
	                    {
	                        xq(c[f >> 2] | 0, c[g >> 2] | 0);
	                        i = d;
	                        return
	                    }
	                    case 8:
	                    {
	                        if (!(c[(c[f >> 2] | 0) + 124 >> 2] | 0)) {
	                            oq(c[f >> 2] | 0);
	                            Ka(c[c[f >> 2] >> 2] | 0, 126216, e | 0) | 0
	                        }
	                        break
	                    }
	                    case 7:
	                    {
	                        if (!(c[(c[f >> 2] | 0) + 124 >> 2] | 0)) {
	                            oq(c[f >> 2] | 0);
	                            b = c[c[f >> 2] >> 2] | 0;
	                            c[e >> 2] = c[(c[g >> 2] | 0) + 8 >> 2];
	                            Ka(b | 0, 126208, e | 0) | 0
	                        }
	                        break
	                    }
	                    case 12:
	                    {
	                        if (!(c[(c[f >> 2] | 0) + 124 >> 2] | 0)) {
	                            oq(c[f >> 2] | 0);
	                            Ka(c[c[f >> 2] >> 2] | 0, 126296, e | 0) | 0
	                        }
	                        break
	                    }
	                    case 14:
	                    {
	                        uq(c[f >> 2] | 0, c[g >> 2] | 0);
	                        i = d;
	                        return
	                    }
	                    case 19:
	                    {
	                        if (c[(c[f >> 2] | 0) + 124 >> 2] | 0) {
	                            i = d;
	                            return
	                        }
	                        oq(c[f >> 2] | 0);
	                        Ka(c[c[f >> 2] >> 2] | 0, 126312, e | 0) | 0;
	                        i = d;
	                        return
	                    }
	                    case 6:
	                    {
	                        if (!(c[(c[f >> 2] | 0) + 124 >> 2] | 0)) {
	                            oq(c[f >> 2] | 0);
	                            Ka(c[c[f >> 2] >> 2] | 0, 126200, e | 0) | 0
	                        }
	                        break
	                    }
	                    case 10:
	                    {
	                        if (!(c[(c[f >> 2] | 0) + 124 >> 2] | 0)) {
	                            oq(c[f >> 2] | 0);
	                            Ka(c[c[f >> 2] >> 2] | 0, 126264, e | 0) | 0
	                        }
	                        break
	                    }
	                    case 18:
	                    {
	                        yq(c[f >> 2] | 0, c[g >> 2] | 0);
	                        i = d;
	                        return
	                    }
	                    case 20:
	                    {
	                        if (c[(c[f >> 2] | 0) + 124 >> 2] | 0) {
	                            i = d;
	                            return
	                        }
	                        oq(c[f >> 2] | 0);
	                        Ka(c[c[f >> 2] >> 2] | 0, 126328, e | 0) | 0;
	                        i = d;
	                        return
	                    }
	                    case 3:
	                    {
	                        if (!(c[(c[f >> 2] | 0) + 124 >> 2] | 0)) {
	                            oq(c[f >> 2] | 0);
	                            b = c[c[f >> 2] >> 2] | 0;
	                            if ((c[(c[g >> 2] | 0) + 8 >> 2] | 0) == 75112)Ka(b | 0, 126112, e | 0) | 0; else Ka(b | 0, 126128, e | 0) | 0;
	                            if (!(c[(c[f >> 2] | 0) + 136 >> 2] & 1)) {
	                                Ka(c[c[f >> 2] >> 2] | 0, 121896, e | 0) | 0;
	                                break a
	                            }
	                            b = c[f >> 2] | 0;
	                            if ((c[(c[g >> 2] | 0) + 40 >> 2] | 0) == ((c[g >> 2] | 0) + 44 | 0)) {
	                                Ka(c[b >> 2] | 0, 126136, e | 0) | 0;
	                                break a
	                            }
	                            a = (CP(c[b + 120 >> 2] | 0, c[(c[g >> 2] | 0) + 40 >> 2] | 0) | 0) == 1;
	                            b = c[c[f >> 2] >> 2] | 0;
	                            if (a) {
	                                Ka(b | 0, 126152, e | 0) | 0;
	                                break a
	                            } else {
	                                Ka(b | 0, 121896, e | 0) | 0;
	                                break a
	                            }
	                        }
	                        break
	                    }
	                    default:
	                    {
	                        if (!(c[(c[f >> 2] | 0) + 124 >> 2] | 0))oq(c[f >> 2] | 0);
	                        zq(c[f >> 2] | 0, 5011, 126016, c[(c[g >> 2] | 0) + 4 >> 2] | 0);
	                        i = d;
	                        return
	                    }
	                } while (0);
	                if (!(c[(c[g >> 2] | 0) + 32 >> 2] | 0)) {
	                    if (!(c[(c[f >> 2] | 0) + 124 >> 2] | 0))oq(c[f >> 2] | 0);
	                    Ka(c[c[f >> 2] >> 2] | 0, 126344, e | 0) | 0
	                }
	                b = (c[f >> 2] | 0) + 108 | 0;
	                c[b >> 2] = (c[b >> 2] | 0) + 1;
	                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 ? (c[(c[g >> 2] | 0) + 48 >> 2] | 0) != 0 : 0)Aq(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 48 >> 2] | 0);
	                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 ? (c[(c[g >> 2] | 0) + 44 >> 2] | 0) != 0 : 0)cq(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 44 >> 2] | 0);
	                b = c[g >> 2] | 0;
	                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 5) {
	                    if (((c[b + 4 >> 2] | 0) != 1 ? (c[(c[g >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) ? (c[(c[f >> 2] | 0) + 124 >> 2] | 0) == 0 : 0) {
	                        oq(c[f >> 2] | 0);
	                        Ka(c[c[f >> 2] >> 2] | 0, 126368, e | 0) | 0;
	                        pq(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 40 >> 2] | 0);
	                        Ka(c[c[f >> 2] >> 2] | 0, 121896, e | 0) | 0
	                    }
	                } else {
	                    c[h >> 2] = ad(c[b + 32 >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0) | 0;
	                    if (c[h >> 2] | 0)Bq(c[f >> 2] | 0, c[h >> 2] | 0)
	                }
	                h = (c[f >> 2] | 0) + 108 | 0;
	                c[h >> 2] = (c[h >> 2] | 0) + -1;
	                rq(c[f >> 2] | 0, c[g >> 2] | 0);
	                i = d;
	                return
	            }

	            function eq(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                b = c[f >> 2] | 0;
	                if (!(c[g >> 2] | 0)) {
	                    if (c[b + 124 >> 2] | 0) {
	                        i = d;
	                        return
	                    }
	                    oq(c[f >> 2] | 0);
	                    Ka(c[c[f >> 2] >> 2] | 0, 126040, e | 0) | 0;
	                    i = d;
	                    return
	                }
	                dq(b, c[g >> 2] | 0);
	                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 18) {
	                    i = d;
	                    return
	                }
	                if (!(c[(c[g >> 2] | 0) + 12 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 5) {
	                    i = d;
	                    return
	                }
	                b = (c[f >> 2] | 0) + 108 | 0;
	                c[b >> 2] = (c[b >> 2] | 0) + 1;
	                fq(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] | 0);
	                g = (c[f >> 2] | 0) + 108 | 0;
	                c[g >> 2] = (c[g >> 2] | 0) + -1;
	                i = d;
	                return
	            }

	            function fq(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                while (1) {
	                    if (!(c[f >> 2] | 0))break;
	                    eq(c[e >> 2] | 0, c[f >> 2] | 0);
	                    c[f >> 2] = c[(c[f >> 2] | 0) + 24 >> 2]
	                }
	                i = d;
	                return
	            }

	            function gq(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                sq(c[f >> 2] | 0, c[g >> 2] | 0);
	                if (!(c[(c[f >> 2] | 0) + 124 >> 2] | 0)) {
	                    if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                        Ka(c[c[f >> 2] >> 2] | 0, 125424, e | 0) | 0;
	                        pq(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0);
	                        Ka(c[c[f >> 2] >> 2] | 0, 121896, e | 0) | 0
	                    }
	                    if (c[(c[g >> 2] | 0) + 56 >> 2] | 0) {
	                        Ka(c[c[f >> 2] >> 2] | 0, 125432, e | 0) | 0;
	                        pq(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 56 >> 2] | 0);
	                        Ka(c[c[f >> 2] >> 2] | 0, 121896, e | 0) | 0
	                    }
	                    if (c[(c[g >> 2] | 0) + 60 >> 2] | 0) {
	                        Ka(c[c[f >> 2] >> 2] | 0, 125448, e | 0) | 0;
	                        pq(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 60 >> 2] | 0);
	                        Ka(c[c[f >> 2] >> 2] | 0, 121896, e | 0) | 0
	                    }
	                    if (c[(c[g >> 2] | 0) + 72 >> 2] | 0) {
	                        Ka(c[c[f >> 2] >> 2] | 0, 125464, e | 0) | 0;
	                        pq(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 72 >> 2] | 0);
	                        Ka(c[c[f >> 2] >> 2] | 0, 121896, e | 0) | 0
	                    }
	                    if (c[(c[g >> 2] | 0) + 40 >> 2] | 0)Ka(c[c[f >> 2] >> 2] | 0, 125472, e | 0) | 0
	                }
	                if (!(c[(c[g >> 2] | 0) + 52 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                Aq(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 52 >> 2] | 0);
	                i = d;
	                return
	            }

	            function hq(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                b = c[f >> 2] | 0;
	                if (!(c[g >> 2] | 0)) {
	                    if (c[b + 124 >> 2] | 0) {
	                        i = d;
	                        return
	                    }
	                    Ka(c[c[f >> 2] >> 2] | 0, 125400, e | 0) | 0;
	                    i = d;
	                    return
	                }
	                gq(b, c[g >> 2] | 0);
	                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 9 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 13 : 0) {
	                    i = d;
	                    return
	                }
	                if (!(c[(c[g >> 2] | 0) + 12 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                b = (c[f >> 2] | 0) + 108 | 0;
	                c[b >> 2] = (c[b >> 2] | 0) + 1;
	                fq(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] | 0);
	                g = (c[f >> 2] | 0) + 108 | 0;
	                c[g >> 2] = (c[g >> 2] | 0) + -1;
	                i = d;
	                return
	            }

	            function iq(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, p = 0, q = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f;
	                h = f + 36 | 0;
	                j = f + 32 | 0;
	                k = f + 28 | 0;
	                l = f + 16 | 0;
	                m = f + 12 | 0;
	                n = f + 8 | 0;
	                p = f + 4 | 0;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[f + 24 >> 2] = d;
	                c[f + 20 >> 2] = e;
	                c[m >> 2] = YM(c[k >> 2] | 0) | 0;
	                $M(c[m >> 2] | 0, 203, 203, c[o >> 2] | 0);
	                c[l >> 2] = _M(c[m >> 2] | 0) | 0;
	                ZM(c[m >> 2] | 0);
	                if (!(c[l >> 2] | 0)) {
	                    m = c[33976] | 0;
	                    e = c[33980] | 0;
	                    c[g >> 2] = c[k >> 2];
	                    Db[m & 511](e, 124416, g);
	                    c[h >> 2] = -1;
	                    q = c[h >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                c[n >> 2] = eN(c[l >> 2] | 0) | 0;
	                gN(c[n >> 2] | 0, 203, 203, c[o >> 2] | 0);
	                c[p >> 2] = iN(c[n >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0) | 0;
	                do if (c[p >> 2] | 0) {
	                    e = c[o >> 2] | 0;
	                    m = c[c[j >> 2] >> 2] | 0;
	                    if ((c[p >> 2] | 0) > 0) {
	                        c[g >> 2] = m;
	                        Ka(e | 0, 124472, g | 0) | 0;
	                        break
	                    } else {
	                        c[g >> 2] = m;
	                        Ka(e | 0, 124496, g | 0) | 0;
	                        break
	                    }
	                } else {
	                    e = c[o >> 2] | 0;
	                    c[g >> 2] = c[c[j >> 2] >> 2];
	                    Ka(e | 0, 124456, g | 0) | 0
	                } while (0);
	                fN(c[n >> 2] | 0);
	                if (c[l >> 2] | 0)VM(c[l >> 2] | 0);
	                c[h >> 2] = 0;
	                q = c[h >> 2] | 0;
	                i = f;
	                return q | 0
	            }

	            function jq(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f;
	                h = f + 20 | 0;
	                j = f + 16 | 0;
	                k = f + 12 | 0;
	                l = f + 8 | 0;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[f + 4 >> 2] = e;
	                if (!(c[j >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    m = c[h >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                if (!(c[l >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    m = c[h >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                if (!(c[k >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    m = c[h >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                if (((vy(c[k >> 2] | 0, 63) | 0) == 0 ? (vy(c[k >> 2] | 0, 42) | 0) == 0 : 0) ? (vy(c[k >> 2] | 0, 46) | 0) == 0 : 0)vy(c[k >> 2] | 0, 91) | 0;
	                a:while (1) {
	                    if (!(c[l >> 2] | 0))break;
	                    e = c[l >> 2] | 0;
	                    if ((c[(c[l >> 2] | 0) + 4 >> 2] | 0) == 8) {
	                        if (wy(c[e + 40 >> 2] | 0, c[k >> 2] | 0) | 0) {
	                            d = c[(c[j >> 2] | 0) + 20 >> 2] | 0;
	                            c[g >> 2] = Oi(c[l >> 2] | 0) | 0;
	                            Ka(d | 0, 124408, g | 0) | 0;
	                            Pp(c[j >> 2] | 0, 0, c[l >> 2] | 0, 0) | 0
	                        }
	                    } else if ((c[e + 4 >> 2] | 0) == 3 ? (wy(c[(c[l >> 2] | 0) + 40 >> 2] | 0, c[k >> 2] | 0) | 0) != 0 : 0) {
	                        e = c[(c[j >> 2] | 0) + 20 >> 2] | 0;
	                        c[g >> 2] = Oi(c[(c[l >> 2] | 0) + 20 >> 2] | 0) | 0;
	                        Ka(e | 0, 124408, g | 0) | 0;
	                        Pp(c[j >> 2] | 0, 0, c[(c[l >> 2] | 0) + 20 >> 2] | 0, 0) | 0
	                    }
	                    if ((c[(c[l >> 2] | 0) + 4 >> 2] | 0) != 9 ? (c[(c[l >> 2] | 0) + 4 >> 2] | 0) != 13 : 0) {
	                        if ((c[(c[l >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 4 >> 2] | 0) != 5 : 0) {
	                            c[l >> 2] = c[(c[l >> 2] | 0) + 12 >> 2];
	                            continue
	                        }
	                        if (c[(c[l >> 2] | 0) + 24 >> 2] | 0) {
	                            c[l >> 2] = c[(c[l >> 2] | 0) + 24 >> 2];
	                            continue
	                        }
	                        while (1) {
	                            if (!(c[l >> 2] | 0))continue a;
	                            if (c[(c[l >> 2] | 0) + 20 >> 2] | 0)c[l >> 2] = c[(c[l >> 2] | 0) + 20 >> 2];
	                            n = c[l >> 2] | 0;
	                            if (c[(c[l >> 2] | 0) + 24 >> 2] | 0) {
	                                o = 30;
	                                break
	                            }
	                            if (!(c[n + 20 >> 2] | 0)) {
	                                o = 32;
	                                break
	                            }
	                        }
	                        if ((o | 0) == 30) {
	                            o = 0;
	                            c[l >> 2] = c[n + 24 >> 2];
	                            continue
	                        } else if ((o | 0) == 32) {
	                            o = 0;
	                            c[l >> 2] = 0;
	                            continue
	                        }
	                    }
	                    c[l >> 2] = c[(c[l >> 2] | 0) + 12 >> 2]
	                }
	                c[h >> 2] = 0;
	                m = c[h >> 2] | 0;
	                i = f;
	                return m | 0
	            }

	            function kq(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f;
	                h = f + 28 | 0;
	                j = f + 24 | 0;
	                k = f + 20 | 0;
	                l = f + 16 | 0;
	                m = f + 8 | 0;
	                n = f + 4 | 0;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[f + 12 >> 2] = e;
	                if (!(c[j >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    o = c[h >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                if (!(c[l >> 2] | 0)) {
	                    Ka(c[(c[j >> 2] | 0) + 20 >> 2] | 0, 121712, g | 0) | 0;
	                    c[h >> 2] = 0;
	                    o = c[h >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                if (!(c[k >> 2] | 0)) {
	                    Ka(c[(c[j >> 2] | 0) + 20 >> 2] | 0, 121712, g | 0) | 0;
	                    c[h >> 2] = 0;
	                    o = c[h >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                e = c[l >> 2] | 0;
	                d = c[k >> 2] | 0;
	                c[n >> 2] = Yf(e, d, ZT(c[k >> 2] | 0) | 0, 0, m) | 0;
	                if (!(c[n >> 2] | 0)) {
	                    if (c[(c[l >> 2] | 0) + 12 >> 2] | 0) {
	                        Uh(c[(c[l >> 2] | 0) + 12 >> 2] | 0);
	                        c[(c[l >> 2] | 0) + 12 >> 2] = 0;
	                        c[(c[l >> 2] | 0) + 16 >> 2] = 0
	                    }
	                    yi(c[l >> 2] | 0, c[m >> 2] | 0) | 0
	                } else Ka(c[(c[j >> 2] | 0) + 20 >> 2] | 0, 124376, g | 0) | 0;
	                c[h >> 2] = 0;
	                o = c[h >> 2] | 0;
	                i = f;
	                return o | 0
	            }

	            function lq(b, e, f, g) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h;
	                k = h + 40 | 0;
	                l = h + 36 | 0;
	                m = h + 32 | 0;
	                n = h + 20 | 0;
	                o = h + 16 | 0;
	                p = h + 12 | 0;
	                q = h + 8 | 0;
	                c[l >> 2] = b;
	                c[m >> 2] = e;
	                c[h + 28 >> 2] = f;
	                c[h + 24 >> 2] = g;
	                c[n >> 2] = my(c[m >> 2] | 0) | 0;
	                c[q >> 2] = c[n >> 2];
	                while (1) {
	                    if (!(c[q >> 2] | 0)) {
	                        r = 10;
	                        break
	                    }
	                    if (!(d[c[q >> 2] >> 0] | 0)) {
	                        r = 10;
	                        break
	                    }
	                    c[o >> 2] = c[q >> 2];
	                    c[q >> 2] = vy(c[q >> 2] | 0, 61) | 0;
	                    if (!(c[q >> 2] | 0)) {
	                        r = 5;
	                        break
	                    }
	                    m = c[q >> 2] | 0;
	                    c[q >> 2] = m + 1;
	                    a[m >> 0] = 0;
	                    c[p >> 2] = c[q >> 2];
	                    c[q >> 2] = vy(c[q >> 2] | 0, 32) | 0;
	                    if (c[q >> 2] | 0) {
	                        m = c[q >> 2] | 0;
	                        c[q >> 2] = m + 1;
	                        a[m >> 0] = 0
	                    }
	                    if (rr(c[(c[l >> 2] | 0) + 12 >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0) | 0) {
	                        r = 9;
	                        break
	                    }
	                }
	                if ((r | 0) == 5) {
	                    Ka(c[(c[l >> 2] | 0) + 20 >> 2] | 0, 124040, j | 0) | 0;
	                    zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                    c[k >> 2] = -1;
	                    s = c[k >> 2] | 0;
	                    i = h;
	                    return s | 0
	                } else if ((r | 0) == 9) {
	                    q = c[(c[l >> 2] | 0) + 20 >> 2] | 0;
	                    l = c[p >> 2] | 0;
	                    c[j >> 2] = c[o >> 2];
	                    c[j + 4 >> 2] = l;
	                    Ka(q | 0, 124312, j | 0) | 0;
	                    zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                    c[k >> 2] = -1;
	                    s = c[k >> 2] | 0;
	                    i = h;
	                    return s | 0
	                } else if ((r | 0) == 10) {
	                    zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                    c[k >> 2] = 0;
	                    s = c[k >> 2] | 0;
	                    i = h;
	                    return s | 0
	                }
	                return 0
	            }

	            function mq(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 8 | 0;
	                k = f;
	                c[h >> 2] = a;
	                c[f + 12 >> 2] = b;
	                c[j >> 2] = d;
	                c[f + 4 >> 2] = e;
	                if ((((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? !((c[h >> 2] | 0) == 0 ? 1 : (c[(c[j >> 2] | 0) + 48 >> 2] | 0) == 0) : 0) ? (c[(c[h >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                    c[k >> 2] = c[(c[j >> 2] | 0) + 48 >> 2];
	                    while (1) {
	                        if (!(c[k >> 2] | 0))break;
	                        j = c[(c[h >> 2] | 0) + 12 >> 2] | 0;
	                        e = c[k >> 2] | 0;
	                        if (!(c[(c[k >> 2] | 0) + 12 >> 2] | 0))rr(j, 124296, c[e + 8 >> 2] | 0) | 0; else rr(j, c[e + 12 >> 2] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        c[k >> 2] = c[c[k >> 2] >> 2]
	                    }
	                    c[g >> 2] = 0;
	                    l = c[g >> 2] | 0;
	                    i = f;
	                    return l | 0
	                }
	                c[g >> 2] = -1;
	                l = c[g >> 2] | 0;
	                i = f;
	                return l | 0
	            }

	            function nq(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 8 | 0;
	                h = f + 4 | 0;
	                c[f + 12 >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[f >> 2] = e;
	                Wi(c[h >> 2] | 0, c[g >> 2] | 0);
	                i = f;
	                return 0
	            }

	            function oq(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                e = b + 4 | 0;
	                c[e >> 2] = a;
	                if (c[(c[e >> 2] | 0) + 124 >> 2] | 0) {
	                    i = b;
	                    return
	                }
	                if (!(c[c[e >> 2] >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if ((c[(c[e >> 2] | 0) + 108 >> 2] | 0) <= 0) {
	                    i = b;
	                    return
	                }
	                a = c[c[e >> 2] >> 2] | 0;
	                f = c[e >> 2] | 0;
	                if ((c[(c[e >> 2] | 0) + 108 >> 2] | 0) < 50) {
	                    c[d >> 2] = (c[e >> 2] | 0) + 4 + (100 - (c[f + 108 >> 2] << 1));
	                    Ka(a | 0, 121856, d | 0) | 0;
	                    i = b;
	                    return
	                } else {
	                    c[d >> 2] = f + 4;
	                    Ka(a | 0, 121856, d | 0) | 0;
	                    i = b;
	                    return
	                }
	            }

	            function pq(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                if (c[(c[g >> 2] | 0) + 124 >> 2] | 0) {
	                    i = e;
	                    return
	                }
	                if (!(c[h >> 2] | 0)) {
	                    Ka(c[c[g >> 2] >> 2] | 0, 121688, f | 0) | 0;
	                    i = e;
	                    return
	                }
	                c[j >> 2] = 0;
	                while (1) {
	                    if ((c[j >> 2] | 0) >= 40)break;
	                    if (!(d[(c[h >> 2] | 0) + (c[j >> 2] | 0) >> 0] | 0)) {
	                        k = 17;
	                        break
	                    }
	                    do if ((d[(c[h >> 2] | 0) + (c[j >> 2] | 0) >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[(c[h >> 2] | 0) + (c[j >> 2] | 0) >> 0] | 0 | 0) ? (d[(c[h >> 2] | 0) + (c[j >> 2] | 0) >> 0] | 0 | 0) <= 10 : 0) {
	                            k = 11;
	                            break
	                        }
	                        if ((d[(c[h >> 2] | 0) + (c[j >> 2] | 0) >> 0] | 0 | 0) != 13)if ((d[(c[h >> 2] | 0) + (c[j >> 2] | 0) >> 0] | 0 | 0) >= 128) {
	                            b = c[c[g >> 2] >> 2] | 0;
	                            c[f >> 2] = d[(c[h >> 2] | 0) + (c[j >> 2] | 0) >> 0];
	                            Ka(b | 0, 121696, f | 0) | 0;
	                            break
	                        } else {
	                            fb(d[(c[h >> 2] | 0) + (c[j >> 2] | 0) >> 0] | 0 | 0, c[c[g >> 2] >> 2] | 0) | 0;
	                            break
	                        } else k = 11
	                    } else k = 11; while (0);
	                    if ((k | 0) == 11) {
	                        k = 0;
	                        fb(32, c[c[g >> 2] >> 2] | 0) | 0
	                    }
	                    c[j >> 2] = (c[j >> 2] | 0) + 1
	                }
	                if ((k | 0) == 17) {
	                    i = e;
	                    return
	                }
	                Ka(c[c[g >> 2] >> 2] | 0, 121704, f | 0) | 0;
	                i = e;
	                return
	            }

	            function qq(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                d = (c[g >> 2] | 0) + 128 | 0;
	                c[d >> 2] = (c[d >> 2] | 0) + 1;
	                d = c[(c[g >> 2] | 0) + 116 >> 2] | 0;
	                g = c[h >> 2] | 0;
	                c[f >> 2] = c[j >> 2];
	                Xd(0, 0, 0, 0, d, 24, g, 2, 0, 0, 0, 0, 0, 0, 0, 121856, f);
	                i = e;
	                return
	            }

	            function rq(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[g >> 2] = c[(c[f >> 2] | 0) + 32 >> 2];
	                if (!(c[(c[f >> 2] | 0) + 20 >> 2] | 0))qq(c[e >> 2] | 0, 5013, 124640);
	                if (c[(c[f >> 2] | 0) + 32 >> 2] | 0) {
	                    c[h >> 2] = c[(c[g >> 2] | 0) + 80 >> 2];
	                    if ((c[h >> 2] | 0) == 0 ? (c[(c[e >> 2] | 0) + 132 >> 2] | 0) == 0 : 0)c[(c[e >> 2] | 0) + 132 >> 2] = 1;
	                    if (!(c[(c[e >> 2] | 0) + 112 >> 2] | 0))c[(c[e >> 2] | 0) + 112 >> 2] = c[g >> 2];
	                    if (!(c[(c[e >> 2] | 0) + 120 >> 2] | 0))c[(c[e >> 2] | 0) + 120 >> 2] = c[h >> 2]
	                } else {
	                    qq(c[e >> 2] | 0, 5014, 124664);
	                    c[h >> 2] = 0
	                }
	                if (((c[(c[f >> 2] | 0) + 20 >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 32 >> 2] | 0) != (c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 32 >> 2] | 0) : 0) ? (qy(c[(c[f >> 2] | 0) + 8 >> 2] | 0, 124688) | 0) == 0 : 0)qq(c[e >> 2] | 0, 5017, 124704);
	                h = c[f >> 2] | 0;
	                do if (!(c[(c[f >> 2] | 0) + 28 >> 2] | 0)) {
	                    g = (c[(c[f >> 2] | 0) + 20 >> 2] | 0) != 0;
	                    if ((c[h + 4 >> 2] | 0) == 2) {
	                        if (!g)break;
	                        if ((c[f >> 2] | 0) == (c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 44 >> 2] | 0))break;
	                        qq(c[e >> 2] | 0, 5018, 124744);
	                        break
	                    } else {
	                        if (!g)break;
	                        if ((c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 12 >> 2] | 0) == (c[f >> 2] | 0))break;
	                        qq(c[e >> 2] | 0, 5018, 124792);
	                        break
	                    }
	                } else if ((c[(c[h + 28 >> 2] | 0) + 24 >> 2] | 0) != (c[f >> 2] | 0))qq(c[e >> 2] | 0, 5019, 124840); while (0);
	                h = c[f >> 2] | 0;
	                if (!(c[(c[f >> 2] | 0) + 24 >> 2] | 0)) {
	                    if ((((c[h + 20 >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 2 : 0) ? (c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 16 >> 2] | 0) != (c[f >> 2] | 0) : 0) ? (c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 4 >> 2] | 0) == 1 : 0)qq(c[e >> 2] | 0, 5020, 124880)
	                } else {
	                    if ((c[(c[h + 24 >> 2] | 0) + 28 >> 2] | 0) != (c[f >> 2] | 0))qq(c[e >> 2] | 0, 5021, 124928);
	                    if ((c[(c[(c[f >> 2] | 0) + 24 >> 2] | 0) + 20 >> 2] | 0) != (c[(c[f >> 2] | 0) + 20 >> 2] | 0))qq(c[e >> 2] | 0, 5029, 124928)
	                }
	                h = c[f >> 2] | 0;
	                if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                    c[j >> 2] = c[h + 48 >> 2];
	                    while (1) {
	                        if (!(c[j >> 2] | 0))break;
	                        Cq(c[e >> 2] | 0, c[f >> 2] | 0, c[j >> 2] | 0);
	                        c[j >> 2] = c[c[j >> 2] >> 2]
	                    }
	                    if (c[(c[f >> 2] | 0) + 36 >> 2] | 0)Cq(c[e >> 2] | 0, c[f >> 2] | 0, c[(c[f >> 2] | 0) + 36 >> 2] | 0)
	                } else if ((c[h + 4 >> 2] | 0) == 2 ? (c[(c[f >> 2] | 0) + 36 >> 2] | 0) != 0 : 0)Cq(c[e >> 2] | 0, c[f >> 2] | 0, c[(c[f >> 2] | 0) + 36 >> 2] | 0);
	                if ((((((((c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 2 : 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 15 : 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 16 : 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 14 : 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 13 : 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 9 : 0) ? (c[(c[f >> 2] | 0) + 40 >> 2] | 0) != 0 : 0)Dq(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 40 >> 2] | 0);
	                switch (c[(c[f >> 2] | 0) + 4 >> 2] | 0) {
	                    case 2:
	                    case 1:
	                    {
	                        Eq(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0);
	                        i = d;
	                        return
	                    }
	                    case 4:
	                    {
	                        if (!(c[(c[f >> 2] | 0) + 8 >> 2] | 0)) {
	                            i = d;
	                            return
	                        }
	                        Fq(c[e >> 2] | 0, 5037, 125048, c[(c[f >> 2] | 0) + 8 >> 2] | 0);
	                        i = d;
	                        return
	                    }
	                    case 3:
	                    {
	                        if ((c[(c[f >> 2] | 0) + 8 >> 2] | 0) == 75104) {
	                            i = d;
	                            return
	                        }
	                        if ((c[(c[f >> 2] | 0) + 8 >> 2] | 0) == 75112) {
	                            i = d;
	                            return
	                        }
	                        if ((c[(c[e >> 2] | 0) + 120 >> 2] | 0) != 0 ? (h = c[(c[f >> 2] | 0) + 8 >> 2] | 0, (h | 0) == (AP(c[(c[e >> 2] | 0) + 120 >> 2] | 0, 124968, 7) | 0)) : 0) {
	                            i = d;
	                            return
	                        }
	                        Fq(c[e >> 2] | 0, 5036, 124976, c[(c[f >> 2] | 0) + 8 >> 2] | 0);
	                        i = d;
	                        return
	                    }
	                    case 7:
	                    {
	                        Eq(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0);
	                        i = d;
	                        return
	                    }
	                    case 8:
	                    {
	                        if ((c[(c[f >> 2] | 0) + 8 >> 2] | 0) == 75128) {
	                            i = d;
	                            return
	                        }
	                        Fq(c[e >> 2] | 0, 5036, 125008, c[(c[f >> 2] | 0) + 8 >> 2] | 0);
	                        i = d;
	                        return
	                    }
	                    default:
	                    {
	                        i = d;
	                        return
	                    }
	                }
	            }

	            function sq(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                a:do if (!(c[g >> 2] | 0)) {
	                    if (!(c[(c[f >> 2] | 0) + 124 >> 2] | 0))Ka(c[c[f >> 2] >> 2] | 0, 125400, e | 0) | 0
	                } else {
	                    c[(c[f >> 2] | 0) + 116 >> 2] = c[g >> 2];
	                    do switch (c[(c[g >> 2] | 0) + 4 >> 2] | 0) {
	                        case 3:
	                        {
	                            qq(c[f >> 2] | 0, 5002, 125744);
	                            break a;
	                            break
	                        }
	                        case 5:
	                        {
	                            qq(c[f >> 2] | 0, 5004, 125792);
	                            break a;
	                            break
	                        }
	                        case 10:
	                        {
	                            qq(c[f >> 2] | 0, 5008, 125928);
	                            break a;
	                            break
	                        }
	                        case 12:
	                        {
	                            qq(c[f >> 2] | 0, 5010, 125984);
	                            break a;
	                            break
	                        }
	                        case 4:
	                        {
	                            qq(c[f >> 2] | 0, 5003, 125768);
	                            break a;
	                            break
	                        }
	                        case 13:
	                        {
	                            if (c[(c[f >> 2] | 0) + 124 >> 2] | 0)break a;
	                            Ka(c[c[f >> 2] >> 2] | 0, 125912, e | 0) | 0;
	                            break a;
	                            break
	                        }
	                        case 9:
	                        {
	                            if (c[(c[f >> 2] | 0) + 124 >> 2] | 0)break a;
	                            Ka(c[c[f >> 2] >> 2] | 0, 125896, e | 0) | 0;
	                            break a;
	                            break
	                        }
	                        case 7:
	                        {
	                            qq(c[f >> 2] | 0, 5006, 125848);
	                            break a;
	                            break
	                        }
	                        case 2:
	                        {
	                            qq(c[f >> 2] | 0, 5001, 125712);
	                            break a;
	                            break
	                        }
	                        case 8:
	                        {
	                            qq(c[f >> 2] | 0, 5007, 125872);
	                            break a;
	                            break
	                        }
	                        case 1:
	                        {
	                            qq(c[f >> 2] | 0, 5e3, 125688);
	                            break a;
	                            break
	                        }
	                        case 11:
	                        {
	                            qq(c[f >> 2] | 0, 5009, 125952);
	                            break a;
	                            break
	                        }
	                        case 6:
	                        {
	                            qq(c[f >> 2] | 0, 5005, 125824);
	                            break a;
	                            break
	                        }
	                        default:
	                        {
	                            zq(c[f >> 2] | 0, 5011, 126016, c[(c[g >> 2] | 0) + 4 >> 2] | 0);
	                            break a
	                        }
	                    } while (0)
	                } while (0);
	                i = d;
	                return
	            }

	            function tq(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                b = (c[(c[g >> 2] | 0) + 124 >> 2] | 0) != 0;
	                if (!(c[f >> 2] | 0)) {
	                    if (b) {
	                        i = d;
	                        return
	                    }
	                    Ka(c[c[g >> 2] >> 2] | 0, 127600, e | 0) | 0;
	                    i = d;
	                    return
	                }
	                if (b) {
	                    i = d;
	                    return
	                }
	                b = c[c[g >> 2] >> 2] | 0;
	                c[e >> 2] = c[(c[f >> 2] | 0) + 8 >> 2];
	                Ka(b | 0, 124408, e | 0) | 0;
	                switch (c[(c[f >> 2] | 0) + 48 >> 2] | 0) {
	                    case 2:
	                    {
	                        Ka(c[c[g >> 2] >> 2] | 0, 127640, e | 0) | 0;
	                        break
	                    }
	                    case 5:
	                    {
	                        Ka(c[c[g >> 2] >> 2] | 0, 127712, e | 0) | 0;
	                        break
	                    }
	                    case 1:
	                    {
	                        Ka(c[c[g >> 2] >> 2] | 0, 127616, e | 0) | 0;
	                        break
	                    }
	                    case 3:
	                    {
	                        Ka(c[c[g >> 2] >> 2] | 0, 127664, e | 0) | 0;
	                        break
	                    }
	                    case 4:
	                    {
	                        Ka(c[c[g >> 2] >> 2] | 0, 127688, e | 0) | 0;
	                        break
	                    }
	                    default:
	                        zq(c[g >> 2] | 0, 5012, 127736, c[(c[f >> 2] | 0) + 48 >> 2] | 0)
	                }
	                if (c[(c[f >> 2] | 0) + 52 >> 2] | 0) {
	                    b = c[c[g >> 2] >> 2] | 0;
	                    c[e >> 2] = c[(c[f >> 2] | 0) + 52 >> 2];
	                    Ka(b | 0, 127760, e | 0) | 0
	                }
	                if (c[(c[f >> 2] | 0) + 56 >> 2] | 0) {
	                    b = c[c[g >> 2] >> 2] | 0;
	                    c[e >> 2] = c[(c[f >> 2] | 0) + 56 >> 2];
	                    Ka(b | 0, 127768, e | 0) | 0
	                }
	                if (c[(c[f >> 2] | 0) + 36 >> 2] | 0) {
	                    b = c[c[g >> 2] >> 2] | 0;
	                    c[e >> 2] = c[(c[f >> 2] | 0) + 36 >> 2];
	                    Ka(b | 0, 127784, e | 0) | 0
	                }
	                if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[f >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) {
	                    b = c[c[g >> 2] >> 2] | 0;
	                    c[e >> 2] = c[(c[f >> 2] | 0) + 40 >> 2];
	                    Ka(b | 0, 127800, e | 0) | 0
	                }
	                Ka(c[c[g >> 2] >> 2] | 0, 121896, e | 0) | 0;
	                i = d;
	                return
	            }

	            function uq(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                oq(c[f >> 2] | 0);
	                if (!(c[g >> 2] | 0)) {
	                    if (c[(c[f >> 2] | 0) + 124 >> 2] | 0) {
	                        i = d;
	                        return
	                    }
	                    Ka(c[c[f >> 2] >> 2] | 0, 124544, e | 0) | 0;
	                    i = d;
	                    return
	                }
	                b = c[f >> 2] | 0;
	                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 14) {
	                    qq(b, 5022, 124568);
	                    i = d;
	                    return
	                }
	                if (!(c[b + 124 >> 2] | 0)) {
	                    b = c[c[f >> 2] >> 2] | 0;
	                    if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                        c[e >> 2] = c[(c[g >> 2] | 0) + 8 >> 2];
	                        Ka(b | 0, 124592, e | 0) | 0
	                    } else Ka(b | 0, 124600, e | 0) | 0;
	                    if (c[(c[g >> 2] | 0) + 52 >> 2] | 0) {
	                        b = c[c[f >> 2] >> 2] | 0;
	                        c[e >> 2] = c[(c[g >> 2] | 0) + 52 >> 2];
	                        Ka(b | 0, 124608, e | 0) | 0
	                    }
	                    if (c[(c[g >> 2] | 0) + 56 >> 2] | 0) {
	                        b = c[c[f >> 2] >> 2] | 0;
	                        c[e >> 2] = c[(c[g >> 2] | 0) + 56 >> 2];
	                        Ka(b | 0, 124624, e | 0) | 0
	                    }
	                    Ka(c[c[f >> 2] >> 2] | 0, 121896, e | 0) | 0
	                }
	                rq(c[f >> 2] | 0, c[g >> 2] | 0);
	                i = d;
	                return
	            }

	            function vq(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 5024 | 0;
	                f = e;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e + 12 | 0;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                oq(c[g >> 2] | 0);
	                if (!(c[h >> 2] | 0)) {
	                    if (c[(c[g >> 2] | 0) + 124 >> 2] | 0) {
	                        i = e;
	                        return
	                    }
	                    Ka(c[c[g >> 2] >> 2] | 0, 127304, f | 0) | 0;
	                    i = e;
	                    return
	                }
	                if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 15) {
	                    qq(c[g >> 2] | 0, 5025, 127336);
	                    i = e;
	                    return
	                }
	                d = c[g >> 2] | 0;
	                if (c[(c[h >> 2] | 0) + 8 >> 2] | 0) {
	                    if (!(c[d + 124 >> 2] | 0)) {
	                        Ka(c[c[g >> 2] >> 2] | 0, 127376, f | 0) | 0;
	                        pq(c[g >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0);
	                        Ka(c[c[g >> 2] >> 2] | 0, 126712, f | 0) | 0
	                    }
	                } else qq(d, 5015, 127392);
	                if (!(c[(c[g >> 2] | 0) + 124 >> 2] | 0)) {
	                    switch (c[(c[h >> 2] | 0) + 36 >> 2] | 0) {
	                        case 0:
	                        {
	                            Ka(c[c[g >> 2] >> 2] | 0, 127424, f | 0) | 0;
	                            break
	                        }
	                        case 2:
	                        {
	                            Ka(c[c[g >> 2] >> 2] | 0, 127448, f | 0) | 0;
	                            break
	                        }
	                        case 4:
	                        {
	                            Ka(c[c[g >> 2] >> 2] | 0, 127456, f | 0) | 0;
	                            break
	                        }
	                        case 1:
	                        {
	                            Ka(c[c[g >> 2] >> 2] | 0, 127440, f | 0) | 0;
	                            break
	                        }
	                        case 3:
	                        {
	                            Ka(c[c[g >> 2] >> 2] | 0, 127456, f | 0) | 0;
	                            break
	                        }
	                        default:
	                        {
	                        }
	                    }
	                    if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[h >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) {
	                        a[j >> 0] = 0;
	                        fm(j, 5e3, c[(c[h >> 2] | 0) + 40 >> 2] | 0, 1);
	                        a[j + 5e3 >> 0] = 0;
	                        d = c[c[g >> 2] >> 2] | 0;
	                        c[f >> 2] = j;
	                        Ka(d | 0, 121856, f | 0) | 0
	                    }
	                    Ka(c[c[g >> 2] >> 2] | 0, 121896, f | 0) | 0
	                }
	                rq(c[g >> 2] | 0, c[h >> 2] | 0);
	                i = e;
	                return
	            }

	            function wq(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                oq(c[f >> 2] | 0);
	                if (!(c[g >> 2] | 0)) {
	                    if (c[(c[f >> 2] | 0) + 124 >> 2] | 0) {
	                        i = d;
	                        return
	                    }
	                    Ka(c[c[f >> 2] >> 2] | 0, 126928, e | 0) | 0;
	                    i = d;
	                    return
	                }
	                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 16) {
	                    qq(c[f >> 2] | 0, 5024, 126960);
	                    i = d;
	                    return
	                }
	                b = c[f >> 2] | 0;
	                if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                    if (!(c[b + 124 >> 2] | 0)) {
	                        a = c[c[f >> 2] >> 2] | 0;
	                        c[e >> 2] = c[(c[g >> 2] | 0) + 8 >> 2];
	                        Ka(a | 0, 127e3, e | 0) | 0
	                    }
	                } else qq(b, 5015, 127016);
	                b = c[f >> 2] | 0;
	                if (c[(c[g >> 2] | 0) + 60 >> 2] | 0) {
	                    if (!(c[b + 124 >> 2] | 0)) {
	                        a = c[c[f >> 2] >> 2] | 0;
	                        c[e >> 2] = c[(c[g >> 2] | 0) + 60 >> 2];
	                        Ka(a | 0, 127056, e | 0) | 0
	                    }
	                } else qq(b, 5016, 127064);
	                if (!(c[(c[f >> 2] | 0) + 124 >> 2] | 0)) {
	                    do switch (c[(c[g >> 2] | 0) + 40 >> 2] | 0) {
	                        case 3:
	                        {
	                            Ka(c[c[f >> 2] >> 2] | 0, 127128, e | 0) | 0;
	                            break
	                        }
	                        case 8:
	                        {
	                            Ka(c[c[f >> 2] >> 2] | 0, 127184, e | 0) | 0;
	                            break
	                        }
	                        case 1:
	                        {
	                            Ka(c[c[f >> 2] >> 2] | 0, 127112, e | 0) | 0;
	                            break
	                        }
	                        case 9:
	                        {
	                            Ka(c[c[f >> 2] >> 2] | 0, 127200, e | 0) | 0;
	                            break
	                        }
	                        case 2:
	                        {
	                            Ka(c[c[f >> 2] >> 2] | 0, 127120, e | 0) | 0;
	                            break
	                        }
	                        case 6:
	                        {
	                            Ka(c[c[f >> 2] >> 2] | 0, 127152, e | 0) | 0;
	                            break
	                        }
	                        case 5:
	                        {
	                            Ka(c[c[f >> 2] >> 2] | 0, 127144, e | 0) | 0;
	                            break
	                        }
	                        case 10:
	                        {
	                            Ka(c[c[f >> 2] >> 2] | 0, 127216, e | 0) | 0;
	                            break
	                        }
	                        case 4:
	                        {
	                            Ka(c[c[f >> 2] >> 2] | 0, 127136, e | 0) | 0;
	                            break
	                        }
	                        case 7:
	                        {
	                            Ka(c[c[f >> 2] >> 2] | 0, 127168, e | 0) | 0;
	                            break
	                        }
	                        default:
	                        {
	                        }
	                    } while (0);
	                    do if (c[(c[g >> 2] | 0) + 52 >> 2] | 0) {
	                        c[j >> 2] = c[(c[g >> 2] | 0) + 52 >> 2];
	                        c[h >> 2] = 0;
	                        while (1) {
	                            if ((c[h >> 2] | 0) >= 5)break;
	                            b = c[c[f >> 2] >> 2] | 0;
	                            a = c[(c[j >> 2] | 0) + 4 >> 2] | 0;
	                            if (c[h >> 2] | 0) {
	                                c[e >> 2] = a;
	                                Ka(b | 0, 127232, e | 0) | 0
	                            } else {
	                                c[e >> 2] = a;
	                                Ka(b | 0, 127240, e | 0) | 0
	                            }
	                            c[j >> 2] = c[c[j >> 2] >> 2];
	                            if (!(c[j >> 2] | 0))break;
	                            c[h >> 2] = (c[h >> 2] | 0) + 1
	                        }
	                        b = c[c[f >> 2] >> 2] | 0;
	                        if (!(c[j >> 2] | 0)) {
	                            Ka(b | 0, 126712, e | 0) | 0;
	                            break
	                        } else {
	                            Ka(b | 0, 127248, e | 0) | 0;
	                            break
	                        }
	                    } while (0);
	                    j = c[(c[g >> 2] | 0) + 44 >> 2] | 0;
	                    if ((j | 0) == 4)Ka(c[c[f >> 2] >> 2] | 0, 127288, e | 0) | 0; else if ((j | 0) == 2)Ka(c[c[f >> 2] >> 2] | 0, 127256, e | 0) | 0; else if ((j | 0) == 3)Ka(c[c[f >> 2] >> 2] | 0, 127272, e | 0) | 0;
	                    if (c[(c[g >> 2] | 0) + 48 >> 2] | 0) {
	                        Ka(c[c[f >> 2] >> 2] | 0, 127296, e | 0) | 0;
	                        pq(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 48 >> 2] | 0);
	                        Ka(c[c[f >> 2] >> 2] | 0, 127296, e | 0) | 0
	                    }
	                    Ka(c[c[f >> 2] >> 2] | 0, 121896, e | 0) | 0
	                }
	                rq(c[f >> 2] | 0, c[g >> 2] | 0);
	                i = d;
	                return
	            }

	            function xq(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                oq(c[f >> 2] | 0);
	                if (!(c[g >> 2] | 0)) {
	                    if (c[(c[f >> 2] | 0) + 124 >> 2] | 0) {
	                        i = d;
	                        return
	                    }
	                    Ka(c[c[f >> 2] >> 2] | 0, 126624, e | 0) | 0;
	                    i = d;
	                    return
	                }
	                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 17) {
	                    qq(c[f >> 2] | 0, 5026, 126656);
	                    i = d;
	                    return
	                }
	                b = c[f >> 2] | 0;
	                if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                    if (!(c[b + 124 >> 2] | 0)) {
	                        Ka(c[c[f >> 2] >> 2] | 0, 126696, e | 0) | 0;
	                        pq(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0);
	                        Ka(c[c[f >> 2] >> 2] | 0, 126712, e | 0) | 0
	                    }
	                } else qq(b, 5015, 126720);
	                if (!(c[(c[f >> 2] | 0) + 124 >> 2] | 0)) {
	                    switch (c[(c[g >> 2] | 0) + 48 >> 2] | 0) {
	                        case 5:
	                        {
	                            Ka(c[c[f >> 2] >> 2] | 0, 126824, e | 0) | 0;
	                            break
	                        }
	                        case 2:
	                        {
	                            Ka(c[c[f >> 2] >> 2] | 0, 126768, e | 0) | 0;
	                            break
	                        }
	                        case 4:
	                        {
	                            Ka(c[c[f >> 2] >> 2] | 0, 126808, e | 0) | 0;
	                            break
	                        }
	                        case 6:
	                        {
	                            Ka(c[c[f >> 2] >> 2] | 0, 126848, e | 0) | 0;
	                            break
	                        }
	                        case 1:
	                        {
	                            Ka(c[c[f >> 2] >> 2] | 0, 126752, e | 0) | 0;
	                            break
	                        }
	                        case 3:
	                        {
	                            Ka(c[c[f >> 2] >> 2] | 0, 126792, e | 0) | 0;
	                            break
	                        }
	                        default:
	                        {
	                        }
	                    }
	                    if (c[(c[g >> 2] | 0) + 52 >> 2] | 0) {
	                        oq(c[f >> 2] | 0);
	                        b = c[c[f >> 2] >> 2] | 0;
	                        c[e >> 2] = c[(c[g >> 2] | 0) + 52 >> 2];
	                        Ka(b | 0, 126864, e | 0) | 0
	                    }
	                    if (c[(c[g >> 2] | 0) + 56 >> 2] | 0) {
	                        oq(c[f >> 2] | 0);
	                        b = c[c[f >> 2] >> 2] | 0;
	                        c[e >> 2] = c[(c[g >> 2] | 0) + 56 >> 2];
	                        Ka(b | 0, 126880, e | 0) | 0
	                    }
	                    if (c[(c[g >> 2] | 0) + 64 >> 2] | 0) {
	                        oq(c[f >> 2] | 0);
	                        b = c[c[f >> 2] >> 2] | 0;
	                        c[e >> 2] = c[(c[g >> 2] | 0) + 64 >> 2];
	                        Ka(b | 0, 126896, e | 0) | 0
	                    }
	                    if (c[(c[g >> 2] | 0) + 40 >> 2] | 0) {
	                        oq(c[f >> 2] | 0);
	                        Ka(c[c[f >> 2] >> 2] | 0, 126912, e | 0) | 0;
	                        pq(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 40 >> 2] | 0);
	                        Ka(c[c[f >> 2] >> 2] | 0, 121896, e | 0) | 0
	                    }
	                }
	                rq(c[f >> 2] | 0, c[g >> 2] | 0);
	                i = d;
	                return
	            }

	            function yq(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                oq(c[f >> 2] | 0);
	                if (!(c[g >> 2] | 0)) {
	                    if (c[(c[f >> 2] | 0) + 124 >> 2] | 0) {
	                        i = d;
	                        return
	                    }
	                    Ka(c[c[f >> 2] >> 2] | 0, 125496, e | 0) | 0;
	                    i = d;
	                    return
	                }
	                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 18) {
	                    qq(c[f >> 2] | 0, 5027, 125520);
	                    i = d;
	                    return
	                }
	                if (!(c[(c[g >> 2] | 0) + 8 >> 2] | 0)) {
	                    b = c[f >> 2] | 0;
	                    if (c[(c[g >> 2] | 0) + 12 >> 2] | 0) {
	                        Fq(b, 5028, 125560, c[(c[g >> 2] | 0) + 12 >> 2] | 0);
	                        i = d;
	                        return
	                    } else {
	                        qq(b, 5028, 125600);
	                        i = d;
	                        return
	                    }
	                }
	                if (c[(c[f >> 2] | 0) + 124 >> 2] | 0) {
	                    i = d;
	                    return
	                }
	                b = c[c[f >> 2] >> 2] | 0;
	                if (c[(c[g >> 2] | 0) + 12 >> 2] | 0) {
	                    c[e >> 2] = c[(c[g >> 2] | 0) + 12 >> 2];
	                    Ka(b | 0, 125640, e | 0) | 0
	                } else Ka(b | 0, 125664, e | 0) | 0;
	                pq(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0);
	                Ka(c[c[f >> 2] >> 2] | 0, 121896, e | 0) | 0;
	                i = d;
	                return
	            }

	            function zq(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                e = (c[h >> 2] | 0) + 128 | 0;
	                c[e >> 2] = (c[e >> 2] | 0) + 1;
	                e = c[(c[h >> 2] | 0) + 116 >> 2] | 0;
	                h = c[j >> 2] | 0;
	                j = c[k >> 2] | 0;
	                c[g >> 2] = c[l >> 2];
	                Xd(0, 0, 0, 0, e, 24, h, 2, 0, 0, 0, 0, 0, 0, 0, j, g);
	                i = f;
	                return
	            }

	            function Aq(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                while (1) {
	                    if (!(c[f >> 2] | 0))break;
	                    yq(c[e >> 2] | 0, c[f >> 2] | 0);
	                    c[f >> 2] = c[c[f >> 2] >> 2]
	                }
	                i = d;
	                return
	            }

	            function Bq(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                oq(c[f >> 2] | 0);
	                b = (c[(c[f >> 2] | 0) + 124 >> 2] | 0) != 0;
	                if (!(c[g >> 2] | 0)) {
	                    if (b) {
	                        i = d;
	                        return
	                    }
	                    Ka(c[c[f >> 2] >> 2] | 0, 126384, e | 0) | 0;
	                    i = d;
	                    return
	                }
	                if (b) {
	                    i = d;
	                    return
	                }
	                switch (c[(c[g >> 2] | 0) + 48 >> 2] | 0) {
	                    case 5:
	                    {
	                        Ka(c[c[f >> 2] >> 2] | 0, 126536, e | 0) | 0;
	                        break
	                    }
	                    case 2:
	                    {
	                        Ka(c[c[f >> 2] >> 2] | 0, 126432, e | 0) | 0;
	                        break
	                    }
	                    case 3:
	                    {
	                        Ka(c[c[f >> 2] >> 2] | 0, 126464, e | 0) | 0;
	                        break
	                    }
	                    case 4:
	                    {
	                        Ka(c[c[f >> 2] >> 2] | 0, 126504, e | 0) | 0;
	                        break
	                    }
	                    case 1:
	                    {
	                        Ka(c[c[f >> 2] >> 2] | 0, 126400, e | 0) | 0;
	                        break
	                    }
	                    default:
	                    {
	                        b = c[c[f >> 2] >> 2] | 0;
	                        c[e >> 2] = c[(c[g >> 2] | 0) + 48 >> 2];
	                        Ka(b | 0, 126568, e | 0) | 0
	                    }
	                }
	                b = c[c[f >> 2] >> 2] | 0;
	                c[e >> 2] = c[(c[g >> 2] | 0) + 8 >> 2];
	                Ka(b | 0, 122096, e | 0) | 0;
	                if (c[(c[g >> 2] | 0) + 52 >> 2] | 0) {
	                    oq(c[f >> 2] | 0);
	                    b = c[c[f >> 2] >> 2] | 0;
	                    c[e >> 2] = c[(c[g >> 2] | 0) + 52 >> 2];
	                    Ka(b | 0, 126584, e | 0) | 0
	                }
	                if (c[(c[g >> 2] | 0) + 56 >> 2] | 0) {
	                    oq(c[f >> 2] | 0);
	                    b = c[c[f >> 2] >> 2] | 0;
	                    c[e >> 2] = c[(c[g >> 2] | 0) + 56 >> 2];
	                    Ka(b | 0, 126600, e | 0) | 0
	                }
	                if (c[(c[g >> 2] | 0) + 64 >> 2] | 0) {
	                    oq(c[f >> 2] | 0);
	                    b = c[c[f >> 2] >> 2] | 0;
	                    c[e >> 2] = c[(c[g >> 2] | 0) + 64 >> 2];
	                    Ka(b | 0, 126616, e | 0) | 0
	                }
	                if (!(c[(c[g >> 2] | 0) + 40 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                oq(c[f >> 2] | 0);
	                Ka(c[c[f >> 2] >> 2] | 0, 126368, e | 0) | 0;
	                pq(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 40 >> 2] | 0);
	                Ka(c[c[f >> 2] >> 2] | 0, 121896, e | 0) | 0;
	                i = d;
	                return
	            }

	            function Cq(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = Gq(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                do if ((c[j >> 2] | 0) == -2) {
	                    g = c[f >> 2] | 0;
	                    if (!(c[(c[h >> 2] | 0) + 12 >> 2] | 0)) {
	                        qq(g, 5030, 125208);
	                        break
	                    } else {
	                        Fq(g, 5030, 125256, c[(c[h >> 2] | 0) + 12 >> 2] | 0);
	                        break
	                    }
	                } while (0);
	                if ((c[j >> 2] | 0) != -3) {
	                    i = e;
	                    return
	                }
	                j = c[f >> 2] | 0;
	                if (!(c[(c[h >> 2] | 0) + 12 >> 2] | 0)) {
	                    qq(j, 5031, 125304);
	                    i = e;
	                    return
	                } else {
	                    Fq(j, 5031, 125352, c[(c[h >> 2] | 0) + 12 >> 2] | 0);
	                    i = e;
	                    return
	                }
	            }

	            function Dq(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if (!(c[(c[e >> 2] | 0) + 124 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if (Fy(c[f >> 2] | 0) | 0) {
	                    i = d;
	                    return
	                }
	                Fq(c[e >> 2] | 0, 5032, 125184, c[f >> 2] | 0);
	                i = d;
	                return
	            }

	            function Eq(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[(c[e >> 2] | 0) + 124 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if (!(c[f >> 2] | 0)) {
	                    qq(c[e >> 2] | 0, 5015, 125088);
	                    i = d;
	                    return
	                }
	                if (Gh(c[f >> 2] | 0, 0) | 0)Fq(c[e >> 2] | 0, 5034, 125104, c[f >> 2] | 0);
	                if (!(c[(c[e >> 2] | 0) + 120 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if (CP(c[(c[e >> 2] | 0) + 120 >> 2] | 0, c[f >> 2] | 0) | 0) {
	                    i = d;
	                    return
	                }
	                if ((c[(c[e >> 2] | 0) + 112 >> 2] | 0) != 0 ? (c[(c[(c[e >> 2] | 0) + 112 >> 2] | 0) + 88 >> 2] & 4608 | 0) != 0 : 0) {
	                    i = d;
	                    return
	                }
	                Fq(c[e >> 2] | 0, 5035, 125136, c[f >> 2] | 0);
	                i = d;
	                return
	            }

	            function Fq(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                e = (c[h >> 2] | 0) + 128 | 0;
	                c[e >> 2] = (c[e >> 2] | 0) + 1;
	                e = c[(c[h >> 2] | 0) + 116 >> 2] | 0;
	                h = c[j >> 2] | 0;
	                j = c[k >> 2] | 0;
	                c[g >> 2] = c[l >> 2];
	                Xd(0, 0, 0, 0, e, 24, h, 2, 0, 0, 0, 0, 0, 0, 0, j, g);
	                i = f;
	                return
	            }

	            function Gq(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = -1;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                if ((((((c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 2 : 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 9 : 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 3 : 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 13 : 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 19 : 0) {
	                    c[e >> 2] = -2;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                a:while (1) {
	                    if (c[f >> 2] | 0)if (((c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 2 : 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 3 : 0)l = (c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 19; else l = 1; else l = 0;
	                    m = c[f >> 2] | 0;
	                    if (!l) {
	                        n = 26;
	                        break
	                    }
	                    if (!((c[m + 4 >> 2] | 0) != 1 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 19 : 0))n = 18;
	                    b:do if ((n | 0) == 18) {
	                        n = 0;
	                        c[h >> 2] = c[(c[f >> 2] | 0) + 48 >> 2];
	                        while (1) {
	                            if (!(c[h >> 2] | 0))break b;
	                            if ((c[h >> 2] | 0) == (c[g >> 2] | 0)) {
	                                n = 21;
	                                break a
	                            }
	                            if (qy(c[(c[h >> 2] | 0) + 12 >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] | 0) | 0) {
	                                n = 23;
	                                break a
	                            }
	                            c[h >> 2] = c[c[h >> 2] >> 2]
	                        }
	                    } while (0);
	                    c[f >> 2] = c[(c[f >> 2] | 0) + 20 >> 2]
	                }
	                if ((n | 0) == 21) {
	                    c[e >> 2] = 1;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                } else if ((n | 0) == 23) {
	                    c[e >> 2] = -2;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                } else if ((n | 0) == 26) {
	                    do if (m) {
	                        if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 9 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 13 : 0)break;
	                        c[j >> 2] = c[(c[f >> 2] | 0) + 52 >> 2];
	                        if ((c[j >> 2] | 0) == (c[g >> 2] | 0)) {
	                            c[e >> 2] = 1;
	                            k = c[e >> 2] | 0;
	                            i = d;
	                            return k | 0
	                        }
	                    } while (0);
	                    c[e >> 2] = -3;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                return 0
	            }

	            function Hq(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 28 | 0;
	                f = d + 8 | 0;
	                g = d + 24 | 0;
	                h = d + 20 | 0;
	                j = d + 16 | 0;
	                k = d;
	                l = f;
	                c[l >> 2] = a;
	                c[l + 4 >> 2] = b;
	                b = f;
	                l = Ha(c[b >> 2] | 0, c[b + 4 >> 2] | 0, 0) | 0;
	                c[g >> 2] = 64 - l;
	                c[h >> 2] = ((c[g >> 2] | 0) > 6 ? c[g >> 2] | 0 : 6) - 6;
	                g = f;
	                l = dU(c[g >> 2] | 0, c[g + 4 >> 2] | 0, c[h >> 2] | 0) | 0;
	                c[j >> 2] = l;
	                l = $T(1, 0, c[h >> 2] | 0) | 0;
	                h = XT(l | 0, G | 0, 1, 0) | 0;
	                l = k;
	                c[l >> 2] = h;
	                c[l + 4 >> 2] = G;
	                l = k;
	                k = f;
	                f = c[j >> 2] | 0;
	                if ((c[l >> 2] & c[k >> 2] | 0) != 0 ? 1 : (c[l + 4 >> 2] & c[k + 4 >> 2] | 0) != 0) {
	                    c[e >> 2] = f + 1;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                } else {
	                    c[e >> 2] = f;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                return 0
	            }

	            function Iq(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                Ss(c[e >> 2] | 0, 1, c[f >> 2] | 0);
	                i = d;
	                return
	            }

	            function Jq(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                d = i;
	                i = i + 2112 | 0;
	                e = d + 2096 | 0;
	                f = d + 2092 | 0;
	                g = d + 2088 | 0;
	                h = d + 2076 | 0;
	                j = d + 24 | 0;
	                k = d + 2072 | 0;
	                l = d + 16 | 0;
	                m = d + 8 | 0;
	                n = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[k >> 2] = 0;
	                b = n;
	                c[b >> 2] = 0;
	                c[b + 4 >> 2] = 0;
	                if ((c[f >> 2] | 0) >>> 0 < 64) {
	                    Iq(c[e >> 2] | 0, c[f >> 2] | 0);
	                    i = d;
	                    return
	                }
	                c[g >> 2] = Hq(c[f >> 2] | 0, 0) | 0;
	                c[h >> 2] = d + 2080;
	                c[c[h >> 2] >> 2] = 0;
	                c[(c[h >> 2] | 0) + 4 >> 2] = 0;
	                b = n;
	                a = Ts(c[e >> 2] | 0, c[b >> 2] | 0, c[b + 4 >> 2] | 0, c[f >> 2] | 0) | 0;
	                b = l;
	                c[b >> 2] = a;
	                c[b + 4 >> 2] = G;
	                b = c[g >> 2] | 0;
	                a = m;
	                c[a >> 2] = b;
	                c[a + 4 >> 2] = ((b | 0) < 0) << 31 >> 31;
	                b = m;
	                a = c[b + 4 >> 2] | 0;
	                o = c[g >> 2] | 0;
	                p = ((o | 0) < 0) << 31 >> 31;
	                if ((a | 0) < (p | 0) | ((a | 0) == (p | 0) ? (c[b >> 2] | 0) >>> 0 < o >>> 0 : 0)) {
	                    o = c[g >> 2] | 0;
	                    b = m;
	                    c[b >> 2] = o;
	                    c[b + 4 >> 2] = ((o | 0) < 0) << 31 >> 31
	                }
	                o = m;
	                b = c[o >> 2] | 0;
	                p = c[o + 4 >> 2] | 0;
	                o = n;
	                a = XT(c[f >> 2] | 0, 0, c[o >> 2] | 0, c[o + 4 >> 2] | 0) | 0;
	                o = G;
	                if ((p | 0) > (o | 0) | (p | 0) == (o | 0) & b >>> 0 > a >>> 0) {
	                    a = n;
	                    b = XT(c[f >> 2] | 0, 0, c[a >> 2] | 0, c[a + 4 >> 2] | 0) | 0;
	                    a = m;
	                    c[a >> 2] = b;
	                    c[a + 4 >> 2] = G
	                }
	                a = m;
	                b = c[a + 4 >> 2] | 0;
	                o = l;
	                p = c[o + 4 >> 2] | 0;
	                if ((b | 0) > (p | 0) | ((b | 0) == (p | 0) ? (c[a >> 2] | 0) >>> 0 > (c[o >> 2] | 0) >>> 0 : 0)) {
	                    Ss((c[e >> 2] | 0) + (c[n >> 2] << 2) | 0, c[l >> 2] | 0, c[m >> 2] | 0);
	                    o = m;
	                    a = c[o + 4 >> 2] | 0;
	                    p = l;
	                    c[p >> 2] = c[o >> 2];
	                    c[p + 4 >> 2] = a
	                }
	                a = n;
	                p = c[a + 4 >> 2] | 0;
	                o = j + (c[k >> 2] << 4) | 0;
	                c[o >> 2] = c[a >> 2];
	                c[o + 4 >> 2] = p;
	                p = l;
	                o = c[p + 4 >> 2] | 0;
	                a = j + (c[k >> 2] << 4) + 8 | 0;
	                c[a >> 2] = c[p >> 2];
	                c[a + 4 >> 2] = o;
	                c[k >> 2] = (c[k >> 2] | 0) + 1;
	                o = l;
	                a = n;
	                p = bU(c[a >> 2] | 0, c[a + 4 >> 2] | 0, c[o >> 2] | 0, c[o + 4 >> 2] | 0) | 0;
	                o = n;
	                c[o >> 2] = p;
	                c[o + 4 >> 2] = G;
	                o = n;
	                if ((c[o + 4 >> 2] | 0) == 0 ? (c[o >> 2] | 0) == (c[f >> 2] | 0) : 0) {
	                    while (1) {
	                        if ((c[k >> 2] | 0) <= 1)break;
	                        Us(c[e >> 2] | 0, j, c[k >> 2] | 0, c[h >> 2] | 0);
	                        o = j + ((c[k >> 2] | 0) - 1 << 4) + 8 | 0;
	                        p = j + ((c[k >> 2] | 0) - 2 << 4) + 8 | 0;
	                        a = p;
	                        b = bU(c[a >> 2] | 0, c[a + 4 >> 2] | 0, c[o >> 2] | 0, c[o + 4 >> 2] | 0) | 0;
	                        o = p;
	                        c[o >> 2] = b;
	                        c[o + 4 >> 2] = G;
	                        c[k >> 2] = (c[k >> 2] | 0) + -1
	                    }
	                    if (!(c[(c[h >> 2] | 0) + 4 >> 2] | 0)) {
	                        i = d;
	                        return
	                    }
	                    jT(c[(c[h >> 2] | 0) + 4 >> 2] | 0);
	                    c[(c[h >> 2] | 0) + 4 >> 2] = 0;
	                    i = d;
	                    return
	                }
	                o = n;
	                b = Ts(c[e >> 2] | 0, c[o >> 2] | 0, c[o + 4 >> 2] | 0, c[f >> 2] | 0) | 0;
	                o = l;
	                c[o >> 2] = b;
	                c[o + 4 >> 2] = G;
	                o = c[g >> 2] | 0;
	                b = m;
	                c[b >> 2] = o;
	                c[b + 4 >> 2] = ((o | 0) < 0) << 31 >> 31;
	                o = m;
	                b = c[o + 4 >> 2] | 0;
	                p = c[g >> 2] | 0;
	                a = ((p | 0) < 0) << 31 >> 31;
	                if ((b | 0) < (a | 0) | ((b | 0) == (a | 0) ? (c[o >> 2] | 0) >>> 0 < p >>> 0 : 0)) {
	                    p = c[g >> 2] | 0;
	                    o = m;
	                    c[o >> 2] = p;
	                    c[o + 4 >> 2] = ((p | 0) < 0) << 31 >> 31
	                }
	                p = m;
	                o = c[p >> 2] | 0;
	                a = c[p + 4 >> 2] | 0;
	                p = n;
	                b = XT(c[f >> 2] | 0, 0, c[p >> 2] | 0, c[p + 4 >> 2] | 0) | 0;
	                p = G;
	                if ((a | 0) > (p | 0) | (a | 0) == (p | 0) & o >>> 0 > b >>> 0) {
	                    b = n;
	                    o = XT(c[f >> 2] | 0, 0, c[b >> 2] | 0, c[b + 4 >> 2] | 0) | 0;
	                    b = m;
	                    c[b >> 2] = o;
	                    c[b + 4 >> 2] = G
	                }
	                b = m;
	                o = c[b + 4 >> 2] | 0;
	                p = l;
	                a = c[p + 4 >> 2] | 0;
	                if ((o | 0) > (a | 0) | ((o | 0) == (a | 0) ? (c[b >> 2] | 0) >>> 0 > (c[p >> 2] | 0) >>> 0 : 0)) {
	                    Ss((c[e >> 2] | 0) + (c[n >> 2] << 2) | 0, c[l >> 2] | 0, c[m >> 2] | 0);
	                    p = m;
	                    b = c[p + 4 >> 2] | 0;
	                    a = l;
	                    c[a >> 2] = c[p >> 2];
	                    c[a + 4 >> 2] = b
	                }
	                b = n;
	                a = c[b + 4 >> 2] | 0;
	                p = j + (c[k >> 2] << 4) | 0;
	                c[p >> 2] = c[b >> 2];
	                c[p + 4 >> 2] = a;
	                a = l;
	                p = c[a + 4 >> 2] | 0;
	                b = j + (c[k >> 2] << 4) + 8 | 0;
	                c[b >> 2] = c[a >> 2];
	                c[b + 4 >> 2] = p;
	                c[k >> 2] = (c[k >> 2] | 0) + 1;
	                p = l;
	                b = n;
	                a = bU(c[b >> 2] | 0, c[b + 4 >> 2] | 0, c[p >> 2] | 0, c[p + 4 >> 2] | 0) | 0;
	                p = n;
	                c[p >> 2] = a;
	                c[p + 4 >> 2] = G;
	                p = n;
	                if ((c[p + 4 >> 2] | 0) == 0 ? (c[p >> 2] | 0) == (c[f >> 2] | 0) : 0) {
	                    while (1) {
	                        if ((c[k >> 2] | 0) <= 1)break;
	                        Us(c[e >> 2] | 0, j, c[k >> 2] | 0, c[h >> 2] | 0);
	                        p = j + ((c[k >> 2] | 0) - 1 << 4) + 8 | 0;
	                        a = j + ((c[k >> 2] | 0) - 2 << 4) + 8 | 0;
	                        b = a;
	                        o = bU(c[b >> 2] | 0, c[b + 4 >> 2] | 0, c[p >> 2] | 0, c[p + 4 >> 2] | 0) | 0;
	                        p = a;
	                        c[p >> 2] = o;
	                        c[p + 4 >> 2] = G;
	                        c[k >> 2] = (c[k >> 2] | 0) + -1
	                    }
	                    if (!(c[(c[h >> 2] | 0) + 4 >> 2] | 0)) {
	                        i = d;
	                        return
	                    }
	                    jT(c[(c[h >> 2] | 0) + 4 >> 2] | 0);
	                    c[(c[h >> 2] | 0) + 4 >> 2] = 0;
	                    i = d;
	                    return
	                }
	                p = n;
	                o = Ts(c[e >> 2] | 0, c[p >> 2] | 0, c[p + 4 >> 2] | 0, c[f >> 2] | 0) | 0;
	                p = l;
	                c[p >> 2] = o;
	                c[p + 4 >> 2] = G;
	                p = c[g >> 2] | 0;
	                o = m;
	                c[o >> 2] = p;
	                c[o + 4 >> 2] = ((p | 0) < 0) << 31 >> 31;
	                p = m;
	                o = c[p + 4 >> 2] | 0;
	                a = c[g >> 2] | 0;
	                b = ((a | 0) < 0) << 31 >> 31;
	                if ((o | 0) < (b | 0) | ((o | 0) == (b | 0) ? (c[p >> 2] | 0) >>> 0 < a >>> 0 : 0)) {
	                    a = c[g >> 2] | 0;
	                    p = m;
	                    c[p >> 2] = a;
	                    c[p + 4 >> 2] = ((a | 0) < 0) << 31 >> 31
	                }
	                a = m;
	                p = c[a >> 2] | 0;
	                b = c[a + 4 >> 2] | 0;
	                a = n;
	                o = XT(c[f >> 2] | 0, 0, c[a >> 2] | 0, c[a + 4 >> 2] | 0) | 0;
	                a = G;
	                if ((b | 0) > (a | 0) | (b | 0) == (a | 0) & p >>> 0 > o >>> 0) {
	                    o = n;
	                    p = XT(c[f >> 2] | 0, 0, c[o >> 2] | 0, c[o + 4 >> 2] | 0) | 0;
	                    o = m;
	                    c[o >> 2] = p;
	                    c[o + 4 >> 2] = G
	                }
	                o = m;
	                p = c[o + 4 >> 2] | 0;
	                a = l;
	                b = c[a + 4 >> 2] | 0;
	                if ((p | 0) > (b | 0) | ((p | 0) == (b | 0) ? (c[o >> 2] | 0) >>> 0 > (c[a >> 2] | 0) >>> 0 : 0)) {
	                    Ss((c[e >> 2] | 0) + (c[n >> 2] << 2) | 0, c[l >> 2] | 0, c[m >> 2] | 0);
	                    a = m;
	                    o = c[a + 4 >> 2] | 0;
	                    b = l;
	                    c[b >> 2] = c[a >> 2];
	                    c[b + 4 >> 2] = o
	                }
	                o = n;
	                b = c[o + 4 >> 2] | 0;
	                a = j + (c[k >> 2] << 4) | 0;
	                c[a >> 2] = c[o >> 2];
	                c[a + 4 >> 2] = b;
	                b = l;
	                a = c[b + 4 >> 2] | 0;
	                o = j + (c[k >> 2] << 4) + 8 | 0;
	                c[o >> 2] = c[b >> 2];
	                c[o + 4 >> 2] = a;
	                c[k >> 2] = (c[k >> 2] | 0) + 1;
	                a = l;
	                o = n;
	                b = bU(c[o >> 2] | 0, c[o + 4 >> 2] | 0, c[a >> 2] | 0, c[a + 4 >> 2] | 0) | 0;
	                a = n;
	                c[a >> 2] = b;
	                c[a + 4 >> 2] = G;
	                a = n;
	                if ((c[a + 4 >> 2] | 0) == 0 ? (c[a >> 2] | 0) == (c[f >> 2] | 0) : 0) {
	                    while (1) {
	                        if ((c[k >> 2] | 0) <= 1)break;
	                        Us(c[e >> 2] | 0, j, c[k >> 2] | 0, c[h >> 2] | 0);
	                        a = j + ((c[k >> 2] | 0) - 1 << 4) + 8 | 0;
	                        b = j + ((c[k >> 2] | 0) - 2 << 4) + 8 | 0;
	                        o = b;
	                        p = bU(c[o >> 2] | 0, c[o + 4 >> 2] | 0, c[a >> 2] | 0, c[a + 4 >> 2] | 0) | 0;
	                        a = b;
	                        c[a >> 2] = p;
	                        c[a + 4 >> 2] = G;
	                        c[k >> 2] = (c[k >> 2] | 0) + -1
	                    }
	                    if (!(c[(c[h >> 2] | 0) + 4 >> 2] | 0)) {
	                        i = d;
	                        return
	                    }
	                    jT(c[(c[h >> 2] | 0) + 4 >> 2] | 0);
	                    c[(c[h >> 2] | 0) + 4 >> 2] = 0;
	                    i = d;
	                    return
	                }
	                while (1) {
	                    a = (Vs(j, c[k >> 2] | 0) | 0) != 0;
	                    p = c[e >> 2] | 0;
	                    if (!a) {
	                        c[k >> 2] = Ws(p, j, c[k >> 2] | 0, c[h >> 2] | 0, c[f >> 2] | 0) | 0;
	                        continue
	                    }
	                    a = n;
	                    b = Ts(p, c[a >> 2] | 0, c[a + 4 >> 2] | 0, c[f >> 2] | 0) | 0;
	                    a = l;
	                    c[a >> 2] = b;
	                    c[a + 4 >> 2] = G;
	                    a = c[g >> 2] | 0;
	                    b = m;
	                    c[b >> 2] = a;
	                    c[b + 4 >> 2] = ((a | 0) < 0) << 31 >> 31;
	                    a = m;
	                    b = c[a + 4 >> 2] | 0;
	                    p = c[g >> 2] | 0;
	                    o = ((p | 0) < 0) << 31 >> 31;
	                    if ((b | 0) < (o | 0) | ((b | 0) == (o | 0) ? (c[a >> 2] | 0) >>> 0 < p >>> 0 : 0)) {
	                        p = c[g >> 2] | 0;
	                        a = m;
	                        c[a >> 2] = p;
	                        c[a + 4 >> 2] = ((p | 0) < 0) << 31 >> 31
	                    }
	                    p = m;
	                    a = c[p >> 2] | 0;
	                    o = c[p + 4 >> 2] | 0;
	                    p = n;
	                    b = XT(c[f >> 2] | 0, 0, c[p >> 2] | 0, c[p + 4 >> 2] | 0) | 0;
	                    p = G;
	                    if ((o | 0) > (p | 0) | (o | 0) == (p | 0) & a >>> 0 > b >>> 0) {
	                        b = n;
	                        a = XT(c[f >> 2] | 0, 0, c[b >> 2] | 0, c[b + 4 >> 2] | 0) | 0;
	                        b = m;
	                        c[b >> 2] = a;
	                        c[b + 4 >> 2] = G
	                    }
	                    b = m;
	                    a = c[b + 4 >> 2] | 0;
	                    p = l;
	                    o = c[p + 4 >> 2] | 0;
	                    if ((a | 0) > (o | 0) | ((a | 0) == (o | 0) ? (c[b >> 2] | 0) >>> 0 > (c[p >> 2] | 0) >>> 0 : 0)) {
	                        Ss((c[e >> 2] | 0) + (c[n >> 2] << 2) | 0, c[l >> 2] | 0, c[m >> 2] | 0);
	                        p = m;
	                        b = c[p + 4 >> 2] | 0;
	                        o = l;
	                        c[o >> 2] = c[p >> 2];
	                        c[o + 4 >> 2] = b
	                    }
	                    b = n;
	                    o = c[b + 4 >> 2] | 0;
	                    p = j + (c[k >> 2] << 4) | 0;
	                    c[p >> 2] = c[b >> 2];
	                    c[p + 4 >> 2] = o;
	                    o = l;
	                    p = c[o + 4 >> 2] | 0;
	                    b = j + (c[k >> 2] << 4) + 8 | 0;
	                    c[b >> 2] = c[o >> 2];
	                    c[b + 4 >> 2] = p;
	                    c[k >> 2] = (c[k >> 2] | 0) + 1;
	                    p = l;
	                    b = n;
	                    o = bU(c[b >> 2] | 0, c[b + 4 >> 2] | 0, c[p >> 2] | 0, c[p + 4 >> 2] | 0) | 0;
	                    p = n;
	                    c[p >> 2] = o;
	                    c[p + 4 >> 2] = G;
	                    p = n;
	                    if ((c[p + 4 >> 2] | 0) == 0 ? (c[p >> 2] | 0) == (c[f >> 2] | 0) : 0)break
	                }
	                while (1) {
	                    if ((c[k >> 2] | 0) <= 1)break;
	                    Us(c[e >> 2] | 0, j, c[k >> 2] | 0, c[h >> 2] | 0);
	                    f = j + ((c[k >> 2] | 0) - 1 << 4) + 8 | 0;
	                    n = j + ((c[k >> 2] | 0) - 2 << 4) + 8 | 0;
	                    l = n;
	                    m = bU(c[l >> 2] | 0, c[l + 4 >> 2] | 0, c[f >> 2] | 0, c[f + 4 >> 2] | 0) | 0;
	                    f = n;
	                    c[f >> 2] = m;
	                    c[f + 4 >> 2] = G;
	                    c[k >> 2] = (c[k >> 2] | 0) + -1
	                }
	                if (!(c[(c[h >> 2] | 0) + 4 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                jT(c[(c[h >> 2] | 0) + 4 >> 2] | 0);
	                c[(c[h >> 2] | 0) + 4 >> 2] = 0;
	                i = d;
	                return
	            }

	            function Kq() {
	                var a = 0;
	                a = i;
	                if (c[31974] | 0) {
	                    i = a;
	                    return
	                }
	                h[15985] = +Xs();
	                h[15986] = +Ys();
	                h[15984] = +Zs();
	                h[15988] = +_s();
	                c[31974] = 1;
	                i = a;
	                return
	            }

	            function Lq(a) {
	                a = +a;
	                var b = 0, c = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                c = b;
	                h[c >> 3] = a;
	                d = $s(+h[c >> 3]) | 0;
	                i = b;
	                return d | 0
	            }

	            function Mq(a) {
	                a = +a;
	                var b = 0, c = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                c = b;
	                h[c >> 3] = a;
	                d = at(+h[c >> 3]) | 0;
	                i = b;
	                return d | 0
	            }

	            function Nq(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[g >> 2] = (c[g >> 2] | 0) < 0 | (c[g >> 2] | 0) > 25 ? 25 : b;
	                b = c[g >> 2] | 0;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = c[127920 + (c[g >> 2] << 2) >> 2];
	                    Xd(0, 0, 0, 0, 0, 12, b + 1200 - 0 | 0, 2, 0, 0, 0, 0, 0, 0, 0, 127912, e);
	                    i = d;
	                    return
	                }
	                c[(c[f >> 2] | 0) + 8 >> 2] = b;
	                if (!(c[(c[f >> 2] | 0) + 12 >> 2] | 0)) {
	                    b = (c[g >> 2] | 0) + 1200 - 0 | 0;
	                    a = c[(c[f >> 2] | 0) + 4 >> 2] | 0;
	                    h = (c[c[f >> 2] >> 2] | 0) - (c[(c[f >> 2] | 0) + 4 >> 2] | 0) | 0;
	                    c[e >> 2] = c[127920 + (c[g >> 2] << 2) >> 2];
	                    Xd(0, 0, 0, 0, 0, 12, b, 2, 0, 0, a, 0, 0, h, 0, 127912, e);
	                    i = d;
	                    return
	                }
	                Yd((c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 136 | 0);
	                c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 136 >> 2] = 12;
	                c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 140 >> 2] = (c[g >> 2] | 0) + 1200 - 0;
	                c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 148 >> 2] = 2;
	                h = my(c[(c[f >> 2] | 0) + 4 >> 2] | 0) | 0;
	                c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 160 >> 2] = h;
	                c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 172 >> 2] = (c[c[f >> 2] >> 2] | 0) - (c[(c[f >> 2] | 0) + 4 >> 2] | 0);
	                c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 184 >> 2] = c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 188 >> 2];
	                h = c[(c[f >> 2] | 0) + 12 >> 2] | 0;
	                if (c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 132 >> 2] | 0) {
	                    Ab[c[h + 132 >> 2] & 511](c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 128 >> 2] | 0, (c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 136 | 0);
	                    i = d;
	                    return
	                } else {
	                    a = c[h + 188 >> 2] | 0;
	                    h = (c[g >> 2] | 0) + 1200 - 0 | 0;
	                    b = c[(c[f >> 2] | 0) + 4 >> 2] | 0;
	                    j = (c[c[f >> 2] >> 2] | 0) - (c[(c[f >> 2] | 0) + 4 >> 2] | 0) | 0;
	                    c[e >> 2] = c[127920 + (c[g >> 2] << 2) >> 2];
	                    Xd(0, 0, 0, 0, a, 12, h, 2, 0, 0, b, 0, 0, j, 0, 127912, e);
	                    i = d;
	                    return
	                }
	            }

	            function Oq(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 12 | 0;
	                h = f;
	                c[g >> 2] = a;
	                c[f + 8 >> 2] = b;
	                c[f + 4 >> 2] = d;
	                c[h >> 2] = e;
	                Nq(c[g >> 2] | 0, c[h >> 2] | 0);
	                i = f;
	                return
	            }

	            function Pq(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                a = (c[(c[d >> 2] | 0) + 20 >> 2] | 0) == 0;
	                c[f >> 2] = 0;
	                a:do if (a)while (1) {
	                    if ((c[f >> 2] | 0) >= (c[c[d >> 2] >> 2] | 0))break a;
	                    c[e >> 2] = (c[(c[d >> 2] | 0) + 8 >> 2] | 0) + ((c[f >> 2] | 0) * 40 | 0);
	                    do if (c[(c[e >> 2] | 0) + 24 >> 2] | 0)if ((c[c[e >> 2] >> 2] | 0) == 12) {
	                        Qq(c[(c[e >> 2] | 0) + 24 >> 2] | 0);
	                        break
	                    } else {
	                        zb[c[135736 >> 2] & 511](c[(c[e >> 2] | 0) + 24 >> 2] | 0);
	                        break
	                    } while (0);
	                    if (c[(c[e >> 2] | 0) + 28 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[e >> 2] | 0) + 28 >> 2] | 0);
	                    c[f >> 2] = (c[f >> 2] | 0) + 1
	                } else {
	                    while (1) {
	                        if ((c[f >> 2] | 0) >= (c[c[d >> 2] >> 2] | 0))break;
	                        c[e >> 2] = (c[(c[d >> 2] | 0) + 8 >> 2] | 0) + ((c[f >> 2] | 0) * 40 | 0);
	                        if ((c[(c[e >> 2] | 0) + 24 >> 2] | 0) != 0 ? (c[c[e >> 2] >> 2] | 0) == 12 : 0)Qq(c[(c[e >> 2] | 0) + 24 >> 2] | 0);
	                        c[f >> 2] = (c[f >> 2] | 0) + 1
	                    }
	                    zP(c[(c[d >> 2] | 0) + 20 >> 2] | 0)
	                } while (0);
	                if (c[(c[d >> 2] | 0) + 8 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 24 >> 2] | 0)FQ(c[(c[d >> 2] | 0) + 24 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 16 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 16 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function Qq(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                do if ((c[c[d >> 2] >> 2] | 0) != 1 ? (c[c[d >> 2] >> 2] | 0) != 9 : 0) {
	                    a = c[d >> 2] | 0;
	                    if ((c[c[d >> 2] >> 2] | 0) == 7) {
	                        if (!(c[a + 28 >> 2] | 0))break;
	                        ev(c[(c[d >> 2] | 0) + 28 >> 2] | 0);
	                        break
	                    }
	                    if ((c[a >> 2] | 0) == 4 ? (c[(c[d >> 2] | 0) + 24 >> 2] | 0) != 0 : 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 24 >> 2] | 0)
	                } else e = 4; while (0);
	                do if ((e | 0) == 4) {
	                    a = c[d >> 2] | 0;
	                    if (c[(c[d >> 2] | 0) + 8 >> 2] | 0) {
	                        c[a >> 2] = 9;
	                        if (!(c[(c[d >> 2] | 0) + 4 >> 2] | 0))break;
	                        bt(c[(c[d >> 2] | 0) + 4 >> 2] | 0);
	                        break
	                    } else {
	                        if (!(c[a + 4 >> 2] | 0))break;
	                        fr(c[(c[d >> 2] | 0) + 4 >> 2] | 0);
	                        break
	                    }
	                } while (0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function Rq(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, j = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                f = i;
	                i = i + 128 | 0;
	                g = f;
	                j = f + 20 | 0;
	                l = f + 16 | 0;
	                m = f + 12 | 0;
	                n = f + 8 | 0;
	                o = f + 24 | 0;
	                c[j >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                if (!(c[j >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                c[n >> 2] = 0;
	                while (1) {
	                    p = o + ((c[n >> 2] << 1) + 1) | 0;
	                    if (!((c[n >> 2] | 0) < 25 ? (c[n >> 2] | 0) < (c[m >> 2] | 0) : 0))break;
	                    a[p >> 0] = 32;
	                    a[o + (c[n >> 2] << 1) >> 0] = 32;
	                    c[n >> 2] = (c[n >> 2] | 0) + 1
	                }
	                a[p >> 0] = 0;
	                a[o + (c[n >> 2] << 1) >> 0] = 0;
	                n = c[j >> 2] | 0;
	                c[g >> 2] = o;
	                Ka(n | 0, 127912, g | 0) | 0;
	                if (!(c[l >> 2] | 0)) {
	                    Ka(c[j >> 2] | 0, 128024, g | 0) | 0;
	                    i = f;
	                    return
	                }
	                do switch (c[c[l >> 2] >> 2] | 0) {
	                    case 5:
	                    {
	                        n = c[j >> 2] | 0;
	                        c[g >> 2] = c[(c[l >> 2] | 0) + 32 >> 2];
	                        Ka(n | 0, 128360, g | 0) | 0;
	                        ft(c[j >> 2] | 0, c[(c[l >> 2] | 0) + 28 >> 2] | 0, (c[m >> 2] | 0) + 1 | 0);
	                        Ka(c[j >> 2] | 0, 128352, g | 0) | 0;
	                        i = f;
	                        return
	                    }
	                    case 6:
	                    {
	                        do if (c[(c[l >> 2] | 0) + 36 >> 2] | 0) {
	                            if ((c[(c[l >> 2] | 0) + 36 >> 2] | 0) == (c[(c[l >> 2] | 0) + 28 >> 2] | 0) ? (c[(c[l >> 2] | 0) + 32 >> 2] | 0) == (c[(c[l >> 2] | 0) + 40 >> 2] | 0) : 0)break;
	                            Ka(c[j >> 2] | 0, 128456, g | 0) | 0;
	                            n = c[j >> 2] | 0;
	                            c[g >> 2] = o;
	                            Ka(n | 0, 127912, g | 0) | 0;
	                            Ka(c[j >> 2] | 0, 128480, g | 0) | 0;
	                            if ((c[(c[l >> 2] | 0) + 32 >> 2] | 0) >= 0) {
	                                n = c[j >> 2] | 0;
	                                c[g >> 2] = c[(c[l >> 2] | 0) + 32 >> 2];
	                                Ka(n | 0, 128432, g | 0) | 0
	                            }
	                            Ka(c[j >> 2] | 0, 128448, g | 0) | 0;
	                            ft(c[j >> 2] | 0, c[(c[l >> 2] | 0) + 28 >> 2] | 0, (c[m >> 2] | 0) + 1 | 0);
	                            n = c[j >> 2] | 0;
	                            c[g >> 2] = o;
	                            Ka(n | 0, 127912, g | 0) | 0;
	                            Ka(c[j >> 2] | 0, 128488, g | 0) | 0;
	                            if ((c[(c[l >> 2] | 0) + 40 >> 2] | 0) >= 0) {
	                                n = c[j >> 2] | 0;
	                                c[g >> 2] = c[(c[l >> 2] | 0) + 40 >> 2];
	                                Ka(n | 0, 128432, g | 0) | 0
	                            }
	                            Ka(c[j >> 2] | 0, 128448, g | 0) | 0;
	                            ft(c[j >> 2] | 0, c[(c[l >> 2] | 0) + 36 >> 2] | 0, (c[m >> 2] | 0) + 1 | 0);
	                            Ka(c[j >> 2] | 0, 128352, g | 0) | 0;
	                            i = f;
	                            return
	                        } while (0);
	                        Ka(c[j >> 2] | 0, 128400, g | 0) | 0;
	                        n = c[j >> 2] | 0;
	                        c[g >> 2] = o;
	                        Ka(n | 0, 127912, g | 0) | 0;
	                        if ((c[(c[l >> 2] | 0) + 32 >> 2] | 0) >= 0) {
	                            n = c[j >> 2] | 0;
	                            c[g >> 2] = c[(c[l >> 2] | 0) + 32 >> 2];
	                            Ka(n | 0, 128432, g | 0) | 0
	                        }
	                        Ka(c[j >> 2] | 0, 128448, g | 0) | 0;
	                        ft(c[j >> 2] | 0, c[(c[l >> 2] | 0) + 28 >> 2] | 0, (c[m >> 2] | 0) + 1 | 0);
	                        i = f;
	                        return
	                    }
	                    case 9:
	                    {
	                        Ka(c[j >> 2] | 0, 128104, g | 0) | 0;
	                        dt(c[j >> 2] | 0, c[(c[l >> 2] | 0) + 4 >> 2] | 0, c[m >> 2] | 0);
	                        i = f;
	                        return
	                    }
	                    case 0:
	                    {
	                        Ka(c[j >> 2] | 0, 128048, g | 0) | 0;
	                        i = f;
	                        return
	                    }
	                    case 4:
	                    {
	                        Ka(c[j >> 2] | 0, 128328, g | 0) | 0;
	                        Hp(c[j >> 2] | 0, c[(c[l >> 2] | 0) + 24 >> 2] | 0);
	                        Ka(c[j >> 2] | 0, 128352, g | 0) | 0;
	                        i = f;
	                        return
	                    }
	                    case 3:
	                    {
	                        n = Mq(+h[(c[l >> 2] | 0) + 16 >> 3]) | 0;
	                        if ((n | 0) == -1) {
	                            Ka(c[j >> 2] | 0, 128208, g | 0) | 0;
	                            i = f;
	                            return
	                        } else if ((n | 0) == 1) {
	                            Ka(c[j >> 2] | 0, 128176, g | 0) | 0;
	                            i = f;
	                            return
	                        } else {
	                            if (Lq(+h[(c[l >> 2] | 0) + 16 >> 3]) | 0) {
	                                Ka(c[j >> 2] | 0, 128240, g | 0) | 0;
	                                i = f;
	                                return
	                            }
	                            if (+h[(c[l >> 2] | 0) + 16 >> 3] == 0.0 ? (et(+h[(c[l >> 2] | 0) + 16 >> 3]) | 0) != 0 : 0) {
	                                Ka(c[j >> 2] | 0, 128272, g | 0) | 0;
	                                i = f;
	                                return
	                            }
	                            n = c[j >> 2] | 0;
	                            h[k >> 3] = +h[(c[l >> 2] | 0) + 16 >> 3];
	                            c[g >> 2] = c[k >> 2];
	                            c[g + 4 >> 2] = c[k + 4 >> 2];
	                            Ka(n | 0, 128296, g | 0) | 0;
	                            i = f;
	                            return
	                        }
	                        break
	                    }
	                    case 7:
	                    {
	                        Ka(c[j >> 2] | 0, 128496, g | 0) | 0;
	                        gt(c[j >> 2] | 0, c[(c[l >> 2] | 0) + 28 >> 2] | 0, c[m >> 2] | 0);
	                        i = f;
	                        return
	                    }
	                    case 8:
	                    {
	                        Ka(c[j >> 2] | 0, 128528, g | 0) | 0;
	                        i = f;
	                        return
	                    }
	                    case 1:
	                    {
	                        Ka(c[j >> 2] | 0, 128080, g | 0) | 0;
	                        ct(c[j >> 2] | 0, c[(c[l >> 2] | 0) + 4 >> 2] | 0, c[m >> 2] | 0);
	                        i = f;
	                        return
	                    }
	                    case 2:
	                    {
	                        Ka(c[j >> 2] | 0, 128136, g | 0) | 0;
	                        n = c[j >> 2] | 0;
	                        if (c[(c[l >> 2] | 0) + 8 >> 2] | 0) {
	                            Ka(n | 0, 128160, g | 0) | 0;
	                            i = f;
	                            return
	                        } else {
	                            Ka(n | 0, 128168, g | 0) | 0;
	                            i = f;
	                            return
	                        }
	                        break
	                    }
	                    default:
	                    {
	                        i = f;
	                        return
	                    }
	                } while (0)
	            }

	            function Sq(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 20 >> 2] | 0) > 0 : 0) {
	                    a = c[e >> 2] | 0;
	                    if ((c[(c[e >> 2] | 0) + 20 >> 2] | 0) <= (c[(c[e >> 2] | 0) + 44 >> 2] | 0)) {
	                        Oq(a, 128552, 2830, 23);
	                        c[d >> 2] = 0;
	                        g = c[d >> 2] | 0;
	                        i = b;
	                        return g | 0
	                    }
	                    h = a + 20 | 0;
	                    c[h >> 2] = (c[h >> 2] | 0) + -1;
	                    h = c[e >> 2] | 0;
	                    if ((c[(c[e >> 2] | 0) + 20 >> 2] | 0) > 0)c[(c[e >> 2] | 0) + 16 >> 2] = c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + ((c[h + 20 >> 2] | 0) - 1 << 2) >> 2]; else c[h + 16 >> 2] = 0;
	                    c[f >> 2] = c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + (c[(c[e >> 2] | 0) + 20 >> 2] << 2) >> 2];
	                    c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + (c[(c[e >> 2] | 0) + 20 >> 2] << 2) >> 2] = 0;
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[d >> 2] = 0;
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function Tq(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = -1;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                do if ((c[(c[f >> 2] | 0) + 20 >> 2] | 0) >= (c[(c[f >> 2] | 0) + 24 >> 2] | 0)) {
	                    if ((c[(c[f >> 2] | 0) + 24 >> 2] | 0) >= 1e6) {
	                        it(0, 128576);
	                        c[(c[f >> 2] | 0) + 8 >> 2] = 15;
	                        c[e >> 2] = 0;
	                        j = c[e >> 2] | 0;
	                        i = d;
	                        return j | 0
	                    }
	                    c[h >> 2] = Hb[c[135760 >> 2] & 511](c[(c[f >> 2] | 0) + 28 >> 2] | 0, c[(c[f >> 2] | 0) + 24 >> 2] << 1 << 2) | 0;
	                    if (c[h >> 2] | 0) {
	                        b = (c[f >> 2] | 0) + 24 | 0;
	                        c[b >> 2] = c[b >> 2] << 1;
	                        c[(c[f >> 2] | 0) + 28 >> 2] = c[h >> 2];
	                        break
	                    }
	                    it(0, 128616);
	                    c[(c[f >> 2] | 0) + 8 >> 2] = 15;
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } while (0);
	                c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + (c[(c[f >> 2] | 0) + 20 >> 2] << 2) >> 2] = c[g >> 2];
	                c[(c[f >> 2] | 0) + 16 >> 2] = c[g >> 2];
	                g = (c[f >> 2] | 0) + 20 | 0;
	                f = c[g >> 2] | 0;
	                c[g >> 2] = f + 1;
	                c[e >> 2] = f;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function Uq(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Sq(c[e >> 2] | 0) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    Oq(c[e >> 2] | 0, 128552, 2896, 10);
	                    if (c[e >> 2] | 0)c[(c[e >> 2] | 0) + 8 >> 2] = 10;
	                    c[d >> 2] = 0;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                a = c[f >> 2] | 0;
	                if ((c[c[f >> 2] >> 2] | 0) != 2)c[g >> 2] = Vq(a) | 0; else c[g >> 2] = c[a + 8 >> 2];
	                jt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[f >> 2] | 0);
	                c[d >> 2] = c[g >> 2];
	                h = c[d >> 2] | 0;
	                i = b;
	                return h | 0
	            }

	            function Vq(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, j = 0, k = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b;
	                e = b + 16 | 0;
	                f = b + 12 | 0;
	                g = b + 8 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = 0;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                switch (c[c[f >> 2] >> 2] | 0) {
	                    case 2:
	                    {
	                        c[g >> 2] = c[(c[f >> 2] | 0) + 8 >> 2];
	                        break
	                    }
	                    case 4:
	                    {
	                        c[g >> 2] = Jr(c[(c[f >> 2] | 0) + 24 >> 2] | 0) | 0;
	                        break
	                    }
	                    case 3:
	                    {
	                        c[g >> 2] = Ir(+h[(c[f >> 2] | 0) + 16 >> 3]) | 0;
	                        break
	                    }
	                    case 7:
	                    case 6:
	                    case 5:
	                    case 8:
	                    {
	                        a = c[33976] | 0;
	                        k = c[33980] | 0;
	                        c[d >> 2] = 128552;
	                        c[d + 4 >> 2] = 6066;
	                        Db[a & 511](k, 129064, d);
	                        c[g >> 2] = 0;
	                        break
	                    }
	                    case 9:
	                    case 1:
	                    {
	                        c[g >> 2] = Kr(c[(c[f >> 2] | 0) + 4 >> 2] | 0) | 0;
	                        break
	                    }
	                    case 0:
	                    {
	                        c[g >> 2] = 0;
	                        break
	                    }
	                    default:
	                    {
	                    }
	                }
	                c[e >> 2] = c[g >> 2];
	                j = c[e >> 2] | 0;
	                i = b;
	                return j | 0
	            }

	            function Wq(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, j = 0.0, k = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 16 | 0;
	                e = b + 8 | 0;
	                f = b + 24 | 0;
	                g = b;
	                c[f >> 2] = a;
	                h[g >> 3] = 0.0;
	                if (!(c[f >> 2] | 0)) {
	                    h[e >> 3] = +h[15984];
	                    j = +h[e >> 3];
	                    i = b;
	                    return +j
	                }
	                switch (c[c[f >> 2] >> 2] | 0) {
	                    case 0:
	                    {
	                        h[g >> 3] = +h[15984];
	                        break
	                    }
	                    case 2:
	                    {
	                        h[g >> 3] = +Dr(c[(c[f >> 2] | 0) + 8 >> 2] | 0);
	                        break
	                    }
	                    case 4:
	                    {
	                        h[g >> 3] = +Er(c[(c[f >> 2] | 0) + 24 >> 2] | 0);
	                        break
	                    }
	                    case 3:
	                    {
	                        h[g >> 3] = +h[(c[f >> 2] | 0) + 16 >> 3];
	                        break
	                    }
	                    case 7:
	                    case 6:
	                    case 5:
	                    case 8:
	                    {
	                        a = c[33976] | 0;
	                        k = c[33980] | 0;
	                        c[d >> 2] = 128552;
	                        c[d + 4 >> 2] = 5954;
	                        Db[a & 511](k, 129064, d);
	                        h[g >> 3] = +h[15984];
	                        break
	                    }
	                    case 9:
	                    case 1:
	                    {
	                        h[g >> 3] = +Hr(c[(c[f >> 2] | 0) + 4 >> 2] | 0);
	                        break
	                    }
	                    default:
	                    {
	                    }
	                }
	                h[e >> 3] = +h[g >> 3];
	                j = +h[e >> 3];
	                i = b;
	                return +j
	            }

	            function Xq(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = -1;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                c[g >> 2] = c[(c[e >> 2] | 0) + 12 >> 2];
	                a:while (1) {
	                    if (!(c[g >> 2] | 0))break;
	                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 ? (a = (c[f >> 2] | 0) + 1 | 0, c[f >> 2] = a, c[(c[g >> 2] | 0) + 40 >> 2] = 0 - a, (c[(c[g >> 2] | 0) + 12 >> 2] | 0) != 0) : 0) {
	                        c[g >> 2] = c[(c[g >> 2] | 0) + 12 >> 2];
	                        continue
	                    }
	                    if (c[(c[g >> 2] | 0) + 24 >> 2] | 0) {
	                        c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                        continue
	                    }
	                    while (1) {
	                        c[g >> 2] = c[(c[g >> 2] | 0) + 20 >> 2];
	                        if (!(c[g >> 2] | 0))continue a;
	                        if ((c[g >> 2] | 0) == (c[e >> 2] | 0)) {
	                            j = 12;
	                            break
	                        }
	                        k = c[g >> 2] | 0;
	                        if (c[(c[g >> 2] | 0) + 24 >> 2] | 0) {
	                            j = 14;
	                            break
	                        }
	                        if (!k)continue a
	                    }
	                    if ((j | 0) == 12) {
	                        j = 0;
	                        c[g >> 2] = 0;
	                        continue
	                    } else if ((j | 0) == 14) {
	                        j = 0;
	                        c[g >> 2] = c[k + 24 >> 2];
	                        continue
	                    }
	                }
	                c[d >> 2] = c[f >> 2];
	                h = c[d >> 2] | 0;
	                i = b;
	                return h | 0
	            }

	            function Yq(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0;
	                d = i;
	                i = i + 64 | 0;
	                e = d + 56 | 0;
	                f = d + 52 | 0;
	                g = d + 48 | 0;
	                h = d + 44 | 0;
	                j = d + 40 | 0;
	                k = d + 36 | 0;
	                l = d + 32 | 0;
	                m = d + 28 | 0;
	                n = d + 24 | 0;
	                o = d + 20 | 0;
	                p = d + 16 | 0;
	                q = d + 12 | 0;
	                r = d + 8 | 0;
	                s = d + 4 | 0;
	                t = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[k >> 2] = 0;
	                c[l >> 2] = 0;
	                c[m >> 2] = 0;
	                c[n >> 2] = 0;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = -2;
	                    u = c[e >> 2] | 0;
	                    i = d;
	                    return u | 0
	                }
	                if ((c[f >> 2] | 0) == (c[g >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    u = c[e >> 2] | 0;
	                    i = d;
	                    return u | 0
	                }
	                if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 2) {
	                    c[k >> 2] = 1;
	                    c[m >> 2] = c[f >> 2];
	                    c[f >> 2] = c[(c[f >> 2] | 0) + 20 >> 2]
	                }
	                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 2) {
	                    c[l >> 2] = 1;
	                    c[n >> 2] = c[g >> 2];
	                    c[g >> 2] = c[(c[g >> 2] | 0) + 20 >> 2]
	                }
	                if ((c[f >> 2] | 0) == (c[g >> 2] | 0)) {
	                    if ((c[k >> 2] | 0) != (c[l >> 2] | 0))if ((c[l >> 2] | 0) == 1) {
	                        c[e >> 2] = 1;
	                        u = c[e >> 2] | 0;
	                        i = d;
	                        return u | 0
	                    } else {
	                        c[e >> 2] = -1;
	                        u = c[e >> 2] | 0;
	                        i = d;
	                        return u | 0
	                    }
	                    if (!(c[k >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        u = c[e >> 2] | 0;
	                        i = d;
	                        return u | 0
	                    }
	                    c[o >> 2] = c[(c[n >> 2] | 0) + 28 >> 2];
	                    while (1) {
	                        if (!(c[o >> 2] | 0)) {
	                            v = 17;
	                            break
	                        }
	                        if ((c[o >> 2] | 0) == (c[m >> 2] | 0)) {
	                            v = 15;
	                            break
	                        }
	                        c[o >> 2] = c[(c[o >> 2] | 0) + 28 >> 2]
	                    }
	                    if ((v | 0) == 15) {
	                        c[e >> 2] = 1;
	                        u = c[e >> 2] | 0;
	                        i = d;
	                        return u | 0
	                    } else if ((v | 0) == 17) {
	                        c[e >> 2] = -1;
	                        u = c[e >> 2] | 0;
	                        i = d;
	                        return u | 0
	                    }
	                }
	                if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 18 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                    if ((c[f >> 2] | 0) == (c[(c[g >> 2] | 0) + 28 >> 2] | 0)) {
	                        c[e >> 2] = 1;
	                        u = c[e >> 2] | 0;
	                        i = d;
	                        return u | 0
	                    }
	                    if ((c[f >> 2] | 0) == (c[(c[g >> 2] | 0) + 24 >> 2] | 0)) {
	                        c[e >> 2] = -1;
	                        u = c[e >> 2] | 0;
	                        i = d;
	                        return u | 0
	                    }
	                    if (((((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 1 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? 0 > (c[(c[f >> 2] | 0) + 40 >> 2] | 0) : 0) ? 0 > (c[(c[g >> 2] | 0) + 40 >> 2] | 0) : 0) ? (c[(c[f >> 2] | 0) + 32 >> 2] | 0) == (c[(c[g >> 2] | 0) + 32 >> 2] | 0) : 0) {
	                        c[q >> 2] = 0 - (c[(c[f >> 2] | 0) + 40 >> 2] | 0);
	                        c[r >> 2] = 0 - (c[(c[g >> 2] | 0) + 40 >> 2] | 0);
	                        if ((c[q >> 2] | 0) < (c[r >> 2] | 0)) {
	                            c[e >> 2] = 1;
	                            u = c[e >> 2] | 0;
	                            i = d;
	                            return u | 0
	                        }
	                        if ((c[q >> 2] | 0) > (c[r >> 2] | 0)) {
	                            c[e >> 2] = -1;
	                            u = c[e >> 2] | 0;
	                            i = d;
	                            return u | 0
	                        }
	                    }
	                    c[j >> 2] = 0;
	                    c[o >> 2] = c[g >> 2];
	                    while (1) {
	                        w = c[o >> 2] | 0;
	                        if (!(c[(c[o >> 2] | 0) + 20 >> 2] | 0))break;
	                        if ((w | 0) == (c[f >> 2] | 0)) {
	                            v = 41;
	                            break
	                        }
	                        c[j >> 2] = (c[j >> 2] | 0) + 1;
	                        c[o >> 2] = c[(c[o >> 2] | 0) + 20 >> 2]
	                    }
	                    if ((v | 0) == 41) {
	                        c[e >> 2] = 1;
	                        u = c[e >> 2] | 0;
	                        i = d;
	                        return u | 0
	                    }
	                    c[p >> 2] = w;
	                    c[h >> 2] = 0;
	                    c[o >> 2] = c[f >> 2];
	                    while (1) {
	                        if (!(c[(c[o >> 2] | 0) + 20 >> 2] | 0))break;
	                        if ((c[o >> 2] | 0) == (c[g >> 2] | 0)) {
	                            v = 46;
	                            break
	                        }
	                        c[h >> 2] = (c[h >> 2] | 0) + 1;
	                        c[o >> 2] = c[(c[o >> 2] | 0) + 20 >> 2]
	                    }
	                    if ((v | 0) == 46) {
	                        c[e >> 2] = -1;
	                        u = c[e >> 2] | 0;
	                        i = d;
	                        return u | 0
	                    }
	                    if ((c[p >> 2] | 0) != (c[o >> 2] | 0)) {
	                        c[e >> 2] = -2;
	                        u = c[e >> 2] | 0;
	                        i = d;
	                        return u | 0
	                    }
	                    while (1) {
	                        if ((c[h >> 2] | 0) <= (c[j >> 2] | 0))break;
	                        c[h >> 2] = (c[h >> 2] | 0) + -1;
	                        c[f >> 2] = c[(c[f >> 2] | 0) + 20 >> 2]
	                    }
	                    while (1) {
	                        if ((c[j >> 2] | 0) <= (c[h >> 2] | 0))break;
	                        c[j >> 2] = (c[j >> 2] | 0) + -1;
	                        c[g >> 2] = c[(c[g >> 2] | 0) + 20 >> 2]
	                    }
	                    while (1) {
	                        x = c[f >> 2] | 0;
	                        if ((c[(c[f >> 2] | 0) + 20 >> 2] | 0) == (c[(c[g >> 2] | 0) + 20 >> 2] | 0))break;
	                        c[f >> 2] = c[x + 20 >> 2];
	                        c[g >> 2] = c[(c[g >> 2] | 0) + 20 >> 2];
	                        if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                            v = 56;
	                            break
	                        }
	                    }
	                    if ((v | 0) == 56) {
	                        c[e >> 2] = -2;
	                        u = c[e >> 2] | 0;
	                        i = d;
	                        return u | 0
	                    }
	                    if ((x | 0) == (c[(c[g >> 2] | 0) + 28 >> 2] | 0)) {
	                        c[e >> 2] = 1;
	                        u = c[e >> 2] | 0;
	                        i = d;
	                        return u | 0
	                    }
	                    if ((c[f >> 2] | 0) == (c[(c[g >> 2] | 0) + 24 >> 2] | 0)) {
	                        c[e >> 2] = -1;
	                        u = c[e >> 2] | 0;
	                        i = d;
	                        return u | 0
	                    }
	                    do if (((((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 1 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? 0 > (c[(c[f >> 2] | 0) + 40 >> 2] | 0) : 0) ? 0 > (c[(c[g >> 2] | 0) + 40 >> 2] | 0) : 0) ? (c[(c[f >> 2] | 0) + 32 >> 2] | 0) == (c[(c[g >> 2] | 0) + 32 >> 2] | 0) : 0) {
	                        c[s >> 2] = 0 - (c[(c[f >> 2] | 0) + 40 >> 2] | 0);
	                        c[t >> 2] = 0 - (c[(c[g >> 2] | 0) + 40 >> 2] | 0);
	                        if ((c[s >> 2] | 0) < (c[t >> 2] | 0)) {
	                            c[e >> 2] = 1;
	                            u = c[e >> 2] | 0;
	                            i = d;
	                            return u | 0
	                        }
	                        if ((c[s >> 2] | 0) <= (c[t >> 2] | 0))break;
	                        c[e >> 2] = -1;
	                        u = c[e >> 2] | 0;
	                        i = d;
	                        return u | 0
	                    } while (0);
	                    c[o >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                    while (1) {
	                        if (!(c[o >> 2] | 0)) {
	                            v = 75;
	                            break
	                        }
	                        if ((c[o >> 2] | 0) == (c[g >> 2] | 0)) {
	                            v = 73;
	                            break
	                        }
	                        c[o >> 2] = c[(c[o >> 2] | 0) + 24 >> 2]
	                    }
	                    if ((v | 0) == 73) {
	                        c[e >> 2] = 1;
	                        u = c[e >> 2] | 0;
	                        i = d;
	                        return u | 0
	                    } else if ((v | 0) == 75) {
	                        c[e >> 2] = -1;
	                        u = c[e >> 2] | 0;
	                        i = d;
	                        return u | 0
	                    }
	                }
	                c[e >> 2] = 1;
	                u = c[e >> 2] | 0;
	                i = d;
	                return u | 0
	            }

	            function Zq(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                Jq(c[(c[d >> 2] | 0) + 8 >> 2] | 0, c[c[d >> 2] >> 2] | 0);
	                i = b;
	                return
	            }

	            function _q(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if ((c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 18) {
	                    i = b;
	                    return
	                }
	                if (!(c[c[d >> 2] >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if ((c[(c[c[d >> 2] >> 2] | 0) + 4 >> 2] | 0) == 18) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 8 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 12 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 12 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function $q(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](12) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    it(0, 128632);
	                    c[d >> 2] = 0;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                a = c[f >> 2] | 0;
	                c[a + 0 >> 2] = 0;
	                c[a + 4 >> 2] = 0;
	                c[a + 8 >> 2] = 0;
	                do if (c[e >> 2] | 0) {
	                    a = Cb[c[135744 >> 2] & 511](40) | 0;
	                    c[(c[f >> 2] | 0) + 8 >> 2] = a;
	                    if (!(c[(c[f >> 2] | 0) + 8 >> 2] | 0)) {
	                        it(0, 128632);
	                        zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                        c[d >> 2] = 0;
	                        h = c[d >> 2] | 0;
	                        i = b;
	                        return h | 0
	                    }
	                    a = (c[(c[f >> 2] | 0) + 8 >> 2] | 0) + 0 | 0;
	                    j = a + 40 | 0;
	                    do {
	                        c[a >> 2] = 0;
	                        a = a + 4 | 0
	                    } while ((a | 0) < (j | 0));
	                    c[(c[f >> 2] | 0) + 4 >> 2] = 10;
	                    a = c[e >> 2] | 0;
	                    if ((c[(c[e >> 2] | 0) + 4 >> 2] | 0) == 18) {
	                        c[g >> 2] = a;
	                        j = kt(c[c[g >> 2] >> 2] | 0, c[g >> 2] | 0) | 0;
	                        k = c[f >> 2] | 0;
	                        l = c[k >> 2] | 0;
	                        c[k >> 2] = l + 1;
	                        c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + (l << 2) >> 2] = j;
	                        break
	                    } else {
	                        j = c[f >> 2] | 0;
	                        l = c[j >> 2] | 0;
	                        c[j >> 2] = l + 1;
	                        c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + (l << 2) >> 2] = a;
	                        break
	                    }
	                } while (0);
	                c[d >> 2] = c[f >> 2];
	                h = c[d >> 2] | 0;
	                i = b;
	                return h | 0
	            }

	            function ar(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                b = (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 18;
	                c[h >> 2] = 0;
	                a:do if (b) {
	                    while (1) {
	                        if ((c[h >> 2] | 0) >= (c[c[f >> 2] >> 2] | 0))break a;
	                        if ((c[(c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + (c[h >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0) == 18) {
	                            c[j >> 2] = c[g >> 2];
	                            c[k >> 2] = c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + (c[h >> 2] << 2) >> 2];
	                            if ((c[j >> 2] | 0) == (c[k >> 2] | 0)) {
	                                m = 7;
	                                break
	                            }
	                            if (((c[c[j >> 2] >> 2] | 0) != 0 ? (c[c[k >> 2] >> 2] | 0) == (c[c[j >> 2] >> 2] | 0) : 0) ? (qy(c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[(c[k >> 2] | 0) + 12 >> 2] | 0) | 0) != 0 : 0) {
	                                m = 11;
	                                break
	                            }
	                        }
	                        c[h >> 2] = (c[h >> 2] | 0) + 1
	                    }
	                    if ((m | 0) == 7) {
	                        c[e >> 2] = 1;
	                        l = c[e >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    } else if ((m | 0) == 11) {
	                        c[e >> 2] = 1;
	                        l = c[e >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    }
	                } else {
	                    while (1) {
	                        if ((c[h >> 2] | 0) >= (c[c[f >> 2] >> 2] | 0))break a;
	                        if ((c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + (c[h >> 2] << 2) >> 2] | 0) == (c[g >> 2] | 0))break;
	                        c[h >> 2] = (c[h >> 2] | 0) + 1
	                    }
	                    c[e >> 2] = 1;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                } while (0);
	                c[e >> 2] = 0;
	                l = c[e >> 2] | 0;
	                i = d;
	                return l | 0
	            }

	            function br(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if ((!((c[g >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) == 18 : 0) ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) {
	                    c[k >> 2] = 0;
	                    while (1) {
	                        if ((c[k >> 2] | 0) >= (c[c[g >> 2] >> 2] | 0))break;
	                        if ((((c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) != 0 ? (c[(c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0) == 18 : 0) ? (c[c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + (c[k >> 2] << 2) >> 2] >> 2] | 0) == (c[h >> 2] | 0) : 0) ? (qy(c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0) | 0) != 0 : 0) {
	                            m = 11;
	                            break
	                        }
	                        c[k >> 2] = (c[k >> 2] | 0) + 1
	                    }
	                    if ((m | 0) == 11) {
	                        c[f >> 2] = 0;
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    }
	                    do if (c[(c[g >> 2] | 0) + 4 >> 2] | 0) {
	                        if ((c[c[g >> 2] >> 2] | 0) == (c[(c[g >> 2] | 0) + 4 >> 2] | 0)) {
	                            if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) >= 1e7) {
	                                it(0, 128680);
	                                c[f >> 2] = -1;
	                                n = c[f >> 2] | 0;
	                                i = e;
	                                return n | 0
	                            }
	                            c[l >> 2] = Hb[c[135760 >> 2] & 511](c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] << 1 << 2) | 0;
	                            if (c[l >> 2] | 0) {
	                                m = (c[g >> 2] | 0) + 4 | 0;
	                                c[m >> 2] = c[m >> 2] << 1;
	                                c[(c[g >> 2] | 0) + 8 >> 2] = c[l >> 2];
	                                break
	                            }
	                            it(0, 128656);
	                            c[f >> 2] = -1;
	                            n = c[f >> 2] | 0;
	                            i = e;
	                            return n | 0
	                        }
	                    } else {
	                        m = Cb[c[135744 >> 2] & 511](40) | 0;
	                        c[(c[g >> 2] | 0) + 8 >> 2] = m;
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            m = (c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 0 | 0;
	                            k = m + 40 | 0;
	                            do {
	                                c[m >> 2] = 0;
	                                m = m + 4 | 0
	                            } while ((m | 0) < (k | 0));
	                            c[(c[g >> 2] | 0) + 4 >> 2] = 10;
	                            break
	                        }
	                        it(0, 128656);
	                        c[f >> 2] = -1;
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    } while (0);
	                    l = kt(c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                    j = c[g >> 2] | 0;
	                    h = c[j >> 2] | 0;
	                    c[j >> 2] = h + 1;
	                    c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + (h << 2) >> 2] = l;
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                c[f >> 2] = -1;
	                n = c[f >> 2] | 0;
	                i = e;
	                return n | 0
	            }

	            function cr(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = -1;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                c[h >> 2] = 0;
	                while (1) {
	                    if ((c[h >> 2] | 0) >= (c[c[f >> 2] >> 2] | 0))break;
	                    if ((c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + (c[h >> 2] << 2) >> 2] | 0) == (c[g >> 2] | 0)) {
	                        m = 6;
	                        break
	                    }
	                    c[h >> 2] = (c[h >> 2] | 0) + 1
	                }
	                if ((m | 0) == 6) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                do if (c[(c[f >> 2] | 0) + 4 >> 2] | 0) {
	                    if ((c[c[f >> 2] >> 2] | 0) == (c[(c[f >> 2] | 0) + 4 >> 2] | 0)) {
	                        if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) >= 1e7) {
	                            it(0, 128680);
	                            c[e >> 2] = -1;
	                            l = c[e >> 2] | 0;
	                            i = d;
	                            return l | 0
	                        }
	                        c[j >> 2] = Hb[c[135760 >> 2] & 511](c[(c[f >> 2] | 0) + 8 >> 2] | 0, c[(c[f >> 2] | 0) + 4 >> 2] << 1 << 2) | 0;
	                        if (c[j >> 2] | 0) {
	                            m = (c[f >> 2] | 0) + 4 | 0;
	                            c[m >> 2] = c[m >> 2] << 1;
	                            c[(c[f >> 2] | 0) + 8 >> 2] = c[j >> 2];
	                            break
	                        }
	                        it(0, 128656);
	                        c[e >> 2] = -1;
	                        l = c[e >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    }
	                } else {
	                    m = Cb[c[135744 >> 2] & 511](40) | 0;
	                    c[(c[f >> 2] | 0) + 8 >> 2] = m;
	                    if (c[(c[f >> 2] | 0) + 8 >> 2] | 0) {
	                        m = (c[(c[f >> 2] | 0) + 8 >> 2] | 0) + 0 | 0;
	                        h = m + 40 | 0;
	                        do {
	                            c[m >> 2] = 0;
	                            m = m + 4 | 0
	                        } while ((m | 0) < (h | 0));
	                        c[(c[f >> 2] | 0) + 4 >> 2] = 10;
	                        break
	                    }
	                    it(0, 128656);
	                    c[e >> 2] = -1;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                } while (0);
	                j = c[g >> 2] | 0;
	                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 18) {
	                    c[k >> 2] = j;
	                    g = kt(c[c[k >> 2] >> 2] | 0, c[k >> 2] | 0) | 0;
	                    k = c[f >> 2] | 0;
	                    m = c[k >> 2] | 0;
	                    c[k >> 2] = m + 1;
	                    c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + (m << 2) >> 2] = g
	                } else {
	                    g = c[f >> 2] | 0;
	                    m = c[g >> 2] | 0;
	                    c[g >> 2] = m + 1;
	                    c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + (m << 2) >> 2] = j
	                }
	                c[e >> 2] = 0;
	                l = c[e >> 2] | 0;
	                i = d;
	                return l | 0
	            }

	            function dr(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = -1;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                do if (c[(c[f >> 2] | 0) + 4 >> 2] | 0) {
	                    if ((c[c[f >> 2] >> 2] | 0) == (c[(c[f >> 2] | 0) + 4 >> 2] | 0)) {
	                        if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) >= 1e7) {
	                            it(0, 128680);
	                            c[e >> 2] = -1;
	                            k = c[e >> 2] | 0;
	                            i = d;
	                            return k | 0
	                        }
	                        c[h >> 2] = Hb[c[135760 >> 2] & 511](c[(c[f >> 2] | 0) + 8 >> 2] | 0, c[(c[f >> 2] | 0) + 4 >> 2] << 1 << 2) | 0;
	                        if (c[h >> 2] | 0) {
	                            c[(c[f >> 2] | 0) + 8 >> 2] = c[h >> 2];
	                            b = (c[f >> 2] | 0) + 4 | 0;
	                            c[b >> 2] = c[b >> 2] << 1;
	                            break
	                        }
	                        it(0, 128656);
	                        c[e >> 2] = -1;
	                        k = c[e >> 2] | 0;
	                        i = d;
	                        return k | 0
	                    }
	                } else {
	                    b = Cb[c[135744 >> 2] & 511](40) | 0;
	                    c[(c[f >> 2] | 0) + 8 >> 2] = b;
	                    if (c[(c[f >> 2] | 0) + 8 >> 2] | 0) {
	                        b = (c[(c[f >> 2] | 0) + 8 >> 2] | 0) + 0 | 0;
	                        a = b + 40 | 0;
	                        do {
	                            c[b >> 2] = 0;
	                            b = b + 4 | 0
	                        } while ((b | 0) < (a | 0));
	                        c[(c[f >> 2] | 0) + 4 >> 2] = 10;
	                        break
	                    }
	                    it(0, 128656);
	                    c[e >> 2] = -1;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                } while (0);
	                h = c[g >> 2] | 0;
	                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 18) {
	                    c[j >> 2] = h;
	                    g = kt(c[c[j >> 2] >> 2] | 0, c[j >> 2] | 0) | 0;
	                    j = c[f >> 2] | 0;
	                    b = c[j >> 2] | 0;
	                    c[j >> 2] = b + 1;
	                    c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + (b << 2) >> 2] = g
	                } else {
	                    g = c[f >> 2] | 0;
	                    b = c[g >> 2] | 0;
	                    c[g >> 2] = b + 1;
	                    c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + (b << 2) >> 2] = h
	                }
	                c[e >> 2] = 0;
	                k = c[e >> 2] | 0;
	                i = d;
	                return k | 0
	            }

	            function er(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                d = i;
	                i = i + 48 | 0;
	                e = d + 40 | 0;
	                f = d + 36 | 0;
	                g = d + 32 | 0;
	                h = d + 28 | 0;
	                j = d + 24 | 0;
	                k = d + 20 | 0;
	                l = d + 16 | 0;
	                m = d + 12 | 0;
	                n = d + 8 | 0;
	                o = d + 4 | 0;
	                p = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                b = c[f >> 2] | 0;
	                if (!(c[g >> 2] | 0)) {
	                    c[e >> 2] = b;
	                    q = c[e >> 2] | 0;
	                    i = d;
	                    return q | 0
	                }
	                if ((b | 0) == 0 ? (c[f >> 2] = $q(0) | 0, (c[f >> 2] | 0) == 0) : 0) {
	                    c[e >> 2] = 0;
	                    q = c[e >> 2] | 0;
	                    i = d;
	                    return q | 0
	                }
	                c[k >> 2] = c[c[f >> 2] >> 2];
	                c[h >> 2] = 0;
	                a:while (1) {
	                    if ((c[h >> 2] | 0) >= (c[c[g >> 2] >> 2] | 0)) {
	                        r = 33;
	                        break
	                    }
	                    c[n >> 2] = c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + (c[h >> 2] << 2) >> 2];
	                    c[l >> 2] = 0;
	                    c[j >> 2] = 0;
	                    while (1) {
	                        if ((c[j >> 2] | 0) >= (c[k >> 2] | 0))break;
	                        c[m >> 2] = c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + (c[j >> 2] << 2) >> 2];
	                        if ((c[m >> 2] | 0) == (c[n >> 2] | 0)) {
	                            r = 11;
	                            break
	                        }
	                        if ((((c[(c[m >> 2] | 0) + 4 >> 2] | 0) == 18 ? (c[(c[n >> 2] | 0) + 4 >> 2] | 0) == 18 : 0) ? (c[c[m >> 2] >> 2] | 0) == (c[c[n >> 2] >> 2] | 0) : 0) ? (qy(c[(c[m >> 2] | 0) + 12 >> 2] | 0, c[(c[n >> 2] | 0) + 12 >> 2] | 0) | 0) != 0 : 0) {
	                            r = 16;
	                            break
	                        }
	                        c[j >> 2] = (c[j >> 2] | 0) + 1
	                    }
	                    if ((r | 0) == 11) {
	                        r = 0;
	                        c[l >> 2] = 1
	                    } else if ((r | 0) == 16) {
	                        r = 0;
	                        c[l >> 2] = 1
	                    }
	                    do if (!(c[l >> 2] | 0)) {
	                        if (c[(c[f >> 2] | 0) + 4 >> 2] | 0) {
	                            if ((c[c[f >> 2] >> 2] | 0) == (c[(c[f >> 2] | 0) + 4 >> 2] | 0)) {
	                                if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) >= 1e7) {
	                                    r = 25;
	                                    break a
	                                }
	                                c[o >> 2] = Hb[c[135760 >> 2] & 511](c[(c[f >> 2] | 0) + 8 >> 2] | 0, c[(c[f >> 2] | 0) + 4 >> 2] << 1 << 2) | 0;
	                                if (!(c[o >> 2] | 0)) {
	                                    r = 27;
	                                    break a
	                                }
	                                c[(c[f >> 2] | 0) + 8 >> 2] = c[o >> 2];
	                                b = (c[f >> 2] | 0) + 4 | 0;
	                                c[b >> 2] = c[b >> 2] << 1
	                            }
	                        } else {
	                            b = Cb[c[135744 >> 2] & 511](40) | 0;
	                            c[(c[f >> 2] | 0) + 8 >> 2] = b;
	                            if (!(c[(c[f >> 2] | 0) + 8 >> 2] | 0)) {
	                                r = 21;
	                                break a
	                            }
	                            b = (c[(c[f >> 2] | 0) + 8 >> 2] | 0) + 0 | 0;
	                            a = b + 40 | 0;
	                            do {
	                                c[b >> 2] = 0;
	                                b = b + 4 | 0
	                            } while ((b | 0) < (a | 0));
	                            c[(c[f >> 2] | 0) + 4 >> 2] = 10
	                        }
	                        b = c[n >> 2] | 0;
	                        if ((c[(c[n >> 2] | 0) + 4 >> 2] | 0) == 18) {
	                            c[p >> 2] = b;
	                            a = kt(c[c[p >> 2] >> 2] | 0, c[p >> 2] | 0) | 0;
	                            s = c[f >> 2] | 0;
	                            t = c[s >> 2] | 0;
	                            c[s >> 2] = t + 1;
	                            c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + (t << 2) >> 2] = a;
	                            break
	                        } else {
	                            a = c[f >> 2] | 0;
	                            t = c[a >> 2] | 0;
	                            c[a >> 2] = t + 1;
	                            c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + (t << 2) >> 2] = b;
	                            break
	                        }
	                    } while (0);
	                    c[h >> 2] = (c[h >> 2] | 0) + 1
	                }
	                if ((r | 0) == 21) {
	                    it(0, 128712);
	                    c[e >> 2] = 0;
	                    q = c[e >> 2] | 0;
	                    i = d;
	                    return q | 0
	                } else if ((r | 0) == 25) {
	                    it(0, 128736);
	                    c[e >> 2] = 0;
	                    q = c[e >> 2] | 0;
	                    i = d;
	                    return q | 0
	                } else if ((r | 0) == 27) {
	                    it(0, 128712);
	                    c[e >> 2] = 0;
	                    q = c[e >> 2] | 0;
	                    i = d;
	                    return q | 0
	                } else if ((r | 0) == 33) {
	                    c[e >> 2] = c[f >> 2];
	                    q = c[e >> 2] | 0;
	                    i = d;
	                    return q | 0
	                }
	                return 0
	            }

	            function fr(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 8 >> 2] | 0) {
	                    c[e >> 2] = 0;
	                    while (1) {
	                        if ((c[e >> 2] | 0) >= (c[c[d >> 2] >> 2] | 0))break;
	                        if ((c[(c[(c[d >> 2] | 0) + 8 >> 2] | 0) + (c[e >> 2] << 2) >> 2] | 0) != 0 ? (c[(c[(c[(c[d >> 2] | 0) + 8 >> 2] | 0) + (c[e >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0) == 18 : 0)_q(c[(c[(c[d >> 2] | 0) + 8 >> 2] | 0) + (c[e >> 2] << 2) >> 2] | 0);
	                        c[e >> 2] = (c[e >> 2] | 0) + 1
	                    }
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 8 >> 2] | 0)
	                }
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function gr(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](48) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    it(0, 128632);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    a = (c[f >> 2] | 0) + 0 | 0;
	                    h = a + 48 | 0;
	                    do {
	                        c[a >> 2] = 0;
	                        a = a + 4 | 0
	                    } while ((a | 0) < (h | 0));
	                    c[c[f >> 2] >> 2] = 1;
	                    c[(c[f >> 2] | 0) + 8 >> 2] = 0;
	                    a = $q(c[e >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 4 >> 2] = a;
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function hr(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](48) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    it(0, 128768);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    a = (c[f >> 2] | 0) + 0 | 0;
	                    h = a + 48 | 0;
	                    do {
	                        c[a >> 2] = 0;
	                        a = a + 4 | 0
	                    } while ((a | 0) < (h | 0));
	                    c[c[f >> 2] >> 2] = 1;
	                    c[(c[f >> 2] | 0) + 4 >> 2] = c[e >> 2];
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function ir(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                a = _i(c[d >> 2] | 0) | 0;
	                c[e >> 2] = a;
	                if (!a)c[e >> 2] = my(128928) | 0;
	                i = b;
	                return c[e >> 2] | 0
	            }

	            function jr(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                d = kr(c[f >> 2] | 0, c[g >> 2] | 0, 0, c[h >> 2] | 0) | 0;
	                i = e;
	                return d | 0
	            }

	            function kr(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                do if (c[h >> 2] | 0) {
	                    if (!(c[j >> 2] | 0)) {
	                        c[g >> 2] = -1;
	                        break
	                    }
	                    if (!(c[(c[h >> 2] | 0) + 40 >> 2] | 0)) {
	                        e = Ij(0) | 0;
	                        c[(c[h >> 2] | 0) + 40 >> 2] = e
	                    }
	                    if (!(c[(c[h >> 2] | 0) + 40 >> 2] | 0)) {
	                        c[g >> 2] = -1;
	                        break
	                    }
	                    e = c[(c[h >> 2] | 0) + 40 >> 2] | 0;
	                    d = c[j >> 2] | 0;
	                    b = c[k >> 2] | 0;
	                    if (!(c[l >> 2] | 0)) {
	                        c[g >> 2] = ck(e, d, b, 0) | 0;
	                        break
	                    } else {
	                        c[g >> 2] = Nj(e, d, b, c[l >> 2] | 0) | 0;
	                        break
	                    }
	                } else c[g >> 2] = -1; while (0);
	                i = f;
	                return c[g >> 2] | 0
	            }

	            function lr(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                if ((c[(c[f >> 2] | 0) + 112 >> 2] | 0) != 0 ? (c[j >> 2] = c[(c[f >> 2] | 0) + 112 >> 2], c[k >> 2] = vb[c[j >> 2] & 511](c[(c[f >> 2] | 0) + 116 >> 2] | 0, c[g >> 2] | 0, 0) | 0, c[h >> 2] = c[k >> 2], (c[h >> 2] | 0) != 0) : 0) {
	                    c[e >> 2] = c[h >> 2];
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                c[e >> 2] = mr(c[f >> 2] | 0, c[g >> 2] | 0, 0) | 0;
	                l = c[e >> 2] | 0;
	                i = d;
	                return l | 0
	            }

	            function mr(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 20 | 0;
	                h = e + 16 | 0;
	                j = e + 12 | 0;
	                k = e + 8 | 0;
	                l = e + 4 | 0;
	                m = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                if ((c[(c[g >> 2] | 0) + 112 >> 2] | 0) != 0 ? (c[l >> 2] = c[(c[g >> 2] | 0) + 112 >> 2], c[m >> 2] = vb[c[l >> 2] & 511](c[(c[g >> 2] | 0) + 116 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0, c[k >> 2] = c[m >> 2], (c[k >> 2] | 0) != 0) : 0) {
	                    c[f >> 2] = c[k >> 2];
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                if (!(c[(c[g >> 2] | 0) + 40 >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                } else {
	                    c[k >> 2] = Tj(c[(c[g >> 2] | 0) + 40 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                    c[f >> 2] = c[k >> 2];
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                return 0
	            }

	            function nr(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                Kj(c[(c[d >> 2] | 0) + 40 >> 2] | 0, 0);
	                c[(c[d >> 2] | 0) + 40 >> 2] = 0;
	                i = b;
	                return
	            }

	            function or(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                b = c[f >> 2] | 0;
	                if (c[(c[f >> 2] | 0) + 92 >> 2] | 0) {
	                    c[h >> 2] = vb[c[b + 92 >> 2] & 511](c[(c[f >> 2] | 0) + 96 >> 2] | 0, c[g >> 2] | 0, 0) | 0;
	                    c[e >> 2] = c[h >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } else {
	                    c[e >> 2] = pr(b, c[g >> 2] | 0, 0) | 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                return 0
	            }

	            function pr(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                if ((c[(c[g >> 2] | 0) + 92 >> 2] | 0) != 0 ? (c[k >> 2] = vb[c[(c[g >> 2] | 0) + 92 >> 2] & 511](c[(c[g >> 2] | 0) + 96 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0, (c[k >> 2] | 0) != 0) : 0) {
	                    c[f >> 2] = c[k >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                if (!(c[(c[g >> 2] | 0) + 16 >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } else {
	                    k = c[g >> 2] | 0;
	                    c[f >> 2] = lt(k, Tj(c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0) | 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                return 0
	            }

	            function qr(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                Kj(c[(c[d >> 2] | 0) + 16 >> 2] | 0, 260);
	                c[(c[d >> 2] | 0) + 16 >> 2] = 0;
	                i = b;
	                return
	            }

	            function rr(a, b, e) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 12 | 0;
	                h = f + 8 | 0;
	                j = f + 4 | 0;
	                k = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                do if (c[h >> 2] | 0) {
	                    if (!(c[j >> 2] | 0)) {
	                        c[g >> 2] = -1;
	                        break
	                    }
	                    if (!(d[c[j >> 2] >> 0] | 0)) {
	                        c[g >> 2] = -1;
	                        break
	                    }
	                    if (!(c[(c[h >> 2] | 0) + 88 >> 2] | 0)) {
	                        e = Ij(10) | 0;
	                        c[(c[h >> 2] | 0) + 88 >> 2] = e
	                    }
	                    if (!(c[(c[h >> 2] | 0) + 88 >> 2] | 0)) {
	                        c[g >> 2] = -1;
	                        break
	                    }
	                    e = c[(c[h >> 2] | 0) + 88 >> 2] | 0;
	                    b = c[j >> 2] | 0;
	                    if (!(c[k >> 2] | 0)) {
	                        c[g >> 2] = ak(e, b, c[33934] | 0) | 0;
	                        break
	                    } else {
	                        a = my(c[k >> 2] | 0) | 0;
	                        c[g >> 2] = Oj(e, b, a, c[33934] | 0) | 0;
	                        break
	                    }
	                } else c[g >> 2] = -1; while (0);
	                i = f;
	                return c[g >> 2] | 0
	            }

	            function sr(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                if (!(c[g >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                if (qy(c[g >> 2] | 0, 128800) | 0) {
	                    c[e >> 2] = 128808;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                a:do if (c[(c[f >> 2] | 0) + 56 >> 2] | 0) {
	                    c[h >> 2] = 0;
	                    while (1) {
	                        if ((c[h >> 2] | 0) >= (c[(c[f >> 2] | 0) + 60 >> 2] | 0))break a;
	                        if ((c[(c[(c[f >> 2] | 0) + 56 >> 2] | 0) + (c[h >> 2] << 2) >> 2] | 0) != 0 ? (qy(c[(c[(c[(c[f >> 2] | 0) + 56 >> 2] | 0) + (c[h >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0, c[g >> 2] | 0) | 0) != 0 : 0)break;
	                        c[h >> 2] = (c[h >> 2] | 0) + 1
	                    }
	                    c[e >> 2] = c[(c[(c[(c[f >> 2] | 0) + 56 >> 2] | 0) + (c[h >> 2] << 2) >> 2] | 0) + 8 >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } while (0);
	                c[e >> 2] = Rj(c[(c[f >> 2] | 0) + 88 >> 2] | 0, c[g >> 2] | 0) | 0;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function tr(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                Kj(c[(c[d >> 2] | 0) + 88 >> 2] | 0, c[33934] | 0);
	                c[(c[d >> 2] | 0) + 88 >> 2] = 0;
	                i = b;
	                return
	            }

	            function ur(a) {
	                a = +a;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, j = 0, k = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b;
	                f = b + 8 | 0;
	                h[e >> 3] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](48) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    it(0, 128848);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    j = (c[f >> 2] | 0) + 0 | 0;
	                    k = j + 48 | 0;
	                    do {
	                        c[j >> 2] = 0;
	                        j = j + 4 | 0
	                    } while ((j | 0) < (k | 0));
	                    c[c[f >> 2] >> 2] = 3;
	                    h[(c[f >> 2] | 0) + 16 >> 3] = +h[e >> 3];
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function vr(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](48) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    it(0, 128872);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    a = (c[f >> 2] | 0) + 0 | 0;
	                    h = a + 48 | 0;
	                    do {
	                        c[a >> 2] = 0;
	                        a = a + 4 | 0
	                    } while ((a | 0) < (h | 0));
	                    c[c[f >> 2] >> 2] = 2;
	                    c[(c[f >> 2] | 0) + 8 >> 2] = (c[e >> 2] | 0) != 0 & 1;
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function wr(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](48) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    it(0, 128904);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = (c[f >> 2] | 0) + 0 | 0;
	                h = a + 48 | 0;
	                do {
	                    c[a >> 2] = 0;
	                    a = a + 4 | 0
	                } while ((a | 0) < (h | 0));
	                c[c[f >> 2] >> 2] = 4;
	                if (c[e >> 2] | 0) {
	                    a = my(c[e >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 24 >> 2] = a
	                } else {
	                    a = my(128928) | 0;
	                    c[(c[f >> 2] | 0) + 24 >> 2] = a
	                }
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function xr(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](48) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    it(0, 128904);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    a = (c[f >> 2] | 0) + 0 | 0;
	                    h = a + 48 | 0;
	                    do {
	                        c[a >> 2] = 0;
	                        a = a + 4 | 0
	                    } while ((a | 0) < (h | 0));
	                    c[c[f >> 2] >> 2] = 4;
	                    c[(c[f >> 2] | 0) + 24 >> 2] = c[e >> 2];
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function yr(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](48) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    it(0, 128904);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    a = (c[f >> 2] | 0) + 0 | 0;
	                    h = a + 48 | 0;
	                    do {
	                        c[a >> 2] = 0;
	                        a = a + 4 | 0
	                    } while ((a | 0) < (h | 0));
	                    c[c[f >> 2] >> 2] = 4;
	                    a = my(c[e >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 24 >> 2] = a;
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function zr(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b;
	                e = b + 16 | 0;
	                f = b + 12 | 0;
	                g = b + 8 | 0;
	                h = b + 4 | 0;
	                c[f >> 2] = a;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                c[g >> 2] = Cb[c[135744 >> 2] & 511](48) | 0;
	                if (!(c[g >> 2] | 0)) {
	                    it(0, 128936);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                a = (c[g >> 2] | 0) + 0 | 0;
	                k = (c[f >> 2] | 0) + 0 | 0;
	                l = a + 48 | 0;
	                do {
	                    c[a >> 2] = c[k >> 2];
	                    a = a + 4 | 0;
	                    k = k + 4 | 0
	                } while ((a | 0) < (l | 0));
	                switch (c[c[f >> 2] >> 2] | 0) {
	                    case 9:
	                    case 1:
	                    {
	                        k = er(0, c[(c[f >> 2] | 0) + 4 >> 2] | 0) | 0;
	                        c[(c[g >> 2] | 0) + 4 >> 2] = k;
	                        c[(c[g >> 2] | 0) + 8 >> 2] = 0;
	                        break
	                    }
	                    case 0:
	                    {
	                        k = c[33976] | 0;
	                        a = c[33980] | 0;
	                        c[d >> 2] = c[c[f >> 2] >> 2];
	                        Db[k & 511](a, 128952, d);
	                        break
	                    }
	                    case 7:
	                    {
	                        c[h >> 2] = c[(c[f >> 2] | 0) + 28 >> 2];
	                        d = dv(0, c[h >> 2] | 0) | 0;
	                        c[(c[g >> 2] | 0) + 28 >> 2] = d;
	                        break
	                    }
	                    case 8:
	                    {
	                        c[(c[g >> 2] | 0) + 28 >> 2] = c[(c[f >> 2] | 0) + 28 >> 2];
	                        break
	                    }
	                    case 4:
	                    {
	                        d = my(c[(c[f >> 2] | 0) + 24 >> 2] | 0) | 0;
	                        c[(c[g >> 2] | 0) + 24 >> 2] = d;
	                        break
	                    }
	                    default:
	                    {
	                    }
	                }
	                c[e >> 2] = c[g >> 2];
	                j = c[e >> 2] | 0;
	                i = b;
	                return j | 0
	            }

	            function Ar(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                if (c[d >> 2] | 0)c[e >> 2] = my(129e3) | 0; else c[e >> 2] = my(129008) | 0;
	                i = b;
	                return c[e >> 2] | 0
	            }

	            function Br(b) {
	                b = +b;
	                var d = 0, e = 0, f = 0, g = 0, j = 0;
	                d = i;
	                i = i + 112 | 0;
	                e = d;
	                f = d + 8 | 0;
	                g = d + 12 | 0;
	                h[e >> 3] = b;
	                j = Mq(+h[e >> 3]) | 0;
	                do if ((j | 0) == 1)c[f >> 2] = my(129016) | 0; else if ((j | 0) == -1)c[f >> 2] = my(129032) | 0; else {
	                    if (Lq(+h[e >> 3]) | 0) {
	                        c[f >> 2] = my(129048) | 0;
	                        break
	                    }
	                    if (+h[e >> 3] == 0.0 ? (et(+h[e >> 3]) | 0) != 0 : 0) {
	                        c[f >> 2] = my(129056) | 0;
	                        break
	                    }
	                    mt(+h[e >> 3], g, 99);
	                    a[g + 99 >> 0] = 0;
	                    c[f >> 2] = my(g) | 0
	                } while (0);
	                i = d;
	                return c[f >> 2] | 0
	            }

	            function Cr(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                if (((c[e >> 2] | 0) != 0 ? (c[c[e >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[e >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                    if ((c[c[e >> 2] >> 2] | 0) > 1)Zq(c[e >> 2] | 0);
	                    c[d >> 2] = ir(c[c[(c[e >> 2] | 0) + 8 >> 2] >> 2] | 0) | 0;
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                }
	                c[d >> 2] = my(128928) | 0;
	                f = c[d >> 2] | 0;
	                i = b;
	                return f | 0
	            }

	            function Dr(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                e = b + 8 | 0;
	                c[e >> 2] = a;
	                if (c[e >> 2] | 0)h[d >> 3] = 1.0; else h[d >> 3] = 0.0;
	                i = b;
	                return +(+h[d >> 3])
	            }

	            function Er(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0.0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                e = +Fr(c[d >> 2] | 0);
	                i = b;
	                return +e
	            }

	            function Fr(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0.0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0.0;
	                b = i;
	                i = i + 80 | 0;
	                e = b + 24 | 0;
	                f = b + 64 | 0;
	                g = b + 60 | 0;
	                j = b + 16 | 0;
	                k = b + 56 | 0;
	                l = b + 52 | 0;
	                m = b + 48 | 0;
	                n = b + 44 | 0;
	                o = b + 40 | 0;
	                p = b + 8 | 0;
	                q = b + 36 | 0;
	                r = b + 32 | 0;
	                s = b;
	                c[f >> 2] = a;
	                c[g >> 2] = c[f >> 2];
	                c[k >> 2] = 0;
	                c[l >> 2] = 0;
	                c[m >> 2] = 0;
	                c[n >> 2] = 0;
	                c[o >> 2] = 0;
	                if (!(c[g >> 2] | 0)) {
	                    h[e >> 3] = 0.0;
	                    t = +h[e >> 3];
	                    i = b;
	                    return +t
	                }
	                while (1) {
	                    do if ((d[c[g >> 2] >> 0] | 0 | 0) == 32)u = 1; else {
	                        if (9 <= (d[c[g >> 2] >> 0] | 0 | 0) ? (d[c[g >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            u = 1;
	                            break
	                        }
	                        u = (d[c[g >> 2] >> 0] | 0 | 0) == 13
	                    } while (0);
	                    v = c[g >> 2] | 0;
	                    if (!u)break;
	                    c[g >> 2] = v + 1
	                }
	                do if ((d[v >> 0] | 0 | 0) != 46) {
	                    if ((d[c[g >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[g >> 2] >> 0] | 0 | 0) <= 57 : 0)break;
	                    if ((d[c[g >> 2] >> 0] | 0 | 0) != 45) {
	                        h[e >> 3] = +h[15984];
	                        t = +h[e >> 3];
	                        i = b;
	                        return +t
	                    }
	                } while (0);
	                if ((d[c[g >> 2] >> 0] | 0 | 0) == 45) {
	                    c[l >> 2] = 1;
	                    c[g >> 2] = (c[g >> 2] | 0) + 1
	                }
	                h[j >> 3] = 0.0;
	                while (1) {
	                    if ((d[c[g >> 2] >> 0] | 0 | 0) < 48)break;
	                    if ((d[c[g >> 2] >> 0] | 0 | 0) > 57)break;
	                    h[j >> 3] = +h[j >> 3] * 10.0;
	                    c[o >> 2] = (d[c[g >> 2] >> 0] | 0) - 48;
	                    c[k >> 2] = 1;
	                    c[g >> 2] = (c[g >> 2] | 0) + 1;
	                    h[p >> 3] = +((c[o >> 2] | 0) >>> 0);
	                    h[j >> 3] = +h[j >> 3] + +h[p >> 3]
	                }
	                a:do if ((d[c[g >> 2] >> 0] | 0 | 0) == 46) {
	                    c[r >> 2] = 0;
	                    h[s >> 3] = 0.0;
	                    c[g >> 2] = (c[g >> 2] | 0) + 1;
	                    if ((d[c[g >> 2] >> 0] | 0 | 0) < 48) {
	                        if (!(c[k >> 2] | 0))w = 24
	                    } else if (!((c[k >> 2] | 0) != 0 ? 1 : (d[c[g >> 2] >> 0] | 0 | 0) <= 57))w = 24;
	                    if ((w | 0) == 24) {
	                        h[e >> 3] = +h[15984];
	                        t = +h[e >> 3];
	                        i = b;
	                        return +t
	                    }
	                    while (1) {
	                        if ((d[c[g >> 2] >> 0] | 0 | 0) < 48)break;
	                        if (!((c[r >> 2] | 0) < 20 ? (d[c[g >> 2] >> 0] | 0 | 0) <= 57 : 0))break;
	                        c[q >> 2] = (d[c[g >> 2] >> 0] | 0) - 48;
	                        h[s >> 3] = +h[s >> 3] * 10.0 + +(c[q >> 2] | 0);
	                        c[r >> 2] = (c[r >> 2] | 0) + 1;
	                        c[g >> 2] = (c[g >> 2] | 0) + 1
	                    }
	                    h[s >> 3] = +h[s >> 3] / +h[129232 + (c[r >> 2] << 3) >> 3];
	                    h[j >> 3] = +h[j >> 3] + +h[s >> 3];
	                    while (1) {
	                        if ((d[c[g >> 2] >> 0] | 0 | 0) < 48)break a;
	                        if ((d[c[g >> 2] >> 0] | 0 | 0) > 57)break a;
	                        c[g >> 2] = (c[g >> 2] | 0) + 1
	                    }
	                } while (0);
	                if (!((d[c[g >> 2] >> 0] | 0 | 0) != 101 ? (d[c[g >> 2] >> 0] | 0 | 0) != 69 : 0))w = 34;
	                b:do if ((w | 0) == 34) {
	                    c[g >> 2] = (c[g >> 2] | 0) + 1;
	                    if ((d[c[g >> 2] >> 0] | 0 | 0) != 45) {
	                        if ((d[c[g >> 2] >> 0] | 0 | 0) == 43)c[g >> 2] = (c[g >> 2] | 0) + 1
	                    } else {
	                        c[n >> 2] = 1;
	                        c[g >> 2] = (c[g >> 2] | 0) + 1
	                    }
	                    while (1) {
	                        if ((d[c[g >> 2] >> 0] | 0 | 0) < 48)break b;
	                        if ((d[c[g >> 2] >> 0] | 0 | 0) > 57)break b;
	                        c[m >> 2] = ((c[m >> 2] | 0) * 10 | 0) + ((d[c[g >> 2] >> 0] | 0) - 48);
	                        c[g >> 2] = (c[g >> 2] | 0) + 1
	                    }
	                } while (0);
	                while (1) {
	                    do if ((d[c[g >> 2] >> 0] | 0 | 0) == 32)x = 1; else {
	                        if (9 <= (d[c[g >> 2] >> 0] | 0 | 0) ? (d[c[g >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            x = 1;
	                            break
	                        }
	                        x = (d[c[g >> 2] >> 0] | 0 | 0) == 13
	                    } while (0);
	                    y = c[g >> 2] | 0;
	                    if (!x)break;
	                    c[g >> 2] = y + 1
	                }
	                if (d[y >> 0] | 0) {
	                    h[e >> 3] = +h[15984];
	                    t = +h[e >> 3];
	                    i = b;
	                    return +t
	                }
	                if (c[l >> 2] | 0)h[j >> 3] = -+h[j >> 3];
	                if (c[n >> 2] | 0)c[m >> 2] = 0 - (c[m >> 2] | 0);
	                z = +T(10.0, +(+(c[m >> 2] | 0)));
	                h[j >> 3] = +h[j >> 3] * z;
	                h[e >> 3] = +h[j >> 3];
	                t = +h[e >> 3];
	                i = b;
	                return +t
	            }

	            function Gr(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, j = 0.0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 8 | 0;
	                e = b + 20 | 0;
	                f = b + 16 | 0;
	                g = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    h[d >> 3] = +h[15984];
	                    j = +h[d >> 3];
	                    i = b;
	                    return +j
	                }
	                c[f >> 2] = ir(c[e >> 2] | 0) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    h[d >> 3] = +h[15984];
	                    j = +h[d >> 3];
	                    i = b;
	                    return +j
	                } else {
	                    h[g >> 3] = +Er(c[f >> 2] | 0);
	                    zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                    h[d >> 3] = +h[g >> 3];
	                    j = +h[d >> 3];
	                    i = b;
	                    return +j
	                }
	                return +(0.0)
	            }

	            function Hr(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, j = 0.0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 8 | 0;
	                e = b + 20 | 0;
	                f = b + 16 | 0;
	                g = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    h[d >> 3] = +h[15984];
	                    j = +h[d >> 3];
	                    i = b;
	                    return +j
	                } else {
	                    c[f >> 2] = Cr(c[e >> 2] | 0) | 0;
	                    h[g >> 3] = +Er(c[f >> 2] | 0);
	                    zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                    h[d >> 3] = +h[g >> 3];
	                    j = +h[d >> 3];
	                    i = b;
	                    return +j
	                }
	                return +(0.0)
	            }

	            function Ir(a) {
	                a = +a;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b;
	                h[e >> 3] = a;
	                f = (Lq(+h[e >> 3]) | 0) != 0;
	                if (f | +h[e >> 3] == 0.0) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    c[d >> 2] = 1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function Jr(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                if ((c[e >> 2] | 0) != 0 ? (xy(c[e >> 2] | 0) | 0) != 0 : 0)c[d >> 2] = 1; else c[d >> 2] = 0;
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function Kr(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                if ((c[e >> 2] | 0) != 0 ? (c[c[e >> 2] >> 2] | 0) != 0 : 0)c[d >> 2] = 1; else c[d >> 2] = 0;
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function Lr(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](204) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    it(0, 129096);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    cU(c[f >> 2] | 0, 0, 204) | 0;
	                    c[c[f >> 2] >> 2] = c[e >> 2];
	                    c[(c[f >> 2] | 0) + 4 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 16 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 20 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 24 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 28 >> 2] = 0;
	                    e = Ij(0) | 0;
	                    c[(c[f >> 2] | 0) + 40 >> 2] = e;
	                    c[(c[f >> 2] | 0) + 44 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 48 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 52 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 88 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 64 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 68 >> 2] = -1;
	                    c[(c[f >> 2] | 0) + 72 >> 2] = -1;
	                    Mr(c[f >> 2] | 0);
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function Mr(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                jr(c[d >> 2] | 0, 129592, 261) | 0;
	                jr(c[d >> 2] | 0, 129600, 262) | 0;
	                jr(c[d >> 2] | 0, 129608, 263) | 0;
	                jr(c[d >> 2] | 0, 129616, 264) | 0;
	                jr(c[d >> 2] | 0, 129624, 265) | 0;
	                jr(c[d >> 2] | 0, 129640, 266) | 0;
	                jr(c[d >> 2] | 0, 129008, 267) | 0;
	                jr(c[d >> 2] | 0, 129648, 268) | 0;
	                jr(c[d >> 2] | 0, 129656, 269) | 0;
	                jr(c[d >> 2] | 0, 129664, 270) | 0;
	                jr(c[d >> 2] | 0, 129672, 271) | 0;
	                jr(c[d >> 2] | 0, 129688, 272) | 0;
	                jr(c[d >> 2] | 0, 129696, 273) | 0;
	                jr(c[d >> 2] | 0, 129704, 274) | 0;
	                jr(c[d >> 2] | 0, 129720, 275) | 0;
	                jr(c[d >> 2] | 0, 129736, 276) | 0;
	                jr(c[d >> 2] | 0, 129744, 277) | 0;
	                jr(c[d >> 2] | 0, 129760, 278) | 0;
	                jr(c[d >> 2] | 0, 129768, 279) | 0;
	                jr(c[d >> 2] | 0, 129776, 280) | 0;
	                jr(c[d >> 2] | 0, 129792, 281) | 0;
	                jr(c[d >> 2] | 0, 129808, 282) | 0;
	                jr(c[d >> 2] | 0, 129824, 283) | 0;
	                jr(c[d >> 2] | 0, 129848, 284) | 0;
	                jr(c[d >> 2] | 0, 129864, 285) | 0;
	                jr(c[d >> 2] | 0, 129e3, 286) | 0;
	                jr(c[d >> 2] | 0, 129872, 287) | 0;
	                kr(c[d >> 2] | 0, 129888, 129904, 288) | 0;
	                i = b;
	                return
	            }

	            function Nr(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 200 >> 2] | 0)ht(c[(c[d >> 2] | 0) + 200 >> 2] | 0);
	                tr(c[d >> 2] | 0);
	                nr(c[d >> 2] | 0);
	                qr(c[d >> 2] | 0);
	                Yd((c[d >> 2] | 0) + 136 | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function Or(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = Cb[c[135744 >> 2] & 511](48) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    it(c[g >> 2] | 0, 129120);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                b = (c[h >> 2] | 0) + 0 | 0;
	                a = b + 48 | 0;
	                do {
	                    c[b >> 2] = 0;
	                    b = b + 4 | 0
	                } while ((b | 0) < (a | 0));
	                b = c[f >> 2] | 0;
	                c[(c[h >> 2] | 0) + 4 >> 2] = b;
	                c[c[h >> 2] >> 2] = b;
	                c[(c[h >> 2] | 0) + 12 >> 2] = c[g >> 2];
	                b = pt() | 0;
	                c[(c[h >> 2] | 0) + 32 >> 2] = b;
	                if (!(c[(c[h >> 2] | 0) + 32 >> 2] | 0)) {
	                    zb[c[135736 >> 2] & 511](c[(c[h >> 2] | 0) + 28 >> 2] | 0);
	                    zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 192 >> 2] | 0) != 0 : 0) {
	                    c[(c[(c[h >> 2] | 0) + 32 >> 2] | 0) + 20 >> 2] = c[(c[g >> 2] | 0) + 192 >> 2];
	                    yP(c[(c[(c[h >> 2] | 0) + 32 >> 2] | 0) + 20 >> 2] | 0) | 0
	                }
	                c[e >> 2] = c[h >> 2];
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function Pr(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (c[(c[d >> 2] | 0) + 28 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 28 >> 2] | 0);
	                if (!(c[(c[d >> 2] | 0) + 32 >> 2] | 0)) {
	                    e = c[33934] | 0;
	                    f = c[d >> 2] | 0;
	                    zb[e & 511](f);
	                    i = b;
	                    return
	                }
	                if (c[(c[(c[d >> 2] | 0) + 32 >> 2] | 0) + 24 >> 2] | 0) {
	                    FQ(c[(c[(c[d >> 2] | 0) + 32 >> 2] | 0) + 24 >> 2] | 0);
	                    c[(c[(c[d >> 2] | 0) + 32 >> 2] | 0) + 24 >> 2] = 0
	                }
	                Pq(c[(c[d >> 2] | 0) + 32 >> 2] | 0);
	                e = c[33934] | 0;
	                f = c[d >> 2] | 0;
	                zb[e & 511](f);
	                i = b;
	                return
	            }

	            function Qr(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b;
	                e = b + 28 | 0;
	                f = b + 24 | 0;
	                g = b + 20 | 0;
	                j = b + 16 | 0;
	                k = b + 12 | 0;
	                l = b + 8 | 0;
	                c[f >> 2] = a;
	                c[l >> 2] = 0;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                    c[j >> 2] = Sq(c[f >> 2] | 0) | 0;
	                    c[g >> 2] = Sq(c[f >> 2] | 0) | 0;
	                    a = c[g >> 2] | 0;
	                    if ((c[g >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                        m = c[(c[f >> 2] | 0) + 12 >> 2] | 0;
	                        if (a)jt(m, c[g >> 2] | 0); else jt(m, c[j >> 2] | 0);
	                        Nq(c[f >> 2] | 0, 10);
	                        c[e >> 2] = 0;
	                        n = c[e >> 2] | 0;
	                        i = b;
	                        return n | 0
	                    }
	                    if ((a | 0) == (c[j >> 2] | 0)) {
	                        Qq(c[g >> 2] | 0);
	                        c[e >> 2] = 1;
	                        n = c[e >> 2] | 0;
	                        i = b;
	                        return n | 0
	                    }
	                    if ((((c[c[j >> 2] >> 2] | 0) != 1 ? (c[c[j >> 2] >> 2] | 0) != 9 : 0) ? (c[c[g >> 2] >> 2] | 0) != 1 : 0) ? (c[c[g >> 2] >> 2] | 0) != 9 : 0) {
	                        c[e >> 2] = tt(c[f >> 2] | 0, c[g >> 2] | 0, c[j >> 2] | 0) | 0;
	                        n = c[e >> 2] | 0;
	                        i = b;
	                        return n | 0
	                    }
	                    if ((c[c[g >> 2] >> 2] | 0) != 1 ? (c[c[g >> 2] >> 2] | 0) != 9 : 0) {
	                        c[k >> 2] = c[j >> 2];
	                        c[j >> 2] = c[g >> 2];
	                        c[g >> 2] = c[k >> 2]
	                    }
	                    switch (c[c[j >> 2] >> 2] | 0) {
	                        case 2:
	                        {
	                            if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 4 >> 2] >> 2] | 0) != 0 : 0)c[l >> 2] = 1; else c[l >> 2] = 0;
	                            c[l >> 2] = (c[l >> 2] | 0) == (c[(c[j >> 2] | 0) + 8 >> 2] | 0) & 1;
	                            break
	                        }
	                        case 3:
	                        {
	                            c[l >> 2] = rt(c[f >> 2] | 0, c[g >> 2] | 0, +h[(c[j >> 2] | 0) + 16 >> 3], 0) | 0;
	                            break
	                        }
	                        case 4:
	                        {
	                            c[l >> 2] = st(c[g >> 2] | 0, c[(c[j >> 2] | 0) + 24 >> 2] | 0, 0) | 0;
	                            break
	                        }
	                        case 6:
	                        case 5:
	                        case 8:
	                        case 7:
	                        {
	                            k = c[33976] | 0;
	                            a = c[33980] | 0;
	                            c[d >> 2] = 128552;
	                            c[d + 4 >> 2] = 7204;
	                            Db[k & 511](a, 129064, d);
	                            break
	                        }
	                        case 9:
	                        case 1:
	                        {
	                            c[l >> 2] = qt(c[g >> 2] | 0, c[j >> 2] | 0, 0) | 0;
	                            break
	                        }
	                        default:
	                        {
	                        }
	                    }
	                    jt(c[(c[f >> 2] | 0) + 12 >> 2] | 0, c[g >> 2] | 0);
	                    jt(c[(c[f >> 2] | 0) + 12 >> 2] | 0, c[j >> 2] | 0);
	                    c[e >> 2] = c[l >> 2];
	                    n = c[e >> 2] | 0;
	                    i = b;
	                    return n | 0
	                }
	                c[e >> 2] = 0;
	                n = c[e >> 2] | 0;
	                i = b;
	                return n | 0
	            }

	            function Rr(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b;
	                e = b + 28 | 0;
	                f = b + 24 | 0;
	                g = b + 20 | 0;
	                j = b + 16 | 0;
	                k = b + 12 | 0;
	                l = b + 8 | 0;
	                c[f >> 2] = a;
	                c[l >> 2] = 0;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                    c[j >> 2] = Sq(c[f >> 2] | 0) | 0;
	                    c[g >> 2] = Sq(c[f >> 2] | 0) | 0;
	                    a = c[g >> 2] | 0;
	                    if ((c[g >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                        m = c[(c[f >> 2] | 0) + 12 >> 2] | 0;
	                        if (a)jt(m, c[g >> 2] | 0); else jt(m, c[j >> 2] | 0);
	                        Nq(c[f >> 2] | 0, 10);
	                        c[e >> 2] = 0;
	                        n = c[e >> 2] | 0;
	                        i = b;
	                        return n | 0
	                    }
	                    if ((a | 0) == (c[j >> 2] | 0)) {
	                        jt(c[(c[f >> 2] | 0) + 12 >> 2] | 0, c[g >> 2] | 0);
	                        c[e >> 2] = 0;
	                        n = c[e >> 2] | 0;
	                        i = b;
	                        return n | 0
	                    }
	                    if ((((c[c[j >> 2] >> 2] | 0) != 1 ? (c[c[j >> 2] >> 2] | 0) != 9 : 0) ? (c[c[g >> 2] >> 2] | 0) != 1 : 0) ? (c[c[g >> 2] >> 2] | 0) != 9 : 0) {
	                        c[e >> 2] = ((tt(c[f >> 2] | 0, c[g >> 2] | 0, c[j >> 2] | 0) | 0) != 0 ^ 1) & 1;
	                        n = c[e >> 2] | 0;
	                        i = b;
	                        return n | 0
	                    }
	                    if ((c[c[g >> 2] >> 2] | 0) != 1 ? (c[c[g >> 2] >> 2] | 0) != 9 : 0) {
	                        c[k >> 2] = c[j >> 2];
	                        c[j >> 2] = c[g >> 2];
	                        c[g >> 2] = c[k >> 2]
	                    }
	                    switch (c[c[j >> 2] >> 2] | 0) {
	                        case 2:
	                        {
	                            if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 4 >> 2] >> 2] | 0) != 0 : 0)c[l >> 2] = 1; else c[l >> 2] = 0;
	                            c[l >> 2] = (c[l >> 2] | 0) != (c[(c[j >> 2] | 0) + 8 >> 2] | 0) & 1;
	                            break
	                        }
	                        case 4:
	                        {
	                            c[l >> 2] = st(c[g >> 2] | 0, c[(c[j >> 2] | 0) + 24 >> 2] | 0, 1) | 0;
	                            break
	                        }
	                        case 3:
	                        {
	                            c[l >> 2] = rt(c[f >> 2] | 0, c[g >> 2] | 0, +h[(c[j >> 2] | 0) + 16 >> 3], 1) | 0;
	                            break
	                        }
	                        case 6:
	                        case 5:
	                        case 8:
	                        case 7:
	                        {
	                            k = c[33976] | 0;
	                            a = c[33980] | 0;
	                            c[d >> 2] = 128552;
	                            c[d + 4 >> 2] = 7289;
	                            Db[k & 511](a, 129064, d);
	                            break
	                        }
	                        case 9:
	                        case 1:
	                        {
	                            c[l >> 2] = qt(c[g >> 2] | 0, c[j >> 2] | 0, 1) | 0;
	                            break
	                        }
	                        default:
	                        {
	                        }
	                    }
	                    jt(c[(c[f >> 2] | 0) + 12 >> 2] | 0, c[g >> 2] | 0);
	                    jt(c[(c[f >> 2] | 0) + 12 >> 2] | 0, c[j >> 2] | 0);
	                    c[e >> 2] = c[l >> 2];
	                    n = c[e >> 2] | 0;
	                    i = b;
	                    return n | 0
	                }
	                c[e >> 2] = 0;
	                n = c[e >> 2] | 0;
	                i = b;
	                return n | 0
	            }

	            function Sr(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 32 | 0;
	                g = e + 28 | 0;
	                j = e + 24 | 0;
	                k = e + 20 | 0;
	                l = e + 16 | 0;
	                m = e + 12 | 0;
	                n = e + 8 | 0;
	                o = e + 4 | 0;
	                p = e;
	                c[g >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = 0;
	                c[m >> 2] = 0;
	                c[n >> 2] = 0;
	                if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                    c[p >> 2] = Sq(c[g >> 2] | 0) | 0;
	                    c[o >> 2] = Sq(c[g >> 2] | 0) | 0;
	                    if ((c[o >> 2] | 0) == 0 | (c[p >> 2] | 0) == 0) {
	                        d = c[(c[g >> 2] | 0) + 12 >> 2] | 0;
	                        if (c[o >> 2] | 0)jt(d, c[o >> 2] | 0); else jt(d, c[p >> 2] | 0);
	                        Nq(c[g >> 2] | 0, 10);
	                        c[f >> 2] = 0;
	                        q = c[f >> 2] | 0;
	                        i = e;
	                        return q | 0
	                    }
	                    if ((((c[c[p >> 2] >> 2] | 0) != 1 ? (c[c[p >> 2] >> 2] | 0) != 9 : 0) ? (c[c[o >> 2] >> 2] | 0) != 1 : 0) ? (c[c[o >> 2] >> 2] | 0) != 9 : 0) {
	                        if ((c[c[o >> 2] >> 2] | 0) != 3) {
	                            Tq(c[g >> 2] | 0, c[o >> 2] | 0) | 0;
	                            Tr(c[g >> 2] | 0, 1);
	                            c[o >> 2] = Sq(c[g >> 2] | 0) | 0
	                        }
	                        if ((c[c[o >> 2] >> 2] | 0) != 3) {
	                            Qq(c[o >> 2] | 0);
	                            Qq(c[p >> 2] | 0);
	                            Nq(c[g >> 2] | 0, 10);
	                            c[f >> 2] = 0;
	                            q = c[f >> 2] | 0;
	                            i = e;
	                            return q | 0
	                        }
	                        if ((c[c[p >> 2] >> 2] | 0) != 3) {
	                            Tq(c[g >> 2] | 0, c[p >> 2] | 0) | 0;
	                            Tr(c[g >> 2] | 0, 1);
	                            c[p >> 2] = Sq(c[g >> 2] | 0) | 0
	                        }
	                        if ((c[c[p >> 2] >> 2] | 0) != 3) {
	                            jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[o >> 2] | 0);
	                            jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[p >> 2] | 0);
	                            Nq(c[g >> 2] | 0, 10);
	                            c[f >> 2] = 0;
	                            q = c[f >> 2] | 0;
	                            i = e;
	                            return q | 0
	                        }
	                        a:do if ((Lq(+h[(c[o >> 2] | 0) + 16 >> 3]) | 0) == 0 ? (Lq(+h[(c[p >> 2] | 0) + 16 >> 3]) | 0) == 0 : 0) {
	                            c[m >> 2] = Mq(+h[(c[o >> 2] | 0) + 16 >> 3]) | 0;
	                            c[n >> 2] = Mq(+h[(c[p >> 2] | 0) + 16 >> 3]) | 0;
	                            if ((c[j >> 2] | 0) != 0 & (c[k >> 2] | 0) != 0) {
	                                do if (!((c[m >> 2] | 0) == -1 & (c[n >> 2] | 0) != -1)) {
	                                    if ((c[n >> 2] | 0) == 1 & (c[m >> 2] | 0) != 1)break;
	                                    if ((c[m >> 2] | 0) == 0 & (c[n >> 2] | 0) == 0) {
	                                        c[l >> 2] = +h[(c[o >> 2] | 0) + 16 >> 3] < +h[(c[p >> 2] | 0) + 16 >> 3] & 1;
	                                        break a
	                                    } else {
	                                        c[l >> 2] = 0;
	                                        break a
	                                    }
	                                } while (0);
	                                c[l >> 2] = 1;
	                                break
	                            }
	                            if (!((c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) != 0)) {
	                                if ((c[m >> 2] | 0) == -1 | (c[n >> 2] | 0) == 1) {
	                                    c[l >> 2] = 1;
	                                    break
	                                }
	                                if ((c[m >> 2] | 0) == 0 & (c[n >> 2] | 0) == 0) {
	                                    c[l >> 2] = +h[(c[o >> 2] | 0) + 16 >> 3] <= +h[(c[p >> 2] | 0) + 16 >> 3] & 1;
	                                    break
	                                } else {
	                                    c[l >> 2] = 0;
	                                    break
	                                }
	                            }
	                            if (!((c[j >> 2] | 0) == 0 & (c[k >> 2] | 0) != 0)) {
	                                if ((c[j >> 2] | 0) != 0 | (c[k >> 2] | 0) != 0)break;
	                                if ((c[m >> 2] | 0) == 1 | (c[n >> 2] | 0) == -1) {
	                                    c[l >> 2] = 1;
	                                    break
	                                }
	                                if ((c[m >> 2] | 0) == 0 & (c[n >> 2] | 0) == 0) {
	                                    c[l >> 2] = +h[(c[o >> 2] | 0) + 16 >> 3] >= +h[(c[p >> 2] | 0) + 16 >> 3] & 1;
	                                    break
	                                } else {
	                                    c[l >> 2] = 0;
	                                    break
	                                }
	                            } else {
	                                do if (!((c[m >> 2] | 0) == 1 & (c[n >> 2] | 0) != 1)) {
	                                    if ((c[n >> 2] | 0) == -1 & (c[m >> 2] | 0) != -1)break;
	                                    if ((c[m >> 2] | 0) == 0 & (c[n >> 2] | 0) == 0) {
	                                        c[l >> 2] = +h[(c[o >> 2] | 0) + 16 >> 3] > +h[(c[p >> 2] | 0) + 16 >> 3] & 1;
	                                        break a
	                                    } else {
	                                        c[l >> 2] = 0;
	                                        break a
	                                    }
	                                } while (0);
	                                c[l >> 2] = 1;
	                                break
	                            }
	                        } else r = 33; while (0);
	                        if ((r | 0) == 33)c[l >> 2] = 0;
	                        jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[o >> 2] | 0);
	                        jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[p >> 2] | 0);
	                        c[f >> 2] = c[l >> 2];
	                        q = c[f >> 2] | 0;
	                        i = e;
	                        return q | 0
	                    }
	                    if ((c[c[p >> 2] >> 2] | 0) != 1 ? (c[c[p >> 2] >> 2] | 0) != 9 : 0)r = 18; else r = 15;
	                    do if ((r | 0) == 15) {
	                        if ((c[c[o >> 2] >> 2] | 0) != 1 ? (c[c[o >> 2] >> 2] | 0) != 9 : 0) {
	                            r = 18;
	                            break
	                        }
	                        c[l >> 2] = ut(c[j >> 2] | 0, c[k >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0) | 0
	                    } while (0);
	                    do if ((r | 0) == 18) {
	                        if ((c[c[o >> 2] >> 2] | 0) != 1 ? (c[c[o >> 2] >> 2] | 0) != 9 : 0) {
	                            c[l >> 2] = vt(c[g >> 2] | 0, ((c[j >> 2] | 0) != 0 ^ 1) & 1, c[k >> 2] | 0, c[p >> 2] | 0, c[o >> 2] | 0) | 0;
	                            break
	                        }
	                        c[l >> 2] = vt(c[g >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0) | 0
	                    } while (0);
	                    c[f >> 2] = c[l >> 2];
	                    q = c[f >> 2] | 0;
	                    i = e;
	                    return q | 0
	                }
	                c[f >> 2] = 0;
	                q = c[f >> 2] | 0;
	                i = e;
	                return q | 0
	            }

	            function Tr(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                j = d;
	                k = d + 8 | 0;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if (!(c[f >> 2] | 0)) {
	                    a = c[e >> 2] | 0;
	                    if (!(c[(c[b + 12 >> 2] | 0) + 4 >> 2] | 0)) {
	                        Tq(a, wt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, 0.0) | 0) | 0;
	                        i = d;
	                        return
	                    } else {
	                        c[k >> 2] = _i(c[(c[a + 12 >> 2] | 0) + 4 >> 2] | 0) | 0;
	                        h[j >> 3] = +Fr(c[k >> 2] | 0);
	                        a = c[e >> 2] | 0;
	                        Tq(a, wt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, +h[j >> 3]) | 0) | 0;
	                        zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                        i = d;
	                        return
	                    }
	                }
	                if (!b) {
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if ((c[f >> 2] | 0) != 1) {
	                    Nq(b, 12);
	                    i = d;
	                    return
	                }
	                f = c[e >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 1 | 0)) {
	                    Nq(f, 23);
	                    i = d;
	                    return
	                } else {
	                    c[g >> 2] = Sq(f) | 0;
	                    f = c[e >> 2] | 0;
	                    Tq(f, xt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[g >> 2] | 0) | 0) | 0;
	                    i = d;
	                    return
	                }
	            }

	            function Ur(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0.0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (!(c[(c[d >> 2] | 0) + 12 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if ((c[(c[d >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[d >> 2] | 0) + 16 >> 2] >> 2] | 0) != 3 : 0)Tr(c[d >> 2] | 0, 1);
	                if ((c[(c[d >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[d >> 2] | 0) + 16 >> 2] >> 2] | 0) == 3 : 0) {
	                    if (Lq(+h[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3]) | 0) {
	                        h[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] = +h[15984];
	                        i = b;
	                        return
	                    }
	                    if ((Mq(+h[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3]) | 0) == 1) {
	                        h[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] = +h[15986];
	                        i = b;
	                        return
	                    }
	                    if ((Mq(+h[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3]) | 0) == -1) {
	                        h[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] = +h[15985];
	                        i = b;
	                        return
	                    }
	                    e = +h[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3];
	                    if (!(+h[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] == 0.0)) {
	                        h[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] = -e;
	                        i = b;
	                        return
	                    }
	                    if (!(et(e) | 0)) {
	                        h[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] = +h[15988];
	                        i = b;
	                        return
	                    } else {
	                        h[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] = 0.0;
	                        i = b;
	                        return
	                    }
	                }
	                Nq(c[d >> 2] | 0, 11);
	                i = b;
	                return
	            }

	            function Vr(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b;
	                c[d >> 2] = a;
	                c[e >> 2] = Sq(c[d >> 2] | 0) | 0;
	                if (!(c[e >> 2] | 0)) {
	                    Nq(c[d >> 2] | 0, 10);
	                    i = b;
	                    return
	                }
	                h[f >> 3] = +Wq(c[e >> 2] | 0);
	                jt(c[(c[d >> 2] | 0) + 12 >> 2] | 0, c[e >> 2] | 0);
	                if ((c[(c[d >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[d >> 2] | 0) + 16 >> 2] >> 2] | 0) != 3 : 0)Tr(c[d >> 2] | 0, 1);
	                if ((c[(c[d >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[d >> 2] | 0) + 16 >> 2] >> 2] | 0) == 3 : 0) {
	                    e = (c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 | 0;
	                    h[e >> 3] = +h[e >> 3] + +h[f >> 3];
	                    i = b;
	                    return
	                }
	                Nq(c[d >> 2] | 0, 11);
	                i = b;
	                return
	            }

	            function Wr(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b;
	                c[d >> 2] = a;
	                c[e >> 2] = Sq(c[d >> 2] | 0) | 0;
	                if (!(c[e >> 2] | 0)) {
	                    Nq(c[d >> 2] | 0, 10);
	                    i = b;
	                    return
	                }
	                h[f >> 3] = +Wq(c[e >> 2] | 0);
	                jt(c[(c[d >> 2] | 0) + 12 >> 2] | 0, c[e >> 2] | 0);
	                if ((c[(c[d >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[d >> 2] | 0) + 16 >> 2] >> 2] | 0) != 3 : 0)Tr(c[d >> 2] | 0, 1);
	                if ((c[(c[d >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[d >> 2] | 0) + 16 >> 2] >> 2] | 0) == 3 : 0) {
	                    e = (c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 | 0;
	                    h[e >> 3] = +h[e >> 3] - +h[f >> 3];
	                    i = b;
	                    return
	                }
	                Nq(c[d >> 2] | 0, 11);
	                i = b;
	                return
	            }

	            function Xr(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b;
	                c[d >> 2] = a;
	                c[e >> 2] = Sq(c[d >> 2] | 0) | 0;
	                if (!(c[e >> 2] | 0)) {
	                    Nq(c[d >> 2] | 0, 10);
	                    i = b;
	                    return
	                }
	                h[f >> 3] = +Wq(c[e >> 2] | 0);
	                jt(c[(c[d >> 2] | 0) + 12 >> 2] | 0, c[e >> 2] | 0);
	                if ((c[(c[d >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[d >> 2] | 0) + 16 >> 2] >> 2] | 0) != 3 : 0)Tr(c[d >> 2] | 0, 1);
	                if ((c[(c[d >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[d >> 2] | 0) + 16 >> 2] >> 2] | 0) == 3 : 0) {
	                    e = (c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 | 0;
	                    h[e >> 3] = +h[e >> 3] * +h[f >> 3];
	                    i = b;
	                    return
	                }
	                Nq(c[d >> 2] | 0, 11);
	                i = b;
	                return
	            }

	            function Yr(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b;
	                c[d >> 2] = a;
	                c[e >> 2] = Sq(c[d >> 2] | 0) | 0;
	                if (!(c[e >> 2] | 0)) {
	                    Nq(c[d >> 2] | 0, 10);
	                    i = b;
	                    return
	                }
	                h[f >> 3] = +Wq(c[e >> 2] | 0);
	                jt(c[(c[d >> 2] | 0) + 12 >> 2] | 0, c[e >> 2] | 0);
	                if ((c[(c[d >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[d >> 2] | 0) + 16 >> 2] >> 2] | 0) != 3 : 0)Tr(c[d >> 2] | 0, 1);
	                if ((c[(c[d >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[d >> 2] | 0) + 16 >> 2] >> 2] | 0) == 3 : 0) {
	                    if ((Lq(+h[f >> 3]) | 0) == 0 ? (Lq(+h[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3]) | 0) == 0 : 0) {
	                        if (+h[f >> 3] == 0.0 ? (et(+h[f >> 3]) | 0) != 0 : 0) {
	                            if (+h[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] == 0.0) {
	                                h[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] = +h[15984];
	                                i = b;
	                                return
	                            }
	                            if (+h[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] > 0.0) {
	                                h[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] = +h[15986];
	                                i = b;
	                                return
	                            }
	                            if (!(+h[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] < 0.0)) {
	                                i = b;
	                                return
	                            }
	                            h[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] = +h[15985];
	                            i = b;
	                            return
	                        }
	                        if (!(+h[f >> 3] == 0.0)) {
	                            e = (c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 | 0;
	                            h[e >> 3] = +h[e >> 3] / +h[f >> 3];
	                            i = b;
	                            return
	                        }
	                        if (+h[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] == 0.0) {
	                            h[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] = +h[15984];
	                            i = b;
	                            return
	                        }
	                        if (+h[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] > 0.0) {
	                            h[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] = +h[15985];
	                            i = b;
	                            return
	                        }
	                        if (!(+h[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] < 0.0)) {
	                            i = b;
	                            return
	                        }
	                        h[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] = +h[15986];
	                        i = b;
	                        return
	                    }
	                    h[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] = +h[15984];
	                    i = b;
	                    return
	                }
	                Nq(c[d >> 2] | 0, 11);
	                i = b;
	                return
	            }

	            function Zr(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, j = 0.0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 20 | 0;
	                e = b + 16 | 0;
	                f = b + 8 | 0;
	                g = b;
	                c[d >> 2] = a;
	                c[e >> 2] = Sq(c[d >> 2] | 0) | 0;
	                if (!(c[e >> 2] | 0)) {
	                    Nq(c[d >> 2] | 0, 10);
	                    i = b;
	                    return
	                }
	                h[g >> 3] = +Wq(c[e >> 2] | 0);
	                jt(c[(c[d >> 2] | 0) + 12 >> 2] | 0, c[e >> 2] | 0);
	                if ((c[(c[d >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[d >> 2] | 0) + 16 >> 2] >> 2] | 0) != 3 : 0)Tr(c[d >> 2] | 0, 1);
	                if ((c[(c[d >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[d >> 2] | 0) + 16 >> 2] >> 2] | 0) == 3 : 0) {
	                    h[f >> 3] = +h[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3];
	                    if (+h[g >> 3] == 0.0) {
	                        h[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] = +h[15984];
	                        i = b;
	                        return
	                    } else {
	                        j = +uT(+h[f >> 3], +h[g >> 3]);
	                        h[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] = j;
	                        i = b;
	                        return
	                    }
	                }
	                Nq(c[d >> 2] | 0, 11);
	                i = b;
	                return
	            }

	            function _r(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                do if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 12 >> 2] | 0) != 0 : 0)if (!(c[g >> 2] | 0)) {
	                    c[e >> 2] = c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2];
	                    break
	                } else {
	                    c[e >> 2] = 0;
	                    break
	                } else h = 3; while (0);
	                if ((h | 0) == 3)c[e >> 2] = 0;
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function $r(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                a:do if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                    if (c[g >> 2] | 0) {
	                        if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 9 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 13 : 0) {
	                            c[e >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                            break
	                        }
	                        c[e >> 2] = 0;
	                        break
	                    }
	                    if (!(c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        break
	                    }
	                    switch (c[(c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) + 4 >> 2] | 0) {
	                        case 20:
	                        case 19:
	                        case 18:
	                        case 2:
	                        case 17:
	                        case 16:
	                        case 15:
	                        {
	                            c[e >> 2] = 0;
	                            break a;
	                            break
	                        }
	                        case 14:
	                        case 12:
	                        case 8:
	                        case 7:
	                        case 6:
	                        case 5:
	                        case 4:
	                        case 3:
	                        case 1:
	                        {
	                            c[e >> 2] = c[(c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) + 12 >> 2];
	                            break a;
	                            break
	                        }
	                        case 21:
	                        case 13:
	                        case 11:
	                        case 10:
	                        case 9:
	                        {
	                            c[e >> 2] = c[(c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) + 12 >> 2];
	                            break a;
	                            break
	                        }
	                        default:
	                        {
	                            c[e >> 2] = 0;
	                            break a
	                        }
	                    }
	                } else h = 3; while (0);
	                if ((h | 0) == 3)c[e >> 2] = 0;
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function as(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                    if (!(c[g >> 2] | 0)) {
	                        if (!(c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0)) {
	                            c[e >> 2] = 0;
	                            h = c[e >> 2] | 0;
	                            i = d;
	                            return h | 0
	                        }
	                        if ((c[(c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) + 4 >> 2] | 0) != 2 ? (c[(c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                            b = c[(c[f >> 2] | 0) + 12 >> 2] | 0;
	                            if ((c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) == (c[c[(c[f >> 2] | 0) + 12 >> 2] >> 2] | 0)) {
	                                c[e >> 2] = c[(c[b >> 2] | 0) + 12 >> 2];
	                                h = c[e >> 2] | 0;
	                                i = d;
	                                return h | 0
	                            } else {
	                                c[e >> 2] = c[(c[b + 4 >> 2] | 0) + 12 >> 2];
	                                h = c[e >> 2] | 0;
	                                i = d;
	                                return h | 0
	                            }
	                        }
	                        c[e >> 2] = 0;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 18) {
	                        c[e >> 2] = 0;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                    if (((c[(c[g >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) != 17 : 0) ? (c[g >> 2] = c[(c[g >> 2] | 0) + 12 >> 2], (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 14) : 0) {
	                        c[e >> 2] = c[g >> 2];
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                    if ((c[g >> 2] | 0) == (c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                    while (1) {
	                        if (!(c[(c[g >> 2] | 0) + 24 >> 2] | 0))break;
	                        c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                        if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 17)continue;
	                        if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 14) {
	                            j = 24;
	                            break
	                        }
	                    }
	                    if ((j | 0) == 24) {
	                        c[e >> 2] = c[g >> 2];
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                    while (1) {
	                        c[g >> 2] = c[(c[g >> 2] | 0) + 20 >> 2];
	                        if (!(c[g >> 2] | 0)) {
	                            j = 31;
	                            break
	                        }
	                        if ((c[g >> 2] | 0) == (c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0)) {
	                            j = 27;
	                            break
	                        }
	                        k = c[g >> 2] | 0;
	                        if (c[(c[g >> 2] | 0) + 24 >> 2] | 0) {
	                            j = 29;
	                            break
	                        }
	                        if (!k) {
	                            j = 31;
	                            break
	                        }
	                    }
	                    if ((j | 0) == 27) {
	                        c[e >> 2] = 0;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    } else if ((j | 0) == 29) {
	                        c[g >> 2] = c[k + 24 >> 2];
	                        c[e >> 2] = c[g >> 2];
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    } else if ((j | 0) == 31) {
	                        c[e >> 2] = c[g >> 2];
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                }
	                c[e >> 2] = 0;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function bs(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                    b = c[f >> 2] | 0;
	                    if (c[g >> 2] | 0) {
	                        c[e >> 2] = as(b, c[g >> 2] | 0) | 0;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                    if (!(c[(c[b + 12 >> 2] | 0) + 4 >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                    if ((c[(c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) + 4 >> 2] | 0) != 2 ? (c[(c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                        c[e >> 2] = c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2];
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                c[e >> 2] = 0;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function cs(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                    a:do if (!(c[h >> 2] | 0)) {
	                        if (!(c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0)) {
	                            c[f >> 2] = 0;
	                            l = c[f >> 2] | 0;
	                            i = e;
	                            return l | 0
	                        }
	                        switch (c[(c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) + 4 >> 2] | 0) {
	                            case 2:
	                            {
	                                c[j >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2];
	                                c[f >> 2] = c[(c[j >> 2] | 0) + 20 >> 2];
	                                l = c[f >> 2] | 0;
	                                i = e;
	                                return l | 0
	                            }
	                            case 21:
	                            case 13:
	                            case 11:
	                            case 10:
	                            case 9:
	                            {
	                                c[f >> 2] = 0;
	                                l = c[f >> 2] | 0;
	                                i = e;
	                                return l | 0
	                            }
	                            case 18:
	                            {
	                                c[k >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2];
	                                if ((c[c[k >> 2] >> 2] | 0) != 0 ? (c[(c[c[k >> 2] >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                                    c[f >> 2] = c[c[k >> 2] >> 2];
	                                    l = c[f >> 2] | 0;
	                                    i = e;
	                                    return l | 0
	                                }
	                                c[f >> 2] = 0;
	                                l = c[f >> 2] | 0;
	                                i = e;
	                                return l | 0
	                            }
	                            case 17:
	                            case 20:
	                            case 19:
	                            case 16:
	                            case 15:
	                            case 14:
	                            case 12:
	                            case 8:
	                            case 7:
	                            case 6:
	                            case 5:
	                            case 4:
	                            case 3:
	                            case 1:
	                            {
	                                b = c[(c[g >> 2] | 0) + 12 >> 2] | 0;
	                                if (!(c[(c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) + 20 >> 2] | 0)) {
	                                    c[f >> 2] = c[b >> 2];
	                                    l = c[f >> 2] | 0;
	                                    i = e;
	                                    return l | 0
	                                }
	                                do if ((c[(c[(c[b + 4 >> 2] | 0) + 20 >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                                    if ((d[c[(c[(c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] >> 0] | 0 | 0) != 32 ? (qy(c[(c[(c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0, 129152) | 0) == 0 : 0)break;
	                                    c[f >> 2] = 0;
	                                    l = c[f >> 2] | 0;
	                                    i = e;
	                                    return l | 0
	                                } while (0);
	                                c[f >> 2] = c[(c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) + 20 >> 2];
	                                l = c[f >> 2] | 0;
	                                i = e;
	                                return l | 0
	                            }
	                            default:
	                                break a
	                        }
	                    } while (0);
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[f >> 2] = 0;
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function ds(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 20 | 0;
	                h = e + 16 | 0;
	                j = e + 12 | 0;
	                k = e + 8 | 0;
	                l = e + 4 | 0;
	                m = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                a:do if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                    if (!(c[h >> 2] | 0)) {
	                        if (!(c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0)) {
	                            c[f >> 2] = 0;
	                            break
	                        }
	                        switch (c[(c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) + 4 >> 2] | 0) {
	                            case 2:
	                            {
	                                c[j >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2];
	                                c[f >> 2] = c[(c[j >> 2] | 0) + 20 >> 2];
	                                break a;
	                                break
	                            }
	                            case 18:
	                            {
	                                c[k >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2];
	                                if ((c[c[k >> 2] >> 2] | 0) != 0 ? (c[(c[c[k >> 2] >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                                    c[f >> 2] = c[c[k >> 2] >> 2];
	                                    break a
	                                }
	                                c[f >> 2] = 0;
	                                break a;
	                                break
	                            }
	                            case 20:
	                            case 19:
	                            case 12:
	                            case 17:
	                            case 16:
	                            case 15:
	                            case 14:
	                            case 8:
	                            case 7:
	                            case 6:
	                            case 5:
	                            case 4:
	                            case 3:
	                            case 1:
	                            {
	                                b = c[(c[g >> 2] | 0) + 12 >> 2] | 0;
	                                if (!(c[(c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) + 20 >> 2] | 0)) {
	                                    c[f >> 2] = c[b >> 2];
	                                    break a
	                                }
	                                do if ((c[(c[(c[b + 4 >> 2] | 0) + 20 >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                                    if ((d[c[(c[(c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] >> 0] | 0 | 0) != 32 ? (qy(c[(c[(c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0, 129152) | 0) == 0 : 0)break;
	                                    c[f >> 2] = 0;
	                                    break a
	                                } while (0);
	                                c[f >> 2] = c[(c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) + 20 >> 2];
	                                break a;
	                                break
	                            }
	                            case 21:
	                            case 13:
	                            case 11:
	                            case 10:
	                            case 9:
	                            {
	                                c[f >> 2] = 0;
	                                break a;
	                                break
	                            }
	                            default:
	                            {
	                                c[f >> 2] = 0;
	                                break a
	                            }
	                        }
	                    }
	                    if ((c[h >> 2] | 0) == (c[(c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2] | 0) + 12 >> 2] | 0)) {
	                        c[f >> 2] = c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2];
	                        break
	                    }
	                    if ((c[h >> 2] | 0) == (c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        break
	                    }
	                    switch (c[(c[h >> 2] | 0) + 4 >> 2] | 0) {
	                        case 21:
	                        case 13:
	                        case 11:
	                        case 10:
	                        case 9:
	                        {
	                            c[f >> 2] = 0;
	                            break a;
	                            break
	                        }
	                        case 18:
	                        {
	                            c[m >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2];
	                            if ((c[c[m >> 2] >> 2] | 0) != 0 ? (c[(c[c[m >> 2] >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                                c[f >> 2] = c[c[m >> 2] >> 2];
	                                break a
	                            }
	                            c[f >> 2] = 0;
	                            break a;
	                            break
	                        }
	                        case 20:
	                        case 19:
	                        case 17:
	                        case 16:
	                        case 15:
	                        case 14:
	                        case 12:
	                        case 8:
	                        case 7:
	                        case 6:
	                        case 5:
	                        case 4:
	                        case 3:
	                        case 1:
	                        {
	                            if (!(c[(c[h >> 2] | 0) + 20 >> 2] | 0)) {
	                                c[f >> 2] = 0;
	                                break a
	                            }
	                            do if ((c[(c[(c[h >> 2] | 0) + 20 >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                                if ((d[c[(c[(c[h >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] >> 0] | 0 | 0) != 32 ? (qy(c[(c[(c[h >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0, 129152) | 0) == 0 : 0)break;
	                                c[f >> 2] = 0;
	                                break a
	                            } while (0);
	                            c[f >> 2] = c[(c[h >> 2] | 0) + 20 >> 2];
	                            break a;
	                            break
	                        }
	                        case 2:
	                        {
	                            c[l >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2];
	                            c[f >> 2] = c[(c[l >> 2] | 0) + 20 >> 2];
	                            break a;
	                            break
	                        }
	                        default:
	                        {
	                            c[f >> 2] = 0;
	                            break a
	                        }
	                    }
	                } else n = 3; while (0);
	                if ((n | 0) == 3)c[f >> 2] = 0;
	                i = e;
	                return c[f >> 2] | 0
	            }

	            function es(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                    b = c[f >> 2] | 0;
	                    if (!(c[g >> 2] | 0)) {
	                        c[e >> 2] = c[(c[b + 12 >> 2] | 0) + 4 >> 2];
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    } else {
	                        c[e >> 2] = ds(b, c[g >> 2] | 0) | 0;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                }
	                c[e >> 2] = 0;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function fs(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                    if ((c[(c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) + 4 >> 2] | 0) != 2 ? (c[(c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                        if ((c[g >> 2] | 0) == (c[c[(c[f >> 2] | 0) + 12 >> 2] >> 2] | 0)) {
	                            c[e >> 2] = 0;
	                            h = c[e >> 2] | 0;
	                            i = d;
	                            return h | 0
	                        }
	                        if (!(c[g >> 2] | 0)) {
	                            c[e >> 2] = c[(c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) + 24 >> 2];
	                            h = c[e >> 2] | 0;
	                            i = d;
	                            return h | 0
	                        } else {
	                            c[e >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                            h = c[e >> 2] | 0;
	                            i = d;
	                            return h | 0
	                        }
	                    }
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                c[e >> 2] = 0;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function gs(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                    if ((c[(c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) + 4 >> 2] | 0) != 2 ? (c[(c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                        if ((c[g >> 2] | 0) == (c[c[(c[f >> 2] | 0) + 12 >> 2] >> 2] | 0)) {
	                            c[e >> 2] = 0;
	                            h = c[e >> 2] | 0;
	                            i = d;
	                            return h | 0
	                        }
	                        if (!(c[g >> 2] | 0)) {
	                            c[e >> 2] = c[(c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) + 28 >> 2];
	                            h = c[e >> 2] | 0;
	                            i = d;
	                            return h | 0
	                        }
	                        if (((c[(c[g >> 2] | 0) + 28 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 4 >> 2] | 0) == 14 : 0) ? (c[g >> 2] = c[(c[g >> 2] | 0) + 28 >> 2], (c[g >> 2] | 0) == 0) : 0) {
	                            c[e >> 2] = c[(c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) + 28 >> 2];
	                            h = c[e >> 2] | 0;
	                            i = d;
	                            return h | 0
	                        }
	                        c[e >> 2] = c[(c[g >> 2] | 0) + 28 >> 2];
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                c[e >> 2] = 0;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function hs(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                    if ((((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 2 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) ? (c[(c[g >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                        c[e >> 2] = c[(c[g >> 2] | 0) + 12 >> 2];
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                    do if (!(c[g >> 2] | 0)) {
	                        c[g >> 2] = c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2];
	                        if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 18) {
	                            c[e >> 2] = 0;
	                            h = c[e >> 2] | 0;
	                            i = d;
	                            return h | 0
	                        } else {
	                            if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 2)break;
	                            c[g >> 2] = c[(c[g >> 2] | 0) + 20 >> 2];
	                            break
	                        }
	                    } while (0);
	                    if (!(c[g >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                    if (c[(c[g >> 2] | 0) + 24 >> 2] | 0) {
	                        c[e >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                    while (1) {
	                        c[g >> 2] = c[(c[g >> 2] | 0) + 20 >> 2];
	                        if (!(c[g >> 2] | 0)) {
	                            j = 24;
	                            break
	                        }
	                        if ((c[g >> 2] | 0) == (c[c[(c[f >> 2] | 0) + 12 >> 2] >> 2] | 0)) {
	                            j = 20;
	                            break
	                        }
	                        k = c[g >> 2] | 0;
	                        if (c[(c[g >> 2] | 0) + 24 >> 2] | 0) {
	                            j = 22;
	                            break
	                        }
	                        if (!k) {
	                            j = 24;
	                            break
	                        }
	                    }
	                    if ((j | 0) == 20) {
	                        c[e >> 2] = 0;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    } else if ((j | 0) == 22) {
	                        c[e >> 2] = c[k + 24 >> 2];
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    } else if ((j | 0) == 24) {
	                        c[e >> 2] = c[g >> 2];
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                }
	                c[e >> 2] = 0;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function is(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                    if ((c[(c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) + 4 >> 2] | 0) != 1) {
	                        c[e >> 2] = 0;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                    if ((c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 120 >> 2] | 0) == 0 ? (c[g >> 2] | 0) != (c[32294] | 0) : 0) {
	                        if (c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 120 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 120 >> 2] | 0);
	                        g = bj(c[c[(c[f >> 2] | 0) + 12 >> 2] >> 2] | 0, c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) | 0;
	                        c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 120 >> 2] = g;
	                        c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 124 >> 2] = 0;
	                        a:do if (c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 120 >> 2] | 0)while (1) {
	                            if (!(c[(c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 120 >> 2] | 0) + (c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 124 >> 2] << 2) >> 2] | 0))break a;
	                            g = (c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 124 | 0;
	                            c[g >> 2] = (c[g >> 2] | 0) + 1
	                        } while (0);
	                        c[e >> 2] = c[32294];
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                    g = c[(c[f >> 2] | 0) + 12 >> 2] | 0;
	                    if ((c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 124 >> 2] | 0) > 0) {
	                        b = g + 124 | 0;
	                        a = (c[b >> 2] | 0) + -1 | 0;
	                        c[b >> 2] = a;
	                        c[e >> 2] = c[(c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 120 >> 2] | 0) + (a << 2) >> 2];
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                    if (c[g + 120 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 120 >> 2] | 0);
	                    c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 120 >> 2] = 0;
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                c[e >> 2] = 0;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function js(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                do if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                    if (!(c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        break
	                    }
	                    if ((c[(c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) + 4 >> 2] | 0) != 1) {
	                        c[e >> 2] = 0;
	                        break
	                    }
	                    if (c[g >> 2] | 0) {
	                        c[e >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                        break
	                    }
	                    if ((c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) == (c[c[(c[f >> 2] | 0) + 12 >> 2] >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        break
	                    } else {
	                        c[e >> 2] = c[(c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) + 44 >> 2];
	                        break
	                    }
	                } else h = 3; while (0);
	                if ((h | 0) == 3)c[e >> 2] = 0;
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function ks(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (!(c[(c[d >> 2] | 0) + 12 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                c[(c[(c[d >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[c[(c[d >> 2] | 0) + 12 >> 2] >> 2];
	                a = c[d >> 2] | 0;
	                Tq(a, yt(c[(c[d >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[d >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) | 0) | 0;
	                i = b;
	                return
	            }

	            function ls(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if (c[f >> 2] | 0) {
	                    Nq(b, 12);
	                    i = d;
	                    return
	                }
	                f = c[e >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 0 | 0)) {
	                    Nq(f, 23);
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if ((c[(c[f + 12 >> 2] | 0) + 68 >> 2] | 0) >= 0) {
	                    Tq(b, wt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, +(c[(c[(c[e >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] | 0)) | 0) | 0;
	                    i = d;
	                    return
	                } else {
	                    Nq(b, 13);
	                    i = d;
	                    return
	                }
	            }

	            function ms(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if (c[f >> 2] | 0) {
	                    Nq(b, 12);
	                    i = d;
	                    return
	                }
	                f = c[e >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 0 | 0)) {
	                    Nq(f, 23);
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if ((c[(c[f + 12 >> 2] | 0) + 72 >> 2] | 0) >= 0) {
	                    Tq(b, wt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, +(c[(c[(c[e >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2] | 0)) | 0) | 0;
	                    i = d;
	                    return
	                } else {
	                    Nq(b, 14);
	                    i = d;
	                    return
	                }
	            }

	            function ns(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if ((c[f >> 2] | 0) != 1) {
	                    Nq(b, 12);
	                    i = d;
	                    return
	                }
	                f = c[e >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 1 | 0)) {
	                    Nq(f, 23);
	                    i = d;
	                    return
	                }
	                do if (c[f + 16 >> 2] | 0) {
	                    if ((c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 1 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 9 : 0)break;
	                    c[g >> 2] = Sq(c[e >> 2] | 0) | 0;
	                    do if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                        if ((c[c[g >> 2] >> 2] | 0) != 1 ? (c[c[g >> 2] >> 2] | 0) != 9 : 0) {
	                            if ((c[c[(c[g >> 2] | 0) + 4 >> 2] >> 2] | 0) == 1 ? (c[(c[(c[g >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                                c[j >> 2] = 0;
	                                c[h >> 2] = c[c[(c[(c[g >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] >> 2];
	                                a:do if ((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                                    c[h >> 2] = c[(c[h >> 2] | 0) + 12 >> 2];
	                                    while (1) {
	                                        if (!(c[h >> 2] | 0))break a;
	                                        c[h >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                                        c[j >> 2] = (c[j >> 2] | 0) + 1
	                                    }
	                                } while (0);
	                                b = c[e >> 2] | 0;
	                                Tq(b, wt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, +(c[j >> 2] | 0)) | 0) | 0;
	                                break
	                            }
	                            b = c[e >> 2] | 0;
	                            Tq(b, wt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, 0.0) | 0) | 0;
	                            break
	                        }
	                        b = c[e >> 2] | 0;
	                        Tq(b, wt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, +(c[c[(c[g >> 2] | 0) + 4 >> 2] >> 2] | 0)) | 0) | 0
	                    } else k = 12; while (0);
	                    if ((k | 0) == 12) {
	                        b = c[e >> 2] | 0;
	                        Tq(b, wt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, 0.0) | 0) | 0
	                    }
	                    jt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[g >> 2] | 0);
	                    i = d;
	                    return
	                } while (0);
	                Nq(c[e >> 2] | 0, 11);
	                i = d;
	                return
	            }

	            function os(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 24 | 0;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                l = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if ((c[f >> 2] | 0) != 1) {
	                    Nq(b, 12);
	                    i = d;
	                    return
	                }
	                f = c[e >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 1 | 0)) {
	                    Nq(f, 23);
	                    i = d;
	                    return
	                }
	                c[j >> 2] = Sq(f) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    Nq(c[e >> 2] | 0, 10);
	                    i = d;
	                    return
	                }
	                if ((c[c[j >> 2] >> 2] | 0) != 1 ? (c[c[j >> 2] >> 2] | 0) != 9 : 0) {
	                    c[j >> 2] = Bt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[j >> 2] | 0) | 0;
	                    c[h >> 2] = zt(c[c[(c[e >> 2] | 0) + 12 >> 2] >> 2] | 0, c[(c[j >> 2] | 0) + 24 >> 2] | 0) | 0;
	                    f = c[e >> 2] | 0;
	                    Tq(f, At(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[h >> 2] | 0) | 0) | 0;
	                    jt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[j >> 2] | 0);
	                    i = d;
	                    return
	                }
	                c[h >> 2] = $q(0) | 0;
	                a:do if (c[(c[j >> 2] | 0) + 4 >> 2] | 0) {
	                    c[l >> 2] = 0;
	                    while (1) {
	                        if ((c[l >> 2] | 0) >= (c[c[(c[j >> 2] | 0) + 4 >> 2] >> 2] | 0))break a;
	                        c[g >> 2] = ir(c[(c[(c[(c[j >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) + (c[l >> 2] << 2) >> 2] | 0) | 0;
	                        c[k >> 2] = zt(c[c[(c[e >> 2] | 0) + 12 >> 2] >> 2] | 0, c[g >> 2] | 0) | 0;
	                        c[h >> 2] = er(c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                        fr(c[k >> 2] | 0);
	                        if (c[g >> 2] | 0)zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                        c[l >> 2] = (c[l >> 2] | 0) + 1
	                    }
	                } while (0);
	                jt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[j >> 2] | 0);
	                j = c[e >> 2] | 0;
	                Tq(j, At(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[h >> 2] | 0) | 0) | 0;
	                i = d;
	                return
	            }

	            function ps(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                if (!(c[g >> 2] | 0)) {
	                    b = c[f >> 2] | 0;
	                    Tq(b, yt(c[(c[f >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) | 0) | 0;
	                    c[g >> 2] = 1
	                }
	                if (!(c[f >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                b = c[f >> 2] | 0;
	                if ((c[g >> 2] | 0) != 1) {
	                    Nq(b, 12);
	                    i = e;
	                    return
	                }
	                g = c[f >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[f >> 2] | 0) + 44 >> 2] | 0) + 1 | 0)) {
	                    Nq(g, 23);
	                    i = e;
	                    return
	                }
	                do if (c[g + 16 >> 2] | 0) {
	                    if ((c[c[(c[f >> 2] | 0) + 16 >> 2] >> 2] | 0) != 1 ? (c[c[(c[f >> 2] | 0) + 16 >> 2] >> 2] | 0) != 9 : 0)break;
	                    c[h >> 2] = Sq(c[f >> 2] | 0) | 0;
	                    do if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 0 ? (c[c[(c[h >> 2] | 0) + 4 >> 2] >> 2] | 0) != 0 : 0) {
	                        c[j >> 2] = 0;
	                        b = c[(c[(c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0;
	                        if ((b | 0) == 7 | (b | 0) == 2 | (b | 0) == 1) {
	                            a = c[f >> 2] | 0;
	                            k = c[(c[f >> 2] | 0) + 12 >> 2] | 0;
	                            if ((d[c[(c[(c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) + 8 >> 2] >> 0] | 0 | 0) == 32) {
	                                Tq(a, Ct(k, 128928) | 0) | 0;
	                                break
	                            } else {
	                                Tq(a, Dt(k, c[(c[(c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) + 8 >> 2] | 0) | 0) | 0;
	                                break
	                            }
	                        } else if ((b | 0) == 18) {
	                            b = c[f >> 2] | 0;
	                            Tq(b, Dt(c[(c[f >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0) | 0) | 0;
	                            break
	                        } else {
	                            b = c[f >> 2] | 0;
	                            Tq(b, Ct(c[(c[f >> 2] | 0) + 12 >> 2] | 0, 128928) | 0) | 0;
	                            break
	                        }
	                    } else l = 15; while (0);
	                    if ((l | 0) == 15) {
	                        b = c[f >> 2] | 0;
	                        Tq(b, Ct(c[(c[f >> 2] | 0) + 12 >> 2] | 0, 128928) | 0) | 0
	                    }
	                    jt(c[(c[f >> 2] | 0) + 12 >> 2] | 0, c[h >> 2] | 0);
	                    i = e;
	                    return
	                } while (0);
	                Nq(c[f >> 2] | 0, 11);
	                i = e;
	                return
	            }

	            function qs(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if (!(c[f >> 2] | 0)) {
	                    b = c[e >> 2] | 0;
	                    Tq(b, yt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[e >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) | 0) | 0;
	                    c[f >> 2] = 1
	                }
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if ((c[f >> 2] | 0) != 1) {
	                    Nq(b, 12);
	                    i = d;
	                    return
	                }
	                f = c[e >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 1 | 0)) {
	                    Nq(f, 23);
	                    i = d;
	                    return
	                }
	                do if (c[f + 16 >> 2] | 0) {
	                    if ((c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 1 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 9 : 0)break;
	                    c[g >> 2] = Sq(c[e >> 2] | 0) | 0;
	                    do if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 4 >> 2] >> 2] | 0) != 0 : 0) {
	                        c[h >> 2] = 0;
	                        if (((c[(c[(c[(c[(c[g >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) + (c[h >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0) + -1 | 0) >>> 0 >= 2) {
	                            b = c[e >> 2] | 0;
	                            Tq(b, Ct(c[(c[e >> 2] | 0) + 12 >> 2] | 0, 128928) | 0) | 0;
	                            break
	                        }
	                        b = c[e >> 2] | 0;
	                        a = c[(c[e >> 2] | 0) + 12 >> 2] | 0;
	                        if (!(c[(c[(c[(c[(c[g >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) + (c[h >> 2] << 2) >> 2] | 0) + 36 >> 2] | 0)) {
	                            Tq(b, Ct(a, 128928) | 0) | 0;
	                            break
	                        } else {
	                            Tq(b, Dt(a, c[(c[(c[(c[(c[(c[g >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) + (c[h >> 2] << 2) >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) | 0) | 0;
	                            break
	                        }
	                    } else j = 15; while (0);
	                    if ((j | 0) == 15) {
	                        a = c[e >> 2] | 0;
	                        Tq(a, Ct(c[(c[e >> 2] | 0) + 12 >> 2] | 0, 128928) | 0) | 0
	                    }
	                    jt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[g >> 2] | 0);
	                    i = d;
	                    return
	                } while (0);
	                Nq(c[e >> 2] | 0, 11);
	                i = d;
	                return
	            }

	            function rs(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if (!(c[f >> 2] | 0)) {
	                    a = c[(c[e >> 2] | 0) + 12 >> 2] | 0;
	                    Tq(b, Et(a, ir(c[(c[(c[e >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) | 0) | 0) | 0;
	                    i = d;
	                    return
	                }
	                if (!b) {
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if ((c[f >> 2] | 0) != 1) {
	                    Nq(b, 12);
	                    i = d;
	                    return
	                }
	                f = c[e >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 1 | 0)) {
	                    Nq(f, 23);
	                    i = d;
	                    return
	                }
	                c[g >> 2] = Sq(f) | 0;
	                f = c[e >> 2] | 0;
	                if (!(c[g >> 2] | 0)) {
	                    Nq(f, 10);
	                    i = d;
	                    return
	                } else {
	                    Tq(f, Bt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[g >> 2] | 0) | 0) | 0;
	                    i = d;
	                    return
	                }
	            }

	            function ss(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                b = (c[e >> 2] | 0) == 0;
	                if (!(c[f >> 2] | 0)) {
	                    if (b) {
	                        i = d;
	                        return
	                    }
	                    if (!(c[(c[e >> 2] | 0) + 12 >> 2] | 0)) {
	                        i = d;
	                        return
	                    }
	                    a = c[e >> 2] | 0;
	                    if (!(c[(c[(c[e >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0)) {
	                        Tq(a, wt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, 0.0) | 0) | 0;
	                        i = d;
	                        return
	                    } else {
	                        c[h >> 2] = ir(c[(c[a + 12 >> 2] | 0) + 4 >> 2] | 0) | 0;
	                        a = c[e >> 2] | 0;
	                        j = c[(c[e >> 2] | 0) + 12 >> 2] | 0;
	                        Tq(a, wt(j, +(Dy(c[h >> 2] | 0) | 0)) | 0) | 0;
	                        zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                        i = d;
	                        return
	                    }
	                }
	                if (b) {
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if ((c[f >> 2] | 0) != 1) {
	                    Nq(b, 12);
	                    i = d;
	                    return
	                }
	                f = c[e >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 1 | 0)) {
	                    Nq(f, 23);
	                    i = d;
	                    return
	                }
	                if ((c[f + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 4 : 0)rs(c[e >> 2] | 0, 1);
	                if ((c[(c[e >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) == 4 : 0) {
	                    c[g >> 2] = Sq(c[e >> 2] | 0) | 0;
	                    f = c[e >> 2] | 0;
	                    b = c[(c[e >> 2] | 0) + 12 >> 2] | 0;
	                    Tq(f, wt(b, +(Dy(c[(c[g >> 2] | 0) + 24 >> 2] | 0) | 0)) | 0) | 0;
	                    jt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[g >> 2] | 0);
	                    i = d;
	                    return
	                }
	                Nq(c[e >> 2] | 0, 11);
	                i = d;
	                return
	            }

	            function ts(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if ((c[f >> 2] | 0) < 2) {
	                    if (!(c[e >> 2] | 0)) {
	                        i = d;
	                        return
	                    }
	                    b = c[e >> 2] | 0;
	                    if ((c[f >> 2] | 0) != 2) {
	                        Nq(b, 12);
	                        i = d;
	                        return
	                    }
	                    if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 2 | 0)) {
	                        Nq(c[e >> 2] | 0, 23);
	                        i = d;
	                        return
	                    }
	                }
	                if ((c[(c[e >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 4 : 0)rs(c[e >> 2] | 0, 1);
	                c[g >> 2] = Sq(c[e >> 2] | 0) | 0;
	                if ((c[g >> 2] | 0) != 0 ? (c[c[g >> 2] >> 2] | 0) == 4 : 0) {
	                    c[f >> 2] = (c[f >> 2] | 0) + -1;
	                    while (1) {
	                        k = c[e >> 2] | 0;
	                        if ((c[f >> 2] | 0) <= 0) {
	                            l = 23;
	                            break
	                        }
	                        if ((c[k + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 4 : 0)rs(c[e >> 2] | 0, 1);
	                        c[h >> 2] = Sq(c[e >> 2] | 0) | 0;
	                        if (!(c[h >> 2] | 0)) {
	                            l = 21;
	                            break
	                        }
	                        if ((c[c[h >> 2] >> 2] | 0) != 4) {
	                            l = 21;
	                            break
	                        }
	                        c[j >> 2] = By(c[(c[h >> 2] | 0) + 24 >> 2] | 0, c[(c[g >> 2] | 0) + 24 >> 2] | 0) | 0;
	                        c[(c[h >> 2] | 0) + 24 >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                        c[(c[g >> 2] | 0) + 24 >> 2] = c[j >> 2];
	                        jt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[h >> 2] | 0);
	                        c[f >> 2] = (c[f >> 2] | 0) + -1
	                    }
	                    if ((l | 0) == 21) {
	                        jt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[h >> 2] | 0);
	                        jt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[g >> 2] | 0);
	                        Nq(c[e >> 2] | 0, 11);
	                        i = d;
	                        return
	                    } else if ((l | 0) == 23) {
	                        Tq(k, c[g >> 2] | 0) | 0;
	                        i = d;
	                        return
	                    }
	                }
	                jt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[g >> 2] | 0);
	                i = d;
	                return
	            }

	            function us(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if ((c[f >> 2] | 0) != 2) {
	                    Nq(b, 12);
	                    i = d;
	                    return
	                }
	                f = c[e >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 2 | 0)) {
	                    Nq(f, 23);
	                    i = d;
	                    return
	                }
	                if ((c[f + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 4 : 0)rs(c[e >> 2] | 0, 1);
	                if ((c[(c[e >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) == 4 : 0) {
	                    c[h >> 2] = Sq(c[e >> 2] | 0) | 0;
	                    if ((c[(c[e >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 4 : 0)rs(c[e >> 2] | 0, 1);
	                    c[g >> 2] = Sq(c[e >> 2] | 0) | 0;
	                    if ((c[g >> 2] | 0) != 0 ? (c[c[g >> 2] >> 2] | 0) == 4 : 0) {
	                        f = (wy(c[(c[g >> 2] | 0) + 24 >> 2] | 0, c[(c[h >> 2] | 0) + 24 >> 2] | 0) | 0) != 0;
	                        b = c[e >> 2] | 0;
	                        a = c[(c[e >> 2] | 0) + 12 >> 2] | 0;
	                        if (f)Tq(b, Ft(a, 1) | 0) | 0; else Tq(b, Ft(a, 0) | 0) | 0;
	                        jt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[g >> 2] | 0);
	                        jt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[h >> 2] | 0);
	                        i = d;
	                        return
	                    }
	                    jt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[g >> 2] | 0);
	                    jt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[h >> 2] | 0);
	                    Nq(c[e >> 2] | 0, 11);
	                    i = d;
	                    return
	                }
	                Nq(c[e >> 2] | 0, 11);
	                i = d;
	                return
	            }

	            function vs(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if ((c[f >> 2] | 0) != 2) {
	                    Nq(b, 12);
	                    i = d;
	                    return
	                }
	                f = c[e >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 2 | 0)) {
	                    Nq(f, 23);
	                    i = d;
	                    return
	                }
	                if ((c[f + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 4 : 0)rs(c[e >> 2] | 0, 1);
	                if ((c[(c[e >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) == 4 : 0) {
	                    c[h >> 2] = Sq(c[e >> 2] | 0) | 0;
	                    if ((c[(c[e >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 4 : 0)rs(c[e >> 2] | 0, 1);
	                    c[g >> 2] = Sq(c[e >> 2] | 0) | 0;
	                    if ((c[g >> 2] | 0) != 0 ? (c[c[g >> 2] >> 2] | 0) == 4 : 0) {
	                        c[j >> 2] = xy(c[(c[h >> 2] | 0) + 24 >> 2] | 0) | 0;
	                        f = (sy(c[(c[g >> 2] | 0) + 24 >> 2] | 0, c[(c[h >> 2] | 0) + 24 >> 2] | 0, c[j >> 2] | 0) | 0) != 0;
	                        j = c[e >> 2] | 0;
	                        b = c[(c[e >> 2] | 0) + 12 >> 2] | 0;
	                        if (f)Tq(j, Ft(b, 0) | 0) | 0; else Tq(j, Ft(b, 1) | 0) | 0;
	                        jt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[g >> 2] | 0);
	                        jt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[h >> 2] | 0);
	                        i = d;
	                        return
	                    }
	                    jt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[g >> 2] | 0);
	                    jt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[h >> 2] | 0);
	                    Nq(c[e >> 2] | 0, 11);
	                    i = d;
	                    return
	                }
	                Nq(c[e >> 2] | 0, 11);
	                i = d;
	                return
	            }

	            function ws(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                d = i;
	                i = i + 64 | 0;
	                e = d + 48 | 0;
	                f = d + 44 | 0;
	                g = d + 40 | 0;
	                j = d + 36 | 0;
	                k = d + 32 | 0;
	                l = d + 8 | 0;
	                m = d;
	                n = d + 28 | 0;
	                o = d + 24 | 0;
	                p = d + 20 | 0;
	                q = d + 16 | 0;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                h[l >> 3] = 0.0;
	                if ((c[f >> 2] | 0) < 2) {
	                    if (!(c[e >> 2] | 0)) {
	                        i = d;
	                        return
	                    }
	                    b = c[e >> 2] | 0;
	                    if ((c[f >> 2] | 0) != 2) {
	                        Nq(b, 12);
	                        i = d;
	                        return
	                    }
	                    if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 2 | 0)) {
	                        Nq(c[e >> 2] | 0, 23);
	                        i = d;
	                        return
	                    }
	                }
	                if ((c[f >> 2] | 0) > 3) {
	                    if (!(c[e >> 2] | 0)) {
	                        i = d;
	                        return
	                    }
	                    b = c[e >> 2] | 0;
	                    if ((c[f >> 2] | 0) != 3) {
	                        Nq(b, 12);
	                        i = d;
	                        return
	                    }
	                    if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 3 | 0)) {
	                        Nq(c[e >> 2] | 0, 23);
	                        i = d;
	                        return
	                    }
	                }
	                do if ((c[f >> 2] | 0) == 3) {
	                    if ((c[(c[e >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 3 : 0)Tr(c[e >> 2] | 0, 1);
	                    if ((c[(c[e >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) == 3 : 0) {
	                        c[k >> 2] = Sq(c[e >> 2] | 0) | 0;
	                        h[l >> 3] = +h[(c[k >> 2] | 0) + 16 >> 3];
	                        jt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[k >> 2] | 0);
	                        break
	                    }
	                    Nq(c[e >> 2] | 0, 11);
	                    i = d;
	                    return
	                } while (0);
	                if ((c[(c[e >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 3 : 0)Tr(c[e >> 2] | 0, 1);
	                if ((c[(c[e >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) == 3 : 0) {
	                    c[j >> 2] = Sq(c[e >> 2] | 0) | 0;
	                    h[m >> 3] = +h[(c[j >> 2] | 0) + 16 >> 3];
	                    jt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[j >> 2] | 0);
	                    if ((c[(c[e >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 4 : 0)rs(c[e >> 2] | 0, 1);
	                    if ((c[(c[e >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) == 4 : 0) {
	                        c[g >> 2] = Sq(c[e >> 2] | 0) | 0;
	                        c[p >> 2] = Dy(c[(c[g >> 2] | 0) + 24 >> 2] | 0) | 0;
	                        if ((c[f >> 2] | 0) != 3 ? (h[l >> 3] = +(c[p >> 2] | 0), +h[m >> 3] < 1.0) : 0)h[m >> 3] = 1.0;
	                        if ((Mq(+h[m >> 3]) | 0) == 0 ? (Lq(+h[m >> 3] + +h[l >> 3]) | 0) == 0 : 0) {
	                            c[n >> 2] = ~~+h[m >> 3];
	                            if (+(c[n >> 2] | 0) + .5 <= +h[m >> 3])c[n >> 2] = (c[n >> 2] | 0) + 1;
	                            do if ((Mq(+h[l >> 3]) | 0) == 1) {
	                                c[o >> 2] = c[p >> 2];
	                                if ((c[n >> 2] | 0) < 1)c[n >> 2] = 1
	                            } else {
	                                m = (Mq(+h[l >> 3]) | 0) == -1;
	                                if (m | +h[l >> 3] < 0.0) {
	                                    c[o >> 2] = 0;
	                                    break
	                                }
	                                c[o >> 2] = ~~+h[l >> 3];
	                                if (+(c[o >> 2] | 0) + .5 <= +h[l >> 3])c[o >> 2] = (c[o >> 2] | 0) + 1
	                            } while (0);
	                            c[n >> 2] = (c[n >> 2] | 0) - 1;
	                            c[o >> 2] = (c[o >> 2] | 0) + (c[n >> 2] | 0);
	                            if ((c[n >> 2] | 0) < 0)c[n >> 2] = 0;
	                            if ((c[o >> 2] | 0) > (c[p >> 2] | 0))c[o >> 2] = c[p >> 2];
	                            c[o >> 2] = (c[o >> 2] | 0) - (c[n >> 2] | 0);
	                            c[q >> 2] = Ky(c[(c[g >> 2] | 0) + 24 >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0) | 0
	                        } else c[q >> 2] = 0;
	                        o = c[e >> 2] | 0;
	                        n = c[(c[e >> 2] | 0) + 12 >> 2] | 0;
	                        if (!(c[q >> 2] | 0))Tq(o, Ct(n, 128928) | 0) | 0; else {
	                            Tq(o, Dt(n, c[q >> 2] | 0) | 0) | 0;
	                            zb[c[135736 >> 2] & 511](c[q >> 2] | 0)
	                        }
	                        jt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[g >> 2] | 0);
	                        i = d;
	                        return
	                    }
	                    Nq(c[e >> 2] | 0, 11);
	                    i = d;
	                    return
	                }
	                Nq(c[e >> 2] | 0, 11);
	                i = d;
	                return
	            }

	            function xs(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 24 | 0;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                l = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if ((c[f >> 2] | 0) != 2) {
	                    Nq(b, 12);
	                    i = d;
	                    return
	                }
	                f = c[e >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 2 | 0)) {
	                    Nq(f, 23);
	                    i = d;
	                    return
	                }
	                if ((c[f + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 4 : 0)rs(c[e >> 2] | 0, 1);
	                c[h >> 2] = Sq(c[e >> 2] | 0) | 0;
	                if ((c[(c[e >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 4 : 0)rs(c[e >> 2] | 0, 1);
	                c[g >> 2] = Sq(c[e >> 2] | 0) | 0;
	                c[j >> 2] = Ly() | 0;
	                if (c[j >> 2] | 0) {
	                    c[k >> 2] = wy(c[(c[g >> 2] | 0) + 24 >> 2] | 0, c[(c[h >> 2] | 0) + 24 >> 2] | 0) | 0;
	                    if (c[k >> 2] | 0) {
	                        c[l >> 2] = (c[k >> 2] | 0) - (c[(c[g >> 2] | 0) + 24 >> 2] | 0);
	                        cz(c[j >> 2] | 0, c[(c[g >> 2] | 0) + 24 >> 2] | 0, c[l >> 2] | 0) | 0
	                    }
	                    l = c[e >> 2] | 0;
	                    k = c[(c[e >> 2] | 0) + 12 >> 2] | 0;
	                    Tq(l, Dt(k, Vy(c[j >> 2] | 0) | 0) | 0) | 0;
	                    Ry(c[j >> 2] | 0)
	                }
	                jt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[g >> 2] | 0);
	                jt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[h >> 2] | 0);
	                i = d;
	                return
	            }

	            function ys(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 24 | 0;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                l = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if ((c[f >> 2] | 0) != 2) {
	                    Nq(b, 12);
	                    i = d;
	                    return
	                }
	                f = c[e >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 2 | 0)) {
	                    Nq(f, 23);
	                    i = d;
	                    return
	                }
	                if ((c[f + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 4 : 0)rs(c[e >> 2] | 0, 1);
	                c[h >> 2] = Sq(c[e >> 2] | 0) | 0;
	                if ((c[(c[e >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 4 : 0)rs(c[e >> 2] | 0, 1);
	                c[g >> 2] = Sq(c[e >> 2] | 0) | 0;
	                c[j >> 2] = Ly() | 0;
	                if (c[j >> 2] | 0) {
	                    c[k >> 2] = wy(c[(c[g >> 2] | 0) + 24 >> 2] | 0, c[(c[h >> 2] | 0) + 24 >> 2] | 0) | 0;
	                    if (c[k >> 2] | 0) {
	                        f = (c[k >> 2] | 0) - (c[(c[g >> 2] | 0) + 24 >> 2] | 0) | 0;
	                        c[l >> 2] = f + (xy(c[(c[h >> 2] | 0) + 24 >> 2] | 0) | 0);
	                        f = c[j >> 2] | 0;
	                        k = (c[(c[g >> 2] | 0) + 24 >> 2] | 0) + (c[l >> 2] | 0) | 0;
	                        b = xy(c[(c[g >> 2] | 0) + 24 >> 2] | 0) | 0;
	                        cz(f, k, b - (c[l >> 2] | 0) | 0) | 0
	                    }
	                    l = c[e >> 2] | 0;
	                    b = c[(c[e >> 2] | 0) + 12 >> 2] | 0;
	                    Tq(l, Dt(b, Vy(c[j >> 2] | 0) | 0) | 0) | 0;
	                    Ry(c[j >> 2] | 0)
	                }
	                jt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[g >> 2] | 0);
	                jt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[h >> 2] | 0);
	                i = d;
	                return
	            }

	            function zs(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                m = f + 20 | 0;
	                c[g >> 2] = b;
	                c[h >> 2] = e;
	                c[j >> 2] = 0;
	                c[k >> 2] = 0;
	                if (!(c[g >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                if (!(c[h >> 2] | 0)) {
	                    e = c[g >> 2] | 0;
	                    b = c[(c[g >> 2] | 0) + 12 >> 2] | 0;
	                    Tq(e, Et(b, ir(c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) | 0) | 0) | 0;
	                    c[h >> 2] = 1
	                }
	                if (!(c[g >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                b = c[g >> 2] | 0;
	                if ((c[h >> 2] | 0) != 1) {
	                    Nq(b, 12);
	                    i = f;
	                    return
	                }
	                h = c[g >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[g >> 2] | 0) + 44 >> 2] | 0) + 1 | 0)) {
	                    Nq(h, 23);
	                    i = f;
	                    return
	                }
	                if ((c[h + 16 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) != 4 : 0)rs(c[g >> 2] | 0, 1);
	                if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) == 4 : 0) {
	                    c[j >> 2] = Sq(c[g >> 2] | 0) | 0;
	                    c[k >> 2] = c[(c[j >> 2] | 0) + 24 >> 2];
	                    c[l >> 2] = Ly() | 0;
	                    if ((c[l >> 2] | 0) != 0 & (c[k >> 2] | 0) != 0) {
	                        a:while (1) {
	                            do if ((d[c[k >> 2] >> 0] | 0) != 32) {
	                                if (9 <= (d[c[k >> 2] >> 0] | 0) ? (d[c[k >> 2] >> 0] | 0) <= 10 : 0)break;
	                                if ((d[c[k >> 2] >> 0] | 0) != 13)break a
	                            } while (0);
	                            c[k >> 2] = (c[k >> 2] | 0) + 1
	                        }
	                        a[m >> 0] = 0;
	                        while (1) {
	                            if (!(a[c[k >> 2] >> 0] | 0))break;
	                            do if ((d[c[k >> 2] >> 0] | 0) != 32) {
	                                if (9 <= (d[c[k >> 2] >> 0] | 0) ? (d[c[k >> 2] >> 0] | 0) <= 10 : 0) {
	                                    n = 27;
	                                    break
	                                }
	                                if ((d[c[k >> 2] >> 0] | 0) != 13) {
	                                    if (a[m >> 0] | 0) {
	                                        cz(c[l >> 2] | 0, m, 1) | 0;
	                                        a[m >> 0] = 0
	                                    }
	                                    cz(c[l >> 2] | 0, c[k >> 2] | 0, 1) | 0
	                                } else n = 27
	                            } else n = 27; while (0);
	                            if ((n | 0) == 27) {
	                                n = 0;
	                                a[m >> 0] = 32
	                            }
	                            c[k >> 2] = (c[k >> 2] | 0) + 1
	                        }
	                        k = c[g >> 2] | 0;
	                        m = c[(c[g >> 2] | 0) + 12 >> 2] | 0;
	                        Tq(k, Dt(m, Vy(c[l >> 2] | 0) | 0) | 0) | 0;
	                        Ry(c[l >> 2] | 0)
	                    }
	                    jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[j >> 2] | 0);
	                    i = f;
	                    return
	                }
	                Nq(c[g >> 2] | 0, 11);
	                i = f;
	                return
	            }

	            function As(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f;
	                h = f + 40 | 0;
	                j = f + 36 | 0;
	                k = f + 32 | 0;
	                l = f + 28 | 0;
	                m = f + 24 | 0;
	                n = f + 20 | 0;
	                o = f + 16 | 0;
	                p = f + 12 | 0;
	                q = f + 44 | 0;
	                r = f + 8 | 0;
	                s = f + 4 | 0;
	                c[h >> 2] = b;
	                c[j >> 2] = e;
	                if (!(c[h >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                e = c[h >> 2] | 0;
	                if ((c[j >> 2] | 0) != 3) {
	                    Nq(e, 12);
	                    i = f;
	                    return
	                }
	                j = c[h >> 2] | 0;
	                if ((c[e + 20 >> 2] | 0) < ((c[(c[h >> 2] | 0) + 44 >> 2] | 0) + 3 | 0)) {
	                    Nq(j, 23);
	                    i = f;
	                    return
	                }
	                if ((c[j + 16 >> 2] | 0) != 0 ? (c[c[(c[h >> 2] | 0) + 16 >> 2] >> 2] | 0) != 4 : 0)rs(c[h >> 2] | 0, 1);
	                c[m >> 2] = Sq(c[h >> 2] | 0) | 0;
	                if ((c[(c[h >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[h >> 2] | 0) + 16 >> 2] >> 2] | 0) != 4 : 0)rs(c[h >> 2] | 0, 1);
	                c[l >> 2] = Sq(c[h >> 2] | 0) | 0;
	                if ((c[(c[h >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[h >> 2] | 0) + 16 >> 2] >> 2] | 0) != 4 : 0)rs(c[h >> 2] | 0, 1);
	                c[k >> 2] = Sq(c[h >> 2] | 0) | 0;
	                c[n >> 2] = Ly() | 0;
	                a:do if (c[n >> 2] | 0) {
	                    c[p >> 2] = Dy(c[(c[m >> 2] | 0) + 24 >> 2] | 0) | 0;
	                    c[s >> 2] = c[(c[k >> 2] | 0) + 24 >> 2];
	                    while (1) {
	                        j = a[c[s >> 2] >> 0] | 0;
	                        a[q >> 0] = j;
	                        if (!(j << 24 >> 24))break a;
	                        c[o >> 2] = Jy(c[(c[l >> 2] | 0) + 24 >> 2] | 0, c[s >> 2] | 0) | 0;
	                        if ((c[o >> 2] | 0) >= 0) {
	                            if ((c[o >> 2] | 0) < (c[p >> 2] | 0) ? (c[r >> 2] = Iy(c[(c[m >> 2] | 0) + 24 >> 2] | 0, c[o >> 2] | 0) | 0, (c[r >> 2] | 0) != 0) : 0) {
	                                j = c[n >> 2] | 0;
	                                e = c[r >> 2] | 0;
	                                cz(j, e, Gy(c[r >> 2] | 0, 1) | 0) | 0
	                            }
	                        } else {
	                            e = c[n >> 2] | 0;
	                            j = c[s >> 2] | 0;
	                            cz(e, j, Gy(c[s >> 2] | 0, 1) | 0) | 0
	                        }
	                        c[s >> 2] = (c[s >> 2] | 0) + 1;
	                        if (!((d[q >> 0] | 0) & 128))continue;
	                        if (((d[q >> 0] | 0) & 192 | 0) != 192)break;
	                        while (1) {
	                            j = (d[q >> 0] | 0) << 1 & 255;
	                            a[q >> 0] = j;
	                            if (!(j & 128))break;
	                            j = c[s >> 2] | 0;
	                            c[s >> 2] = j + 1;
	                            if (((d[j >> 0] | 0) & 192 | 0) != 128) {
	                                t = 28;
	                                break
	                            }
	                        }
	                        if ((t | 0) == 28) {
	                            t = 0;
	                            Db[c[135904 >> 2] & 511](c[33980] | 0, 129184, g)
	                        }
	                        if ((d[q >> 0] | 0) & 128)break a
	                    }
	                    Db[c[135904 >> 2] & 511](c[33980] | 0, 129184, g)
	                } while (0);
	                g = c[h >> 2] | 0;
	                q = c[(c[h >> 2] | 0) + 12 >> 2] | 0;
	                Tq(g, Dt(q, Vy(c[n >> 2] | 0) | 0) | 0) | 0;
	                Ry(c[n >> 2] | 0);
	                jt(c[(c[h >> 2] | 0) + 12 >> 2] | 0, c[k >> 2] | 0);
	                jt(c[(c[h >> 2] | 0) + 12 >> 2] | 0, c[l >> 2] | 0);
	                jt(c[(c[h >> 2] | 0) + 12 >> 2] | 0, c[m >> 2] | 0);
	                i = f;
	                return
	            }

	            function Bs(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if ((c[f >> 2] | 0) != 1) {
	                    Nq(b, 12);
	                    i = d;
	                    return
	                }
	                f = c[e >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 1 | 0)) {
	                    Nq(f, 23);
	                    i = d;
	                    return
	                }
	                c[g >> 2] = Sq(f) | 0;
	                f = c[e >> 2] | 0;
	                if (!(c[g >> 2] | 0)) {
	                    Nq(f, 10);
	                    i = d;
	                    return
	                } else {
	                    c[g >> 2] = Gt(c[f + 12 >> 2] | 0, c[g >> 2] | 0) | 0;
	                    Tq(c[e >> 2] | 0, c[g >> 2] | 0) | 0;
	                    i = d;
	                    return
	                }
	            }

	            function Cs(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if ((c[f >> 2] | 0) != 1) {
	                    Nq(b, 12);
	                    i = d;
	                    return
	                }
	                f = c[e >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 1 | 0)) {
	                    Nq(f, 23);
	                    i = d;
	                    return
	                }
	                if ((c[f + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 2 : 0)Bs(c[e >> 2] | 0, 1);
	                if ((c[(c[e >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) == 2 : 0) {
	                    c[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 8 >> 2] = ((c[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 8 >> 2] | 0) != 0 ^ 1) & 1;
	                    i = d;
	                    return
	                }
	                Nq(c[e >> 2] | 0, 11);
	                i = d;
	                return
	            }

	            function Ds(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if (c[f >> 2] | 0) {
	                    Nq(b, 12);
	                    i = d;
	                    return
	                }
	                f = c[e >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 0 | 0)) {
	                    Nq(f, 23);
	                    i = d;
	                    return
	                } else {
	                    Tq(f, Ft(c[(c[e >> 2] | 0) + 12 >> 2] | 0, 1) | 0) | 0;
	                    i = d;
	                    return
	                }
	            }

	            function Es(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if (c[f >> 2] | 0) {
	                    Nq(b, 12);
	                    i = d;
	                    return
	                }
	                f = c[e >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 0 | 0)) {
	                    Nq(f, 23);
	                    i = d;
	                    return
	                } else {
	                    Tq(f, Ft(c[(c[e >> 2] | 0) + 12 >> 2] | 0, 0) | 0) | 0;
	                    i = d;
	                    return
	                }
	            }

	            function Fs(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 20 | 0;
	                h = e + 16 | 0;
	                j = e + 12 | 0;
	                k = e + 8 | 0;
	                l = e + 4 | 0;
	                m = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                c[j >> 2] = 0;
	                c[l >> 2] = 0;
	                if (!(c[f >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                b = c[f >> 2] | 0;
	                if ((c[g >> 2] | 0) != 1) {
	                    Nq(b, 12);
	                    i = e;
	                    return
	                }
	                g = c[f >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[f >> 2] | 0) + 44 >> 2] | 0) + 1 | 0)) {
	                    Nq(g, 23);
	                    i = e;
	                    return
	                }
	                if ((c[g + 16 >> 2] | 0) != 0 ? (c[c[(c[f >> 2] | 0) + 16 >> 2] >> 2] | 0) != 4 : 0)rs(c[f >> 2] | 0, 1);
	                if ((c[(c[f >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[f >> 2] | 0) + 16 >> 2] >> 2] | 0) == 4 : 0) {
	                    c[h >> 2] = Sq(c[f >> 2] | 0) | 0;
	                    c[k >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                    c[j >> 2] = Ti(c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) | 0;
	                    a:do if ((c[j >> 2] | 0) != 0 & (c[k >> 2] | 0) != 0) {
	                        c[m >> 2] = 0;
	                        while (1) {
	                            n = c[m >> 2] | 0;
	                            if (!(d[(c[k >> 2] | 0) + (c[m >> 2] | 0) >> 0] | 0))break;
	                            g = WS(d[(c[k >> 2] | 0) + n >> 0] | 0) | 0;
	                            if ((g | 0) != (WS(d[(c[j >> 2] | 0) + (c[m >> 2] | 0) >> 0] | 0) | 0))break a;
	                            c[m >> 2] = (c[m >> 2] | 0) + 1
	                        }
	                        if ((d[(c[j >> 2] | 0) + n >> 0] | 0 | 0) != 0 ? (d[(c[j >> 2] | 0) + (c[m >> 2] | 0) >> 0] | 0 | 0) != 45 : 0)break;
	                        c[l >> 2] = 1
	                    } while (0);
	                    if (c[j >> 2] | 0)zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                    jt(c[(c[f >> 2] | 0) + 12 >> 2] | 0, c[h >> 2] | 0);
	                    h = c[f >> 2] | 0;
	                    Tq(h, Ft(c[(c[f >> 2] | 0) + 12 >> 2] | 0, c[l >> 2] | 0) | 0) | 0;
	                    i = e;
	                    return
	                }
	                Nq(c[f >> 2] | 0, 11);
	                i = e;
	                return
	            }

	            function Gs(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, j = 0, k = 0, l = 0.0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                h[k >> 3] = 0.0;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if ((c[f >> 2] | 0) != 1) {
	                    Nq(b, 12);
	                    i = d;
	                    return
	                }
	                f = c[e >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 1 | 0)) {
	                    Nq(f, 23);
	                    i = d;
	                    return
	                }
	                do if (c[f + 16 >> 2] | 0) {
	                    if ((c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 1 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 9 : 0)break;
	                    c[g >> 2] = Sq(c[e >> 2] | 0) | 0;
	                    a:do if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 4 >> 2] >> 2] | 0) != 0 : 0) {
	                        c[j >> 2] = 0;
	                        while (1) {
	                            if ((c[j >> 2] | 0) >= (c[c[(c[g >> 2] | 0) + 4 >> 2] >> 2] | 0))break a;
	                            l = +Gr(c[(c[(c[(c[g >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0);
	                            h[k >> 3] = +h[k >> 3] + l;
	                            c[j >> 2] = (c[j >> 2] | 0) + 1
	                        }
	                    } while (0);
	                    b = c[e >> 2] | 0;
	                    Tq(b, wt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, +h[k >> 3]) | 0) | 0;
	                    jt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[g >> 2] | 0);
	                    i = d;
	                    return
	                } while (0);
	                Nq(c[e >> 2] | 0, 11);
	                i = d;
	                return
	            }

	            function Hs(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, j = 0.0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if ((c[f >> 2] | 0) != 1) {
	                    Nq(b, 12);
	                    i = d;
	                    return
	                }
	                f = c[e >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 1 | 0)) {
	                    Nq(f, 23);
	                    i = d;
	                    return
	                }
	                if ((c[f + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 3 : 0)Tr(c[e >> 2] | 0, 1);
	                if ((c[(c[e >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) == 3 : 0) {
	                    h[g >> 3] = +uT(+h[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3], 2147483647.0);
	                    h[g >> 3] = +h[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] - +h[g >> 3] + +(~~+h[g >> 3] | 0);
	                    if (!(+h[g >> 3] != +h[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3])) {
	                        i = d;
	                        return
	                    }
	                    j = +h[g >> 3];
	                    if (+h[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] > 0.0) {
	                        h[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] = j;
	                        i = d;
	                        return
	                    } else {
	                        h[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] = j - 1.0;
	                        i = d;
	                        return
	                    }
	                }
	                Nq(c[e >> 2] | 0, 11);
	                i = d;
	                return
	            }

	            function Is(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if ((c[f >> 2] | 0) != 1) {
	                    Nq(b, 12);
	                    i = d;
	                    return
	                }
	                f = c[e >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 1 | 0)) {
	                    Nq(f, 23);
	                    i = d;
	                    return
	                }
	                if ((c[f + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 3 : 0)Tr(c[e >> 2] | 0, 1);
	                if ((c[(c[e >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) == 3 : 0) {
	                    h[g >> 3] = +uT(+h[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3], 2147483647.0);
	                    h[g >> 3] = +h[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] - +h[g >> 3] + +(~~+h[g >> 3] | 0);
	                    if (!(+h[g >> 3] != +h[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3])) {
	                        i = d;
	                        return
	                    }
	                    if (+h[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] > 0.0) {
	                        h[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] = +h[g >> 3] + 1.0;
	                        i = d;
	                        return
	                    }
	                    if (+h[g >> 3] == 0.0 ? +h[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] < 0.0 : 0) {
	                        h[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] = +h[15988];
	                        i = d;
	                        return
	                    } else {
	                        h[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] = +h[g >> 3];
	                        i = d;
	                        return
	                    }
	                }
	                Nq(c[e >> 2] | 0, 11);
	                i = d;
	                return
	            }

	            function Js(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, j = 0.0, k = 0.0, l = 0.0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if ((c[f >> 2] | 0) != 1) {
	                    Nq(b, 12);
	                    i = d;
	                    return
	                }
	                f = c[e >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 1 | 0)) {
	                    Nq(f, 23);
	                    i = d;
	                    return
	                }
	                if ((c[f + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 3 : 0)Tr(c[e >> 2] | 0, 1);
	                if ((c[(c[e >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) == 3 : 0) {
	                    if (Lq(+h[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3]) | 0) {
	                        i = d;
	                        return
	                    }
	                    if ((Mq(+h[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3]) | 0) == 1) {
	                        i = d;
	                        return
	                    }
	                    if ((Mq(+h[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3]) | 0) == -1) {
	                        i = d;
	                        return
	                    }
	                    if (+h[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] == 0.0) {
	                        i = d;
	                        return
	                    }
	                    h[g >> 3] = +uT(+h[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3], 2147483647.0);
	                    h[g >> 3] = +h[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] - +h[g >> 3] + +(~~+h[g >> 3] | 0);
	                    j = +h[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3];
	                    k = +h[g >> 3];
	                    if (!(+h[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] < 0.0)) {
	                        l = +h[g >> 3];
	                        if (j < k + .5) {
	                            h[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] = l;
	                            i = d;
	                            return
	                        } else {
	                            h[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] = l + 1.0;
	                            i = d;
	                            return
	                        }
	                    }
	                    l = +h[g >> 3];
	                    if (j < k - .5)h[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] = l - 1.0; else h[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] = l;
	                    if (!(+h[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] == 0.0)) {
	                        i = d;
	                        return
	                    }
	                    h[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 3] = +h[15988];
	                    i = d;
	                    return
	                }
	                Nq(c[e >> 2] | 0, 11);
	                i = d;
	                return
	            }

	            function Ks(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                b = i;
	                i = i + 32 | 0;
	                e = b + 16 | 0;
	                f = b + 12 | 0;
	                g = b + 8 | 0;
	                h = b + 4 | 0;
	                j = b;
	                c[f >> 2] = a;
	                c[j >> 2] = 0;
	                if ((c[f >> 2] | 0) != 0 ? (c[c[f >> 2] >> 2] | 0) != 0 : 0) {
	                    c[g >> 2] = c[c[f >> 2] >> 2];
	                    if ((d[c[g >> 2] >> 0] | 0 | 0) >= 97 ? (d[c[g >> 2] >> 0] | 0 | 0) <= 122 : 0)k = 9; else k = 6;
	                    do if ((k | 0) == 6) {
	                        if ((d[c[g >> 2] >> 0] | 0 | 0) >= 65 ? (d[c[g >> 2] >> 0] | 0 | 0) <= 90 : 0) {
	                            k = 9;
	                            break
	                        }
	                        if ((d[c[g >> 2] >> 0] | 0 | 0) == 95)k = 9
	                    } while (0);
	                    do if ((k | 0) == 9) {
	                        c[g >> 2] = (c[g >> 2] | 0) + 1;
	                        while (1) {
	                            if ((d[c[g >> 2] >> 0] | 0 | 0) >= 97 ? (d[c[g >> 2] >> 0] | 0 | 0) <= 122 : 0)l = 1; else k = 12;
	                            do if ((k | 0) == 12) {
	                                k = 0;
	                                if ((d[c[g >> 2] >> 0] | 0 | 0) >= 65 ? (d[c[g >> 2] >> 0] | 0 | 0) <= 90 : 0) {
	                                    l = 1;
	                                    break
	                                }
	                                if ((d[c[g >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[g >> 2] >> 0] | 0 | 0) <= 57 : 0) {
	                                    l = 1;
	                                    break
	                                }
	                                if ((d[c[g >> 2] >> 0] | 0 | 0) != 95 ? (d[c[g >> 2] >> 0] | 0 | 0) != 46 : 0)l = (d[c[g >> 2] >> 0] | 0 | 0) == 45; else l = 1
	                            } while (0);
	                            m = c[g >> 2] | 0;
	                            if (!l)break;
	                            c[g >> 2] = m + 1
	                        }
	                        if ((((((((d[m >> 0] | 0 | 0) != 32 ? (d[c[g >> 2] >> 0] | 0 | 0) != 62 : 0) ? (d[c[g >> 2] >> 0] | 0 | 0) != 47 : 0) ? (d[c[g >> 2] >> 0] | 0 | 0) != 91 : 0) ? (d[c[g >> 2] >> 0] | 0 | 0) != 93 : 0) ? (d[c[g >> 2] >> 0] | 0 | 0) != 58 : 0) ? (d[c[g >> 2] >> 0] | 0 | 0) != 64 : 0) ? (d[c[g >> 2] >> 0] | 0 | 0) != 42 : 0)break;
	                        c[j >> 2] = (c[g >> 2] | 0) - (c[c[f >> 2] >> 2] | 0);
	                        if (!(c[j >> 2] | 0)) {
	                            c[e >> 2] = 0;
	                            n = c[e >> 2] | 0;
	                            i = b;
	                            return n | 0
	                        } else {
	                            c[h >> 2] = ly(c[c[f >> 2] >> 2] | 0, c[j >> 2] | 0) | 0;
	                            c[c[f >> 2] >> 2] = c[g >> 2];
	                            c[e >> 2] = c[h >> 2];
	                            n = c[e >> 2] | 0;
	                            i = b;
	                            return n | 0
	                        }
	                    } while (0);
	                    c[e >> 2] = Ht(c[f >> 2] | 0, 0) | 0;
	                    n = c[e >> 2] | 0;
	                    i = b;
	                    return n | 0
	                }
	                c[e >> 2] = 0;
	                n = c[e >> 2] | 0;
	                i = b;
	                return n | 0
	            }

	            function Ls(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                b = i;
	                i = i + 32 | 0;
	                e = b + 16 | 0;
	                f = b + 12 | 0;
	                g = b + 8 | 0;
	                h = b + 4 | 0;
	                j = b;
	                c[f >> 2] = a;
	                c[j >> 2] = 0;
	                if ((c[f >> 2] | 0) != 0 ? (c[c[f >> 2] >> 2] | 0) != 0 : 0) {
	                    c[g >> 2] = c[c[f >> 2] >> 2];
	                    if ((d[c[g >> 2] >> 0] | 0 | 0) >= 97 ? (d[c[g >> 2] >> 0] | 0 | 0) <= 122 : 0)k = 10; else k = 6;
	                    do if ((k | 0) == 6) {
	                        if ((d[c[g >> 2] >> 0] | 0 | 0) >= 65 ? (d[c[g >> 2] >> 0] | 0 | 0) <= 90 : 0) {
	                            k = 10;
	                            break
	                        }
	                        if (!((d[c[g >> 2] >> 0] | 0 | 0) != 95 ? (d[c[g >> 2] >> 0] | 0 | 0) != 58 : 0))k = 10
	                    } while (0);
	                    if ((k | 0) == 10) {
	                        c[g >> 2] = (c[g >> 2] | 0) + 1;
	                        while (1) {
	                            if ((d[c[g >> 2] >> 0] | 0 | 0) >= 97 ? (d[c[g >> 2] >> 0] | 0 | 0) <= 122 : 0)l = 1; else k = 13;
	                            do if ((k | 0) == 13) {
	                                k = 0;
	                                if ((d[c[g >> 2] >> 0] | 0 | 0) >= 65 ? (d[c[g >> 2] >> 0] | 0 | 0) <= 90 : 0) {
	                                    l = 1;
	                                    break
	                                }
	                                if ((d[c[g >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[g >> 2] >> 0] | 0 | 0) <= 57 : 0) {
	                                    l = 1;
	                                    break
	                                }
	                                if (((d[c[g >> 2] >> 0] | 0 | 0) != 95 ? (d[c[g >> 2] >> 0] | 0 | 0) != 45 : 0) ? (d[c[g >> 2] >> 0] | 0 | 0) != 58 : 0)l = (d[c[g >> 2] >> 0] | 0 | 0) == 46; else l = 1
	                            } while (0);
	                            m = c[g >> 2] | 0;
	                            if (!l)break;
	                            c[g >> 2] = m + 1
	                        }
	                        if ((d[m >> 0] | 0 | 0) > 0 ? (d[c[g >> 2] >> 0] | 0 | 0) < 128 : 0) {
	                            c[j >> 2] = (c[g >> 2] | 0) - (c[c[f >> 2] >> 2] | 0);
	                            if ((c[j >> 2] | 0) >>> 0 > 5e4) {
	                                c[c[f >> 2] >> 2] = c[g >> 2];
	                                Nq(c[f >> 2] | 0, 7);
	                                c[e >> 2] = 0;
	                                n = c[e >> 2] | 0;
	                                i = b;
	                                return n | 0
	                            } else {
	                                c[h >> 2] = ly(c[c[f >> 2] >> 2] | 0, c[j >> 2] | 0) | 0;
	                                c[c[f >> 2] >> 2] = c[g >> 2];
	                                c[e >> 2] = c[h >> 2];
	                                n = c[e >> 2] | 0;
	                                i = b;
	                                return n | 0
	                            }
	                        }
	                    }
	                    c[e >> 2] = Ht(c[f >> 2] | 0, 1) | 0;
	                    n = c[e >> 2] | 0;
	                    i = b;
	                    return n | 0
	                }
	                c[e >> 2] = 0;
	                n = c[e >> 2] | 0;
	                i = b;
	                return n | 0
	            }

	            function Ms(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                do if (c[e >> 2] | 0) {
	                    if (qy(c[e >> 2] | 0, 129400) | 0) {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    if (qy(c[e >> 2] | 0, 129408) | 0) {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    if (qy(c[e >> 2] | 0, 129416) | 0) {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    if (qy(c[e >> 2] | 0, 129424) | 0) {
	                        c[d >> 2] = 1;
	                        break
	                    } else {
	                        c[d >> 2] = 0;
	                        break
	                    }
	                } else c[d >> 2] = 0; while (0);
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function Ns(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e;
	                g = e + 20 | 0;
	                j = e + 16 | 0;
	                k = e + 12 | 0;
	                l = e + 8 | 0;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                a:do if ((c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0)c[g >> 2] = 0; else switch (c[c[k >> 2] >> 2] | 0) {
	                    case 9:
	                    case 1:
	                    {
	                        if (!(c[(c[k >> 2] | 0) + 4 >> 2] | 0)) {
	                            c[g >> 2] = 0;
	                            break a
	                        } else {
	                            c[g >> 2] = (c[c[(c[k >> 2] | 0) + 4 >> 2] >> 2] | 0) != 0 & 1;
	                            break a
	                        }
	                        break
	                    }
	                    case 2:
	                    {
	                        c[g >> 2] = c[(c[k >> 2] | 0) + 8 >> 2];
	                        break a;
	                        break
	                    }
	                    case 7:
	                    {
	                        c[l >> 2] = c[(c[k >> 2] | 0) + 28 >> 2];
	                        if (!(c[l >> 2] | 0)) {
	                            c[g >> 2] = 0;
	                            break a
	                        } else {
	                            c[g >> 2] = (c[c[l >> 2] >> 2] | 0) != 0 & 1;
	                            break a
	                        }
	                        break
	                    }
	                    case 4:
	                    {
	                        if (c[(c[k >> 2] | 0) + 24 >> 2] | 0)m = (d[c[(c[k >> 2] | 0) + 24 >> 2] >> 0] | 0 | 0) != 0; else m = 0;
	                        c[g >> 2] = m & 1;
	                        break a;
	                        break
	                    }
	                    case 3:
	                    {
	                        c[g >> 2] = +h[(c[k >> 2] | 0) + 16 >> 3] == +(c[(c[(c[j >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2] | 0) & 1;
	                        break a;
	                        break
	                    }
	                    default:
	                    {
	                        b = c[33976] | 0;
	                        a = c[33980] | 0;
	                        c[f >> 2] = 128552;
	                        c[f + 4 >> 2] = 14647;
	                        Db[b & 511](a, 129448, f);
	                        c[g >> 2] = 0;
	                        break a
	                    }
	                } while (0);
	                i = e;
	                return c[g >> 2] | 0
	            }

	            function Os(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[k >> 2] = It(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                if (c[k >> 2] | 0) {
	                    c[f >> 2] = c[k >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                Kq();
	                c[j >> 2] = Or(c[h >> 2] | 0, c[g >> 2] | 0) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                Jt(c[j >> 2] | 0, 1);
	                g = c[j >> 2] | 0;
	                if (c[(c[j >> 2] | 0) + 8 >> 2] | 0) {
	                    Pr(g);
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                b = c[j >> 2] | 0;
	                if (d[c[g >> 2] >> 0] | 0) {
	                    Oq(b, 128552, 14835, 7);
	                    c[k >> 2] = 0
	                } else {
	                    c[k >> 2] = c[b + 32 >> 2];
	                    c[(c[j >> 2] | 0) + 32 >> 2] = 0
	                }
	                Pr(c[j >> 2] | 0);
	                if (((c[k >> 2] | 0) != 0 ? (j = my(c[h >> 2] | 0) | 0, c[(c[k >> 2] | 0) + 16 >> 2] = j, (c[c[k >> 2] >> 2] | 0) > 1) : 0) ? (c[(c[k >> 2] | 0) + 12 >> 2] | 0) >= 0 : 0)Kt(c[k >> 2] | 0, (c[(c[k >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[k >> 2] | 0) + 12 >> 2] | 0) * 40 | 0) | 0);
	                c[f >> 2] = c[k >> 2];
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function Ps(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[g >> 2] = 0;
	                Lt(c[e >> 2] | 0, c[f >> 2] | 0, g, 0) | 0;
	                i = d;
	                return c[g >> 2] | 0
	            }

	            function Qs(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                c[f >> 2] = It(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[(c[e >> 2] | 0) + 4 >> 2] | 0) | 0;
	                a = c[e >> 2] | 0;
	                a:do if (c[f >> 2] | 0) {
	                    if (c[a + 32 >> 2] | 0)Pq(c[(c[e >> 2] | 0) + 32 >> 2] | 0);
	                    c[(c[e >> 2] | 0) + 32 >> 2] = c[f >> 2];
	                    if (c[c[e >> 2] >> 2] | 0)while (1) {
	                        if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))break a;
	                        g = c[e >> 2] | 0;
	                        c[g >> 2] = (c[g >> 2] | 0) + 1
	                    }
	                } else {
	                    Jt(a, 1);
	                    if ((((c[(c[e >> 2] | 0) + 8 >> 2] | 0) == 0 ? (c[(c[e >> 2] | 0) + 32 >> 2] | 0) != 0 : 0) ? (c[c[(c[e >> 2] | 0) + 32 >> 2] >> 2] | 0) > 1 : 0) ? (c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2] | 0) >= 0 : 0)Kt(c[(c[e >> 2] | 0) + 32 >> 2] | 0, (c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2] | 0) * 40 | 0) | 0)
	                } while (0);
	                if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                    i = b;
	                    return
	                }
	                Mt(c[e >> 2] | 0, 0) | 0;
	                i = b;
	                return
	            }

	            function Rs(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e;
	                g = e + 32 | 0;
	                h = e + 28 | 0;
	                j = e + 24 | 0;
	                k = e + 20 | 0;
	                l = e + 16 | 0;
	                m = e + 12 | 0;
	                n = e + 8 | 0;
	                o = e + 4 | 0;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[n >> 2] = 0;
	                c[o >> 2] = 0;
	                if (!(c[j >> 2] | 0)) {
	                    Xd(0, 0, 0, 0, 0, 12, 1, 3, 128552, 15056, 0, 0, 0, 0, 0, 129480, f);
	                    c[g >> 2] = 0;
	                    p = c[g >> 2] | 0;
	                    i = e;
	                    return p | 0
	                }
	                Kq();
	                c[k >> 2] = Or(c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    p = c[g >> 2] | 0;
	                    i = e;
	                    return p | 0
	                }
	                Qs(c[k >> 2] | 0);
	                do if (!(c[(c[k >> 2] | 0) + 16 >> 2] | 0)) {
	                    Db[c[135904 >> 2] & 511](c[33980] | 0, 129504, f);
	                    c[l >> 2] = 0
	                } else {
	                    if (((d[c[c[k >> 2] >> 2] >> 0] | 0 | 0) != 0 ? (c[(c[k >> 2] | 0) + 32 >> 2] | 0) != 0 : 0) ? (c[(c[(c[k >> 2] | 0) + 32 >> 2] | 0) + 24 >> 2] | 0) == 0 : 0) {
	                        Oq(c[k >> 2] | 0, 128552, 15074, 7);
	                        c[l >> 2] = 0;
	                        break
	                    }
	                    c[l >> 2] = Sq(c[k >> 2] | 0) | 0
	                } while (0);
	                do {
	                    c[m >> 2] = Sq(c[k >> 2] | 0) | 0;
	                    if (c[m >> 2] | 0) {
	                        if ((c[m >> 2] | 0) != (c[n >> 2] | 0))c[o >> 2] = (c[o >> 2] | 0) + 1;
	                        jt(c[j >> 2] | 0, c[m >> 2] | 0)
	                    }
	                } while ((c[m >> 2] | 0) != 0);
	                if ((c[o >> 2] | 0) != 0 & (c[l >> 2] | 0) != 0) {
	                    m = c[33976] | 0;
	                    j = c[33980] | 0;
	                    c[f >> 2] = c[o >> 2];
	                    Db[m & 511](j, 129544, f)
	                }
	                if (c[(c[k >> 2] | 0) + 8 >> 2] | 0) {
	                    Qq(c[l >> 2] | 0);
	                    c[l >> 2] = 0
	                }
	                Pr(c[k >> 2] | 0);
	                c[g >> 2] = c[l >> 2];
	                p = c[g >> 2] | 0;
	                i = e;
	                return p | 0
	            }

	            function Ss(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 36 | 0;
	                g = e + 32 | 0;
	                h = e + 28 | 0;
	                j = e + 16 | 0;
	                k = e + 8 | 0;
	                l = e + 24 | 0;
	                m = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                d = j;
	                c[d >> 2] = c[g >> 2];
	                c[d + 4 >> 2] = 0;
	                while (1) {
	                    d = j;
	                    g = c[d + 4 >> 2] | 0;
	                    if (!((g | 0) < 0 | ((g | 0) == 0 ? (c[d >> 2] | 0) >>> 0 < (c[h >> 2] | 0) >>> 0 : 0)))break;
	                    d = j;
	                    g = XT(c[d >> 2] | 0, c[d + 4 >> 2] | 0, 1, 0) | 0;
	                    if ((Nt(c[(c[f >> 2] | 0) + (g << 2) >> 2] | 0, c[(c[f >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) | 0) > 0) {
	                        c[l >> 2] = c[(c[f >> 2] | 0) + (c[j >> 2] << 2) >> 2];
	                        g = Ot(c[f >> 2] | 0, c[l >> 2] | 0, c[j >> 2] | 0) | 0;
	                        d = m;
	                        c[d >> 2] = g;
	                        c[d + 4 >> 2] = G;
	                        d = j;
	                        g = XT(c[d >> 2] | 0, c[d + 4 >> 2] | 0, 1, 0) | 0;
	                        d = k;
	                        c[d >> 2] = g;
	                        c[d + 4 >> 2] = G;
	                        while (1) {
	                            d = k;
	                            g = c[d + 4 >> 2] | 0;
	                            b = m;
	                            a = c[b + 4 >> 2] | 0;
	                            if (!((g | 0) > (a | 0) | ((g | 0) == (a | 0) ? (c[d >> 2] | 0) >>> 0 >= (c[b >> 2] | 0) >>> 0 : 0)))break;
	                            b = c[(c[f >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0;
	                            d = k;
	                            a = bU(c[d >> 2] | 0, c[d + 4 >> 2] | 0, 1, 0) | 0;
	                            c[(c[f >> 2] | 0) + (a << 2) >> 2] = b;
	                            b = k;
	                            a = bU(c[b >> 2] | 0, c[b + 4 >> 2] | 0, -1, -1) | 0;
	                            b = k;
	                            c[b >> 2] = a;
	                            c[b + 4 >> 2] = G
	                        }
	                        c[(c[f >> 2] | 0) + (c[m >> 2] << 2) >> 2] = c[l >> 2]
	                    }
	                    b = j;
	                    a = bU(c[b >> 2] | 0, c[b + 4 >> 2] | 0, 1, 0) | 0;
	                    b = j;
	                    c[b >> 2] = a;
	                    c[b + 4 >> 2] = G
	                }
	                i = e;
	                return
	            }

	            function Ts(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f + 16 | 0;
	                h = f + 32 | 0;
	                j = f + 8 | 0;
	                k = f + 28 | 0;
	                l = f;
	                m = f + 24 | 0;
	                c[h >> 2] = a;
	                a = j;
	                c[a >> 2] = b;
	                c[a + 4 >> 2] = d;
	                c[k >> 2] = e;
	                e = j;
	                d = XT(c[k >> 2] | 0, 0, c[e >> 2] | 0, c[e + 4 >> 2] | 0) | 0;
	                if ((d | 0) == 1 & (G | 0) == 0) {
	                    d = g;
	                    c[d >> 2] = 1;
	                    c[d + 4 >> 2] = 0;
	                    n = g;
	                    o = n;
	                    p = c[o >> 2] | 0;
	                    q = n + 4 | 0;
	                    r = q;
	                    s = c[r >> 2] | 0;
	                    G = s;
	                    i = f;
	                    return p | 0
	                }
	                d = j;
	                e = c[d >> 2] | 0;
	                a = c[d + 4 >> 2] | 0;
	                d = XT(c[k >> 2] | 0, 0, 2, 0) | 0;
	                b = G;
	                if ((a | 0) > (b | 0) | (a | 0) == (b | 0) & e >>> 0 >= d >>> 0) {
	                    if ((Nt(c[(c[h >> 2] | 0) + ((c[k >> 2] | 0) - 2 << 2) >> 2] | 0, c[(c[h >> 2] | 0) + ((c[k >> 2] | 0) - 1 << 2) >> 2] | 0) | 0) > 0) {
	                        c[m >> 2] = c[(c[h >> 2] | 0) + ((c[k >> 2] | 0) - 2 << 2) >> 2];
	                        c[(c[h >> 2] | 0) + ((c[k >> 2] | 0) - 2 << 2) >> 2] = c[(c[h >> 2] | 0) + ((c[k >> 2] | 0) - 1 << 2) >> 2];
	                        c[(c[h >> 2] | 0) + ((c[k >> 2] | 0) - 1 << 2) >> 2] = c[m >> 2]
	                    }
	                    m = g;
	                    c[m >> 2] = 2;
	                    c[m + 4 >> 2] = 0;
	                    n = g;
	                    o = n;
	                    p = c[o >> 2] | 0;
	                    q = n + 4 | 0;
	                    r = q;
	                    s = c[r >> 2] | 0;
	                    G = s;
	                    i = f;
	                    return p | 0
	                }
	                m = j;
	                d = bU(c[m >> 2] | 0, c[m + 4 >> 2] | 0, 2, 0) | 0;
	                m = l;
	                c[m >> 2] = d;
	                c[m + 4 >> 2] = G;
	                m = c[(c[h >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0;
	                d = j;
	                e = bU(c[d >> 2] | 0, c[d + 4 >> 2] | 0, 1, 0) | 0;
	                if ((Nt(m, c[(c[h >> 2] | 0) + (e << 2) >> 2] | 0) | 0) <= 0) {
	                    while (1) {
	                        e = l;
	                        m = c[e >> 2] | 0;
	                        d = c[e + 4 >> 2] | 0;
	                        e = XT(c[k >> 2] | 0, 0, 1, 0) | 0;
	                        if ((m | 0) == (e | 0) & (d | 0) == (G | 0))break;
	                        d = l;
	                        e = XT(c[d >> 2] | 0, c[d + 4 >> 2] | 0, 1, 0) | 0;
	                        if ((Nt(c[(c[h >> 2] | 0) + (e << 2) >> 2] | 0, c[(c[h >> 2] | 0) + (c[l >> 2] << 2) >> 2] | 0) | 0) > 0)break;
	                        e = l;
	                        d = bU(c[e >> 2] | 0, c[e + 4 >> 2] | 0, 1, 0) | 0;
	                        e = l;
	                        c[e >> 2] = d;
	                        c[e + 4 >> 2] = G
	                    }
	                    e = l;
	                    d = j;
	                    m = XT(c[e >> 2] | 0, c[e + 4 >> 2] | 0, c[d >> 2] | 0, c[d + 4 >> 2] | 0) | 0;
	                    d = g;
	                    c[d >> 2] = m;
	                    c[d + 4 >> 2] = G;
	                    n = g;
	                    o = n;
	                    p = c[o >> 2] | 0;
	                    q = n + 4 | 0;
	                    r = q;
	                    s = c[r >> 2] | 0;
	                    G = s;
	                    i = f;
	                    return p | 0
	                } else {
	                    while (1) {
	                        d = l;
	                        m = c[d >> 2] | 0;
	                        e = c[d + 4 >> 2] | 0;
	                        d = XT(c[k >> 2] | 0, 0, 1, 0) | 0;
	                        if ((m | 0) == (d | 0) & (e | 0) == (G | 0))break;
	                        e = l;
	                        d = XT(c[e >> 2] | 0, c[e + 4 >> 2] | 0, 1, 0) | 0;
	                        if ((Nt(c[(c[h >> 2] | 0) + (d << 2) >> 2] | 0, c[(c[h >> 2] | 0) + (c[l >> 2] << 2) >> 2] | 0) | 0) <= 0)break;
	                        d = l;
	                        e = bU(c[d >> 2] | 0, c[d + 4 >> 2] | 0, 1, 0) | 0;
	                        d = l;
	                        c[d >> 2] = e;
	                        c[d + 4 >> 2] = G
	                    }
	                    k = c[h >> 2] | 0;
	                    h = j;
	                    d = c[h >> 2] | 0;
	                    e = c[h + 4 >> 2] | 0;
	                    h = l;
	                    m = XT(c[h >> 2] | 0, c[h + 4 >> 2] | 0, 1, 0) | 0;
	                    Pt(k, d, e, m, G);
	                    m = l;
	                    l = j;
	                    j = XT(c[m >> 2] | 0, c[m + 4 >> 2] | 0, c[l >> 2] | 0, c[l + 4 >> 2] | 0) | 0;
	                    l = g;
	                    c[l >> 2] = j;
	                    c[l + 4 >> 2] = G;
	                    n = g;
	                    o = n;
	                    p = c[o >> 2] | 0;
	                    q = n + 4 | 0;
	                    r = q;
	                    s = c[r >> 2] | 0;
	                    G = s;
	                    i = f;
	                    return p | 0
	                }
	                return 0
	            }

	            function Us(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0;
	                f = i;
	                i = i + 80 | 0;
	                g = f + 64 | 0;
	                h = f + 60 | 0;
	                j = f + 56 | 0;
	                k = f + 52 | 0;
	                l = f + 40 | 0;
	                m = f + 32 | 0;
	                n = f + 24 | 0;
	                o = f + 48 | 0;
	                p = f + 16 | 0;
	                q = f + 8 | 0;
	                r = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                e = (c[h >> 2] | 0) + ((c[j >> 2] | 0) - 2 << 4) + 8 | 0;
	                d = c[e + 4 >> 2] | 0;
	                b = l;
	                c[b >> 2] = c[e >> 2];
	                c[b + 4 >> 2] = d;
	                d = (c[h >> 2] | 0) + ((c[j >> 2] | 0) - 1 << 4) + 8 | 0;
	                b = c[d + 4 >> 2] | 0;
	                e = m;
	                c[e >> 2] = c[d >> 2];
	                c[e + 4 >> 2] = b;
	                b = (c[h >> 2] | 0) + ((c[j >> 2] | 0) - 2 << 4) | 0;
	                j = c[b + 4 >> 2] | 0;
	                h = n;
	                c[h >> 2] = c[b >> 2];
	                c[h + 4 >> 2] = j;
	                j = c[k >> 2] | 0;
	                h = l;
	                b = c[h + 4 >> 2] | 0;
	                e = m;
	                d = c[e + 4 >> 2] | 0;
	                a = (b | 0) < (d | 0) | ((b | 0) == (d | 0) ? (c[h >> 2] | 0) >>> 0 < (c[e >> 2] | 0) >>> 0 : 0);
	                e = l;
	                h = c[e + 4 >> 2] | 0;
	                h = m;
	                d = c[h + 4 >> 2] | 0;
	                d = a ? c[e >> 2] | 0 : c[h >> 2] | 0;
	                Qt(j, d);
	                c[o >> 2] = c[(c[k >> 2] | 0) + 4 >> 2];
	                k = l;
	                d = c[k + 4 >> 2] | 0;
	                j = m;
	                h = c[j + 4 >> 2] | 0;
	                e = c[o >> 2] | 0;
	                a = n;
	                b = c[a >> 2] | 0;
	                s = c[a + 4 >> 2] | 0;
	                if ((d | 0) < (h | 0) | ((d | 0) == (h | 0) ? (c[k >> 2] | 0) >>> 0 < (c[j >> 2] | 0) >>> 0 : 0)) {
	                    j = (c[g >> 2] | 0) + (b << 2) | 0;
	                    k = l;
	                    h = mU(c[k >> 2] | 0, c[k + 4 >> 2] | 0, 4, 0) | 0;
	                    eU(e | 0, j | 0, h | 0) | 0;
	                    h = p;
	                    c[h >> 2] = 0;
	                    c[h + 4 >> 2] = 0;
	                    h = n;
	                    j = l;
	                    k = bU(c[h >> 2] | 0, c[h + 4 >> 2] | 0, c[j >> 2] | 0, c[j + 4 >> 2] | 0) | 0;
	                    j = q;
	                    c[j >> 2] = k;
	                    c[j + 4 >> 2] = G;
	                    j = n;
	                    k = c[j + 4 >> 2] | 0;
	                    h = r;
	                    c[h >> 2] = c[j >> 2];
	                    c[h + 4 >> 2] = k;
	                    while (1) {
	                        k = r;
	                        h = c[k >> 2] | 0;
	                        j = c[k + 4 >> 2] | 0;
	                        k = n;
	                        d = l;
	                        a = bU(c[k >> 2] | 0, c[k + 4 >> 2] | 0, c[d >> 2] | 0, c[d + 4 >> 2] | 0) | 0;
	                        d = m;
	                        k = bU(a | 0, G | 0, c[d >> 2] | 0, c[d + 4 >> 2] | 0) | 0;
	                        d = G;
	                        if (!((j | 0) < (d | 0) | (j | 0) == (d | 0) & h >>> 0 < k >>> 0))break;
	                        k = p;
	                        h = c[k + 4 >> 2] | 0;
	                        d = l;
	                        j = c[d + 4 >> 2] | 0;
	                        do if ((h | 0) < (j | 0) | ((h | 0) == (j | 0) ? (c[k >> 2] | 0) >>> 0 < (c[d >> 2] | 0) >>> 0 : 0) ? (a = q, t = c[a >> 2] | 0, u = c[a + 4 >> 2] | 0, a = n, v = l, w = bU(c[a >> 2] | 0, c[a + 4 >> 2] | 0, c[v >> 2] | 0, c[v + 4 >> 2] | 0) | 0, v = m, a = bU(w | 0, G | 0, c[v >> 2] | 0, c[v + 4 >> 2] | 0) | 0, v = G, (u | 0) < (v | 0) | (u | 0) == (v | 0) & t >>> 0 < a >>> 0) : 0)if ((Nt(c[(c[o >> 2] | 0) + (c[p >> 2] << 2) >> 2] | 0, c[(c[g >> 2] | 0) + (c[q >> 2] << 2) >> 2] | 0) | 0) <= 0) {
	                            a = p;
	                            t = c[a >> 2] | 0;
	                            v = bU(t | 0, c[a + 4 >> 2] | 0, 1, 0) | 0;
	                            a = p;
	                            c[a >> 2] = v;
	                            c[a + 4 >> 2] = G;
	                            c[(c[g >> 2] | 0) + (c[r >> 2] << 2) >> 2] = c[(c[o >> 2] | 0) + (t << 2) >> 2];
	                            break
	                        } else {
	                            t = q;
	                            a = c[t >> 2] | 0;
	                            v = bU(a | 0, c[t + 4 >> 2] | 0, 1, 0) | 0;
	                            t = q;
	                            c[t >> 2] = v;
	                            c[t + 4 >> 2] = G;
	                            c[(c[g >> 2] | 0) + (c[r >> 2] << 2) >> 2] = c[(c[g >> 2] | 0) + (a << 2) >> 2];
	                            break
	                        } else x = 9; while (0);
	                        do if ((x | 0) == 9) {
	                            x = 0;
	                            d = p;
	                            k = c[d + 4 >> 2] | 0;
	                            j = l;
	                            h = c[j + 4 >> 2] | 0;
	                            if ((k | 0) < (h | 0) | ((k | 0) == (h | 0) ? (c[d >> 2] | 0) >>> 0 < (c[j >> 2] | 0) >>> 0 : 0)) {
	                                j = p;
	                                d = c[j >> 2] | 0;
	                                h = bU(d | 0, c[j + 4 >> 2] | 0, 1, 0) | 0;
	                                j = p;
	                                c[j >> 2] = h;
	                                c[j + 4 >> 2] = G;
	                                c[(c[g >> 2] | 0) + (c[r >> 2] << 2) >> 2] = c[(c[o >> 2] | 0) + (d << 2) >> 2];
	                                break
	                            } else {
	                                d = q;
	                                j = c[d >> 2] | 0;
	                                h = bU(j | 0, c[d + 4 >> 2] | 0, 1, 0) | 0;
	                                d = q;
	                                c[d >> 2] = h;
	                                c[d + 4 >> 2] = G;
	                                c[(c[g >> 2] | 0) + (c[r >> 2] << 2) >> 2] = c[(c[g >> 2] | 0) + (j << 2) >> 2];
	                                break
	                            }
	                        } while (0);
	                        j = r;
	                        d = bU(c[j >> 2] | 0, c[j + 4 >> 2] | 0, 1, 0) | 0;
	                        j = r;
	                        c[j >> 2] = d;
	                        c[j + 4 >> 2] = G
	                    }
	                    i = f;
	                    return
	                } else {
	                    j = l;
	                    d = bU(b | 0, s | 0, c[j >> 2] | 0, c[j + 4 >> 2] | 0) | 0;
	                    j = (c[g >> 2] | 0) + (d << 2) | 0;
	                    d = m;
	                    s = mU(c[d >> 2] | 0, c[d + 4 >> 2] | 0, 4, 0) | 0;
	                    eU(e | 0, j | 0, s | 0) | 0;
	                    s = m;
	                    j = XT(c[s >> 2] | 0, c[s + 4 >> 2] | 0, 1, 0) | 0;
	                    s = p;
	                    c[s >> 2] = j;
	                    c[s + 4 >> 2] = G;
	                    s = n;
	                    j = l;
	                    e = bU(c[s >> 2] | 0, c[s + 4 >> 2] | 0, c[j >> 2] | 0, c[j + 4 >> 2] | 0) | 0;
	                    j = XT(e | 0, G | 0, 1, 0) | 0;
	                    e = q;
	                    c[e >> 2] = j;
	                    c[e + 4 >> 2] = G;
	                    e = n;
	                    j = l;
	                    l = bU(c[e >> 2] | 0, c[e + 4 >> 2] | 0, c[j >> 2] | 0, c[j + 4 >> 2] | 0) | 0;
	                    j = m;
	                    m = bU(l | 0, G | 0, c[j >> 2] | 0, c[j + 4 >> 2] | 0) | 0;
	                    j = XT(m | 0, G | 0, 1, 0) | 0;
	                    m = r;
	                    c[m >> 2] = j;
	                    c[m + 4 >> 2] = G;
	                    while (1) {
	                        m = r;
	                        j = c[m + 4 >> 2] | 0;
	                        l = n;
	                        e = c[l + 4 >> 2] | 0;
	                        if (!((j | 0) > (e | 0) | ((j | 0) == (e | 0) ? (c[m >> 2] | 0) >>> 0 >= (c[l >> 2] | 0) >>> 0 : 0)))break;
	                        l = p;
	                        m = c[l + 4 >> 2] | 0;
	                        do if ((m | 0) > 0 | (m | 0) == 0 & (c[l >> 2] | 0) >>> 0 >= 0 ? (e = q, j = c[e + 4 >> 2] | 0, s = n, d = c[s + 4 >> 2] | 0, (j | 0) > (d | 0) | ((j | 0) == (d | 0) ? (c[e >> 2] | 0) >>> 0 >= (c[s >> 2] | 0) >>> 0 : 0)) : 0)if ((Nt(c[(c[g >> 2] | 0) + (c[q >> 2] << 2) >> 2] | 0, c[(c[o >> 2] | 0) + (c[p >> 2] << 2) >> 2] | 0) | 0) > 0) {
	                            s = q;
	                            e = c[s >> 2] | 0;
	                            d = bU(e | 0, c[s + 4 >> 2] | 0, -1, -1) | 0;
	                            s = q;
	                            c[s >> 2] = d;
	                            c[s + 4 >> 2] = G;
	                            c[(c[g >> 2] | 0) + (c[r >> 2] << 2) >> 2] = c[(c[g >> 2] | 0) + (e << 2) >> 2];
	                            break
	                        } else {
	                            e = p;
	                            s = c[e >> 2] | 0;
	                            d = bU(s | 0, c[e + 4 >> 2] | 0, -1, -1) | 0;
	                            e = p;
	                            c[e >> 2] = d;
	                            c[e + 4 >> 2] = G;
	                            c[(c[g >> 2] | 0) + (c[r >> 2] << 2) >> 2] = c[(c[o >> 2] | 0) + (s << 2) >> 2];
	                            break
	                        } else x = 20; while (0);
	                        do if ((x | 0) == 20) {
	                            x = 0;
	                            l = p;
	                            m = c[l + 4 >> 2] | 0;
	                            if ((m | 0) > 0 | (m | 0) == 0 & (c[l >> 2] | 0) >>> 0 >= 0) {
	                                l = p;
	                                m = c[l >> 2] | 0;
	                                s = bU(m | 0, c[l + 4 >> 2] | 0, -1, -1) | 0;
	                                l = p;
	                                c[l >> 2] = s;
	                                c[l + 4 >> 2] = G;
	                                c[(c[g >> 2] | 0) + (c[r >> 2] << 2) >> 2] = c[(c[o >> 2] | 0) + (m << 2) >> 2];
	                                break
	                            } else {
	                                m = q;
	                                l = c[m >> 2] | 0;
	                                s = bU(l | 0, c[m + 4 >> 2] | 0, -1, -1) | 0;
	                                m = q;
	                                c[m >> 2] = s;
	                                c[m + 4 >> 2] = G;
	                                c[(c[g >> 2] | 0) + (c[r >> 2] << 2) >> 2] = c[(c[g >> 2] | 0) + (l << 2) >> 2];
	                                break
	                            }
	                        } while (0);
	                        l = r;
	                        m = bU(c[l >> 2] | 0, c[l + 4 >> 2] | 0, -1, -1) | 0;
	                        l = r;
	                        c[l >> 2] = m;
	                        c[l + 4 >> 2] = G
	                    }
	                    i = f;
	                    return
	                }
	            }

	            function Vs(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                d = i;
	                i = i + 64 | 0;
	                e = d + 48 | 0;
	                f = d + 44 | 0;
	                g = d + 40 | 0;
	                h = d + 32 | 0;
	                j = d + 24 | 0;
	                k = d + 16 | 0;
	                l = d + 8 | 0;
	                m = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[g >> 2] | 0) < 2) {
	                    c[e >> 2] = 1;
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                b = c[g >> 2] | 0;
	                if ((c[g >> 2] | 0) == 2) {
	                    a = (c[f >> 2] | 0) + (b - 2 << 4) + 8 | 0;
	                    o = c[a + 4 >> 2] | 0;
	                    p = l;
	                    c[p >> 2] = c[a >> 2];
	                    c[p + 4 >> 2] = o;
	                    o = (c[f >> 2] | 0) + ((c[g >> 2] | 0) - 1 << 4) + 8 | 0;
	                    p = c[o + 4 >> 2] | 0;
	                    a = m;
	                    c[a >> 2] = c[o >> 2];
	                    c[a + 4 >> 2] = p;
	                    p = l;
	                    l = c[p + 4 >> 2] | 0;
	                    a = m;
	                    m = c[a + 4 >> 2] | 0;
	                    if ((l | 0) < (m | 0) | ((l | 0) == (m | 0) ? (c[p >> 2] | 0) >>> 0 <= (c[a >> 2] | 0) >>> 0 : 0)) {
	                        c[e >> 2] = 0;
	                        n = c[e >> 2] | 0;
	                        i = d;
	                        return n | 0
	                    } else {
	                        c[e >> 2] = 1;
	                        n = c[e >> 2] | 0;
	                        i = d;
	                        return n | 0
	                    }
	                }
	                a = (c[f >> 2] | 0) + (b - 3 << 4) + 8 | 0;
	                b = c[a + 4 >> 2] | 0;
	                p = h;
	                c[p >> 2] = c[a >> 2];
	                c[p + 4 >> 2] = b;
	                b = (c[f >> 2] | 0) + ((c[g >> 2] | 0) - 2 << 4) + 8 | 0;
	                p = c[b + 4 >> 2] | 0;
	                a = j;
	                c[a >> 2] = c[b >> 2];
	                c[a + 4 >> 2] = p;
	                p = (c[f >> 2] | 0) + ((c[g >> 2] | 0) - 1 << 4) + 8 | 0;
	                g = c[p + 4 >> 2] | 0;
	                f = k;
	                c[f >> 2] = c[p >> 2];
	                c[f + 4 >> 2] = g;
	                g = h;
	                h = c[g >> 2] | 0;
	                f = c[g + 4 >> 2] | 0;
	                g = j;
	                p = k;
	                a = bU(c[g >> 2] | 0, c[g + 4 >> 2] | 0, c[p >> 2] | 0, c[p + 4 >> 2] | 0) | 0;
	                p = G;
	                if (!((f | 0) < (p | 0) | (f | 0) == (p | 0) & h >>> 0 <= a >>> 0) ? (a = j, j = c[a + 4 >> 2] | 0, h = k, k = c[h + 4 >> 2] | 0, !((j | 0) < (k | 0) | ((j | 0) == (k | 0) ? (c[a >> 2] | 0) >>> 0 <= (c[h >> 2] | 0) >>> 0 : 0))) : 0) {
	                    c[e >> 2] = 1;
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                c[e >> 2] = 0;
	                n = c[e >> 2] | 0;
	                i = d;
	                return n | 0
	            }

	            function Ws(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                g = i;
	                i = i + 48 | 0;
	                h = g + 40 | 0;
	                j = g + 36 | 0;
	                k = g + 32 | 0;
	                l = g + 28 | 0;
	                m = g + 24 | 0;
	                n = g + 16 | 0;
	                o = g + 8 | 0;
	                p = g;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                while (1) {
	                    if ((c[k >> 2] | 0) <= 1) {
	                        q = 16;
	                        break
	                    }
	                    if ((c[k >> 2] | 0) == 2 ? (f = (c[j >> 2] | 0) + 8 | 0, e = (c[j >> 2] | 0) + 24 | 0, d = bU(c[f >> 2] | 0, c[f + 4 >> 2] | 0, c[e >> 2] | 0, c[e + 4 >> 2] | 0) | 0, (G | 0) == 0 ? (d | 0) == (c[m >> 2] | 0) : 0) : 0) {
	                        q = 5;
	                        break
	                    }
	                    if ((c[k >> 2] | 0) == 2 ? (d = (c[j >> 2] | 0) + 8 | 0, e = c[d + 4 >> 2] | 0, f = (c[j >> 2] | 0) + 24 | 0, b = c[f + 4 >> 2] | 0, (e | 0) < (b | 0) | ((e | 0) == (b | 0) ? (c[d >> 2] | 0) >>> 0 <= (c[f >> 2] | 0) >>> 0 : 0)) : 0) {
	                        q = 8;
	                        break
	                    }
	                    if ((c[k >> 2] | 0) == 2) {
	                        q = 16;
	                        break
	                    }
	                    f = (c[j >> 2] | 0) + ((c[k >> 2] | 0) - 3 << 4) + 8 | 0;
	                    d = c[f + 4 >> 2] | 0;
	                    b = n;
	                    c[b >> 2] = c[f >> 2];
	                    c[b + 4 >> 2] = d;
	                    d = (c[j >> 2] | 0) + ((c[k >> 2] | 0) - 2 << 4) + 8 | 0;
	                    b = c[d + 4 >> 2] | 0;
	                    f = o;
	                    c[f >> 2] = c[d >> 2];
	                    c[f + 4 >> 2] = b;
	                    b = (c[j >> 2] | 0) + ((c[k >> 2] | 0) - 1 << 4) + 8 | 0;
	                    f = c[b + 4 >> 2] | 0;
	                    d = p;
	                    c[d >> 2] = c[b >> 2];
	                    c[d + 4 >> 2] = f;
	                    f = n;
	                    d = c[f >> 2] | 0;
	                    b = c[f + 4 >> 2] | 0;
	                    f = o;
	                    e = p;
	                    a = bU(c[f >> 2] | 0, c[f + 4 >> 2] | 0, c[e >> 2] | 0, c[e + 4 >> 2] | 0) | 0;
	                    e = G;
	                    if (!((b | 0) < (e | 0) | (b | 0) == (e | 0) & d >>> 0 <= a >>> 0)) {
	                        a = o;
	                        d = c[a + 4 >> 2] | 0;
	                        e = p;
	                        b = c[e + 4 >> 2] | 0;
	                        if (!((d | 0) < (b | 0) | ((d | 0) == (b | 0) ? (c[a >> 2] | 0) >>> 0 <= (c[e >> 2] | 0) >>> 0 : 0))) {
	                            q = 16;
	                            break
	                        }
	                        Us(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0);
	                        e = (c[j >> 2] | 0) + ((c[k >> 2] | 0) - 1 << 4) + 8 | 0;
	                        a = (c[j >> 2] | 0) + ((c[k >> 2] | 0) - 2 << 4) + 8 | 0;
	                        b = a;
	                        d = bU(c[b >> 2] | 0, c[b + 4 >> 2] | 0, c[e >> 2] | 0, c[e + 4 >> 2] | 0) | 0;
	                        e = a;
	                        c[e >> 2] = d;
	                        c[e + 4 >> 2] = G;
	                        c[k >> 2] = (c[k >> 2] | 0) + -1;
	                        continue
	                    }
	                    e = n;
	                    d = c[e + 4 >> 2] | 0;
	                    a = p;
	                    b = c[a + 4 >> 2] | 0;
	                    f = c[h >> 2] | 0;
	                    r = c[j >> 2] | 0;
	                    s = c[k >> 2] | 0;
	                    if ((d | 0) < (b | 0) | ((d | 0) == (b | 0) ? (c[e >> 2] | 0) >>> 0 < (c[a >> 2] | 0) >>> 0 : 0)) {
	                        Us(f, r, s - 1 | 0, c[l >> 2] | 0);
	                        a = (c[j >> 2] | 0) + ((c[k >> 2] | 0) - 2 << 4) + 8 | 0;
	                        e = (c[j >> 2] | 0) + ((c[k >> 2] | 0) - 3 << 4) + 8 | 0;
	                        b = e;
	                        d = bU(c[b >> 2] | 0, c[b + 4 >> 2] | 0, c[a >> 2] | 0, c[a + 4 >> 2] | 0) | 0;
	                        a = e;
	                        c[a >> 2] = d;
	                        c[a + 4 >> 2] = G;
	                        a = (c[j >> 2] | 0) + ((c[k >> 2] | 0) - 2 << 4) | 0;
	                        d = (c[j >> 2] | 0) + ((c[k >> 2] | 0) - 1 << 4) | 0;
	                        c[a + 0 >> 2] = c[d + 0 >> 2];
	                        c[a + 4 >> 2] = c[d + 4 >> 2];
	                        c[a + 8 >> 2] = c[d + 8 >> 2];
	                        c[a + 12 >> 2] = c[d + 12 >> 2];
	                        c[k >> 2] = (c[k >> 2] | 0) + -1;
	                        continue
	                    } else {
	                        Us(f, r, s, c[l >> 2] | 0);
	                        s = (c[j >> 2] | 0) + ((c[k >> 2] | 0) - 1 << 4) + 8 | 0;
	                        r = (c[j >> 2] | 0) + ((c[k >> 2] | 0) - 2 << 4) + 8 | 0;
	                        f = r;
	                        d = bU(c[f >> 2] | 0, c[f + 4 >> 2] | 0, c[s >> 2] | 0, c[s + 4 >> 2] | 0) | 0;
	                        s = r;
	                        c[s >> 2] = d;
	                        c[s + 4 >> 2] = G;
	                        c[k >> 2] = (c[k >> 2] | 0) + -1;
	                        continue
	                    }
	                }
	                if ((q | 0) == 5) {
	                    Us(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0);
	                    p = (c[j >> 2] | 0) + 24 | 0;
	                    n = (c[j >> 2] | 0) + 8 | 0;
	                    o = n;
	                    m = bU(c[o >> 2] | 0, c[o + 4 >> 2] | 0, c[p >> 2] | 0, c[p + 4 >> 2] | 0) | 0;
	                    p = n;
	                    c[p >> 2] = m;
	                    c[p + 4 >> 2] = G;
	                    c[k >> 2] = (c[k >> 2] | 0) + -1;
	                    t = c[k >> 2] | 0;
	                    i = g;
	                    return t | 0
	                } else if ((q | 0) == 8) {
	                    Us(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0);
	                    l = (c[j >> 2] | 0) + 24 | 0;
	                    h = (c[j >> 2] | 0) + 8 | 0;
	                    j = h;
	                    p = bU(c[j >> 2] | 0, c[j + 4 >> 2] | 0, c[l >> 2] | 0, c[l + 4 >> 2] | 0) | 0;
	                    l = h;
	                    c[l >> 2] = p;
	                    c[l + 4 >> 2] = G;
	                    c[k >> 2] = (c[k >> 2] | 0) + -1;
	                    t = c[k >> 2] | 0;
	                    i = g;
	                    return t | 0
	                } else if ((q | 0) == 16) {
	                    t = c[k >> 2] | 0;
	                    i = g;
	                    return t | 0
	                }
	                return 0
	            }

	            function Xs() {
	                var a = 0;
	                a = i;
	                if (+h[16480] == 0.0)h[16480] = +Rt(131848);
	                i = a;
	                return +(+h[16480])
	            }

	            function Ys() {
	                var a = 0;
	                a = i;
	                if (+h[16479] == 0.0)h[16479] = -+Xs();
	                i = a;
	                return +(+h[16479])
	            }

	            function Zs() {
	                var a = 0;
	                a = i;
	                if (+h[16478] == 0.0)h[16478] = +zT(128928);
	                i = a;
	                return +(+h[16478])
	            }

	            function _s() {
	                var a = 0, b = 0.0;
	                a = i;
	                b = +Rt(131808);
	                i = a;
	                return +b
	            }

	            function $s(a) {
	                a = +a;
	                var b = 0, c = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                c = b;
	                h[c >> 3] = a;
	                d = St(+h[c >> 3]) | 0;
	                c = G & 2147483647;
	                i = b;
	                return (c >>> 0 > 2146435072 | (c | 0) == 2146435072 & d >>> 0 > 0) & 1 | 0
	            }

	            function at(a) {
	                a = +a;
	                var b = 0, c = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                c = b;
	                h[c >> 3] = a;
	                d = St(+h[c >> 3]) | 0;
	                if (!((d | 0) == 0 & (G & 2147483647 | 0) == 2146435072)) {
	                    e = 0;
	                    i = b;
	                    return e | 0
	                }
	                e = +h[c >> 3] > 0.0 ? 1 : -1;
	                i = b;
	                return e | 0
	            }

	            function bt(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 8 >> 2] | 0) {
	                    c[e >> 2] = 0;
	                    while (1) {
	                        if ((c[e >> 2] | 0) >= (c[c[d >> 2] >> 2] | 0))break;
	                        do if (c[(c[(c[d >> 2] | 0) + 8 >> 2] | 0) + (c[e >> 2] << 2) >> 2] | 0) {
	                            a = c[(c[(c[d >> 2] | 0) + 8 >> 2] | 0) + (c[e >> 2] << 2) >> 2] | 0;
	                            if ((c[(c[(c[(c[d >> 2] | 0) + 8 >> 2] | 0) + (c[e >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0) == 18) {
	                                _q(a);
	                                break
	                            } else {
	                                Uh(a);
	                                break
	                            }
	                        } while (0);
	                        c[e >> 2] = (c[e >> 2] | 0) + 1
	                    }
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 8 >> 2] | 0)
	                }
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function ct(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 128 | 0;
	                g = f;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f + 20 | 0;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[l >> 2] = 0;
	                while (1) {
	                    n = m + ((c[l >> 2] << 1) + 1) | 0;
	                    if (!((c[l >> 2] | 0) < 25 ? (c[l >> 2] | 0) < (c[k >> 2] | 0) : 0))break;
	                    a[n >> 0] = 32;
	                    a[m + (c[l >> 2] << 1) >> 0] = 32;
	                    c[l >> 2] = (c[l >> 2] | 0) + 1
	                }
	                a[n >> 0] = 0;
	                a[m + (c[l >> 2] << 1) >> 0] = 0;
	                if (!(c[j >> 2] | 0)) {
	                    n = c[h >> 2] | 0;
	                    c[g >> 2] = m;
	                    Ka(n | 0, 127912, g | 0) | 0;
	                    Ka(c[h >> 2] | 0, 131120, g | 0) | 0;
	                    i = f;
	                    return
	                }
	                if (!(c[j >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                n = c[h >> 2] | 0;
	                c[g >> 2] = c[c[j >> 2] >> 2];
	                Ka(n | 0, 131144, g | 0) | 0;
	                c[l >> 2] = 0;
	                while (1) {
	                    if ((c[l >> 2] | 0) >= (c[c[j >> 2] >> 2] | 0))break;
	                    n = c[h >> 2] | 0;
	                    c[g >> 2] = m;
	                    Ka(n | 0, 127912, g | 0) | 0;
	                    n = c[h >> 2] | 0;
	                    c[g >> 2] = (c[l >> 2] | 0) + 1;
	                    Ka(n | 0, 130840, g | 0) | 0;
	                    ft(c[h >> 2] | 0, c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + (c[l >> 2] << 2) >> 2] | 0, (c[k >> 2] | 0) + 1 | 0);
	                    c[l >> 2] = (c[l >> 2] | 0) + 1
	                }
	                i = f;
	                return
	            }

	            function dt(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 128 | 0;
	                g = f;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f + 20 | 0;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[l >> 2] = 0;
	                while (1) {
	                    n = m + ((c[l >> 2] << 1) + 1) | 0;
	                    if (!((c[l >> 2] | 0) < 25 ? (c[l >> 2] | 0) < (c[k >> 2] | 0) : 0))break;
	                    a[n >> 0] = 32;
	                    a[m + (c[l >> 2] << 1) >> 0] = 32;
	                    c[l >> 2] = (c[l >> 2] | 0) + 1
	                }
	                a[n >> 0] = 0;
	                a[m + (c[l >> 2] << 1) >> 0] = 0;
	                if (((c[j >> 2] | 0) != 0 ? (c[c[j >> 2] >> 2] | 0) != 0 : 0) ? (c[c[(c[j >> 2] | 0) + 8 >> 2] >> 2] | 0) != 0 : 0) {
	                    n = c[h >> 2] | 0;
	                    c[g >> 2] = m;
	                    Ka(n | 0, 127912, g | 0) | 0;
	                    n = c[h >> 2] | 0;
	                    c[g >> 2] = (c[l >> 2] | 0) + 1;
	                    Ka(n | 0, 130840, g | 0) | 0;
	                    Ut(c[h >> 2] | 0, c[(c[c[(c[j >> 2] | 0) + 8 >> 2] >> 2] | 0) + 12 >> 2] | 0, (c[k >> 2] | 0) + 1 | 0);
	                    i = f;
	                    return
	                }
	                k = c[h >> 2] | 0;
	                c[g >> 2] = m;
	                Ka(k | 0, 127912, g | 0) | 0;
	                Ka(c[h >> 2] | 0, 131096, g | 0) | 0;
	                i = f;
	                return
	            }

	            function et(a) {
	                a = +a;
	                var b = 0, c = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                c = b;
	                h[c >> 3] = a;
	                d = Vt(+h[c >> 3]) | 0;
	                i = b;
	                return d | 0
	            }

	            function ft(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 128 | 0;
	                g = f;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f + 20 | 0;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[l >> 2] = 0;
	                while (1) {
	                    n = m + ((c[l >> 2] << 1) + 1) | 0;
	                    if (!((c[l >> 2] | 0) < 25 ? (c[l >> 2] | 0) < (c[k >> 2] | 0) : 0))break;
	                    a[n >> 0] = 32;
	                    a[m + (c[l >> 2] << 1) >> 0] = 32;
	                    c[l >> 2] = (c[l >> 2] | 0) + 1
	                }
	                a[n >> 0] = 0;
	                a[m + (c[l >> 2] << 1) >> 0] = 0;
	                if (!(c[j >> 2] | 0)) {
	                    l = c[h >> 2] | 0;
	                    c[g >> 2] = m;
	                    Ka(l | 0, 127912, g | 0) | 0;
	                    Ka(c[h >> 2] | 0, 131072, g | 0) | 0;
	                    i = f;
	                    return
	                }
	                if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 9 ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 13 : 0) {
	                    l = c[h >> 2] | 0;
	                    n = c[j >> 2] | 0;
	                    if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) == 2) {
	                        Ip(l, n, c[k >> 2] | 0);
	                        i = f;
	                        return
	                    } else {
	                        Kp(l, n, c[k >> 2] | 0);
	                        i = f;
	                        return
	                    }
	                }
	                k = c[h >> 2] | 0;
	                c[g >> 2] = m;
	                Ka(k | 0, 127912, g | 0) | 0;
	                Ka(c[h >> 2] | 0, 131088, g | 0) | 0;
	                i = f;
	                return
	            }

	            function gt(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 128 | 0;
	                g = f;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f + 20 | 0;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[l >> 2] = 0;
	                while (1) {
	                    n = m + ((c[l >> 2] << 1) + 1) | 0;
	                    if (!((c[l >> 2] | 0) < 25 ? (c[l >> 2] | 0) < (c[k >> 2] | 0) : 0))break;
	                    a[n >> 0] = 32;
	                    a[m + (c[l >> 2] << 1) >> 0] = 32;
	                    c[l >> 2] = (c[l >> 2] | 0) + 1
	                }
	                a[n >> 0] = 0;
	                a[m + (c[l >> 2] << 1) >> 0] = 0;
	                if (!(c[j >> 2] | 0)) {
	                    n = c[h >> 2] | 0;
	                    c[g >> 2] = m;
	                    Ka(n | 0, 127912, g | 0) | 0;
	                    Ka(c[h >> 2] | 0, 131040, g | 0) | 0;
	                    i = f;
	                    return
	                }
	                c[l >> 2] = 0;
	                while (1) {
	                    if ((c[l >> 2] | 0) >= (c[c[j >> 2] >> 2] | 0))break;
	                    n = c[h >> 2] | 0;
	                    c[g >> 2] = m;
	                    Ka(n | 0, 127912, g | 0) | 0;
	                    n = c[h >> 2] | 0;
	                    c[g >> 2] = (c[l >> 2] | 0) + 1;
	                    Ka(n | 0, 131064, g | 0) | 0;
	                    Rq(c[h >> 2] | 0, c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + (c[l >> 2] << 2) >> 2] | 0, (c[k >> 2] | 0) + 1 | 0);
	                    c[l >> 2] = (c[l >> 2] | 0) + 1
	                }
	                i = f;
	                return
	            }

	            function ht(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[c[d >> 2] >> 2] | 0)Wt(c[c[d >> 2] >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 4 >> 2] | 0)Wt(c[(c[d >> 2] | 0) + 4 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 8 >> 2] | 0)Wt(c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 12 >> 2] | 0)Wt(c[(c[d >> 2] | 0) + 12 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 16 >> 2] | 0)Wt(c[(c[d >> 2] | 0) + 16 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function it(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 224 | 0;
	                e = d;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d + 16 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                b = (c[g >> 2] | 0) != 0;
	                if (!(c[f >> 2] | 0))if (b) {
	                    a = c[g >> 2] | 0;
	                    c[e >> 2] = c[g >> 2];
	                    Xd(0, 0, 0, 0, 0, 12, 2, 3, 0, 0, a, 0, 0, 0, 0, 130976, e);
	                    i = d;
	                    return
	                } else {
	                    Xd(0, 0, 0, 0, 0, 12, 2, 3, 0, 0, 0, 0, 0, 0, 0, 131008, e);
	                    i = d;
	                    return
	                }
	                if (b) {
	                    c[e >> 2] = c[g >> 2];
	                    Cy(h, 200, 130976, e) | 0;
	                    e = my(h) | 0;
	                    c[(c[f >> 2] | 0) + 144 >> 2] = e
	                } else {
	                    e = my(131008) | 0;
	                    c[(c[f >> 2] | 0) + 144 >> 2] = e
	                }
	                c[(c[f >> 2] | 0) + 136 >> 2] = 12;
	                c[(c[f >> 2] | 0) + 140 >> 2] = 2;
	                if (!(c[(c[f >> 2] | 0) + 132 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                Ab[c[(c[f >> 2] | 0) + 132 >> 2] & 511](c[(c[f >> 2] | 0) + 128 >> 2] | 0, (c[f >> 2] | 0) + 136 | 0);
	                i = d;
	                return
	            }

	            function jt(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 200 >> 2] | 0) != 0 : 0) {
	                    c[g >> 2] = c[(c[e >> 2] | 0) + 200 >> 2];
	                    a:do switch (c[c[f >> 2] >> 2] | 0) {
	                        case 3:
	                        {
	                            if ((c[(c[g >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) >= (c[(c[g >> 2] | 0) + 32 >> 2] | 0) : 0) {
	                                l = 35;
	                                break a
	                            }
	                            if ((c[(c[g >> 2] | 0) + 12 >> 2] | 0) == 0 ? (e = Xt(10) | 0, c[(c[g >> 2] | 0) + 12 >> 2] = e, (c[(c[g >> 2] | 0) + 12 >> 2] | 0) == 0) : 0) {
	                                l = 54;
	                                break a
	                            }
	                            if ((Yt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[f >> 2] | 0, 0) | 0) == -1)l = 54;
	                            break
	                        }
	                        case 7:
	                        {
	                            if (c[(c[f >> 2] | 0) + 28 >> 2] | 0) {
	                                ev(c[(c[f >> 2] | 0) + 28 >> 2] | 0);
	                                l = 54
	                            } else l = 54;
	                            break
	                        }
	                        case 2:
	                        {
	                            if ((c[(c[g >> 2] | 0) + 8 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 4 >> 2] | 0) >= (c[(c[g >> 2] | 0) + 28 >> 2] | 0) : 0) {
	                                l = 35;
	                                break a
	                            }
	                            if ((c[(c[g >> 2] | 0) + 8 >> 2] | 0) == 0 ? (e = Xt(10) | 0, c[(c[g >> 2] | 0) + 8 >> 2] = e, (c[(c[g >> 2] | 0) + 8 >> 2] | 0) == 0) : 0) {
	                                l = 54;
	                                break a
	                            }
	                            if ((Yt(c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[f >> 2] | 0, 0) | 0) == -1)l = 54;
	                            break
	                        }
	                        case 9:
	                        case 1:
	                        {
	                            if (c[(c[f >> 2] | 0) + 4 >> 2] | 0) {
	                                e = c[f >> 2] | 0;
	                                if (c[(c[f >> 2] | 0) + 8 >> 2] | 0) {
	                                    c[e >> 2] = 9;
	                                    bt(c[(c[f >> 2] | 0) + 4 >> 2] | 0);
	                                    c[(c[f >> 2] | 0) + 4 >> 2] = 0;
	                                    l = 35;
	                                    break a
	                                }
	                                do if ((c[(c[e + 4 >> 2] | 0) + 4 >> 2] | 0) <= 40) {
	                                    if ((c[c[g >> 2] >> 2] | 0) != 0 ? (c[(c[c[g >> 2] >> 2] | 0) + 4 >> 2] | 0) >= (c[(c[g >> 2] | 0) + 20 >> 2] | 0) : 0)break;
	                                    if ((c[c[g >> 2] >> 2] | 0) == 0 ? (b = Xt(10) | 0, c[c[g >> 2] >> 2] = b, (c[c[g >> 2] >> 2] | 0) == 0) : 0) {
	                                        l = 54;
	                                        break a
	                                    }
	                                    if ((Yt(c[c[g >> 2] >> 2] | 0, c[f >> 2] | 0, 0) | 0) == -1) {
	                                        l = 54;
	                                        break a
	                                    } else break a
	                                } while (0);
	                                fr(c[(c[f >> 2] | 0) + 4 >> 2] | 0);
	                                c[(c[f >> 2] | 0) + 4 >> 2] = 0;
	                                l = 35
	                            } else l = 35;
	                            break
	                        }
	                        case 4:
	                        {
	                            if (c[(c[f >> 2] | 0) + 24 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 24 >> 2] | 0);
	                            if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 4 >> 2] | 0) + 4 >> 2] | 0) >= (c[(c[g >> 2] | 0) + 24 >> 2] | 0) : 0) {
	                                l = 35;
	                                break a
	                            }
	                            if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 0 ? (e = Xt(10) | 0, c[(c[g >> 2] | 0) + 4 >> 2] = e, (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 0) : 0) {
	                                l = 54;
	                                break a
	                            }
	                            if ((Yt(c[(c[g >> 2] | 0) + 4 >> 2] | 0, c[f >> 2] | 0, 0) | 0) == -1)l = 54;
	                            break
	                        }
	                        default:
	                            l = 54
	                    } while (0);
	                    do if ((l | 0) == 35) {
	                        if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) >= (c[(c[g >> 2] | 0) + 36 >> 2] | 0) : 0) {
	                            l = 54;
	                            break
	                        }
	                        if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) == 0 ? (e = Xt(10) | 0, c[(c[g >> 2] | 0) + 16 >> 2] = e, (c[(c[g >> 2] | 0) + 16 >> 2] | 0) == 0) : 0) {
	                            l = 54;
	                            break
	                        }
	                        if ((Yt(c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[f >> 2] | 0, 0) | 0) == -1)l = 54
	                    } while (0);
	                    if ((l | 0) == 54) {
	                        if (c[(c[f >> 2] | 0) + 4 >> 2] | 0)fr(c[(c[f >> 2] | 0) + 4 >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                        i = d;
	                        return
	                    }
	                    l = c[f >> 2] | 0;
	                    if (!(c[(c[f >> 2] | 0) + 4 >> 2] | 0)) {
	                        m = l + 0 | 0;
	                        n = m + 48 | 0;
	                        do {
	                            c[m >> 2] = 0;
	                            m = m + 4 | 0
	                        } while ((m | 0) < (n | 0));
	                        i = d;
	                        return
	                    }
	                    c[h >> 2] = c[l + 4 >> 2];
	                    b:do if ((c[c[h >> 2] >> 2] | 0) <= 1) {
	                        if (((c[c[h >> 2] >> 2] | 0) == 1 ? (c[c[(c[h >> 2] | 0) + 8 >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[c[(c[h >> 2] | 0) + 8 >> 2] >> 2] | 0) + 4 >> 2] | 0) == 18 : 0)_q(c[c[(c[h >> 2] | 0) + 8 >> 2] >> 2] | 0)
	                    } else {
	                        c[j >> 2] = 0;
	                        while (1) {
	                            if ((c[j >> 2] | 0) >= (c[c[h >> 2] >> 2] | 0))break b;
	                            c[k >> 2] = c[(c[(c[h >> 2] | 0) + 8 >> 2] | 0) + (c[j >> 2] << 2) >> 2];
	                            if ((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 18 : 0)_q(c[k >> 2] | 0);
	                            c[j >> 2] = (c[j >> 2] | 0) + 1
	                        }
	                    } while (0);
	                    c[c[h >> 2] >> 2] = 0;
	                    m = (c[f >> 2] | 0) + 0 | 0;
	                    n = m + 48 | 0;
	                    do {
	                        c[m >> 2] = 0;
	                        m = m + 4 | 0
	                    } while ((m | 0) < (n | 0));
	                    c[(c[f >> 2] | 0) + 4 >> 2] = c[h >> 2];
	                    i = d;
	                    return
	                }
	                Qq(c[f >> 2] | 0);
	                i = d;
	                return
	            }

	            function kt(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 18 : 0) {
	                    if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                        c[h >> 2] = Cb[c[135744 >> 2] & 511](24) | 0;
	                        if (!(c[h >> 2] | 0)) {
	                            it(0, 130952);
	                            c[e >> 2] = 0;
	                            j = c[e >> 2] | 0;
	                            i = d;
	                            return j | 0
	                        }
	                        b = c[h >> 2] | 0;
	                        c[b + 0 >> 2] = 0;
	                        c[b + 4 >> 2] = 0;
	                        c[b + 8 >> 2] = 0;
	                        c[b + 12 >> 2] = 0;
	                        c[b + 16 >> 2] = 0;
	                        c[b + 20 >> 2] = 0;
	                        c[(c[h >> 2] | 0) + 4 >> 2] = 18;
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            b = my(c[(c[g >> 2] | 0) + 8 >> 2] | 0) | 0;
	                            c[(c[h >> 2] | 0) + 8 >> 2] = b
	                        }
	                        if (c[(c[g >> 2] | 0) + 12 >> 2] | 0) {
	                            b = my(c[(c[g >> 2] | 0) + 12 >> 2] | 0) | 0;
	                            c[(c[h >> 2] | 0) + 12 >> 2] = b
	                        }
	                        c[c[h >> 2] >> 2] = c[f >> 2];
	                        c[e >> 2] = c[h >> 2];
	                        j = c[e >> 2] | 0;
	                        i = d;
	                        return j | 0
	                    }
	                    c[e >> 2] = c[g >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[e >> 2] = 0;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function lt(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                a:do if (!(c[g >> 2] | 0))c[e >> 2] = 0; else {
	                    do if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 200 >> 2] | 0) != 0 : 0) {
	                        b = c[c[g >> 2] >> 2] | 0;
	                        if ((b | 0) == 4) {
	                            c[e >> 2] = Dt(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 24 >> 2] | 0) | 0;
	                            break a
	                        } else if ((b | 0) == 3) {
	                            c[e >> 2] = wt(c[f >> 2] | 0, +h[(c[g >> 2] | 0) + 16 >> 3]) | 0;
	                            break a
	                        } else if ((b | 0) == 2) {
	                            c[e >> 2] = Ft(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0) | 0;
	                            break a
	                        } else if ((b | 0) == 1) {
	                            b = c[f >> 2] | 0;
	                            c[e >> 2] = At(b, er(0, c[(c[g >> 2] | 0) + 4 >> 2] | 0) | 0) | 0;
	                            break a
	                        } else break
	                    } while (0);
	                    c[e >> 2] = zr(c[g >> 2] | 0) | 0
	                } while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function mt(b, d, e) {
	                b = +b;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, j = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0;
	                f = i;
	                i = i + 144 | 0;
	                g = f + 16 | 0;
	                j = f + 8 | 0;
	                l = f + 68 | 0;
	                m = f + 64 | 0;
	                n = f + 100 | 0;
	                o = f + 60 | 0;
	                p = f + 56 | 0;
	                q = f + 52 | 0;
	                r = f + 72 | 0;
	                s = f + 48 | 0;
	                t = f + 44 | 0;
	                u = f + 40 | 0;
	                v = f + 36 | 0;
	                w = f;
	                x = f + 32 | 0;
	                h[j >> 3] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                e = Mq(+h[j >> 3]) | 0;
	                if ((e | 0) == -1) {
	                    if ((c[m >> 2] | 0) <= 10) {
	                        i = f;
	                        return
	                    }
	                    JT(c[l >> 2] | 0, c[m >> 2] | 0, 129032, g) | 0;
	                    i = f;
	                    return
	                } else if ((e | 0) == 1) {
	                    if ((c[m >> 2] | 0) <= 9) {
	                        i = f;
	                        return
	                    }
	                    JT(c[l >> 2] | 0, c[m >> 2] | 0, 129016, g) | 0;
	                    i = f;
	                    return
	                } else {
	                    if (Lq(+h[j >> 3]) | 0) {
	                        if ((c[m >> 2] | 0) <= 4) {
	                            i = f;
	                            return
	                        }
	                        JT(c[l >> 2] | 0, c[m >> 2] | 0, 129048, g) | 0;
	                        i = f;
	                        return
	                    }
	                    if (+h[j >> 3] == 0.0 ? (et(+h[j >> 3]) | 0) != 0 : 0) {
	                        JT(c[l >> 2] | 0, c[m >> 2] | 0, 129056, g) | 0;
	                        i = f;
	                        return
	                    }
	                    b = +h[j >> 3];
	                    if (+h[j >> 3] == +(~~+h[j >> 3] | 0)) {
	                        c[q >> 2] = ~~b;
	                        c[o >> 2] = c[l >> 2];
	                        a:do if (!(c[q >> 2] | 0)) {
	                            e = c[o >> 2] | 0;
	                            c[o >> 2] = e + 1;
	                            a[e >> 0] = 48
	                        } else {
	                            c[g >> 2] = c[q >> 2];
	                            JT(n, 29, 130840, g) | 0;
	                            c[p >> 2] = n;
	                            while (1) {
	                                if (!(a[c[p >> 2] >> 0] | 0))break a;
	                                if (((c[o >> 2] | 0) - (c[l >> 2] | 0) | 0) >= (c[m >> 2] | 0))break a;
	                                e = c[p >> 2] | 0;
	                                c[p >> 2] = e + 1;
	                                d = a[e >> 0] | 0;
	                                e = c[o >> 2] | 0;
	                                c[o >> 2] = e + 1;
	                                a[e >> 0] = d
	                            }
	                        } while (0);
	                        if (((c[o >> 2] | 0) - (c[l >> 2] | 0) | 0) < (c[m >> 2] | 0)) {
	                            a[c[o >> 2] >> 0] = 0;
	                            i = f;
	                            return
	                        }
	                        if ((c[m >> 2] | 0) <= 0) {
	                            i = f;
	                            return
	                        }
	                        c[o >> 2] = (c[o >> 2] | 0) + -1;
	                        a[c[o >> 2] >> 0] = 0;
	                        i = f;
	                        return
	                    }
	                    h[w >> 3] = +R(+b);
	                    b:do if ((+h[w >> 3] > 1.0e9 | +h[w >> 3] < 1.0e-05) & +h[w >> 3] != 0.0) {
	                        c[s >> 2] = 21;
	                        c[t >> 2] = 14;
	                        o = c[t >> 2] | 0;
	                        b = +h[j >> 3];
	                        c[g >> 2] = c[s >> 2];
	                        c[g + 4 >> 2] = o;
	                        o = g + 8 | 0;
	                        h[k >> 3] = b;
	                        c[o >> 2] = c[k >> 2];
	                        c[o + 4 >> 2] = c[k + 4 >> 2];
	                        c[x >> 2] = JT(r, 28, 130848, g) | 0;
	                        while (1) {
	                            if ((c[x >> 2] | 0) <= 0)break b;
	                            if ((a[r + (c[x >> 2] | 0) >> 0] | 0) == 101)break b;
	                            c[x >> 2] = (c[x >> 2] | 0) + -1
	                        }
	                    } else {
	                        do if (+h[w >> 3] > 0.0) {
	                            c[s >> 2] = ~~+yT(+h[w >> 3]);
	                            o = 15 - (c[s >> 2] | 0) | 0;
	                            if ((c[s >> 2] | 0) > 0) {
	                                c[t >> 2] = o - 1;
	                                break
	                            } else {
	                                c[t >> 2] = o;
	                                break
	                            }
	                        } else c[t >> 2] = 1; while (0);
	                        b = +h[j >> 3];
	                        c[g >> 2] = c[t >> 2];
	                        o = g + 4 | 0;
	                        h[k >> 3] = b;
	                        c[o >> 2] = c[k >> 2];
	                        c[o + 4 >> 2] = c[k + 4 >> 2];
	                        c[x >> 2] = JT(r, 28, 130856, g) | 0
	                    } while (0);
	                    while (1) {
	                        if ((a[r >> 0] | 0) != 32)break;
	                        c[u >> 2] = r;
	                        while (1) {
	                            g = a[(c[u >> 2] | 0) + 1 >> 0] | 0;
	                            a[c[u >> 2] >> 0] = g;
	                            if (!(g << 24 >> 24))break;
	                            c[u >> 2] = (c[u >> 2] | 0) + 1
	                        }
	                        c[x >> 2] = (c[x >> 2] | 0) + -1
	                    }
	                    c[v >> 2] = r + (c[x >> 2] | 0);
	                    c[u >> 2] = c[v >> 2];
	                    do {
	                        g = (c[u >> 2] | 0) + -1 | 0;
	                        c[u >> 2] = g
	                    } while ((a[g >> 0] | 0) == 48);
	                    if ((a[c[u >> 2] >> 0] | 0) != 46)c[u >> 2] = (c[u >> 2] | 0) + 1;
	                    do {
	                        g = c[v >> 2] | 0;
	                        c[v >> 2] = g + 1;
	                        t = a[g >> 0] | 0;
	                        g = c[u >> 2] | 0;
	                        c[u >> 2] = g + 1;
	                        a[g >> 0] = t
	                    } while ((t << 24 >> 24 | 0) != 0);
	                    c[x >> 2] = (ZT(r | 0) | 0) + 1;
	                    if ((c[x >> 2] | 0) > (c[m >> 2] | 0)) {
	                        a[r + ((c[m >> 2] | 0) - 1) >> 0] = 0;
	                        c[x >> 2] = c[m >> 2]
	                    }
	                    fU(c[l >> 2] | 0, r | 0, c[x >> 2] | 0) | 0;
	                    i = f;
	                    return
	                }
	            }

	            function nt(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    b = c[f >> 2] | 0;
	                    Tq(b, yt(c[(c[f >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) | 0) | 0;
	                    c[g >> 2] = 1
	                }
	                if (!(c[f >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                b = c[f >> 2] | 0;
	                if ((c[g >> 2] | 0) != 1) {
	                    Nq(b, 12);
	                    i = e;
	                    return
	                }
	                g = c[f >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[f >> 2] | 0) + 44 >> 2] | 0) + 1 | 0)) {
	                    Nq(g, 23);
	                    i = e;
	                    return
	                }
	                do if (c[g + 16 >> 2] | 0) {
	                    if ((c[c[(c[f >> 2] | 0) + 16 >> 2] >> 2] | 0) != 1 ? (c[c[(c[f >> 2] | 0) + 16 >> 2] >> 2] | 0) != 9 : 0)break;
	                    c[h >> 2] = Sq(c[f >> 2] | 0) | 0;
	                    do if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 0 ? (c[c[(c[h >> 2] | 0) + 4 >> 2] >> 2] | 0) != 0 : 0) {
	                        c[j >> 2] = 0;
	                        if (((c[(c[(c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0) + -1 | 0) >>> 0 >= 2) {
	                            b = c[f >> 2] | 0;
	                            Tq(b, yt(c[(c[f >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) | 0) | 0;
	                            ps(c[f >> 2] | 0, 1);
	                            break
	                        }
	                        if ((d[c[(c[(c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) + 8 >> 2] >> 0] | 0 | 0) == 32) {
	                            b = c[f >> 2] | 0;
	                            Tq(b, Ct(c[(c[f >> 2] | 0) + 12 >> 2] | 0, 128928) | 0) | 0;
	                            break
	                        }
	                        if ((c[(c[(c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[(c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                            c[k >> 2] = Bh(c[(c[(c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) + 8 >> 2] | 0, c[(c[(c[(c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0, 0, 0) | 0;
	                            if ((c[k >> 2] | 0) == (c[(c[(c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) + 8 >> 2] | 0))c[k >> 2] = my(c[(c[(c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) + 8 >> 2] | 0) | 0;
	                            b = c[f >> 2] | 0;
	                            if (c[k >> 2] | 0) {
	                                Tq(b, Et(c[(c[f >> 2] | 0) + 12 >> 2] | 0, c[k >> 2] | 0) | 0) | 0;
	                                break
	                            }
	                            Nq(b, 15);
	                            i = e;
	                            return
	                        }
	                        b = c[f >> 2] | 0;
	                        Tq(b, Dt(c[(c[f >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) + 8 >> 2] | 0) | 0) | 0
	                    } else l = 14; while (0);
	                    if ((l | 0) == 14) {
	                        b = c[f >> 2] | 0;
	                        Tq(b, Ct(c[(c[f >> 2] | 0) + 12 >> 2] | 0, 128928) | 0) | 0
	                    }
	                    jt(c[(c[f >> 2] | 0) + 12 >> 2] | 0, c[h >> 2] | 0);
	                    i = e;
	                    return
	                } while (0);
	                Nq(c[f >> 2] | 0, 11);
	                i = e;
	                return
	            }

	            function ot(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                n = f + 24 | 0;
	                c[g >> 2] = b;
	                c[h >> 2] = e;
	                if (!(c[g >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                e = c[g >> 2] | 0;
	                if ((c[h >> 2] | 0) != 2) {
	                    Nq(e, 12);
	                    i = f;
	                    return
	                }
	                h = c[g >> 2] | 0;
	                if ((c[e + 20 >> 2] | 0) < ((c[(c[g >> 2] | 0) + 44 >> 2] | 0) + 2 | 0)) {
	                    Nq(h, 23);
	                    i = f;
	                    return
	                }
	                c[k >> 2] = Uq(h) | 0;
	                if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) != 4 : 0)rs(c[g >> 2] | 0, 1);
	                c[j >> 2] = Sq(c[g >> 2] | 0) | 0;
	                c[l >> 2] = Ly() | 0;
	                a[n >> 0] = 37;
	                a[n + 3 >> 0] = 0;
	                a:do if (c[l >> 2] | 0) {
	                    c[m >> 2] = c[(c[j >> 2] | 0) + 24 >> 2];
	                    while (1) {
	                        if (!(a[c[m >> 2] >> 0] | 0))break a;
	                        if ((d[c[m >> 2] >> 0] | 0) >= 65 ? (d[c[m >> 2] >> 0] | 0) <= 90 : 0)o = 51; else o = 14;
	                        b:do if ((o | 0) == 14) {
	                            o = 0;
	                            if ((d[c[m >> 2] >> 0] | 0) >= 97 ? (d[c[m >> 2] >> 0] | 0) <= 122 : 0) {
	                                o = 51;
	                                break
	                            }
	                            if ((d[c[m >> 2] >> 0] | 0) >= 48 ? (d[c[m >> 2] >> 0] | 0) <= 57 : 0) {
	                                o = 51;
	                                break
	                            }
	                            if ((((((((d[c[m >> 2] >> 0] | 0) != 45 ? (d[c[m >> 2] >> 0] | 0) != 95 : 0) ? (d[c[m >> 2] >> 0] | 0) != 46 : 0) ? (d[c[m >> 2] >> 0] | 0) != 33 : 0) ? (d[c[m >> 2] >> 0] | 0) != 126 : 0) ? (d[c[m >> 2] >> 0] | 0) != 42 : 0) ? (d[c[m >> 2] >> 0] | 0) != 39 : 0) ? (d[c[m >> 2] >> 0] | 0) != 40 : 0) {
	                                if ((d[c[m >> 2] >> 0] | 0) == 41) {
	                                    o = 51;
	                                    break
	                                }
	                                c:do if ((d[c[m >> 2] >> 0] | 0) == 37) {
	                                    if (!((d[(c[m >> 2] | 0) + 1 >> 0] | 0) >= 65 ? (d[(c[m >> 2] | 0) + 1 >> 0] | 0) <= 70 : 0))o = 30;
	                                    do if ((o | 0) == 30) {
	                                        o = 0;
	                                        if ((d[(c[m >> 2] | 0) + 1 >> 0] | 0) >= 97 ? (d[(c[m >> 2] | 0) + 1 >> 0] | 0) <= 102 : 0)break;
	                                        if ((d[(c[m >> 2] | 0) + 1 >> 0] | 0) < 48)break c;
	                                        if ((d[(c[m >> 2] | 0) + 1 >> 0] | 0) > 57)break c
	                                    } while (0);
	                                    if ((d[(c[m >> 2] | 0) + 2 >> 0] | 0) >= 65 ? (d[(c[m >> 2] | 0) + 2 >> 0] | 0) <= 70 : 0) {
	                                        o = 51;
	                                        break b
	                                    }
	                                    if ((d[(c[m >> 2] | 0) + 2 >> 0] | 0) >= 97 ? (d[(c[m >> 2] | 0) + 2 >> 0] | 0) <= 102 : 0) {
	                                        o = 51;
	                                        break b
	                                    }
	                                    if ((d[(c[m >> 2] | 0) + 2 >> 0] | 0) < 48)break;
	                                    if ((d[(c[m >> 2] | 0) + 2 >> 0] | 0) <= 57) {
	                                        o = 51;
	                                        break b
	                                    }
	                                } while (0);
	                                if (!(c[k >> 2] | 0)) {
	                                    if ((d[c[m >> 2] >> 0] | 0) == 59) {
	                                        o = 51;
	                                        break
	                                    }
	                                    if ((d[c[m >> 2] >> 0] | 0) == 47) {
	                                        o = 51;
	                                        break
	                                    }
	                                    if ((d[c[m >> 2] >> 0] | 0) == 63) {
	                                        o = 51;
	                                        break
	                                    }
	                                    if ((d[c[m >> 2] >> 0] | 0) == 58) {
	                                        o = 51;
	                                        break
	                                    }
	                                    if ((d[c[m >> 2] >> 0] | 0) == 64) {
	                                        o = 51;
	                                        break
	                                    }
	                                    if ((d[c[m >> 2] >> 0] | 0) == 38) {
	                                        o = 51;
	                                        break
	                                    }
	                                    if ((d[c[m >> 2] >> 0] | 0) == 61) {
	                                        o = 51;
	                                        break
	                                    }
	                                    if ((d[c[m >> 2] >> 0] | 0) == 43) {
	                                        o = 51;
	                                        break
	                                    }
	                                    if ((d[c[m >> 2] >> 0] | 0) == 36) {
	                                        o = 51;
	                                        break
	                                    }
	                                    if ((d[c[m >> 2] >> 0] | 0) == 44) {
	                                        o = 51;
	                                        break
	                                    }
	                                }
	                                h = d[c[m >> 2] >> 0] >> 4;
	                                if ((d[c[m >> 2] >> 0] >> 4 | 0) < 10)a[n + 1 >> 0] = 48 + h; else a[n + 1 >> 0] = 55 + h;
	                                h = d[c[m >> 2] >> 0] & 15;
	                                if ((d[c[m >> 2] >> 0] & 15 | 0) < 10)a[n + 2 >> 0] = 48 + h; else a[n + 2 >> 0] = 55 + h;
	                                cz(c[l >> 2] | 0, n, 3) | 0
	                            } else o = 51
	                        } while (0);
	                        if ((o | 0) == 51) {
	                            o = 0;
	                            cz(c[l >> 2] | 0, c[m >> 2] | 0, 1) | 0
	                        }
	                        c[m >> 2] = (c[m >> 2] | 0) + 1
	                    }
	                } while (0);
	                m = c[g >> 2] | 0;
	                o = c[(c[g >> 2] | 0) + 12 >> 2] | 0;
	                Tq(m, Dt(o, Vy(c[l >> 2] | 0) | 0) | 0) | 0;
	                Ry(c[l >> 2] | 0);
	                jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[j >> 2] | 0);
	                i = f;
	                return
	            }

	            function pt() {
	                var a = 0, b = 0, d = 0, e = 0, f = 0;
	                a = i;
	                i = i + 16 | 0;
	                b = a + 4 | 0;
	                d = a;
	                c[d >> 2] = Cb[c[135744 >> 2] & 511](28) | 0;
	                if (!(c[d >> 2] | 0)) {
	                    it(0, 130792);
	                    c[b >> 2] = 0;
	                    e = c[b >> 2] | 0;
	                    i = a;
	                    return e | 0
	                }
	                f = c[d >> 2] | 0;
	                c[f + 0 >> 2] = 0;
	                c[f + 4 >> 2] = 0;
	                c[f + 8 >> 2] = 0;
	                c[f + 12 >> 2] = 0;
	                c[f + 16 >> 2] = 0;
	                c[f + 20 >> 2] = 0;
	                c[f + 24 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 4 >> 2] = 10;
	                c[c[d >> 2] >> 2] = 0;
	                f = Cb[c[135744 >> 2] & 511]((c[(c[d >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0;
	                c[(c[d >> 2] | 0) + 8 >> 2] = f;
	                if (!(c[(c[d >> 2] | 0) + 8 >> 2] | 0)) {
	                    it(0, 130816);
	                    zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                    c[b >> 2] = 0;
	                    e = c[b >> 2] | 0;
	                    i = a;
	                    return e | 0
	                } else {
	                    cU(c[(c[d >> 2] | 0) + 8 >> 2] | 0, 0, (c[(c[d >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0;
	                    c[(c[d >> 2] | 0) + 12 >> 2] = -1;
	                    c[b >> 2] = c[d >> 2];
	                    e = c[b >> 2] | 0;
	                    i = a;
	                    return e | 0
	                }
	                return 0
	            }

	            function qt(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                e = i;
	                i = i + 64 | 0;
	                f = e + 48 | 0;
	                g = e + 44 | 0;
	                h = e + 40 | 0;
	                j = e + 36 | 0;
	                k = e + 32 | 0;
	                l = e + 28 | 0;
	                m = e + 24 | 0;
	                n = e + 20 | 0;
	                o = e + 16 | 0;
	                p = e + 12 | 0;
	                q = e + 8 | 0;
	                r = e + 4 | 0;
	                s = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[q >> 2] = 0;
	                do if (c[g >> 2] | 0) {
	                    if ((c[c[g >> 2] >> 2] | 0) != 1 ? (c[c[g >> 2] >> 2] | 0) != 9 : 0)break;
	                    do if (c[h >> 2] | 0) {
	                        if ((c[c[h >> 2] >> 2] | 0) != 1 ? (c[c[h >> 2] >> 2] | 0) != 9 : 0)break;
	                        c[r >> 2] = c[(c[g >> 2] | 0) + 4 >> 2];
	                        c[s >> 2] = c[(c[h >> 2] | 0) + 4 >> 2];
	                        if ((c[r >> 2] | 0) != 0 ? (c[c[r >> 2] >> 2] | 0) > 0 : 0) {
	                            if ((c[s >> 2] | 0) != 0 ? (c[c[s >> 2] >> 2] | 0) > 0 : 0) {
	                                a:do if (!(c[j >> 2] | 0)) {
	                                    c[k >> 2] = 0;
	                                    b:while (1) {
	                                        if ((c[k >> 2] | 0) >= (c[c[r >> 2] >> 2] | 0))break a;
	                                        c[l >> 2] = 0;
	                                        while (1) {
	                                            t = c[k >> 2] | 0;
	                                            if ((c[l >> 2] | 0) >= (c[c[s >> 2] >> 2] | 0))break;
	                                            if ((c[(c[(c[r >> 2] | 0) + 8 >> 2] | 0) + (t << 2) >> 2] | 0) == (c[(c[(c[s >> 2] | 0) + 8 >> 2] | 0) + (c[l >> 2] << 2) >> 2] | 0))break b;
	                                            c[l >> 2] = (c[l >> 2] | 0) + 1
	                                        }
	                                        c[k >> 2] = t + 1
	                                    }
	                                    c[f >> 2] = 1;
	                                    u = c[f >> 2] | 0;
	                                    i = e;
	                                    return u | 0
	                                } while (0);
	                                c[o >> 2] = Cb[c[135744 >> 2] & 511](c[c[r >> 2] >> 2] << 2) | 0;
	                                if (!(c[o >> 2] | 0)) {
	                                    it(0, 130768);
	                                    c[f >> 2] = 0;
	                                    u = c[f >> 2] | 0;
	                                    i = e;
	                                    return u | 0
	                                }
	                                c[m >> 2] = Cb[c[135744 >> 2] & 511](c[c[r >> 2] >> 2] << 2) | 0;
	                                if (!(c[m >> 2] | 0)) {
	                                    it(0, 130768);
	                                    zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                                    c[f >> 2] = 0;
	                                    u = c[f >> 2] | 0;
	                                    i = e;
	                                    return u | 0
	                                }
	                                cU(c[o >> 2] | 0, 0, c[c[r >> 2] >> 2] << 2 | 0) | 0;
	                                c[p >> 2] = Cb[c[135744 >> 2] & 511](c[c[s >> 2] >> 2] << 2) | 0;
	                                if (!(c[p >> 2] | 0)) {
	                                    it(0, 130768);
	                                    zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                                    zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                                    c[f >> 2] = 0;
	                                    u = c[f >> 2] | 0;
	                                    i = e;
	                                    return u | 0
	                                }
	                                c[n >> 2] = Cb[c[135744 >> 2] & 511](c[c[s >> 2] >> 2] << 2) | 0;
	                                if (!(c[n >> 2] | 0)) {
	                                    it(0, 130768);
	                                    zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                                    zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                                    zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                                    c[f >> 2] = 0;
	                                    u = c[f >> 2] | 0;
	                                    i = e;
	                                    return u | 0
	                                }
	                                cU(c[p >> 2] | 0, 0, c[c[s >> 2] >> 2] << 2 | 0) | 0;
	                                c[k >> 2] = 0;
	                                while (1) {
	                                    if ((c[k >> 2] | 0) >= (c[c[r >> 2] >> 2] | 0))break;
	                                    d = Zt(c[(c[(c[r >> 2] | 0) + 8 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) | 0;
	                                    c[(c[m >> 2] | 0) + (c[k >> 2] << 2) >> 2] = d;
	                                    c[l >> 2] = 0;
	                                    while (1) {
	                                        if ((c[l >> 2] | 0) >= (c[c[s >> 2] >> 2] | 0))break;
	                                        if (!(c[k >> 2] | 0)) {
	                                            d = Zt(c[(c[(c[s >> 2] | 0) + 8 >> 2] | 0) + (c[l >> 2] << 2) >> 2] | 0) | 0;
	                                            c[(c[n >> 2] | 0) + (c[l >> 2] << 2) >> 2] = d
	                                        }
	                                        if ((c[(c[m >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) != (c[(c[n >> 2] | 0) + (c[l >> 2] << 2) >> 2] | 0)) {
	                                            if (c[j >> 2] | 0) {
	                                                v = 40;
	                                                break
	                                            }
	                                        } else {
	                                            if (!(c[(c[o >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0)) {
	                                                d = _i(c[(c[(c[r >> 2] | 0) + 8 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) | 0;
	                                                c[(c[o >> 2] | 0) + (c[k >> 2] << 2) >> 2] = d
	                                            }
	                                            if (!(c[(c[p >> 2] | 0) + (c[l >> 2] << 2) >> 2] | 0)) {
	                                                d = _i(c[(c[(c[s >> 2] | 0) + 8 >> 2] | 0) + (c[l >> 2] << 2) >> 2] | 0) | 0;
	                                                c[(c[p >> 2] | 0) + (c[l >> 2] << 2) >> 2] = d
	                                            }
	                                            d = qy(c[(c[o >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, c[(c[p >> 2] | 0) + (c[l >> 2] << 2) >> 2] | 0) | 0;
	                                            c[q >> 2] = d ^ c[j >> 2];
	                                            if (c[q >> 2] | 0)break
	                                        }
	                                        c[l >> 2] = (c[l >> 2] | 0) + 1
	                                    }
	                                    if ((v | 0) == 40) {
	                                        v = 0;
	                                        c[q >> 2] = 1
	                                    }
	                                    if (c[q >> 2] | 0)break;
	                                    c[k >> 2] = (c[k >> 2] | 0) + 1
	                                }
	                                c[k >> 2] = 0;
	                                while (1) {
	                                    if ((c[k >> 2] | 0) >= (c[c[r >> 2] >> 2] | 0))break;
	                                    if (c[(c[o >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[o >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0);
	                                    c[k >> 2] = (c[k >> 2] | 0) + 1
	                                }
	                                c[l >> 2] = 0;
	                                while (1) {
	                                    if ((c[l >> 2] | 0) >= (c[c[s >> 2] >> 2] | 0))break;
	                                    if (c[(c[p >> 2] | 0) + (c[l >> 2] << 2) >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[p >> 2] | 0) + (c[l >> 2] << 2) >> 2] | 0);
	                                    c[l >> 2] = (c[l >> 2] | 0) + 1
	                                }
	                                zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                                zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                                zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                                zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                                c[f >> 2] = c[q >> 2];
	                                u = c[f >> 2] | 0;
	                                i = e;
	                                return u | 0
	                            }
	                            c[f >> 2] = 0;
	                            u = c[f >> 2] | 0;
	                            i = e;
	                            return u | 0
	                        }
	                        c[f >> 2] = 0;
	                        u = c[f >> 2] | 0;
	                        i = e;
	                        return u | 0
	                    } while (0);
	                    c[f >> 2] = 0;
	                    u = c[f >> 2] | 0;
	                    i = e;
	                    return u | 0
	                } while (0);
	                c[f >> 2] = 0;
	                u = c[f >> 2] | 0;
	                i = e;
	                return u | 0
	            }

	            function rt(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = +d;
	                e = e | 0;
	                var f = 0, g = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                f = i;
	                i = i + 64 | 0;
	                g = f + 48 | 0;
	                j = f + 44 | 0;
	                k = f + 40 | 0;
	                l = f + 8 | 0;
	                m = f + 36 | 0;
	                n = f + 32 | 0;
	                o = f + 28 | 0;
	                p = f + 24 | 0;
	                q = f + 20 | 0;
	                r = f + 16 | 0;
	                s = f;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                h[l >> 3] = d;
	                c[m >> 2] = e;
	                c[o >> 2] = 0;
	                do if (c[k >> 2] | 0) {
	                    if ((c[c[k >> 2] >> 2] | 0) != 1 ? (c[c[k >> 2] >> 2] | 0) != 9 : 0)break;
	                    c[p >> 2] = c[(c[k >> 2] | 0) + 4 >> 2];
	                    a:do if (c[p >> 2] | 0) {
	                        c[n >> 2] = 0;
	                        b:while (1) {
	                            if ((c[n >> 2] | 0) >= (c[c[p >> 2] >> 2] | 0))break a;
	                            c[q >> 2] = ir(c[(c[(c[p >> 2] | 0) + 8 >> 2] | 0) + (c[n >> 2] << 2) >> 2] | 0) | 0;
	                            do if (c[q >> 2] | 0) {
	                                e = c[j >> 2] | 0;
	                                Tq(e, Dt(c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[q >> 2] | 0) | 0) | 0;
	                                zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                                Tr(c[j >> 2] | 0, 1);
	                                c[r >> 2] = Sq(c[j >> 2] | 0) | 0;
	                                h[s >> 3] = +h[(c[r >> 2] | 0) + 16 >> 3];
	                                jt(c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[r >> 2] | 0);
	                                e = (Lq(+h[s >> 3]) | 0) != 0;
	                                b = (c[m >> 2] | 0) != 0;
	                                if (e) {
	                                    if (!b)break;
	                                    c[o >> 2] = 1;
	                                    break
	                                }
	                                if (!b ? +h[s >> 3] == +h[l >> 3] : 0) {
	                                    t = 12;
	                                    break b
	                                }
	                                if ((c[m >> 2] | 0) != 0 ? +h[s >> 3] != +h[l >> 3] : 0) {
	                                    t = 15;
	                                    break b
	                                }
	                            } while (0);
	                            c[n >> 2] = (c[n >> 2] | 0) + 1
	                        }
	                        if ((t | 0) == 12) {
	                            c[o >> 2] = 1;
	                            break
	                        } else if ((t | 0) == 15) {
	                            c[o >> 2] = 1;
	                            break
	                        }
	                    } while (0);
	                    c[g >> 2] = c[o >> 2];
	                    u = c[g >> 2] | 0;
	                    i = f;
	                    return u | 0
	                } while (0);
	                c[g >> 2] = 0;
	                u = c[g >> 2] | 0;
	                i = f;
	                return u | 0
	            }

	            function st(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 28 | 0;
	                g = e + 24 | 0;
	                h = e + 20 | 0;
	                j = e + 16 | 0;
	                k = e + 12 | 0;
	                l = e + 8 | 0;
	                m = e + 4 | 0;
	                n = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                do if (!((c[h >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0)) {
	                    if ((c[c[g >> 2] >> 2] | 0) != 1 ? (c[c[g >> 2] >> 2] | 0) != 9 : 0)break;
	                    c[l >> 2] = c[(c[g >> 2] | 0) + 4 >> 2];
	                    if ((c[l >> 2] | 0) != 0 ? (c[c[l >> 2] >> 2] | 0) > 0 : 0) {
	                        c[n >> 2] = _t(c[h >> 2] | 0) | 0;
	                        c[k >> 2] = 0;
	                        a:while (1) {
	                            if ((c[k >> 2] | 0) >= (c[c[l >> 2] >> 2] | 0)) {
	                                o = 28;
	                                break
	                            }
	                            d = Zt(c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) | 0;
	                            do if ((d | 0) == (c[n >> 2] | 0)) {
	                                c[m >> 2] = _i(c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) | 0;
	                                if ((c[m >> 2] | 0) != 0 ? (qy(c[h >> 2] | 0, c[m >> 2] | 0) | 0) != 0 : 0) {
	                                    zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                                    if (c[j >> 2] | 0)break; else {
	                                        o = 14;
	                                        break a
	                                    }
	                                }
	                                if ((c[m >> 2] | 0) == 0 ? (qy(c[h >> 2] | 0, 128928) | 0) != 0 : 0)if (c[j >> 2] | 0)break; else {
	                                    o = 18;
	                                    break a
	                                }
	                                p = (c[m >> 2] | 0) != 0;
	                                if (c[j >> 2] | 0) {
	                                    o = 20;
	                                    break a
	                                }
	                                if (p)zb[c[135736 >> 2] & 511](c[m >> 2] | 0)
	                            } else if (c[j >> 2] | 0) {
	                                o = 26;
	                                break a
	                            } while (0);
	                            c[k >> 2] = (c[k >> 2] | 0) + 1
	                        }
	                        if ((o | 0) == 14) {
	                            c[f >> 2] = 1;
	                            q = c[f >> 2] | 0;
	                            i = e;
	                            return q | 0
	                        } else if ((o | 0) == 18) {
	                            c[f >> 2] = 1;
	                            q = c[f >> 2] | 0;
	                            i = e;
	                            return q | 0
	                        } else if ((o | 0) == 20) {
	                            if (p)zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                            c[f >> 2] = 1;
	                            q = c[f >> 2] | 0;
	                            i = e;
	                            return q | 0
	                        } else if ((o | 0) == 26) {
	                            c[f >> 2] = 1;
	                            q = c[f >> 2] | 0;
	                            i = e;
	                            return q | 0
	                        } else if ((o | 0) == 28) {
	                            c[f >> 2] = 0;
	                            q = c[f >> 2] | 0;
	                            i = e;
	                            return q | 0
	                        }
	                    }
	                    c[f >> 2] = 0;
	                    q = c[f >> 2] | 0;
	                    i = e;
	                    return q | 0
	                } while (0);
	                c[f >> 2] = 0;
	                q = c[f >> 2] | 0;
	                i = e;
	                return q | 0
	            }

	            function tt(a, b, e) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, j = 0, k = 0, l = 0, m = 0, n = 0.0;
	                f = i;
	                i = i + 32 | 0;
	                g = f;
	                j = f + 20 | 0;
	                k = f + 16 | 0;
	                l = f + 12 | 0;
	                m = f + 8 | 0;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = e;
	                c[m >> 2] = 0;
	                a:do switch (c[c[k >> 2] >> 2] | 0) {
	                    case 3:
	                    {
	                        switch (c[c[l >> 2] >> 2] | 0) {
	                            case 4:
	                            {
	                                Tq(c[j >> 2] | 0, c[l >> 2] | 0) | 0;
	                                Tr(c[j >> 2] | 0, 1);
	                                c[l >> 2] = Sq(c[j >> 2] | 0) | 0;
	                                break
	                            }
	                            case 3:
	                                break;
	                            case 6:
	                            case 5:
	                            case 8:
	                            case 7:
	                            {
	                                e = c[33976] | 0;
	                                b = c[33980] | 0;
	                                c[g >> 2] = 128552;
	                                c[g + 4 >> 2] = 7047;
	                                Db[e & 511](b, 129064, g);
	                                break a;
	                                break
	                            }
	                            case 2:
	                            {
	                                c[m >> 2] = (c[(c[l >> 2] | 0) + 8 >> 2] | 0) == (Ir(+h[(c[k >> 2] | 0) + 16 >> 3]) | 0) & 1;
	                                break a;
	                                break
	                            }
	                            default:
	                                break a
	                        }
	                        if ((Lq(+h[(c[k >> 2] | 0) + 16 >> 3]) | 0) == 0 ? (Lq(+h[(c[l >> 2] | 0) + 16 >> 3]) | 0) == 0 : 0) {
	                            if ((Mq(+h[(c[k >> 2] | 0) + 16 >> 3]) | 0) == 1)if ((Mq(+h[(c[l >> 2] | 0) + 16 >> 3]) | 0) == 1) {
	                                c[m >> 2] = 1;
	                                break a
	                            } else {
	                                c[m >> 2] = 0;
	                                break a
	                            }
	                            b = (Mq(+h[(c[k >> 2] | 0) + 16 >> 3]) | 0) == -1;
	                            e = Mq(+h[(c[l >> 2] | 0) + 16 >> 3]) | 0;
	                            if (b)if ((e | 0) == -1) {
	                                c[m >> 2] = 1;
	                                break a
	                            } else {
	                                c[m >> 2] = 0;
	                                break a
	                            }
	                            if ((e | 0) == 1)if ((Mq(+h[(c[k >> 2] | 0) + 16 >> 3]) | 0) == 1) {
	                                c[m >> 2] = 1;
	                                break a
	                            } else {
	                                c[m >> 2] = 0;
	                                break a
	                            }
	                            e = (Mq(+h[(c[l >> 2] | 0) + 16 >> 3]) | 0) == -1;
	                            n = +h[(c[k >> 2] | 0) + 16 >> 3];
	                            if (!e) {
	                                c[m >> 2] = n == +h[(c[l >> 2] | 0) + 16 >> 3] & 1;
	                                break a
	                            }
	                            if ((Mq(n) | 0) == -1) {
	                                c[m >> 2] = 1;
	                                break a
	                            } else {
	                                c[m >> 2] = 0;
	                                break a
	                            }
	                        }
	                        c[m >> 2] = 0;
	                        break
	                    }
	                    case 6:
	                    case 5:
	                    case 8:
	                    case 7:
	                    {
	                        e = c[33976] | 0;
	                        b = c[33980] | 0;
	                        c[g >> 2] = 128552;
	                        c[g + 4 >> 2] = 7119;
	                        Db[e & 511](b, 129064, g);
	                        break
	                    }
	                    case 2:
	                    {
	                        switch (c[c[l >> 2] >> 2] | 0) {
	                            case 6:
	                            case 5:
	                            case 8:
	                            case 7:
	                            {
	                                b = c[33976] | 0;
	                                e = c[33980] | 0;
	                                c[g >> 2] = 128552;
	                                c[g + 4 >> 2] = 6990;
	                                Db[b & 511](e, 129064, g);
	                                break a;
	                                break
	                            }
	                            case 3:
	                            {
	                                c[m >> 2] = (c[(c[k >> 2] | 0) + 8 >> 2] | 0) == (Ir(+h[(c[l >> 2] | 0) + 16 >> 3]) | 0) & 1;
	                                break a;
	                                break
	                            }
	                            case 2:
	                            {
	                                c[m >> 2] = (c[(c[k >> 2] | 0) + 8 >> 2] | 0) == (c[(c[l >> 2] | 0) + 8 >> 2] | 0) & 1;
	                                break a;
	                                break
	                            }
	                            case 4:
	                            {
	                                if ((c[(c[l >> 2] | 0) + 24 >> 2] | 0) != 0 ? (d[c[(c[l >> 2] | 0) + 24 >> 2] >> 0] | 0 | 0) != 0 : 0)c[m >> 2] = 1; else c[m >> 2] = 0;
	                                c[m >> 2] = (c[(c[k >> 2] | 0) + 8 >> 2] | 0) == (c[m >> 2] | 0) & 1;
	                                break a;
	                                break
	                            }
	                            default:
	                                break a
	                        }
	                        break
	                    }
	                    case 4:
	                    {
	                        switch (c[c[l >> 2] >> 2] | 0) {
	                            case 3:
	                            {
	                                Tq(c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                                Tr(c[j >> 2] | 0, 1);
	                                c[k >> 2] = Sq(c[j >> 2] | 0) | 0;
	                                if ((Lq(+h[(c[k >> 2] | 0) + 16 >> 3]) | 0) == 0 ? (Lq(+h[(c[l >> 2] | 0) + 16 >> 3]) | 0) == 0 : 0) {
	                                    if ((Mq(+h[(c[k >> 2] | 0) + 16 >> 3]) | 0) == 1)if ((Mq(+h[(c[l >> 2] | 0) + 16 >> 3]) | 0) == 1) {
	                                        c[m >> 2] = 1;
	                                        break a
	                                    } else {
	                                        c[m >> 2] = 0;
	                                        break a
	                                    }
	                                    e = (Mq(+h[(c[k >> 2] | 0) + 16 >> 3]) | 0) == -1;
	                                    b = Mq(+h[(c[l >> 2] | 0) + 16 >> 3]) | 0;
	                                    if (e)if ((b | 0) == -1) {
	                                        c[m >> 2] = 1;
	                                        break a
	                                    } else {
	                                        c[m >> 2] = 0;
	                                        break a
	                                    }
	                                    if ((b | 0) == 1)if ((Mq(+h[(c[k >> 2] | 0) + 16 >> 3]) | 0) == 1) {
	                                        c[m >> 2] = 1;
	                                        break a
	                                    } else {
	                                        c[m >> 2] = 0;
	                                        break a
	                                    }
	                                    b = (Mq(+h[(c[l >> 2] | 0) + 16 >> 3]) | 0) == -1;
	                                    n = +h[(c[k >> 2] | 0) + 16 >> 3];
	                                    if (!b) {
	                                        c[m >> 2] = n == +h[(c[l >> 2] | 0) + 16 >> 3] & 1;
	                                        break a
	                                    }
	                                    if ((Mq(n) | 0) == -1) {
	                                        c[m >> 2] = 1;
	                                        break a
	                                    } else {
	                                        c[m >> 2] = 0;
	                                        break a
	                                    }
	                                }
	                                c[m >> 2] = 0;
	                                break a;
	                                break
	                            }
	                            case 6:
	                            case 5:
	                            case 8:
	                            case 7:
	                            {
	                                b = c[33976] | 0;
	                                e = c[33980] | 0;
	                                c[g >> 2] = 128552;
	                                c[g + 4 >> 2] = 7108;
	                                Db[b & 511](e, 129064, g);
	                                break a;
	                                break
	                            }
	                            case 2:
	                            {
	                                if ((c[(c[k >> 2] | 0) + 24 >> 2] | 0) != 0 ? (d[c[(c[k >> 2] | 0) + 24 >> 2] >> 0] | 0 | 0) != 0 : 0)c[m >> 2] = 1; else c[m >> 2] = 0;
	                                c[m >> 2] = (c[(c[l >> 2] | 0) + 8 >> 2] | 0) == (c[m >> 2] | 0) & 1;
	                                break a;
	                                break
	                            }
	                            case 4:
	                            {
	                                c[m >> 2] = qy(c[(c[k >> 2] | 0) + 24 >> 2] | 0, c[(c[l >> 2] | 0) + 24 >> 2] | 0) | 0;
	                                break a;
	                                break
	                            }
	                            default:
	                                break a
	                        }
	                        break
	                    }
	                    default:
	                    {
	                    }
	                } while (0);
	                jt(c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[k >> 2] | 0);
	                jt(c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[l >> 2] | 0);
	                i = f;
	                return c[m >> 2] | 0
	            }

	            function ut(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0.0;
	                f = i;
	                i = i + 64 | 0;
	                g = f + 52 | 0;
	                j = f + 48 | 0;
	                k = f + 44 | 0;
	                l = f + 40 | 0;
	                m = f + 36 | 0;
	                n = f + 32 | 0;
	                o = f + 28 | 0;
	                p = f + 24 | 0;
	                q = f;
	                r = f + 20 | 0;
	                s = f + 16 | 0;
	                t = f + 12 | 0;
	                u = f + 8 | 0;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[p >> 2] = 0;
	                c[s >> 2] = 0;
	                do if (c[l >> 2] | 0) {
	                    if ((c[c[l >> 2] >> 2] | 0) != 1 ? (c[c[l >> 2] >> 2] | 0) != 9 : 0)break;
	                    do if (c[m >> 2] | 0) {
	                        if ((c[c[m >> 2] >> 2] | 0) != 1 ? (c[c[m >> 2] >> 2] | 0) != 9 : 0)break;
	                        c[t >> 2] = c[(c[l >> 2] | 0) + 4 >> 2];
	                        c[u >> 2] = c[(c[m >> 2] | 0) + 4 >> 2];
	                        if ((c[t >> 2] | 0) != 0 ? (c[c[t >> 2] >> 2] | 0) > 0 : 0) {
	                            if ((c[u >> 2] | 0) != 0 ? (c[c[u >> 2] >> 2] | 0) > 0 : 0) {
	                                c[r >> 2] = Cb[c[135744 >> 2] & 511](c[c[u >> 2] >> 2] << 3) | 0;
	                                if (!(c[r >> 2] | 0)) {
	                                    it(0, 130768);
	                                    Qq(c[l >> 2] | 0);
	                                    Qq(c[m >> 2] | 0);
	                                    c[g >> 2] = 0;
	                                    v = c[g >> 2] | 0;
	                                    i = f;
	                                    return v | 0
	                                }
	                                c[n >> 2] = 0;
	                                while (1) {
	                                    if ((c[n >> 2] | 0) >= (c[c[t >> 2] >> 2] | 0))break;
	                                    h[q >> 3] = +Gr(c[(c[(c[t >> 2] | 0) + 8 >> 2] | 0) + (c[n >> 2] << 2) >> 2] | 0);
	                                    if (!(Lq(+h[q >> 3]) | 0)) {
	                                        c[o >> 2] = 0;
	                                        while (1) {
	                                            if ((c[o >> 2] | 0) >= (c[c[u >> 2] >> 2] | 0))break;
	                                            if (!(c[p >> 2] | 0)) {
	                                                w = +Gr(c[(c[(c[u >> 2] | 0) + 8 >> 2] | 0) + (c[o >> 2] << 2) >> 2] | 0);
	                                                h[(c[r >> 2] | 0) + (c[o >> 2] << 3) >> 3] = w
	                                            }
	                                            if (!(Lq(+h[(c[r >> 2] | 0) + (c[o >> 2] << 3) >> 3]) | 0)) {
	                                                do if ((c[j >> 2] | 0) != 0 & (c[k >> 2] | 0) != 0)c[s >> 2] = +h[q >> 3] < +h[(c[r >> 2] | 0) + (c[o >> 2] << 3) >> 3] & 1; else {
	                                                    if (!((c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) != 0)) {
	                                                        c[s >> 2] = +h[q >> 3] <= +h[(c[r >> 2] | 0) + (c[o >> 2] << 3) >> 3] & 1;
	                                                        break
	                                                    }
	                                                    if ((c[j >> 2] | 0) == 0 & (c[k >> 2] | 0) != 0) {
	                                                        c[s >> 2] = +h[q >> 3] > +h[(c[r >> 2] | 0) + (c[o >> 2] << 3) >> 3] & 1;
	                                                        break
	                                                    }
	                                                    if ((c[j >> 2] | 0) != 0 | (c[k >> 2] | 0) != 0)break;
	                                                    c[s >> 2] = +h[q >> 3] >= +h[(c[r >> 2] | 0) + (c[o >> 2] << 3) >> 3] & 1
	                                                } while (0);
	                                                if (c[s >> 2] | 0)break
	                                            }
	                                            c[o >> 2] = (c[o >> 2] | 0) + 1
	                                        }
	                                        if (c[s >> 2] | 0)break;
	                                        c[p >> 2] = 1
	                                    }
	                                    c[n >> 2] = (c[n >> 2] | 0) + 1
	                                }
	                                zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                                Qq(c[l >> 2] | 0);
	                                Qq(c[m >> 2] | 0);
	                                c[g >> 2] = c[s >> 2];
	                                v = c[g >> 2] | 0;
	                                i = f;
	                                return v | 0
	                            }
	                            Qq(c[l >> 2] | 0);
	                            Qq(c[m >> 2] | 0);
	                            c[g >> 2] = 0;
	                            v = c[g >> 2] | 0;
	                            i = f;
	                            return v | 0
	                        }
	                        Qq(c[l >> 2] | 0);
	                        Qq(c[m >> 2] | 0);
	                        c[g >> 2] = 0;
	                        v = c[g >> 2] | 0;
	                        i = f;
	                        return v | 0
	                    } while (0);
	                    Qq(c[l >> 2] | 0);
	                    Qq(c[m >> 2] | 0);
	                    c[g >> 2] = 0;
	                    v = c[g >> 2] | 0;
	                    i = f;
	                    return v | 0
	                } while (0);
	                Qq(c[m >> 2] | 0);
	                c[g >> 2] = 0;
	                v = c[g >> 2] | 0;
	                i = f;
	                return v | 0
	            }

	            function vt(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g;
	                j = g + 28 | 0;
	                k = g + 24 | 0;
	                l = g + 20 | 0;
	                m = g + 16 | 0;
	                n = g + 12 | 0;
	                o = g + 8 | 0;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                do if (!((c[o >> 2] | 0) == 0 | (c[n >> 2] | 0) == 0)) {
	                    if ((c[c[n >> 2] >> 2] | 0) != 1 ? (c[c[n >> 2] >> 2] | 0) != 9 : 0)break;
	                    switch (c[c[o >> 2] >> 2] | 0) {
	                        case 9:
	                        case 1:
	                        {
	                            c[j >> 2] = ut(c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0) | 0;
	                            p = c[j >> 2] | 0;
	                            i = g;
	                            return p | 0
	                        }
	                        case 4:
	                        {
	                            c[j >> 2] = au(c[k >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0) | 0;
	                            p = c[j >> 2] | 0;
	                            i = g;
	                            return p | 0
	                        }
	                        case 2:
	                        {
	                            Tq(c[k >> 2] | 0, c[n >> 2] | 0) | 0;
	                            Bs(c[k >> 2] | 0, 1);
	                            Tq(c[k >> 2] | 0, c[o >> 2] | 0) | 0;
	                            c[j >> 2] = Sr(c[k >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0) | 0;
	                            p = c[j >> 2] | 0;
	                            i = g;
	                            return p | 0
	                        }
	                        case 3:
	                        {
	                            c[j >> 2] = $t(c[k >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0) | 0;
	                            p = c[j >> 2] | 0;
	                            i = g;
	                            return p | 0
	                        }
	                        default:
	                        {
	                            f = c[33976] | 0;
	                            e = c[33980] | 0;
	                            c[h >> 2] = 128552;
	                            c[h + 4 >> 2] = 6705;
	                            Db[f & 511](e, 129064, h);
	                            c[j >> 2] = 0;
	                            p = c[j >> 2] | 0;
	                            i = g;
	                            return p | 0
	                        }
	                    }
	                } while (0);
	                c[j >> 2] = 0;
	                p = c[j >> 2] | 0;
	                i = g;
	                return p | 0
	            }

	            function wt(a, b) {
	                a = a | 0;
	                b = +b;
	                var d = 0, e = 0, f = 0, g = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 24 | 0;
	                f = d + 20 | 0;
	                g = d;
	                j = d + 16 | 0;
	                k = d + 12 | 0;
	                l = d + 8 | 0;
	                c[f >> 2] = a;
	                h[g >> 3] = b;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 200 >> 2] | 0) != 0 : 0) {
	                    c[j >> 2] = c[(c[f >> 2] | 0) + 200 >> 2];
	                    if ((c[(c[j >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[(c[(c[j >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                        f = (c[(c[j >> 2] | 0) + 12 >> 2] | 0) + 4 | 0;
	                        a = (c[f >> 2] | 0) + -1 | 0;
	                        c[f >> 2] = a;
	                        c[k >> 2] = c[(c[c[(c[j >> 2] | 0) + 12 >> 2] >> 2] | 0) + (a << 2) >> 2];
	                        c[c[k >> 2] >> 2] = 3;
	                        h[(c[k >> 2] | 0) + 16 >> 3] = +h[g >> 3];
	                        c[e >> 2] = c[k >> 2];
	                        m = c[e >> 2] | 0;
	                        i = d;
	                        return m | 0
	                    }
	                    if ((c[(c[j >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[(c[(c[j >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                        k = (c[(c[j >> 2] | 0) + 16 >> 2] | 0) + 4 | 0;
	                        a = (c[k >> 2] | 0) + -1 | 0;
	                        c[k >> 2] = a;
	                        c[l >> 2] = c[(c[c[(c[j >> 2] | 0) + 16 >> 2] >> 2] | 0) + (a << 2) >> 2];
	                        c[c[l >> 2] >> 2] = 3;
	                        h[(c[l >> 2] | 0) + 16 >> 3] = +h[g >> 3];
	                        c[e >> 2] = c[l >> 2];
	                        m = c[e >> 2] | 0;
	                        i = d;
	                        return m | 0
	                    }
	                }
	                c[e >> 2] = ur(+h[g >> 3]) | 0;
	                m = c[e >> 2] | 0;
	                i = d;
	                return m | 0
	            }

	            function xt(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    c[e >> 2] = wt(c[f >> 2] | 0, 0.0) | 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                if ((c[c[g >> 2] >> 2] | 0) == 3) {
	                    c[e >> 2] = c[g >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } else {
	                    b = c[f >> 2] | 0;
	                    c[h >> 2] = wt(b, +Wq(c[g >> 2] | 0)) | 0;
	                    jt(c[f >> 2] | 0, c[g >> 2] | 0);
	                    c[e >> 2] = c[h >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                return 0
	            }

	            function yt(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 200 >> 2] | 0) != 0 : 0) {
	                    c[h >> 2] = c[(c[f >> 2] | 0) + 200 >> 2];
	                    if ((c[c[h >> 2] >> 2] | 0) != 0 ? (c[(c[c[h >> 2] >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                        b = (c[c[h >> 2] >> 2] | 0) + 4 | 0;
	                        a = (c[b >> 2] | 0) + -1 | 0;
	                        c[b >> 2] = a;
	                        c[j >> 2] = c[(c[c[c[h >> 2] >> 2] >> 2] | 0) + (a << 2) >> 2];
	                        c[c[j >> 2] >> 2] = 1;
	                        c[(c[j >> 2] | 0) + 8 >> 2] = 0;
	                        do if (c[g >> 2] | 0) {
	                            if ((c[(c[(c[j >> 2] | 0) + 4 >> 2] | 0) + 4 >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                                c[c[(c[(c[j >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] >> 2] = c[g >> 2];
	                                c[c[(c[j >> 2] | 0) + 4 >> 2] >> 2] = 1;
	                                break
	                            }
	                            dr(c[(c[j >> 2] | 0) + 4 >> 2] | 0, c[g >> 2] | 0) | 0
	                        } while (0);
	                        c[e >> 2] = c[j >> 2];
	                        l = c[e >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    }
	                    if ((c[(c[h >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                        j = (c[(c[h >> 2] | 0) + 16 >> 2] | 0) + 4 | 0;
	                        a = (c[j >> 2] | 0) + -1 | 0;
	                        c[j >> 2] = a;
	                        c[k >> 2] = c[(c[c[(c[h >> 2] | 0) + 16 >> 2] >> 2] | 0) + (a << 2) >> 2];
	                        c[c[k >> 2] >> 2] = 1;
	                        c[(c[k >> 2] | 0) + 8 >> 2] = 0;
	                        a = $q(c[g >> 2] | 0) | 0;
	                        c[(c[k >> 2] | 0) + 4 >> 2] = a;
	                        if (!(c[(c[k >> 2] | 0) + 4 >> 2] | 0)) {
	                            c[(c[f >> 2] | 0) + 136 >> 2] = 12;
	                            c[(c[f >> 2] | 0) + 140 >> 2] = 2;
	                            c[e >> 2] = 0;
	                            l = c[e >> 2] | 0;
	                            i = d;
	                            return l | 0
	                        } else {
	                            c[e >> 2] = c[k >> 2];
	                            l = c[e >> 2] | 0;
	                            i = d;
	                            return l | 0
	                        }
	                    }
	                }
	                c[e >> 2] = gr(c[g >> 2] | 0) | 0;
	                l = c[e >> 2] | 0;
	                i = d;
	                return l | 0
	            }

	            function zt(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 28 | 0;
	                g = e + 24 | 0;
	                h = e + 20 | 0;
	                j = e + 16 | 0;
	                k = e + 12 | 0;
	                l = e + 8 | 0;
	                m = e + 4 | 0;
	                n = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[k >> 2] = c[h >> 2];
	                c[n >> 2] = 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                c[j >> 2] = $q(0) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    c[f >> 2] = c[j >> 2];
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                a:while (1) {
	                    do if ((d[c[k >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[k >> 2] >> 0] | 0 | 0) ? (d[c[k >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[k >> 2] >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    c[k >> 2] = (c[k >> 2] | 0) + 1
	                }
	                while (1) {
	                    if (!(d[c[k >> 2] >> 0] | 0))break;
	                    while (1) {
	                        if ((d[c[k >> 2] >> 0] | 0 | 0) == 32)break;
	                        if (9 <= (d[c[k >> 2] >> 0] | 0 | 0) ? (d[c[k >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[k >> 2] >> 0] | 0 | 0) == 13)break;
	                        if (!(d[c[k >> 2] >> 0] | 0))break;
	                        c[k >> 2] = (c[k >> 2] | 0) + 1
	                    }
	                    c[l >> 2] = ly(c[h >> 2] | 0, (c[k >> 2] | 0) - (c[h >> 2] | 0) | 0) | 0;
	                    if (c[l >> 2] | 0) {
	                        c[m >> 2] = Hm(c[g >> 2] | 0, c[l >> 2] | 0) | 0;
	                        if (c[m >> 2] | 0) {
	                            b = c[m >> 2] | 0;
	                            do if ((c[(c[m >> 2] | 0) + 4 >> 2] | 0) != 2)if ((c[b + 4 >> 2] | 0) == 1) {
	                                c[n >> 2] = c[m >> 2];
	                                break
	                            } else {
	                                c[n >> 2] = 0;
	                                break
	                            } else c[n >> 2] = c[b + 20 >> 2]; while (0);
	                            if (c[n >> 2] | 0)cr(c[j >> 2] | 0, c[n >> 2] | 0) | 0
	                        }
	                        zb[c[135736 >> 2] & 511](c[l >> 2] | 0)
	                    }
	                    while (1) {
	                        do if ((d[c[k >> 2] >> 0] | 0 | 0) == 32)p = 1; else {
	                            if (9 <= (d[c[k >> 2] >> 0] | 0 | 0) ? (d[c[k >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                p = 1;
	                                break
	                            }
	                            p = (d[c[k >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        q = c[k >> 2] | 0;
	                        if (!p)break;
	                        c[k >> 2] = q + 1
	                    }
	                    c[h >> 2] = q
	                }
	                c[f >> 2] = c[j >> 2];
	                o = c[f >> 2] | 0;
	                i = e;
	                return o | 0
	            }

	            function At(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 200 >> 2] | 0) != 0 : 0) ? (c[h >> 2] = c[(c[f >> 2] | 0) + 200 >> 2], (c[(c[h >> 2] | 0) + 16 >> 2] | 0) != 0) : 0) ? (c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                    f = (c[(c[h >> 2] | 0) + 16 >> 2] | 0) + 4 | 0;
	                    b = (c[f >> 2] | 0) + -1 | 0;
	                    c[f >> 2] = b;
	                    c[j >> 2] = c[(c[c[(c[h >> 2] | 0) + 16 >> 2] >> 2] | 0) + (b << 2) >> 2];
	                    c[c[j >> 2] >> 2] = 1;
	                    c[(c[j >> 2] | 0) + 4 >> 2] = c[g >> 2];
	                    c[e >> 2] = c[j >> 2];
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                c[e >> 2] = hr(c[g >> 2] | 0) | 0;
	                k = c[e >> 2] | 0;
	                i = d;
	                return k | 0
	            }

	            function Bt(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                j = d + 12 | 0;
	                k = d + 8 | 0;
	                c[g >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = 0;
	                if (!(c[j >> 2] | 0)) {
	                    c[f >> 2] = Ct(c[g >> 2] | 0, 128928) | 0;
	                    l = c[f >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                switch (c[c[j >> 2] >> 2] | 0) {
	                    case 9:
	                    case 1:
	                    {
	                        c[k >> 2] = Cr(c[(c[j >> 2] | 0) + 4 >> 2] | 0) | 0;
	                        break
	                    }
	                    case 3:
	                    {
	                        c[k >> 2] = Br(+h[(c[j >> 2] | 0) + 16 >> 3]) | 0;
	                        break
	                    }
	                    case 6:
	                    case 5:
	                    case 8:
	                    case 7:
	                    {
	                        b = c[33976] | 0;
	                        a = c[33980] | 0;
	                        c[e >> 2] = 128552;
	                        c[e + 4 >> 2] = 2680;
	                        Db[b & 511](a, 129064, e);
	                        break
	                    }
	                    case 2:
	                    {
	                        c[k >> 2] = Ar(c[(c[j >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        break
	                    }
	                    case 4:
	                    {
	                        c[f >> 2] = c[j >> 2];
	                        l = c[f >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    }
	                    default:
	                    {
	                    }
	                }
	                jt(c[g >> 2] | 0, c[j >> 2] | 0);
	                j = c[g >> 2] | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[f >> 2] = Ct(j, 128928) | 0;
	                    l = c[f >> 2] | 0;
	                    i = d;
	                    return l | 0
	                } else {
	                    c[f >> 2] = Et(j, c[k >> 2] | 0) | 0;
	                    l = c[f >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                return 0
	            }

	            function Ct(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 200 >> 2] | 0) != 0 : 0) {
	                    c[h >> 2] = c[(c[f >> 2] | 0) + 200 >> 2];
	                    if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 0 ? (c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                        f = (c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 4 | 0;
	                        b = (c[f >> 2] | 0) + -1 | 0;
	                        c[f >> 2] = b;
	                        c[j >> 2] = c[(c[c[(c[h >> 2] | 0) + 4 >> 2] >> 2] | 0) + (b << 2) >> 2];
	                        c[c[j >> 2] >> 2] = 4;
	                        b = my(c[g >> 2] | 0) | 0;
	                        c[(c[j >> 2] | 0) + 24 >> 2] = b;
	                        c[e >> 2] = c[j >> 2];
	                        l = c[e >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    }
	                    if ((c[(c[h >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                        j = (c[(c[h >> 2] | 0) + 16 >> 2] | 0) + 4 | 0;
	                        b = (c[j >> 2] | 0) + -1 | 0;
	                        c[j >> 2] = b;
	                        c[k >> 2] = c[(c[c[(c[h >> 2] | 0) + 16 >> 2] >> 2] | 0) + (b << 2) >> 2];
	                        c[c[k >> 2] >> 2] = 4;
	                        b = my(c[g >> 2] | 0) | 0;
	                        c[(c[k >> 2] | 0) + 24 >> 2] = b;
	                        c[e >> 2] = c[k >> 2];
	                        l = c[e >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    }
	                }
	                c[e >> 2] = yr(c[g >> 2] | 0) | 0;
	                l = c[e >> 2] | 0;
	                i = d;
	                return l | 0
	            }

	            function Dt(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 200 >> 2] | 0) != 0 : 0) {
	                    c[h >> 2] = c[(c[f >> 2] | 0) + 200 >> 2];
	                    if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 0 ? (c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                        f = (c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 4 | 0;
	                        b = (c[f >> 2] | 0) + -1 | 0;
	                        c[f >> 2] = b;
	                        c[j >> 2] = c[(c[c[(c[h >> 2] | 0) + 4 >> 2] >> 2] | 0) + (b << 2) >> 2];
	                        c[c[j >> 2] >> 2] = 4;
	                        if (c[g >> 2] | 0) {
	                            b = my(c[g >> 2] | 0) | 0;
	                            c[(c[j >> 2] | 0) + 24 >> 2] = b
	                        } else {
	                            b = my(128928) | 0;
	                            c[(c[j >> 2] | 0) + 24 >> 2] = b
	                        }
	                        c[e >> 2] = c[j >> 2];
	                        l = c[e >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    }
	                    if ((c[(c[h >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                        j = (c[(c[h >> 2] | 0) + 16 >> 2] | 0) + 4 | 0;
	                        b = (c[j >> 2] | 0) + -1 | 0;
	                        c[j >> 2] = b;
	                        c[k >> 2] = c[(c[c[(c[h >> 2] | 0) + 16 >> 2] >> 2] | 0) + (b << 2) >> 2];
	                        c[c[k >> 2] >> 2] = 4;
	                        if (c[g >> 2] | 0) {
	                            b = my(c[g >> 2] | 0) | 0;
	                            c[(c[k >> 2] | 0) + 24 >> 2] = b
	                        } else {
	                            b = my(128928) | 0;
	                            c[(c[k >> 2] | 0) + 24 >> 2] = b
	                        }
	                        c[e >> 2] = c[k >> 2];
	                        l = c[e >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    }
	                }
	                c[e >> 2] = wr(c[g >> 2] | 0) | 0;
	                l = c[e >> 2] | 0;
	                i = d;
	                return l | 0
	            }

	            function Et(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 200 >> 2] | 0) != 0 : 0) {
	                    c[h >> 2] = c[(c[f >> 2] | 0) + 200 >> 2];
	                    if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 0 ? (c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                        f = (c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 4 | 0;
	                        b = (c[f >> 2] | 0) + -1 | 0;
	                        c[f >> 2] = b;
	                        c[j >> 2] = c[(c[c[(c[h >> 2] | 0) + 4 >> 2] >> 2] | 0) + (b << 2) >> 2];
	                        c[c[j >> 2] >> 2] = 4;
	                        c[(c[j >> 2] | 0) + 24 >> 2] = c[g >> 2];
	                        c[e >> 2] = c[j >> 2];
	                        l = c[e >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    }
	                    if ((c[(c[h >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                        j = (c[(c[h >> 2] | 0) + 16 >> 2] | 0) + 4 | 0;
	                        b = (c[j >> 2] | 0) + -1 | 0;
	                        c[j >> 2] = b;
	                        c[k >> 2] = c[(c[c[(c[h >> 2] | 0) + 16 >> 2] >> 2] | 0) + (b << 2) >> 2];
	                        c[c[k >> 2] >> 2] = 4;
	                        c[(c[k >> 2] | 0) + 24 >> 2] = c[g >> 2];
	                        c[e >> 2] = c[k >> 2];
	                        l = c[e >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    }
	                }
	                c[e >> 2] = xr(c[g >> 2] | 0) | 0;
	                l = c[e >> 2] | 0;
	                i = d;
	                return l | 0
	            }

	            function Ft(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 200 >> 2] | 0) != 0 : 0) {
	                    c[h >> 2] = c[(c[f >> 2] | 0) + 200 >> 2];
	                    if ((c[(c[h >> 2] | 0) + 8 >> 2] | 0) != 0 ? (c[(c[(c[h >> 2] | 0) + 8 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                        f = (c[(c[h >> 2] | 0) + 8 >> 2] | 0) + 4 | 0;
	                        b = (c[f >> 2] | 0) + -1 | 0;
	                        c[f >> 2] = b;
	                        c[j >> 2] = c[(c[c[(c[h >> 2] | 0) + 8 >> 2] >> 2] | 0) + (b << 2) >> 2];
	                        c[c[j >> 2] >> 2] = 2;
	                        c[(c[j >> 2] | 0) + 8 >> 2] = (c[g >> 2] | 0) != 0 & 1;
	                        c[e >> 2] = c[j >> 2];
	                        l = c[e >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    }
	                    if ((c[(c[h >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                        j = (c[(c[h >> 2] | 0) + 16 >> 2] | 0) + 4 | 0;
	                        b = (c[j >> 2] | 0) + -1 | 0;
	                        c[j >> 2] = b;
	                        c[k >> 2] = c[(c[c[(c[h >> 2] | 0) + 16 >> 2] >> 2] | 0) + (b << 2) >> 2];
	                        c[c[k >> 2] >> 2] = 2;
	                        c[(c[k >> 2] | 0) + 8 >> 2] = (c[g >> 2] | 0) != 0 & 1;
	                        c[e >> 2] = c[k >> 2];
	                        l = c[e >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    }
	                }
	                c[e >> 2] = vr(c[g >> 2] | 0) | 0;
	                l = c[e >> 2] | 0;
	                i = d;
	                return l | 0
	            }

	            function Gt(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    c[e >> 2] = Ft(c[f >> 2] | 0, 0) | 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                if ((c[c[g >> 2] >> 2] | 0) == 2) {
	                    c[e >> 2] = c[g >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } else {
	                    b = c[f >> 2] | 0;
	                    c[h >> 2] = Ft(b, Vq(c[g >> 2] | 0) | 0) | 0;
	                    jt(c[f >> 2] | 0, c[g >> 2] | 0);
	                    c[e >> 2] = c[h >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                return 0
	            }

	            function Ht(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                e = i;
	                i = i + 144 | 0;
	                f = e + 28 | 0;
	                g = e + 24 | 0;
	                h = e + 20 | 0;
	                j = e + 32 | 0;
	                k = e + 16 | 0;
	                l = e + 12 | 0;
	                m = e + 8 | 0;
	                n = e + 4 | 0;
	                o = e;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[k >> 2] = 0;
	                c[m >> 2] = bu(c[g >> 2] | 0, l) | 0;
	                a:do if (!((c[m >> 2] | 0) == 32 | (c[m >> 2] | 0) == 62 | (c[m >> 2] | 0) == 47 | (c[m >> 2] | 0) == 91 | (c[m >> 2] | 0) == 93 | (c[m >> 2] | 0) == 64 | (c[m >> 2] | 0) == 42)) {
	                    d = c[m >> 2] | 0;
	                    if ((c[m >> 2] | 0) < 256) {
	                        if (((!(65 <= (d | 0) & (c[m >> 2] | 0) <= 90) ? !(97 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 122) : 0) ? !(192 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 214) : 0) ? !(216 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 246 | 248 <= (c[m >> 2] | 0)) : 0)p = 8
	                    } else if (!(DQ(d, 199744) | 0))p = 8;
	                    do if ((p | 0) == 8) {
	                        d = c[m >> 2] | 0;
	                        if ((c[m >> 2] | 0) < 256)if ((d | 0) != 95 & (c[h >> 2] | 0) != 0 & (c[m >> 2] | 0) != 58)break a; else break;
	                        if (!(19968 <= (d | 0) & (c[m >> 2] | 0) <= 40869 | (c[m >> 2] | 0) == 12295) ? (12321 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 12329 ^ 1) & (c[m >> 2] | 0) != 95 & (c[h >> 2] | 0) != 0 & (c[m >> 2] | 0) != 58 : 0)break a
	                    } while (0);
	                    b:do {
	                        if (!((c[m >> 2] | 0) != 32 & (c[m >> 2] | 0) != 62 & (c[m >> 2] | 0) != 47)) {
	                            p = 72;
	                            break
	                        }
	                        d = c[m >> 2] | 0;
	                        if ((c[m >> 2] | 0) < 256) {
	                            if (((!(65 <= (d | 0) & (c[m >> 2] | 0) <= 90) ? !(97 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 122) : 0) ? !(192 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 214) : 0) ? !(216 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 246 | 248 <= (c[m >> 2] | 0)) : 0)p = 20
	                        } else if (!(DQ(d, 199744) | 0))p = 20;
	                        do if ((p | 0) == 20) {
	                            p = 0;
	                            if ((c[m >> 2] | 0) >= 256) {
	                                if (19968 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 40869 | (c[m >> 2] | 0) == 12295)break;
	                                if (12321 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 12329)break
	                            }
	                            d = c[m >> 2] | 0;
	                            if ((c[m >> 2] | 0) < 256) {
	                                if (48 <= (d | 0) & (c[m >> 2] | 0) <= 57 | (c[m >> 2] | 0) == 46 | (c[m >> 2] | 0) == 45 | (c[m >> 2] | 0) == 95)break
	                            } else {
	                                b = (DQ(d, 200216) | 0) != 0;
	                                if (b | (c[m >> 2] | 0) == 46 | (c[m >> 2] | 0) == 45 | (c[m >> 2] | 0) == 95)break
	                            }
	                            if (!((c[h >> 2] | 0) != 0 & (c[m >> 2] | 0) == 58)) {
	                                if ((c[m >> 2] | 0) >= 256 ? (DQ(c[m >> 2] | 0, 200144) | 0) != 0 : 0)break;
	                                b = c[m >> 2] | 0;
	                                if ((c[m >> 2] | 0) < 256)q = (b | 0) == 183 & 1; else q = DQ(b, 200272) | 0;
	                                if (!q) {
	                                    p = 72;
	                                    break b
	                                }
	                            }
	                        } while (0);
	                        if ((c[l >> 2] | 0) == 1) {
	                            b = c[m >> 2] & 255;
	                            d = c[k >> 2] | 0;
	                            c[k >> 2] = d + 1;
	                            a[j + d >> 0] = b
	                        } else {
	                            b = qe(c[l >> 2] | 0, j + (c[k >> 2] | 0) | 0, c[m >> 2] | 0) | 0;
	                            c[k >> 2] = (c[k >> 2] | 0) + b
	                        }
	                        b = c[g >> 2] | 0;
	                        c[b >> 2] = (c[b >> 2] | 0) + (c[l >> 2] | 0);
	                        c[m >> 2] = bu(c[g >> 2] | 0, l) | 0
	                    } while ((c[k >> 2] | 0) < 100);
	                    if ((p | 0) == 72)if (!(c[k >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    } else {
	                        c[f >> 2] = ly(j, c[k >> 2] | 0) | 0;
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    }
	                    c[o >> 2] = c[k >> 2] << 1;
	                    if ((c[k >> 2] | 0) > 5e4) {
	                        Nq(c[g >> 2] | 0, 7);
	                        c[f >> 2] = 0;
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    }
	                    c[n >> 2] = Cb[c[135752 >> 2] & 511](c[o >> 2] | 0) | 0;
	                    if (!(c[n >> 2] | 0)) {
	                        Nq(c[g >> 2] | 0, 15);
	                        c[f >> 2] = 0;
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    }
	                    eU(c[n >> 2] | 0, j | 0, c[k >> 2] | 0) | 0;
	                    while (1) {
	                        b = c[m >> 2] | 0;
	                        if ((c[m >> 2] | 0) < 256)if (((!(65 <= (b | 0) & (c[m >> 2] | 0) <= 90) ? !(97 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 122) : 0) ? !(192 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 214) : 0) ? !(216 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 246 | 248 <= (c[m >> 2] | 0)) : 0)p = 48; else s = 1; else if (DQ(b, 199744) | 0)s = 1; else p = 48;
	                        do if ((p | 0) == 48) {
	                            p = 0;
	                            if ((c[m >> 2] | 0) >= 256) {
	                                if (19968 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 40869 | (c[m >> 2] | 0) == 12295) {
	                                    s = 1;
	                                    break
	                                }
	                                if (12321 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 12329) {
	                                    s = 1;
	                                    break
	                                }
	                            }
	                            b = c[m >> 2] | 0;
	                            if ((c[m >> 2] | 0) < 256) {
	                                if (48 <= (b | 0) & (c[m >> 2] | 0) <= 57 | (c[m >> 2] | 0) == 46 | (c[m >> 2] | 0) == 45 | (c[m >> 2] | 0) == 95) {
	                                    s = 1;
	                                    break
	                                }
	                            } else {
	                                d = (DQ(b, 200216) | 0) != 0;
	                                if (d | (c[m >> 2] | 0) == 46 | (c[m >> 2] | 0) == 45 | (c[m >> 2] | 0) == 95) {
	                                    s = 1;
	                                    break
	                                }
	                            }
	                            if ((c[h >> 2] | 0) != 0 & (c[m >> 2] | 0) == 58)s = 1; else {
	                                if ((c[m >> 2] | 0) >= 256 ? (DQ(c[m >> 2] | 0, 200144) | 0) != 0 : 0) {
	                                    s = 1;
	                                    break
	                                }
	                                d = c[m >> 2] | 0;
	                                if ((c[m >> 2] | 0) < 256)t = (d | 0) == 183 & 1; else t = DQ(d, 200272) | 0;
	                                s = (t | 0) != 0
	                            }
	                        } while (0);
	                        u = c[k >> 2] | 0;
	                        if (!s) {
	                            p = 71;
	                            break
	                        }
	                        if ((u + 10 | 0) > (c[o >> 2] | 0)) {
	                            if ((c[o >> 2] | 0) > 5e4) {
	                                p = 64;
	                                break
	                            }
	                            c[o >> 2] = c[o >> 2] << 1;
	                            c[n >> 2] = Hb[c[135760 >> 2] & 511](c[n >> 2] | 0, c[o >> 2] | 0) | 0;
	                            if (!(c[n >> 2] | 0)) {
	                                p = 66;
	                                break
	                            }
	                        }
	                        if ((c[l >> 2] | 0) == 1) {
	                            d = c[m >> 2] & 255;
	                            b = c[k >> 2] | 0;
	                            c[k >> 2] = b + 1;
	                            a[(c[n >> 2] | 0) + b >> 0] = d
	                        } else {
	                            d = qe(c[l >> 2] | 0, (c[n >> 2] | 0) + (c[k >> 2] | 0) | 0, c[m >> 2] | 0) | 0;
	                            c[k >> 2] = (c[k >> 2] | 0) + d
	                        }
	                        d = c[g >> 2] | 0;
	                        c[d >> 2] = (c[d >> 2] | 0) + (c[l >> 2] | 0);
	                        c[m >> 2] = bu(c[g >> 2] | 0, l) | 0
	                    }
	                    if ((p | 0) == 64) {
	                        Nq(c[g >> 2] | 0, 7);
	                        c[f >> 2] = 0;
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    } else if ((p | 0) == 66) {
	                        Nq(c[g >> 2] | 0, 15);
	                        c[f >> 2] = 0;
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    } else if ((p | 0) == 71) {
	                        a[(c[n >> 2] | 0) + u >> 0] = 0;
	                        c[f >> 2] = c[n >> 2];
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    }
	                } while (0);
	                c[f >> 2] = 0;
	                r = c[f >> 2] | 0;
	                i = e;
	                return r | 0
	            }

	            function It(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 40 | 0;
	                g = e + 36 | 0;
	                h = e + 32 | 0;
	                j = e + 28 | 0;
	                k = e + 24 | 0;
	                l = e + 20 | 0;
	                m = e + 16 | 0;
	                n = e + 12 | 0;
	                o = e + 8 | 0;
	                p = e + 4 | 0;
	                q = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[l >> 2] = 0;
	                c[m >> 2] = 0;
	                if (((vy(c[h >> 2] | 0, 91) | 0) == 0 ? (vy(c[h >> 2] | 0, 40) | 0) == 0 : 0) ? (vy(c[h >> 2] | 0, 64) | 0) == 0 : 0) {
	                    c[q >> 2] = vy(c[h >> 2] | 0, 58) | 0;
	                    do if (c[q >> 2] | 0) {
	                        if (((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 60 >> 2] | 0) != 0 : 0) ? (d[(c[q >> 2] | 0) + 1 >> 0] | 0 | 0) != 58 : 0)break;
	                        c[f >> 2] = 0;
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    } while (0);
	                    if ((c[g >> 2] | 0) != 0 ? (c[l >> 2] = c[(c[g >> 2] | 0) + 192 >> 2], (c[(c[g >> 2] | 0) + 60 >> 2] | 0) > 0) : 0) {
	                        c[m >> 2] = Cb[c[135744 >> 2] & 511]((c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 1 << 1 << 2) | 0;
	                        if (!(c[m >> 2] | 0)) {
	                            it(c[g >> 2] | 0, 130672);
	                            c[f >> 2] = 0;
	                            r = c[f >> 2] | 0;
	                            i = e;
	                            return r | 0
	                        }
	                        c[o >> 2] = 0;
	                        c[p >> 2] = 0;
	                        while (1) {
	                            if ((c[p >> 2] | 0) >= (c[(c[g >> 2] | 0) + 60 >> 2] | 0))break;
	                            c[n >> 2] = c[(c[(c[g >> 2] | 0) + 56 >> 2] | 0) + (c[p >> 2] << 2) >> 2];
	                            q = c[(c[n >> 2] | 0) + 8 >> 2] | 0;
	                            b = c[o >> 2] | 0;
	                            c[o >> 2] = b + 1;
	                            c[(c[m >> 2] | 0) + (b << 2) >> 2] = q;
	                            q = c[(c[n >> 2] | 0) + 12 >> 2] | 0;
	                            b = c[o >> 2] | 0;
	                            c[o >> 2] = b + 1;
	                            c[(c[m >> 2] | 0) + (b << 2) >> 2] = q;
	                            c[p >> 2] = (c[p >> 2] | 0) + 1
	                        }
	                        p = c[o >> 2] | 0;
	                        c[o >> 2] = p + 1;
	                        c[(c[m >> 2] | 0) + (p << 2) >> 2] = 0;
	                        c[(c[m >> 2] | 0) + (c[o >> 2] << 2) >> 2] = 0
	                    }
	                    c[j >> 2] = MQ(c[h >> 2] | 0, c[l >> 2] | 0, 1, c[m >> 2] | 0) | 0;
	                    if (c[m >> 2] | 0)zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                    if ((c[j >> 2] | 0) != 0 ? (PQ(c[j >> 2] | 0) | 0) == 1 : 0) {
	                        c[k >> 2] = pt() | 0;
	                        if (!(c[k >> 2] | 0)) {
	                            it(c[g >> 2] | 0, 130704);
	                            c[f >> 2] = 0;
	                            r = c[f >> 2] | 0;
	                            i = e;
	                            return r | 0
	                        }
	                        c[(c[k >> 2] | 0) + 24 >> 2] = c[j >> 2];
	                        c[(c[k >> 2] | 0) + 20 >> 2] = c[l >> 2];
	                        if (c[(c[k >> 2] | 0) + 20 >> 2] | 0)yP(c[(c[k >> 2] | 0) + 20 >> 2] | 0) | 0;
	                        c[f >> 2] = c[k >> 2];
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    }
	                    EQ(c[j >> 2] | 0)
	                }
	                c[f >> 2] = 0;
	                r = c[f >> 2] | 0;
	                i = e;
	                return r | 0
	            }

	            function Jt(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                cu(c[f >> 2] | 0);
	                if (c[(c[f >> 2] | 0) + 8 >> 2] | 0) {
	                    i = e;
	                    return
	                }
	                a:while (1) {
	                    do if ((d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    b = c[f >> 2] | 0;
	                    if (!(d[c[c[f >> 2] >> 2] >> 0] | 0))continue;
	                    c[b >> 2] = (c[b >> 2] | 0) + 1
	                }
	                b:while (1) {
	                    if ((d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) != 111)break;
	                    if ((d[(c[c[f >> 2] >> 2] | 0) + 1 >> 0] | 0 | 0) != 114)break;
	                    c[h >> 2] = c[(c[(c[f >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2];
	                    b = c[f >> 2] | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 2;
	                    while (1) {
	                        do if ((d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) == 32)j = 1; else {
	                            if (9 <= (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                j = 1;
	                                break
	                            }
	                            j = (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        k = c[f >> 2] | 0;
	                        if (!j)break;
	                        b = c[f >> 2] | 0;
	                        if (!(d[c[k >> 2] >> 0] | 0))continue;
	                        c[b >> 2] = (c[b >> 2] | 0) + 1
	                    }
	                    cu(k);
	                    if (c[(c[f >> 2] | 0) + 8 >> 2] | 0) {
	                        l = 29;
	                        break
	                    }
	                    du(c[(c[f >> 2] | 0) + 32 >> 2] | 0, c[h >> 2] | 0, c[(c[(c[f >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2] | 0, 2, 0, 0, 0, 0, 0) | 0;
	                    while (1) {
	                        do if ((d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) != 13)continue b
	                        } while (0);
	                        b = c[f >> 2] | 0;
	                        if (!(d[c[c[f >> 2] >> 2] >> 0] | 0))continue;
	                        c[b >> 2] = (c[b >> 2] | 0) + 1
	                    }
	                }
	                if ((l | 0) == 29) {
	                    i = e;
	                    return
	                }
	                if (!(c[g >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                if ((c[(c[(c[(c[f >> 2] | 0) + 32 >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[(c[f >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2] | 0) * 40 | 0) >> 2] | 0) == 12) {
	                    i = e;
	                    return
	                }
	                du(c[(c[f >> 2] | 0) + 32 >> 2] | 0, c[(c[(c[f >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2] | 0, -1, 18, 0, 0, 0, 0, 0) | 0;
	                i = e;
	                return
	            }

	            function Kt(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                do if ((((((((c[c[f >> 2] >> 2] | 0) == 11 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != -1 : 0) ? (c[(c[f >> 2] | 0) + 8 >> 2] | 0) == -1 : 0) ? (c[g >> 2] = (c[(c[e >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) * 40 | 0), (c[c[g >> 2] >> 2] | 0) == 11) : 0) ? (c[(c[g >> 2] | 0) + 12 >> 2] | 0) == 6 : 0) ? (c[(c[g >> 2] | 0) + 8 >> 2] | 0) == -1 : 0) ? (c[(c[g >> 2] | 0) + 16 >> 2] | 0) == 1 : 0) ? (c[(c[g >> 2] | 0) + 20 >> 2] | 0) == 0 : 0) {
	                    b = c[(c[f >> 2] | 0) + 12 >> 2] | 0;
	                    if ((b | 0) == 6 | (b | 0) == 13) {
	                        c[(c[f >> 2] | 0) + 4 >> 2] = c[(c[g >> 2] | 0) + 4 >> 2];
	                        c[(c[f >> 2] | 0) + 12 >> 2] = 6;
	                        break
	                    } else if ((b | 0) == 5 | (b | 0) == 4) {
	                        c[(c[f >> 2] | 0) + 4 >> 2] = c[(c[g >> 2] | 0) + 4 >> 2];
	                        c[(c[f >> 2] | 0) + 12 >> 2] = 5;
	                        break
	                    } else break
	                } while (0);
	                if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) != -1)Kt(c[e >> 2] | 0, (c[(c[e >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0);
	                if ((c[(c[f >> 2] | 0) + 8 >> 2] | 0) == -1) {
	                    i = d;
	                    return
	                }
	                Kt(c[e >> 2] | 0, (c[(c[e >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[f >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) | 0);
	                i = d;
	                return
	            }

	            function Lt(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f;
	                h = f + 36 | 0;
	                j = f + 32 | 0;
	                k = f + 28 | 0;
	                l = f + 24 | 0;
	                m = f + 20 | 0;
	                n = f + 16 | 0;
	                o = f + 12 | 0;
	                p = f + 8 | 0;
	                q = f + 4 | 0;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                if (!(c[k >> 2] | 0)) {
	                    Xd(0, 0, 0, 0, 0, 12, 1, 3, 128552, 14895, 0, 0, 0, 0, 0, 129480, g);
	                    c[h >> 2] = -1;
	                    r = c[h >> 2] | 0;
	                    i = f;
	                    return r | 0
	                }
	                if (!(c[j >> 2] | 0)) {
	                    c[h >> 2] = -1;
	                    r = c[h >> 2] | 0;
	                    i = f;
	                    return r | 0
	                }
	                Kq();
	                c[32576] = (c[32576] | 0) + 1;
	                if ((c[32576] | 0) > 1)c[32574] = 1;
	                c[n >> 2] = eu(c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                c[o >> 2] = Mt(c[n >> 2] | 0, c[m >> 2] | 0) | 0;
	                do if (c[l >> 2] | 0)if (!(c[(c[n >> 2] | 0) + 16 >> 2] | 0)) {
	                    Db[c[135904 >> 2] & 511](c[33980] | 0, 130312, g);
	                    c[c[l >> 2] >> 2] = 0;
	                    break
	                } else {
	                    j = Sq(c[n >> 2] | 0) | 0;
	                    c[c[l >> 2] >> 2] = j;
	                    break
	                } while (0);
	                do if ((c[(c[n >> 2] | 0) + 20 >> 2] | 0) > 0) {
	                    c[q >> 2] = 0;
	                    do {
	                        c[p >> 2] = Sq(c[n >> 2] | 0) | 0;
	                        if (c[p >> 2] | 0) {
	                            c[q >> 2] = (c[q >> 2] | 0) + 1;
	                            jt(c[k >> 2] | 0, c[p >> 2] | 0)
	                        }
	                    } while ((c[p >> 2] | 0) != 0);
	                    if (c[q >> 2] | 0) {
	                        if (!(c[m >> 2] | 0)) {
	                            if (!(c[l >> 2] | 0))break;
	                            if (!(c[c[l >> 2] >> 2] | 0))break
	                        }
	                        j = c[33976] | 0;
	                        e = c[33980] | 0;
	                        c[g >> 2] = c[q >> 2];
	                        Db[j & 511](e, 130360, g)
	                    }
	                } while (0);
	                if (((c[l >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (c[c[l >> 2] >> 2] | 0) != 0 : 0) {
	                    Qq(c[c[l >> 2] >> 2] | 0);
	                    c[c[l >> 2] >> 2] = 0
	                }
	                c[(c[n >> 2] | 0) + 32 >> 2] = 0;
	                Pr(c[n >> 2] | 0);
	                c[32576] = (c[32576] | 0) + -1;
	                c[h >> 2] = c[o >> 2];
	                r = c[h >> 2] | 0;
	                i = f;
	                return r | 0
	            }

	            function Mt(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 24 | 0;
	                g = d + 20 | 0;
	                h = d + 16 | 0;
	                j = d + 12 | 0;
	                k = d + 8 | 0;
	                l = d + 4 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 32 >> 2] | 0) != 0 : 0) {
	                    if (!(c[(c[g >> 2] | 0) + 28 >> 2] | 0)) {
	                        b = Cb[c[135744 >> 2] & 511](40) | 0;
	                        c[(c[g >> 2] | 0) + 28 >> 2] = b;
	                        if (!(c[(c[g >> 2] | 0) + 28 >> 2] | 0)) {
	                            fu(c[g >> 2] | 0, 129952);
	                            zb[c[135736 >> 2] & 511](c[g >> 2] | 0)
	                        }
	                        c[(c[g >> 2] | 0) + 20 >> 2] = 0;
	                        c[(c[g >> 2] | 0) + 24 >> 2] = 10;
	                        c[(c[g >> 2] | 0) + 16 >> 2] = 0;
	                        c[(c[g >> 2] | 0) + 44 >> 2] = 0
	                    }
	                    do if (c[(c[(c[g >> 2] | 0) + 32 >> 2] | 0) + 24 >> 2] | 0) {
	                        if (c[h >> 2] | 0) {
	                            c[k >> 2] = gu(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[g >> 2] | 0) + 32 >> 2] | 0) + 24 >> 2] | 0, 0, 1) | 0;
	                            if ((c[k >> 2] | 0) == -1)break;
	                            c[f >> 2] = c[k >> 2];
	                            m = c[f >> 2] | 0;
	                            i = d;
	                            return m | 0
	                        }
	                        c[l >> 2] = 0;
	                        c[k >> 2] = gu(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[g >> 2] | 0) + 32 >> 2] | 0) + 24 >> 2] | 0, l, 0) | 0;
	                        if ((c[k >> 2] | 0) != -1 & (c[l >> 2] | 0) != 0) {
	                            Tq(c[g >> 2] | 0, c[l >> 2] | 0) | 0;
	                            c[f >> 2] = 0;
	                            m = c[f >> 2] | 0;
	                            i = d;
	                            return m | 0
	                        } else {
	                            if (!(c[l >> 2] | 0))break;
	                            jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[l >> 2] | 0);
	                            break
	                        }
	                    } while (0);
	                    c[j >> 2] = c[(c[g >> 2] | 0) + 32 >> 2];
	                    if ((c[(c[j >> 2] | 0) + 12 >> 2] | 0) < 0) {
	                        Db[c[135904 >> 2] & 511](c[33980] | 0, 129984, e);
	                        c[f >> 2] = -1;
	                        m = c[f >> 2] | 0;
	                        i = d;
	                        return m | 0
	                    }
	                    e = c[g >> 2] | 0;
	                    g = (c[(c[j >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 12 >> 2] | 0) * 40 | 0) | 0;
	                    if (c[h >> 2] | 0) {
	                        c[f >> 2] = hu(e, g, 0) | 0;
	                        m = c[f >> 2] | 0;
	                        i = d;
	                        return m | 0
	                    } else {
	                        iu(e, g) | 0;
	                        c[f >> 2] = 0;
	                        m = c[f >> 2] | 0;
	                        i = d;
	                        return m | 0
	                    }
	                }
	                c[f >> 2] = -1;
	                m = c[f >> 2] | 0;
	                i = d;
	                return m | 0
	            }

	            function Nt(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[g >> 2] = ju(c[e >> 2] | 0, c[f >> 2] | 0) | 0;
	                f = c[g >> 2] | 0;
	                i = d;
	                return ((c[g >> 2] | 0) == -2 ? f : 0 - f | 0) | 0
	            }

	            function Ot(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0;
	                e = i;
	                i = i + 64 | 0;
	                f = e + 32 | 0;
	                g = e + 60 | 0;
	                h = e + 56 | 0;
	                j = e + 52 | 0;
	                k = e + 24 | 0;
	                l = e + 16 | 0;
	                m = e + 8 | 0;
	                n = e + 48 | 0;
	                o = e + 44 | 0;
	                p = e;
	                q = e + 40 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                d = k;
	                c[d >> 2] = 0;
	                c[d + 4 >> 2] = 0;
	                d = m;
	                c[d >> 2] = (c[j >> 2] | 0) - 1;
	                c[d + 4 >> 2] = 0;
	                d = m;
	                j = YT(c[d >> 2] | 0, c[d + 4 >> 2] | 0, 1) | 0;
	                d = l;
	                c[d >> 2] = j;
	                c[d + 4 >> 2] = G;
	                c[n >> 2] = c[(c[g >> 2] | 0) + (c[k >> 2] << 2) >> 2];
	                if ((Nt(c[h >> 2] | 0, c[n >> 2] | 0) | 0) < 0) {
	                    d = f;
	                    c[d >> 2] = 0;
	                    c[d + 4 >> 2] = 0;
	                    r = f;
	                    s = r;
	                    t = c[s >> 2] | 0;
	                    u = r + 4 | 0;
	                    v = u;
	                    w = c[v >> 2] | 0;
	                    G = w;
	                    i = e;
	                    return t | 0
	                }
	                if (!(Nt(c[h >> 2] | 0, c[n >> 2] | 0) | 0)) {
	                    d = p;
	                    c[d >> 2] = 1;
	                    c[d + 4 >> 2] = 0;
	                    while (1) {
	                        d = (Nt(c[h >> 2] | 0, c[(c[g >> 2] | 0) + (c[p >> 2] << 2) >> 2] | 0) | 0) == 0;
	                        j = p;
	                        x = c[j >> 2] | 0;
	                        y = c[j + 4 >> 2] | 0;
	                        if (!d)break;
	                        d = bU(x | 0, y | 0, 1, 0) | 0;
	                        j = p;
	                        c[j >> 2] = d;
	                        c[j + 4 >> 2] = G
	                    }
	                    p = f;
	                    c[p >> 2] = x;
	                    c[p + 4 >> 2] = y;
	                    r = f;
	                    s = r;
	                    t = c[s >> 2] | 0;
	                    u = r + 4 | 0;
	                    v = u;
	                    w = c[v >> 2] | 0;
	                    G = w;
	                    i = e;
	                    return t | 0
	                }
	                c[o >> 2] = c[(c[g >> 2] | 0) + (c[l >> 2] << 2) >> 2];
	                while (1) {
	                    c[q >> 2] = Nt(c[h >> 2] | 0, c[o >> 2] | 0) | 0;
	                    if ((c[q >> 2] | 0) < 0) {
	                        y = l;
	                        p = k;
	                        x = XT(c[y >> 2] | 0, c[y + 4 >> 2] | 0, c[p >> 2] | 0, c[p + 4 >> 2] | 0) | 0;
	                        p = G;
	                        y = l;
	                        z = c[y >> 2] | 0;
	                        A = c[y + 4 >> 2] | 0;
	                        if ((p | 0) < 0 | (p | 0) == 0 & x >>> 0 <= 1) {
	                            B = 11;
	                            break
	                        }
	                        x = m;
	                        c[x >> 2] = z;
	                        c[x + 4 >> 2] = A
	                    } else {
	                        if ((c[q >> 2] | 0) <= 0) {
	                            B = 17;
	                            break
	                        }
	                        x = m;
	                        p = l;
	                        y = XT(c[x >> 2] | 0, c[x + 4 >> 2] | 0, c[p >> 2] | 0, c[p + 4 >> 2] | 0) | 0;
	                        p = G;
	                        x = l;
	                        C = c[x >> 2] | 0;
	                        D = c[x + 4 >> 2] | 0;
	                        if ((p | 0) < 0 | (p | 0) == 0 & y >>> 0 <= 1) {
	                            B = 15;
	                            break
	                        }
	                        y = k;
	                        c[y >> 2] = C;
	                        c[y + 4 >> 2] = D;
	                        c[n >> 2] = c[o >> 2]
	                    }
	                    y = k;
	                    p = c[y >> 2] | 0;
	                    x = c[y + 4 >> 2] | 0;
	                    y = m;
	                    j = k;
	                    d = XT(c[y >> 2] | 0, c[y + 4 >> 2] | 0, c[j >> 2] | 0, c[j + 4 >> 2] | 0) | 0;
	                    j = YT(d | 0, G | 0, 1) | 0;
	                    d = bU(p | 0, x | 0, j | 0, G | 0) | 0;
	                    j = l;
	                    c[j >> 2] = d;
	                    c[j + 4 >> 2] = G;
	                    c[o >> 2] = c[(c[g >> 2] | 0) + (c[l >> 2] << 2) >> 2]
	                }
	                if ((B | 0) == 11) {
	                    k = f;
	                    c[k >> 2] = z;
	                    c[k + 4 >> 2] = A;
	                    r = f;
	                    s = r;
	                    t = c[s >> 2] | 0;
	                    u = r + 4 | 0;
	                    v = u;
	                    w = c[v >> 2] | 0;
	                    G = w;
	                    i = e;
	                    return t | 0
	                } else if ((B | 0) == 15) {
	                    A = bU(C | 0, D | 0, 1, 0) | 0;
	                    D = f;
	                    c[D >> 2] = A;
	                    c[D + 4 >> 2] = G;
	                    r = f;
	                    s = r;
	                    t = c[s >> 2] | 0;
	                    u = r + 4 | 0;
	                    v = u;
	                    w = c[v >> 2] | 0;
	                    G = w;
	                    i = e;
	                    return t | 0
	                } else if ((B | 0) == 17) {
	                    while (1) {
	                        B = 0;
	                        D = l;
	                        A = bU(c[D >> 2] | 0, c[D + 4 >> 2] | 0, 1, 0) | 0;
	                        D = l;
	                        c[D >> 2] = A;
	                        c[D + 4 >> 2] = G;
	                        c[o >> 2] = c[(c[g >> 2] | 0) + (A << 2) >> 2];
	                        if (!(Nt(c[h >> 2] | 0, c[o >> 2] | 0) | 0))B = 17; else break
	                    }
	                    B = l;
	                    l = c[B + 4 >> 2] | 0;
	                    o = f;
	                    c[o >> 2] = c[B >> 2];
	                    c[o + 4 >> 2] = l;
	                    r = f;
	                    s = r;
	                    t = c[s >> 2] | 0;
	                    u = r + 4 | 0;
	                    v = u;
	                    w = c[v >> 2] | 0;
	                    G = w;
	                    i = e;
	                    return t | 0
	                }
	                return 0
	            }

	            function Pt(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 20 | 0;
	                j = g + 8 | 0;
	                k = g;
	                l = g + 16 | 0;
	                c[h >> 2] = a;
	                a = j;
	                c[a >> 2] = b;
	                c[a + 4 >> 2] = d;
	                d = k;
	                c[d >> 2] = e;
	                c[d + 4 >> 2] = f;
	                while (1) {
	                    f = j;
	                    d = c[f + 4 >> 2] | 0;
	                    e = k;
	                    a = c[e + 4 >> 2] | 0;
	                    if ((d | 0) > (a | 0) | ((d | 0) == (a | 0) ? (c[f >> 2] | 0) >>> 0 >= (c[e >> 2] | 0) >>> 0 : 0))break;
	                    c[l >> 2] = c[(c[h >> 2] | 0) + (c[j >> 2] << 2) >> 2];
	                    c[(c[h >> 2] | 0) + (c[j >> 2] << 2) >> 2] = c[(c[h >> 2] | 0) + (c[k >> 2] << 2) >> 2];
	                    c[(c[h >> 2] | 0) + (c[k >> 2] << 2) >> 2] = c[l >> 2];
	                    e = j;
	                    f = bU(c[e >> 2] | 0, c[e + 4 >> 2] | 0, 1, 0) | 0;
	                    e = j;
	                    c[e >> 2] = f;
	                    c[e + 4 >> 2] = G;
	                    e = k;
	                    f = bU(c[e >> 2] | 0, c[e + 4 >> 2] | 0, -1, -1) | 0;
	                    e = k;
	                    c[e >> 2] = f;
	                    c[e + 4 >> 2] = G
	                }
	                i = g;
	                return
	            }

	            function Qt(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[c[f >> 2] >> 2] | 0) >>> 0 >= (c[g >> 2] | 0) >>> 0) {
	                    i = d;
	                    return
	                }
	                c[h >> 2] = kT(c[(c[f >> 2] | 0) + 4 >> 2] | 0, c[g >> 2] << 2) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    b = c[o >> 2] | 0;
	                    c[e >> 2] = c[g >> 2] << 2;
	                    Ka(b | 0, 131856, e | 0) | 0;
	                    qb(1)
	                }
	                c[(c[f >> 2] | 0) + 4 >> 2] = c[h >> 2];
	                c[c[f >> 2] >> 2] = c[g >> 2];
	                i = d;
	                return
	            }

	            function Rt(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e;
	                j = e + 8 | 0;
	                c[f >> 2] = b;
	                c[j >> 2] = 0;
	                while (1) {
	                    if ((c[j >> 2] | 0) >= 8)break;
	                    a[g + (d[131816 + (7 - (c[j >> 2] | 0)) >> 0] | 0) >> 0] = a[(c[f >> 2] | 0) + (c[j >> 2] | 0) >> 0] | 0;
	                    c[j >> 2] = (c[j >> 2] | 0) + 1
	                }
	                i = e;
	                return +(+h[g >> 3])
	            }

	            function St(a) {
	                a = +a;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b;
	                h[d >> 3] = a;
	                h[e >> 3] = +h[d >> 3];
	                d = e;
	                G = c[d + 4 >> 2] | 0;
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function Tt(a) {
	                a = +a;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                g[d >> 2] = a;
	                g[e >> 2] = +g[d >> 2];
	                i = b;
	                return c[e >> 2] | 0
	            }

	            function Ut(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                f = i;
	                i = i + 128 | 0;
	                g = f;
	                h = f + 20 | 0;
	                j = f + 16 | 0;
	                k = f + 12 | 0;
	                l = f + 8 | 0;
	                m = f + 4 | 0;
	                n = f + 24 | 0;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[m >> 2] = 0;
	                while (1) {
	                    o = n + ((c[m >> 2] << 1) + 1) | 0;
	                    if (!((c[m >> 2] | 0) < 25 ? (c[m >> 2] | 0) < (c[k >> 2] | 0) : 0))break;
	                    a[o >> 0] = 32;
	                    a[n + (c[m >> 2] << 1) >> 0] = 32;
	                    c[m >> 2] = (c[m >> 2] | 0) + 1
	                }
	                a[o >> 0] = 0;
	                a[n + (c[m >> 2] << 1) >> 0] = 0;
	                if (!(c[j >> 2] | 0)) {
	                    m = c[h >> 2] | 0;
	                    c[g >> 2] = n;
	                    Ka(m | 0, 127912, g | 0) | 0;
	                    Ka(c[h >> 2] | 0, 131072, g | 0) | 0;
	                    i = f;
	                    return
	                }
	                while (1) {
	                    if (!(c[j >> 2] | 0))break;
	                    c[l >> 2] = c[j >> 2];
	                    c[j >> 2] = c[(c[j >> 2] | 0) + 24 >> 2];
	                    Kp(c[h >> 2] | 0, c[l >> 2] | 0, c[k >> 2] | 0)
	                }
	                i = f;
	                return
	            }

	            function Vt(a) {
	                a = +a;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                e = b + 8 | 0;
	                h[d >> 3] = a;
	                ku(+h[d >> 3], e) | 0;
	                i = b;
	                return c[e >> 2] | 0
	            }

	            function Wt(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                c[e >> 2] = 0;
	                while (1) {
	                    if ((c[e >> 2] | 0) >= (c[(c[d >> 2] | 0) + 4 >> 2] | 0))break;
	                    c[f >> 2] = c[(c[c[d >> 2] >> 2] | 0) + (c[e >> 2] << 2) >> 2];
	                    if (c[(c[f >> 2] | 0) + 4 >> 2] | 0) {
	                        if (c[(c[(c[f >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[(c[f >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0)
	                    }
	                    zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                    c[e >> 2] = (c[e >> 2] | 0) + 1
	                }
	                lu(c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function Xt(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](12) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    it(0, 130864);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = c[f >> 2] | 0;
	                c[a + 0 >> 2] = 0;
	                c[a + 4 >> 2] = 0;
	                c[a + 8 >> 2] = 0;
	                if ((c[e >> 2] | 0) > 0) {
	                    Yt(c[f >> 2] | 0, 0, c[e >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 4 >> 2] = 0
	                }
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function Yt(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                do if (c[c[g >> 2] >> 2] | 0) {
	                    if ((c[(c[g >> 2] | 0) + 8 >> 2] | 0) <= (c[(c[g >> 2] | 0) + 4 >> 2] | 0)) {
	                        if ((c[(c[g >> 2] | 0) + 8 >> 2] | 0) > 5e7) {
	                            it(0, 130904);
	                            c[f >> 2] = -1;
	                            k = c[f >> 2] | 0;
	                            i = e;
	                            return k | 0
	                        }
	                        d = (c[g >> 2] | 0) + 8 | 0;
	                        c[d >> 2] = c[d >> 2] << 1;
	                        d = Hb[c[135760 >> 2] & 511](c[c[g >> 2] >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] << 2) | 0;
	                        c[c[g >> 2] >> 2] = d;
	                        if (!(c[c[g >> 2] >> 2] | 0)) {
	                            it(0, 130904);
	                            c[(c[g >> 2] | 0) + 8 >> 2] = 0;
	                            c[f >> 2] = -1;
	                            k = c[f >> 2] | 0;
	                            i = e;
	                            return k | 0
	                        }
	                    }
	                } else {
	                    if ((c[j >> 2] | 0) <= 0)c[j >> 2] = 1;
	                    d = Cb[c[135744 >> 2] & 511](c[j >> 2] << 2) | 0;
	                    c[c[g >> 2] >> 2] = d;
	                    if (c[c[g >> 2] >> 2] | 0) {
	                        c[(c[g >> 2] | 0) + 4 >> 2] = 0;
	                        c[(c[g >> 2] | 0) + 8 >> 2] = c[j >> 2];
	                        break
	                    }
	                    it(0, 130864);
	                    c[f >> 2] = -1;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                } while (0);
	                j = c[h >> 2] | 0;
	                h = (c[g >> 2] | 0) + 4 | 0;
	                d = c[h >> 2] | 0;
	                c[h >> 2] = d + 1;
	                c[(c[c[g >> 2] >> 2] | 0) + (d << 2) >> 2] = j;
	                c[f >> 2] = 0;
	                k = c[f >> 2] | 0;
	                i = e;
	                return k | 0
	            }

	            function Zt(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                b = i;
	                i = i + 32 | 0;
	                e = b + 20 | 0;
	                f = b + 16 | 0;
	                g = b + 12 | 0;
	                h = b + 8 | 0;
	                j = b + 4 | 0;
	                k = b;
	                c[f >> 2] = a;
	                c[g >> 2] = 2;
	                c[h >> 2] = 0;
	                c[j >> 2] = 0;
	                c[k >> 2] = 0;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = b;
	                    return l | 0
	                }
	                if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 9) {
	                    c[j >> 2] = Pi(c[f >> 2] | 0) | 0;
	                    if (!(c[j >> 2] | 0))c[f >> 2] = c[(c[f >> 2] | 0) + 12 >> 2]; else c[f >> 2] = c[j >> 2];
	                    if (!(c[f >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        l = c[e >> 2] | 0;
	                        i = b;
	                        return l | 0
	                    }
	                }
	                switch (c[(c[f >> 2] | 0) + 4 >> 2] | 0) {
	                    case 2:
	                    {
	                        c[j >> 2] = c[(c[f >> 2] | 0) + 12 >> 2];
	                        break
	                    }
	                    case 1:
	                    {
	                        c[j >> 2] = c[(c[f >> 2] | 0) + 12 >> 2];
	                        break
	                    }
	                    case 3:
	                    case 4:
	                    case 7:
	                    case 8:
	                    {
	                        c[h >> 2] = c[(c[f >> 2] | 0) + 40 >> 2];
	                        if (!(c[h >> 2] | 0)) {
	                            c[e >> 2] = 0;
	                            l = c[e >> 2] | 0;
	                            i = b;
	                            return l | 0
	                        }
	                        if (!(d[c[h >> 2] >> 0] | 0)) {
	                            c[e >> 2] = 0;
	                            l = c[e >> 2] | 0;
	                            i = b;
	                            return l | 0
	                        } else {
	                            c[e >> 2] = (d[c[h >> 2] >> 0] | 0) + ((d[(c[h >> 2] | 0) + 1 >> 0] | 0) << 8);
	                            l = c[e >> 2] | 0;
	                            i = b;
	                            return l | 0
	                        }
	                        break
	                    }
	                    case 18:
	                    {
	                        c[h >> 2] = c[(c[f >> 2] | 0) + 8 >> 2];
	                        if (!(c[h >> 2] | 0)) {
	                            c[e >> 2] = 0;
	                            l = c[e >> 2] | 0;
	                            i = b;
	                            return l | 0
	                        }
	                        if (!(d[c[h >> 2] >> 0] | 0)) {
	                            c[e >> 2] = 0;
	                            l = c[e >> 2] | 0;
	                            i = b;
	                            return l | 0
	                        } else {
	                            c[e >> 2] = (d[c[h >> 2] >> 0] | 0) + ((d[(c[h >> 2] | 0) + 1 >> 0] | 0) << 8);
	                            l = c[e >> 2] | 0;
	                            i = b;
	                            return l | 0
	                        }
	                        break
	                    }
	                    default:
	                    {
	                        c[e >> 2] = 0;
	                        l = c[e >> 2] | 0;
	                        i = b;
	                        return l | 0
	                    }
	                }
	                a:while (1) {
	                    if (!(c[j >> 2] | 0)) {
	                        m = 47;
	                        break
	                    }
	                    switch (c[(c[j >> 2] | 0) + 4 >> 2] | 0) {
	                        case 18:
	                        {
	                            c[h >> 2] = c[(c[j >> 2] | 0) + 8 >> 2];
	                            break
	                        }
	                        case 3:
	                        case 4:
	                        case 7:
	                        case 8:
	                        {
	                            c[h >> 2] = c[(c[j >> 2] | 0) + 40 >> 2];
	                            break
	                        }
	                        default:
	                        {
	                        }
	                    }
	                    if ((c[h >> 2] | 0) != 0 ? (d[c[h >> 2] >> 0] | 0 | 0) != 0 : 0) {
	                        if ((c[g >> 2] | 0) == 1) {
	                            m = 30;
	                            break
	                        }
	                        if (d[(c[h >> 2] | 0) + 1 >> 0] | 0) {
	                            m = 33;
	                            break
	                        }
	                        c[g >> 2] = 1;
	                        c[k >> 2] = d[c[h >> 2] >> 0]
	                    }
	                    if (((c[(c[j >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 14 : 0) ? (c[(c[(c[j >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) != 17 : 0) {
	                        c[j >> 2] = c[(c[j >> 2] | 0) + 12 >> 2];
	                        continue
	                    }
	                    if ((c[j >> 2] | 0) == (c[f >> 2] | 0)) {
	                        m = 47;
	                        break
	                    }
	                    if (c[(c[j >> 2] | 0) + 24 >> 2] | 0) {
	                        c[j >> 2] = c[(c[j >> 2] | 0) + 24 >> 2];
	                        continue
	                    }
	                    while (1) {
	                        c[j >> 2] = c[(c[j >> 2] | 0) + 20 >> 2];
	                        if (!(c[j >> 2] | 0))continue a;
	                        if ((c[j >> 2] | 0) == (c[f >> 2] | 0)) {
	                            m = 43;
	                            break
	                        }
	                        n = c[j >> 2] | 0;
	                        if (c[(c[j >> 2] | 0) + 24 >> 2] | 0) {
	                            m = 45;
	                            break
	                        }
	                        if (!n)continue a
	                    }
	                    if ((m | 0) == 43) {
	                        m = 0;
	                        c[j >> 2] = 0;
	                        continue
	                    } else if ((m | 0) == 45) {
	                        m = 0;
	                        c[j >> 2] = c[n + 24 >> 2];
	                        continue
	                    }
	                }
	                if ((m | 0) == 30) {
	                    c[e >> 2] = (c[k >> 2] | 0) + ((d[c[h >> 2] >> 0] | 0) << 8);
	                    l = c[e >> 2] | 0;
	                    i = b;
	                    return l | 0
	                } else if ((m | 0) == 33) {
	                    c[e >> 2] = (d[c[h >> 2] >> 0] | 0) + ((d[(c[h >> 2] | 0) + 1 >> 0] | 0) << 8);
	                    l = c[e >> 2] | 0;
	                    i = b;
	                    return l | 0
	                } else if ((m | 0) == 47) {
	                    c[e >> 2] = c[k >> 2];
	                    l = c[e >> 2] | 0;
	                    i = b;
	                    return l | 0
	                }
	                return 0
	            }

	            function _t(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[f >> 2] = a;
	                do if (c[f >> 2] | 0)if (!(d[c[f >> 2] >> 0] | 0)) {
	                    c[e >> 2] = 0;
	                    break
	                } else {
	                    c[e >> 2] = (d[c[f >> 2] >> 0] | 0) + ((d[(c[f >> 2] | 0) + 1 >> 0] | 0) << 8);
	                    break
	                } else c[e >> 2] = 0; while (0);
	                i = b;
	                return c[e >> 2] | 0
	            }

	            function $t(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                g = i;
	                i = i + 48 | 0;
	                h = g + 36 | 0;
	                j = g + 32 | 0;
	                k = g + 28 | 0;
	                l = g + 24 | 0;
	                m = g + 20 | 0;
	                n = g + 16 | 0;
	                o = g + 12 | 0;
	                p = g + 8 | 0;
	                q = g + 4 | 0;
	                r = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[p >> 2] = 0;
	                do if (!((c[n >> 2] | 0) == 0 | (c[m >> 2] | 0) == 0)) {
	                    if ((c[c[m >> 2] >> 2] | 0) != 1 ? (c[c[m >> 2] >> 2] | 0) != 9 : 0)break;
	                    c[q >> 2] = c[(c[m >> 2] | 0) + 4 >> 2];
	                    a:do if (c[q >> 2] | 0) {
	                        c[o >> 2] = 0;
	                        while (1) {
	                            if ((c[o >> 2] | 0) >= (c[c[q >> 2] >> 2] | 0))break a;
	                            c[r >> 2] = ir(c[(c[(c[q >> 2] | 0) + 8 >> 2] | 0) + (c[o >> 2] << 2) >> 2] | 0) | 0;
	                            if ((c[r >> 2] | 0) != 0 ? (f = c[j >> 2] | 0, Tq(f, Dt(c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[r >> 2] | 0) | 0) | 0, zb[c[135736 >> 2] & 511](c[r >> 2] | 0), Tr(c[j >> 2] | 0, 1), f = c[j >> 2] | 0, Tq(f, lt(c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[n >> 2] | 0) | 0) | 0, c[p >> 2] = Sr(c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0, (c[p >> 2] | 0) != 0) : 0)break a;
	                            c[o >> 2] = (c[o >> 2] | 0) + 1
	                        }
	                    } while (0);
	                    jt(c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[m >> 2] | 0);
	                    jt(c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[n >> 2] | 0);
	                    c[h >> 2] = c[p >> 2];
	                    s = c[h >> 2] | 0;
	                    i = g;
	                    return s | 0
	                } while (0);
	                jt(c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[m >> 2] | 0);
	                jt(c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[n >> 2] | 0);
	                c[h >> 2] = 0;
	                s = c[h >> 2] | 0;
	                i = g;
	                return s | 0
	            }

	            function au(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                g = i;
	                i = i + 48 | 0;
	                h = g + 36 | 0;
	                j = g + 32 | 0;
	                k = g + 28 | 0;
	                l = g + 24 | 0;
	                m = g + 20 | 0;
	                n = g + 16 | 0;
	                o = g + 12 | 0;
	                p = g + 8 | 0;
	                q = g + 4 | 0;
	                r = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[p >> 2] = 0;
	                do if (!((c[n >> 2] | 0) == 0 | (c[m >> 2] | 0) == 0)) {
	                    if ((c[c[m >> 2] >> 2] | 0) != 1 ? (c[c[m >> 2] >> 2] | 0) != 9 : 0)break;
	                    c[q >> 2] = c[(c[m >> 2] | 0) + 4 >> 2];
	                    a:do if (c[q >> 2] | 0) {
	                        c[o >> 2] = 0;
	                        while (1) {
	                            if ((c[o >> 2] | 0) >= (c[c[q >> 2] >> 2] | 0))break a;
	                            c[r >> 2] = ir(c[(c[(c[q >> 2] | 0) + 8 >> 2] | 0) + (c[o >> 2] << 2) >> 2] | 0) | 0;
	                            if ((c[r >> 2] | 0) != 0 ? (f = c[j >> 2] | 0, Tq(f, Dt(c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[r >> 2] | 0) | 0) | 0, zb[c[135736 >> 2] & 511](c[r >> 2] | 0), f = c[j >> 2] | 0, Tq(f, lt(c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[n >> 2] | 0) | 0) | 0, c[p >> 2] = Sr(c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0, (c[p >> 2] | 0) != 0) : 0)break a;
	                            c[o >> 2] = (c[o >> 2] | 0) + 1
	                        }
	                    } while (0);
	                    jt(c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[m >> 2] | 0);
	                    jt(c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[n >> 2] | 0);
	                    c[h >> 2] = c[p >> 2];
	                    s = c[h >> 2] | 0;
	                    i = g;
	                    return s | 0
	                } while (0);
	                jt(c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[m >> 2] | 0);
	                jt(c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[n >> 2] | 0);
	                c[h >> 2] = 0;
	                s = c[h >> 2] | 0;
	                i = g;
	                return s | 0
	            }

	            function bu(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 20 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[h >> 2] = b;
	                c[j >> 2] = e;
	                if (!(c[h >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                c[m >> 2] = c[c[h >> 2] >> 2];
	                a[k >> 0] = a[c[m >> 2] >> 0] | 0;
	                if (!((d[k >> 0] | 0) & 128)) {
	                    c[c[j >> 2] >> 2] = 1;
	                    c[g >> 2] = d[c[m >> 2] >> 0];
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                a:do if (((d[(c[m >> 2] | 0) + 1 >> 0] | 0) & 192 | 0) == 128) {
	                    do if (((d[k >> 0] | 0) & 224 | 0) == 224) {
	                        if (((d[(c[m >> 2] | 0) + 2 >> 0] | 0) & 192 | 0) != 128)break a;
	                        if (((d[k >> 0] | 0) & 240 | 0) != 240) {
	                            c[c[j >> 2] >> 2] = 3;
	                            c[l >> 2] = ((d[c[m >> 2] >> 0] | 0) & 15) << 12;
	                            c[l >> 2] = c[l >> 2] | ((d[(c[m >> 2] | 0) + 1 >> 0] | 0) & 63) << 6;
	                            c[l >> 2] = c[l >> 2] | (d[(c[m >> 2] | 0) + 2 >> 0] | 0) & 63;
	                            break
	                        }
	                        if (((d[k >> 0] | 0) & 248 | 0) != 240)break a;
	                        if (((d[(c[m >> 2] | 0) + 3 >> 0] | 0) & 192 | 0) != 128)break a;
	                        c[c[j >> 2] >> 2] = 4;
	                        c[l >> 2] = ((d[c[m >> 2] >> 0] | 0) & 7) << 18;
	                        c[l >> 2] = c[l >> 2] | ((d[(c[m >> 2] | 0) + 1 >> 0] | 0) & 63) << 12;
	                        c[l >> 2] = c[l >> 2] | ((d[(c[m >> 2] | 0) + 2 >> 0] | 0) & 63) << 6;
	                        c[l >> 2] = c[l >> 2] | (d[(c[m >> 2] | 0) + 3 >> 0] | 0) & 63
	                    } else {
	                        c[c[j >> 2] >> 2] = 2;
	                        c[l >> 2] = ((d[c[m >> 2] >> 0] | 0) & 31) << 6;
	                        c[l >> 2] = c[l >> 2] | (d[(c[m >> 2] | 0) + 1 >> 0] | 0) & 63
	                    } while (0);
	                    e = c[l >> 2] | 0;
	                    if ((c[l >> 2] | 0) >>> 0 < 256)if (9 <= e >>> 0 & (c[l >> 2] | 0) >>> 0 <= 10 | (c[l >> 2] | 0) == 13 | 32 <= (c[l >> 2] | 0) >>> 0)o = 19; else o = 18; else if ((!(256 <= e >>> 0 & (c[l >> 2] | 0) >>> 0 <= 55295) ? !(57344 <= (c[l >> 2] | 0) >>> 0 & (c[l >> 2] | 0) >>> 0 <= 65533) : 0) ? !(65536 <= (c[l >> 2] | 0) >>> 0 & (c[l >> 2] | 0) >>> 0 <= 1114111) : 0)o = 18; else o = 19;
	                    if ((o | 0) == 18) {
	                        Nq(c[h >> 2] | 0, 21);
	                        c[g >> 2] = 0;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    } else if ((o | 0) == 19) {
	                        c[g >> 2] = c[l >> 2];
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                } while (0);
	                c[c[j >> 2] >> 2] = 0;
	                Nq(c[h >> 2] | 0, 20);
	                c[g >> 2] = 0;
	                n = c[g >> 2] | 0;
	                i = f;
	                return n | 0
	            }

	            function cu(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                mu(c[e >> 2] | 0);
	                if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                    i = b;
	                    return
	                }
	                a:while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    a = c[e >> 2] | 0;
	                    if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1
	                }
	                b:while (1) {
	                    if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 97) {
	                        g = 27;
	                        break
	                    }
	                    if ((d[(c[c[e >> 2] >> 2] | 0) + 1 >> 0] | 0 | 0) != 110) {
	                        g = 27;
	                        break
	                    }
	                    if ((d[(c[c[e >> 2] >> 2] | 0) + 2 >> 0] | 0 | 0) != 100) {
	                        g = 27;
	                        break
	                    }
	                    c[f >> 2] = c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2];
	                    a = c[e >> 2] | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 3;
	                    while (1) {
	                        do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)h = 1; else {
	                            if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                h = 1;
	                                break
	                            }
	                            h = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        j = c[e >> 2] | 0;
	                        if (!h)break;
	                        a = c[e >> 2] | 0;
	                        if (!(d[c[j >> 2] >> 0] | 0))continue;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1
	                    }
	                    mu(j);
	                    if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                        g = 27;
	                        break
	                    }
	                    du(c[(c[e >> 2] | 0) + 32 >> 2] | 0, c[f >> 2] | 0, c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2] | 0, 1, 0, 0, 0, 0, 0) | 0;
	                    while (1) {
	                        do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)continue b
	                        } while (0);
	                        a = c[e >> 2] | 0;
	                        if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1
	                    }
	                }
	                if ((g | 0) == 27) {
	                    i = b;
	                    return
	                }
	            }

	            function du(a, b, d, e, f, g, h, j, k) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                k = k | 0;
	                var l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0;
	                l = i;
	                i = i + 48 | 0;
	                m = l + 40 | 0;
	                n = l + 36 | 0;
	                o = l + 32 | 0;
	                p = l + 28 | 0;
	                q = l + 24 | 0;
	                r = l + 20 | 0;
	                s = l + 16 | 0;
	                t = l + 12 | 0;
	                u = l + 8 | 0;
	                v = l + 4 | 0;
	                w = l;
	                c[n >> 2] = a;
	                c[o >> 2] = b;
	                c[p >> 2] = d;
	                c[q >> 2] = e;
	                c[r >> 2] = f;
	                c[s >> 2] = g;
	                c[t >> 2] = h;
	                c[u >> 2] = j;
	                c[v >> 2] = k;
	                do if ((c[c[n >> 2] >> 2] | 0) >= (c[(c[n >> 2] | 0) + 4 >> 2] | 0)) {
	                    if ((c[(c[n >> 2] | 0) + 4 >> 2] | 0) >= 1e6) {
	                        it(0, 130416);
	                        c[m >> 2] = -1;
	                        x = c[m >> 2] | 0;
	                        i = l;
	                        return x | 0
	                    }
	                    k = (c[n >> 2] | 0) + 4 | 0;
	                    c[k >> 2] = c[k >> 2] << 1;
	                    c[w >> 2] = Hb[c[135760 >> 2] & 511](c[(c[n >> 2] | 0) + 8 >> 2] | 0, (c[(c[n >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0;
	                    if (c[w >> 2] | 0) {
	                        c[(c[n >> 2] | 0) + 8 >> 2] = c[w >> 2];
	                        break
	                    }
	                    k = (c[n >> 2] | 0) + 4 | 0;
	                    c[k >> 2] = (c[k >> 2] | 0) / 2 | 0;
	                    it(0, 130416);
	                    c[m >> 2] = -1;
	                    x = c[m >> 2] | 0;
	                    i = l;
	                    return x | 0
	                } while (0);
	                c[(c[n >> 2] | 0) + 12 >> 2] = c[c[n >> 2] >> 2];
	                c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[c[n >> 2] >> 2] | 0) * 40 | 0) + 4 >> 2] = c[o >> 2];
	                c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[c[n >> 2] >> 2] | 0) * 40 | 0) + 8 >> 2] = c[p >> 2];
	                c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[c[n >> 2] >> 2] | 0) * 40 | 0) >> 2] = c[q >> 2];
	                c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[c[n >> 2] >> 2] | 0) * 40 | 0) + 12 >> 2] = c[r >> 2];
	                c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[c[n >> 2] >> 2] | 0) * 40 | 0) + 16 >> 2] = c[s >> 2];
	                c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[c[n >> 2] >> 2] | 0) * 40 | 0) + 20 >> 2] = c[t >> 2];
	                do if ((c[(c[n >> 2] | 0) + 20 >> 2] | 0) != 0 ? (c[q >> 2] | 0) == 14 | (c[q >> 2] | 0) == 13 | (c[q >> 2] | 0) == 11 : 0) {
	                    t = c[n >> 2] | 0;
	                    if (c[u >> 2] | 0) {
	                        s = AP(c[t + 20 >> 2] | 0, c[u >> 2] | 0, -1) | 0;
	                        c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[c[n >> 2] >> 2] | 0) * 40 | 0) + 24 >> 2] = s;
	                        zb[c[135736 >> 2] & 511](c[u >> 2] | 0)
	                    } else c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[t >> 2] | 0) * 40 | 0) + 24 >> 2] = 0;
	                    t = c[n >> 2] | 0;
	                    if (c[v >> 2] | 0) {
	                        s = AP(c[t + 20 >> 2] | 0, c[v >> 2] | 0, -1) | 0;
	                        c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[c[n >> 2] >> 2] | 0) * 40 | 0) + 28 >> 2] = s;
	                        zb[c[135736 >> 2] & 511](c[v >> 2] | 0);
	                        break
	                    } else {
	                        c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[t >> 2] | 0) * 40 | 0) + 28 >> 2] = 0;
	                        break
	                    }
	                } else y = 15; while (0);
	                if ((y | 0) == 15) {
	                    c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[c[n >> 2] >> 2] | 0) * 40 | 0) + 24 >> 2] = c[u >> 2];
	                    c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[c[n >> 2] >> 2] | 0) * 40 | 0) + 28 >> 2] = c[v >> 2]
	                }
	                c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[c[n >> 2] >> 2] | 0) * 40 | 0) + 32 >> 2] = 0;
	                v = c[n >> 2] | 0;
	                n = c[v >> 2] | 0;
	                c[v >> 2] = n + 1;
	                c[m >> 2] = n;
	                x = c[m >> 2] | 0;
	                i = l;
	                return x | 0
	            }

	            function eu(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = Cb[c[135744 >> 2] & 511](48) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    it(c[g >> 2] | 0, 129952);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                b = (c[h >> 2] | 0) + 0 | 0;
	                a = b + 48 | 0;
	                do {
	                    c[b >> 2] = 0;
	                    b = b + 4 | 0
	                } while ((b | 0) < (a | 0));
	                b = Cb[c[135744 >> 2] & 511](40) | 0;
	                c[(c[h >> 2] | 0) + 28 >> 2] = b;
	                if (!(c[(c[h >> 2] | 0) + 28 >> 2] | 0)) {
	                    zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                    it(c[g >> 2] | 0, 129952);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } else {
	                    c[(c[h >> 2] | 0) + 20 >> 2] = 0;
	                    c[(c[h >> 2] | 0) + 24 >> 2] = 10;
	                    c[(c[h >> 2] | 0) + 16 >> 2] = 0;
	                    c[(c[h >> 2] | 0) + 44 >> 2] = 0;
	                    c[(c[h >> 2] | 0) + 12 >> 2] = c[g >> 2];
	                    c[(c[h >> 2] | 0) + 32 >> 2] = c[f >> 2];
	                    c[e >> 2] = c[h >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                return 0
	            }

	            function fu(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    it(0, c[f >> 2] | 0);
	                    i = d;
	                    return
	                } else {
	                    c[(c[e >> 2] | 0) + 8 >> 2] = 15;
	                    it(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[f >> 2] | 0);
	                    i = d;
	                    return
	                }
	            }

	            function gu(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0;
	                f = i;
	                i = i + 64 | 0;
	                g = f + 56 | 0;
	                h = f + 52 | 0;
	                j = f + 48 | 0;
	                k = f + 44 | 0;
	                l = f + 40 | 0;
	                m = f + 36 | 0;
	                n = f + 32 | 0;
	                o = f + 28 | 0;
	                p = f + 24 | 0;
	                q = f + 20 | 0;
	                r = f + 16 | 0;
	                s = f + 12 | 0;
	                t = f + 8 | 0;
	                u = f + 4 | 0;
	                v = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[s >> 2] = 0;
	                c[t >> 2] = 0;
	                c[u >> 2] = 0;
	                c[v >> 2] = 0;
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    c[g >> 2] = -1;
	                    w = c[g >> 2] | 0;
	                    i = f;
	                    return w | 0
	                }
	                c[m >> 2] = QQ(c[j >> 2] | 0) | 0;
	                if ((c[m >> 2] | 0) == -1) {
	                    c[g >> 2] = -1;
	                    w = c[g >> 2] | 0;
	                    i = f;
	                    return w | 0
	                }
	                if ((c[m >> 2] | 0) == -2)c[m >> 2] = 1e4;
	                c[n >> 2] = RQ(c[j >> 2] | 0) | 0;
	                if ((c[n >> 2] | 0) == -1) {
	                    c[g >> 2] = -1;
	                    w = c[g >> 2] | 0;
	                    i = f;
	                    return w | 0
	                }
	                c[o >> 2] = SQ(c[j >> 2] | 0) | 0;
	                if ((c[o >> 2] | 0) < 0) {
	                    c[g >> 2] = -1;
	                    w = c[g >> 2] | 0;
	                    i = f;
	                    return w | 0
	                }
	                if (!(c[l >> 2] | 0)) {
	                    if (!(c[k >> 2] | 0)) {
	                        c[g >> 2] = -1;
	                        w = c[g >> 2] | 0;
	                        i = f;
	                        return w | 0
	                    }
	                    e = yt(c[h >> 2] | 0, 0) | 0;
	                    c[c[k >> 2] >> 2] = e;
	                    if (!(c[c[k >> 2] >> 2] | 0)) {
	                        c[g >> 2] = -1;
	                        w = c[g >> 2] | 0;
	                        i = f;
	                        return w | 0
	                    }
	                }
	                do if (!(c[n >> 2] | 0)) {
	                    e = (c[l >> 2] | 0) != 0;
	                    if (c[o >> 2] | 0) {
	                        if (!e) {
	                            dr(c[(c[c[k >> 2] >> 2] | 0) + 4 >> 2] | 0, c[c[h >> 2] >> 2] | 0) | 0;
	                            break
	                        }
	                        c[g >> 2] = 1;
	                        w = c[g >> 2] | 0;
	                        i = f;
	                        return w | 0
	                    } else {
	                        if (!e) {
	                            dr(c[(c[c[k >> 2] >> 2] | 0) + 4 >> 2] | 0, c[(c[h >> 2] | 0) + 4 >> 2] | 0) | 0;
	                            break
	                        }
	                        c[g >> 2] = 1;
	                        w = c[g >> 2] | 0;
	                        i = f;
	                        return w | 0
	                    }
	                } while (0);
	                if (!(c[m >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    w = c[g >> 2] | 0;
	                    i = f;
	                    return w | 0
	                }
	                n = c[h >> 2] | 0;
	                if (!(c[o >> 2] | 0)) {
	                    if (c[n + 4 >> 2] | 0) {
	                        switch (c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 4 >> 2] | 0) {
	                            case 21:
	                            case 13:
	                            case 11:
	                            case 9:
	                            case 1:
	                            {
	                                c[s >> 2] = c[(c[h >> 2] | 0) + 4 >> 2];
	                                break
	                            }
	                            default:
	                            {
	                            }
	                        }
	                        c[t >> 2] = c[s >> 2]
	                    }
	                } else c[s >> 2] = c[n >> 2];
	                if (!(c[s >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    w = c[g >> 2] | 0;
	                    i = f;
	                    return w | 0
	                }
	                c[u >> 2] = OQ(c[j >> 2] | 0) | 0;
	                if (!(c[u >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    w = c[g >> 2] | 0;
	                    i = f;
	                    return w | 0
	                }
	                c[r >> 2] = LQ(c[u >> 2] | 0) | 0;
	                if ((c[o >> 2] | 0) != 0 ? (c[p >> 2] = HQ(c[u >> 2] | 0, 0, 0) | 0, (c[p >> 2] | 0) >= 0 & (c[p >> 2] | 0) == 1) : 0) {
	                    if (!(c[l >> 2] | 0)) {
	                        dr(c[(c[c[k >> 2] >> 2] | 0) + 4 >> 2] | 0, c[s >> 2] | 0) | 0;
	                        x = 40
	                    }
	                } else x = 40;
	                a:do if ((x | 0) == 40) {
	                    c[q >> 2] = 0;
	                    b:while (1) {
	                        if ((c[(c[s >> 2] | 0) + 4 >> 2] | 0) == 18)break;
	                        if ((((c[(c[s >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[q >> 2] | 0) < (c[m >> 2] | 0) : 0) ? (c[(c[(c[s >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) != 17 : 0) ? (c[s >> 2] = c[(c[s >> 2] | 0) + 12 >> 2], c[q >> 2] = (c[q >> 2] | 0) + 1, (c[(c[s >> 2] | 0) + 4 >> 2] | 0) != 14) : 0)x = 80; else x = 63;
	                        c:do if ((x | 0) == 63) {
	                            x = 0;
	                            if ((c[s >> 2] | 0) == (c[t >> 2] | 0))break b;
	                            while (1) {
	                                if (!(c[(c[s >> 2] | 0) + 24 >> 2] | 0))break;
	                                c[s >> 2] = c[(c[s >> 2] | 0) + 24 >> 2];
	                                if ((c[(c[s >> 2] | 0) + 4 >> 2] | 0) == 17)continue;
	                                if ((c[(c[s >> 2] | 0) + 4 >> 2] | 0) != 14)break c
	                            }
	                            while (1) {
	                                c[s >> 2] = c[(c[s >> 2] | 0) + 20 >> 2];
	                                c[q >> 2] = (c[q >> 2] | 0) + -1;
	                                if (!(c[s >> 2] | 0))break b;
	                                if ((c[s >> 2] | 0) == (c[t >> 2] | 0))break b;
	                                d:do if ((c[(c[s >> 2] | 0) + 4 >> 2] | 0) == 1)c[p >> 2] = KQ(c[u >> 2] | 0) | 0; else {
	                                    if (!(c[r >> 2] | 0))break;
	                                    do if ((c[(c[s >> 2] | 0) + 4 >> 2] | 0) != 3) {
	                                        if ((c[(c[s >> 2] | 0) + 4 >> 2] | 0) == 4)break;
	                                        if ((c[(c[s >> 2] | 0) + 4 >> 2] | 0) == 8)break;
	                                        if ((c[(c[s >> 2] | 0) + 4 >> 2] | 0) != 7)break d
	                                    } while (0);
	                                    c[p >> 2] = KQ(c[u >> 2] | 0) | 0
	                                } while (0);
	                                y = c[s >> 2] | 0;
	                                if (c[(c[s >> 2] | 0) + 24 >> 2] | 0)break;
	                                if (!y) {
	                                    x = 80;
	                                    break c
	                                }
	                            }
	                            c[s >> 2] = c[y + 24 >> 2];
	                            x = 80
	                        } while (0);
	                        if ((x | 0) == 80 ? (x = 0, !((c[s >> 2] | 0) != 0 & (c[q >> 2] | 0) >= 0)) : 0)break;
	                        e:while (1) {
	                            c[v >> 2] = (c[v >> 2] | 0) + 1;
	                            switch (c[(c[s >> 2] | 0) + 4 >> 2] | 0) {
	                                case 7:
	                                case 8:
	                                case 4:
	                                case 3:
	                                case 1:
	                                    break;
	                                default:
	                                    continue b
	                            }
	                            if ((c[(c[s >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                                if (c[(c[s >> 2] | 0) + 36 >> 2] | 0)z = c[(c[(c[s >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0; else z = 0;
	                                c[p >> 2] = HQ(c[u >> 2] | 0, c[(c[s >> 2] | 0) + 8 >> 2] | 0, z) | 0
	                            } else {
	                                if (!(c[r >> 2] | 0))continue b;
	                                c[p >> 2] = IQ(c[u >> 2] | 0, 0, 0, c[(c[s >> 2] | 0) + 4 >> 2] | 0) | 0
	                            }
	                            do if ((c[p >> 2] | 0) >= 0 & (c[p >> 2] | 0) == 1) {
	                                if (c[l >> 2] | 0)break a;
	                                if ((dr(c[(c[c[k >> 2] >> 2] | 0) + 4 >> 2] | 0, c[s >> 2] | 0) | 0) >= 0)break;
	                                c[(c[h >> 2] | 0) + 136 >> 2] = 12;
	                                c[(c[h >> 2] | 0) + 140 >> 2] = 2
	                            } while (0);
	                            if ((c[(c[s >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[q >> 2] | 0) < (c[m >> 2] | 0) : 0)continue b;
	                            c[p >> 2] = KQ(c[u >> 2] | 0) | 0;
	                            while (1) {
	                                if (!(c[(c[s >> 2] | 0) + 24 >> 2] | 0))continue b;
	                                c[s >> 2] = c[(c[s >> 2] | 0) + 24 >> 2];
	                                if ((c[(c[s >> 2] | 0) + 4 >> 2] | 0) == 17)continue;
	                                if ((c[(c[s >> 2] | 0) + 4 >> 2] | 0) != 14)continue e
	                            }
	                        }
	                    }
	                    if (c[u >> 2] | 0)GQ(c[u >> 2] | 0);
	                    c[g >> 2] = 0;
	                    w = c[g >> 2] | 0;
	                    i = f;
	                    return w | 0
	                } while (0);
	                if (c[u >> 2] | 0)GQ(c[u >> 2] | 0);
	                c[g >> 2] = 1;
	                w = c[g >> 2] | 0;
	                i = f;
	                return w | 0
	            }

	            function hu(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 0;
	                while (1) {
	                    d = c[c[h >> 2] >> 2] | 0;
	                    if (!d) {
	                        m = 3;
	                        break
	                    } else if ((d | 0) == 11) {
	                        m = 10;
	                        break
	                    } else if ((d | 0) == 12) {
	                        m = 4;
	                        break
	                    } else if ((d | 0) != 18) {
	                        m = 18;
	                        break
	                    }
	                    if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == -1) {
	                        m = 9;
	                        break
	                    }
	                    c[h >> 2] = (c[(c[(c[g >> 2] | 0) + 32 >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) * 40 | 0)
	                }
	                do if ((m | 0) == 3)c[f >> 2] = 0; else if ((m | 0) == 4) {
	                    c[k >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                    if (c[j >> 2] | 0) {
	                        c[f >> 2] = Ns(c[g >> 2] | 0, c[k >> 2] | 0) | 0;
	                        break
	                    } else {
	                        c[f >> 2] = Vq(c[k >> 2] | 0) | 0;
	                        break
	                    }
	                } else if ((m | 0) == 9)c[f >> 2] = 0; else if ((m | 0) == 10) {
	                    if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == -1) {
	                        c[f >> 2] = 0;
	                        break
	                    }
	                    iu(c[g >> 2] | 0, (c[(c[(c[g >> 2] | 0) + 32 >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0) | 0;
	                    if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                        c[f >> 2] = -1;
	                        break
	                    }
	                    nu(c[g >> 2] | 0, c[h >> 2] | 0, 0, 0, 1) | 0;
	                    if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                        c[f >> 2] = -1;
	                        break
	                    }
	                    c[k >> 2] = Sq(c[g >> 2] | 0) | 0;
	                    if (!(c[k >> 2] | 0))c[f >> 2] = -1; else m = 22
	                } else if ((m | 0) == 18) {
	                    iu(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                    if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                        c[f >> 2] = -1;
	                        break
	                    }
	                    c[k >> 2] = Sq(c[g >> 2] | 0) | 0;
	                    if (!(c[k >> 2] | 0))c[f >> 2] = -1; else m = 22
	                } while (0);
	                do if ((m | 0) == 22) {
	                    if (!(c[k >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        break
	                    }
	                    do if ((c[c[k >> 2] >> 2] | 0) != 2)if (c[j >> 2] | 0) {
	                        c[l >> 2] = Ns(c[g >> 2] | 0, c[k >> 2] | 0) | 0;
	                        break
	                    } else {
	                        c[l >> 2] = Vq(c[k >> 2] | 0) | 0;
	                        break
	                    } else c[l >> 2] = c[(c[k >> 2] | 0) + 8 >> 2]; while (0);
	                    jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[k >> 2] | 0);
	                    c[f >> 2] = c[l >> 2]
	                } while (0);
	                i = e;
	                return c[f >> 2] | 0
	            }

	            function iu(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0, J = 0, K = 0, L = 0, M = 0, N = 0, O = 0, P = 0, Q = 0, R = 0, S = 0, T = 0, U = 0, V = 0, W = 0, X = 0, Y = 0, Z = 0, _ = 0, $ = 0, aa = 0, ba = 0, ca = 0;
	                d = i;
	                i = i + 192 | 0;
	                e = d;
	                f = d + 184 | 0;
	                g = d + 180 | 0;
	                j = d + 176 | 0;
	                k = d + 172 | 0;
	                l = d + 168 | 0;
	                m = d + 164 | 0;
	                n = d + 160 | 0;
	                o = d + 156 | 0;
	                p = d + 152 | 0;
	                q = d + 148 | 0;
	                r = d + 144 | 0;
	                s = d + 140 | 0;
	                t = d + 136 | 0;
	                u = d + 132 | 0;
	                v = d + 128 | 0;
	                w = d + 124 | 0;
	                x = d + 120 | 0;
	                y = d + 116 | 0;
	                z = d + 112 | 0;
	                A = d + 108 | 0;
	                B = d + 104 | 0;
	                C = d + 100 | 0;
	                D = d + 96 | 0;
	                E = d + 92 | 0;
	                F = d + 88 | 0;
	                G = d + 84 | 0;
	                H = d + 80 | 0;
	                I = d + 76 | 0;
	                J = d + 72 | 0;
	                K = d + 68 | 0;
	                L = d + 64 | 0;
	                M = d + 60 | 0;
	                N = d + 56 | 0;
	                O = d + 52 | 0;
	                P = d + 48 | 0;
	                Q = d + 44 | 0;
	                R = d + 40 | 0;
	                S = d + 36 | 0;
	                T = d + 32 | 0;
	                U = d + 28 | 0;
	                V = d + 24 | 0;
	                W = d + 20 | 0;
	                X = d + 16 | 0;
	                Y = d + 12 | 0;
	                Z = d + 8 | 0;
	                c[g >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = 0;
	                if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                    c[f >> 2] = 0;
	                    _ = c[f >> 2] | 0;
	                    i = d;
	                    return _ | 0
	                }
	                c[n >> 2] = c[(c[g >> 2] | 0) + 32 >> 2];
	                do switch (c[c[j >> 2] >> 2] | 0) {
	                    case 0:
	                    {
	                        c[f >> 2] = 0;
	                        _ = c[f >> 2] | 0;
	                        i = d;
	                        return _ | 0
	                    }
	                    case 8:
	                    {
	                        ks(c[g >> 2] | 0);
	                        c[f >> 2] = c[k >> 2];
	                        _ = c[f >> 2] | 0;
	                        i = d;
	                        return _ | 0
	                    }
	                    case 10:
	                    {
	                        if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) != -1) {
	                            b = iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0) | 0;
	                            c[k >> 2] = (c[k >> 2] | 0) + b
	                        }
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        if ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) != -1) {
	                            b = iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) | 0) | 0;
	                            c[k >> 2] = (c[k >> 2] | 0) + b
	                        }
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        } else {
	                            c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 0;
	                            c[f >> 2] = c[k >> 2];
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        break
	                    }
	                    case 9:
	                    {
	                        if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) != -1) {
	                            b = iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0) | 0;
	                            c[k >> 2] = (c[k >> 2] | 0) + b
	                        }
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        if ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) != -1) {
	                            b = iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) | 0) | 0;
	                            c[k >> 2] = (c[k >> 2] | 0) + b
	                        }
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        } else {
	                            b = c[g >> 2] | 0;
	                            Tq(b, yt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) | 0) | 0;
	                            c[f >> 2] = c[k >> 2];
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        break
	                    }
	                    case 11:
	                    {
	                        if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) == -1) {
	                            c[f >> 2] = c[k >> 2];
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        c[k >> 2] = (iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0) | 0) + (c[k >> 2] | 0);
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        } else {
	                            b = nu(c[g >> 2] | 0, c[j >> 2] | 0, 0, 0, 0) | 0;
	                            c[k >> 2] = (c[k >> 2] | 0) + b;
	                            c[f >> 2] = c[k >> 2];
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        break
	                    }
	                    case 7:
	                    {
	                        c[r >> 2] = c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2];
	                        c[q >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2];
	                        c[s >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2];
	                        c[t >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2];
	                        c[k >> 2] = (iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0) | 0) + (c[k >> 2] | 0);
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2] = c[r >> 2];
	                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[q >> 2];
	                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2] = c[s >> 2];
	                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] = c[t >> 2];
	                        c[k >> 2] = (iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) | 0) | 0) + (c[k >> 2] | 0);
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) == 1 : 0) {
	                            c[p >> 2] = Sq(c[g >> 2] | 0) | 0;
	                            if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) == 1 : 0) {
	                                c[o >> 2] = Sq(c[g >> 2] | 0) | 0;
	                                if (c[(c[o >> 2] | 0) + 4 >> 2] | 0) {
	                                    if ((c[(c[p >> 2] | 0) + 4 >> 2] | 0) != 0 ? (c[c[(c[p >> 2] | 0) + 4 >> 2] >> 2] | 0) != 0 : 0)$ = 78
	                                } else $ = 78;
	                                if (($ | 0) == 78) {
	                                    b = er(c[(c[o >> 2] | 0) + 4 >> 2] | 0, c[(c[p >> 2] | 0) + 4 >> 2] | 0) | 0;
	                                    c[(c[o >> 2] | 0) + 4 >> 2] = b
	                                }
	                                Tq(c[g >> 2] | 0, c[o >> 2] | 0) | 0;
	                                jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[p >> 2] | 0);
	                                c[f >> 2] = c[k >> 2];
	                                _ = c[f >> 2] | 0;
	                                i = d;
	                                return _ | 0
	                            }
	                            Nq(c[g >> 2] | 0, 11);
	                            c[f >> 2] = 0;
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        Nq(c[g >> 2] | 0, 11);
	                        c[f >> 2] = 0;
	                        _ = c[f >> 2] | 0;
	                        i = d;
	                        return _ | 0
	                    }
	                    case 5:
	                    {
	                        c[r >> 2] = c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2];
	                        c[q >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2];
	                        c[s >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2];
	                        c[t >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2];
	                        c[k >> 2] = (iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0) | 0) + (c[k >> 2] | 0);
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        if ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) != -1) {
	                            c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2] = c[r >> 2];
	                            c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[q >> 2];
	                            c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2] = c[s >> 2];
	                            c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] = c[t >> 2];
	                            b = iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) | 0) | 0;
	                            c[k >> 2] = (c[k >> 2] | 0) + b
	                        }
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        do if (c[(c[j >> 2] | 0) + 12 >> 2] | 0) {
	                            if ((c[(c[j >> 2] | 0) + 12 >> 2] | 0) == 1) {
	                                Vr(c[g >> 2] | 0);
	                                break
	                            }
	                            if ((c[(c[j >> 2] | 0) + 12 >> 2] | 0) == 2) {
	                                Ur(c[g >> 2] | 0);
	                                break
	                            }
	                            if ((c[(c[j >> 2] | 0) + 12 >> 2] | 0) == 3) {
	                                if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) != 3 : 0)Tr(c[g >> 2] | 0, 1);
	                                if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) == 3 : 0)break;
	                                Nq(c[g >> 2] | 0, 11);
	                                c[f >> 2] = 0;
	                                _ = c[f >> 2] | 0;
	                                i = d;
	                                return _ | 0
	                            }
	                        } else Wr(c[g >> 2] | 0); while (0);
	                        c[f >> 2] = c[k >> 2];
	                        _ = c[f >> 2] | 0;
	                        i = d;
	                        return _ | 0
	                    }
	                    case 1:
	                    {
	                        c[r >> 2] = c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2];
	                        c[q >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2];
	                        c[s >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2];
	                        c[t >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2];
	                        c[k >> 2] = (iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0) | 0) + (c[k >> 2] | 0);
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        Bs(c[g >> 2] | 0, 1);
	                        if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                            c[p >> 2] = Sq(c[g >> 2] | 0) | 0;
	                            c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2] = c[r >> 2];
	                            c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[q >> 2];
	                            c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2] = c[s >> 2];
	                            c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] = c[t >> 2];
	                            b = iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) | 0) | 0;
	                            c[k >> 2] = (c[k >> 2] | 0) + b;
	                            if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                                Qq(c[p >> 2] | 0);
	                                c[f >> 2] = 0;
	                                _ = c[f >> 2] | 0;
	                                i = d;
	                                return _ | 0
	                            } else {
	                                Bs(c[g >> 2] | 0, 1);
	                                c[o >> 2] = Sq(c[g >> 2] | 0) | 0;
	                                b = (c[o >> 2] | 0) + 8 | 0;
	                                c[b >> 2] = c[b >> 2] & c[(c[p >> 2] | 0) + 8 >> 2];
	                                Tq(c[g >> 2] | 0, c[o >> 2] | 0) | 0;
	                                jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[p >> 2] | 0);
	                                c[f >> 2] = c[k >> 2];
	                                _ = c[f >> 2] | 0;
	                                i = d;
	                                return _ | 0
	                            }
	                        }
	                        c[f >> 2] = c[k >> 2];
	                        _ = c[f >> 2] | 0;
	                        i = d;
	                        return _ | 0
	                    }
	                    case 2:
	                    {
	                        c[r >> 2] = c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2];
	                        c[q >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2];
	                        c[s >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2];
	                        c[t >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2];
	                        c[k >> 2] = (iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0) | 0) + (c[k >> 2] | 0);
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        Bs(c[g >> 2] | 0, 1);
	                        if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 8 >> 2] | 0) != 1 : 0) {
	                            c[p >> 2] = Sq(c[g >> 2] | 0) | 0;
	                            c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2] = c[r >> 2];
	                            c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[q >> 2];
	                            c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2] = c[s >> 2];
	                            c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] = c[t >> 2];
	                            b = iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) | 0) | 0;
	                            c[k >> 2] = (c[k >> 2] | 0) + b;
	                            if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                                Qq(c[p >> 2] | 0);
	                                c[f >> 2] = 0;
	                                _ = c[f >> 2] | 0;
	                                i = d;
	                                return _ | 0
	                            } else {
	                                Bs(c[g >> 2] | 0, 1);
	                                c[o >> 2] = Sq(c[g >> 2] | 0) | 0;
	                                b = (c[o >> 2] | 0) + 8 | 0;
	                                c[b >> 2] = c[b >> 2] | c[(c[p >> 2] | 0) + 8 >> 2];
	                                Tq(c[g >> 2] | 0, c[o >> 2] | 0) | 0;
	                                jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[p >> 2] | 0);
	                                c[f >> 2] = c[k >> 2];
	                                _ = c[f >> 2] | 0;
	                                i = d;
	                                return _ | 0
	                            }
	                        }
	                        c[f >> 2] = c[k >> 2];
	                        _ = c[f >> 2] | 0;
	                        i = d;
	                        return _ | 0
	                    }
	                    case 4:
	                    {
	                        c[r >> 2] = c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2];
	                        c[q >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2];
	                        c[s >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2];
	                        c[t >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2];
	                        c[k >> 2] = (iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0) | 0) + (c[k >> 2] | 0);
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2] = c[r >> 2];
	                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[q >> 2];
	                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2] = c[s >> 2];
	                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] = c[t >> 2];
	                        c[k >> 2] = (iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) | 0) | 0) + (c[k >> 2] | 0);
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        } else {
	                            c[m >> 2] = Sr(c[g >> 2] | 0, c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[(c[j >> 2] | 0) + 16 >> 2] | 0) | 0;
	                            b = c[g >> 2] | 0;
	                            Tq(b, Ft(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[m >> 2] | 0) | 0) | 0;
	                            c[f >> 2] = c[k >> 2];
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        break
	                    }
	                    case 12:
	                    {
	                        Tq(c[g >> 2] | 0, lt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[(c[j >> 2] | 0) + 24 >> 2] | 0) | 0) | 0;
	                        c[f >> 2] = c[k >> 2];
	                        _ = c[f >> 2] | 0;
	                        i = d;
	                        return _ | 0
	                    }
	                    case 13:
	                    {
	                        if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) != -1) {
	                            b = iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0) | 0;
	                            c[k >> 2] = (c[k >> 2] | 0) + b
	                        }
	                        b = c[(c[g >> 2] | 0) + 12 >> 2] | 0;
	                        a = c[j >> 2] | 0;
	                        do if (!(c[(c[j >> 2] | 0) + 28 >> 2] | 0)) {
	                            c[u >> 2] = or(b, c[a + 24 >> 2] | 0) | 0;
	                            aa = c[g >> 2] | 0;
	                            if (c[u >> 2] | 0) {
	                                Tq(aa, c[u >> 2] | 0) | 0;
	                                break
	                            }
	                            c[aa + 8 >> 2] = 5;
	                            c[f >> 2] = 0;
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        } else {
	                            c[v >> 2] = sr(b, c[a + 28 >> 2] | 0) | 0;
	                            if (!(c[v >> 2] | 0)) {
	                                aa = c[33976] | 0;
	                                ba = c[33980] | 0;
	                                ca = c[(c[j >> 2] | 0) + 28 >> 2] | 0;
	                                c[e >> 2] = c[(c[j >> 2] | 0) + 24 >> 2];
	                                c[e + 4 >> 2] = ca;
	                                Db[aa & 511](ba, 130032, e);
	                                c[(c[g >> 2] | 0) + 8 >> 2] = 19;
	                                c[f >> 2] = c[k >> 2];
	                                _ = c[f >> 2] | 0;
	                                i = d;
	                                return _ | 0
	                            }
	                            c[u >> 2] = pr(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[(c[j >> 2] | 0) + 24 >> 2] | 0, c[v >> 2] | 0) | 0;
	                            ba = c[g >> 2] | 0;
	                            if (c[u >> 2] | 0) {
	                                Tq(ba, c[u >> 2] | 0) | 0;
	                                break
	                            }
	                            c[ba + 8 >> 2] = 5;
	                            c[f >> 2] = 0;
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        } while (0);
	                        c[f >> 2] = c[k >> 2];
	                        _ = c[f >> 2] | 0;
	                        i = d;
	                        return _ | 0
	                    }
	                    case 14:
	                    {
	                        c[A >> 2] = ou(c[g >> 2] | 0) | 0;
	                        if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) != -1 ? (a = iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0) | 0, c[k >> 2] = (c[k >> 2] | 0) + a, (c[(c[g >> 2] | 0) + 8 >> 2] | 0) != 0) : 0) {
	                            pu(c[g >> 2] | 0, c[A >> 2] | 0);
	                            c[f >> 2] = c[k >> 2];
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        if ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) < ((c[(c[g >> 2] | 0) + 44 >> 2] | 0) + (c[(c[j >> 2] | 0) + 12 >> 2] | 0) | 0)) {
	                            Db[c[135904 >> 2] & 511](c[33980] | 0, 130096, e);
	                            c[(c[g >> 2] | 0) + 8 >> 2] = 10;
	                            pu(c[g >> 2] | 0, c[A >> 2] | 0);
	                            c[f >> 2] = c[k >> 2];
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        c[z >> 2] = 0;
	                        while (1) {
	                            if ((c[z >> 2] | 0) >= (c[(c[j >> 2] | 0) + 12 >> 2] | 0))break;
	                            if (!(c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) - 1 - (c[z >> 2] | 0) << 2) >> 2] | 0)) {
	                                $ = 125;
	                                break
	                            }
	                            c[z >> 2] = (c[z >> 2] | 0) + 1
	                        }
	                        if (($ | 0) == 125) {
	                            Db[c[135904 >> 2] & 511](c[33980] | 0, 130096, e);
	                            c[(c[g >> 2] | 0) + 8 >> 2] = 10;
	                            pu(c[g >> 2] | 0, c[A >> 2] | 0);
	                            c[f >> 2] = c[k >> 2];
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        do if (c[(c[j >> 2] | 0) + 32 >> 2] | 0)c[w >> 2] = c[(c[j >> 2] | 0) + 32 >> 2]; else {
	                            c[B >> 2] = 0;
	                            a = c[(c[g >> 2] | 0) + 12 >> 2] | 0;
	                            b = c[j >> 2] | 0;
	                            do if (!(c[(c[j >> 2] | 0) + 28 >> 2] | 0))c[w >> 2] = lr(a, c[b + 24 >> 2] | 0) | 0; else {
	                                c[B >> 2] = sr(a, c[b + 28 >> 2] | 0) | 0;
	                                if (c[B >> 2] | 0) {
	                                    c[w >> 2] = mr(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[(c[j >> 2] | 0) + 24 >> 2] | 0, c[B >> 2] | 0) | 0;
	                                    break
	                                }
	                                ba = c[33976] | 0;
	                                aa = c[33980] | 0;
	                                ca = c[(c[j >> 2] | 0) + 28 >> 2] | 0;
	                                c[e >> 2] = c[(c[j >> 2] | 0) + 24 >> 2];
	                                c[e + 4 >> 2] = ca;
	                                Db[ba & 511](aa, 130136, e);
	                                pu(c[g >> 2] | 0, c[A >> 2] | 0);
	                                c[(c[g >> 2] | 0) + 8 >> 2] = 19;
	                                c[f >> 2] = c[k >> 2];
	                                _ = c[f >> 2] | 0;
	                                i = d;
	                                return _ | 0
	                            } while (0);
	                            if (c[w >> 2] | 0) {
	                                c[(c[j >> 2] | 0) + 32 >> 2] = c[w >> 2];
	                                c[(c[j >> 2] | 0) + 36 >> 2] = c[B >> 2];
	                                break
	                            }
	                            b = c[33976] | 0;
	                            a = c[33980] | 0;
	                            c[e >> 2] = c[(c[j >> 2] | 0) + 24 >> 2];
	                            Db[b & 511](a, 130200, e);
	                            Nq(c[g >> 2] | 0, 9);
	                            c[f >> 2] = 0;
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        } while (0);
	                        c[x >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 104 >> 2];
	                        c[y >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 108 >> 2];
	                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 104 >> 2] = c[(c[j >> 2] | 0) + 24 >> 2];
	                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 108 >> 2] = c[(c[j >> 2] | 0) + 36 >> 2];
	                        Ab[c[w >> 2] & 511](c[g >> 2] | 0, c[(c[j >> 2] | 0) + 12 >> 2] | 0);
	                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 104 >> 2] = c[x >> 2];
	                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 108 >> 2] = c[y >> 2];
	                        pu(c[g >> 2] | 0, c[A >> 2] | 0);
	                        c[f >> 2] = c[k >> 2];
	                        _ = c[f >> 2] | 0;
	                        i = d;
	                        return _ | 0
	                    }
	                    case 18:
	                    {
	                        if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) != -1) {
	                            a = iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0) | 0;
	                            c[k >> 2] = (c[k >> 2] | 0) + a
	                        }
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        if ((((c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) == 1 : 0) ? (c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) ? (c[c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] >> 2] | 0) > 1 : 0)Zq(c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0);
	                        c[f >> 2] = c[k >> 2];
	                        _ = c[f >> 2] | 0;
	                        i = d;
	                        return _ | 0
	                    }
	                    case 19:
	                    {
	                        c[U >> 2] = 0;
	                        if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) != -1) {
	                            a = iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0) | 0;
	                            c[k >> 2] = (c[k >> 2] | 0) + a
	                        }
	                        if ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) == -1) {
	                            c[f >> 2] = c[k >> 2];
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        a = (c[(c[g >> 2] | 0) + 16 >> 2] | 0) == 0;
	                        a:do if ((c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) == 7) {
	                            if (!a ? (c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) == 7 : 0) {
	                                c[S >> 2] = Sq(c[g >> 2] | 0) | 0;
	                                c[V >> 2] = c[(c[S >> 2] | 0) + 28 >> 2];
	                                if ((c[V >> 2] | 0) != 0 ? (c[c[V >> 2] >> 2] | 0) != 0 : 0) {
	                                    c[U >> 2] = bv(0) | 0;
	                                    c[X >> 2] = 0;
	                                    while (1) {
	                                        if ((c[X >> 2] | 0) >= (c[c[V >> 2] >> 2] | 0))break a;
	                                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[(c[(c[(c[V >> 2] | 0) + 8 >> 2] | 0) + (c[X >> 2] << 2) >> 2] | 0) + 28 >> 2];
	                                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] = c[c[V >> 2] >> 2];
	                                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2] = (c[X >> 2] | 0) + 1;
	                                        c[T >> 2] = yt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) | 0;
	                                        Tq(c[g >> 2] | 0, c[T >> 2] | 0) | 0;
	                                        if ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) != -1) {
	                                            b = iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) | 0) | 0;
	                                            c[k >> 2] = (c[k >> 2] | 0) + b
	                                        }
	                                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0)break;
	                                        c[R >> 2] = Sq(c[g >> 2] | 0) | 0;
	                                        b:do if ((c[c[R >> 2] >> 2] | 0) != 7) {
	                                            c[Q >> 2] = av(c[(c[(c[(c[V >> 2] | 0) + 8 >> 2] | 0) + (c[X >> 2] << 2) >> 2] | 0) + 28 >> 2] | 0, c[R >> 2] | 0) | 0;
	                                            if (c[Q >> 2] | 0)cv(c[U >> 2] | 0, c[Q >> 2] | 0)
	                                        } else {
	                                            c[Z >> 2] = c[(c[R >> 2] | 0) + 28 >> 2];
	                                            c[Y >> 2] = 0;
	                                            while (1) {
	                                                if ((c[Y >> 2] | 0) >= (c[c[Z >> 2] >> 2] | 0))break b;
	                                                c[Q >> 2] = Zu(c[(c[(c[(c[V >> 2] | 0) + 8 >> 2] | 0) + (c[X >> 2] << 2) >> 2] | 0) + 28 >> 2] | 0, c[(c[(c[(c[V >> 2] | 0) + 8 >> 2] | 0) + (c[X >> 2] << 2) >> 2] | 0) + 32 >> 2] | 0, c[(c[(c[(c[Z >> 2] | 0) + 8 >> 2] | 0) + (c[Y >> 2] << 2) >> 2] | 0) + 36 >> 2] | 0, c[(c[(c[(c[Z >> 2] | 0) + 8 >> 2] | 0) + (c[Y >> 2] << 2) >> 2] | 0) + 40 >> 2] | 0) | 0;
	                                                if (c[Q >> 2] | 0)cv(c[U >> 2] | 0, c[Q >> 2] | 0);
	                                                c[Y >> 2] = (c[Y >> 2] | 0) + 1
	                                            }
	                                        } while (0);
	                                        if (c[R >> 2] | 0)jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[R >> 2] | 0);
	                                        if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) == (c[T >> 2] | 0)) {
	                                            c[R >> 2] = Sq(c[g >> 2] | 0) | 0;
	                                            jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[R >> 2] | 0)
	                                        }
	                                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 0;
	                                        c[X >> 2] = (c[X >> 2] | 0) + 1
	                                    }
	                                    Qq(c[S >> 2] | 0);
	                                    c[f >> 2] = 0;
	                                    _ = c[f >> 2] | 0;
	                                    i = d;
	                                    return _ | 0
	                                }
	                                c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 0;
	                                c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] = 0;
	                                c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2] = 0;
	                                b = iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) | 0) | 0;
	                                c[k >> 2] = (c[k >> 2] | 0) + b;
	                                c[R >> 2] = Sq(c[g >> 2] | 0) | 0;
	                                if (c[R >> 2] | 0)jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[R >> 2] | 0);
	                                Tq(c[g >> 2] | 0, c[S >> 2] | 0) | 0;
	                                if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                                    c[f >> 2] = 0;
	                                    _ = c[f >> 2] | 0;
	                                    i = d;
	                                    return _ | 0
	                                } else {
	                                    c[f >> 2] = c[k >> 2];
	                                    _ = c[f >> 2] | 0;
	                                    i = d;
	                                    return _ | 0
	                                }
	                            }
	                            Nq(c[g >> 2] | 0, 11);
	                            c[f >> 2] = 0;
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        } else {
	                            if (!a ? (c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) == 1 : 0) {
	                                c[S >> 2] = Sq(c[g >> 2] | 0) | 0;
	                                c[W >> 2] = c[(c[S >> 2] | 0) + 4 >> 2];
	                                c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 0;
	                                c[U >> 2] = bv(0) | 0;
	                                if (!(c[W >> 2] | 0))break;
	                                c[X >> 2] = 0;
	                                while (1) {
	                                    if ((c[X >> 2] | 0) >= (c[c[W >> 2] >> 2] | 0))break a;
	                                    c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[(c[(c[W >> 2] | 0) + 8 >> 2] | 0) + (c[X >> 2] << 2) >> 2];
	                                    c[T >> 2] = yt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) | 0;
	                                    Tq(c[g >> 2] | 0, c[T >> 2] | 0) | 0;
	                                    if ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) != -1) {
	                                        b = iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) | 0) | 0;
	                                        c[k >> 2] = (c[k >> 2] | 0) + b
	                                    }
	                                    if (c[(c[g >> 2] | 0) + 8 >> 2] | 0)break;
	                                    c[R >> 2] = Sq(c[g >> 2] | 0) | 0;
	                                    c[Q >> 2] = av(c[(c[(c[W >> 2] | 0) + 8 >> 2] | 0) + (c[X >> 2] << 2) >> 2] | 0, c[R >> 2] | 0) | 0;
	                                    if (c[Q >> 2] | 0)cv(c[U >> 2] | 0, c[Q >> 2] | 0);
	                                    if (c[R >> 2] | 0)jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[R >> 2] | 0);
	                                    if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) == (c[T >> 2] | 0)) {
	                                        c[R >> 2] = Sq(c[g >> 2] | 0) | 0;
	                                        jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[R >> 2] | 0)
	                                    }
	                                    c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 0;
	                                    c[X >> 2] = (c[X >> 2] | 0) + 1
	                                }
	                                Qq(c[S >> 2] | 0);
	                                c[f >> 2] = 0;
	                                _ = c[f >> 2] | 0;
	                                i = d;
	                                return _ | 0
	                            }
	                            Nq(c[g >> 2] | 0, 11);
	                            c[f >> 2] = 0;
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        } while (0);
	                        jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[S >> 2] | 0);
	                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 0;
	                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] = -1;
	                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2] = -1;
	                        a = c[g >> 2] | 0;
	                        Tq(a, hv(c[U >> 2] | 0) | 0) | 0;
	                        c[f >> 2] = c[k >> 2];
	                        _ = c[f >> 2] | 0;
	                        i = d;
	                        return _ | 0
	                    }
	                    case 15:
	                    {
	                        c[r >> 2] = c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2];
	                        c[q >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2];
	                        c[s >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2];
	                        c[t >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2];
	                        if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) != -1 ? (a = iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0) | 0, c[k >> 2] = (c[k >> 2] | 0) + a, c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] = c[t >> 2], c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2] = c[s >> 2], c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[q >> 2], c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2] = c[r >> 2], (c[(c[g >> 2] | 0) + 8 >> 2] | 0) != 0) : 0) {
	                            c[f >> 2] = 0;
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        if ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) != -1 ? (a = iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) | 0) | 0, c[k >> 2] = (c[k >> 2] | 0) + a, c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] = c[t >> 2], c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2] = c[s >> 2], c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[q >> 2], c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2] = c[r >> 2], (c[(c[g >> 2] | 0) + 8 >> 2] | 0) != 0) : 0) {
	                            c[f >> 2] = 0;
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        c[f >> 2] = c[k >> 2];
	                        _ = c[f >> 2] | 0;
	                        i = d;
	                        return _ | 0
	                    }
	                    case 17:
	                    case 16:
	                    {
	                        c[F >> 2] = 0;
	                        do if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) != -1 ? (c[(c[j >> 2] | 0) + 8 >> 2] | 0) != -1 : 0) {
	                            if ((c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) >> 2] | 0) != 18 ? (c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) >> 2] | 0) != 17 : 0)break;
	                            if ((((c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) >> 2] | 0) == 12 ? (c[K >> 2] = c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) + 24 >> 2], (c[K >> 2] | 0) != 0) : 0) ? (c[c[K >> 2] >> 2] | 0) == 3 : 0) ? +h[(c[K >> 2] | 0) + 16 >> 3] == 1.0 : 0) {
	                                c[L >> 2] = 0;
	                                a = qu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0, L) | 0;
	                                c[k >> 2] = (c[k >> 2] | 0) + a;
	                                if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                                    c[f >> 2] = 0;
	                                    _ = c[f >> 2] | 0;
	                                    i = d;
	                                    return _ | 0
	                                }
	                                if ((((c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) == 1 : 0) ? (c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) ? (c[c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] >> 2] | 0) > 1 : 0)c[c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] >> 2] = 1;
	                                c[f >> 2] = c[k >> 2];
	                                _ = c[f >> 2] | 0;
	                                i = d;
	                                return _ | 0
	                            }
	                        } while (0);
	                        if ((((((((((c[(c[j >> 2] | 0) + 4 >> 2] | 0) != -1 ? (c[(c[j >> 2] | 0) + 8 >> 2] | 0) != -1 : 0) ? (c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) >> 2] | 0) == 18 : 0) ? (c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) >> 2] | 0) == 18 : 0) ? (c[M >> 2] = c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) + 4 >> 2], (c[M >> 2] | 0) != -1) : 0) ? (c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[M >> 2] | 0) * 40 | 0) >> 2] | 0) == 14 : 0) ? (c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[M >> 2] | 0) * 40 | 0) + 28 >> 2] | 0) == 0 : 0) ? (c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[M >> 2] | 0) * 40 | 0) + 12 >> 2] | 0) == 0 : 0) ? (c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[M >> 2] | 0) * 40 | 0) + 24 >> 2] | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[M >> 2] | 0) * 40 | 0) + 24 >> 2] | 0, 129656) | 0) != 0 : 0) {
	                            c[N >> 2] = 0;
	                            a = ru(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0, N) | 0;
	                            c[k >> 2] = (c[k >> 2] | 0) + a;
	                            if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                                c[f >> 2] = 0;
	                                _ = c[f >> 2] | 0;
	                                i = d;
	                                return _ | 0
	                            }
	                            do if ((((c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) == 1 : 0) ? (c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) ? (c[(c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                                if ((c[c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] >> 2] | 0) <= 1)break;
	                                c[c[(c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] >> 2] = c[(c[(c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) + ((c[c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] >> 2] | 0) - 1 << 2) >> 2];
	                                c[c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] >> 2] = 1
	                            } while (0);
	                            c[f >> 2] = c[k >> 2];
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) != -1) {
	                            a = iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0) | 0;
	                            c[k >> 2] = (c[k >> 2] | 0) + a
	                        }
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        if ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) == -1) {
	                            c[f >> 2] = c[k >> 2];
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        if (!(c[(c[g >> 2] | 0) + 16 >> 2] | 0)) {
	                            c[f >> 2] = c[k >> 2];
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        c[H >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2];
	                        if ((c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) == 7) {
	                            c[O >> 2] = 0;
	                            if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) == 7 : 0) {
	                                c[D >> 2] = Sq(c[g >> 2] | 0) | 0;
	                                c[P >> 2] = c[(c[D >> 2] | 0) + 28 >> 2];
	                                c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 0;
	                                if ((c[P >> 2] | 0) != 0 ? (c[c[P >> 2] >> 2] | 0) != 0 : 0) {
	                                    c[O >> 2] = bv(0) | 0;
	                                    c[J >> 2] = 0;
	                                    while (1) {
	                                        if ((c[J >> 2] | 0) >= (c[c[P >> 2] >> 2] | 0)) {
	                                            $ = 214;
	                                            break
	                                        }
	                                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[(c[(c[(c[P >> 2] | 0) + 8 >> 2] | 0) + (c[J >> 2] << 2) >> 2] | 0) + 28 >> 2];
	                                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] = c[c[P >> 2] >> 2];
	                                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2] = (c[J >> 2] | 0) + 1;
	                                        c[E >> 2] = yt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) | 0;
	                                        Tq(c[g >> 2] | 0, c[E >> 2] | 0) | 0;
	                                        if ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) != -1) {
	                                            a = iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) | 0) | 0;
	                                            c[k >> 2] = (c[k >> 2] | 0) + a
	                                        }
	                                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                                            $ = 206;
	                                            break
	                                        }
	                                        c[C >> 2] = Sq(c[g >> 2] | 0) | 0;
	                                        if (Ns(c[g >> 2] | 0, c[C >> 2] | 0) | 0) {
	                                            a = c[O >> 2] | 0;
	                                            cv(a, zr(c[(c[(c[P >> 2] | 0) + 8 >> 2] | 0) + (c[J >> 2] << 2) >> 2] | 0) | 0)
	                                        }
	                                        if (c[C >> 2] | 0)jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[C >> 2] | 0);
	                                        if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) == (c[E >> 2] | 0)) {
	                                            c[C >> 2] = Sq(c[g >> 2] | 0) | 0;
	                                            jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[C >> 2] | 0)
	                                        }
	                                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 0;
	                                        c[J >> 2] = (c[J >> 2] | 0) + 1
	                                    }
	                                    if (($ | 0) == 206) {
	                                        Qq(c[D >> 2] | 0);
	                                        c[f >> 2] = 0;
	                                        _ = c[f >> 2] | 0;
	                                        i = d;
	                                        return _ | 0
	                                    } else if (($ | 0) == 214) {
	                                        jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[D >> 2] | 0);
	                                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 0;
	                                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] = -1;
	                                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2] = -1;
	                                        a = c[g >> 2] | 0;
	                                        Tq(a, hv(c[O >> 2] | 0) | 0) | 0;
	                                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[H >> 2];
	                                        c[f >> 2] = c[k >> 2];
	                                        _ = c[f >> 2] | 0;
	                                        i = d;
	                                        return _ | 0
	                                    }
	                                }
	                                c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] = 0;
	                                c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2] = 0;
	                                if ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) != -1) {
	                                    a = iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) | 0) | 0;
	                                    c[k >> 2] = (c[k >> 2] | 0) + a
	                                }
	                                c[C >> 2] = Sq(c[g >> 2] | 0) | 0;
	                                if (c[C >> 2] | 0)jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[C >> 2] | 0);
	                                Tq(c[g >> 2] | 0, c[D >> 2] | 0) | 0;
	                                if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                                    c[f >> 2] = 0;
	                                    _ = c[f >> 2] | 0;
	                                    i = d;
	                                    return _ | 0
	                                } else {
	                                    c[f >> 2] = c[k >> 2];
	                                    _ = c[f >> 2] | 0;
	                                    i = d;
	                                    return _ | 0
	                                }
	                            }
	                            Nq(c[g >> 2] | 0, 11);
	                            c[f >> 2] = 0;
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) == 1 : 0) {
	                            c[D >> 2] = Sq(c[g >> 2] | 0) | 0;
	                            c[G >> 2] = c[(c[D >> 2] | 0) + 4 >> 2];
	                            c[H >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2];
	                            c[I >> 2] = c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2];
	                            c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 0;
	                            if ((c[G >> 2] | 0) != 0 ? (c[c[G >> 2] >> 2] | 0) != 0 : 0) {
	                                c[E >> 2] = 0;
	                                c[F >> 2] = $q(0) | 0;
	                                c[J >> 2] = 0;
	                                while (1) {
	                                    if ((c[J >> 2] | 0) >= (c[c[G >> 2] >> 2] | 0))break;
	                                    c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[(c[(c[G >> 2] | 0) + 8 >> 2] | 0) + (c[J >> 2] << 2) >> 2];
	                                    if ((c[(c[(c[(c[G >> 2] | 0) + 8 >> 2] | 0) + (c[J >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0) != 18 ? (c[(c[(c[(c[G >> 2] | 0) + 8 >> 2] | 0) + (c[J >> 2] << 2) >> 2] | 0) + 32 >> 2] | 0) != 0 : 0)c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2] = c[(c[(c[(c[G >> 2] | 0) + 8 >> 2] | 0) + (c[J >> 2] << 2) >> 2] | 0) + 32 >> 2];
	                                    do if (!(c[E >> 2] | 0))c[E >> 2] = yt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) | 0; else {
	                                        if ((dr(c[(c[E >> 2] | 0) + 4 >> 2] | 0, c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) | 0) >= 0)break;
	                                        c[(c[g >> 2] | 0) + 8 >> 2] = 15
	                                    } while (0);
	                                    Tq(c[g >> 2] | 0, c[E >> 2] | 0) | 0;
	                                    c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] = c[c[G >> 2] >> 2];
	                                    c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2] = (c[J >> 2] | 0) + 1;
	                                    if ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) != -1) {
	                                        a = iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) | 0) | 0;
	                                        c[k >> 2] = (c[k >> 2] | 0) + a
	                                    }
	                                    if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                                        $ = 234;
	                                        break
	                                    }
	                                    c[C >> 2] = Sq(c[g >> 2] | 0) | 0;
	                                    do if (Ns(c[g >> 2] | 0, c[C >> 2] | 0) | 0) {
	                                        if ((cr(c[F >> 2] | 0, c[(c[(c[G >> 2] | 0) + 8 >> 2] | 0) + (c[J >> 2] << 2) >> 2] | 0) | 0) >= 0)break;
	                                        c[(c[g >> 2] | 0) + 8 >> 2] = 15
	                                    } while (0);
	                                    if (c[C >> 2] | 0)jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[C >> 2] | 0);
	                                    if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) == (c[E >> 2] | 0)) {
	                                        Sq(c[g >> 2] | 0) | 0;
	                                        su(c[(c[E >> 2] | 0) + 4 >> 2] | 0, 1)
	                                    } else c[E >> 2] = 0;
	                                    c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 0;
	                                    c[J >> 2] = (c[J >> 2] | 0) + 1
	                                }
	                                if (($ | 0) == 234) {
	                                    fr(c[F >> 2] | 0);
	                                    Qq(c[D >> 2] | 0);
	                                    c[f >> 2] = 0;
	                                    _ = c[f >> 2] | 0;
	                                    i = d;
	                                    return _ | 0
	                                }
	                                if (c[E >> 2] | 0)jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[E >> 2] | 0);
	                                jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[D >> 2] | 0);
	                                c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 0;
	                                c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] = -1;
	                                c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2] = -1;
	                                c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2] = c[I >> 2];
	                                a = c[g >> 2] | 0;
	                                Tq(a, At(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[F >> 2] | 0) | 0) | 0
	                            } else $ = 220;
	                            if (($ | 0) == 220 ? (c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] = 0, c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2] = 0, Tq(c[g >> 2] | 0, c[D >> 2] | 0) | 0, c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[H >> 2], (c[(c[g >> 2] | 0) + 8 >> 2] | 0) != 0) : 0) {
	                                c[f >> 2] = 0;
	                                _ = c[f >> 2] | 0;
	                                i = d;
	                                return _ | 0
	                            }
	                            c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[H >> 2];
	                            c[f >> 2] = c[k >> 2];
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        Nq(c[g >> 2] | 0, 11);
	                        c[f >> 2] = 0;
	                        _ = c[f >> 2] | 0;
	                        i = d;
	                        return _ | 0
	                    }
	                    case 3:
	                    {
	                        c[r >> 2] = c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2];
	                        c[q >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2];
	                        c[s >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2];
	                        c[t >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2];
	                        a = iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0) | 0;
	                        c[k >> 2] = (c[k >> 2] | 0) + a;
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2] = c[r >> 2];
	                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[q >> 2];
	                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2] = c[s >> 2];
	                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] = c[t >> 2];
	                        a = iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) | 0) | 0;
	                        c[k >> 2] = (c[k >> 2] | 0) + a;
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        a = c[g >> 2] | 0;
	                        if (c[(c[j >> 2] | 0) + 12 >> 2] | 0)c[l >> 2] = Qr(a) | 0; else c[l >> 2] = Rr(a) | 0;
	                        a = c[g >> 2] | 0;
	                        Tq(a, Ft(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[l >> 2] | 0) | 0) | 0;
	                        c[f >> 2] = c[k >> 2];
	                        _ = c[f >> 2] | 0;
	                        i = d;
	                        return _ | 0
	                    }
	                    case 6:
	                    {
	                        c[r >> 2] = c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2];
	                        c[q >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2];
	                        c[s >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2];
	                        c[t >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2];
	                        a = iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0) | 0;
	                        c[k >> 2] = (c[k >> 2] | 0) + a;
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2] = c[r >> 2];
	                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[q >> 2];
	                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2] = c[s >> 2];
	                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] = c[t >> 2];
	                        a = iu(c[g >> 2] | 0, (c[(c[n >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) | 0) | 0;
	                        c[k >> 2] = (c[k >> 2] | 0) + a;
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            _ = c[f >> 2] | 0;
	                            i = d;
	                            return _ | 0
	                        }
	                        do if (c[(c[j >> 2] | 0) + 12 >> 2] | 0) {
	                            if ((c[(c[j >> 2] | 0) + 12 >> 2] | 0) == 1) {
	                                Yr(c[g >> 2] | 0);
	                                break
	                            }
	                            if ((c[(c[j >> 2] | 0) + 12 >> 2] | 0) == 2)Zr(c[g >> 2] | 0)
	                        } else Xr(c[g >> 2] | 0); while (0);
	                        c[f >> 2] = c[k >> 2];
	                        _ = c[f >> 2] | 0;
	                        i = d;
	                        return _ | 0
	                    }
	                    default:
	                    {
	                        a = c[33976] | 0;
	                        b = c[33980] | 0;
	                        c[e >> 2] = c[c[j >> 2] >> 2];
	                        Db[a & 511](b, 130248, e);
	                        c[(c[g >> 2] | 0) + 8 >> 2] = 10;
	                        c[f >> 2] = c[k >> 2];
	                        _ = c[f >> 2] | 0;
	                        i = d;
	                        return _ | 0
	                    }
	                } while (0);
	                return 0
	            }

	            function ju(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0;
	                d = i;
	                i = i + 64 | 0;
	                e = d + 52 | 0;
	                f = d + 48 | 0;
	                g = d + 44 | 0;
	                h = d + 40 | 0;
	                j = d + 36 | 0;
	                k = d + 32 | 0;
	                l = d + 28 | 0;
	                m = d + 24 | 0;
	                n = d + 20 | 0;
	                o = d + 16 | 0;
	                p = d + 12 | 0;
	                q = d + 8 | 0;
	                r = d + 4 | 0;
	                s = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[k >> 2] = 0;
	                c[l >> 2] = 0;
	                c[m >> 2] = 0;
	                c[n >> 2] = 0;
	                c[o >> 2] = 0;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = -2;
	                    t = c[e >> 2] | 0;
	                    i = d;
	                    return t | 0
	                }
	                if ((c[f >> 2] | 0) == (c[g >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    t = c[e >> 2] | 0;
	                    i = d;
	                    return t | 0
	                }
	                a:do switch (c[(c[f >> 2] | 0) + 4 >> 2] | 0) {
	                    case 2:
	                    {
	                        c[l >> 2] = 1;
	                        c[n >> 2] = c[f >> 2];
	                        c[f >> 2] = c[(c[f >> 2] | 0) + 20 >> 2];
	                        c[k >> 2] = 1;
	                        u = 27;
	                        break
	                    }
	                    case 7:
	                    case 8:
	                    case 4:
	                    case 3:
	                    {
	                        c[n >> 2] = c[f >> 2];
	                        do if (c[(c[f >> 2] | 0) + 28 >> 2] | 0) {
	                            while (1) {
	                                c[f >> 2] = c[(c[f >> 2] | 0) + 28 >> 2];
	                                if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                                    u = 17;
	                                    break
	                                }
	                                if (!(c[(c[f >> 2] | 0) + 28 >> 2] | 0)) {
	                                    u = 19;
	                                    break
	                                }
	                            }
	                            if ((u | 0) == 17) {
	                                c[l >> 2] = 3;
	                                break
	                            } else if ((u | 0) == 19) {
	                                c[l >> 2] = 2;
	                                c[f >> 2] = c[(c[f >> 2] | 0) + 20 >> 2];
	                                break
	                            }
	                        } else {
	                            c[l >> 2] = 2;
	                            c[f >> 2] = c[(c[f >> 2] | 0) + 20 >> 2]
	                        } while (0);
	                        if (((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? 0 > (c[(c[f >> 2] | 0) + 40 >> 2] | 0) : 0) {
	                            c[k >> 2] = 1;
	                            u = 27;
	                            break a
	                        }
	                        c[f >> 2] = c[n >> 2];
	                        c[l >> 2] = 0;
	                        u = 27;
	                        break
	                    }
	                    case 18:
	                    {
	                        c[e >> 2] = 1;
	                        t = c[e >> 2] | 0;
	                        i = d;
	                        return t | 0
	                    }
	                    case 1:
	                    {
	                        if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                            if ((0 > (c[(c[f >> 2] | 0) + 40 >> 2] | 0) ? 0 > (c[(c[g >> 2] | 0) + 40 >> 2] | 0) : 0) ? (c[(c[f >> 2] | 0) + 32 >> 2] | 0) == (c[(c[g >> 2] | 0) + 32 >> 2] | 0) : 0) {
	                                c[r >> 2] = 0 - (c[(c[f >> 2] | 0) + 40 >> 2] | 0);
	                                c[s >> 2] = 0 - (c[(c[g >> 2] | 0) + 40 >> 2] | 0);
	                                if ((c[r >> 2] | 0) < (c[s >> 2] | 0)) {
	                                    c[e >> 2] = 1;
	                                    t = c[e >> 2] | 0;
	                                    i = d;
	                                    return t | 0
	                                }
	                                if ((c[r >> 2] | 0) > (c[s >> 2] | 0)) {
	                                    c[e >> 2] = -1;
	                                    t = c[e >> 2] | 0;
	                                    i = d;
	                                    return t | 0
	                                } else u = 27
	                            }
	                        } else u = 27;
	                        break
	                    }
	                    default:
	                        u = 27
	                } while (0);
	                if ((u | 0) == 27) {
	                    b:do switch (c[(c[g >> 2] | 0) + 4 >> 2] | 0) {
	                        case 7:
	                        case 8:
	                        case 4:
	                        case 3:
	                        {
	                            c[o >> 2] = c[g >> 2];
	                            do if (c[(c[g >> 2] | 0) + 28 >> 2] | 0) {
	                                while (1) {
	                                    c[g >> 2] = c[(c[g >> 2] | 0) + 28 >> 2];
	                                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                                        u = 31;
	                                        break
	                                    }
	                                    if (!(c[(c[g >> 2] | 0) + 28 >> 2] | 0)) {
	                                        u = 33;
	                                        break
	                                    }
	                                }
	                                if ((u | 0) == 31) {
	                                    c[m >> 2] = 3;
	                                    break
	                                } else if ((u | 0) == 33) {
	                                    c[m >> 2] = 2;
	                                    c[g >> 2] = c[(c[g >> 2] | 0) + 20 >> 2];
	                                    break
	                                }
	                            } else {
	                                c[m >> 2] = 2;
	                                c[g >> 2] = c[(c[g >> 2] | 0) + 20 >> 2]
	                            } while (0);
	                            if (((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? 0 > (c[(c[g >> 2] | 0) + 40 >> 2] | 0) : 0) {
	                                c[k >> 2] = 1;
	                                break b
	                            }
	                            c[g >> 2] = c[o >> 2];
	                            c[m >> 2] = 0;
	                            break
	                        }
	                        case 2:
	                        {
	                            c[m >> 2] = 1;
	                            c[o >> 2] = c[g >> 2];
	                            c[g >> 2] = c[(c[g >> 2] | 0) + 20 >> 2];
	                            c[k >> 2] = 1;
	                            break
	                        }
	                        case 18:
	                        {
	                            c[e >> 2] = 1;
	                            t = c[e >> 2] | 0;
	                            i = d;
	                            return t | 0
	                        }
	                        default:
	                        {
	                        }
	                    } while (0);
	                    c:do if (c[k >> 2] | 0) {
	                        if ((c[f >> 2] | 0) != (c[g >> 2] | 0)) {
	                            d:do if ((c[m >> 2] | 0) == 3 & (c[l >> 2] | 0) > 1) {
	                                c[p >> 2] = c[(c[f >> 2] | 0) + 20 >> 2];
	                                while (1) {
	                                    if (!(c[p >> 2] | 0))break d;
	                                    if ((c[p >> 2] | 0) == (c[g >> 2] | 0))break;
	                                    c[p >> 2] = c[(c[p >> 2] | 0) + 20 >> 2]
	                                }
	                                c[e >> 2] = 1;
	                                t = c[e >> 2] | 0;
	                                i = d;
	                                return t | 0
	                            } while (0);
	                            if (!((c[l >> 2] | 0) == 3 & (c[m >> 2] | 0) > 1))break;
	                            c[p >> 2] = c[(c[g >> 2] | 0) + 20 >> 2];
	                            while (1) {
	                                if (!(c[p >> 2] | 0))break c;
	                                if ((c[p >> 2] | 0) == (c[f >> 2] | 0))break;
	                                c[p >> 2] = c[(c[p >> 2] | 0) + 20 >> 2]
	                            }
	                            c[e >> 2] = -1;
	                            t = c[e >> 2] | 0;
	                            i = d;
	                            return t | 0
	                        }
	                        if ((c[l >> 2] | 0) != (c[m >> 2] | 0))if ((c[l >> 2] | 0) < (c[m >> 2] | 0)) {
	                            c[e >> 2] = 1;
	                            t = c[e >> 2] | 0;
	                            i = d;
	                            return t | 0
	                        } else {
	                            c[e >> 2] = -1;
	                            t = c[e >> 2] | 0;
	                            i = d;
	                            return t | 0
	                        }
	                        c[p >> 2] = c[(c[o >> 2] | 0) + 28 >> 2];
	                        while (1) {
	                            if (!(c[p >> 2] | 0)) {
	                                u = 51;
	                                break
	                            }
	                            if ((c[p >> 2] | 0) == (c[n >> 2] | 0)) {
	                                u = 47;
	                                break
	                            }
	                            if ((c[(c[p >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                                u = 49;
	                                break
	                            }
	                            c[p >> 2] = c[(c[p >> 2] | 0) + 28 >> 2]
	                        }
	                        if ((u | 0) == 47) {
	                            c[e >> 2] = 1;
	                            t = c[e >> 2] | 0;
	                            i = d;
	                            return t | 0
	                        } else if ((u | 0) == 49) {
	                            c[e >> 2] = -1;
	                            t = c[e >> 2] | 0;
	                            i = d;
	                            return t | 0
	                        } else if ((u | 0) == 51) {
	                            c[e >> 2] = -1;
	                            t = c[e >> 2] | 0;
	                            i = d;
	                            return t | 0
	                        }
	                    } while (0);
	                    if (((((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 1 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? 0 > (c[(c[f >> 2] | 0) + 40 >> 2] | 0) : 0) ? 0 > (c[(c[g >> 2] | 0) + 40 >> 2] | 0) : 0) ? (c[(c[f >> 2] | 0) + 32 >> 2] | 0) == (c[(c[g >> 2] | 0) + 32 >> 2] | 0) : 0) {
	                        c[r >> 2] = 0 - (c[(c[f >> 2] | 0) + 40 >> 2] | 0);
	                        c[s >> 2] = 0 - (c[(c[g >> 2] | 0) + 40 >> 2] | 0);
	                        if ((c[r >> 2] | 0) < (c[s >> 2] | 0)) {
	                            c[e >> 2] = 1;
	                            t = c[e >> 2] | 0;
	                            i = d;
	                            return t | 0
	                        }
	                        if ((c[r >> 2] | 0) > (c[s >> 2] | 0)) {
	                            c[e >> 2] = -1;
	                            t = c[e >> 2] | 0;
	                            i = d;
	                            return t | 0
	                        }
	                    }
	                }
	                if ((c[f >> 2] | 0) == (c[(c[g >> 2] | 0) + 28 >> 2] | 0)) {
	                    c[e >> 2] = 1;
	                    t = c[e >> 2] | 0;
	                    i = d;
	                    return t | 0
	                }
	                if ((c[f >> 2] | 0) == (c[(c[g >> 2] | 0) + 24 >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    t = c[e >> 2] | 0;
	                    i = d;
	                    return t | 0
	                }
	                c[j >> 2] = 0;
	                c[p >> 2] = c[g >> 2];
	                while (1) {
	                    v = c[p >> 2] | 0;
	                    if (!(c[(c[p >> 2] | 0) + 20 >> 2] | 0))break;
	                    if ((v | 0) == (c[f >> 2] | 0)) {
	                        u = 83;
	                        break
	                    }
	                    c[j >> 2] = (c[j >> 2] | 0) + 1;
	                    c[p >> 2] = c[(c[p >> 2] | 0) + 20 >> 2]
	                }
	                if ((u | 0) == 83) {
	                    c[e >> 2] = 1;
	                    t = c[e >> 2] | 0;
	                    i = d;
	                    return t | 0
	                }
	                c[q >> 2] = v;
	                c[h >> 2] = 0;
	                c[p >> 2] = c[f >> 2];
	                while (1) {
	                    if (!(c[(c[p >> 2] | 0) + 20 >> 2] | 0))break;
	                    if ((c[p >> 2] | 0) == (c[g >> 2] | 0)) {
	                        u = 88;
	                        break
	                    }
	                    c[h >> 2] = (c[h >> 2] | 0) + 1;
	                    c[p >> 2] = c[(c[p >> 2] | 0) + 20 >> 2]
	                }
	                if ((u | 0) == 88) {
	                    c[e >> 2] = -1;
	                    t = c[e >> 2] | 0;
	                    i = d;
	                    return t | 0
	                }
	                if ((c[q >> 2] | 0) != (c[p >> 2] | 0)) {
	                    c[e >> 2] = -2;
	                    t = c[e >> 2] | 0;
	                    i = d;
	                    return t | 0
	                }
	                while (1) {
	                    if ((c[h >> 2] | 0) <= (c[j >> 2] | 0))break;
	                    c[h >> 2] = (c[h >> 2] | 0) + -1;
	                    c[f >> 2] = c[(c[f >> 2] | 0) + 20 >> 2]
	                }
	                while (1) {
	                    if ((c[j >> 2] | 0) <= (c[h >> 2] | 0))break;
	                    c[j >> 2] = (c[j >> 2] | 0) + -1;
	                    c[g >> 2] = c[(c[g >> 2] | 0) + 20 >> 2]
	                }
	                while (1) {
	                    w = c[f >> 2] | 0;
	                    if ((c[(c[f >> 2] | 0) + 20 >> 2] | 0) == (c[(c[g >> 2] | 0) + 20 >> 2] | 0))break;
	                    c[f >> 2] = c[w + 20 >> 2];
	                    c[g >> 2] = c[(c[g >> 2] | 0) + 20 >> 2];
	                    if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                        u = 98;
	                        break
	                    }
	                }
	                if ((u | 0) == 98) {
	                    c[e >> 2] = -2;
	                    t = c[e >> 2] | 0;
	                    i = d;
	                    return t | 0
	                }
	                if ((w | 0) == (c[(c[g >> 2] | 0) + 28 >> 2] | 0)) {
	                    c[e >> 2] = 1;
	                    t = c[e >> 2] | 0;
	                    i = d;
	                    return t | 0
	                }
	                if ((c[f >> 2] | 0) == (c[(c[g >> 2] | 0) + 24 >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    t = c[e >> 2] | 0;
	                    i = d;
	                    return t | 0
	                }
	                if (((((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 1 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? 0 > (c[(c[f >> 2] | 0) + 40 >> 2] | 0) : 0) ? 0 > (c[(c[g >> 2] | 0) + 40 >> 2] | 0) : 0) ? (c[(c[f >> 2] | 0) + 32 >> 2] | 0) == (c[(c[g >> 2] | 0) + 32 >> 2] | 0) : 0) {
	                    c[r >> 2] = 0 - (c[(c[f >> 2] | 0) + 40 >> 2] | 0);
	                    c[s >> 2] = 0 - (c[(c[g >> 2] | 0) + 40 >> 2] | 0);
	                    if ((c[r >> 2] | 0) < (c[s >> 2] | 0)) {
	                        c[e >> 2] = 1;
	                        t = c[e >> 2] | 0;
	                        i = d;
	                        return t | 0
	                    }
	                    if ((c[r >> 2] | 0) > (c[s >> 2] | 0)) {
	                        c[e >> 2] = -1;
	                        t = c[e >> 2] | 0;
	                        i = d;
	                        return t | 0
	                    }
	                }
	                c[p >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                while (1) {
	                    if (!(c[p >> 2] | 0)) {
	                        u = 117;
	                        break
	                    }
	                    if ((c[p >> 2] | 0) == (c[g >> 2] | 0)) {
	                        u = 115;
	                        break
	                    }
	                    c[p >> 2] = c[(c[p >> 2] | 0) + 24 >> 2]
	                }
	                if ((u | 0) == 115) {
	                    c[e >> 2] = 1;
	                    t = c[e >> 2] | 0;
	                    i = d;
	                    return t | 0
	                } else if ((u | 0) == 117) {
	                    c[e >> 2] = -1;
	                    t = c[e >> 2] | 0;
	                    i = d;
	                    return t | 0
	                }
	                return 0
	            }

	            function ku(a, b) {
	                a = +a;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d;
	                g = d + 8 | 0;
	                h[f >> 3] = a;
	                c[g >> 2] = b;
	                b = St(+h[f >> 3]) | 0;
	                j = dU(b | 0, G | 0, 63) | 0;
	                c[c[g >> 2] >> 2] = j;
	                j = rT(+h[f >> 3]) | 0;
	                if ((j | 0) == 3)c[e >> 2] = 3; else if ((j | 0) == 2)c[e >> 2] = 4; else if (!j)c[e >> 2] = 1; else if ((j | 0) == 1)c[e >> 2] = 0; else c[e >> 2] = 2;
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function lu(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[c[d >> 2] >> 2] | 0)zb[c[135736 >> 2] & 511](c[c[d >> 2] >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function mu(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                tu(c[e >> 2] | 0);
	                if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                    i = b;
	                    return
	                }
	                a:while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    a = c[e >> 2] | 0;
	                    if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1
	                }
	                b:while (1) {
	                    if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 61) {
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 33) {
	                            h = 34;
	                            break
	                        }
	                        if ((d[(c[c[e >> 2] >> 2] | 0) + 1 >> 0] | 0 | 0) != 61) {
	                            h = 34;
	                            break
	                        }
	                    }
	                    c[g >> 2] = c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2];
	                    if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 61)c[f >> 2] = 1; else c[f >> 2] = 0;
	                    a = c[e >> 2] | 0;
	                    if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[a >> 2] = (c[a >> 2] | 0) + 1;
	                    if ((c[f >> 2] | 0) == 0 ? (a = c[e >> 2] | 0, (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 0) : 0)c[a >> 2] = (c[a >> 2] | 0) + 1;
	                    while (1) {
	                        do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)j = 1; else {
	                            if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                j = 1;
	                                break
	                            }
	                            j = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        k = c[e >> 2] | 0;
	                        if (!j)break;
	                        a = c[e >> 2] | 0;
	                        if (!(d[c[k >> 2] >> 0] | 0))continue;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1
	                    }
	                    tu(k);
	                    if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                        h = 34;
	                        break
	                    }
	                    du(c[(c[e >> 2] | 0) + 32 >> 2] | 0, c[g >> 2] | 0, c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2] | 0, 3, c[f >> 2] | 0, 0, 0, 0, 0) | 0;
	                    while (1) {
	                        do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)continue b
	                        } while (0);
	                        a = c[e >> 2] | 0;
	                        if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1
	                    }
	                }
	                if ((h | 0) == 34) {
	                    i = b;
	                    return
	                }
	            }

	            function nu(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0, J = 0, K = 0, L = 0, M = 0, N = 0, O = 0, P = 0, Q = 0, R = 0, S = 0, T = 0, U = 0, V = 0;
	                g = i;
	                i = i + 160 | 0;
	                h = g;
	                j = g + 148 | 0;
	                k = g + 144 | 0;
	                l = g + 140 | 0;
	                m = g + 136 | 0;
	                n = g + 132 | 0;
	                o = g + 128 | 0;
	                p = g + 124 | 0;
	                q = g + 120 | 0;
	                r = g + 116 | 0;
	                s = g + 112 | 0;
	                t = g + 108 | 0;
	                u = g + 104 | 0;
	                v = g + 100 | 0;
	                w = g + 96 | 0;
	                x = g + 92 | 0;
	                y = g + 88 | 0;
	                z = g + 84 | 0;
	                A = g + 80 | 0;
	                B = g + 76 | 0;
	                C = g + 72 | 0;
	                D = g + 68 | 0;
	                E = g + 64 | 0;
	                F = g + 60 | 0;
	                G = g + 56 | 0;
	                H = g + 52 | 0;
	                I = g + 48 | 0;
	                J = g + 44 | 0;
	                K = g + 40 | 0;
	                L = g + 36 | 0;
	                M = g + 32 | 0;
	                N = g + 28 | 0;
	                O = g + 24 | 0;
	                P = g + 20 | 0;
	                Q = g + 16 | 0;
	                R = g + 12 | 0;
	                S = g + 8 | 0;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = c[(c[l >> 2] | 0) + 12 >> 2];
	                c[q >> 2] = c[(c[l >> 2] | 0) + 16 >> 2];
	                c[r >> 2] = c[(c[l >> 2] | 0) + 20 >> 2];
	                c[s >> 2] = c[(c[l >> 2] | 0) + 24 >> 2];
	                c[t >> 2] = c[(c[l >> 2] | 0) + 28 >> 2];
	                c[u >> 2] = 0;
	                c[v >> 2] = 0;
	                c[w >> 2] = 0;
	                c[M >> 2] = 0;
	                c[Q >> 2] = c[(c[k >> 2] | 0) + 12 >> 2];
	                if ((c[(c[k >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[k >> 2] | 0) + 16 >> 2] >> 2] | 0) == 1 : 0) {
	                    c[x >> 2] = Sq(c[k >> 2] | 0) | 0;
	                    if ((c[s >> 2] | 0) != 0 ? (c[u >> 2] = sr(c[Q >> 2] | 0, c[s >> 2] | 0) | 0, (c[u >> 2] | 0) == 0) : 0) {
	                        jt(c[Q >> 2] | 0, c[x >> 2] | 0);
	                        Nq(c[k >> 2] | 0, 19);
	                        c[j >> 2] = 0;
	                        T = c[j >> 2] | 0;
	                        i = g;
	                        return T | 0
	                    }
	                    c[O >> 2] = 289;
	                    do switch (c[p >> 2] | 0) {
	                        case 9:
	                        {
	                            c[m >> 2] = 0;
	                            c[n >> 2] = 0;
	                            c[M >> 2] = 300;
	                            c[O >> 2] = 293;
	                            break
	                        }
	                        case 3:
	                        {
	                            c[m >> 2] = 0;
	                            c[n >> 2] = 0;
	                            c[M >> 2] = 292;
	                            c[O >> 2] = 293;
	                            break
	                        }
	                        case 7:
	                        {
	                            c[n >> 2] = 0;
	                            c[M >> 2] = 298;
	                            break
	                        }
	                        case 11:
	                        {
	                            c[m >> 2] = 0;
	                            c[M >> 2] = 302;
	                            break
	                        }
	                        case 8:
	                        {
	                            c[n >> 2] = 0;
	                            c[M >> 2] = 299;
	                            break
	                        }
	                        case 1:
	                        {
	                            c[m >> 2] = 0;
	                            c[M >> 2] = 290;
	                            break
	                        }
	                        case 12:
	                        {
	                            c[m >> 2] = 0;
	                            c[M >> 2] = 303;
	                            break
	                        }
	                        case 6:
	                        {
	                            c[n >> 2] = 0;
	                            c[M >> 2] = 297;
	                            break
	                        }
	                        case 4:
	                        {
	                            c[n >> 2] = 0;
	                            if (((c[q >> 2] | 0) == 5 | (c[q >> 2] | 0) == 3) & (c[r >> 2] | 0) == 0)c[M >> 2] = 294; else c[M >> 2] = 295;
	                            c[O >> 2] = 293;
	                            break
	                        }
	                        case 13:
	                        {
	                            c[m >> 2] = 0;
	                            c[n >> 2] = 0;
	                            c[M >> 2] = 304;
	                            c[O >> 2] = 293;
	                            break
	                        }
	                        case 2:
	                        {
	                            c[m >> 2] = 0;
	                            c[M >> 2] = 291;
	                            break
	                        }
	                        case 5:
	                        {
	                            c[n >> 2] = 0;
	                            c[M >> 2] = 296;
	                            break
	                        }
	                        case 10:
	                        {
	                            c[m >> 2] = 0;
	                            c[M >> 2] = 301;
	                            break
	                        }
	                        default:
	                        {
	                        }
	                    } while (0);
	                    if (!(c[M >> 2] | 0)) {
	                        jt(c[Q >> 2] | 0, c[x >> 2] | 0);
	                        c[j >> 2] = 0;
	                        T = c[j >> 2] | 0;
	                        i = g;
	                        return T | 0
	                    }
	                    c[y >> 2] = c[(c[x >> 2] | 0) + 4 >> 2];
	                    if ((c[y >> 2] | 0) != 0 ? (c[c[y >> 2] >> 2] | 0) > 0 : 0) {
	                        c[F >> 2] = 0;
	                        c[E >> 2] = 0;
	                        c[G >> 2] = 0;
	                        c[H >> 2] = 0;
	                        do if ((c[(c[l >> 2] | 0) + 8 >> 2] | 0) != -1 ? (c[E >> 2] = (c[(c[(c[k >> 2] | 0) + 32 >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[l >> 2] | 0) + 8 >> 2] | 0) * 40 | 0), (yu(c[k >> 2] | 0, c[E >> 2] | 0, F) | 0) != 0) : 0)if ((c[(c[E >> 2] | 0) + 4 >> 2] | 0) != -1) {
	                            c[E >> 2] = (c[(c[(c[k >> 2] | 0) + 32 >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[E >> 2] | 0) + 4 >> 2] | 0) * 40 | 0);
	                            c[G >> 2] = 1;
	                            break
	                        } else {
	                            c[E >> 2] = 0;
	                            c[H >> 2] = 1;
	                            break
	                        } while (0);
	                        if (c[o >> 2] | 0)U = (c[E >> 2] | 0) == 0; else U = 0;
	                        c[L >> 2] = U ? 1 : 0;
	                        c[P >> 2] = c[(c[Q >> 2] | 0) + 4 >> 2];
	                        c[N >> 2] = 305;
	                        c[B >> 2] = 0;
	                        c[C >> 2] = 0;
	                        c[A >> 2] = 0;
	                        c[z >> 2] = 0;
	                        a:while (1) {
	                            if (!((c[A >> 2] | 0) != 0 ? 1 : (c[z >> 2] | 0) < (c[c[y >> 2] >> 2] | 0)))break;
	                            if (c[(c[k >> 2] | 0) + 8 >> 2] | 0)break;
	                            U = c[z >> 2] | 0;
	                            c[z >> 2] = U + 1;
	                            c[(c[Q >> 2] | 0) + 4 >> 2] = c[(c[(c[y >> 2] | 0) + 8 >> 2] | 0) + (U << 2) >> 2];
	                            if ((c[C >> 2] | 0) == 0 ? (c[C >> 2] = $q(0) | 0, (c[C >> 2] | 0) == 0) : 0) {
	                                V = 41;
	                                break
	                            }
	                            c[I >> 2] = 0;
	                            c[D >> 2] = 0;
	                            c[w >> 2] = 0;
	                            b:while (1) {
	                                c[D >> 2] = Hb[c[M >> 2] & 511](c[k >> 2] | 0, c[D >> 2] | 0) | 0;
	                                if (!(c[D >> 2] | 0)) {
	                                    V = 211;
	                                    break
	                                }
	                                do if ((c[m >> 2] | 0) != 0 ? (c[c[m >> 2] >> 2] | 0) != 0 : 0) {
	                                    if ((c[c[m >> 2] >> 2] | 0) == (c[D >> 2] | 0)) {
	                                        V = 211;
	                                        break b
	                                    }
	                                    if ((c[v >> 2] | 0) % 256 | 0)break;
	                                    if ((ju(c[c[m >> 2] >> 2] | 0, c[D >> 2] | 0) | 0) >= 0) {
	                                        V = 211;
	                                        break b
	                                    }
	                                } while (0);
	                                do if ((c[n >> 2] | 0) != 0 ? (c[c[n >> 2] >> 2] | 0) != 0 : 0) {
	                                    if ((c[c[n >> 2] >> 2] | 0) == (c[D >> 2] | 0)) {
	                                        V = 211;
	                                        break b
	                                    }
	                                    if ((c[v >> 2] | 0) % 256 | 0)break;
	                                    if ((ju(c[D >> 2] | 0, c[c[n >> 2] >> 2] | 0) | 0) >= 0) {
	                                        V = 211;
	                                        break b
	                                    }
	                                } while (0);
	                                c[v >> 2] = (c[v >> 2] | 0) + 1;
	                                c:do switch (c[q >> 2] | 0) {
	                                    case 5:
	                                    {
	                                        do if ((c[p >> 2] | 0) == 3) {
	                                            if ((c[(c[D >> 2] | 0) + 4 >> 2] | 0) != 2)break c
	                                        } else {
	                                            U = c[(c[D >> 2] | 0) + 4 >> 2] | 0;
	                                            if ((c[p >> 2] | 0) == 9)if ((U | 0) != 18)break c; else break; else if ((U | 0) != 1)break c; else break
	                                        } while (0);
	                                        U = c[(c[D >> 2] | 0) + 4 >> 2] | 0;
	                                        if ((U | 0) == 18) {
	                                            if ((c[(c[D >> 2] | 0) + 4 >> 2] | 0) != 18)break c;
	                                            c[S >> 2] = c[D >> 2];
	                                            if (!((c[t >> 2] | 0) != 0 ? (c[(c[S >> 2] | 0) + 12 >> 2] | 0) != 0 : 0))break c;
	                                            if (!(qy(c[(c[S >> 2] | 0) + 12 >> 2] | 0, c[t >> 2] | 0) | 0))break c;
	                                            if (c[H >> 2] | 0) {
	                                                l = (c[I >> 2] | 0) + 1 | 0;
	                                                c[I >> 2] = l;
	                                                if ((l | 0) == (c[F >> 2] | 0)) {
	                                                    V = 197;
	                                                    break b
	                                                } else break c
	                                            }
	                                            c[w >> 2] = 1;
	                                            if ((br(c[C >> 2] | 0, c[(c[Q >> 2] | 0) + 4 >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                            if (c[L >> 2] | 0) {
	                                                V = 208;
	                                                break a
	                                            } else break c
	                                        } else if ((U | 0) == 2) {
	                                            c[R >> 2] = c[D >> 2];
	                                            if (!(qy(c[t >> 2] | 0, c[(c[R >> 2] | 0) + 8 >> 2] | 0) | 0))break c;
	                                            l = c[(c[R >> 2] | 0) + 36 >> 2] | 0;
	                                            if (!(c[s >> 2] | 0)) {
	                                                if ((l | 0) != 0 ? (c[(c[(c[R >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0)break c;
	                                                if (c[H >> 2] | 0) {
	                                                    f = (c[I >> 2] | 0) + 1 | 0;
	                                                    c[I >> 2] = f;
	                                                    if ((f | 0) == (c[F >> 2] | 0)) {
	                                                        V = 178;
	                                                        break b
	                                                    } else break c
	                                                }
	                                                if ((Hb[c[N >> 2] & 511](c[C >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                                if (c[L >> 2] | 0) {
	                                                    V = 208;
	                                                    break a
	                                                } else break c
	                                            } else {
	                                                if (!l)break c;
	                                                if (!(qy(c[u >> 2] | 0, c[(c[(c[R >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) | 0))break c;
	                                                if (c[H >> 2] | 0) {
	                                                    l = (c[I >> 2] | 0) + 1 | 0;
	                                                    c[I >> 2] = l;
	                                                    if ((l | 0) == (c[F >> 2] | 0)) {
	                                                        V = 187;
	                                                        break b
	                                                    } else break c
	                                                }
	                                                if ((Hb[c[N >> 2] & 511](c[C >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                                if (c[L >> 2] | 0) {
	                                                    V = 208;
	                                                    break a
	                                                } else break c
	                                            }
	                                        } else if ((U | 0) == 1) {
	                                            if (!(qy(c[t >> 2] | 0, c[(c[D >> 2] | 0) + 8 >> 2] | 0) | 0))break c;
	                                            U = c[(c[D >> 2] | 0) + 36 >> 2] | 0;
	                                            if (!(c[s >> 2] | 0)) {
	                                                if (U)break c;
	                                                if (c[H >> 2] | 0) {
	                                                    l = (c[I >> 2] | 0) + 1 | 0;
	                                                    c[I >> 2] = l;
	                                                    if ((l | 0) == (c[F >> 2] | 0)) {
	                                                        V = 158;
	                                                        break b
	                                                    } else break c
	                                                }
	                                                if ((Hb[c[N >> 2] & 511](c[C >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                                if (c[L >> 2] | 0) {
	                                                    V = 208;
	                                                    break a
	                                                } else break c
	                                            }
	                                            if (!U)break c;
	                                            if (!(qy(c[u >> 2] | 0, c[(c[(c[D >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) | 0))break c;
	                                            if (c[H >> 2] | 0) {
	                                                U = (c[I >> 2] | 0) + 1 | 0;
	                                                c[I >> 2] = U;
	                                                if ((U | 0) == (c[F >> 2] | 0)) {
	                                                    V = 167;
	                                                    break b
	                                                } else break c
	                                            }
	                                            if ((Hb[c[N >> 2] & 511](c[C >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                            if (c[L >> 2] | 0) {
	                                                V = 208;
	                                                break a
	                                            } else break c
	                                        } else break c;
	                                        break
	                                    }
	                                    case 2:
	                                    {
	                                        if ((c[(c[D >> 2] | 0) + 4 >> 2] | 0) == 7) {
	                                            if ((c[t >> 2] | 0) != 0 ? (qy(c[t >> 2] | 0, c[(c[D >> 2] | 0) + 8 >> 2] | 0) | 0) == 0 : 0)break c;
	                                            if (c[H >> 2] | 0) {
	                                                U = (c[I >> 2] | 0) + 1 | 0;
	                                                c[I >> 2] = U;
	                                                if ((U | 0) == (c[F >> 2] | 0)) {
	                                                    V = 95;
	                                                    break b
	                                                } else break c
	                                            }
	                                            if ((Hb[c[N >> 2] & 511](c[C >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                            if (c[L >> 2] | 0) {
	                                                V = 208;
	                                                break a
	                                            }
	                                        }
	                                        break
	                                    }
	                                    case 1:
	                                    {
	                                        U = c[(c[D >> 2] | 0) + 4 >> 2] | 0;
	                                        if (!(c[r >> 2] | 0)) {
	                                            switch (U | 0) {
	                                                case 18:
	                                                case 3:
	                                                case 4:
	                                                case 8:
	                                                case 7:
	                                                case 2:
	                                                case 1:
	                                                case 21:
	                                                case 13:
	                                                case 9:
	                                                    break;
	                                                default:
	                                                    break c
	                                            }
	                                            if (c[H >> 2] | 0) {
	                                                l = (c[I >> 2] | 0) + 1 | 0;
	                                                c[I >> 2] = l;
	                                                if ((l | 0) == (c[F >> 2] | 0)) {
	                                                    V = 60;
	                                                    break b
	                                                } else break c
	                                            }
	                                            if ((Hb[c[N >> 2] & 511](c[C >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                            if (c[L >> 2] | 0) {
	                                                V = 208;
	                                                break a
	                                            } else break c
	                                        }
	                                        if ((U | 0) != (c[r >> 2] | 0)) {
	                                            if ((c[r >> 2] | 0) != 3)break c;
	                                            if ((c[(c[D >> 2] | 0) + 4 >> 2] | 0) != 4)break c;
	                                            if (c[H >> 2] | 0) {
	                                                U = (c[I >> 2] | 0) + 1 | 0;
	                                                c[I >> 2] = U;
	                                                if ((U | 0) == (c[F >> 2] | 0)) {
	                                                    V = 85;
	                                                    break b
	                                                } else break c
	                                            }
	                                            if ((Hb[c[N >> 2] & 511](c[C >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                            if (c[L >> 2] | 0) {
	                                                V = 208;
	                                                break a
	                                            } else break c
	                                        }
	                                        U = (c[H >> 2] | 0) != 0;
	                                        if ((c[(c[D >> 2] | 0) + 4 >> 2] | 0) == 18) {
	                                            if (U) {
	                                                l = (c[I >> 2] | 0) + 1 | 0;
	                                                c[I >> 2] = l;
	                                                if ((l | 0) == (c[F >> 2] | 0)) {
	                                                    V = 69;
	                                                    break b
	                                                } else break c
	                                            }
	                                            c[w >> 2] = 1;
	                                            if ((br(c[C >> 2] | 0, c[(c[Q >> 2] | 0) + 4 >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                            if (c[L >> 2] | 0) {
	                                                V = 208;
	                                                break a
	                                            } else break c
	                                        } else {
	                                            if (U) {
	                                                U = (c[I >> 2] | 0) + 1 | 0;
	                                                c[I >> 2] = U;
	                                                if ((U | 0) == (c[F >> 2] | 0)) {
	                                                    V = 76;
	                                                    break b
	                                                } else break c
	                                            }
	                                            if ((Hb[c[N >> 2] & 511](c[C >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                            if (c[L >> 2] | 0) {
	                                                V = 208;
	                                                break a
	                                            } else break c
	                                        }
	                                        break
	                                    }
	                                    case 0:
	                                    {
	                                        V = 55;
	                                        break a;
	                                        break
	                                    }
	                                    case 4:
	                                    {
	                                        U = c[33976] | 0;
	                                        l = c[33980] | 0;
	                                        c[h >> 2] = 128552;
	                                        c[h + 4 >> 2] = 12457;
	                                        Db[U & 511](l, 129064, h);
	                                        break
	                                    }
	                                    case 3:
	                                    {
	                                        if ((c[p >> 2] | 0) == 3) {
	                                            if ((c[(c[D >> 2] | 0) + 4 >> 2] | 0) != 2)break c;
	                                            if (!(c[s >> 2] | 0)) {
	                                                if (c[H >> 2] | 0) {
	                                                    l = (c[I >> 2] | 0) + 1 | 0;
	                                                    c[I >> 2] = l;
	                                                    if ((l | 0) == (c[F >> 2] | 0)) {
	                                                        V = 105;
	                                                        break b
	                                                    } else break c
	                                                }
	                                                if ((Hb[c[N >> 2] & 511](c[C >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                                if (c[L >> 2] | 0) {
	                                                    V = 208;
	                                                    break a
	                                                } else break c
	                                            }
	                                            if (!(c[(c[D >> 2] | 0) + 36 >> 2] | 0))break c;
	                                            if (!(qy(c[u >> 2] | 0, c[(c[(c[D >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) | 0))break c;
	                                            if (c[H >> 2] | 0) {
	                                                l = (c[I >> 2] | 0) + 1 | 0;
	                                                c[I >> 2] = l;
	                                                if ((l | 0) == (c[F >> 2] | 0)) {
	                                                    V = 114;
	                                                    break b
	                                                } else break c
	                                            }
	                                            if ((Hb[c[N >> 2] & 511](c[C >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                            if (c[L >> 2] | 0) {
	                                                V = 208;
	                                                break a
	                                            } else break c
	                                        }
	                                        l = c[(c[D >> 2] | 0) + 4 >> 2] | 0;
	                                        if ((c[p >> 2] | 0) == 9) {
	                                            if ((l | 0) != 18)break c;
	                                            if (c[H >> 2] | 0) {
	                                                U = (c[I >> 2] | 0) + 1 | 0;
	                                                c[I >> 2] = U;
	                                                if ((U | 0) == (c[F >> 2] | 0)) {
	                                                    V = 123;
	                                                    break b
	                                                } else break c
	                                            }
	                                            c[w >> 2] = 1;
	                                            if ((br(c[C >> 2] | 0, c[(c[Q >> 2] | 0) + 4 >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                            if (c[L >> 2] | 0) {
	                                                V = 208;
	                                                break a
	                                            } else break c
	                                        }
	                                        if ((l | 0) != 1)break c;
	                                        if (!(c[s >> 2] | 0)) {
	                                            if (c[H >> 2] | 0) {
	                                                l = (c[I >> 2] | 0) + 1 | 0;
	                                                c[I >> 2] = l;
	                                                if ((l | 0) == (c[F >> 2] | 0)) {
	                                                    V = 132;
	                                                    break b
	                                                } else break c
	                                            }
	                                            if ((Hb[c[N >> 2] & 511](c[C >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                            if (c[L >> 2] | 0) {
	                                                V = 208;
	                                                break a
	                                            } else break c
	                                        }
	                                        if (!(c[(c[D >> 2] | 0) + 36 >> 2] | 0))break c;
	                                        if (!(qy(c[u >> 2] | 0, c[(c[(c[D >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) | 0))break c;
	                                        if (c[H >> 2] | 0) {
	                                            l = (c[I >> 2] | 0) + 1 | 0;
	                                            c[I >> 2] = l;
	                                            if ((l | 0) == (c[F >> 2] | 0)) {
	                                                V = 141;
	                                                break b
	                                            } else break c
	                                        }
	                                        if ((Hb[c[N >> 2] & 511](c[C >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                        if (c[L >> 2] | 0) {
	                                            V = 208;
	                                            break a
	                                        }
	                                        break
	                                    }
	                                    default:
	                                    {
	                                    }
	                                } while (0);
	                                if (!(c[D >> 2] | 0)) {
	                                    V = 211;
	                                    break
	                                }
	                                if (c[(c[k >> 2] | 0) + 8 >> 2] | 0) {
	                                    V = 211;
	                                    break
	                                }
	                            }
	                            switch (V | 0) {
	                                case 60:
	                                {
	                                    V = 0;
	                                    if ((Hb[c[N >> 2] & 511](c[C >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                    break
	                                }
	                                case 69:
	                                {
	                                    V = 0;
	                                    c[w >> 2] = 1;
	                                    if ((br(c[C >> 2] | 0, c[(c[Q >> 2] | 0) + 4 >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                    break
	                                }
	                                case 76:
	                                {
	                                    V = 0;
	                                    if ((Hb[c[N >> 2] & 511](c[C >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                    break
	                                }
	                                case 85:
	                                {
	                                    V = 0;
	                                    if ((Hb[c[N >> 2] & 511](c[C >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                    break
	                                }
	                                case 95:
	                                {
	                                    V = 0;
	                                    if ((Hb[c[N >> 2] & 511](c[C >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                    break
	                                }
	                                case 105:
	                                {
	                                    V = 0;
	                                    if ((Hb[c[N >> 2] & 511](c[C >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                    break
	                                }
	                                case 114:
	                                {
	                                    V = 0;
	                                    if ((Hb[c[N >> 2] & 511](c[C >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                    break
	                                }
	                                case 123:
	                                {
	                                    V = 0;
	                                    c[w >> 2] = 1;
	                                    if ((br(c[C >> 2] | 0, c[(c[Q >> 2] | 0) + 4 >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                    break
	                                }
	                                case 132:
	                                {
	                                    V = 0;
	                                    if ((Hb[c[N >> 2] & 511](c[C >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                    break
	                                }
	                                case 141:
	                                {
	                                    V = 0;
	                                    if ((Hb[c[N >> 2] & 511](c[C >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                    break
	                                }
	                                case 158:
	                                {
	                                    V = 0;
	                                    if ((Hb[c[N >> 2] & 511](c[C >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                    break
	                                }
	                                case 167:
	                                {
	                                    V = 0;
	                                    if ((Hb[c[N >> 2] & 511](c[C >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                    break
	                                }
	                                case 178:
	                                {
	                                    V = 0;
	                                    if ((Hb[c[N >> 2] & 511](c[C >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                    break
	                                }
	                                case 187:
	                                {
	                                    V = 0;
	                                    if ((Hb[c[N >> 2] & 511](c[C >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                    break
	                                }
	                                case 197:
	                                {
	                                    V = 0;
	                                    c[w >> 2] = 1;
	                                    if ((br(c[C >> 2] | 0, c[(c[Q >> 2] | 0) + 4 >> 2] | 0, c[D >> 2] | 0) | 0) < 0)c[(c[k >> 2] | 0) + 8 >> 2] = 15;
	                                    break
	                                }
	                                case 211:
	                                {
	                                    V = 0;
	                                    if (c[(c[k >> 2] | 0) + 8 >> 2] | 0)break a;
	                                    if ((c[E >> 2] | 0) != 0 ? (c[c[C >> 2] >> 2] | 0) > 0 : 0) {
	                                        c[J >> 2] = c[c[C >> 2] >> 2];
	                                        l = c[k >> 2] | 0;
	                                        U = c[E >> 2] | 0;
	                                        f = c[C >> 2] | 0;
	                                        e = c[J >> 2] | 0;
	                                        if (c[G >> 2] | 0)c[K >> 2] = zu(l, U, f, e, c[F >> 2] | 0, c[F >> 2] | 0, c[w >> 2] | 0) | 0; else c[K >> 2] = Au(l, U, f, e, c[w >> 2] | 0) | 0;
	                                        if (c[(c[k >> 2] | 0) + 8 >> 2] | 0) {
	                                            V = 218;
	                                            break a
	                                        }
	                                        e = c[C >> 2] | 0;
	                                        if (!(c[K >> 2] | 0)) {
	                                            su(e, c[w >> 2] | 0);
	                                            continue a
	                                        }
	                                        if ((c[e >> 2] | 0) <= 0)continue a;
	                                        do if (!(c[B >> 2] | 0))if ((c[J >> 2] | 0) != (c[K >> 2] | 0)) {
	                                            c[B >> 2] = vb[c[O >> 2] & 511](0, c[C >> 2] | 0, 1) | 0;
	                                            break
	                                        } else {
	                                            c[B >> 2] = c[C >> 2];
	                                            c[C >> 2] = 0;
	                                            break
	                                        } else c[B >> 2] = vb[c[O >> 2] & 511](c[B >> 2] | 0, c[C >> 2] | 0, (c[J >> 2] | 0) != (c[K >> 2] | 0) ? 1 : 0) | 0; while (0);
	                                        if (c[o >> 2] | 0)break a; else continue a
	                                    }
	                                    if ((c[c[C >> 2] >> 2] | 0) <= 0)continue a;
	                                    if (!(c[B >> 2] | 0)) {
	                                        c[B >> 2] = c[C >> 2];
	                                        c[C >> 2] = 0;
	                                        continue a
	                                    } else {
	                                        c[B >> 2] = vb[c[O >> 2] & 511](c[B >> 2] | 0, c[C >> 2] | 0, 0) | 0;
	                                        continue a
	                                    }
	                                    break
	                                }
	                            }
	                            if (!(c[B >> 2] | 0)) {
	                                c[B >> 2] = c[C >> 2];
	                                c[C >> 2] = 0
	                            } else c[B >> 2] = vb[c[O >> 2] & 511](c[B >> 2] | 0, c[C >> 2] | 0, 0) | 0;
	                            if (c[o >> 2] | 0)break
	                        }
	                        do if ((V | 0) == 41)c[v >> 2] = 0; else if ((V | 0) == 55) {
	                            c[v >> 2] = 0;
	                            o = c[33976] | 0;
	                            K = c[33980] | 0;
	                            c[h >> 2] = 128552;
	                            c[h + 4 >> 2] = 12379;
	                            Db[o & 511](K, 129448, h)
	                        } else if ((V | 0) == 208)if (!(c[B >> 2] | 0)) {
	                            c[B >> 2] = c[C >> 2];
	                            c[C >> 2] = 0;
	                            break
	                        } else {
	                            c[B >> 2] = vb[c[O >> 2] & 511](c[B >> 2] | 0, c[C >> 2] | 0, 0) | 0;
	                            break
	                        } else if ((V | 0) == 218)c[v >> 2] = 0; while (0);
	                        if ((c[(c[x >> 2] | 0) + 8 >> 2] | 0) != 0 ? (c[(c[x >> 2] | 0) + 28 >> 2] | 0) != 0 : 0) {
	                            c[(c[(c[k >> 2] | 0) + 16 >> 2] | 0) + 8 >> 2] = 1;
	                            c[(c[(c[k >> 2] | 0) + 16 >> 2] | 0) + 28 >> 2] = c[(c[x >> 2] | 0) + 28 >> 2];
	                            c[(c[x >> 2] | 0) + 28 >> 2] = 0;
	                            c[(c[x >> 2] | 0) + 8 >> 2] = 0
	                        }
	                        jt(c[Q >> 2] | 0, c[x >> 2] | 0);
	                        do if (!(c[B >> 2] | 0)) {
	                            if ((c[C >> 2] | 0) != 0 ? (c[c[C >> 2] >> 2] | 0) == 0 : 0) {
	                                c[B >> 2] = c[C >> 2];
	                                break
	                            }
	                            c[B >> 2] = $q(0) | 0
	                        } while (0);
	                        if ((c[C >> 2] | 0) != 0 ? (c[C >> 2] | 0) != (c[B >> 2] | 0) : 0)fr(c[C >> 2] | 0);
	                        C = c[k >> 2] | 0;
	                        Tq(C, At(c[Q >> 2] | 0, c[B >> 2] | 0) | 0) | 0;
	                        c[(c[Q >> 2] | 0) + 4 >> 2] = c[P >> 2];
	                        c[j >> 2] = c[v >> 2];
	                        T = c[j >> 2] | 0;
	                        i = g;
	                        return T | 0
	                    }
	                    jt(c[Q >> 2] | 0, c[x >> 2] | 0);
	                    x = c[k >> 2] | 0;
	                    Tq(x, At(c[Q >> 2] | 0, 0) | 0) | 0;
	                    c[j >> 2] = 0;
	                    T = c[j >> 2] | 0;
	                    i = g;
	                    return T | 0
	                }
	                Nq(c[k >> 2] | 0, 11);
	                c[j >> 2] = 0;
	                T = c[j >> 2] | 0;
	                i = g;
	                return T | 0
	            }

	            function ou(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    c[f >> 2] = c[(c[e >> 2] | 0) + 44 >> 2];
	                    c[(c[e >> 2] | 0) + 44 >> 2] = c[(c[e >> 2] | 0) + 20 >> 2];
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function pu(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if ((c[(c[e >> 2] | 0) + 20 >> 2] | 0) < (c[(c[e >> 2] | 0) + 44 >> 2] | 0))Oq(c[e >> 2] | 0, 128552, 2808, 23);
	                c[(c[e >> 2] | 0) + 44 >> 2] = c[f >> 2];
	                i = d;
	                return
	            }

	            function qu(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 32 | 0;
	                g = e + 28 | 0;
	                h = e + 24 | 0;
	                j = e + 20 | 0;
	                k = e + 16 | 0;
	                l = e + 12 | 0;
	                m = e + 8 | 0;
	                n = e + 4 | 0;
	                o = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 0;
	                if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                    c[f >> 2] = 0;
	                    p = c[f >> 2] | 0;
	                    i = e;
	                    return p | 0
	                }
	                c[m >> 2] = c[(c[g >> 2] | 0) + 32 >> 2];
	                do switch (c[c[h >> 2] >> 2] | 0) {
	                    case 0:
	                    {
	                        c[f >> 2] = 0;
	                        p = c[f >> 2] | 0;
	                        i = e;
	                        return p | 0
	                    }
	                    case 12:
	                    {
	                        Tq(c[g >> 2] | 0, lt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[(c[h >> 2] | 0) + 24 >> 2] | 0) | 0) | 0;
	                        c[f >> 2] = 0;
	                        p = c[f >> 2] | 0;
	                        i = e;
	                        return p | 0
	                    }
	                    case 7:
	                    {
	                        c[k >> 2] = qu(c[g >> 2] | 0, (c[(c[m >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0, c[j >> 2] | 0) | 0;
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            p = c[f >> 2] | 0;
	                            i = e;
	                            return p | 0
	                        }
	                        if ((((c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) == 1 : 0) ? (c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) ? (c[c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] >> 2] | 0) >= 1 : 0) {
	                            if ((c[c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] >> 2] | 0) > 1)Zq(c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0);
	                            c[c[j >> 2] >> 2] = c[c[(c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] >> 2]
	                        }
	                        c[l >> 2] = qu(c[g >> 2] | 0, (c[(c[m >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[h >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) | 0, c[j >> 2] | 0) | 0;
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            p = c[f >> 2] | 0;
	                            i = e;
	                            return p | 0
	                        }
	                        if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) == 1 : 0) {
	                            c[o >> 2] = Sq(c[g >> 2] | 0) | 0;
	                            if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) == 1 : 0) {
	                                c[n >> 2] = Sq(c[g >> 2] | 0) | 0;
	                                d = er(c[(c[n >> 2] | 0) + 4 >> 2] | 0, c[(c[o >> 2] | 0) + 4 >> 2] | 0) | 0;
	                                c[(c[n >> 2] | 0) + 4 >> 2] = d;
	                                Tq(c[g >> 2] | 0, c[n >> 2] | 0) | 0;
	                                jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[o >> 2] | 0);
	                                if ((c[k >> 2] | 0) > (c[l >> 2] | 0))Bu(c[h >> 2] | 0);
	                                c[f >> 2] = (c[k >> 2] | 0) + (c[l >> 2] | 0);
	                                p = c[f >> 2] | 0;
	                                i = e;
	                                return p | 0
	                            }
	                            Nq(c[g >> 2] | 0, 11);
	                            c[f >> 2] = 0;
	                            p = c[f >> 2] | 0;
	                            i = e;
	                            return p | 0
	                        }
	                        Nq(c[g >> 2] | 0, 11);
	                        c[f >> 2] = 0;
	                        p = c[f >> 2] | 0;
	                        i = e;
	                        return p | 0
	                    }
	                    case 10:
	                    {
	                        if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) != -1) {
	                            d = iu(c[g >> 2] | 0, (c[(c[m >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0) | 0;
	                            c[k >> 2] = (c[k >> 2] | 0) + d
	                        }
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            p = c[f >> 2] | 0;
	                            i = e;
	                            return p | 0
	                        }
	                        if ((c[(c[h >> 2] | 0) + 8 >> 2] | 0) != -1) {
	                            d = iu(c[g >> 2] | 0, (c[(c[m >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[h >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) | 0) | 0;
	                            c[k >> 2] = (c[k >> 2] | 0) + d
	                        }
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            p = c[f >> 2] | 0;
	                            i = e;
	                            return p | 0
	                        } else {
	                            c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 0;
	                            c[f >> 2] = c[k >> 2];
	                            p = c[f >> 2] | 0;
	                            i = e;
	                            return p | 0
	                        }
	                        break
	                    }
	                    case 18:
	                    {
	                        if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) != -1) {
	                            d = qu(c[g >> 2] | 0, (c[(c[m >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0, c[j >> 2] | 0) | 0;
	                            c[k >> 2] = (c[k >> 2] | 0) + d
	                        }
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            p = c[f >> 2] | 0;
	                            i = e;
	                            return p | 0
	                        }
	                        if ((((c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) == 1 : 0) ? (c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) ? (c[c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] >> 2] | 0) > 1 : 0)Zq(c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0);
	                        c[f >> 2] = c[k >> 2];
	                        p = c[f >> 2] | 0;
	                        i = e;
	                        return p | 0
	                    }
	                    case 9:
	                    {
	                        if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) != -1) {
	                            d = iu(c[g >> 2] | 0, (c[(c[m >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0) | 0;
	                            c[k >> 2] = (c[k >> 2] | 0) + d
	                        }
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            p = c[f >> 2] | 0;
	                            i = e;
	                            return p | 0
	                        }
	                        if ((c[(c[h >> 2] | 0) + 8 >> 2] | 0) != -1) {
	                            d = iu(c[g >> 2] | 0, (c[(c[m >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[h >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) | 0) | 0;
	                            c[k >> 2] = (c[k >> 2] | 0) + d
	                        }
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            p = c[f >> 2] | 0;
	                            i = e;
	                            return p | 0
	                        } else {
	                            d = c[g >> 2] | 0;
	                            Tq(d, yt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) | 0) | 0;
	                            c[f >> 2] = c[k >> 2];
	                            p = c[f >> 2] | 0;
	                            i = e;
	                            return p | 0
	                        }
	                        break
	                    }
	                    case 11:
	                    {
	                        if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == -1) {
	                            c[f >> 2] = c[k >> 2];
	                            p = c[f >> 2] | 0;
	                            i = e;
	                            return p | 0
	                        }
	                        c[k >> 2] = iu(c[g >> 2] | 0, (c[(c[m >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0) | 0;
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            p = c[f >> 2] | 0;
	                            i = e;
	                            return p | 0
	                        } else {
	                            d = nu(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, 0, 0) | 0;
	                            c[k >> 2] = (c[k >> 2] | 0) + d;
	                            c[f >> 2] = c[k >> 2];
	                            p = c[f >> 2] | 0;
	                            i = e;
	                            return p | 0
	                        }
	                        break
	                    }
	                    case 8:
	                    {
	                        ks(c[g >> 2] | 0);
	                        c[f >> 2] = 0;
	                        p = c[f >> 2] | 0;
	                        i = e;
	                        return p | 0
	                    }
	                    case 17:
	                    {
	                        c[k >> 2] = (Cu(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0) + (c[k >> 2] | 0);
	                        c[f >> 2] = c[k >> 2];
	                        p = c[f >> 2] | 0;
	                        i = e;
	                        return p | 0
	                    }
	                    default:
	                    {
	                        c[f >> 2] = iu(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                        p = c[f >> 2] | 0;
	                        i = e;
	                        return p | 0
	                    }
	                } while (0);
	                return 0
	            }

	            function ru(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                e = i;
	                i = i + 64 | 0;
	                f = e + 48 | 0;
	                g = e + 44 | 0;
	                h = e + 40 | 0;
	                j = e + 36 | 0;
	                k = e + 32 | 0;
	                l = e + 28 | 0;
	                m = e + 24 | 0;
	                n = e + 20 | 0;
	                o = e + 16 | 0;
	                p = e + 12 | 0;
	                q = e + 8 | 0;
	                r = e + 4 | 0;
	                s = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 0;
	                if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                    c[f >> 2] = 0;
	                    t = c[f >> 2] | 0;
	                    i = e;
	                    return t | 0
	                }
	                c[m >> 2] = c[(c[g >> 2] | 0) + 32 >> 2];
	                switch (c[c[h >> 2] >> 2] | 0) {
	                    case 0:
	                    {
	                        c[f >> 2] = 0;
	                        t = c[f >> 2] | 0;
	                        i = e;
	                        return t | 0
	                    }
	                    case 11:
	                    {
	                        if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == -1) {
	                            c[f >> 2] = 0;
	                            t = c[f >> 2] | 0;
	                            i = e;
	                            return t | 0
	                        }
	                        c[k >> 2] = (iu(c[g >> 2] | 0, (c[(c[m >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0) | 0) + (c[k >> 2] | 0);
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            t = c[f >> 2] | 0;
	                            i = e;
	                            return t | 0
	                        } else {
	                            d = nu(c[g >> 2] | 0, c[h >> 2] | 0, 0, c[j >> 2] | 0, 0) | 0;
	                            c[k >> 2] = (c[k >> 2] | 0) + d;
	                            c[f >> 2] = c[k >> 2];
	                            t = c[f >> 2] | 0;
	                            i = e;
	                            return t | 0
	                        }
	                        break
	                    }
	                    case 7:
	                    {
	                        c[q >> 2] = c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2];
	                        c[p >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2];
	                        c[r >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2];
	                        c[s >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2];
	                        c[k >> 2] = ru(c[g >> 2] | 0, (c[(c[m >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0, c[j >> 2] | 0) | 0;
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            t = c[f >> 2] | 0;
	                            i = e;
	                            return t | 0
	                        }
	                        if ((((c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) == 1 : 0) ? (c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) ? (c[c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] >> 2] | 0) >= 1 : 0) {
	                            if ((c[c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] >> 2] | 0) > 1)Zq(c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0);
	                            c[c[j >> 2] >> 2] = c[(c[(c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) + ((c[c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] >> 2] | 0) - 1 << 2) >> 2]
	                        }
	                        c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2] = c[q >> 2];
	                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[p >> 2];
	                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2] = c[r >> 2];
	                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] = c[s >> 2];
	                        c[l >> 2] = ru(c[g >> 2] | 0, (c[(c[m >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[h >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) | 0, c[j >> 2] | 0) | 0;
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            t = c[f >> 2] | 0;
	                            i = e;
	                            return t | 0
	                        }
	                        if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) == 1 : 0) {
	                            c[o >> 2] = Sq(c[g >> 2] | 0) | 0;
	                            if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) == 1 : 0) {
	                                c[n >> 2] = Sq(c[g >> 2] | 0) | 0;
	                                s = er(c[(c[n >> 2] | 0) + 4 >> 2] | 0, c[(c[o >> 2] | 0) + 4 >> 2] | 0) | 0;
	                                c[(c[n >> 2] | 0) + 4 >> 2] = s;
	                                Tq(c[g >> 2] | 0, c[n >> 2] | 0) | 0;
	                                jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[o >> 2] | 0);
	                                if ((c[k >> 2] | 0) > (c[l >> 2] | 0))Bu(c[h >> 2] | 0);
	                                c[f >> 2] = (c[k >> 2] | 0) + (c[l >> 2] | 0);
	                                t = c[f >> 2] | 0;
	                                i = e;
	                                return t | 0
	                            }
	                            Nq(c[g >> 2] | 0, 11);
	                            c[f >> 2] = 0;
	                            t = c[f >> 2] | 0;
	                            i = e;
	                            return t | 0
	                        }
	                        Nq(c[g >> 2] | 0, 11);
	                        c[f >> 2] = 0;
	                        t = c[f >> 2] | 0;
	                        i = e;
	                        return t | 0
	                    }
	                    case 10:
	                    {
	                        if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) != -1) {
	                            l = iu(c[g >> 2] | 0, (c[(c[m >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0) | 0;
	                            c[k >> 2] = (c[k >> 2] | 0) + l
	                        }
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            t = c[f >> 2] | 0;
	                            i = e;
	                            return t | 0
	                        }
	                        if ((c[(c[h >> 2] | 0) + 8 >> 2] | 0) != -1) {
	                            l = iu(c[g >> 2] | 0, (c[(c[m >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[h >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) | 0) | 0;
	                            c[k >> 2] = (c[k >> 2] | 0) + l
	                        }
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            t = c[f >> 2] | 0;
	                            i = e;
	                            return t | 0
	                        } else {
	                            c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 0;
	                            c[f >> 2] = c[k >> 2];
	                            t = c[f >> 2] | 0;
	                            i = e;
	                            return t | 0
	                        }
	                        break
	                    }
	                    case 9:
	                    {
	                        if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) != -1) {
	                            l = iu(c[g >> 2] | 0, (c[(c[m >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0) | 0;
	                            c[k >> 2] = (c[k >> 2] | 0) + l
	                        }
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            t = c[f >> 2] | 0;
	                            i = e;
	                            return t | 0
	                        }
	                        if ((c[(c[h >> 2] | 0) + 8 >> 2] | 0) != -1) {
	                            l = iu(c[g >> 2] | 0, (c[(c[m >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[h >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) | 0) | 0;
	                            c[k >> 2] = (c[k >> 2] | 0) + l
	                        }
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            t = c[f >> 2] | 0;
	                            i = e;
	                            return t | 0
	                        } else {
	                            l = c[g >> 2] | 0;
	                            Tq(l, yt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) | 0) | 0;
	                            c[f >> 2] = c[k >> 2];
	                            t = c[f >> 2] | 0;
	                            i = e;
	                            return t | 0
	                        }
	                        break
	                    }
	                    case 8:
	                    {
	                        ks(c[g >> 2] | 0);
	                        c[f >> 2] = 0;
	                        t = c[f >> 2] | 0;
	                        i = e;
	                        return t | 0
	                    }
	                    case 12:
	                    {
	                        Tq(c[g >> 2] | 0, lt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[(c[h >> 2] | 0) + 24 >> 2] | 0) | 0) | 0;
	                        c[f >> 2] = 0;
	                        t = c[f >> 2] | 0;
	                        i = e;
	                        return t | 0
	                    }
	                    case 18:
	                    {
	                        if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) != -1) {
	                            l = ru(c[g >> 2] | 0, (c[(c[m >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0, c[j >> 2] | 0) | 0;
	                            c[k >> 2] = (c[k >> 2] | 0) + l
	                        }
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            t = c[f >> 2] | 0;
	                            i = e;
	                            return t | 0
	                        }
	                        if ((((c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) == 1 : 0) ? (c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) ? (c[c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] >> 2] | 0) > 1 : 0)Zq(c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0);
	                        c[f >> 2] = c[k >> 2];
	                        t = c[f >> 2] | 0;
	                        i = e;
	                        return t | 0
	                    }
	                    default:
	                    {
	                        c[f >> 2] = iu(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                        t = c[f >> 2] | 0;
	                        i = e;
	                        return t | 0
	                    }
	                }
	                return 0
	            }

	            function su(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if ((c[c[e >> 2] >> 2] | 0) <= 0) {
	                    i = d;
	                    return
	                }
	                a:do if (c[f >> 2] | 0) {
	                    c[g >> 2] = 0;
	                    while (1) {
	                        if ((c[g >> 2] | 0) >= (c[c[e >> 2] >> 2] | 0))break a;
	                        c[h >> 2] = c[(c[(c[e >> 2] | 0) + 8 >> 2] | 0) + (c[g >> 2] << 2) >> 2];
	                        if ((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 18 : 0)_q(c[h >> 2] | 0);
	                        c[g >> 2] = (c[g >> 2] | 0) + 1
	                    }
	                } while (0);
	                c[c[e >> 2] >> 2] = 0;
	                i = d;
	                return
	            }

	            function tu(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                g = b + 4 | 0;
	                h = b;
	                c[e >> 2] = a;
	                Du(c[e >> 2] | 0);
	                if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                    i = b;
	                    return
	                }
	                a:while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    a = c[e >> 2] | 0;
	                    if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1
	                }
	                b:while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 60 ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 62 : 0) {
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[c[e >> 2] >> 2] | 0) + 1 >> 0] | 0 | 0) == 61 : 0)break;
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 62) {
	                            j = 40;
	                            break b
	                        }
	                        if ((d[(c[c[e >> 2] >> 2] | 0) + 1 >> 0] | 0 | 0) != 61) {
	                            j = 40;
	                            break b
	                        }
	                    } while (0);
	                    c[h >> 2] = c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2];
	                    if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 60)c[f >> 2] = 1; else c[f >> 2] = 0;
	                    if ((d[(c[c[e >> 2] >> 2] | 0) + 1 >> 0] | 0 | 0) == 61)c[g >> 2] = 0; else c[g >> 2] = 1;
	                    a = c[e >> 2] | 0;
	                    if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[a >> 2] = (c[a >> 2] | 0) + 1;
	                    if ((c[g >> 2] | 0) == 0 ? (a = c[e >> 2] | 0, (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 0) : 0)c[a >> 2] = (c[a >> 2] | 0) + 1;
	                    while (1) {
	                        do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)k = 1; else {
	                            if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                k = 1;
	                                break
	                            }
	                            k = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        l = c[e >> 2] | 0;
	                        if (!k)break;
	                        a = c[e >> 2] | 0;
	                        if (!(d[c[l >> 2] >> 0] | 0))continue;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1
	                    }
	                    Du(l);
	                    if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                        j = 40;
	                        break
	                    }
	                    du(c[(c[e >> 2] | 0) + 32 >> 2] | 0, c[h >> 2] | 0, c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2] | 0, 4, c[f >> 2] | 0, c[g >> 2] | 0, 0, 0, 0) | 0;
	                    while (1) {
	                        do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)continue b
	                        } while (0);
	                        a = c[e >> 2] | 0;
	                        if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1
	                    }
	                }
	                if ((j | 0) == 40) {
	                    i = b;
	                    return
	                }
	            }

	            function uu(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 40 | 0;
	                g = e + 36 | 0;
	                h = e + 32 | 0;
	                j = e + 28 | 0;
	                k = e + 24 | 0;
	                l = e + 20 | 0;
	                m = e + 16 | 0;
	                n = e + 12 | 0;
	                o = e + 8 | 0;
	                p = e + 4 | 0;
	                q = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                a:do if ((c[g >> 2] | 0) == 0 & (c[j >> 2] | 0) == 0) {
	                    c[g >> 2] = Eu(c[c[h >> 2] >> 2] | 0) | 0;
	                    if (!(c[g >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    } else {
	                        if (!(c[c[h >> 2] >> 2] | 0))break;
	                        eU(c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[c[h >> 2] >> 2] << 2 | 0) | 0;
	                        c[c[g >> 2] >> 2] = c[c[h >> 2] >> 2];
	                        break
	                    }
	                } else {
	                    if (!(c[g >> 2] | 0))c[g >> 2] = $q(0) | 0;
	                    if (!(c[g >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    }
	                    c[m >> 2] = c[c[g >> 2] >> 2];
	                    c[k >> 2] = 0;
	                    b:while (1) {
	                        if ((c[k >> 2] | 0) >= (c[c[h >> 2] >> 2] | 0))break a;
	                        c[o >> 2] = c[(c[(c[h >> 2] | 0) + 8 >> 2] | 0) + (c[k >> 2] << 2) >> 2];
	                        c:do if (c[o >> 2] | 0) {
	                            c[l >> 2] = 0;
	                            while (1) {
	                                if ((c[l >> 2] | 0) >= (c[m >> 2] | 0))break;
	                                c[n >> 2] = c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + (c[l >> 2] << 2) >> 2];
	                                if ((c[n >> 2] | 0) == (c[o >> 2] | 0))break c;
	                                if ((((c[(c[n >> 2] | 0) + 4 >> 2] | 0) == 18 ? (c[(c[o >> 2] | 0) + 4 >> 2] | 0) == 18 : 0) ? (c[c[n >> 2] >> 2] | 0) == (c[c[o >> 2] >> 2] | 0) : 0) ? (qy(c[(c[n >> 2] | 0) + 12 >> 2] | 0, c[(c[o >> 2] | 0) + 12 >> 2] | 0) | 0) != 0 : 0) {
	                                    s = 20;
	                                    break
	                                }
	                                c[l >> 2] = (c[l >> 2] | 0) + 1
	                            }
	                            if ((s | 0) == 20) {
	                                s = 0;
	                                c[(c[(c[h >> 2] | 0) + 8 >> 2] | 0) + (c[k >> 2] << 2) >> 2] = 0;
	                                _q(c[o >> 2] | 0);
	                                break
	                            }
	                            if (c[(c[g >> 2] | 0) + 4 >> 2] | 0) {
	                                if ((c[c[g >> 2] >> 2] | 0) >= (c[(c[g >> 2] | 0) + 4 >> 2] | 0)) {
	                                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) >= 1e7) {
	                                        s = 28;
	                                        break b
	                                    }
	                                    c[p >> 2] = Hb[c[135760 >> 2] & 511](c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] << 1 << 2) | 0;
	                                    if (!(c[p >> 2] | 0)) {
	                                        s = 30;
	                                        break b
	                                    }
	                                    c[(c[g >> 2] | 0) + 8 >> 2] = c[p >> 2];
	                                    d = (c[g >> 2] | 0) + 4 | 0;
	                                    c[d >> 2] = c[d >> 2] << 1
	                                }
	                            } else {
	                                d = Cb[c[135744 >> 2] & 511](40) | 0;
	                                c[(c[g >> 2] | 0) + 8 >> 2] = d;
	                                if (!(c[(c[g >> 2] | 0) + 8 >> 2] | 0)) {
	                                    s = 24;
	                                    break b
	                                }
	                                d = (c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 0 | 0;
	                                b = d + 40 | 0;
	                                do {
	                                    c[d >> 2] = 0;
	                                    d = d + 4 | 0
	                                } while ((d | 0) < (b | 0));
	                                c[(c[g >> 2] | 0) + 4 >> 2] = 10
	                            }
	                            d = c[o >> 2] | 0;
	                            if ((c[(c[o >> 2] | 0) + 4 >> 2] | 0) == 18) {
	                                c[q >> 2] = d;
	                                b = kt(c[c[q >> 2] >> 2] | 0, c[q >> 2] | 0) | 0;
	                                a = c[g >> 2] | 0;
	                                t = c[a >> 2] | 0;
	                                c[a >> 2] = t + 1;
	                                c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + (t << 2) >> 2] = b;
	                                break
	                            } else {
	                                b = c[g >> 2] | 0;
	                                t = c[b >> 2] | 0;
	                                c[b >> 2] = t + 1;
	                                c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + (t << 2) >> 2] = d;
	                                break
	                            }
	                        } while (0);
	                        c[k >> 2] = (c[k >> 2] | 0) + 1
	                    }
	                    if ((s | 0) == 24) {
	                        it(0, 128712);
	                        c[f >> 2] = 0;
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    } else if ((s | 0) == 28) {
	                        it(0, 128736);
	                        c[f >> 2] = 0;
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    } else if ((s | 0) == 30) {
	                        it(0, 128712);
	                        c[f >> 2] = 0;
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    }
	                } while (0);
	                c[c[h >> 2] >> 2] = 0;
	                c[f >> 2] = c[g >> 2];
	                r = c[f >> 2] | 0;
	                i = e;
	                return r | 0
	            }

	            function vu(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 20 | 0;
	                h = e + 16 | 0;
	                j = e + 12 | 0;
	                k = e + 8 | 0;
	                l = e + 4 | 0;
	                m = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                d = c[g >> 2] | 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = d;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                a:do if ((d | 0) == 0 & (c[j >> 2] | 0) == 0) {
	                    c[g >> 2] = Eu(c[c[h >> 2] >> 2] | 0) | 0;
	                    if (!(c[g >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    } else {
	                        if (!(c[c[h >> 2] >> 2] | 0))break;
	                        eU(c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[c[h >> 2] >> 2] << 2 | 0) | 0;
	                        c[c[g >> 2] >> 2] = c[c[h >> 2] >> 2];
	                        break
	                    }
	                } else {
	                    if (!(c[g >> 2] | 0))c[g >> 2] = $q(0) | 0;
	                    if (!(c[g >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    }
	                    c[k >> 2] = 0;
	                    while (1) {
	                        if ((c[k >> 2] | 0) >= (c[c[h >> 2] >> 2] | 0))break a;
	                        c[l >> 2] = c[(c[(c[h >> 2] | 0) + 8 >> 2] | 0) + (c[k >> 2] << 2) >> 2];
	                        if (c[l >> 2] | 0) {
	                            if (c[(c[g >> 2] | 0) + 4 >> 2] | 0) {
	                                if ((c[c[g >> 2] >> 2] | 0) >= (c[(c[g >> 2] | 0) + 4 >> 2] | 0)) {
	                                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) >= 1e7) {
	                                        o = 21;
	                                        break
	                                    }
	                                    c[m >> 2] = Hb[c[135760 >> 2] & 511](c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] << 1 << 2) | 0;
	                                    if (!(c[m >> 2] | 0)) {
	                                        o = 23;
	                                        break
	                                    }
	                                    c[(c[g >> 2] | 0) + 8 >> 2] = c[m >> 2];
	                                    b = (c[g >> 2] | 0) + 4 | 0;
	                                    c[b >> 2] = c[b >> 2] << 1
	                                }
	                            } else {
	                                b = Cb[c[135744 >> 2] & 511](40) | 0;
	                                c[(c[g >> 2] | 0) + 8 >> 2] = b;
	                                if (!(c[(c[g >> 2] | 0) + 8 >> 2] | 0)) {
	                                    o = 17;
	                                    break
	                                }
	                                b = (c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 0 | 0;
	                                a = b + 40 | 0;
	                                do {
	                                    c[b >> 2] = 0;
	                                    b = b + 4 | 0
	                                } while ((b | 0) < (a | 0));
	                                c[(c[g >> 2] | 0) + 4 >> 2] = 10
	                            }
	                            b = c[l >> 2] | 0;
	                            a = c[g >> 2] | 0;
	                            p = c[a >> 2] | 0;
	                            c[a >> 2] = p + 1;
	                            c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + (p << 2) >> 2] = b
	                        }
	                        c[k >> 2] = (c[k >> 2] | 0) + 1
	                    }
	                    if ((o | 0) == 17) {
	                        it(0, 128712);
	                        c[f >> 2] = 0;
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    } else if ((o | 0) == 21) {
	                        it(0, 128736);
	                        c[f >> 2] = 0;
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    } else if ((o | 0) == 23) {
	                        it(0, 128712);
	                        c[f >> 2] = 0;
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    }
	                } while (0);
	                c[c[h >> 2] >> 2] = 0;
	                c[f >> 2] = c[g >> 2];
	                n = c[f >> 2] | 0;
	                i = e;
	                return n | 0
	            }

	            function wu(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                a:do if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                    if (c[g >> 2] | 0) {
	                        switch (c[(c[g >> 2] | 0) + 4 >> 2] | 0) {
	                            case 20:
	                            case 8:
	                            case 7:
	                            case 4:
	                            case 6:
	                            case 5:
	                            case 3:
	                            case 1:
	                                break;
	                            default:
	                            {
	                                c[e >> 2] = 0;
	                                break a
	                            }
	                        }
	                        if (!(c[(c[g >> 2] | 0) + 24 >> 2] | 0)) {
	                            c[e >> 2] = 0;
	                            break
	                        }
	                        b = c[(c[g >> 2] | 0) + 24 >> 2] | 0;
	                        if ((c[(c[(c[g >> 2] | 0) + 24 >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                            c[e >> 2] = b;
	                            break
	                        }
	                        c[g >> 2] = b;
	                        do {
	                            c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                            if (!(c[g >> 2] | 0))break
	                        } while ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 1);
	                        c[e >> 2] = c[g >> 2];
	                        break
	                    }
	                    c[g >> 2] = c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2];
	                    if (!(c[g >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        break
	                    }
	                    switch (c[(c[g >> 2] | 0) + 4 >> 2] | 0) {
	                        case 21:
	                        case 13:
	                        case 9:
	                        {
	                            c[e >> 2] = Pi(c[g >> 2] | 0) | 0;
	                            break a;
	                            break
	                        }
	                        case 6:
	                        case 5:
	                        case 11:
	                        case 1:
	                        {
	                            c[g >> 2] = c[(c[g >> 2] | 0) + 12 >> 2];
	                            if (!(c[g >> 2] | 0)) {
	                                c[e >> 2] = 0;
	                                break a
	                            }
	                            if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                                c[e >> 2] = c[g >> 2];
	                                break a
	                            }
	                            do {
	                                c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                                if (!(c[g >> 2] | 0))break
	                            } while ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 1);
	                            c[e >> 2] = c[g >> 2];
	                            break a;
	                            break
	                        }
	                        default:
	                        {
	                            c[e >> 2] = 0;
	                            break a
	                        }
	                    }
	                } else h = 3; while (0);
	                if ((h | 0) == 3)c[e >> 2] = 0;
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function xu(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                    do if (!(c[g >> 2] | 0)) {
	                        c[g >> 2] = c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2];
	                        if (!(c[g >> 2] | 0)) {
	                            c[e >> 2] = 0;
	                            h = c[e >> 2] | 0;
	                            i = d;
	                            return h | 0
	                        }
	                        if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 18) {
	                            c[(c[f >> 2] | 0) + 40 >> 2] = c[(c[g >> 2] | 0) + 20 >> 2];
	                            break
	                        }
	                        c[e >> 2] = 0;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    } while (0);
	                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 18) {
	                        c[e >> 2] = 0;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                    if ((c[(c[g >> 2] | 0) + 28 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 4 >> 2] | 0) == 14 : 0)c[g >> 2] = c[(c[g >> 2] | 0) + 28 >> 2];
	                    while (1) {
	                        j = c[g >> 2] | 0;
	                        if (c[(c[g >> 2] | 0) + 28 >> 2] | 0) {
	                            k = 23;
	                            break
	                        }
	                        c[g >> 2] = c[j + 20 >> 2];
	                        if (!(c[g >> 2] | 0)) {
	                            k = 17;
	                            break
	                        }
	                        if ((c[g >> 2] | 0) == (c[(c[c[(c[f >> 2] | 0) + 12 >> 2] >> 2] | 0) + 12 >> 2] | 0)) {
	                            k = 19;
	                            break
	                        }
	                        l = c[g >> 2] | 0;
	                        if ((c[g >> 2] | 0) != (c[(c[f >> 2] | 0) + 40 >> 2] | 0)) {
	                            k = 21;
	                            break
	                        }
	                        c[(c[f >> 2] | 0) + 40 >> 2] = c[l + 20 >> 2]
	                    }
	                    if ((k | 0) == 17) {
	                        c[e >> 2] = 0;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    } else if ((k | 0) == 19) {
	                        c[e >> 2] = 0;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    } else if ((k | 0) == 21) {
	                        c[e >> 2] = l;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    } else if ((k | 0) == 23) {
	                        c[g >> 2] = c[j + 28 >> 2];
	                        while (1) {
	                            m = c[g >> 2] | 0;
	                            if (!(c[(c[g >> 2] | 0) + 16 >> 2] | 0))break;
	                            c[g >> 2] = c[m + 16 >> 2]
	                        }
	                        c[e >> 2] = m;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                }
	                c[e >> 2] = 0;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function yu(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                if ((c[c[j >> 2] >> 2] | 0) != 16 ? (c[c[j >> 2] >> 2] | 0) != 17 : 0) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                if ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) == -1) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                c[l >> 2] = (c[(c[(c[g >> 2] | 0) + 32 >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) * 40 | 0);
	                if (((((c[l >> 2] | 0) != 0 ? (c[c[l >> 2] >> 2] | 0) == 12 : 0) ? (c[(c[l >> 2] | 0) + 24 >> 2] | 0) != 0 : 0) ? (c[c[(c[l >> 2] | 0) + 24 >> 2] >> 2] | 0) == 3 : 0) ? (c[c[k >> 2] >> 2] = ~~+h[(c[(c[l >> 2] | 0) + 24 >> 2] | 0) + 16 >> 3], +h[(c[(c[l >> 2] | 0) + 24 >> 2] | 0) + 16 >> 3] == +(c[c[k >> 2] >> 2] | 0)) : 0) {
	                    c[f >> 2] = 1;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                c[f >> 2] = 0;
	                m = c[f >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function zu(a, b, d, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0;
	                j = i;
	                i = i + 96 | 0;
	                k = j + 88 | 0;
	                l = j + 84 | 0;
	                m = j + 80 | 0;
	                n = j + 76 | 0;
	                o = j + 72 | 0;
	                p = j + 68 | 0;
	                q = j + 64 | 0;
	                r = j + 60 | 0;
	                s = j + 56 | 0;
	                t = j + 52 | 0;
	                u = j + 48 | 0;
	                v = j + 44 | 0;
	                w = j + 40 | 0;
	                x = j + 36 | 0;
	                y = j + 32 | 0;
	                z = j + 28 | 0;
	                A = j + 24 | 0;
	                B = j + 20 | 0;
	                C = j + 16 | 0;
	                D = j + 12 | 0;
	                E = j + 8 | 0;
	                F = j + 4 | 0;
	                G = j;
	                c[l >> 2] = a;
	                c[m >> 2] = b;
	                c[n >> 2] = d;
	                c[o >> 2] = e;
	                c[p >> 2] = f;
	                c[q >> 2] = g;
	                c[r >> 2] = h;
	                if ((c[(c[m >> 2] | 0) + 4 >> 2] | 0) != -1) {
	                    c[s >> 2] = c[(c[l >> 2] | 0) + 32 >> 2];
	                    c[o >> 2] = Au(c[l >> 2] | 0, (c[(c[s >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[m >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0, c[n >> 2] | 0, c[o >> 2] | 0, c[r >> 2] | 0) | 0;
	                    if (c[(c[l >> 2] | 0) + 8 >> 2] | 0) {
	                        c[k >> 2] = 0;
	                        H = c[k >> 2] | 0;
	                        i = j;
	                        return H | 0
	                    }
	                    if ((c[o >> 2] | 0) <= 0) {
	                        c[k >> 2] = 0;
	                        H = c[k >> 2] | 0;
	                        i = j;
	                        return H | 0
	                    }
	                }
	                if ((c[o >> 2] | 0) < (c[p >> 2] | 0)) {
	                    su(c[n >> 2] | 0, c[r >> 2] | 0);
	                    c[k >> 2] = 0;
	                    H = c[k >> 2] | 0;
	                    i = j;
	                    return H | 0
	                }
	                if ((c[(c[m >> 2] | 0) + 8 >> 2] | 0) == -1) {
	                    c[k >> 2] = c[o >> 2];
	                    H = c[k >> 2] | 0;
	                    i = j;
	                    return H | 0
	                }
	                c[v >> 2] = 0;
	                c[w >> 2] = 0;
	                c[x >> 2] = 0;
	                c[A >> 2] = 0;
	                c[B >> 2] = 0;
	                c[D >> 2] = 0;
	                c[E >> 2] = c[(c[l >> 2] | 0) + 12 >> 2];
	                c[C >> 2] = c[(c[E >> 2] | 0) + 4 >> 2];
	                c[t >> 2] = c[c[E >> 2] >> 2];
	                c[z >> 2] = (c[(c[(c[l >> 2] | 0) + 32 >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[m >> 2] | 0) + 8 >> 2] | 0) * 40 | 0);
	                c[u >> 2] = 0;
	                a:while (1) {
	                    if ((c[u >> 2] | 0) >= (c[c[n >> 2] >> 2] | 0))break;
	                    do if (c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + (c[u >> 2] << 2) >> 2] | 0) {
	                        c[D >> 2] = c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + (c[u >> 2] << 2) >> 2];
	                        c[(c[E >> 2] | 0) + 4 >> 2] = c[D >> 2];
	                        c[(c[E >> 2] | 0) + 68 >> 2] = c[o >> 2];
	                        m = (c[x >> 2] | 0) + 1 | 0;
	                        c[x >> 2] = m;
	                        c[(c[E >> 2] | 0) + 72 >> 2] = m;
	                        if ((c[(c[D >> 2] | 0) + 4 >> 2] | 0) != 18 ? (c[(c[D >> 2] | 0) + 32 >> 2] | 0) != 0 : 0)c[c[E >> 2] >> 2] = c[(c[D >> 2] | 0) + 32 >> 2];
	                        if (c[A >> 2] | 0) {
	                            if ((dr(c[(c[A >> 2] | 0) + 4 >> 2] | 0, c[D >> 2] | 0) | 0) < 0) {
	                                I = 19;
	                                break a
	                            }
	                        } else c[A >> 2] = yt(c[E >> 2] | 0, c[D >> 2] | 0) | 0;
	                        c[F >> 2] = ou(c[l >> 2] | 0) | 0;
	                        Tq(c[l >> 2] | 0, c[A >> 2] | 0) | 0;
	                        c[y >> 2] = hu(c[l >> 2] | 0, c[z >> 2] | 0, 1) | 0;
	                        c[G >> 2] = Sq(c[l >> 2] | 0) | 0;
	                        pu(c[l >> 2] | 0, c[F >> 2] | 0);
	                        if ((c[y >> 2] | 0) == -1 ? 1 : (c[(c[l >> 2] | 0) + 8 >> 2] | 0) != 0) {
	                            I = 21;
	                            break a
	                        }
	                        Tq(c[l >> 2] | 0, c[G >> 2] | 0) | 0;
	                        if (c[y >> 2] | 0)c[v >> 2] = (c[v >> 2] | 0) + 1;
	                        if (((c[y >> 2] | 0) != 0 ? (c[v >> 2] | 0) >= (c[p >> 2] | 0) : 0) ? (c[v >> 2] | 0) <= (c[q >> 2] | 0) : 0) {
	                            c[w >> 2] = (c[w >> 2] | 0) + 1;
	                            if ((c[p >> 2] | 0) == (c[q >> 2] | 0)) {
	                                I = 29;
	                                break a
	                            }
	                            if ((c[v >> 2] | 0) == (c[q >> 2] | 0)) {
	                                I = 33;
	                                break a
	                            }
	                        } else I = 34;
	                        if ((I | 0) == 34 ? (I = 0, c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + (c[u >> 2] << 2) >> 2] = 0, (c[(c[D >> 2] | 0) + 4 >> 2] | 0) == 18) : 0)_q(c[D >> 2] | 0);
	                        if (c[B >> 2] | 0) {
	                            jt(c[(c[l >> 2] | 0) + 12 >> 2] | 0, c[B >> 2] | 0);
	                            c[B >> 2] = 0
	                        }
	                        if ((c[(c[l >> 2] | 0) + 16 >> 2] | 0) == (c[A >> 2] | 0)) {
	                            Sq(c[l >> 2] | 0) | 0;
	                            su(c[(c[A >> 2] | 0) + 4 >> 2] | 0, c[r >> 2] | 0);
	                            break
	                        } else {
	                            c[A >> 2] = 0;
	                            break
	                        }
	                    } while (0);
	                    c[u >> 2] = (c[u >> 2] | 0) + 1
	                }
	                if ((I | 0) == 19)c[(c[l >> 2] | 0) + 8 >> 2] = 15; else if ((I | 0) == 21) {
	                    while (1) {
	                        I = 0;
	                        if ((c[G >> 2] | 0) == (c[A >> 2] | 0))break;
	                        jt(c[E >> 2] | 0, c[G >> 2] | 0);
	                        c[G >> 2] = Sq(c[l >> 2] | 0) | 0;
	                        I = 21
	                    }
	                    su(c[n >> 2] | 0, c[r >> 2] | 0);
	                    c[w >> 2] = 0
	                } else if ((I | 0) == 29) {
	                    if ((c[(c[D >> 2] | 0) + 4 >> 2] | 0) == 18)c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + (c[u >> 2] << 2) >> 2] = 0;
	                    su(c[n >> 2] | 0, c[r >> 2] | 0);
	                    c[c[n >> 2] >> 2] = 1;
	                    c[c[(c[n >> 2] | 0) + 8 >> 2] >> 2] = c[D >> 2]
	                } else if ((I | 0) == 33)Fu(c[n >> 2] | 0, (c[u >> 2] | 0) + 1 | 0, c[r >> 2] | 0);
	                if (c[A >> 2] | 0) {
	                    if ((c[(c[l >> 2] | 0) + 16 >> 2] | 0) == (c[A >> 2] | 0))Sq(c[l >> 2] | 0) | 0;
	                    jt(c[E >> 2] | 0, c[A >> 2] | 0)
	                }
	                if (c[B >> 2] | 0)jt(c[(c[l >> 2] | 0) + 12 >> 2] | 0, c[B >> 2] | 0);
	                c[(c[E >> 2] | 0) + 4 >> 2] = c[C >> 2];
	                c[c[E >> 2] >> 2] = c[t >> 2];
	                c[(c[E >> 2] | 0) + 68 >> 2] = -1;
	                c[(c[E >> 2] | 0) + 72 >> 2] = -1;
	                c[k >> 2] = c[w >> 2];
	                H = c[k >> 2] | 0;
	                i = j;
	                return H | 0
	            }

	            function Au(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0;
	                g = i;
	                i = i + 80 | 0;
	                h = g + 68 | 0;
	                j = g + 64 | 0;
	                k = g + 60 | 0;
	                l = g + 56 | 0;
	                m = g + 52 | 0;
	                n = g + 48 | 0;
	                o = g + 44 | 0;
	                p = g + 40 | 0;
	                q = g + 36 | 0;
	                r = g + 32 | 0;
	                s = g + 28 | 0;
	                t = g + 24 | 0;
	                u = g + 20 | 0;
	                v = g + 16 | 0;
	                w = g + 12 | 0;
	                x = g + 8 | 0;
	                y = g + 4 | 0;
	                z = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) != -1) {
	                    c[o >> 2] = c[(c[j >> 2] | 0) + 32 >> 2];
	                    c[m >> 2] = Au(c[j >> 2] | 0, (c[(c[o >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0, c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0) | 0;
	                    if (c[(c[j >> 2] | 0) + 8 >> 2] | 0) {
	                        c[h >> 2] = 0;
	                        A = c[h >> 2] | 0;
	                        i = g;
	                        return A | 0
	                    }
	                    if ((c[m >> 2] | 0) <= 0) {
	                        c[h >> 2] = 0;
	                        A = c[h >> 2] | 0;
	                        i = g;
	                        return A | 0
	                    }
	                }
	                if ((c[(c[k >> 2] | 0) + 8 >> 2] | 0) == -1) {
	                    c[h >> 2] = c[m >> 2];
	                    A = c[h >> 2] | 0;
	                    i = g;
	                    return A | 0
	                }
	                c[p >> 2] = c[(c[j >> 2] | 0) + 12 >> 2];
	                c[v >> 2] = 0;
	                c[y >> 2] = 0;
	                c[z >> 2] = 0;
	                c[r >> 2] = c[(c[p >> 2] | 0) + 4 >> 2];
	                c[s >> 2] = c[c[p >> 2] >> 2];
	                c[x >> 2] = (c[(c[(c[j >> 2] | 0) + 32 >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[k >> 2] | 0) + 8 >> 2] | 0) * 40 | 0);
	                c[w >> 2] = 0;
	                c[t >> 2] = 0;
	                a:while (1) {
	                    if ((c[t >> 2] | 0) >= (c[c[l >> 2] >> 2] | 0)) {
	                        B = 27;
	                        break
	                    }
	                    do if (c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + (c[t >> 2] << 2) >> 2] | 0) {
	                        c[q >> 2] = c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + (c[t >> 2] << 2) >> 2];
	                        c[(c[p >> 2] | 0) + 4 >> 2] = c[q >> 2];
	                        c[(c[p >> 2] | 0) + 68 >> 2] = c[m >> 2];
	                        k = (c[v >> 2] | 0) + 1 | 0;
	                        c[v >> 2] = k;
	                        c[(c[p >> 2] | 0) + 72 >> 2] = k;
	                        if ((c[(c[q >> 2] | 0) + 4 >> 2] | 0) != 18 ? (c[(c[q >> 2] | 0) + 32 >> 2] | 0) != 0 : 0)c[c[p >> 2] >> 2] = c[(c[q >> 2] | 0) + 32 >> 2];
	                        if (c[y >> 2] | 0) {
	                            if ((dr(c[(c[y >> 2] | 0) + 4 >> 2] | 0, c[q >> 2] | 0) | 0) < 0) {
	                                B = 16;
	                                break a
	                            }
	                        } else c[y >> 2] = yt(c[p >> 2] | 0, c[q >> 2] | 0) | 0;
	                        Tq(c[j >> 2] | 0, c[y >> 2] | 0) | 0;
	                        c[u >> 2] = hu(c[j >> 2] | 0, c[x >> 2] | 0, 1) | 0;
	                        if ((c[u >> 2] | 0) == -1 ? 1 : (c[(c[j >> 2] | 0) + 8 >> 2] | 0) != 0) {
	                            B = 18;
	                            break a
	                        }
	                        if (!(c[u >> 2] | 0)) {
	                            c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + (c[t >> 2] << 2) >> 2] = 0;
	                            if ((c[(c[q >> 2] | 0) + 4 >> 2] | 0) == 18)_q(c[q >> 2] | 0)
	                        } else c[w >> 2] = (c[w >> 2] | 0) + 1;
	                        if ((c[(c[j >> 2] | 0) + 16 >> 2] | 0) == (c[y >> 2] | 0)) {
	                            Sq(c[j >> 2] | 0) | 0;
	                            su(c[(c[y >> 2] | 0) + 4 >> 2] | 0, c[n >> 2] | 0);
	                            break
	                        } else {
	                            c[y >> 2] = 0;
	                            break
	                        }
	                    } while (0);
	                    c[t >> 2] = (c[t >> 2] | 0) + 1
	                }
	                if ((B | 0) == 16)c[(c[j >> 2] | 0) + 8 >> 2] = 15; else if ((B | 0) == 18) {
	                    su(c[l >> 2] | 0, c[n >> 2] | 0);
	                    c[w >> 2] = 0
	                } else if ((B | 0) == 27 ? (c[y >> 2] | 0) != 0 : 0) {
	                    if ((c[(c[j >> 2] | 0) + 16 >> 2] | 0) == (c[y >> 2] | 0))Sq(c[j >> 2] | 0) | 0;
	                    jt(c[p >> 2] | 0, c[y >> 2] | 0)
	                }
	                if (c[z >> 2] | 0)jt(c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[z >> 2] | 0);
	                c[(c[p >> 2] | 0) + 4 >> 2] = c[r >> 2];
	                c[c[p >> 2] >> 2] = c[s >> 2];
	                c[(c[p >> 2] | 0) + 68 >> 2] = -1;
	                c[(c[p >> 2] | 0) + 72 >> 2] = -1;
	                c[h >> 2] = c[w >> 2];
	                A = c[h >> 2] | 0;
	                i = g;
	                return A | 0
	            }

	            function Bu(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                if (c[32574] | 0) {
	                    i = b;
	                    return
	                }
	                c[e >> 2] = c[(c[d >> 2] | 0) + 4 >> 2];
	                c[(c[d >> 2] | 0) + 4 >> 2] = c[(c[d >> 2] | 0) + 8 >> 2];
	                c[(c[d >> 2] | 0) + 8 >> 2] = c[e >> 2];
	                i = b;
	                return
	            }

	            function Cu(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0;
	                e = i;
	                i = i + 80 | 0;
	                f = e + 72 | 0;
	                g = e + 68 | 0;
	                h = e + 64 | 0;
	                j = e + 60 | 0;
	                k = e + 56 | 0;
	                l = e + 52 | 0;
	                m = e + 48 | 0;
	                n = e + 44 | 0;
	                o = e + 40 | 0;
	                p = e + 36 | 0;
	                q = e + 32 | 0;
	                r = e + 28 | 0;
	                s = e + 24 | 0;
	                t = e + 20 | 0;
	                u = e + 16 | 0;
	                v = e + 12 | 0;
	                w = e + 8 | 0;
	                x = e + 4 | 0;
	                y = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 0;
	                if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                    c[f >> 2] = 0;
	                    z = c[f >> 2] | 0;
	                    i = e;
	                    return z | 0
	                }
	                c[l >> 2] = c[(c[g >> 2] | 0) + 32 >> 2];
	                if ((((((((((c[(c[h >> 2] | 0) + 4 >> 2] | 0) != -1 ? (c[(c[h >> 2] | 0) + 8 >> 2] | 0) != -1 : 0) ? (c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) >> 2] | 0) == 18 : 0) ? (c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[h >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) >> 2] | 0) == 18 : 0) ? (c[s >> 2] = c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[h >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) + 4 >> 2], (c[s >> 2] | 0) != -1) : 0) ? (c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + ((c[s >> 2] | 0) * 40 | 0) >> 2] | 0) == 14 : 0) ? (c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + ((c[s >> 2] | 0) * 40 | 0) + 28 >> 2] | 0) == 0 : 0) ? (c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + ((c[s >> 2] | 0) * 40 | 0) + 12 >> 2] | 0) == 0 : 0) ? (c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + ((c[s >> 2] | 0) * 40 | 0) + 24 >> 2] | 0) != 0 : 0) ? (qy(c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + ((c[s >> 2] | 0) * 40 | 0) + 24 >> 2] | 0, 129656) | 0) != 0 : 0) {
	                    c[t >> 2] = 0;
	                    s = ru(c[g >> 2] | 0, (c[(c[l >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0, t) | 0;
	                    c[k >> 2] = (c[k >> 2] | 0) + s;
	                    if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                        c[f >> 2] = 0;
	                        z = c[f >> 2] | 0;
	                        i = e;
	                        return z | 0
	                    }
	                    if (((((c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) == 1 : 0) ? (c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) ? (c[(c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (c[c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] >> 2] | 0) > 1 : 0) {
	                        c[c[(c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] >> 2] = c[(c[(c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) + ((c[c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] >> 2] | 0) - 1 << 2) >> 2];
	                        c[c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] >> 2] = 1;
	                        c[c[j >> 2] >> 2] = c[c[(c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] >> 2]
	                    }
	                    c[f >> 2] = c[k >> 2];
	                    z = c[f >> 2] | 0;
	                    i = e;
	                    return z | 0
	                }
	                if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) != -1) {
	                    s = iu(c[g >> 2] | 0, (c[(c[l >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) * 40 | 0) | 0) | 0;
	                    c[k >> 2] = (c[k >> 2] | 0) + s
	                }
	                if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                    c[f >> 2] = 0;
	                    z = c[f >> 2] | 0;
	                    i = e;
	                    return z | 0
	                }
	                if ((c[(c[h >> 2] | 0) + 8 >> 2] | 0) == -1) {
	                    c[f >> 2] = c[k >> 2];
	                    z = c[f >> 2] | 0;
	                    i = e;
	                    return z | 0
	                }
	                if (!(c[(c[g >> 2] | 0) + 16 >> 2] | 0)) {
	                    c[f >> 2] = c[k >> 2];
	                    z = c[f >> 2] | 0;
	                    i = e;
	                    return z | 0
	                }
	                c[p >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2];
	                if ((c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) != 7) {
	                    if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) == 1 : 0) {
	                        c[n >> 2] = Sq(c[g >> 2] | 0) | 0;
	                        c[o >> 2] = c[(c[n >> 2] | 0) + 4 >> 2];
	                        c[p >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2];
	                        c[q >> 2] = c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2];
	                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 0;
	                        if ((c[o >> 2] | 0) != 0 ? (c[c[o >> 2] >> 2] | 0) != 0 : 0) {
	                            c[y >> 2] = 0;
	                            c[x >> 2] = $q(0) | 0;
	                            c[r >> 2] = 0;
	                            while (1) {
	                                if ((c[r >> 2] | 0) >= (c[c[o >> 2] >> 2] | 0))break;
	                                c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[(c[(c[o >> 2] | 0) + 8 >> 2] | 0) + (c[r >> 2] << 2) >> 2];
	                                if ((c[(c[(c[(c[o >> 2] | 0) + 8 >> 2] | 0) + (c[r >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0) != 18 ? (c[(c[(c[(c[o >> 2] | 0) + 8 >> 2] | 0) + (c[r >> 2] << 2) >> 2] | 0) + 32 >> 2] | 0) != 0 : 0)c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2] = c[(c[(c[(c[o >> 2] | 0) + 8 >> 2] | 0) + (c[r >> 2] << 2) >> 2] | 0) + 32 >> 2];
	                                if (c[y >> 2] | 0) {
	                                    if ((dr(c[(c[y >> 2] | 0) + 4 >> 2] | 0, c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) | 0) < 0)c[(c[g >> 2] | 0) + 8 >> 2] = 15
	                                } else c[y >> 2] = yt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) | 0;
	                                Tq(c[g >> 2] | 0, c[y >> 2] | 0) | 0;
	                                c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] = c[c[o >> 2] >> 2];
	                                c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2] = (c[r >> 2] | 0) + 1;
	                                if ((c[(c[h >> 2] | 0) + 8 >> 2] | 0) != -1) {
	                                    s = iu(c[g >> 2] | 0, (c[(c[l >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[h >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) | 0) | 0;
	                                    c[k >> 2] = (c[k >> 2] | 0) + s
	                                }
	                                if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                                    A = 85;
	                                    break
	                                }
	                                c[m >> 2] = Sq(c[g >> 2] | 0) | 0;
	                                do if (Ns(c[g >> 2] | 0, c[m >> 2] | 0) | 0) {
	                                    if ((cr(c[x >> 2] | 0, c[(c[(c[o >> 2] | 0) + 8 >> 2] | 0) + (c[r >> 2] << 2) >> 2] | 0) | 0) >= 0)break;
	                                    c[(c[g >> 2] | 0) + 8 >> 2] = 15
	                                } while (0);
	                                if (c[m >> 2] | 0)jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[m >> 2] | 0);
	                                if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) == (c[y >> 2] | 0)) {
	                                    Sq(c[g >> 2] | 0) | 0;
	                                    su(c[(c[y >> 2] | 0) + 4 >> 2] | 0, 1)
	                                } else c[y >> 2] = 0;
	                                c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 0;
	                                if ((c[c[x >> 2] >> 2] | 0) > 0) {
	                                    A = 95;
	                                    break
	                                }
	                                c[r >> 2] = (c[r >> 2] | 0) + 1
	                            }
	                            if ((A | 0) == 85) {
	                                fr(c[x >> 2] | 0);
	                                Qq(c[n >> 2] | 0);
	                                c[f >> 2] = 0;
	                                z = c[f >> 2] | 0;
	                                i = e;
	                                return z | 0
	                            } else if ((A | 0) == 95)c[c[j >> 2] >> 2] = c[c[(c[x >> 2] | 0) + 8 >> 2] >> 2];
	                            if (c[y >> 2] | 0)jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[y >> 2] | 0);
	                            jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[n >> 2] | 0);
	                            c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 0;
	                            c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] = -1;
	                            c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2] = -1;
	                            c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2] = c[q >> 2];
	                            q = c[g >> 2] | 0;
	                            Tq(q, At(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[x >> 2] | 0) | 0) | 0
	                        } else A = 71;
	                        if ((A | 0) == 71 ? (c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] = 0, c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2] = 0, Tq(c[g >> 2] | 0, c[n >> 2] | 0) | 0, c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[p >> 2], (c[(c[g >> 2] | 0) + 8 >> 2] | 0) != 0) : 0) {
	                            c[f >> 2] = 0;
	                            z = c[f >> 2] | 0;
	                            i = e;
	                            return z | 0
	                        }
	                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[p >> 2];
	                        c[f >> 2] = c[k >> 2];
	                        z = c[f >> 2] | 0;
	                        i = e;
	                        return z | 0
	                    }
	                    Nq(c[g >> 2] | 0, 11);
	                    c[f >> 2] = 0;
	                    z = c[f >> 2] | 0;
	                    i = e;
	                    return z | 0
	                }
	                c[u >> 2] = 0;
	                c[v >> 2] = 0;
	                if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) == 7 : 0) {
	                    c[n >> 2] = Sq(c[g >> 2] | 0) | 0;
	                    c[w >> 2] = c[(c[n >> 2] | 0) + 28 >> 2];
	                    c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 0;
	                    if ((c[w >> 2] | 0) != 0 ? (c[c[w >> 2] >> 2] | 0) != 0 : 0) {
	                        c[v >> 2] = bv(0) | 0;
	                        c[r >> 2] = 0;
	                        while (1) {
	                            if ((c[r >> 2] | 0) >= (c[c[w >> 2] >> 2] | 0))break;
	                            c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[(c[(c[(c[w >> 2] | 0) + 8 >> 2] | 0) + (c[r >> 2] << 2) >> 2] | 0) + 28 >> 2];
	                            c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] = c[c[w >> 2] >> 2];
	                            c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2] = (c[r >> 2] | 0) + 1;
	                            if (c[u >> 2] | 0) {
	                                if ((dr(c[(c[u >> 2] | 0) + 4 >> 2] | 0, c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) | 0) < 0)c[(c[g >> 2] | 0) + 8 >> 2] = 15
	                            } else c[u >> 2] = yt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) | 0;
	                            Tq(c[g >> 2] | 0, c[u >> 2] | 0) | 0;
	                            if ((c[(c[h >> 2] | 0) + 8 >> 2] | 0) != -1) {
	                                x = iu(c[g >> 2] | 0, (c[(c[l >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[h >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) | 0) | 0;
	                                c[k >> 2] = (c[k >> 2] | 0) + x
	                            }
	                            if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                                A = 52;
	                                break
	                            }
	                            c[m >> 2] = Sq(c[g >> 2] | 0) | 0;
	                            if (Ns(c[g >> 2] | 0, c[m >> 2] | 0) | 0) {
	                                x = c[v >> 2] | 0;
	                                cv(x, lt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[w >> 2] | 0) + 8 >> 2] | 0) + (c[r >> 2] << 2) >> 2] | 0) | 0)
	                            }
	                            if (c[m >> 2] | 0)jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[m >> 2] | 0);
	                            if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) == (c[u >> 2] | 0)) {
	                                Sq(c[g >> 2] | 0) | 0;
	                                su(c[(c[u >> 2] | 0) + 4 >> 2] | 0, 1)
	                            } else c[u >> 2] = 0;
	                            c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 0;
	                            B = c[r >> 2] | 0;
	                            if ((c[c[v >> 2] >> 2] | 0) > 0) {
	                                A = 61;
	                                break
	                            }
	                            c[r >> 2] = B + 1
	                        }
	                        if ((A | 0) == 52) {
	                            Qq(c[n >> 2] | 0);
	                            c[f >> 2] = 0;
	                            z = c[f >> 2] | 0;
	                            i = e;
	                            return z | 0
	                        } else if ((A | 0) == 61)c[c[j >> 2] >> 2] = c[(c[(c[(c[w >> 2] | 0) + 8 >> 2] | 0) + (B << 2) >> 2] | 0) + 28 >> 2];
	                        if (c[u >> 2] | 0)jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[u >> 2] | 0);
	                        jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[n >> 2] | 0);
	                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 0;
	                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] = -1;
	                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2] = -1;
	                        u = c[g >> 2] | 0;
	                        Tq(u, hv(c[v >> 2] | 0) | 0) | 0;
	                        c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[p >> 2];
	                        c[f >> 2] = c[k >> 2];
	                        z = c[f >> 2] | 0;
	                        i = e;
	                        return z | 0
	                    }
	                    c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] = 0;
	                    c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2] = 0;
	                    if ((c[(c[h >> 2] | 0) + 8 >> 2] | 0) != -1) {
	                        p = iu(c[g >> 2] | 0, (c[(c[l >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[h >> 2] | 0) + 8 >> 2] | 0) * 40 | 0) | 0) | 0;
	                        c[k >> 2] = (c[k >> 2] | 0) + p
	                    }
	                    c[m >> 2] = Sq(c[g >> 2] | 0) | 0;
	                    if (c[m >> 2] | 0)jt(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[m >> 2] | 0);
	                    Tq(c[g >> 2] | 0, c[n >> 2] | 0) | 0;
	                    if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                        c[f >> 2] = 0;
	                        z = c[f >> 2] | 0;
	                        i = e;
	                        return z | 0
	                    } else {
	                        c[f >> 2] = c[k >> 2];
	                        z = c[f >> 2] | 0;
	                        i = e;
	                        return z | 0
	                    }
	                }
	                Nq(c[g >> 2] | 0, 11);
	                c[f >> 2] = 0;
	                z = c[f >> 2] | 0;
	                i = e;
	                return z | 0
	            }

	            function Du(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                Gu(c[e >> 2] | 0);
	                if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                    i = b;
	                    return
	                }
	                a:while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    a = c[e >> 2] | 0;
	                    if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1
	                }
	                b:while (1) {
	                    if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 43 ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 45 : 0) {
	                        h = 30;
	                        break
	                    }
	                    c[g >> 2] = c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2];
	                    if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 43)c[f >> 2] = 1; else c[f >> 2] = 0;
	                    a = c[e >> 2] | 0;
	                    if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[a >> 2] = (c[a >> 2] | 0) + 1;
	                    while (1) {
	                        do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)j = 1; else {
	                            if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                j = 1;
	                                break
	                            }
	                            j = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        k = c[e >> 2] | 0;
	                        if (!j)break;
	                        a = c[e >> 2] | 0;
	                        if (!(d[c[k >> 2] >> 0] | 0))continue;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1
	                    }
	                    Gu(k);
	                    if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                        h = 30;
	                        break
	                    }
	                    du(c[(c[e >> 2] | 0) + 32 >> 2] | 0, c[g >> 2] | 0, c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2] | 0, 5, c[f >> 2] | 0, 0, 0, 0, 0) | 0;
	                    while (1) {
	                        do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)continue b
	                        } while (0);
	                        a = c[e >> 2] | 0;
	                        if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1
	                    }
	                }
	                if ((h | 0) == 30) {
	                    i = b;
	                    return
	                }
	            }

	            function Eu(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](12) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    it(0, 128632);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = c[f >> 2] | 0;
	                c[a + 0 >> 2] = 0;
	                c[a + 4 >> 2] = 0;
	                c[a + 8 >> 2] = 0;
	                if ((c[e >> 2] | 0) < 10)c[e >> 2] = 10;
	                a = Cb[c[135744 >> 2] & 511](c[e >> 2] << 2) | 0;
	                c[(c[f >> 2] | 0) + 8 >> 2] = a;
	                if (!(c[(c[f >> 2] | 0) + 8 >> 2] | 0)) {
	                    it(0, 128632);
	                    zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    cU(c[(c[f >> 2] | 0) + 8 >> 2] | 0, 0, c[e >> 2] << 2 | 0) | 0;
	                    c[(c[f >> 2] | 0) + 4 >> 2] = c[e >> 2];
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function Fu(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if (!(c[f >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                if ((c[c[f >> 2] >> 2] | 0) <= 0) {
	                    i = e;
	                    return
	                }
	                if ((c[g >> 2] | 0) >= (c[c[f >> 2] >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                a:do if (c[h >> 2] | 0) {
	                    c[j >> 2] = c[g >> 2];
	                    while (1) {
	                        if ((c[j >> 2] | 0) >= (c[c[f >> 2] >> 2] | 0))break a;
	                        c[k >> 2] = c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + (c[j >> 2] << 2) >> 2];
	                        if ((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 18 : 0)_q(c[k >> 2] | 0);
	                        c[j >> 2] = (c[j >> 2] | 0) + 1
	                    }
	                } while (0);
	                c[c[f >> 2] >> 2] = c[g >> 2];
	                i = e;
	                return
	            }

	            function Gu(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                Hu(c[e >> 2] | 0);
	                if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                    i = b;
	                    return
	                }
	                a:while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    a = c[e >> 2] | 0;
	                    if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1
	                }
	                b:while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 42) {
	                        if (((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 100 ? (d[(c[c[e >> 2] >> 2] | 0) + 1 >> 0] | 0 | 0) == 105 : 0) ? (d[(c[c[e >> 2] >> 2] | 0) + 2 >> 0] | 0 | 0) == 118 : 0)break;
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 109) {
	                            h = 37;
	                            break b
	                        }
	                        if ((d[(c[c[e >> 2] >> 2] | 0) + 1 >> 0] | 0 | 0) != 111) {
	                            h = 37;
	                            break b
	                        }
	                        if ((d[(c[c[e >> 2] >> 2] | 0) + 2 >> 0] | 0 | 0) != 100) {
	                            h = 37;
	                            break b
	                        }
	                    } while (0);
	                    c[f >> 2] = -1;
	                    c[g >> 2] = c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2];
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 42) {
	                        c[f >> 2] = 0;
	                        a = c[e >> 2] | 0;
	                        if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[a >> 2] = (c[a >> 2] | 0) + 1
	                    } else {
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 100) {
	                            c[f >> 2] = 1;
	                            a = c[e >> 2] | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 3;
	                            break
	                        }
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 109) {
	                            c[f >> 2] = 2;
	                            a = c[e >> 2] | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 3
	                        }
	                    } while (0);
	                    while (1) {
	                        do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)j = 1; else {
	                            if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                j = 1;
	                                break
	                            }
	                            j = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        k = c[e >> 2] | 0;
	                        if (!j)break;
	                        a = c[e >> 2] | 0;
	                        if (!(d[c[k >> 2] >> 0] | 0))continue;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1
	                    }
	                    Hu(k);
	                    if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                        h = 37;
	                        break
	                    }
	                    du(c[(c[e >> 2] | 0) + 32 >> 2] | 0, c[g >> 2] | 0, c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2] | 0, 6, c[f >> 2] | 0, 0, 0, 0, 0) | 0;
	                    while (1) {
	                        do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)continue b
	                        } while (0);
	                        a = c[e >> 2] | 0;
	                        if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1
	                    }
	                }
	                if ((h | 0) == 37) {
	                    i = b;
	                    return
	                }
	            }

	            function Hu(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                c[g >> 2] = 0;
	                a:while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    a = c[e >> 2] | 0;
	                    if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1
	                }
	                b:while (1) {
	                    if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 45)break;
	                    c[f >> 2] = 1 - (c[f >> 2] | 0);
	                    c[g >> 2] = 1;
	                    a = c[e >> 2] | 0;
	                    if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[a >> 2] = (c[a >> 2] | 0) + 1;
	                    while (1) {
	                        do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)continue b
	                        } while (0);
	                        a = c[e >> 2] | 0;
	                        if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1
	                    }
	                }
	                Iu(c[e >> 2] | 0);
	                if (!((c[g >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 8 >> 2] | 0) == 0 : 0)) {
	                    i = b;
	                    return
	                }
	                g = c[(c[e >> 2] | 0) + 32 >> 2] | 0;
	                a = c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2] | 0;
	                if (c[f >> 2] | 0) {
	                    du(g, a, -1, 5, 2, 0, 0, 0, 0) | 0;
	                    i = b;
	                    return
	                } else {
	                    du(g, a, -1, 5, 3, 0, 0, 0, 0) | 0;
	                    i = b;
	                    return
	                }
	            }

	            function Iu(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                Ju(c[e >> 2] | 0);
	                if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                    i = b;
	                    return
	                }
	                a:while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    a = c[e >> 2] | 0;
	                    if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1
	                }
	                b:while (1) {
	                    if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 124)break;
	                    c[f >> 2] = c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2];
	                    du(c[(c[e >> 2] | 0) + 32 >> 2] | 0, -1, -1, 9, 0, 0, 0, 0, 0) | 0;
	                    a = c[e >> 2] | 0;
	                    if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[a >> 2] = (c[a >> 2] | 0) + 1;
	                    while (1) {
	                        do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)g = 1; else {
	                            if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                g = 1;
	                                break
	                            }
	                            g = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        h = c[e >> 2] | 0;
	                        if (!g)break;
	                        a = c[e >> 2] | 0;
	                        if (!(d[c[h >> 2] >> 0] | 0))continue;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1
	                    }
	                    Ju(h);
	                    du(c[(c[e >> 2] | 0) + 32 >> 2] | 0, c[f >> 2] | 0, c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2] | 0, 7, 0, 0, 0, 0, 0) | 0;
	                    while (1) {
	                        do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)continue b
	                        } while (0);
	                        a = c[e >> 2] | 0;
	                        if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1
	                    }
	                }
	                i = b;
	                return
	            }

	            function Ju(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                g = b + 4 | 0;
	                h = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 1;
	                c[g >> 2] = 0;
	                while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)j = 1; else {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            j = 1;
	                            break
	                        }
	                        j = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                    } while (0);
	                    k = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                    if (!j)break;
	                    a = c[e >> 2] | 0;
	                    if (!k)continue;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1
	                }
	                do if ((k | 0) != 36 ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 40 : 0) {
	                    if (48 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 57 : 0) {
	                        l = 18;
	                        break
	                    }
	                    if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 39 ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 34 : 0) {
	                        if (((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 46 ? 48 <= (d[(c[c[e >> 2] >> 2] | 0) + 1 >> 0] | 0 | 0) : 0) ? (d[(c[c[e >> 2] >> 2] | 0) + 1 >> 0] | 0 | 0) <= 57 : 0) {
	                            l = 18;
	                            break
	                        }
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 42) {
	                            c[f >> 2] = 1;
	                            break
	                        }
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 47) {
	                            c[f >> 2] = 1;
	                            break
	                        }
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 64) {
	                            c[f >> 2] = 1;
	                            break
	                        }
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 46) {
	                            c[f >> 2] = 1;
	                            break
	                        }
	                        while (1) {
	                            do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)m = 1; else {
	                                if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                    m = 1;
	                                    break
	                                }
	                                m = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                            } while (0);
	                            n = c[e >> 2] | 0;
	                            if (!m)break;
	                            j = c[e >> 2] | 0;
	                            if (!(d[c[n >> 2] >> 0] | 0))continue;
	                            c[j >> 2] = (c[j >> 2] | 0) + 1
	                        }
	                        c[g >> 2] = Ku(n) | 0;
	                        if ((c[g >> 2] | 0) != 0 ? (wy(c[g >> 2] | 0, 130432) | 0) != 0 : 0) {
	                            c[f >> 2] = 1;
	                            zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                            break
	                        }
	                        if (!(c[g >> 2] | 0)) {
	                            Nq(c[e >> 2] | 0, 7);
	                            i = b;
	                            return
	                        }
	                        c[h >> 2] = xy(c[g >> 2] | 0) | 0;
	                        a:while (1) {
	                            if (!(d[(c[c[e >> 2] >> 2] | 0) + (c[h >> 2] | 0) >> 0] | 0))break;
	                            if ((d[(c[c[e >> 2] >> 2] | 0) + (c[h >> 2] | 0) >> 0] | 0 | 0) == 47) {
	                                l = 41;
	                                break
	                            }
	                            do if ((d[(c[c[e >> 2] >> 2] | 0) + (c[h >> 2] | 0) >> 0] | 0 | 0) != 32) {
	                                if (9 <= (d[(c[c[e >> 2] >> 2] | 0) + (c[h >> 2] | 0) >> 0] | 0 | 0) ? (d[(c[c[e >> 2] >> 2] | 0) + (c[h >> 2] | 0) >> 0] | 0 | 0) <= 10 : 0)break;
	                                if ((d[(c[c[e >> 2] >> 2] | 0) + (c[h >> 2] | 0) >> 0] | 0 | 0) != 13) {
	                                    l = 46;
	                                    break a
	                                }
	                            } while (0);
	                            c[h >> 2] = (c[h >> 2] | 0) + 1
	                        }
	                        b:do if ((l | 0) == 41)c[f >> 2] = 1; else if ((l | 0) == 46) {
	                            if ((d[(c[c[e >> 2] >> 2] | 0) + (c[h >> 2] | 0) >> 0] | 0 | 0) == 58) {
	                                c[f >> 2] = 1;
	                                break
	                            }
	                            if ((d[(c[c[e >> 2] >> 2] | 0) + (c[h >> 2] | 0) >> 0] | 0 | 0) == 40)if (Ms(c[g >> 2] | 0) | 0) {
	                                c[f >> 2] = 1;
	                                break
	                            } else {
	                                c[f >> 2] = 0;
	                                break
	                            }
	                            if ((d[(c[c[e >> 2] >> 2] | 0) + (c[h >> 2] | 0) >> 0] | 0 | 0) == 91) {
	                                c[f >> 2] = 1;
	                                break
	                            }
	                            do if ((d[(c[c[e >> 2] >> 2] | 0) + (c[h >> 2] | 0) >> 0] | 0 | 0) != 60 ? (d[(c[c[e >> 2] >> 2] | 0) + (c[h >> 2] | 0) >> 0] | 0 | 0) != 62 : 0) {
	                                if ((d[(c[c[e >> 2] >> 2] | 0) + (c[h >> 2] | 0) >> 0] | 0 | 0) == 61)break;
	                                c[f >> 2] = 1;
	                                break b
	                            } while (0);
	                            c[f >> 2] = 1
	                        } while (0);
	                        if (!(d[(c[c[e >> 2] >> 2] | 0) + (c[h >> 2] | 0) >> 0] | 0))c[f >> 2] = 1;
	                        zb[c[135736 >> 2] & 511](c[g >> 2] | 0)
	                    } else l = 18
	                } else l = 18; while (0);
	                if ((l | 0) == 18)c[f >> 2] = 0;
	                l = c[e >> 2] | 0;
	                do if (!(c[f >> 2] | 0)) {
	                    Mu(l);
	                    if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                        i = b;
	                        return
	                    }
	                    if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 47 ? (d[(c[c[e >> 2] >> 2] | 0) + 1 >> 0] | 0 | 0) == 47 : 0) {
	                        g = c[e >> 2] | 0;
	                        c[g >> 2] = (c[g >> 2] | 0) + 2;
	                        while (1) {
	                            do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)o = 1; else {
	                                if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                    o = 1;
	                                    break
	                                }
	                                o = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                            } while (0);
	                            p = c[e >> 2] | 0;
	                            if (!o)break;
	                            g = c[e >> 2] | 0;
	                            if (!(d[c[p >> 2] >> 0] | 0))continue;
	                            c[g >> 2] = (c[g >> 2] | 0) + 1
	                        }
	                        du(c[p + 32 >> 2] | 0, c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2] | 0, -1, 11, 6, 1, 0, 0, 0) | 0;
	                        du(c[(c[e >> 2] | 0) + 32 >> 2] | 0, c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2] | 0, -1, 10, 1, 0, 0, 0, 0) | 0;
	                        Nu(c[e >> 2] | 0);
	                        break
	                    }
	                    if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 47)Nu(c[e >> 2] | 0)
	                } else {
	                    g = c[(c[e >> 2] | 0) + 32 >> 2] | 0;
	                    if ((d[c[l >> 2] >> 0] | 0 | 0) == 47)du(g, -1, -1, 8, 0, 0, 0, 0, 0) | 0; else du(g, -1, -1, 9, 0, 0, 0, 0, 0) | 0;
	                    Lu(c[e >> 2] | 0)
	                } while (0);
	                c:while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)break c
	                    } while (0);
	                    l = c[e >> 2] | 0;
	                    if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                    c[l >> 2] = (c[l >> 2] | 0) + 1
	                }
	                i = b;
	                return
	            }

	            function Ku(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 24 | 0;
	                e = b + 20 | 0;
	                f = b + 16 | 0;
	                g = b + 12 | 0;
	                h = b + 8 | 0;
	                j = b + 4 | 0;
	                k = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                c[j >> 2] = c[c[e >> 2] >> 2];
	                c[h >> 2] = bu(c[e >> 2] | 0, g) | 0;
	                a:do if (!((c[h >> 2] | 0) == 32 | (c[h >> 2] | 0) == 62 | (c[h >> 2] | 0) == 47)) {
	                    a = c[h >> 2] | 0;
	                    if ((c[h >> 2] | 0) < 256) {
	                        if (((!(65 <= (a | 0) & (c[h >> 2] | 0) <= 90) ? !(97 <= (c[h >> 2] | 0) & (c[h >> 2] | 0) <= 122) : 0) ? !(192 <= (c[h >> 2] | 0) & (c[h >> 2] | 0) <= 214) : 0) ? !(216 <= (c[h >> 2] | 0) & (c[h >> 2] | 0) <= 246 | 248 <= (c[h >> 2] | 0)) : 0)l = 8
	                    } else if (!(DQ(a, 199744) | 0))l = 8;
	                    do if ((l | 0) == 8) {
	                        a = c[h >> 2] | 0;
	                        if ((c[h >> 2] | 0) < 256)if ((a | 0) != 95 & (c[h >> 2] | 0) != 58)break a; else break;
	                        if (!(19968 <= (a | 0) & (c[h >> 2] | 0) <= 40869 | (c[h >> 2] | 0) == 12295) ? (12321 <= (c[h >> 2] | 0) & (c[h >> 2] | 0) <= 12329 ^ 1) & (c[h >> 2] | 0) != 95 & (c[h >> 2] | 0) != 58 : 0)break a
	                    } while (0);
	                    b:while (1) {
	                        if (!((c[h >> 2] | 0) != 32 & (c[h >> 2] | 0) != 62 & (c[h >> 2] | 0) != 47))break;
	                        a = c[h >> 2] | 0;
	                        if ((c[h >> 2] | 0) < 256) {
	                            if (((!(65 <= (a | 0) & (c[h >> 2] | 0) <= 90) ? !(97 <= (c[h >> 2] | 0) & (c[h >> 2] | 0) <= 122) : 0) ? !(192 <= (c[h >> 2] | 0) & (c[h >> 2] | 0) <= 214) : 0) ? !(216 <= (c[h >> 2] | 0) & (c[h >> 2] | 0) <= 246 | 248 <= (c[h >> 2] | 0)) : 0)l = 20
	                        } else if (!(DQ(a, 199744) | 0))l = 20;
	                        do if ((l | 0) == 20) {
	                            l = 0;
	                            if ((c[h >> 2] | 0) >= 256) {
	                                if (19968 <= (c[h >> 2] | 0) & (c[h >> 2] | 0) <= 40869 | (c[h >> 2] | 0) == 12295)break;
	                                if (12321 <= (c[h >> 2] | 0) & (c[h >> 2] | 0) <= 12329)break
	                            }
	                            a = c[h >> 2] | 0;
	                            if ((c[h >> 2] | 0) < 256) {
	                                if (48 <= (a | 0) & (c[h >> 2] | 0) <= 57 | (c[h >> 2] | 0) == 46 | (c[h >> 2] | 0) == 45 | (c[h >> 2] | 0) == 95 | (c[h >> 2] | 0) == 58)break
	                            } else {
	                                m = (DQ(a, 200216) | 0) != 0;
	                                if (m | (c[h >> 2] | 0) == 46 | (c[h >> 2] | 0) == 45 | (c[h >> 2] | 0) == 95 | (c[h >> 2] | 0) == 58)break
	                            }
	                            if ((c[h >> 2] | 0) >= 256 ? (DQ(c[h >> 2] | 0, 200144) | 0) != 0 : 0)break;
	                            m = c[h >> 2] | 0;
	                            if ((c[h >> 2] | 0) < 256)n = (m | 0) == 183 & 1; else n = DQ(m, 200272) | 0;
	                            if (!n)break b
	                        } while (0);
	                        c[f >> 2] = (c[f >> 2] | 0) + (c[g >> 2] | 0);
	                        m = c[e >> 2] | 0;
	                        c[m >> 2] = (c[m >> 2] | 0) + (c[g >> 2] | 0);
	                        c[h >> 2] = bu(c[e >> 2] | 0, g) | 0
	                    }
	                    c[k >> 2] = ly(c[j >> 2] | 0, (c[c[e >> 2] >> 2] | 0) - (c[j >> 2] | 0) | 0) | 0;
	                    c[c[e >> 2] >> 2] = c[j >> 2];
	                    c[d >> 2] = c[k >> 2];
	                    o = c[d >> 2] | 0;
	                    i = b;
	                    return o | 0
	                } while (0);
	                c[d >> 2] = 0;
	                o = c[d >> 2] | 0;
	                i = b;
	                return o | 0
	            }

	            function Lu(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b;
	                c[e >> 2] = a;
	                while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)f = 1; else {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            f = 1;
	                            break
	                        }
	                        f = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                    } while (0);
	                    g = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                    if (!f)break;
	                    a = c[e >> 2] | 0;
	                    if (!g)continue;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1
	                }
	                if ((g | 0) != 47) {
	                    Nu(c[e >> 2] | 0);
	                    i = b;
	                    return
	                }
	                while (1) {
	                    if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 47) {
	                        h = 44;
	                        break
	                    }
	                    if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 47 ? (d[(c[c[e >> 2] >> 2] | 0) + 1 >> 0] | 0 | 0) == 47 : 0) {
	                        g = c[e >> 2] | 0;
	                        c[g >> 2] = (c[g >> 2] | 0) + 2;
	                        while (1) {
	                            do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)j = 1; else {
	                                if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                    j = 1;
	                                    break
	                                }
	                                j = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                            } while (0);
	                            k = c[e >> 2] | 0;
	                            if (!j)break;
	                            g = c[e >> 2] | 0;
	                            if (!(d[c[k >> 2] >> 0] | 0))continue;
	                            c[g >> 2] = (c[g >> 2] | 0) + 1
	                        }
	                        du(c[k + 32 >> 2] | 0, c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2] | 0, -1, 11, 6, 1, 0, 0, 0) | 0;
	                        Nu(c[e >> 2] | 0)
	                    } else h = 23;
	                    a:do if ((h | 0) == 23 ? (h = 0, (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 47) : 0) {
	                        g = c[e >> 2] | 0;
	                        if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[g >> 2] = (c[g >> 2] | 0) + 1;
	                        while (1) {
	                            do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)l = 1; else {
	                                if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                    l = 1;
	                                    break
	                                }
	                                l = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                            } while (0);
	                            m = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 0;
	                            if (!l)break;
	                            g = c[e >> 2] | 0;
	                            if (!m)continue;
	                            c[g >> 2] = (c[g >> 2] | 0) + 1
	                        }
	                        if (m) {
	                            if (!(65 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 90 : 0))h = 36;
	                            do if ((h | 0) == 36) {
	                                h = 0;
	                                if (97 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 122 : 0)break;
	                                if ((((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 95 ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 46 : 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 64 : 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 42 : 0)break a
	                            } while (0);
	                            Nu(c[e >> 2] | 0)
	                        }
	                    } while (0);
	                    if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                        h = 44;
	                        break
	                    }
	                }
	                if ((h | 0) == 44) {
	                    i = b;
	                    return
	                }
	            }

	            function Mu(a) {
	                a = a | 0;
	                var b = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b;
	                c[e >> 2] = a;
	                Ou(c[e >> 2] | 0);
	                if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                    i = b;
	                    return
	                }
	                a:while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    a = c[e >> 2] | 0;
	                    if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1
	                }
	                b:while (1) {
	                    if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 91)break;
	                    Pu(c[e >> 2] | 0, 1);
	                    while (1) {
	                        do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)continue b
	                        } while (0);
	                        a = c[e >> 2] | 0;
	                        if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1
	                    }
	                }
	                i = b;
	                return
	            }

	            function Nu(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b;
	                c[e >> 2] = a;
	                while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)f = 1; else {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            f = 1;
	                            break
	                        }
	                        f = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                    } while (0);
	                    g = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                    if (!f)break;
	                    a = c[e >> 2] | 0;
	                    if (!g)continue;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1
	                }
	                if ((g | 0) == 47 ? (d[(c[c[e >> 2] >> 2] | 0) + 1 >> 0] | 0 | 0) == 47 : 0) {
	                    g = c[e >> 2] | 0;
	                    c[g >> 2] = (c[g >> 2] | 0) + 2;
	                    while (1) {
	                        do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)h = 1; else {
	                            if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                h = 1;
	                                break
	                            }
	                            h = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        j = c[e >> 2] | 0;
	                        if (!h)break;
	                        g = c[e >> 2] | 0;
	                        if (!(d[c[j >> 2] >> 0] | 0))continue;
	                        c[g >> 2] = (c[g >> 2] | 0) + 1
	                    }
	                    du(c[j + 32 >> 2] | 0, c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2] | 0, -1, 11, 6, 1, 0, 0, 0) | 0
	                } else k = 20;
	                a:do if ((k | 0) == 20 ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 47 : 0) {
	                    j = c[e >> 2] | 0;
	                    if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[j >> 2] = (c[j >> 2] | 0) + 1;
	                    while (1) {
	                        do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)break a
	                        } while (0);
	                        j = c[e >> 2] | 0;
	                        if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                        c[j >> 2] = (c[j >> 2] | 0) + 1
	                    }
	                } while (0);
	                Qu(c[e >> 2] | 0);
	                if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                    i = b;
	                    return
	                }
	                b:while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)break b
	                    } while (0);
	                    j = c[e >> 2] | 0;
	                    if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                    c[j >> 2] = (c[j >> 2] | 0) + 1
	                }
	                c:while (1) {
	                    if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 47)break;
	                    if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 47 ? (d[(c[c[e >> 2] >> 2] | 0) + 1 >> 0] | 0 | 0) == 47 : 0) {
	                        j = c[e >> 2] | 0;
	                        c[j >> 2] = (c[j >> 2] | 0) + 2;
	                        while (1) {
	                            do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)l = 1; else {
	                                if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                    l = 1;
	                                    break
	                                }
	                                l = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                            } while (0);
	                            m = c[e >> 2] | 0;
	                            if (!l)break;
	                            j = c[e >> 2] | 0;
	                            if (!(d[c[m >> 2] >> 0] | 0))continue;
	                            c[j >> 2] = (c[j >> 2] | 0) + 1
	                        }
	                        du(c[m + 32 >> 2] | 0, c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2] | 0, -1, 11, 6, 1, 0, 0, 0) | 0;
	                        Qu(c[e >> 2] | 0)
	                    } else k = 48;
	                    if ((k | 0) == 48 ? (k = 0, (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 47) : 0) {
	                        j = c[e >> 2] | 0;
	                        if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[j >> 2] = (c[j >> 2] | 0) + 1;
	                        while (1) {
	                            do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)n = 1; else {
	                                if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                    n = 1;
	                                    break
	                                }
	                                n = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                            } while (0);
	                            o = c[e >> 2] | 0;
	                            if (!n)break;
	                            j = c[e >> 2] | 0;
	                            if (!(d[c[o >> 2] >> 0] | 0))continue;
	                            c[j >> 2] = (c[j >> 2] | 0) + 1
	                        }
	                        Qu(o)
	                    }
	                    while (1) {
	                        do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)continue c
	                        } while (0);
	                        j = c[e >> 2] | 0;
	                        if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                        c[j >> 2] = (c[j >> 2] | 0) + 1
	                    }
	                }
	                i = b;
	                return
	            }

	            function Ou(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b;
	                c[e >> 2] = a;
	                while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)f = 1; else {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            f = 1;
	                            break
	                        }
	                        f = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                    } while (0);
	                    g = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                    if (!f)break;
	                    a = c[e >> 2] | 0;
	                    if (!g)continue;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1
	                }
	                f = c[e >> 2] | 0;
	                a:do if ((g | 0) == 36)Ru(f); else {
	                    a = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                    if ((d[c[f >> 2] >> 0] | 0 | 0) != 40) {
	                        if (!(48 <= (a | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 57 : 0))h = 34;
	                        do if ((h | 0) == 34) {
	                            if (((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 46 ? 48 <= (d[(c[c[e >> 2] >> 2] | 0) + 1 >> 0] | 0 | 0) : 0) ? (d[(c[c[e >> 2] >> 2] | 0) + 1 >> 0] | 0 | 0) <= 57 : 0)break;
	                            if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 39 ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 34 : 0) {
	                                Uu(c[e >> 2] | 0);
	                                break a
	                            }
	                            Tu(c[e >> 2] | 0);
	                            break a
	                        } while (0);
	                        Su(c[e >> 2] | 0);
	                        break
	                    }
	                    j = c[e >> 2] | 0;
	                    if (a)c[j >> 2] = (c[j >> 2] | 0) + 1;
	                    while (1) {
	                        do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)k = 1; else {
	                            if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                k = 1;
	                                break
	                            }
	                            k = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        l = c[e >> 2] | 0;
	                        if (!k)break;
	                        j = c[e >> 2] | 0;
	                        if (!(d[c[l >> 2] >> 0] | 0))continue;
	                        c[j >> 2] = (c[j >> 2] | 0) + 1
	                    }
	                    Jt(l, 1);
	                    if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                        i = b;
	                        return
	                    }
	                    a = c[e >> 2] | 0;
	                    if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 41) {
	                        Nq(a, 7);
	                        i = b;
	                        return
	                    }
	                    j = c[e >> 2] | 0;
	                    if (d[c[a >> 2] >> 0] | 0)c[j >> 2] = (c[j >> 2] | 0) + 1;
	                    while (1) {
	                        do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)break a
	                        } while (0);
	                        j = c[e >> 2] | 0;
	                        if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                        c[j >> 2] = (c[j >> 2] | 0) + 1
	                    }
	                } while (0);
	                b:while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)break b
	                    } while (0);
	                    l = c[e >> 2] | 0;
	                    if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                    c[l >> 2] = (c[l >> 2] | 0) + 1
	                }
	                i = b;
	                return
	            }

	            function Pu(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = c[(c[(c[f >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2];
	                while (1) {
	                    do if ((d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) == 32)j = 1; else {
	                        if (9 <= (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            j = 1;
	                            break
	                        }
	                        j = (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) == 13
	                    } while (0);
	                    k = d[c[c[f >> 2] >> 2] >> 0] | 0;
	                    if (!j)break;
	                    b = c[f >> 2] | 0;
	                    if (!k)continue;
	                    c[b >> 2] = (c[b >> 2] | 0) + 1
	                }
	                j = c[f >> 2] | 0;
	                if ((k | 0) != 91) {
	                    Nq(j, 6);
	                    i = e;
	                    return
	                }
	                k = c[f >> 2] | 0;
	                if (d[c[j >> 2] >> 0] | 0)c[k >> 2] = (c[k >> 2] | 0) + 1;
	                while (1) {
	                    do if ((d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) == 32)l = 1; else {
	                        if (9 <= (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            l = 1;
	                            break
	                        }
	                        l = (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) == 13
	                    } while (0);
	                    m = c[f >> 2] | 0;
	                    if (!l)break;
	                    k = c[f >> 2] | 0;
	                    if (!(d[c[m >> 2] >> 0] | 0))continue;
	                    c[k >> 2] = (c[k >> 2] | 0) + 1
	                }
	                c[(c[m + 32 >> 2] | 0) + 12 >> 2] = -1;
	                m = c[f >> 2] | 0;
	                if (c[g >> 2] | 0)Jt(m, 1); else Jt(m, 0);
	                if (c[(c[f >> 2] | 0) + 8 >> 2] | 0) {
	                    i = e;
	                    return
	                }
	                if ((d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) != 93) {
	                    Nq(c[f >> 2] | 0, 6);
	                    i = e;
	                    return
	                }
	                m = c[(c[f >> 2] | 0) + 32 >> 2] | 0;
	                l = c[h >> 2] | 0;
	                h = c[(c[(c[f >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2] | 0;
	                if (c[g >> 2] | 0)du(m, l, h, 17, 0, 0, 0, 0, 0) | 0; else du(m, l, h, 16, 0, 0, 0, 0, 0) | 0;
	                h = c[f >> 2] | 0;
	                if (d[c[c[f >> 2] >> 2] >> 0] | 0)c[h >> 2] = (c[h >> 2] | 0) + 1;
	                a:while (1) {
	                    do if ((d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    h = c[f >> 2] | 0;
	                    if (!(d[c[c[f >> 2] >> 2] >> 0] | 0))continue;
	                    c[h >> 2] = (c[h >> 2] | 0) + 1
	                }
	                i = e;
	                return
	            }

	            function Qu(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0;
	                b = i;
	                i = i + 48 | 0;
	                e = b + 32 | 0;
	                f = b + 28 | 0;
	                g = b + 24 | 0;
	                h = b + 20 | 0;
	                j = b + 16 | 0;
	                k = b + 12 | 0;
	                l = b + 8 | 0;
	                m = b + 4 | 0;
	                n = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                c[g >> 2] = -1;
	                while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)o = 1; else {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            o = 1;
	                            break
	                        }
	                        o = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                    } while (0);
	                    p = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                    if (!o)break;
	                    a = c[e >> 2] | 0;
	                    if (!p)continue;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1
	                }
	                if ((p | 0) == 46 ? (d[(c[c[e >> 2] >> 2] | 0) + 1 >> 0] | 0 | 0) == 46 : 0) {
	                    p = c[e >> 2] | 0;
	                    c[p >> 2] = (c[p >> 2] | 0) + 2;
	                    while (1) {
	                        do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)q = 1; else {
	                            if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                q = 1;
	                                break
	                            }
	                            q = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        r = c[e >> 2] | 0;
	                        if (!q)break;
	                        p = c[e >> 2] | 0;
	                        if (!(d[c[r >> 2] >> 0] | 0))continue;
	                        c[p >> 2] = (c[p >> 2] | 0) + 1
	                    }
	                    du(c[r + 32 >> 2] | 0, c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2] | 0, -1, 11, 10, 1, 0, 0, 0) | 0;
	                    i = b;
	                    return
	                }
	                if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 46) {
	                    r = c[e >> 2] | 0;
	                    if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[r >> 2] = (c[r >> 2] | 0) + 1;
	                    a:while (1) {
	                        do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)break a
	                        } while (0);
	                        r = c[e >> 2] | 0;
	                        if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                        c[r >> 2] = (c[r >> 2] | 0) + 1
	                    }
	                    i = b;
	                    return
	                }
	                c[h >> 2] = 0;
	                c[j >> 2] = 0;
	                c[k >> 2] = 0;
	                c[l >> 2] = 0;
	                c[m >> 2] = 0;
	                if (((c[(c[e >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[h >> 2] = Ks(c[e >> 2] | 0) | 0, (c[h >> 2] | 0) != 0) : 0) ? (qy(c[h >> 2] | 0, 130440) | 0) != 0 : 0) {
	                    c[g >> 2] = c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2];
	                    zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                    while (1) {
	                        do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)s = 1; else {
	                            if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                s = 1;
	                                break
	                            }
	                            s = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        t = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                        if (!s)break;
	                        r = c[e >> 2] | 0;
	                        if (!t)continue;
	                        c[r >> 2] = (c[r >> 2] | 0) + 1
	                    }
	                    s = c[e >> 2] | 0;
	                    if ((t | 0) != 40) {
	                        Nq(s, 7);
	                        i = b;
	                        return
	                    }
	                    t = c[e >> 2] | 0;
	                    if (d[c[s >> 2] >> 0] | 0)c[t >> 2] = (c[t >> 2] | 0) + 1;
	                    while (1) {
	                        do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)u = 1; else {
	                            if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                u = 1;
	                                break
	                            }
	                            u = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        v = c[e >> 2] | 0;
	                        if (!u)break;
	                        t = c[e >> 2] | 0;
	                        if (!(d[c[v >> 2] >> 0] | 0))continue;
	                        c[t >> 2] = (c[t >> 2] | 0) + 1
	                    }
	                    Jt(v, 1);
	                    if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                        i = b;
	                        return
	                    }
	                    while (1) {
	                        do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)w = 1; else {
	                            if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                w = 1;
	                                break
	                            }
	                            w = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        x = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                        if (!w)break;
	                        v = c[e >> 2] | 0;
	                        if (!x)continue;
	                        c[v >> 2] = (c[v >> 2] | 0) + 1
	                    }
	                    w = c[e >> 2] | 0;
	                    if ((x | 0) != 41) {
	                        Nq(w, 7);
	                        i = b;
	                        return
	                    }
	                    x = c[e >> 2] | 0;
	                    if (d[c[w >> 2] >> 0] | 0)c[x >> 2] = (c[x >> 2] | 0) + 1;
	                    c[f >> 2] = 1
	                } else {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 42)c[l >> 2] = 4; else {
	                        if (!(c[h >> 2] | 0))c[h >> 2] = Ks(c[e >> 2] | 0) | 0;
	                        if (!(c[h >> 2] | 0)) {
	                            if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 64) {
	                                c[l >> 2] = 4;
	                                break
	                            }
	                            x = c[e >> 2] | 0;
	                            if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[x >> 2] = (c[x >> 2] | 0) + 1;
	                            c[l >> 2] = 3;
	                            break
	                        }
	                        c[l >> 2] = Vu(c[h >> 2] | 0) | 0;
	                        if (!(c[l >> 2] | 0)) {
	                            c[l >> 2] = 4;
	                            break
	                        }
	                        while (1) {
	                            do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)y = 1; else {
	                                if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                    y = 1;
	                                    break
	                                }
	                                y = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                            } while (0);
	                            z = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                            if (!y)break;
	                            x = c[e >> 2] | 0;
	                            if (!z)continue;
	                            c[x >> 2] = (c[x >> 2] | 0) + 1
	                        }
	                        if ((z | 0) == 58 ? (d[(c[c[e >> 2] >> 2] | 0) + 1 >> 0] | 0 | 0) == 58 : 0) {
	                            x = c[e >> 2] | 0;
	                            c[x >> 2] = (c[x >> 2] | 0) + 2;
	                            zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                            c[h >> 2] = 0;
	                            break
	                        }
	                        c[l >> 2] = 4
	                    } while (0);
	                    if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                        zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                        i = b;
	                        return
	                    }
	                    c[h >> 2] = Wu(c[e >> 2] | 0, k, m, j, c[h >> 2] | 0) | 0;
	                    if (!(c[k >> 2] | 0)) {
	                        i = b;
	                        return
	                    }
	                    if ((((c[j >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[(c[(c[e >> 2] | 0) + 12 >> 2] | 0) + 196 >> 2] & 1 | 0) != 0 : 0) ? (sr(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[j >> 2] | 0) | 0) == 0 : 0)Nq(c[e >> 2] | 0, 19)
	                }
	                c[n >> 2] = c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2];
	                c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2] = -1;
	                b:while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)break b
	                    } while (0);
	                    z = c[e >> 2] | 0;
	                    if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                    c[z >> 2] = (c[z >> 2] | 0) + 1
	                }
	                while (1) {
	                    if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 91)break;
	                    Pu(c[e >> 2] | 0, 0)
	                }
	                z = c[(c[e >> 2] | 0) + 32 >> 2] | 0;
	                if (c[f >> 2] | 0) {
	                    du(z, c[g >> 2] | 0, c[n >> 2] | 0, 19, 0, 0, 0, 0, 0) | 0;
	                    i = b;
	                    return
	                } else {
	                    du(z, c[n >> 2] | 0, c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2] | 0, 11, c[l >> 2] | 0, c[k >> 2] | 0, c[m >> 2] | 0, c[j >> 2] | 0, c[h >> 2] | 0) | 0;
	                    i = b;
	                    return
	                }
	            }

	            function Ru(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)h = 1; else {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            h = 1;
	                            break
	                        }
	                        h = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                    } while (0);
	                    j = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                    if (!h)break;
	                    a = c[e >> 2] | 0;
	                    if (!j)continue;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1
	                }
	                h = c[e >> 2] | 0;
	                if ((j | 0) != 36) {
	                    Nq(h, 4);
	                    i = b;
	                    return
	                }
	                j = c[e >> 2] | 0;
	                if (d[c[h >> 2] >> 0] | 0)c[j >> 2] = (c[j >> 2] | 0) + 1;
	                c[f >> 2] = Xu(c[e >> 2] | 0, g) | 0;
	                j = c[e >> 2] | 0;
	                if (!(c[f >> 2] | 0)) {
	                    Nq(j, 4);
	                    i = b;
	                    return
	                }
	                c[(c[j + 32 >> 2] | 0) + 12 >> 2] = -1;
	                du(c[(c[e >> 2] | 0) + 32 >> 2] | 0, c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2] | 0, -1, 13, 0, 0, 0, c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)k = 1; else {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            k = 1;
	                            break
	                        }
	                        k = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                    } while (0);
	                    l = c[e >> 2] | 0;
	                    if (!k)break;
	                    g = c[e >> 2] | 0;
	                    if (!(d[c[l >> 2] >> 0] | 0))continue;
	                    c[g >> 2] = (c[g >> 2] | 0) + 1
	                }
	                if (!(c[l + 12 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (!(c[(c[(c[e >> 2] | 0) + 12 >> 2] | 0) + 196 >> 2] & 2)) {
	                    i = b;
	                    return
	                }
	                Nq(c[e >> 2] | 0, 24);
	                i = b;
	                return
	            }

	            function Su(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0.0;
	                b = i;
	                i = i + 64 | 0;
	                e = b + 48 | 0;
	                f = b + 16 | 0;
	                g = b + 44 | 0;
	                j = b + 40 | 0;
	                k = b + 36 | 0;
	                l = b + 32 | 0;
	                m = b + 8 | 0;
	                n = b + 28 | 0;
	                o = b + 24 | 0;
	                p = b;
	                c[e >> 2] = a;
	                h[f >> 3] = 0.0;
	                c[g >> 2] = 0;
	                c[j >> 2] = 0;
	                c[k >> 2] = 0;
	                c[l >> 2] = 0;
	                if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                    i = b;
	                    return
	                }
	                do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 46) {
	                    if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 57 : 0)break;
	                    Nq(c[e >> 2] | 0, 1);
	                    i = b;
	                    return
	                } while (0);
	                h[f >> 3] = 0.0;
	                while (1) {
	                    if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) < 48)break;
	                    if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) > 57)break;
	                    h[f >> 3] = +h[f >> 3] * 10.0;
	                    c[l >> 2] = (d[c[c[e >> 2] >> 2] >> 0] | 0) - 48;
	                    c[g >> 2] = 1;
	                    a = c[e >> 2] | 0;
	                    if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[a >> 2] = (c[a >> 2] | 0) + 1;
	                    h[m >> 3] = +((c[l >> 2] | 0) >>> 0);
	                    h[f >> 3] = +h[f >> 3] + +h[m >> 3]
	                }
	                a:do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 46) {
	                    c[o >> 2] = 0;
	                    h[p >> 3] = 0.0;
	                    m = c[e >> 2] | 0;
	                    if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[m >> 2] = (c[m >> 2] | 0) + 1;
	                    if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) < 48) {
	                        if (!(c[g >> 2] | 0))q = 18
	                    } else if (!((c[g >> 2] | 0) != 0 ? 1 : (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 57))q = 18;
	                    if ((q | 0) == 18) {
	                        Nq(c[e >> 2] | 0, 1);
	                        i = b;
	                        return
	                    }
	                    while (1) {
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) < 48)break;
	                        if (!((c[o >> 2] | 0) < 20 ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 57 : 0))break;
	                        c[n >> 2] = (d[c[c[e >> 2] >> 2] >> 0] | 0) - 48;
	                        h[p >> 3] = +h[p >> 3] * 10.0 + +(c[n >> 2] | 0);
	                        c[o >> 2] = (c[o >> 2] | 0) + 1;
	                        m = c[e >> 2] | 0;
	                        if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                        c[m >> 2] = (c[m >> 2] | 0) + 1
	                    }
	                    h[p >> 3] = +h[p >> 3] / +h[129232 + (c[o >> 2] << 3) >> 3];
	                    h[f >> 3] = +h[f >> 3] + +h[p >> 3];
	                    while (1) {
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) < 48)break a;
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) > 57)break a;
	                        m = c[e >> 2] | 0;
	                        if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                        c[m >> 2] = (c[m >> 2] | 0) + 1
	                    }
	                } while (0);
	                if (!((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 101 ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 69 : 0)) {
	                    p = c[e >> 2] | 0;
	                    if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[p >> 2] = (c[p >> 2] | 0) + 1;
	                    if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 45) {
	                        c[k >> 2] = 1;
	                        p = c[e >> 2] | 0;
	                        if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[p >> 2] = (c[p >> 2] | 0) + 1
	                    } else if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 43 ? (p = c[e >> 2] | 0, (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 0) : 0)c[p >> 2] = (c[p >> 2] | 0) + 1;
	                    while (1) {
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) < 48)break;
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) > 57)break;
	                        c[j >> 2] = ((c[j >> 2] | 0) * 10 | 0) + ((d[c[c[e >> 2] >> 2] >> 0] | 0) - 48);
	                        p = c[e >> 2] | 0;
	                        if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                        c[p >> 2] = (c[p >> 2] | 0) + 1
	                    }
	                    if (c[k >> 2] | 0)c[j >> 2] = 0 - (c[j >> 2] | 0);
	                    r = +T(10.0, +(+(c[j >> 2] | 0)));
	                    h[f >> 3] = +h[f >> 3] * r
	                }
	                j = c[(c[e >> 2] | 0) + 32 >> 2] | 0;
	                k = c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2] | 0;
	                du(j, k, -1, 12, 3, 0, 0, wt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, +h[f >> 3]) | 0, 0) | 0;
	                i = b;
	                return
	            }

	            function Tu(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                c[g >> 2] = 0;
	                a = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 34) {
	                    h = c[e >> 2] | 0;
	                    if (a)c[h >> 2] = (c[h >> 2] | 0) + 1;
	                    c[f >> 2] = c[c[e >> 2] >> 2];
	                    while (1) {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)j = 9; else if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13 ? 32 > (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) : 0)k = 0; else j = 9;
	                        if ((j | 0) == 9) {
	                            j = 0;
	                            k = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 34
	                        }
	                        l = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                        if (!k)break;
	                        h = c[e >> 2] | 0;
	                        if (!l)continue;
	                        c[h >> 2] = (c[h >> 2] | 0) + 1
	                    }
	                    if (!(9 <= (l | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0))j = 15;
	                    if (((j | 0) == 15 ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13 : 0) ? 32 > (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) : 0) {
	                        Nq(c[e >> 2] | 0, 2);
	                        i = b;
	                        return
	                    }
	                    c[g >> 2] = ly(c[f >> 2] | 0, (c[c[e >> 2] >> 2] | 0) - (c[f >> 2] | 0) | 0) | 0;
	                    l = c[e >> 2] | 0;
	                    if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[l >> 2] = (c[l >> 2] | 0) + 1
	                } else {
	                    l = c[e >> 2] | 0;
	                    if ((a | 0) != 39) {
	                        Nq(l, 3);
	                        i = b;
	                        return
	                    }
	                    a = c[e >> 2] | 0;
	                    if (d[c[l >> 2] >> 0] | 0)c[a >> 2] = (c[a >> 2] | 0) + 1;
	                    c[f >> 2] = c[c[e >> 2] >> 2];
	                    while (1) {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)j = 28; else if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13 ? 32 > (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) : 0)m = 0; else j = 28;
	                        if ((j | 0) == 28) {
	                            j = 0;
	                            m = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 39
	                        }
	                        n = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                        if (!m)break;
	                        a = c[e >> 2] | 0;
	                        if (!n)continue;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1
	                    }
	                    if (!(9 <= (n | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0))j = 34;
	                    if (((j | 0) == 34 ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13 : 0) ? 32 > (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) : 0) {
	                        Nq(c[e >> 2] | 0, 2);
	                        i = b;
	                        return
	                    }
	                    c[g >> 2] = ly(c[f >> 2] | 0, (c[c[e >> 2] >> 2] | 0) - (c[f >> 2] | 0) | 0) | 0;
	                    f = c[e >> 2] | 0;
	                    if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[f >> 2] = (c[f >> 2] | 0) + 1
	                }
	                if (!(c[g >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                f = c[(c[e >> 2] | 0) + 32 >> 2] | 0;
	                j = c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2] | 0;
	                du(f, j, -1, 12, 4, 0, 0, Dt(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[g >> 2] | 0) | 0, 0) | 0;
	                zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                i = b;
	                return
	            }

	            function Uu(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                b = i;
	                i = i + 32 | 0;
	                e = b + 20 | 0;
	                f = b + 16 | 0;
	                g = b + 12 | 0;
	                h = b + 8 | 0;
	                j = b + 4 | 0;
	                k = b;
	                c[e >> 2] = a;
	                c[h >> 2] = 0;
	                c[j >> 2] = 1;
	                c[f >> 2] = Xu(c[e >> 2] | 0, g) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                    Nq(c[e >> 2] | 0, 7);
	                    i = b;
	                    return
	                }
	                while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)l = 1; else {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            l = 1;
	                            break
	                        }
	                        l = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                    } while (0);
	                    m = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                    if (!l)break;
	                    a = c[e >> 2] | 0;
	                    if (!m)continue;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1
	                }
	                l = c[e >> 2] | 0;
	                if ((m | 0) != 40) {
	                    Nq(l, 7);
	                    i = b;
	                    return
	                }
	                m = c[e >> 2] | 0;
	                if (d[c[l >> 2] >> 0] | 0)c[m >> 2] = (c[m >> 2] | 0) + 1;
	                a:while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    m = c[e >> 2] | 0;
	                    if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                    c[m >> 2] = (c[m >> 2] | 0) + 1
	                }
	                if (((c[g >> 2] | 0) == 0 ? (d[c[f >> 2] >> 0] | 0 | 0) == 99 : 0) ? (qy(c[f >> 2] | 0, 129608) | 0) != 0 : 0)c[j >> 2] = 0;
	                c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2] = -1;
	                b:do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 41) {
	                    c:while (1) {
	                        if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))break b;
	                        c[k >> 2] = c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2];
	                        c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2] = -1;
	                        Jt(c[e >> 2] | 0, c[j >> 2] | 0);
	                        if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                            n = 27;
	                            break
	                        }
	                        du(c[(c[e >> 2] | 0) + 32 >> 2] | 0, c[k >> 2] | 0, c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2] | 0, 15, 0, 0, 0, 0, 0) | 0;
	                        c[h >> 2] = (c[h >> 2] | 0) + 1;
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 41)break b;
	                        o = c[e >> 2] | 0;
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 44) {
	                            n = 30;
	                            break
	                        }
	                        m = c[e >> 2] | 0;
	                        if (d[c[o >> 2] >> 0] | 0)c[m >> 2] = (c[m >> 2] | 0) + 1;
	                        while (1) {
	                            do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                                if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                                if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)continue c
	                            } while (0);
	                            m = c[e >> 2] | 0;
	                            if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                            c[m >> 2] = (c[m >> 2] | 0) + 1
	                        }
	                    }
	                    if ((n | 0) == 27) {
	                        zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                        i = b;
	                        return
	                    } else if ((n | 0) == 30) {
	                        Nq(o, 7);
	                        i = b;
	                        return
	                    }
	                } while (0);
	                du(c[(c[e >> 2] | 0) + 32 >> 2] | 0, c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2] | 0, -1, 14, c[h >> 2] | 0, 0, 0, c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                g = c[e >> 2] | 0;
	                if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[g >> 2] = (c[g >> 2] | 0) + 1;
	                d:while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)break d
	                    } while (0);
	                    g = c[e >> 2] | 0;
	                    if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                    c[g >> 2] = (c[g >> 2] | 0) + 1
	                }
	                i = b;
	                return
	            }

	            function Vu(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                switch (d[c[e >> 2] >> 0] | 0 | 0) {
	                    case 110:
	                    {
	                        if (qy(c[e >> 2] | 0, 130600) | 0)c[f >> 2] = 9;
	                        break
	                    }
	                    case 115:
	                    {
	                        if (qy(c[e >> 2] | 0, 130664) | 0)c[f >> 2] = 13;
	                        break
	                    }
	                    case 97:
	                    {
	                        if (qy(c[e >> 2] | 0, 130456) | 0)c[f >> 2] = 1;
	                        if (qy(c[e >> 2] | 0, 130472) | 0)c[f >> 2] = 2;
	                        if (qy(c[e >> 2] | 0, 130496) | 0)c[f >> 2] = 3;
	                        break
	                    }
	                    case 99:
	                    {
	                        if (qy(c[e >> 2] | 0, 130512) | 0)c[f >> 2] = 4;
	                        break
	                    }
	                    case 102:
	                    {
	                        if (qy(c[e >> 2] | 0, 130560) | 0)c[f >> 2] = 7;
	                        if (qy(c[e >> 2] | 0, 130576) | 0)c[f >> 2] = 8;
	                        break
	                    }
	                    case 112:
	                    {
	                        if (qy(c[e >> 2] | 0, 130616) | 0)c[f >> 2] = 10;
	                        if (qy(c[e >> 2] | 0, 130624) | 0)c[f >> 2] = 11;
	                        if (qy(c[e >> 2] | 0, 130640) | 0)c[f >> 2] = 12;
	                        break
	                    }
	                    case 100:
	                    {
	                        if (qy(c[e >> 2] | 0, 130520) | 0)c[f >> 2] = 5;
	                        if (qy(c[e >> 2] | 0, 130536) | 0)c[f >> 2] = 6;
	                        break
	                    }
	                    default:
	                    {
	                    }
	                }
	                i = b;
	                return c[f >> 2] | 0
	            }

	            function Wu(a, b, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h;
	                k = h + 32 | 0;
	                l = h + 28 | 0;
	                m = h + 24 | 0;
	                n = h + 20 | 0;
	                o = h + 16 | 0;
	                p = h + 12 | 0;
	                q = h + 8 | 0;
	                c[l >> 2] = a;
	                c[m >> 2] = b;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                if ((c[m >> 2] | 0) == 0 | (c[n >> 2] | 0) == 0 | (c[o >> 2] | 0) == 0) {
	                    g = c[33976] | 0;
	                    f = c[33980] | 0;
	                    c[j >> 2] = 128552;
	                    c[j + 4 >> 2] = 11124;
	                    Db[g & 511](f, 129448, j);
	                    c[k >> 2] = 0;
	                    r = c[k >> 2] | 0;
	                    i = h;
	                    return r | 0
	                }
	                c[c[n >> 2] >> 2] = 0;
	                c[c[m >> 2] >> 2] = 0;
	                c[c[o >> 2] >> 2] = 0;
	                a:while (1) {
	                    do if ((d[c[c[l >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[c[l >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[l >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[c[l >> 2] >> 2] >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    j = c[l >> 2] | 0;
	                    if (!(d[c[c[l >> 2] >> 2] >> 0] | 0))continue;
	                    c[j >> 2] = (c[j >> 2] | 0) + 1
	                }
	                if ((c[p >> 2] | 0) == 0 ? (d[c[c[l >> 2] >> 2] >> 0] | 0 | 0) == 42 : 0) {
	                    j = c[l >> 2] | 0;
	                    if (d[c[c[l >> 2] >> 2] >> 0] | 0)c[j >> 2] = (c[j >> 2] | 0) + 1;
	                    c[c[m >> 2] >> 2] = 3;
	                    c[k >> 2] = 0;
	                    r = c[k >> 2] | 0;
	                    i = h;
	                    return r | 0
	                }
	                if (!(c[p >> 2] | 0))c[p >> 2] = Ks(c[l >> 2] | 0) | 0;
	                j = c[l >> 2] | 0;
	                if (!(c[p >> 2] | 0)) {
	                    Nq(j, 7);
	                    c[k >> 2] = 0;
	                    r = c[k >> 2] | 0;
	                    i = h;
	                    return r | 0
	                }
	                do if ((d[c[j >> 2] >> 0] | 0 | 0) == 32)s = 1; else {
	                    if (9 <= (d[c[c[l >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[l >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                        s = 1;
	                        break
	                    }
	                    s = (d[c[c[l >> 2] >> 2] >> 0] | 0 | 0) == 13
	                } while (0);
	                c[q >> 2] = s & 1;
	                while (1) {
	                    do if ((d[c[c[l >> 2] >> 2] >> 0] | 0 | 0) == 32)t = 1; else {
	                        if (9 <= (d[c[c[l >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[l >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            t = 1;
	                            break
	                        }
	                        t = (d[c[c[l >> 2] >> 2] >> 0] | 0 | 0) == 13
	                    } while (0);
	                    u = d[c[c[l >> 2] >> 2] >> 0] | 0;
	                    if (!t)break;
	                    s = c[l >> 2] | 0;
	                    if (!u)continue;
	                    c[s >> 2] = (c[s >> 2] | 0) + 1
	                }
	                if ((u | 0) != 40) {
	                    c[c[m >> 2] >> 2] = 5;
	                    do if ((c[q >> 2] | 0) == 0 ? (d[c[c[l >> 2] >> 2] >> 0] | 0 | 0) == 58 : 0) {
	                        u = c[l >> 2] | 0;
	                        if (d[c[c[l >> 2] >> 2] >> 0] | 0)c[u >> 2] = (c[u >> 2] | 0) + 1;
	                        c[c[o >> 2] >> 2] = c[p >> 2];
	                        u = c[l >> 2] | 0;
	                        if ((d[c[c[l >> 2] >> 2] >> 0] | 0 | 0) != 42) {
	                            c[p >> 2] = Ks(u) | 0;
	                            if (c[p >> 2] | 0)break;
	                            Nq(c[l >> 2] | 0, 7);
	                            c[k >> 2] = 0;
	                            r = c[k >> 2] | 0;
	                            i = h;
	                            return r | 0
	                        }
	                        t = c[l >> 2] | 0;
	                        if (d[c[u >> 2] >> 0] | 0)c[t >> 2] = (c[t >> 2] | 0) + 1;
	                        c[c[m >> 2] >> 2] = 3;
	                        c[k >> 2] = 0;
	                        r = c[k >> 2] | 0;
	                        i = h;
	                        return r | 0
	                    } while (0);
	                    c[k >> 2] = c[p >> 2];
	                    r = c[k >> 2] | 0;
	                    i = h;
	                    return r | 0
	                }
	                o = c[l >> 2] | 0;
	                if (d[c[c[l >> 2] >> 2] >> 0] | 0)c[o >> 2] = (c[o >> 2] | 0) + 1;
	                do if (qy(c[p >> 2] | 0, 129416) | 0)c[c[n >> 2] >> 2] = 8; else {
	                    if (qy(c[p >> 2] | 0, 129400) | 0) {
	                        c[c[n >> 2] >> 2] = 0;
	                        break
	                    }
	                    if (qy(c[p >> 2] | 0, 129424) | 0) {
	                        c[c[n >> 2] >> 2] = 7;
	                        break
	                    }
	                    if (qy(c[p >> 2] | 0, 129408) | 0) {
	                        c[c[n >> 2] >> 2] = 3;
	                        break
	                    }
	                    if (c[p >> 2] | 0)zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                    Nq(c[l >> 2] | 0, 7);
	                    c[k >> 2] = 0;
	                    r = c[k >> 2] | 0;
	                    i = h;
	                    return r | 0
	                } while (0);
	                c[c[m >> 2] >> 2] = 1;
	                b:while (1) {
	                    do if ((d[c[c[l >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[c[l >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[l >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[c[l >> 2] >> 2] >> 0] | 0 | 0) != 13)break b
	                    } while (0);
	                    o = c[l >> 2] | 0;
	                    if (!(d[c[c[l >> 2] >> 2] >> 0] | 0))continue;
	                    c[o >> 2] = (c[o >> 2] | 0) + 1
	                }
	                c:do if ((c[c[n >> 2] >> 2] | 0) == 7) {
	                    if (c[p >> 2] | 0)zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                    c[p >> 2] = 0;
	                    if ((d[c[c[l >> 2] >> 2] >> 0] | 0 | 0) != 41) {
	                        c[p >> 2] = Yu(c[l >> 2] | 0) | 0;
	                        if (c[(c[l >> 2] | 0) + 8 >> 2] | 0) {
	                            c[k >> 2] = 0;
	                            r = c[k >> 2] | 0;
	                            i = h;
	                            return r | 0
	                        }
	                        c[c[m >> 2] >> 2] = 2;
	                        while (1) {
	                            do if ((d[c[c[l >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                                if (9 <= (d[c[c[l >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[l >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                                if ((d[c[c[l >> 2] >> 2] >> 0] | 0 | 0) != 13)break c
	                            } while (0);
	                            o = c[l >> 2] | 0;
	                            if (!(d[c[c[l >> 2] >> 2] >> 0] | 0))continue;
	                            c[o >> 2] = (c[o >> 2] | 0) + 1
	                        }
	                    }
	                } while (0);
	                if ((d[c[c[l >> 2] >> 2] >> 0] | 0 | 0) != 41) {
	                    if (c[p >> 2] | 0)zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                    Nq(c[l >> 2] | 0, 8);
	                    c[k >> 2] = 0;
	                    r = c[k >> 2] | 0;
	                    i = h;
	                    return r | 0
	                } else {
	                    m = c[l >> 2] | 0;
	                    if (d[c[c[l >> 2] >> 2] >> 0] | 0)c[m >> 2] = (c[m >> 2] | 0) + 1;
	                    c[k >> 2] = c[p >> 2];
	                    r = c[k >> 2] | 0;
	                    i = h;
	                    return r | 0
	                }
	                return 0
	            }

	            function Xu(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                c[c[g >> 2] >> 2] = 0;
	                c[h >> 2] = Ks(c[f >> 2] | 0) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    j = c[h >> 2] | 0;
	                    i = e;
	                    return j | 0
	                }
	                if ((d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) != 58) {
	                    j = c[h >> 2] | 0;
	                    i = e;
	                    return j | 0
	                }
	                c[c[g >> 2] >> 2] = c[h >> 2];
	                g = c[f >> 2] | 0;
	                if (d[c[c[f >> 2] >> 2] >> 0] | 0)c[g >> 2] = (c[g >> 2] | 0) + 1;
	                c[h >> 2] = Ks(c[f >> 2] | 0) | 0;
	                j = c[h >> 2] | 0;
	                i = e;
	                return j | 0
	            }

	            function Yu(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                g = b + 4 | 0;
	                h = b;
	                c[f >> 2] = a;
	                c[h >> 2] = 0;
	                a = d[c[c[f >> 2] >> 2] >> 0] | 0;
	                if ((d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) == 34) {
	                    j = c[f >> 2] | 0;
	                    if (a)c[j >> 2] = (c[j >> 2] | 0) + 1;
	                    c[g >> 2] = c[c[f >> 2] >> 2];
	                    while (1) {
	                        if (9 <= (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)k = 9; else if ((d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) != 13 ? 32 > (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) : 0)l = 0; else k = 9;
	                        if ((k | 0) == 9) {
	                            k = 0;
	                            l = (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) != 34
	                        }
	                        m = d[c[c[f >> 2] >> 2] >> 0] | 0;
	                        if (!l)break;
	                        j = c[f >> 2] | 0;
	                        if (!m)continue;
	                        c[j >> 2] = (c[j >> 2] | 0) + 1
	                    }
	                    if (!(9 <= (m | 0) ? (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0))k = 15;
	                    if (((k | 0) == 15 ? (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) != 13 : 0) ? 32 > (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) : 0) {
	                        Nq(c[f >> 2] | 0, 2);
	                        c[e >> 2] = 0;
	                        n = c[e >> 2] | 0;
	                        i = b;
	                        return n | 0
	                    }
	                    c[h >> 2] = ly(c[g >> 2] | 0, (c[c[f >> 2] >> 2] | 0) - (c[g >> 2] | 0) | 0) | 0;
	                    m = c[f >> 2] | 0;
	                    if (d[c[c[f >> 2] >> 2] >> 0] | 0)c[m >> 2] = (c[m >> 2] | 0) + 1
	                } else {
	                    m = c[f >> 2] | 0;
	                    if ((a | 0) != 39) {
	                        Nq(m, 3);
	                        c[e >> 2] = 0;
	                        n = c[e >> 2] | 0;
	                        i = b;
	                        return n | 0
	                    }
	                    a = c[f >> 2] | 0;
	                    if (d[c[m >> 2] >> 0] | 0)c[a >> 2] = (c[a >> 2] | 0) + 1;
	                    c[g >> 2] = c[c[f >> 2] >> 2];
	                    while (1) {
	                        if (9 <= (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)k = 28; else if ((d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) != 13 ? 32 > (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) : 0)o = 0; else k = 28;
	                        if ((k | 0) == 28) {
	                            k = 0;
	                            o = (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) != 39
	                        }
	                        p = d[c[c[f >> 2] >> 2] >> 0] | 0;
	                        if (!o)break;
	                        a = c[f >> 2] | 0;
	                        if (!p)continue;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1
	                    }
	                    if (!(9 <= (p | 0) ? (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0))k = 34;
	                    if (((k | 0) == 34 ? (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) != 13 : 0) ? 32 > (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) : 0) {
	                        Nq(c[f >> 2] | 0, 2);
	                        c[e >> 2] = 0;
	                        n = c[e >> 2] | 0;
	                        i = b;
	                        return n | 0
	                    }
	                    c[h >> 2] = ly(c[g >> 2] | 0, (c[c[f >> 2] >> 2] | 0) - (c[g >> 2] | 0) | 0) | 0;
	                    g = c[f >> 2] | 0;
	                    if (d[c[c[f >> 2] >> 2] >> 0] | 0)c[g >> 2] = (c[g >> 2] | 0) + 1
	                }
	                c[e >> 2] = c[h >> 2];
	                n = c[e >> 2] | 0;
	                i = b;
	                return n | 0
	            }

	            function Zu(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                do if (c[h >> 2] | 0) {
	                    if (!(c[k >> 2] | 0)) {
	                        c[g >> 2] = 0;
	                        break
	                    }
	                    if ((c[j >> 2] | 0) < 0) {
	                        c[g >> 2] = 0;
	                        break
	                    }
	                    if ((c[l >> 2] | 0) < 0) {
	                        c[g >> 2] = 0;
	                        break
	                    }
	                    c[m >> 2] = Cb[c[135744 >> 2] & 511](48) | 0;
	                    if (!(c[m >> 2] | 0)) {
	                        mv(131920);
	                        c[g >> 2] = 0;
	                        break
	                    } else {
	                        e = (c[m >> 2] | 0) + 0 | 0;
	                        d = e + 48 | 0;
	                        do {
	                            c[e >> 2] = 0;
	                            e = e + 4 | 0
	                        } while ((e | 0) < (d | 0));
	                        c[c[m >> 2] >> 2] = 6;
	                        c[(c[m >> 2] | 0) + 28 >> 2] = c[h >> 2];
	                        c[(c[m >> 2] | 0) + 32 >> 2] = c[j >> 2];
	                        c[(c[m >> 2] | 0) + 36 >> 2] = c[k >> 2];
	                        c[(c[m >> 2] | 0) + 40 >> 2] = c[l >> 2];
	                        nv(c[m >> 2] | 0);
	                        c[g >> 2] = c[m >> 2];
	                        break
	                    }
	                } else c[g >> 2] = 0; while (0);
	                i = f;
	                return c[g >> 2] | 0
	            }

	            function _u(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                if (!(c[g >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[h >> 2] = Cb[c[135744 >> 2] & 511](48) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    mv(131920);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } else {
	                    b = (c[h >> 2] | 0) + 0 | 0;
	                    a = b + 48 | 0;
	                    do {
	                        c[b >> 2] = 0;
	                        b = b + 4 | 0
	                    } while ((b | 0) < (a | 0));
	                    c[c[h >> 2] >> 2] = 6;
	                    c[(c[h >> 2] | 0) + 28 >> 2] = c[f >> 2];
	                    c[(c[h >> 2] | 0) + 32 >> 2] = -1;
	                    c[(c[h >> 2] | 0) + 36 >> 2] = c[g >> 2];
	                    c[(c[h >> 2] | 0) + 40 >> 2] = -1;
	                    nv(c[h >> 2] | 0);
	                    c[e >> 2] = c[h >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                return 0
	            }

	            function $u(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](48) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    mv(131920);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    a = (c[f >> 2] | 0) + 0 | 0;
	                    h = a + 48 | 0;
	                    do {
	                        c[a >> 2] = 0;
	                        a = a + 4 | 0
	                    } while ((a | 0) < (h | 0));
	                    c[c[f >> 2] >> 2] = 6;
	                    c[(c[f >> 2] | 0) + 28 >> 2] = c[e >> 2];
	                    c[(c[f >> 2] | 0) + 32 >> 2] = -1;
	                    c[(c[f >> 2] | 0) + 36 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 40 >> 2] = -1;
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function av(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                b = c[c[h >> 2] >> 2] | 0;
	                if ((b | 0) == 1)l = 6; else if (!((b | 0) == 6 | (b | 0) == 5)) {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                if ((l | 0) == 6 ? (c[c[(c[h >> 2] | 0) + 4 >> 2] >> 2] | 0) <= 0 : 0) {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                c[j >> 2] = Cb[c[135744 >> 2] & 511](48) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    mv(131920);
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                l = (c[j >> 2] | 0) + 0 | 0;
	                b = l + 48 | 0;
	                do {
	                    c[l >> 2] = 0;
	                    l = l + 4 | 0
	                } while ((l | 0) < (b | 0));
	                c[c[j >> 2] >> 2] = 6;
	                c[(c[j >> 2] | 0) + 28 >> 2] = c[g >> 2];
	                c[(c[j >> 2] | 0) + 32 >> 2] = -1;
	                g = c[c[h >> 2] >> 2] | 0;
	                if ((g | 0) == 1) {
	                    c[(c[j >> 2] | 0) + 36 >> 2] = c[(c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) + ((c[c[(c[h >> 2] | 0) + 4 >> 2] >> 2] | 0) - 1 << 2) >> 2];
	                    c[(c[j >> 2] | 0) + 40 >> 2] = -1
	                } else if ((g | 0) == 5) {
	                    c[(c[j >> 2] | 0) + 36 >> 2] = c[(c[h >> 2] | 0) + 28 >> 2];
	                    c[(c[j >> 2] | 0) + 40 >> 2] = c[(c[h >> 2] | 0) + 32 >> 2]
	                } else if ((g | 0) == 6) {
	                    c[(c[j >> 2] | 0) + 36 >> 2] = c[(c[h >> 2] | 0) + 36 >> 2];
	                    c[(c[j >> 2] | 0) + 40 >> 2] = c[(c[h >> 2] | 0) + 40 >> 2]
	                } else {
	                    h = c[33976] | 0;
	                    g = c[33980] | 0;
	                    c[e >> 2] = 131976;
	                    c[e + 4 >> 2] = 590;
	                    Db[h & 511](g, 131944, e);
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                nv(c[j >> 2] | 0);
	                c[f >> 2] = c[j >> 2];
	                k = c[f >> 2] | 0;
	                i = d;
	                return k | 0
	            }

	            function bv(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](12) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    mv(132e3);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = c[f >> 2] | 0;
	                c[a + 0 >> 2] = 0;
	                c[a + 4 >> 2] = 0;
	                c[a + 8 >> 2] = 0;
	                do if (c[e >> 2] | 0) {
	                    a = Cb[c[135744 >> 2] & 511](40) | 0;
	                    c[(c[f >> 2] | 0) + 8 >> 2] = a;
	                    if (c[(c[f >> 2] | 0) + 8 >> 2] | 0) {
	                        a = (c[(c[f >> 2] | 0) + 8 >> 2] | 0) + 0 | 0;
	                        h = a + 40 | 0;
	                        do {
	                            c[a >> 2] = 0;
	                            a = a + 4 | 0
	                        } while ((a | 0) < (h | 0));
	                        c[(c[f >> 2] | 0) + 4 >> 2] = 10;
	                        a = c[e >> 2] | 0;
	                        h = c[f >> 2] | 0;
	                        j = c[h >> 2] | 0;
	                        c[h >> 2] = j + 1;
	                        c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + (j << 2) >> 2] = a;
	                        break
	                    }
	                    mv(132e3);
	                    zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } while (0);
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function cv(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if ((c[e >> 2] | 0) == 0 | (c[f >> 2] | 0) == 0) {
	                    i = d;
	                    return
	                }
	                c[g >> 2] = 0;
	                while (1) {
	                    if ((c[g >> 2] | 0) >= (c[c[e >> 2] >> 2] | 0))break;
	                    if (ov(c[(c[(c[e >> 2] | 0) + 8 >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0, c[f >> 2] | 0) | 0) {
	                        j = 5;
	                        break
	                    }
	                    c[g >> 2] = (c[g >> 2] | 0) + 1
	                }
	                if ((j | 0) == 5) {
	                    Qq(c[f >> 2] | 0);
	                    i = d;
	                    return
	                }
	                do if (c[(c[e >> 2] | 0) + 4 >> 2] | 0) {
	                    if ((c[c[e >> 2] >> 2] | 0) == (c[(c[e >> 2] | 0) + 4 >> 2] | 0)) {
	                        j = (c[e >> 2] | 0) + 4 | 0;
	                        c[j >> 2] = c[j >> 2] << 1;
	                        c[h >> 2] = Hb[c[135760 >> 2] & 511](c[(c[e >> 2] | 0) + 8 >> 2] | 0, c[(c[e >> 2] | 0) + 4 >> 2] << 2) | 0;
	                        if (c[h >> 2] | 0) {
	                            c[(c[e >> 2] | 0) + 8 >> 2] = c[h >> 2];
	                            break
	                        }
	                        mv(132024);
	                        i = d;
	                        return
	                    }
	                } else {
	                    j = Cb[c[135744 >> 2] & 511](40) | 0;
	                    c[(c[e >> 2] | 0) + 8 >> 2] = j;
	                    if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                        j = (c[(c[e >> 2] | 0) + 8 >> 2] | 0) + 0 | 0;
	                        g = j + 40 | 0;
	                        do {
	                            c[j >> 2] = 0;
	                            j = j + 4 | 0
	                        } while ((j | 0) < (g | 0));
	                        c[(c[e >> 2] | 0) + 4 >> 2] = 10;
	                        break
	                    }
	                    mv(132024);
	                    i = d;
	                    return
	                } while (0);
	                h = c[f >> 2] | 0;
	                f = c[e >> 2] | 0;
	                j = c[f >> 2] | 0;
	                c[f >> 2] = j + 1;
	                c[(c[(c[e >> 2] | 0) + 8 >> 2] | 0) + (j << 2) >> 2] = h;
	                i = d;
	                return
	            }

	            function dv(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                if (!(c[g >> 2] | 0)) {
	                    c[e >> 2] = c[f >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[h >> 2] = 0;
	                while (1) {
	                    k = c[f >> 2] | 0;
	                    if ((c[h >> 2] | 0) >= (c[c[g >> 2] >> 2] | 0))break;
	                    cv(k, c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + (c[h >> 2] << 2) >> 2] | 0);
	                    c[h >> 2] = (c[h >> 2] | 0) + 1
	                }
	                c[e >> 2] = k;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function ev(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 8 >> 2] | 0) {
	                    c[e >> 2] = 0;
	                    while (1) {
	                        if ((c[e >> 2] | 0) >= (c[c[d >> 2] >> 2] | 0))break;
	                        Qq(c[(c[(c[d >> 2] | 0) + 8 >> 2] | 0) + (c[e >> 2] << 2) >> 2] | 0);
	                        c[e >> 2] = (c[e >> 2] | 0) + 1
	                    }
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 8 >> 2] | 0)
	                }
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function fv(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = Cb[c[135744 >> 2] & 511](48) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    mv(132e3);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                b = (c[h >> 2] | 0) + 0 | 0;
	                a = b + 48 | 0;
	                do {
	                    c[b >> 2] = 0;
	                    b = b + 4 | 0
	                } while ((b | 0) < (a | 0));
	                c[c[h >> 2] >> 2] = 7;
	                b = c[f >> 2] | 0;
	                if (!(c[g >> 2] | 0)) {
	                    f = bv($u(b) | 0) | 0;
	                    c[(c[h >> 2] | 0) + 28 >> 2] = f
	                } else {
	                    f = bv(_u(b, c[g >> 2] | 0) | 0) | 0;
	                    c[(c[h >> 2] | 0) + 28 >> 2] = f
	                }
	                c[e >> 2] = c[h >> 2];
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function gv(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 16 | 0;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                g = b + 4 | 0;
	                h = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](48) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    mv(132e3);
	                    c[d >> 2] = 0;
	                    j = c[d >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                a = (c[f >> 2] | 0) + 0 | 0;
	                k = a + 48 | 0;
	                do {
	                    c[a >> 2] = 0;
	                    a = a + 4 | 0
	                } while ((a | 0) < (k | 0));
	                c[c[f >> 2] >> 2] = 7;
	                if (c[e >> 2] | 0) {
	                    c[h >> 2] = bv(0) | 0;
	                    if (!(c[h >> 2] | 0)) {
	                        c[d >> 2] = c[f >> 2];
	                        j = c[d >> 2] | 0;
	                        i = b;
	                        return j | 0
	                    }
	                    c[g >> 2] = 0;
	                    while (1) {
	                        l = c[h >> 2] | 0;
	                        if ((c[g >> 2] | 0) >= (c[c[e >> 2] >> 2] | 0))break;
	                        cv(l, $u(c[(c[(c[e >> 2] | 0) + 8 >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0) | 0);
	                        c[g >> 2] = (c[g >> 2] | 0) + 1
	                    }
	                    c[(c[f >> 2] | 0) + 28 >> 2] = l
	                }
	                c[d >> 2] = c[f >> 2];
	                j = c[d >> 2] | 0;
	                i = b;
	                return j | 0
	            }

	            function hv(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](48) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    mv(132e3);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    a = (c[f >> 2] | 0) + 0 | 0;
	                    h = a + 48 | 0;
	                    do {
	                        c[a >> 2] = 0;
	                        a = a + 4 | 0
	                    } while ((a | 0) < (h | 0));
	                    c[c[f >> 2] >> 2] = 7;
	                    c[(c[f >> 2] | 0) + 28 >> 2] = c[e >> 2];
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function iv(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = Lr(c[g >> 2] | 0) | 0;
	                g = c[k >> 2] | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[f >> 2] = g;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } else {
	                    c[g + 76 >> 2] = 1;
	                    c[(c[k >> 2] | 0) + 80 >> 2] = c[h >> 2];
	                    c[(c[k >> 2] | 0) + 84 >> 2] = c[j >> 2];
	                    jr(c[k >> 2] | 0, 132048, 306) | 0;
	                    jr(c[k >> 2] | 0, 132064, 307) | 0;
	                    jr(c[k >> 2] | 0, 132072, 308) | 0;
	                    jr(c[k >> 2] | 0, 132088, 309) | 0;
	                    jr(c[k >> 2] | 0, 132104, 310) | 0;
	                    jr(c[k >> 2] | 0, 132120, 311) | 0;
	                    jr(c[k >> 2] | 0, 132136, 312) | 0;
	                    jr(c[k >> 2] | 0, 132144, 313) | 0;
	                    c[f >> 2] = c[k >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                return 0
	            }

	            function jv(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                d = i;
	                i = i + 48 | 0;
	                e = d + 36 | 0;
	                f = d + 32 | 0;
	                g = d + 28 | 0;
	                h = d + 24 | 0;
	                j = d + 20 | 0;
	                k = d + 16 | 0;
	                l = d + 12 | 0;
	                m = d + 8 | 0;
	                n = d + 4 | 0;
	                o = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[m >> 2] = 0;
	                if ((c[e >> 2] | 0) == 0 | (c[e >> 2] | 0) == 0) {
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if ((c[f >> 2] | 0) != 1) {
	                    Nq(b, 12);
	                    i = d;
	                    return
	                }
	                f = c[e >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 1 | 0)) {
	                    Nq(f, 23);
	                    i = d;
	                    return
	                }
	                if ((c[f + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) == 1 : 0) {
	                    c[k >> 2] = Sq(c[e >> 2] | 0) | 0;
	                    c[n >> 2] = c[(c[k >> 2] | 0) + 4 >> 2];
	                    c[(c[(c[e >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 0;
	                    c[h >> 2] = c[c[e >> 2] >> 2];
	                    c[m >> 2] = bv(0) | 0;
	                    c[o >> 2] = 0;
	                    while (1) {
	                        if ((c[o >> 2] | 0) >= (c[c[n >> 2] >> 2] | 0))break;
	                        c[c[e >> 2] >> 2] = c[h >> 2];
	                        c[(c[(c[e >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + (c[o >> 2] << 2) >> 2];
	                        c[l >> 2] = gr(c[(c[(c[e >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) | 0;
	                        Tq(c[e >> 2] | 0, c[l >> 2] | 0) | 0;
	                        Qs(c[e >> 2] | 0);
	                        if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                            p = 20;
	                            break
	                        }
	                        c[j >> 2] = Sq(c[e >> 2] | 0) | 0;
	                        c[g >> 2] = av(c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + (c[o >> 2] << 2) >> 2] | 0, c[j >> 2] | 0) | 0;
	                        if (c[g >> 2] | 0)cv(c[m >> 2] | 0, c[g >> 2] | 0);
	                        if (c[j >> 2] | 0)Qq(c[j >> 2] | 0);
	                        if ((c[(c[e >> 2] | 0) + 16 >> 2] | 0) == (c[l >> 2] | 0)) {
	                            c[j >> 2] = Sq(c[e >> 2] | 0) | 0;
	                            Qq(c[j >> 2] | 0)
	                        }
	                        c[(c[(c[e >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 0;
	                        c[o >> 2] = (c[o >> 2] | 0) + 1
	                    }
	                    if ((p | 0) == 20) {
	                        i = d;
	                        return
	                    }
	                    Qq(c[k >> 2] | 0);
	                    c[(c[(c[e >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 0;
	                    c[(c[(c[e >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] = -1;
	                    c[(c[(c[e >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2] = -1;
	                    k = c[e >> 2] | 0;
	                    Tq(k, hv(c[m >> 2] | 0) | 0) | 0;
	                    i = d;
	                    return
	                }
	                Nq(c[e >> 2] | 0, 11);
	                i = d;
	                return
	            }

	            function kv(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                d = i;
	                i = i + 48 | 0;
	                e = d + 32 | 0;
	                f = d + 28 | 0;
	                g = d + 24 | 0;
	                h = d + 20 | 0;
	                j = d + 16 | 0;
	                k = d + 12 | 0;
	                l = d + 8 | 0;
	                m = d + 4 | 0;
	                n = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[j >> 2] = 0;
	                c[l >> 2] = 0;
	                c[m >> 2] = 0;
	                Kq();
	                if ((c[g >> 2] | 0) == 0 | (c[f >> 2] | 0) == 0) {
	                    c[e >> 2] = 0;
	                    o = c[e >> 2] | 0;
	                    i = d;
	                    return o | 0
	                }
	                c[h >> 2] = Or(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    o = c[e >> 2] | 0;
	                    i = d;
	                    return o | 0
	                }
	                c[(c[h >> 2] | 0) + 36 >> 2] = 1;
	                wv(c[h >> 2] | 0);
	                if (((c[(c[h >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[h >> 2] | 0) + 16 >> 2] >> 2] | 0) != 1 : 0) ? (c[c[(c[h >> 2] | 0) + 16 >> 2] >> 2] | 0) != 7 : 0)xv(c[h >> 2] | 0, 1902, 132152, 0); else c[j >> 2] = Sq(c[h >> 2] | 0) | 0;
	                do {
	                    c[k >> 2] = Sq(c[h >> 2] | 0) | 0;
	                    if (c[k >> 2] | 0) {
	                        do if ((c[k >> 2] | 0) != (c[l >> 2] | 0)) {
	                            if ((c[c[k >> 2] >> 2] | 0) != 1) {
	                                c[m >> 2] = (c[m >> 2] | 0) + 1;
	                                break
	                            }
	                            c[n >> 2] = c[(c[k >> 2] | 0) + 4 >> 2];
	                            if ((c[c[n >> 2] >> 2] | 0) == 1 ? (c[c[(c[n >> 2] | 0) + 8 >> 2] >> 2] | 0) == (c[c[g >> 2] >> 2] | 0) : 0)break;
	                            c[m >> 2] = (c[m >> 2] | 0) + 1
	                        } while (0);
	                        Qq(c[k >> 2] | 0)
	                    }
	                } while ((c[k >> 2] | 0) != 0);
	                if (c[m >> 2] | 0)xv(c[h >> 2] | 0, 1903, 132208, 0);
	                if (c[(c[h >> 2] | 0) + 8 >> 2] | 0) {
	                    Qq(c[j >> 2] | 0);
	                    c[j >> 2] = 0
	                }
	                Pr(c[h >> 2] | 0);
	                c[e >> 2] = c[j >> 2];
	                o = c[e >> 2] | 0;
	                i = d;
	                return o | 0
	            }

	            function lv(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                a:while (1) {
	                    if (!(c[g >> 2] | 0)) {
	                        j = 4;
	                        break
	                    }
	                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 18) {
	                        j = 4;
	                        break
	                    }
	                    if (c[(c[g >> 2] | 0) + 12 >> 2] | 0) {
	                        c[g >> 2] = c[(c[g >> 2] | 0) + 12 >> 2];
	                        if (c[h >> 2] | 0) {
	                            b = c[h >> 2] | 0;
	                            c[b >> 2] = (c[b >> 2] | 0) + 1;
	                            j = 17
	                        } else j = 17
	                    }
	                    b:while (1) {
	                        if ((j | 0) == 17) {
	                            j = 0;
	                            if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                                j = 24;
	                                break a
	                            }
	                            if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 3) {
	                                j = 24;
	                                break a
	                            }
	                            if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 9) {
	                                j = 24;
	                                break a
	                            }
	                            if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 13) {
	                                j = 24;
	                                break a
	                            }
	                            if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 4) {
	                                j = 24;
	                                break a
	                            }
	                            if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 5)continue a;
	                            b = c[33976] | 0;
	                            a = c[33980] | 0;
	                            c[e >> 2] = 131976;
	                            c[e + 4 >> 2] = 2362;
	                            Db[b & 511](a, 132256, e)
	                        }
	                        if (c[(c[g >> 2] | 0) + 24 >> 2] | 0) {
	                            c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                            j = 17;
	                            continue
	                        }
	                        while (1) {
	                            c[g >> 2] = c[(c[g >> 2] | 0) + 20 >> 2];
	                            if (c[h >> 2] | 0) {
	                                a = c[h >> 2] | 0;
	                                c[a >> 2] = (c[a >> 2] | 0) + -1
	                            }
	                            if (!(c[g >> 2] | 0)) {
	                                j = 13;
	                                break a
	                            }
	                            k = c[g >> 2] | 0;
	                            if (c[(c[g >> 2] | 0) + 24 >> 2] | 0)break;
	                            if (!k) {
	                                j = 17;
	                                continue b
	                            }
	                        }
	                        c[g >> 2] = c[k + 24 >> 2];
	                        j = 17
	                    }
	                }
	                if ((j | 0) == 4) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = d;
	                    return l | 0
	                } else if ((j | 0) == 13) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = d;
	                    return l | 0
	                } else if ((j | 0) == 24) {
	                    c[f >> 2] = c[g >> 2];
	                    l = c[f >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                return 0
	            }

	            function mv(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                e = b + 4 | 0;
	                c[e >> 2] = a;
	                a = c[e >> 2] | 0;
	                c[d >> 2] = c[e >> 2];
	                Xd(0, 0, 0, 0, 0, 13, 2, 2, 0, 0, a, 0, 0, 0, 0, 132472, d);
	                i = b;
	                return
	            }

	            function nv(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if ((c[c[d >> 2] >> 2] | 0) != 6) {
	                    i = b;
	                    return
	                }
	                if (!(c[(c[d >> 2] | 0) + 36 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                c[e >> 2] = yv(c[(c[d >> 2] | 0) + 28 >> 2] | 0, c[(c[d >> 2] | 0) + 32 >> 2] | 0, c[(c[d >> 2] | 0) + 36 >> 2] | 0, c[(c[d >> 2] | 0) + 40 >> 2] | 0) | 0;
	                if ((c[e >> 2] | 0) != -1) {
	                    i = b;
	                    return
	                }
	                c[f >> 2] = c[(c[d >> 2] | 0) + 28 >> 2];
	                c[(c[d >> 2] | 0) + 28 >> 2] = c[(c[d >> 2] | 0) + 36 >> 2];
	                c[(c[d >> 2] | 0) + 36 >> 2] = c[f >> 2];
	                c[e >> 2] = c[(c[d >> 2] | 0) + 32 >> 2];
	                c[(c[d >> 2] | 0) + 32 >> 2] = c[(c[d >> 2] | 0) + 40 >> 2];
	                c[(c[d >> 2] | 0) + 40 >> 2] = c[e >> 2];
	                i = b;
	                return
	            }

	            function ov(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                do if ((c[f >> 2] | 0) != (c[g >> 2] | 0)) {
	                    if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                        c[e >> 2] = 0;
	                        break
	                    }
	                    if ((c[c[f >> 2] >> 2] | 0) != (c[c[g >> 2] >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        break
	                    }
	                    if ((c[c[f >> 2] >> 2] | 0) != 6) {
	                        c[e >> 2] = 0;
	                        break
	                    }
	                    if ((c[(c[f >> 2] | 0) + 28 >> 2] | 0) != (c[(c[g >> 2] | 0) + 28 >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        break
	                    }
	                    if ((c[(c[f >> 2] | 0) + 32 >> 2] | 0) != (c[(c[g >> 2] | 0) + 32 >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        break
	                    }
	                    if ((c[(c[f >> 2] | 0) + 36 >> 2] | 0) != (c[(c[g >> 2] | 0) + 36 >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        break
	                    }
	                    if ((c[(c[f >> 2] | 0) + 40 >> 2] | 0) != (c[(c[g >> 2] | 0) + 40 >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        break
	                    } else {
	                        c[e >> 2] = 1;
	                        break
	                    }
	                } else c[e >> 2] = 1; while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function pv(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 24 | 0;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                l = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if ((c[f >> 2] | 0) != 1) {
	                    Nq(b, 12);
	                    i = d;
	                    return
	                }
	                f = c[e >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 1 | 0)) {
	                    Nq(f, 23);
	                    i = d;
	                    return
	                }
	                do if (c[f + 16 >> 2] | 0) {
	                    if ((c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 7 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 1 : 0)break;
	                    c[h >> 2] = Sq(c[e >> 2] | 0) | 0;
	                    do if ((c[c[h >> 2] >> 2] | 0) == 1) {
	                        c[l >> 2] = gv(c[(c[h >> 2] | 0) + 4 >> 2] | 0) | 0;
	                        Qq(c[h >> 2] | 0);
	                        if (c[l >> 2] | 0) {
	                            c[h >> 2] = c[l >> 2];
	                            break
	                        }
	                        Nq(c[e >> 2] | 0, 15);
	                        i = d;
	                        return
	                    } while (0);
	                    c[j >> 2] = c[(c[h >> 2] | 0) + 28 >> 2];
	                    c[k >> 2] = bv(0) | 0;
	                    if (!(c[k >> 2] | 0)) {
	                        Qq(c[h >> 2] | 0);
	                        Nq(c[e >> 2] | 0, 15);
	                        i = d;
	                        return
	                    }
	                    c[g >> 2] = 0;
	                    while (1) {
	                        if ((c[g >> 2] | 0) >= (c[c[j >> 2] >> 2] | 0))break;
	                        b = c[k >> 2] | 0;
	                        cv(b, zv(c[e >> 2] | 0, c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0) | 0);
	                        c[g >> 2] = (c[g >> 2] | 0) + 1
	                    }
	                    b = c[e >> 2] | 0;
	                    Tq(b, hv(c[k >> 2] | 0) | 0) | 0;
	                    Qq(c[h >> 2] | 0);
	                    i = d;
	                    return
	                } while (0);
	                Nq(c[e >> 2] | 0, 11);
	                i = d;
	                return
	            }

	            function qv(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 24 | 0;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                l = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if ((c[f >> 2] | 0) != 1) {
	                    Nq(b, 12);
	                    i = d;
	                    return
	                }
	                f = c[e >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 1 | 0)) {
	                    Nq(f, 23);
	                    i = d;
	                    return
	                }
	                do if (c[f + 16 >> 2] | 0) {
	                    if ((c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 7 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 1 : 0)break;
	                    c[h >> 2] = Sq(c[e >> 2] | 0) | 0;
	                    do if ((c[c[h >> 2] >> 2] | 0) == 1) {
	                        c[l >> 2] = gv(c[(c[h >> 2] | 0) + 4 >> 2] | 0) | 0;
	                        Qq(c[h >> 2] | 0);
	                        if (c[l >> 2] | 0) {
	                            c[h >> 2] = c[l >> 2];
	                            break
	                        }
	                        Nq(c[e >> 2] | 0, 15);
	                        i = d;
	                        return
	                    } while (0);
	                    c[j >> 2] = c[(c[h >> 2] | 0) + 28 >> 2];
	                    c[k >> 2] = bv(0) | 0;
	                    if (!(c[k >> 2] | 0)) {
	                        Qq(c[h >> 2] | 0);
	                        Nq(c[e >> 2] | 0, 15);
	                        i = d;
	                        return
	                    }
	                    c[g >> 2] = 0;
	                    while (1) {
	                        if ((c[g >> 2] | 0) >= (c[c[j >> 2] >> 2] | 0))break;
	                        b = c[k >> 2] | 0;
	                        cv(b, Av(c[e >> 2] | 0, c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0) | 0);
	                        c[g >> 2] = (c[g >> 2] | 0) + 1
	                    }
	                    b = c[e >> 2] | 0;
	                    Tq(b, hv(c[k >> 2] | 0) | 0) | 0;
	                    Qq(c[h >> 2] | 0);
	                    i = d;
	                    return
	                } while (0);
	                Nq(c[e >> 2] | 0, 11);
	                i = d;
	                return
	            }

	            function rv(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0;
	                e = i;
	                i = i + 96 | 0;
	                f = e + 80 | 0;
	                g = e + 76 | 0;
	                j = e + 72 | 0;
	                k = e + 68 | 0;
	                l = e + 64 | 0;
	                m = e + 60 | 0;
	                n = e + 56 | 0;
	                o = e + 52 | 0;
	                p = e + 48 | 0;
	                q = e + 44 | 0;
	                r = e + 40 | 0;
	                s = e + 36 | 0;
	                t = e + 32 | 0;
	                u = e + 28 | 0;
	                v = e + 24 | 0;
	                w = e + 20 | 0;
	                x = e + 16 | 0;
	                y = e + 12 | 0;
	                z = e + 8 | 0;
	                A = e + 4 | 0;
	                B = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[l >> 2] = 0;
	                c[o >> 2] = 0;
	                c[u >> 2] = 0;
	                c[v >> 2] = 0;
	                c[x >> 2] = 0;
	                c[y >> 2] = 0;
	                if ((c[g >> 2] | 0) < 2 | (c[g >> 2] | 0) > 4) {
	                    Nq(c[f >> 2] | 0, 12);
	                    i = e;
	                    return
	                }
	                do if ((c[g >> 2] | 0) >= 4) {
	                    if ((c[(c[f >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[f >> 2] | 0) + 16 >> 2] >> 2] | 0) == 3 : 0) {
	                        c[v >> 2] = Sq(c[f >> 2] | 0) | 0;
	                        if (!(c[v >> 2] | 0))break;
	                        c[y >> 2] = ~~+h[(c[v >> 2] | 0) + 16 >> 3];
	                        break
	                    }
	                    Nq(c[f >> 2] | 0, 11);
	                    i = e;
	                    return
	                } while (0);
	                do if ((c[g >> 2] | 0) >= 3) {
	                    if ((c[(c[f >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[f >> 2] | 0) + 16 >> 2] >> 2] | 0) == 3 : 0) {
	                        c[u >> 2] = Sq(c[f >> 2] | 0) | 0;
	                        if (!(c[u >> 2] | 0))break;
	                        c[x >> 2] = ~~+h[(c[u >> 2] | 0) + 16 >> 3];
	                        break
	                    }
	                    Nq(c[f >> 2] | 0, 11);
	                    i = e;
	                    return
	                } while (0);
	                if ((c[(c[f >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[f >> 2] | 0) + 16 >> 2] >> 2] | 0) == 4 : 0) {
	                    c[t >> 2] = Sq(c[f >> 2] | 0) | 0;
	                    do if (c[(c[f >> 2] | 0) + 16 >> 2] | 0) {
	                        if ((c[c[(c[f >> 2] | 0) + 16 >> 2] >> 2] | 0) != 7 ? (c[c[(c[f >> 2] | 0) + 16 >> 2] >> 2] | 0) != 1 : 0)break;
	                        c[q >> 2] = Sq(c[f >> 2] | 0) | 0;
	                        c[s >> 2] = bv(0) | 0;
	                        g = c[q >> 2] | 0;
	                        if (!(c[s >> 2] | 0)) {
	                            Qq(g);
	                            Nq(c[f >> 2] | 0, 15);
	                            i = e;
	                            return
	                        }
	                        a:do if (c[g + 4 >> 2] | 0) {
	                            do if ((c[c[q >> 2] >> 2] | 0) == 1) {
	                                c[z >> 2] = gv(c[(c[q >> 2] | 0) + 4 >> 2] | 0) | 0;
	                                Qq(c[q >> 2] | 0);
	                                if (c[z >> 2] | 0) {
	                                    c[q >> 2] = c[z >> 2];
	                                    break
	                                }
	                                Nq(c[f >> 2] | 0, 15);
	                                i = e;
	                                return
	                            } while (0);
	                            c[r >> 2] = c[(c[q >> 2] | 0) + 28 >> 2];
	                            c[j >> 2] = 0;
	                            while (1) {
	                                if ((c[j >> 2] | 0) >= (c[c[r >> 2] >> 2] | 0))break a;
	                                Bv(c[(c[(c[r >> 2] | 0) + 8 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0, n, k) | 0;
	                                Cv(c[(c[(c[r >> 2] | 0) + 8 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0, o, l) | 0;
	                                Dv(n, k, 0) | 0;
	                                Ev(o, l) | 0;
	                                do {
	                                    c[p >> 2] = c[o >> 2];
	                                    c[m >> 2] = c[l >> 2];
	                                    c[w >> 2] = Fv(c[(c[t >> 2] | 0) + 24 >> 2] | 0, n, k, p, m) | 0;
	                                    if ((c[w >> 2] | 0) == 1) {
	                                        do if (c[u >> 2] | 0) {
	                                            if (Dv(n, k, (c[x >> 2] | 0) - 1 | 0) | 0)break;
	                                            if ((c[v >> 2] | 0) != 0 & (c[y >> 2] | 0) > 0) {
	                                                c[B >> 2] = c[n >> 2];
	                                                c[A >> 2] = (c[k >> 2] | 0) - 1;
	                                                if (Dv(B, A, c[y >> 2] | 0) | 0)break;
	                                                b = c[s >> 2] | 0;
	                                                cv(b, Zu(c[n >> 2] | 0, c[k >> 2] | 0, c[B >> 2] | 0, c[A >> 2] | 0) | 0);
	                                                break
	                                            }
	                                            b = c[s >> 2] | 0;
	                                            a = c[n >> 2] | 0;
	                                            C = c[k >> 2] | 0;
	                                            if ((c[v >> 2] | 0) != 0 & (c[y >> 2] | 0) <= 0) {
	                                                cv(b, Zu(a, C, c[n >> 2] | 0, c[k >> 2] | 0) | 0);
	                                                break
	                                            } else {
	                                                cv(b, Zu(a, C, c[p >> 2] | 0, c[m >> 2] | 0) | 0);
	                                                break
	                                            }
	                                        } else {
	                                            C = c[s >> 2] | 0;
	                                            cv(C, Zu(c[n >> 2] | 0, c[k >> 2] | 0, c[p >> 2] | 0, c[m >> 2] | 0) | 0)
	                                        } while (0);
	                                        c[n >> 2] = c[p >> 2];
	                                        c[k >> 2] = c[m >> 2];
	                                        if (!(d[c[(c[t >> 2] | 0) + 24 >> 2] >> 0] | 0))c[k >> 2] = (c[k >> 2] | 0) + 1
	                                    }
	                                } while ((c[w >> 2] | 0) == 1);
	                                c[j >> 2] = (c[j >> 2] | 0) + 1
	                            }
	                        } while (0);
	                        g = c[f >> 2] | 0;
	                        Tq(g, hv(c[s >> 2] | 0) | 0) | 0;
	                        Qq(c[q >> 2] | 0);
	                        Qq(c[t >> 2] | 0);
	                        if (c[u >> 2] | 0)Qq(c[u >> 2] | 0);
	                        if (!(c[v >> 2] | 0)) {
	                            i = e;
	                            return
	                        }
	                        Qq(c[v >> 2] | 0);
	                        i = e;
	                        return
	                    } while (0);
	                    Nq(c[f >> 2] | 0, 11);
	                    i = e;
	                    return
	                }
	                Nq(c[f >> 2] | 0, 11);
	                i = e;
	                return
	            }

	            function sv(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                d = i;
	                i = i + 48 | 0;
	                e = d + 32 | 0;
	                f = d + 28 | 0;
	                g = d + 24 | 0;
	                h = d + 20 | 0;
	                j = d + 16 | 0;
	                k = d + 12 | 0;
	                l = d + 8 | 0;
	                m = d + 4 | 0;
	                n = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[k >> 2] = 0;
	                c[l >> 2] = 0;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if ((c[f >> 2] | 0) != 1) {
	                    Nq(b, 12);
	                    i = d;
	                    return
	                }
	                f = c[e >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 1 | 0)) {
	                    Nq(f, 23);
	                    i = d;
	                    return
	                }
	                do if (c[f + 16 >> 2] | 0) {
	                    if ((c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 7 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 1 : 0)break;
	                    c[h >> 2] = Sq(c[e >> 2] | 0) | 0;
	                    do if ((c[c[h >> 2] >> 2] | 0) == 1) {
	                        c[g >> 2] = gv(c[(c[h >> 2] | 0) + 4 >> 2] | 0) | 0;
	                        Qq(c[h >> 2] | 0);
	                        if (c[g >> 2] | 0) {
	                            c[h >> 2] = c[g >> 2];
	                            break
	                        }
	                        Nq(c[e >> 2] | 0, 15);
	                        i = d;
	                        return
	                    } while (0);
	                    c[k >> 2] = bv(0) | 0;
	                    b = c[h >> 2] | 0;
	                    if (!(c[k >> 2] | 0)) {
	                        Qq(b);
	                        Nq(c[e >> 2] | 0, 15);
	                        i = d;
	                        return
	                    }
	                    c[l >> 2] = c[b + 28 >> 2];
	                    a:do if (c[l >> 2] | 0) {
	                        c[m >> 2] = 0;
	                        while (1) {
	                            if ((c[m >> 2] | 0) >= (c[c[l >> 2] >> 2] | 0))break a;
	                            c[g >> 2] = c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + (c[m >> 2] << 2) >> 2];
	                            if (c[g >> 2] | 0) {
	                                c[j >> 2] = 0;
	                                b = c[c[g >> 2] >> 2] | 0;
	                                if ((b | 0) == 5)c[j >> 2] = Gv(c[(c[g >> 2] | 0) + 28 >> 2] | 0, c[(c[g >> 2] | 0) + 32 >> 2] | 0) | 0; else if ((b | 0) == 6 ? (c[n >> 2] = c[(c[g >> 2] | 0) + 28 >> 2], (c[n >> 2] | 0) != 0) : 0) {
	                                    if ((c[(c[n >> 2] | 0) + 4 >> 2] | 0) == 2)break;
	                                    c[j >> 2] = Gv(c[n >> 2] | 0, c[(c[g >> 2] | 0) + 32 >> 2] | 0) | 0
	                                }
	                                if (c[j >> 2] | 0)cv(c[k >> 2] | 0, c[j >> 2] | 0)
	                            }
	                            c[m >> 2] = (c[m >> 2] | 0) + 1
	                        }
	                        Qq(c[h >> 2] | 0);
	                        ev(c[k >> 2] | 0);
	                        Nq(c[e >> 2] | 0, 16);
	                        i = d;
	                        return
	                    } while (0);
	                    Qq(c[h >> 2] | 0);
	                    b = c[e >> 2] | 0;
	                    Tq(b, hv(c[k >> 2] | 0) | 0) | 0;
	                    i = d;
	                    return
	                } while (0);
	                Nq(c[e >> 2] | 0, 11);
	                i = d;
	                return
	            }

	            function tv(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                d = i;
	                i = i + 48 | 0;
	                e = d + 32 | 0;
	                f = d + 28 | 0;
	                g = d + 24 | 0;
	                h = d + 20 | 0;
	                j = d + 16 | 0;
	                k = d + 12 | 0;
	                l = d + 8 | 0;
	                m = d + 4 | 0;
	                n = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[k >> 2] = 0;
	                c[l >> 2] = 0;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if ((c[f >> 2] | 0) != 1) {
	                    Nq(b, 12);
	                    i = d;
	                    return
	                }
	                f = c[e >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 1 | 0)) {
	                    Nq(f, 23);
	                    i = d;
	                    return
	                }
	                do if (c[f + 16 >> 2] | 0) {
	                    if ((c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 7 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) != 1 : 0)break;
	                    c[h >> 2] = Sq(c[e >> 2] | 0) | 0;
	                    do if ((c[c[h >> 2] >> 2] | 0) == 1) {
	                        c[g >> 2] = gv(c[(c[h >> 2] | 0) + 4 >> 2] | 0) | 0;
	                        Qq(c[h >> 2] | 0);
	                        if (c[g >> 2] | 0) {
	                            c[h >> 2] = c[g >> 2];
	                            break
	                        }
	                        Nq(c[e >> 2] | 0, 15);
	                        i = d;
	                        return
	                    } while (0);
	                    c[k >> 2] = bv(0) | 0;
	                    b = c[h >> 2] | 0;
	                    if (!(c[k >> 2] | 0)) {
	                        Qq(b);
	                        Nq(c[e >> 2] | 0, 15);
	                        i = d;
	                        return
	                    }
	                    c[l >> 2] = c[b + 28 >> 2];
	                    a:do if (c[l >> 2] | 0) {
	                        c[m >> 2] = 0;
	                        b:while (1) {
	                            if ((c[m >> 2] | 0) >= (c[c[l >> 2] >> 2] | 0))break a;
	                            c[g >> 2] = c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + (c[m >> 2] << 2) >> 2];
	                            if (c[g >> 2] | 0) {
	                                c[j >> 2] = 0;
	                                b = c[c[g >> 2] >> 2] | 0;
	                                do if ((b | 0) == 6) {
	                                    c[n >> 2] = c[(c[g >> 2] | 0) + 36 >> 2];
	                                    if (c[n >> 2] | 0) {
	                                        if ((c[(c[n >> 2] | 0) + 4 >> 2] | 0) == 2)break b;
	                                        c[j >> 2] = Gv(c[n >> 2] | 0, c[(c[g >> 2] | 0) + 40 >> 2] | 0) | 0;
	                                        break
	                                    } else {
	                                        if (c[(c[g >> 2] | 0) + 28 >> 2] | 0)break;
	                                        a = c[n >> 2] | 0;
	                                        c[j >> 2] = Gv(a, Hv(c[n >> 2] | 0) | 0) | 0;
	                                        break
	                                    }
	                                } else if ((b | 0) == 5)c[j >> 2] = Gv(c[(c[g >> 2] | 0) + 28 >> 2] | 0, c[(c[g >> 2] | 0) + 32 >> 2] | 0) | 0; while (0);
	                                if (c[j >> 2] | 0)cv(c[k >> 2] | 0, c[j >> 2] | 0)
	                            }
	                            c[m >> 2] = (c[m >> 2] | 0) + 1
	                        }
	                        Qq(c[h >> 2] | 0);
	                        ev(c[k >> 2] | 0);
	                        Nq(c[e >> 2] | 0, 16);
	                        i = d;
	                        return
	                    } while (0);
	                    Qq(c[h >> 2] | 0);
	                    b = c[e >> 2] | 0;
	                    Tq(b, hv(c[k >> 2] | 0) | 0) | 0;
	                    i = d;
	                    return
	                } while (0);
	                Nq(c[e >> 2] | 0, 11);
	                i = d;
	                return
	            }

	            function uv(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if (c[f >> 2] | 0) {
	                    Nq(b, 12);
	                    i = d;
	                    return
	                }
	                f = c[e >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 0 | 0)) {
	                    Nq(f, 23);
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if (!(c[(c[f + 12 >> 2] | 0) + 80 >> 2] | 0)) {
	                    Nq(b, 16);
	                    i = d;
	                    return
	                } else {
	                    Tq(b, fv(c[(c[(c[e >> 2] | 0) + 12 >> 2] | 0) + 80 >> 2] | 0, 0) | 0) | 0;
	                    i = d;
	                    return
	                }
	            }

	            function vv(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if (c[f >> 2] | 0) {
	                    Nq(b, 12);
	                    i = d;
	                    return
	                }
	                f = c[e >> 2] | 0;
	                if ((c[b + 20 >> 2] | 0) < ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) + 0 | 0)) {
	                    Nq(f, 23);
	                    i = d;
	                    return
	                }
	                b = c[e >> 2] | 0;
	                if (!(c[(c[f + 12 >> 2] | 0) + 84 >> 2] | 0)) {
	                    Nq(b, 16);
	                    i = d;
	                    return
	                } else {
	                    Tq(b, fv(c[(c[(c[e >> 2] | 0) + 12 >> 2] | 0) + 84 >> 2] | 0, 0) | 0) | 0;
	                    i = d;
	                    return
	                }
	            }

	            function wv(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                do if (!(c[(c[e >> 2] | 0) + 28 >> 2] | 0)) {
	                    a = Cb[c[135744 >> 2] & 511](40) | 0;
	                    c[(c[e >> 2] | 0) + 28 >> 2] = a;
	                    if (c[(c[e >> 2] | 0) + 28 >> 2] | 0) {
	                        c[(c[e >> 2] | 0) + 20 >> 2] = 0;
	                        c[(c[e >> 2] | 0) + 24 >> 2] = 10;
	                        c[(c[e >> 2] | 0) + 16 >> 2] = 0;
	                        c[(c[e >> 2] | 0) + 44 >> 2] = 0;
	                        break
	                    }
	                    mv(132312);
	                    i = b;
	                    return
	                } while (0);
	                while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)g = 1; else {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            g = 1;
	                            break
	                        }
	                        g = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                    } while (0);
	                    h = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                    if (!g)break;
	                    a = c[e >> 2] | 0;
	                    if (!h)continue;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1
	                }
	                g = c[e >> 2] | 0;
	                do if ((h | 0) == 47) {
	                    ks(g);
	                    Iv(c[e >> 2] | 0, 0)
	                } else {
	                    c[f >> 2] = Ls(g) | 0;
	                    a = c[e >> 2] | 0;
	                    if (!(c[f >> 2] | 0)) {
	                        Nq(a, 7);
	                        i = b;
	                        return
	                    }
	                    j = c[e >> 2] | 0;
	                    k = c[f >> 2] | 0;
	                    if ((d[c[a >> 2] >> 0] | 0 | 0) != 40) {
	                        Iv(j, k);
	                        break
	                    }
	                    Jv(j, k);
	                    i = b;
	                    return
	                } while (0);
	                while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)l = 1; else {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            l = 1;
	                            break
	                        }
	                        l = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                    } while (0);
	                    m = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 0;
	                    if (!l)break;
	                    f = c[e >> 2] | 0;
	                    if (!m)continue;
	                    c[f >> 2] = (c[f >> 2] | 0) + 1
	                }
	                if (!m) {
	                    i = b;
	                    return
	                }
	                Nq(c[e >> 2] | 0, 7);
	                i = b;
	                return
	            }

	            function xv(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if (c[h >> 2] | 0)c[(c[h >> 2] | 0) + 8 >> 2] = c[j >> 2];
	                if ((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                    c[(c[(c[h >> 2] | 0) + 12 >> 2] | 0) + 136 >> 2] = 13;
	                    c[(c[(c[h >> 2] | 0) + 12 >> 2] | 0) + 140 >> 2] = c[j >> 2];
	                    c[(c[(c[h >> 2] | 0) + 12 >> 2] | 0) + 148 >> 2] = 2;
	                    e = my(c[(c[h >> 2] | 0) + 4 >> 2] | 0) | 0;
	                    c[(c[(c[h >> 2] | 0) + 12 >> 2] | 0) + 160 >> 2] = e;
	                    c[(c[(c[h >> 2] | 0) + 12 >> 2] | 0) + 172 >> 2] = (c[c[h >> 2] >> 2] | 0) - (c[(c[h >> 2] | 0) + 4 >> 2] | 0);
	                    c[(c[(c[h >> 2] | 0) + 12 >> 2] | 0) + 184 >> 2] = c[(c[(c[h >> 2] | 0) + 12 >> 2] | 0) + 188 >> 2];
	                    e = c[(c[h >> 2] | 0) + 12 >> 2] | 0;
	                    if (c[(c[(c[h >> 2] | 0) + 12 >> 2] | 0) + 132 >> 2] | 0) {
	                        Ab[c[e + 132 >> 2] & 511](c[(c[(c[h >> 2] | 0) + 12 >> 2] | 0) + 128 >> 2] | 0, (c[(c[h >> 2] | 0) + 12 >> 2] | 0) + 136 | 0);
	                        i = f;
	                        return
	                    } else {
	                        d = c[e + 188 >> 2] | 0;
	                        e = c[j >> 2] | 0;
	                        b = c[l >> 2] | 0;
	                        a = c[(c[h >> 2] | 0) + 4 >> 2] | 0;
	                        m = (c[c[h >> 2] >> 2] | 0) - (c[(c[h >> 2] | 0) + 4 >> 2] | 0) | 0;
	                        h = c[k >> 2] | 0;
	                        c[g >> 2] = c[l >> 2];
	                        Xd(0, 0, 0, 0, d, 13, e, 2, 0, 0, b, a, 0, m, 0, h, g);
	                        i = f;
	                        return
	                    }
	                }
	                h = c[j >> 2] | 0;
	                j = c[l >> 2] | 0;
	                m = c[k >> 2] | 0;
	                c[g >> 2] = c[l >> 2];
	                Xd(0, 0, 0, 0, 0, 13, h, 2, 0, 0, j, 0, 0, 0, 0, m, g);
	                i = f;
	                return
	            }

	            function yv(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                do if (!((c[h >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0)) {
	                    if ((c[h >> 2] | 0) != (c[k >> 2] | 0)) {
	                        c[g >> 2] = Yq(c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                        break
	                    }
	                    if ((c[j >> 2] | 0) < (c[l >> 2] | 0)) {
	                        c[g >> 2] = 1;
	                        break
	                    }
	                    if ((c[j >> 2] | 0) > (c[l >> 2] | 0)) {
	                        c[g >> 2] = -1;
	                        break
	                    } else {
	                        c[g >> 2] = 0;
	                        break
	                    }
	                } else c[g >> 2] = -2; while (0);
	                i = f;
	                return c[g >> 2] | 0
	            }

	            function zv(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 24 | 0;
	                g = d + 20 | 0;
	                h = d + 16 | 0;
	                j = d + 12 | 0;
	                k = d + 8 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                if (((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2] | 0) != 0 : 0) {
	                    b = c[c[h >> 2] >> 2] | 0;
	                    if ((b | 0) == 6) {
	                        a = c[(c[h >> 2] | 0) + 28 >> 2] | 0;
	                        if (c[(c[h >> 2] | 0) + 36 >> 2] | 0) {
	                            c[f >> 2] = Zu(a, c[(c[h >> 2] | 0) + 32 >> 2] | 0, c[(c[h >> 2] | 0) + 36 >> 2] | 0, c[(c[h >> 2] | 0) + 40 >> 2] | 0) | 0;
	                            l = c[f >> 2] | 0;
	                            i = d;
	                            return l | 0
	                        }
	                        c[j >> 2] = a;
	                        a = c[j >> 2] | 0;
	                        if ((c[j >> 2] | 0) == (c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2] | 0)) {
	                            g = c[j >> 2] | 0;
	                            c[f >> 2] = Zu(a, 0, g, Lv(c[j >> 2] | 0) | 0) | 0;
	                            l = c[f >> 2] | 0;
	                            i = d;
	                            return l | 0
	                        }
	                        switch (c[a + 4 >> 2] | 0) {
	                            case 13:
	                            case 12:
	                            case 9:
	                            case 8:
	                            case 7:
	                            case 5:
	                            case 4:
	                            case 3:
	                            case 1:
	                            {
	                                c[k >> 2] = Mv(c[j >> 2] | 0) | 0;
	                                c[j >> 2] = c[(c[j >> 2] | 0) + 20 >> 2];
	                                c[f >> 2] = Zu(c[j >> 2] | 0, (c[k >> 2] | 0) - 1 | 0, c[j >> 2] | 0, (c[k >> 2] | 0) + 1 | 0) | 0;
	                                l = c[f >> 2] | 0;
	                                i = d;
	                                return l | 0
	                            }
	                            case 2:
	                            {
	                                c[f >> 2] = Zu(c[j >> 2] | 0, 0, c[j >> 2] | 0, Lv(c[j >> 2] | 0) | 0) | 0;
	                                l = c[f >> 2] | 0;
	                                i = d;
	                                return l | 0
	                            }
	                            default:
	                            {
	                                c[f >> 2] = 0;
	                                l = c[f >> 2] | 0;
	                                i = d;
	                                return l | 0
	                            }
	                        }
	                    } else if ((b | 0) == 5) {
	                        c[f >> 2] = Zu(c[(c[h >> 2] | 0) + 28 >> 2] | 0, c[(c[h >> 2] | 0) + 32 >> 2] | 0, c[(c[h >> 2] | 0) + 28 >> 2] | 0, c[(c[h >> 2] | 0) + 32 >> 2] | 0) | 0;
	                        l = c[f >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    } else {
	                        h = c[33976] | 0;
	                        b = c[33980] | 0;
	                        c[e >> 2] = 131976;
	                        c[e + 4 >> 2] = 2022;
	                        Db[h & 511](b, 132256, e);
	                        c[f >> 2] = 0;
	                        l = c[f >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    }
	                }
	                c[f >> 2] = 0;
	                l = c[f >> 2] | 0;
	                i = d;
	                return l | 0
	            }

	            function Av(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 24 | 0;
	                g = d + 20 | 0;
	                h = d + 16 | 0;
	                j = d + 12 | 0;
	                k = d + 8 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                a:do if (!(c[h >> 2] | 0))c[f >> 2] = 0; else {
	                    if (((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2] | 0) != 0 : 0) {
	                        b = c[c[h >> 2] >> 2] | 0;
	                        if ((b | 0) == 5) {
	                            c[j >> 2] = c[(c[h >> 2] | 0) + 28 >> 2];
	                            switch (c[(c[j >> 2] | 0) + 4 >> 2] | 0) {
	                                case 4:
	                                case 3:
	                                case 8:
	                                case 7:
	                                {
	                                    a = c[j >> 2] | 0;
	                                    l = c[j >> 2] | 0;
	                                    if (!(c[(c[j >> 2] | 0) + 40 >> 2] | 0)) {
	                                        c[f >> 2] = Zu(a, 0, l, 0) | 0;
	                                        break a
	                                    } else {
	                                        c[f >> 2] = Zu(a, 0, l, xy(c[(c[j >> 2] | 0) + 40 >> 2] | 0) | 0) | 0;
	                                        break a
	                                    }
	                                    break
	                                }
	                                case 13:
	                                case 12:
	                                case 9:
	                                case 5:
	                                case 1:
	                                case 2:
	                                {
	                                    c[f >> 2] = Zu(c[j >> 2] | 0, 0, c[j >> 2] | 0, Lv(c[j >> 2] | 0) | 0) | 0;
	                                    break a;
	                                    break
	                                }
	                                default:
	                                {
	                                    c[f >> 2] = 0;
	                                    break a
	                                }
	                            }
	                        } else if ((b | 0) == 6) {
	                            c[k >> 2] = c[(c[h >> 2] | 0) + 28 >> 2];
	                            b = c[k >> 2] | 0;
	                            if (c[(c[h >> 2] | 0) + 36 >> 2] | 0) {
	                                c[f >> 2] = Zu(b, c[(c[h >> 2] | 0) + 32 >> 2] | 0, c[(c[h >> 2] | 0) + 36 >> 2] | 0, c[(c[h >> 2] | 0) + 40 >> 2] | 0) | 0;
	                                break
	                            }
	                            switch (c[b + 4 >> 2] | 0) {
	                                case 13:
	                                case 12:
	                                case 9:
	                                case 5:
	                                case 1:
	                                case 2:
	                                {
	                                    c[f >> 2] = Zu(c[k >> 2] | 0, 0, c[k >> 2] | 0, Lv(c[k >> 2] | 0) | 0) | 0;
	                                    break a;
	                                    break
	                                }
	                                case 4:
	                                case 3:
	                                case 8:
	                                case 7:
	                                {
	                                    b = c[k >> 2] | 0;
	                                    l = c[k >> 2] | 0;
	                                    if (!(c[(c[k >> 2] | 0) + 40 >> 2] | 0)) {
	                                        c[f >> 2] = Zu(b, 0, l, 0) | 0;
	                                        break a
	                                    } else {
	                                        c[f >> 2] = Zu(b, 0, l, xy(c[(c[k >> 2] | 0) + 40 >> 2] | 0) | 0) | 0;
	                                        break a
	                                    }
	                                    break
	                                }
	                                default:
	                                {
	                                    c[f >> 2] = 0;
	                                    break a
	                                }
	                            }
	                        } else {
	                            l = c[33976] | 0;
	                            b = c[33980] | 0;
	                            c[e >> 2] = 131976;
	                            c[e + 4 >> 2] = 2167;
	                            Db[l & 511](b, 132256, e);
	                            c[f >> 2] = 0;
	                            break
	                        }
	                    }
	                    c[f >> 2] = 0
	                } while (0);
	                i = d;
	                return c[f >> 2] | 0
	            }

	            function Bv(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    c[f >> 2] = -1;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                d = c[c[g >> 2] >> 2] | 0;
	                if ((d | 0) == 5) {
	                    c[c[h >> 2] >> 2] = c[(c[g >> 2] | 0) + 28 >> 2];
	                    if ((c[(c[g >> 2] | 0) + 32 >> 2] | 0) <= 0)c[c[j >> 2] >> 2] = 0; else c[c[j >> 2] >> 2] = c[(c[g >> 2] | 0) + 32 >> 2];
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                } else if ((d | 0) == 6) {
	                    c[c[h >> 2] >> 2] = c[(c[g >> 2] | 0) + 28 >> 2];
	                    if ((c[(c[g >> 2] | 0) + 32 >> 2] | 0) <= 0)c[c[j >> 2] >> 2] = 0; else c[c[j >> 2] >> 2] = c[(c[g >> 2] | 0) + 32 >> 2];
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                } else {
	                    c[f >> 2] = -1;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                return 0
	            }

	            function Cv(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    c[f >> 2] = -1;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                d = c[c[g >> 2] >> 2] | 0;
	                if ((d | 0) == 6) {
	                    c[c[h >> 2] >> 2] = c[(c[g >> 2] | 0) + 28 >> 2];
	                    if ((c[(c[g >> 2] | 0) + 32 >> 2] | 0) <= 0)c[c[j >> 2] >> 2] = 0; else c[c[j >> 2] >> 2] = c[(c[g >> 2] | 0) + 32 >> 2];
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                } else if ((d | 0) == 5) {
	                    c[c[h >> 2] >> 2] = c[(c[g >> 2] | 0) + 28 >> 2];
	                    if ((c[(c[g >> 2] | 0) + 32 >> 2] | 0) <= 0)c[c[j >> 2] >> 2] = 0; else c[c[j >> 2] >> 2] = c[(c[g >> 2] | 0) + 32 >> 2];
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                } else {
	                    c[f >> 2] = -1;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                return 0
	            }

	            function Dv(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e;
	                g = e + 32 | 0;
	                h = e + 28 | 0;
	                j = e + 24 | 0;
	                k = e + 20 | 0;
	                l = e + 16 | 0;
	                m = e + 12 | 0;
	                n = e + 8 | 0;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    c[g >> 2] = -1;
	                    o = c[g >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                c[l >> 2] = c[c[h >> 2] >> 2];
	                if ((c[l >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                    c[m >> 2] = c[c[j >> 2] >> 2];
	                    while (1) {
	                        if ((c[k >> 2] | 0) < 0) {
	                            p = 30;
	                            break
	                        }
	                        while (1) {
	                            if (!(c[l >> 2] | 0))break;
	                            if (((c[(c[l >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[l >> 2] | 0) + 4 >> 2] | 0) != 9 : 0) ? (c[(c[l >> 2] | 0) + 4 >> 2] | 0) != 13 : 0)break;
	                            d = c[l >> 2] | 0;
	                            if ((c[m >> 2] | 0) > 0) {
	                                c[l >> 2] = Kv(d, c[m >> 2] | 0) | 0;
	                                c[m >> 2] = 0;
	                                continue
	                            } else {
	                                c[l >> 2] = lv(d, 0) | 0;
	                                c[m >> 2] = 0;
	                                continue
	                            }
	                        }
	                        if (!(c[l >> 2] | 0)) {
	                            p = 16;
	                            break
	                        }
	                        if (!(c[m >> 2] | 0))c[m >> 2] = 1;
	                        if (!(c[k >> 2] | 0)) {
	                            p = 20;
	                            break
	                        }
	                        c[n >> 2] = 0;
	                        if ((c[(c[l >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[l >> 2] | 0) + 40 >> 2] | 0) != 0 : 0)c[n >> 2] = xy(c[(c[l >> 2] | 0) + 40 >> 2] | 0) | 0;
	                        if ((c[m >> 2] | 0) > (c[n >> 2] | 0)) {
	                            d = c[33976] | 0;
	                            b = c[33980] | 0;
	                            c[f >> 2] = 131976;
	                            c[f + 4 >> 2] = 2436;
	                            Db[d & 511](b, 131944, f);
	                            c[m >> 2] = c[n >> 2]
	                        }
	                        if (((c[m >> 2] | 0) + (c[k >> 2] | 0) | 0) < (c[n >> 2] | 0))if (((c[m >> 2] | 0) + (c[k >> 2] | 0) | 0) < (c[n >> 2] | 0)) {
	                            p = 29;
	                            break
	                        } else continue; else {
	                            c[k >> 2] = (c[k >> 2] | 0) - ((c[n >> 2] | 0) - (c[m >> 2] | 0));
	                            c[l >> 2] = lv(c[l >> 2] | 0, 0) | 0;
	                            c[m >> 2] = 0;
	                            continue
	                        }
	                    }
	                    if ((p | 0) == 16) {
	                        c[c[h >> 2] >> 2] = 0;
	                        c[c[j >> 2] >> 2] = 0;
	                        c[g >> 2] = -1;
	                        o = c[g >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    } else if ((p | 0) == 20) {
	                        c[c[h >> 2] >> 2] = c[l >> 2];
	                        c[c[j >> 2] >> 2] = c[m >> 2];
	                        c[g >> 2] = 0;
	                        o = c[g >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    } else if ((p | 0) == 29) {
	                        c[m >> 2] = (c[m >> 2] | 0) + (c[k >> 2] | 0);
	                        c[c[h >> 2] >> 2] = c[l >> 2];
	                        c[c[j >> 2] >> 2] = c[m >> 2];
	                        c[g >> 2] = 0;
	                        o = c[g >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    } else if ((p | 0) == 30) {
	                        c[g >> 2] = -1;
	                        o = c[g >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    }
	                }
	                c[g >> 2] = -1;
	                o = c[g >> 2] | 0;
	                i = e;
	                return o | 0
	            }

	            function Ev(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[k >> 2] = 0;
	                if (((c[f >> 2] | 0) != 0 ? (c[c[f >> 2] >> 2] | 0) != 0 : 0) ? !((c[g >> 2] | 0) == 0 ? 1 : (c[(c[c[f >> 2] >> 2] | 0) + 4 >> 2] | 0) == 18) : 0) {
	                    c[h >> 2] = c[c[f >> 2] >> 2];
	                    c[j >> 2] = c[c[g >> 2] >> 2];
	                    if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 9 : 0) {
	                        if ((c[j >> 2] | 0) > 0 ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 13 : 0)l = 9
	                    } else l = 8;
	                    if ((l | 0) == 8 ? (c[j >> 2] | 0) > 0 : 0)l = 9;
	                    if ((l | 0) == 9)c[h >> 2] = Kv(c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                    while (1) {
	                        if (!(c[h >> 2] | 0))break;
	                        m = c[h >> 2] | 0;
	                        if (!(c[(c[h >> 2] | 0) + 16 >> 2] | 0)) {
	                            l = 13;
	                            break
	                        }
	                        c[h >> 2] = c[m + 16 >> 2]
	                    }
	                    do if ((l | 0) == 13) {
	                        if ((c[m + 4 >> 2] | 0) != 1 ? (c[(c[h >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) {
	                            c[k >> 2] = xy(c[(c[h >> 2] | 0) + 40 >> 2] | 0) | 0;
	                            break
	                        }
	                        c[e >> 2] = -1;
	                        n = c[e >> 2] | 0;
	                        i = d;
	                        return n | 0
	                    } while (0);
	                    if (!(c[h >> 2] | 0)) {
	                        c[e >> 2] = -1;
	                        n = c[e >> 2] | 0;
	                        i = d;
	                        return n | 0
	                    } else {
	                        c[c[f >> 2] >> 2] = c[h >> 2];
	                        c[c[g >> 2] >> 2] = c[k >> 2];
	                        c[e >> 2] = 0;
	                        n = c[e >> 2] | 0;
	                        i = d;
	                        return n | 0
	                    }
	                }
	                c[e >> 2] = -1;
	                n = c[e >> 2] | 0;
	                i = d;
	                return n | 0
	            }

	            function Fv(b, e, f, g, h) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0;
	                j = i;
	                i = i + 48 | 0;
	                k = j + 36 | 0;
	                l = j + 32 | 0;
	                m = j + 28 | 0;
	                n = j + 24 | 0;
	                o = j + 20 | 0;
	                p = j + 16 | 0;
	                q = j + 12 | 0;
	                r = j + 8 | 0;
	                s = j + 4 | 0;
	                t = j;
	                u = j + 40 | 0;
	                c[l >> 2] = b;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                c[p >> 2] = h;
	                if (!(c[l >> 2] | 0)) {
	                    c[k >> 2] = -1;
	                    v = c[k >> 2] | 0;
	                    i = j;
	                    return v | 0
	                }
	                if (((c[m >> 2] | 0) != 0 ? (c[c[m >> 2] >> 2] | 0) != 0 : 0) ? !((c[n >> 2] | 0) == 0 ? 1 : (c[(c[c[m >> 2] >> 2] | 0) + 4 >> 2] | 0) == 18) : 0) {
	                    if ((c[o >> 2] | 0) == 0 | (c[p >> 2] | 0) == 0) {
	                        c[k >> 2] = -1;
	                        v = c[k >> 2] | 0;
	                        i = j;
	                        return v | 0
	                    }
	                    c[q >> 2] = c[c[m >> 2] >> 2];
	                    c[s >> 2] = (c[c[n >> 2] >> 2] | 0) - 1;
	                    a[u >> 0] = a[c[l >> 2] >> 0] | 0;
	                    a:while (1) {
	                        if (!(c[q >> 2] | 0)) {
	                            w = 28;
	                            break
	                        }
	                        b:do if ((c[(c[q >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[q >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) {
	                            c[t >> 2] = xy(c[(c[q >> 2] | 0) + 40 >> 2] | 0) | 0;
	                            while (1) {
	                                if ((c[s >> 2] | 0) > (c[t >> 2] | 0))break b;
	                                if (!(d[u >> 0] | 0)) {
	                                    w = 21;
	                                    break a
	                                }
	                                c[r >> 2] = vy((c[(c[q >> 2] | 0) + 40 >> 2] | 0) + (c[s >> 2] | 0) | 0, a[u >> 0] | 0) | 0;
	                                if (!(c[r >> 2] | 0)) {
	                                    c[s >> 2] = (c[t >> 2] | 0) + 1;
	                                    continue
	                                }
	                                c[s >> 2] = (c[r >> 2] | 0) - (c[(c[q >> 2] | 0) + 40 >> 2] | 0);
	                                if (Nv(c[l >> 2] | 0, c[q >> 2] | 0, (c[s >> 2] | 0) + 1 | 0, c[o >> 2] | 0, c[p >> 2] | 0) | 0) {
	                                    w = 18;
	                                    break a
	                                }
	                                c[s >> 2] = (c[s >> 2] | 0) + 1
	                            }
	                        } while (0);
	                        if ((c[q >> 2] | 0) == (c[c[o >> 2] >> 2] | 0) ? (c[s >> 2] | 0) >= (c[c[p >> 2] >> 2] | 0) : 0) {
	                            w = 24;
	                            break
	                        }
	                        c[q >> 2] = lv(c[q >> 2] | 0, 0) | 0;
	                        if (!(c[q >> 2] | 0)) {
	                            w = 26;
	                            break
	                        }
	                        c[s >> 2] = 1
	                    }
	                    if ((w | 0) == 18) {
	                        c[c[m >> 2] >> 2] = c[q >> 2];
	                        c[c[n >> 2] >> 2] = (c[s >> 2] | 0) + 1;
	                        c[k >> 2] = 1;
	                        v = c[k >> 2] | 0;
	                        i = j;
	                        return v | 0
	                    } else if ((w | 0) == 21) {
	                        c[c[m >> 2] >> 2] = c[q >> 2];
	                        c[c[n >> 2] >> 2] = (c[s >> 2] | 0) + 1;
	                        c[c[o >> 2] >> 2] = c[q >> 2];
	                        c[c[p >> 2] >> 2] = (c[s >> 2] | 0) + 1;
	                        c[k >> 2] = 1;
	                        v = c[k >> 2] | 0;
	                        i = j;
	                        return v | 0
	                    } else if ((w | 0) == 24) {
	                        c[k >> 2] = 0;
	                        v = c[k >> 2] | 0;
	                        i = j;
	                        return v | 0
	                    } else if ((w | 0) == 26) {
	                        c[k >> 2] = 0;
	                        v = c[k >> 2] | 0;
	                        i = j;
	                        return v | 0
	                    } else if ((w | 0) == 28) {
	                        c[k >> 2] = 0;
	                        v = c[k >> 2] | 0;
	                        i = j;
	                        return v | 0
	                    }
	                }
	                c[k >> 2] = -1;
	                v = c[k >> 2] | 0;
	                i = j;
	                return v | 0
	            }

	            function Gv(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                if ((c[g >> 2] | 0) < 0) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[h >> 2] = Cb[c[135744 >> 2] & 511](48) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    mv(132288);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } else {
	                    b = (c[h >> 2] | 0) + 0 | 0;
	                    a = b + 48 | 0;
	                    do {
	                        c[b >> 2] = 0;
	                        b = b + 4 | 0
	                    } while ((b | 0) < (a | 0));
	                    c[c[h >> 2] >> 2] = 5;
	                    c[(c[h >> 2] | 0) + 28 >> 2] = c[f >> 2];
	                    c[(c[h >> 2] | 0) + 32 >> 2] = c[g >> 2];
	                    c[e >> 2] = c[h >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                return 0
	            }

	            function Hv(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = -1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a:do switch (c[(c[e >> 2] | 0) + 4 >> 2] | 0) {
	                    case 1:
	                    case 9:
	                    case 13:
	                    {
	                        c[e >> 2] = c[(c[e >> 2] | 0) + 12 >> 2];
	                        while (1) {
	                            if (!(c[e >> 2] | 0))break a;
	                            if ((c[(c[e >> 2] | 0) + 4 >> 2] | 0) == 1)c[f >> 2] = (c[f >> 2] | 0) + 1;
	                            c[e >> 2] = c[(c[e >> 2] | 0) + 24 >> 2]
	                        }
	                        break
	                    }
	                    case 2:
	                    {
	                        c[d >> 2] = -1;
	                        g = c[d >> 2] | 0;
	                        i = b;
	                        return g | 0
	                    }
	                    case 5:
	                    case 4:
	                    case 3:
	                    case 8:
	                    case 7:
	                    {
	                        c[f >> 2] = xy(c[(c[e >> 2] | 0) + 40 >> 2] | 0) | 0;
	                        break
	                    }
	                    default:
	                    {
	                        c[d >> 2] = -1;
	                        g = c[d >> 2] | 0;
	                        i = b;
	                        return g | 0
	                    }
	                } while (0);
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function Iv(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (((c[g >> 2] | 0) == 0 ? (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) == 47 : 0) ? (d[(c[c[f >> 2] >> 2] | 0) + 1 >> 0] | 0 | 0) != 49 : 0)xv(c[f >> 2] | 0, 1901, 132432, 0);
	                if ((c[g >> 2] | 0) != 0 ? (b = c[f >> 2] | 0, Tq(b, wr(c[g >> 2] | 0) | 0) | 0, zb[c[135736 >> 2] & 511](c[g >> 2] | 0), os(c[f >> 2] | 0, 1), (c[(c[f >> 2] | 0) + 8 >> 2] | 0) != 0) : 0) {
	                    i = e;
	                    return
	                }
	                while (1) {
	                    if ((d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) != 47)break;
	                    c[h >> 2] = 0;
	                    g = c[f >> 2] | 0;
	                    if (d[c[c[f >> 2] >> 2] >> 0] | 0)c[g >> 2] = (c[g >> 2] | 0) + 1;
	                    while (1) {
	                        if ((d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) < 48)break;
	                        if ((d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) > 57)break;
	                        c[h >> 2] = ((c[h >> 2] | 0) * 10 | 0) + ((d[c[c[f >> 2] >> 2] >> 0] | 0) - 48);
	                        g = c[f >> 2] | 0;
	                        if (!(d[c[c[f >> 2] >> 2] >> 0] | 0))continue;
	                        c[g >> 2] = (c[g >> 2] | 0) + 1
	                    }
	                    Ov(c[f >> 2] | 0, c[h >> 2] | 0)
	                }
	                i = e;
	                return
	            }

	            function Jv(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[g >> 2] | 0))c[g >> 2] = Ls(c[f >> 2] | 0) | 0;
	                if (!(c[g >> 2] | 0)) {
	                    Nq(c[f >> 2] | 0, 7);
	                    i = e;
	                    return
	                }
	                while (1) {
	                    if (!(c[g >> 2] | 0)) {
	                        l = 25;
	                        break
	                    }
	                    c[(c[f >> 2] | 0) + 8 >> 2] = 0;
	                    Pv(c[f >> 2] | 0, c[g >> 2] | 0);
	                    if ((c[(c[f >> 2] | 0) + 8 >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 8 >> 2] | 0) != 1900 : 0) {
	                        l = 25;
	                        break
	                    }
	                    if (c[(c[f >> 2] | 0) + 16 >> 2] | 0) {
	                        c[h >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                        b = c[c[h >> 2] >> 2] | 0;
	                        if ((b | 0) == 7) {
	                            c[j >> 2] = c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + 28 >> 2];
	                            if ((c[j >> 2] | 0) != 0 ? (c[c[j >> 2] >> 2] | 0) > 0 : 0) {
	                                l = 25;
	                                break
	                            }
	                        } else if (((b | 0) == 1 ? (c[k >> 2] = c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2], (c[k >> 2] | 0) != 0) : 0) ? (c[c[k >> 2] >> 2] | 0) > 0 : 0) {
	                            l = 25;
	                            break
	                        }
	                        do {
	                            c[h >> 2] = Sq(c[f >> 2] | 0) | 0;
	                            if (c[h >> 2] | 0)Qq(c[h >> 2] | 0)
	                        } while ((c[h >> 2] | 0) != 0)
	                    }
	                    while (1) {
	                        do if ((d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) == 32)m = 1; else {
	                            if (9 <= (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                m = 1;
	                                break
	                            }
	                            m = (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        n = c[f >> 2] | 0;
	                        if (!m)break;
	                        b = c[f >> 2] | 0;
	                        if (!(d[c[n >> 2] >> 0] | 0))continue;
	                        c[b >> 2] = (c[b >> 2] | 0) + 1
	                    }
	                    c[g >> 2] = Ls(n) | 0
	                }
	                if ((l | 0) == 25) {
	                    i = e;
	                    return
	                }
	            }

	            function Kv(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                    c[f >> 2] = c[(c[f >> 2] | 0) + 12 >> 2];
	                    c[h >> 2] = 0;
	                    while (1) {
	                        if ((c[h >> 2] | 0) > (c[g >> 2] | 0)) {
	                            j = 13;
	                            break
	                        }
	                        k = c[f >> 2] | 0;
	                        if (!(c[f >> 2] | 0)) {
	                            j = 7;
	                            break
	                        }
	                        if (!(((c[k + 4 >> 2] | 0) != 1 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 9 : 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 13 : 0))j = 11;
	                        if ((j | 0) == 11 ? (j = 0, c[h >> 2] = (c[h >> 2] | 0) + 1, (c[h >> 2] | 0) == (c[g >> 2] | 0)) : 0) {
	                            j = 13;
	                            break
	                        }
	                        c[f >> 2] = c[(c[f >> 2] | 0) + 24 >> 2]
	                    }
	                    if ((j | 0) == 7) {
	                        c[e >> 2] = k;
	                        l = c[e >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    } else if ((j | 0) == 13) {
	                        c[e >> 2] = c[f >> 2];
	                        l = c[e >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    }
	                }
	                c[e >> 2] = c[f >> 2];
	                l = c[e >> 2] | 0;
	                i = d;
	                return l | 0
	            }

	            function Lv(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                    c[e >> 2] = c[(c[e >> 2] | 0) + 12 >> 2];
	                    c[f >> 2] = 0;
	                    while (1) {
	                        if (!(c[e >> 2] | 0))break;
	                        if (!(((c[(c[e >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[e >> 2] | 0) + 4 >> 2] | 0) != 9 : 0) ? (c[(c[e >> 2] | 0) + 4 >> 2] | 0) != 13 : 0))c[f >> 2] = (c[f >> 2] | 0) + 1;
	                        c[e >> 2] = c[(c[e >> 2] | 0) + 24 >> 2]
	                    }
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[d >> 2] = -1;
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function Mv(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                    c[f >> 2] = 1;
	                    while (1) {
	                        if (!(c[e >> 2] | 0))break;
	                        if (!(((c[(c[e >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[e >> 2] | 0) + 4 >> 2] | 0) != 9 : 0) ? (c[(c[e >> 2] | 0) + 4 >> 2] | 0) != 13 : 0))c[f >> 2] = (c[f >> 2] | 0) + 1;
	                        c[e >> 2] = c[(c[e >> 2] | 0) + 28 >> 2]
	                    }
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[d >> 2] = -1;
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function Nv(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                g = i;
	                i = i + 48 | 0;
	                h = g + 44 | 0;
	                j = g + 40 | 0;
	                k = g + 36 | 0;
	                l = g + 32 | 0;
	                m = g + 28 | 0;
	                n = g + 24 | 0;
	                o = g + 20 | 0;
	                p = g + 16 | 0;
	                q = g + 12 | 0;
	                r = g + 8 | 0;
	                s = g + 4 | 0;
	                t = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                if (!(c[j >> 2] | 0)) {
	                    c[h >> 2] = -1;
	                    u = c[h >> 2] | 0;
	                    i = g;
	                    return u | 0
	                }
	                if ((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                    if (((c[m >> 2] | 0) != 0 ? (c[c[m >> 2] >> 2] | 0) != 0 : 0) ? !((c[n >> 2] | 0) == 0 ? 1 : (c[(c[c[m >> 2] >> 2] | 0) + 4 >> 2] | 0) == 18) : 0) {
	                        c[o >> 2] = c[k >> 2];
	                        c[p >> 2] = (c[l >> 2] | 0) - 1;
	                        c[r >> 2] = xy(c[j >> 2] | 0) | 0;
	                        while (1) {
	                            if ((c[r >> 2] | 0) <= 0) {
	                                v = 27;
	                                break
	                            }
	                            if ((c[o >> 2] | 0) == (c[c[m >> 2] >> 2] | 0) ? ((c[p >> 2] | 0) + (c[r >> 2] | 0) | 0) > (c[c[n >> 2] >> 2] | 0) : 0) {
	                                v = 14;
	                                break
	                            }
	                            if ((c[(c[o >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[o >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) {
	                                c[q >> 2] = xy(c[(c[o >> 2] | 0) + 40 >> 2] | 0) | 0;
	                                if ((c[q >> 2] | 0) >= ((c[p >> 2] | 0) + (c[r >> 2] | 0) | 0)) {
	                                    v = 18;
	                                    break
	                                }
	                                c[t >> 2] = (c[q >> 2] | 0) - (c[p >> 2] | 0);
	                                c[s >> 2] = ((sy((c[(c[o >> 2] | 0) + 40 >> 2] | 0) + (c[p >> 2] | 0) | 0, c[j >> 2] | 0, c[t >> 2] | 0) | 0) != 0 ^ 1) & 1;
	                                if (!(c[s >> 2] | 0)) {
	                                    v = 23;
	                                    break
	                                }
	                                c[j >> 2] = (c[j >> 2] | 0) + (c[t >> 2] | 0);
	                                c[r >> 2] = (c[r >> 2] | 0) - (c[t >> 2] | 0)
	                            }
	                            c[o >> 2] = lv(c[o >> 2] | 0, 0) | 0;
	                            if (!(c[o >> 2] | 0)) {
	                                v = 25;
	                                break
	                            }
	                            c[p >> 2] = 0
	                        }
	                        if ((v | 0) == 14) {
	                            c[h >> 2] = 0;
	                            u = c[h >> 2] | 0;
	                            i = g;
	                            return u | 0
	                        } else if ((v | 0) == 18) {
	                            c[s >> 2] = ((sy((c[(c[o >> 2] | 0) + 40 >> 2] | 0) + (c[p >> 2] | 0) | 0, c[j >> 2] | 0, c[r >> 2] | 0) | 0) != 0 ^ 1) & 1;
	                            if (c[s >> 2] | 0) {
	                                c[c[m >> 2] >> 2] = c[o >> 2];
	                                c[c[n >> 2] >> 2] = (c[p >> 2] | 0) + (c[r >> 2] | 0);
	                                c[h >> 2] = 1;
	                                u = c[h >> 2] | 0;
	                                i = g;
	                                return u | 0
	                            } else {
	                                c[h >> 2] = 0;
	                                u = c[h >> 2] | 0;
	                                i = g;
	                                return u | 0
	                            }
	                        } else if ((v | 0) == 23) {
	                            c[h >> 2] = 0;
	                            u = c[h >> 2] | 0;
	                            i = g;
	                            return u | 0
	                        } else if ((v | 0) == 25) {
	                            c[h >> 2] = 0;
	                            u = c[h >> 2] | 0;
	                            i = g;
	                            return u | 0
	                        } else if ((v | 0) == 27) {
	                            c[h >> 2] = 1;
	                            u = c[h >> 2] | 0;
	                            i = g;
	                            return u | 0
	                        }
	                    }
	                    c[h >> 2] = -1;
	                    u = c[h >> 2] | 0;
	                    i = g;
	                    return u | 0
	                }
	                c[h >> 2] = -1;
	                u = c[h >> 2] | 0;
	                i = g;
	                return u | 0
	            }

	            function Ov(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[g >> 2] = 0;
	                if ((c[(c[e >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 16 >> 2] >> 2] | 0) == 1 : 0) {
	                    c[h >> 2] = Sq(c[e >> 2] | 0) | 0;
	                    c[j >> 2] = c[(c[h >> 2] | 0) + 4 >> 2];
	                    if (!((c[f >> 2] | 0) <= 0 | (c[j >> 2] | 0) == 0) ? (c[c[j >> 2] >> 2] | 0) == 1 : 0) {
	                        c[g >> 2] = Kv(c[c[(c[j >> 2] | 0) + 8 >> 2] >> 2] | 0, c[f >> 2] | 0) | 0;
	                        if (!(c[g >> 2] | 0)) {
	                            Qq(c[h >> 2] | 0);
	                            f = c[e >> 2] | 0;
	                            Tq(f, gr(0) | 0) | 0;
	                            i = d;
	                            return
	                        } else {
	                            c[c[(c[j >> 2] | 0) + 8 >> 2] >> 2] = c[g >> 2];
	                            Tq(c[e >> 2] | 0, c[h >> 2] | 0) | 0;
	                            i = d;
	                            return
	                        }
	                    }
	                    Qq(c[h >> 2] | 0);
	                    h = c[e >> 2] | 0;
	                    Tq(h, gr(0) | 0) | 0;
	                    i = d;
	                    return
	                }
	                Nq(c[e >> 2] | 0, 11);
	                i = d;
	                return
	            }

	            function Pv(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0;
	                f = i;
	                i = i + 64 | 0;
	                g = f + 48 | 0;
	                h = f + 44 | 0;
	                j = f + 40 | 0;
	                k = f + 36 | 0;
	                l = f + 32 | 0;
	                m = f + 28 | 0;
	                n = f + 24 | 0;
	                o = f + 20 | 0;
	                p = f + 16 | 0;
	                q = f + 12 | 0;
	                r = f + 8 | 0;
	                s = f + 4 | 0;
	                t = f;
	                c[g >> 2] = b;
	                c[h >> 2] = e;
	                if (!(c[h >> 2] | 0))c[h >> 2] = Ls(c[g >> 2] | 0) | 0;
	                e = c[g >> 2] | 0;
	                if (!(c[h >> 2] | 0)) {
	                    Nq(e, 7);
	                    i = f;
	                    return
	                }
	                b = c[g >> 2] | 0;
	                if ((d[c[e >> 2] >> 0] | 0 | 0) != 40) {
	                    Nq(b, 7);
	                    i = f;
	                    return
	                }
	                e = c[g >> 2] | 0;
	                if (d[c[b >> 2] >> 0] | 0)c[e >> 2] = (c[e >> 2] | 0) + 1;
	                c[m >> 2] = 1;
	                c[l >> 2] = xy(c[c[g >> 2] >> 2] | 0) | 0;
	                c[l >> 2] = (c[l >> 2] | 0) + 1;
	                c[j >> 2] = Cb[c[135752 >> 2] & 511](c[l >> 2] | 0) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    mv(132344);
	                    i = f;
	                    return
	                }
	                c[k >> 2] = c[j >> 2];
	                a:while (1) {
	                    if (!(d[c[c[g >> 2] >> 2] >> 0] | 0))break;
	                    do if ((d[c[c[g >> 2] >> 2] >> 0] | 0 | 0) == 41) {
	                        c[m >> 2] = (c[m >> 2] | 0) + -1;
	                        if (!(c[m >> 2] | 0)) {
	                            u = 15;
	                            break a
	                        }
	                    } else {
	                        if ((d[c[c[g >> 2] >> 2] >> 0] | 0 | 0) == 40) {
	                            c[m >> 2] = (c[m >> 2] | 0) + 1;
	                            break
	                        }
	                        if ((d[c[c[g >> 2] >> 2] >> 0] | 0 | 0) == 94) {
	                            if (((d[(c[c[g >> 2] >> 2] | 0) + 1 >> 0] | 0 | 0) != 41 ? (d[(c[c[g >> 2] >> 2] | 0) + 1 >> 0] | 0 | 0) != 40 : 0) ? (d[(c[c[g >> 2] >> 2] | 0) + 1 >> 0] | 0 | 0) != 94 : 0)break;
	                            l = c[g >> 2] | 0;
	                            if (d[c[c[g >> 2] >> 2] >> 0] | 0)c[l >> 2] = (c[l >> 2] | 0) + 1
	                        }
	                    } while (0);
	                    l = a[c[c[g >> 2] >> 2] >> 0] | 0;
	                    e = c[k >> 2] | 0;
	                    c[k >> 2] = e + 1;
	                    a[e >> 0] = l;
	                    l = c[g >> 2] | 0;
	                    if (!(d[c[c[g >> 2] >> 2] >> 0] | 0))continue;
	                    c[l >> 2] = (c[l >> 2] | 0) + 1
	                }
	                if ((u | 0) == 15 ? (u = c[g >> 2] | 0, (d[c[c[g >> 2] >> 2] >> 0] | 0 | 0) != 0) : 0)c[u >> 2] = (c[u >> 2] | 0) + 1;
	                a[c[k >> 2] >> 0] = 0;
	                if ((c[m >> 2] | 0) != 0 ? (d[c[c[g >> 2] >> 2] >> 0] | 0 | 0) == 0 : 0) {
	                    zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                    Nq(c[g >> 2] | 0, 16);
	                    i = f;
	                    return
	                }
	                do if (qy(c[h >> 2] | 0, 132368) | 0) {
	                    c[n >> 2] = c[c[g >> 2] >> 2];
	                    c[c[g >> 2] >> 2] = c[j >> 2];
	                    c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2];
	                    c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 72 >> 2] = 1;
	                    c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] = 1;
	                    Qs(c[g >> 2] | 0);
	                    c[c[g >> 2] >> 2] = c[n >> 2]
	                } else {
	                    if (qy(c[h >> 2] | 0, 132384) | 0) {
	                        c[o >> 2] = c[c[g >> 2] >> 2];
	                        c[c[g >> 2] >> 2] = c[j >> 2];
	                        m = c[g >> 2] | 0;
	                        do if ((d[c[j >> 2] >> 0] | 0 | 0) == 47) {
	                            ks(m);
	                            Iv(c[g >> 2] | 0, 0)
	                        } else {
	                            c[p >> 2] = Ls(m) | 0;
	                            if (c[p >> 2] | 0) {
	                                Iv(c[g >> 2] | 0, c[p >> 2] | 0);
	                                break
	                            }
	                            c[c[g >> 2] >> 2] = c[o >> 2];
	                            zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                            Nq(c[g >> 2] | 0, 7);
	                            i = f;
	                            return
	                        } while (0);
	                        c[c[g >> 2] >> 2] = c[o >> 2];
	                        break
	                    }
	                    m = (qy(c[h >> 2] | 0, 132392) | 0) != 0;
	                    k = c[g >> 2] | 0;
	                    if (!m) {
	                        xv(k, 1900, 132400, c[h >> 2] | 0);
	                        break
	                    }
	                    c[q >> 2] = c[k >> 2];
	                    c[c[g >> 2] >> 2] = c[j >> 2];
	                    c[r >> 2] = Ks(c[g >> 2] | 0) | 0;
	                    if (!(c[r >> 2] | 0)) {
	                        zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                        Nq(c[g >> 2] | 0, 16);
	                        i = f;
	                        return
	                    }
	                    while (1) {
	                        do if ((d[c[c[g >> 2] >> 2] >> 0] | 0 | 0) == 32)v = 1; else {
	                            if (9 <= (d[c[c[g >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[g >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                v = 1;
	                                break
	                            }
	                            v = (d[c[c[g >> 2] >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        w = d[c[c[g >> 2] >> 2] >> 0] | 0;
	                        if (!v)break;
	                        k = c[g >> 2] | 0;
	                        if (!w)continue;
	                        c[k >> 2] = (c[k >> 2] | 0) + 1
	                    }
	                    if ((w | 0) != 61) {
	                        zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                        Nq(c[g >> 2] | 0, 16);
	                        i = f;
	                        return
	                    }
	                    k = c[g >> 2] | 0;
	                    if (d[c[c[g >> 2] >> 2] >> 0] | 0)c[k >> 2] = (c[k >> 2] | 0) + 1;
	                    while (1) {
	                        do if ((d[c[c[g >> 2] >> 2] >> 0] | 0 | 0) == 32)x = 1; else {
	                            if (9 <= (d[c[c[g >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[g >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                x = 1;
	                                break
	                            }
	                            x = (d[c[c[g >> 2] >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        y = c[c[g >> 2] >> 2] | 0;
	                        if (!x)break;
	                        k = c[g >> 2] | 0;
	                        if (!(d[y >> 0] | 0))continue;
	                        c[k >> 2] = (c[k >> 2] | 0) + 1
	                    }
	                    c[t >> 2] = yl(y) | 0;
	                    if (!(c[t >> 2] | 0)) {
	                        zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                        Nq(c[g >> 2] | 0, 16);
	                        i = f;
	                        return
	                    }
	                    c[s >> 2] = Cl(c[t >> 2] | 0) | 0;
	                    Al(c[t >> 2] | 0);
	                    if (c[s >> 2] | 0) {
	                        rr(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[r >> 2] | 0, c[s >> 2] | 0) | 0;
	                        c[c[g >> 2] >> 2] = c[q >> 2];
	                        zb[c[135736 >> 2] & 511](c[s >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                        break
	                    }
	                    zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                    zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                    zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                    Nq(c[g >> 2] | 0, 15);
	                    i = f;
	                    return
	                } while (0);
	                zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                i = f;
	                return
	            }

	            function Qv(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](72) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    Xv(0, c[e >> 2] | 0, 132504);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    a = (c[f >> 2] | 0) + 0 | 0;
	                    h = a + 72 | 0;
	                    do {
	                        c[a >> 2] = 0;
	                        a = a + 4 | 0
	                    } while ((a | 0) < (h | 0));
	                    c[c[f >> 2] >> 2] = c[e >> 2];
	                    c[(c[f >> 2] | 0) + 8 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 4 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 12 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 16 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 52 >> 2] = 0;
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function Rv(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                while (1) {
	                    f = c[d >> 2] | 0;
	                    if ((c[(c[d >> 2] | 0) + 40 >> 2] | 0) <= 0)break;
	                    Yv(f)
	                }
	                if (c[f + 48 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 48 >> 2] | 0);
	                c[e >> 2] = 0;
	                while (1) {
	                    if ((c[e >> 2] | 0) >= (c[(c[d >> 2] | 0) + 8 >> 2] | 0))break;
	                    if (c[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + (c[e >> 2] << 2) >> 2] | 0)Zv(c[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + (c[e >> 2] << 2) >> 2] | 0);
	                    c[e >> 2] = (c[e >> 2] | 0) + 1
	                }
	                a:do if (c[(c[d >> 2] | 0) + 32 >> 2] | 0) {
	                    c[e >> 2] = 0;
	                    while (1) {
	                        if ((c[e >> 2] | 0) >= (c[(c[d >> 2] | 0) + 20 >> 2] | 0))break a;
	                        if (c[(c[(c[d >> 2] | 0) + 32 >> 2] | 0) + (c[e >> 2] << 2) >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[(c[d >> 2] | 0) + 32 >> 2] | 0) + (c[e >> 2] << 2) >> 2] | 0);
	                        c[e >> 2] = (c[e >> 2] | 0) + 1
	                    }
	                } while (0);
	                if (c[(c[d >> 2] | 0) + 16 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 16 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 28 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 28 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 32 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 32 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 64 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 64 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function Sv(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                } else {
	                    c[(c[f >> 2] | 0) + 60 >> 2] = c[g >> 2];
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                return 0
	            }

	            function Tv(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[l >> 2] = 0;
	                if (((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) ? (c[(c[g >> 2] | 0) + 32 >> 2] | 0) != 0 : 0) {
	                    c[k >> 2] = Qv(c[(c[g >> 2] | 0) + 32 >> 2] | 0) | 0;
	                    if (!(c[k >> 2] | 0)) {
	                        c[f >> 2] = -1;
	                        m = c[f >> 2] | 0;
	                        i = e;
	                        return m | 0
	                    }
	                    c[(c[k >> 2] | 0) + 68 >> 2] = c[j >> 2];
	                    j = my(c[(c[(c[g >> 2] | 0) + 32 >> 2] | 0) + 72 >> 2] | 0) | 0;
	                    c[(c[k >> 2] | 0) + 64 >> 2] = j;
	                    Sv(c[k >> 2] | 0, c[h >> 2] | 0) | 0;
	                    c[l >> 2] = _v(c[k >> 2] | 0, c[(c[g >> 2] | 0) + 32 >> 2] | 0, c[g >> 2] | 0) | 0;
	                    if ((c[l >> 2] | 0) >= 0 ? (c[(c[k >> 2] | 0) + 52 >> 2] | 0) > 0 : 0)c[l >> 2] = -1;
	                    Rv(c[k >> 2] | 0);
	                    c[f >> 2] = c[l >> 2];
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                c[f >> 2] = -1;
	                m = c[f >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function Uv(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = -1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[k >> 2] = Pi(c[g >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[f >> 2] = -1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } else {
	                    c[f >> 2] = Tv(c[k >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                return 0
	            }

	            function Vv(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                b = Uv(c[e >> 2] | 0, c[f >> 2] | 0, 0) | 0;
	                i = d;
	                return b | 0
	            }

	            function Wv(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                if (((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) ? !((c[f >> 2] | 0) == 0 ? 1 : (c[(c[g >> 2] | 0) + 32 >> 2] | 0) == 0) : 0) {
	                    c[h >> 2] = _v(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 32 >> 2] | 0, c[g >> 2] | 0) | 0;
	                    if ((c[h >> 2] | 0) >= 0 ? (c[(c[f >> 2] | 0) + 52 >> 2] | 0) > 0 : 0)c[h >> 2] = -1;
	                    c[e >> 2] = c[h >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[e >> 2] = -1;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function Xv(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (c[g >> 2] | 0) {
	                    d = (c[g >> 2] | 0) + 52 | 0;
	                    c[d >> 2] = (c[d >> 2] | 0) + 1
	                }
	                d = c[g >> 2] | 0;
	                g = c[h >> 2] | 0;
	                h = c[j >> 2] | 0;
	                c[f >> 2] = c[j >> 2];
	                Xd(0, 0, 0, d, g, 11, 2, 2, 0, 0, h, 0, 0, 0, 0, 133840, f);
	                i = e;
	                return
	            }

	            function Yv(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                if ((c[(c[d >> 2] | 0) + 40 >> 2] | 0) <= 0) {
	                    i = b;
	                    return
	                }
	                a = (c[d >> 2] | 0) + 40 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + -1;
	                a = c[d >> 2] | 0;
	                if ((c[(c[d >> 2] | 0) + 40 >> 2] | 0) > 0)c[(c[d >> 2] | 0) + 36 >> 2] = c[(c[(c[d >> 2] | 0) + 48 >> 2] | 0) + ((c[a + 40 >> 2] | 0) - 1 << 2) >> 2]; else c[a + 36 >> 2] = 0;
	                c[e >> 2] = c[(c[(c[d >> 2] | 0) + 48 >> 2] | 0) + (c[(c[d >> 2] | 0) + 40 >> 2] << 2) >> 2];
	                c[(c[(c[d >> 2] | 0) + 48 >> 2] | 0) + (c[(c[d >> 2] | 0) + 40 >> 2] << 2) >> 2] = 0;
	                if (!(c[e >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[e >> 2] | 0);
	                i = b;
	                return
	            }

	            function Zv(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 8 >> 2] | 0)Th(c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                if (c[c[d >> 2] >> 2] | 0)zb[c[135736 >> 2] & 511](c[c[d >> 2] >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 4 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 4 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 28 >> 2] | 0)Qq(c[(c[d >> 2] | 0) + 28 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function _v(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 28 | 0;
	                g = e + 24 | 0;
	                h = e + 20 | 0;
	                j = e + 16 | 0;
	                k = e + 12 | 0;
	                l = e + 8 | 0;
	                m = e + 4 | 0;
	                n = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[l >> 2] = 0;
	                if (!((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                    if (!(c[g >> 2] | 0)) {
	                        c[f >> 2] = -1;
	                        o = c[f >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    }
	                    if ((c[(c[h >> 2] | 0) + 72 >> 2] | 0) != 0 ? (c[l >> 2] = $v(c[g >> 2] | 0, c[(c[h >> 2] | 0) + 72 >> 2] | 0) | 0, (c[l >> 2] | 0) < 0) : 0) {
	                        c[f >> 2] = -1;
	                        o = c[f >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    }
	                    c[n >> 2] = c[(c[g >> 2] | 0) + 8 >> 2];
	                    c[k >> 2] = c[j >> 2];
	                    if ((aw(c[g >> 2] | 0, c[k >> 2] | 0) | 0) == 1)bw(c[g >> 2] | 0, c[k >> 2] | 0) | 0;
	                    a:while (1) {
	                        if (!(c[k >> 2] | 0))break;
	                        if ((c[k >> 2] | 0) == (c[(c[j >> 2] | 0) + 20 >> 2] | 0))break;
	                        if ((((c[(c[k >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[(c[(c[k >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) != 17 : 0) ? (c[(c[(c[k >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) != 19 : 0) ? (c[(c[(c[k >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) != 20 : 0) {
	                            c[k >> 2] = c[(c[k >> 2] | 0) + 12 >> 2];
	                            if (!(aw(c[g >> 2] | 0, c[k >> 2] | 0) | 0))continue;
	                            bw(c[g >> 2] | 0, c[k >> 2] | 0) | 0;
	                            continue
	                        }
	                        d = c[k >> 2] | 0;
	                        if (c[(c[k >> 2] | 0) + 24 >> 2] | 0) {
	                            c[k >> 2] = c[d + 24 >> 2];
	                            if (!(aw(c[g >> 2] | 0, c[k >> 2] | 0) | 0))continue;
	                            bw(c[g >> 2] | 0, c[k >> 2] | 0) | 0;
	                            continue
	                        }
	                        if ((d | 0) == (c[j >> 2] | 0))break;
	                        while (1) {
	                            c[k >> 2] = c[(c[k >> 2] | 0) + 20 >> 2];
	                            if (!(c[k >> 2] | 0))continue a;
	                            if ((c[k >> 2] | 0) == (c[(c[j >> 2] | 0) + 20 >> 2] | 0))continue a;
	                            p = c[k >> 2] | 0;
	                            if (c[(c[k >> 2] | 0) + 24 >> 2] | 0)break;
	                            if (!p)continue a
	                        }
	                        c[k >> 2] = c[p + 24 >> 2];
	                        if (!(aw(c[g >> 2] | 0, c[k >> 2] | 0) | 0))continue;
	                        bw(c[g >> 2] | 0, c[k >> 2] | 0) | 0
	                    }
	                    c[m >> 2] = c[n >> 2];
	                    while (1) {
	                        q = c[g >> 2] | 0;
	                        if ((c[m >> 2] | 0) >= (c[(c[g >> 2] | 0) + 8 >> 2] | 0))break;
	                        cw(q, c[m >> 2] | 0) | 0;
	                        c[l >> 2] = (c[l >> 2] | 0) + 1;
	                        c[m >> 2] = (c[m >> 2] | 0) + 1
	                    }
	                    c[m >> 2] = c[q + 4 >> 2];
	                    while (1) {
	                        if ((c[m >> 2] | 0) >= (c[(c[g >> 2] | 0) + 8 >> 2] | 0))break;
	                        if (!(((c[(c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + (c[m >> 2] << 2) >> 2] | 0) + 16 >> 2] | 0) == 0 ? (c[(c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + (c[m >> 2] << 2) >> 2] | 0) + 28 >> 2] | 0) == 0 : 0) ? (c[(c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + (c[m >> 2] << 2) >> 2] | 0) + 32 >> 2] | 0) == 0 : 0))dw(c[g >> 2] | 0, c[m >> 2] | 0) | 0;
	                        c[m >> 2] = (c[m >> 2] | 0) + 1
	                    }
	                    if (c[(c[h >> 2] | 0) + 72 >> 2] | 0)Yv(c[g >> 2] | 0);
	                    c[f >> 2] = c[l >> 2];
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                c[f >> 2] = -1;
	                o = c[f >> 2] | 0;
	                i = e;
	                return o | 0
	            }

	            function $v(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                b = c[f >> 2] | 0;
	                if ((c[(c[f >> 2] | 0) + 40 >> 2] | 0) > 40) {
	                    ew(b, 0, 1600, 133640, c[g >> 2] | 0);
	                    c[e >> 2] = -1;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                if ((c[b + 48 >> 2] | 0) == 0 ? (c[(c[f >> 2] | 0) + 44 >> 2] = 4, c[(c[f >> 2] | 0) + 40 >> 2] = 0, b = Cb[c[135744 >> 2] & 511](c[(c[f >> 2] | 0) + 44 >> 2] << 2) | 0, c[(c[f >> 2] | 0) + 48 >> 2] = b, (c[(c[f >> 2] | 0) + 48 >> 2] | 0) == 0) : 0) {
	                    Xv(c[f >> 2] | 0, 0, 133824);
	                    c[e >> 2] = -1;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                if ((c[(c[f >> 2] | 0) + 40 >> 2] | 0) >= (c[(c[f >> 2] | 0) + 44 >> 2] | 0) ? (b = (c[f >> 2] | 0) + 44 | 0, c[b >> 2] = c[b >> 2] << 1, b = Hb[c[135760 >> 2] & 511](c[(c[f >> 2] | 0) + 48 >> 2] | 0, c[(c[f >> 2] | 0) + 44 >> 2] << 2) | 0, c[(c[f >> 2] | 0) + 48 >> 2] = b, (c[(c[f >> 2] | 0) + 48 >> 2] | 0) == 0) : 0) {
	                    Xv(c[f >> 2] | 0, 0, 133824);
	                    c[e >> 2] = -1;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                b = my(c[g >> 2] | 0) | 0;
	                c[(c[(c[f >> 2] | 0) + 48 >> 2] | 0) + (c[(c[f >> 2] | 0) + 40 >> 2] << 2) >> 2] = b;
	                c[(c[f >> 2] | 0) + 36 >> 2] = b;
	                b = (c[f >> 2] | 0) + 40 | 0;
	                f = c[b >> 2] | 0;
	                c[b >> 2] = f + 1;
	                c[e >> 2] = f;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function aw(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 1) {
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                if (!(c[(c[g >> 2] | 0) + 36 >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                if (!((qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, 132728) | 0) == 0 ? (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, 132760) | 0) == 0 : 0))l = 9;
	                a:do if ((l | 0) == 9) {
	                    if ((qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, 132760) | 0) != 0 ? (c[(c[f >> 2] | 0) + 56 >> 2] | 0) == 0 : 0)c[(c[f >> 2] | 0) + 56 >> 2] = 1;
	                    b = (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 133704) | 0) != 0;
	                    a = c[g >> 2] | 0;
	                    if (!b) {
	                        if (!(qy(c[a + 8 >> 2] | 0, 132712) | 0))break;
	                        do if (((c[(c[g >> 2] | 0) + 20 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) {
	                            if ((qy(c[(c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, 132728) | 0) == 0 ? (qy(c[(c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, 132760) | 0) == 0 : 0)break;
	                            if (qy(c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0, 133704) | 0)break a
	                        } while (0);
	                        ew(c[f >> 2] | 0, c[g >> 2] | 0, 1616, 133784, 132712);
	                        break
	                    }
	                    c[h >> 2] = c[a + 12 >> 2];
	                    c[j >> 2] = 0;
	                    b:while (1) {
	                        if (!(c[h >> 2] | 0))break;
	                        do if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 1 ? (c[(c[h >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) {
	                            if ((qy(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, 132728) | 0) == 0 ? (qy(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, 132760) | 0) == 0 : 0)break;
	                            if (qy(c[(c[h >> 2] | 0) + 8 >> 2] | 0, 133704) | 0) {
	                                l = 20;
	                                break b
	                            }
	                            if (qy(c[(c[h >> 2] | 0) + 8 >> 2] | 0, 132712) | 0)c[j >> 2] = (c[j >> 2] | 0) + 1
	                        } while (0);
	                        c[h >> 2] = c[(c[h >> 2] | 0) + 24 >> 2]
	                    }
	                    if ((l | 0) == 20) {
	                        ew(c[f >> 2] | 0, c[g >> 2] | 0, 1614, 133712, 133704);
	                        c[e >> 2] = 0;
	                        k = c[e >> 2] | 0;
	                        i = d;
	                        return k | 0
	                    }
	                    if ((c[j >> 2] | 0) > 1) {
	                        ew(c[f >> 2] | 0, c[g >> 2] | 0, 1615, 133744, 133704);
	                        c[e >> 2] = 0;
	                        k = c[e >> 2] | 0;
	                        i = d;
	                        return k | 0
	                    } else {
	                        c[e >> 2] = 1;
	                        k = c[e >> 2] | 0;
	                        i = d;
	                        return k | 0
	                    }
	                } while (0);
	                c[e >> 2] = 0;
	                k = c[e >> 2] | 0;
	                i = d;
	                return k | 0
	            }

	            function bw(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                fw(c[e >> 2] | 0, c[f >> 2] | 0) | 0;
	                i = d;
	                return 0
	            }

	            function cw(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                d = i;
	                i = i + 64 | 0;
	                e = d + 52 | 0;
	                f = d + 48 | 0;
	                g = d + 44 | 0;
	                h = d + 40 | 0;
	                j = d + 36 | 0;
	                k = d + 32 | 0;
	                l = d + 28 | 0;
	                m = d + 24 | 0;
	                n = d + 20 | 0;
	                o = d + 16 | 0;
	                p = d + 12 | 0;
	                q = d + 8 | 0;
	                r = d + 4 | 0;
	                s = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[o >> 2] = 1;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    t = c[e >> 2] | 0;
	                    i = d;
	                    return t | 0
	                }
	                if ((c[g >> 2] | 0) >= 0 ? (c[g >> 2] | 0) < (c[(c[f >> 2] | 0) + 8 >> 2] | 0) : 0) {
	                    c[h >> 2] = c[(c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0) + 12 >> 2];
	                    if (!(c[h >> 2] | 0)) {
	                        c[e >> 2] = -1;
	                        t = c[e >> 2] | 0;
	                        i = d;
	                        return t | 0
	                    }
	                    c[j >> 2] = gw(c[f >> 2] | 0, c[h >> 2] | 0, 132616) | 0;
	                    if ((c[j >> 2] | 0) == 0 ? (c[j >> 2] = my(132624) | 0, (c[j >> 2] | 0) == 0) : 0) {
	                        c[e >> 2] = -1;
	                        t = c[e >> 2] | 0;
	                        i = d;
	                        return t | 0
	                    }
	                    c[k >> 2] = gw(c[f >> 2] | 0, c[h >> 2] | 0, 132632) | 0;
	                    do if (c[k >> 2] | 0) {
	                        if (qy(c[k >> 2] | 0, 132640) | 0) {
	                            c[o >> 2] = 1;
	                            break
	                        }
	                        if (qy(c[k >> 2] | 0, 132648) | 0) {
	                            c[o >> 2] = 0;
	                            break
	                        }
	                        ew(c[f >> 2] | 0, c[(c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0, 1601, 132656, c[k >> 2] | 0);
	                        if (c[j >> 2] | 0)zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                        if (c[k >> 2] | 0)zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                        c[e >> 2] = -1;
	                        t = c[e >> 2] | 0;
	                        i = d;
	                        return t | 0
	                    } while (0);
	                    c[l >> 2] = Xi(c[c[f >> 2] >> 2] | 0, c[h >> 2] | 0) | 0;
	                    b = c[j >> 2] | 0;
	                    if (!(c[l >> 2] | 0))c[n >> 2] = Hl(b, c[(c[c[f >> 2] >> 2] | 0) + 72 >> 2] | 0) | 0; else c[n >> 2] = Hl(b, c[l >> 2] | 0) | 0;
	                    if (!(c[n >> 2] | 0)) {
	                        c[q >> 2] = Gl(c[l >> 2] | 0) | 0;
	                        c[r >> 2] = Gl(c[j >> 2] | 0) | 0;
	                        c[n >> 2] = Hl(c[r >> 2] | 0, c[q >> 2] | 0) | 0;
	                        if (c[q >> 2] | 0)zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                        if (c[r >> 2] | 0)zb[c[135736 >> 2] & 511](c[r >> 2] | 0)
	                    }
	                    r = c[f >> 2] | 0;
	                    if (!(c[n >> 2] | 0)) {
	                        ew(r, c[(c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0, 1605, 132688, 0);
	                        if (c[k >> 2] | 0)zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                        if (c[j >> 2] | 0)zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                        if (c[l >> 2] | 0)zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                        c[e >> 2] = -1;
	                        t = c[e >> 2] | 0;
	                        i = d;
	                        return t | 0
	                    }
	                    c[m >> 2] = c[r + 64 >> 2];
	                    c[(c[f >> 2] | 0) + 64 >> 2] = c[l >> 2];
	                    r = c[f >> 2] | 0;
	                    q = c[n >> 2] | 0;
	                    b = c[g >> 2] | 0;
	                    if (c[o >> 2] | 0)c[p >> 2] = hw(r, q, b) | 0; else c[p >> 2] = iw(r, q, b) | 0;
	                    c[(c[f >> 2] | 0) + 64 >> 2] = c[m >> 2];
	                    a:do if ((c[p >> 2] | 0) < 0) {
	                        c[s >> 2] = c[(c[h >> 2] | 0) + 12 >> 2];
	                        while (1) {
	                            if (!(c[s >> 2] | 0))break a;
	                            do if (((c[(c[s >> 2] | 0) + 4 >> 2] | 0) == 1 ? (c[(c[s >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[s >> 2] | 0) + 8 >> 2] | 0, 132712) | 0) != 0 : 0) {
	                                if ((qy(c[(c[(c[s >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, 132728) | 0) == 0 ? (qy(c[(c[(c[s >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, 132760) | 0) == 0 : 0)break;
	                                c[p >> 2] = jw(c[f >> 2] | 0, c[s >> 2] | 0, c[g >> 2] | 0) | 0;
	                                if (!(c[p >> 2] | 0))break a
	                            } while (0);
	                            c[s >> 2] = c[(c[s >> 2] | 0) + 24 >> 2]
	                        }
	                    } while (0);
	                    if ((c[p >> 2] | 0) < 0)ew(c[f >> 2] | 0, c[(c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0, 1604, 132792, c[n >> 2] | 0);
	                    if (c[n >> 2] | 0)zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                    if (c[k >> 2] | 0)zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    if (c[j >> 2] | 0)zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                    if (c[l >> 2] | 0)zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                    c[e >> 2] = 0;
	                    t = c[e >> 2] | 0;
	                    i = d;
	                    return t | 0
	                }
	                c[e >> 2] = -1;
	                t = c[e >> 2] | 0;
	                i = d;
	                return t | 0
	            }

	            function dw(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 28 | 0;
	                f = d + 24 | 0;
	                g = d + 20 | 0;
	                h = d + 16 | 0;
	                j = d + 12 | 0;
	                k = d + 8 | 0;
	                l = d + 4 | 0;
	                m = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                if ((c[g >> 2] | 0) >= 0 ? (c[g >> 2] | 0) < (c[(c[f >> 2] | 0) + 8 >> 2] | 0) : 0) {
	                    c[h >> 2] = c[(c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0) + 12 >> 2];
	                    if ((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                        if ((c[(c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0) + 16 >> 2] | 0) == 0 ? (c[(c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0) + 28 >> 2] | 0) != 0 : 0) {
	                            b = kw(c[f >> 2] | 0, c[c[f >> 2] >> 2] | 0, c[c[f >> 2] >> 2] | 0, c[(c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0) + 28 >> 2] | 0) | 0;
	                            c[(c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0) + 16 >> 2] = b;
	                            Qq(c[(c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0) + 28 >> 2] | 0);
	                            c[(c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0) + 28 >> 2] = 0
	                        }
	                        c[k >> 2] = c[(c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0) + 16 >> 2];
	                        c[(c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0) + 16 >> 2] = 0;
	                        if ((c[(c[h >> 2] | 0) + 20 >> 2] | 0) != 0 ? (c[(c[(c[h >> 2] | 0) + 20 >> 2] | 0) + 4 >> 2] | 0) != 1 : 0) {
	                            c[m >> 2] = 0;
	                            c[l >> 2] = c[k >> 2];
	                            while (1) {
	                                if (!(c[l >> 2] | 0))break;
	                                if ((c[(c[l >> 2] | 0) + 4 >> 2] | 0) == 1)c[m >> 2] = (c[m >> 2] | 0) + 1;
	                                c[l >> 2] = c[(c[l >> 2] | 0) + 24 >> 2]
	                            }
	                            if ((c[m >> 2] | 0) > 1) {
	                                ew(c[f >> 2] | 0, c[(c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0, 1611, 132536, 0);
	                                c[e >> 2] = -1;
	                                n = c[e >> 2] | 0;
	                                i = d;
	                                return n | 0
	                            }
	                        }
	                        a:do if (c[(c[f >> 2] | 0) + 60 >> 2] & 32768) {
	                            while (1) {
	                                if (!(c[k >> 2] | 0))break;
	                                c[j >> 2] = c[k >> 2];
	                                c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2];
	                                wi(c[h >> 2] | 0, c[j >> 2] | 0) | 0
	                            }
	                            Qh(c[h >> 2] | 0);
	                            Rh(c[h >> 2] | 0)
	                        } else {
	                            c[(c[h >> 2] | 0) + 4 >> 2] = 19;
	                            c[j >> 2] = ji(c[(c[h >> 2] | 0) + 32 >> 2] | 0, c[(c[h >> 2] | 0) + 36 >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0, 0) | 0;
	                            if (!(c[j >> 2] | 0)) {
	                                ew(c[f >> 2] | 0, c[(c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0, 1609, 132592, 0);
	                                c[e >> 2] = -1;
	                                n = c[e >> 2] | 0;
	                                i = d;
	                                return n | 0
	                            }
	                            c[(c[j >> 2] | 0) + 4 >> 2] = 20;
	                            Xh(c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                            while (1) {
	                                if (!(c[k >> 2] | 0))break a;
	                                c[h >> 2] = c[k >> 2];
	                                c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2];
	                                wi(c[j >> 2] | 0, c[h >> 2] | 0) | 0
	                            }
	                        } while (0);
	                        c[e >> 2] = 0;
	                        n = c[e >> 2] | 0;
	                        i = d;
	                        return n | 0
	                    }
	                    c[e >> 2] = -1;
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                c[e >> 2] = -1;
	                n = c[e >> 2] | 0;
	                i = d;
	                return n | 0
	            }

	            function ew(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g;
	                j = g + 20 | 0;
	                k = g + 16 | 0;
	                l = g + 12 | 0;
	                m = g + 8 | 0;
	                n = g + 4 | 0;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                if (c[j >> 2] | 0) {
	                    f = (c[j >> 2] | 0) + 52 | 0;
	                    c[f >> 2] = (c[f >> 2] | 0) + 1
	                }
	                f = c[j >> 2] | 0;
	                j = c[k >> 2] | 0;
	                k = c[l >> 2] | 0;
	                l = c[n >> 2] | 0;
	                e = c[m >> 2] | 0;
	                c[h >> 2] = c[n >> 2];
	                Xd(0, 0, 0, f, j, 11, k, 2, 0, 0, l, 0, 0, 0, 0, e, h);
	                i = g;
	                return
	            }

	            function fw(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0;
	                e = i;
	                i = i + 64 | 0;
	                f = e + 60 | 0;
	                g = e + 56 | 0;
	                h = e + 52 | 0;
	                j = e + 48 | 0;
	                k = e + 44 | 0;
	                l = e + 40 | 0;
	                m = e + 36 | 0;
	                n = e + 32 | 0;
	                o = e + 28 | 0;
	                p = e + 24 | 0;
	                q = e + 20 | 0;
	                r = e + 16 | 0;
	                s = e + 12 | 0;
	                t = e + 8 | 0;
	                u = e + 4 | 0;
	                v = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[m >> 2] = 0;
	                c[r >> 2] = 1;
	                c[t >> 2] = 0;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = -1;
	                    w = c[f >> 2] | 0;
	                    i = e;
	                    return w | 0
	                }
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = -1;
	                    w = c[f >> 2] | 0;
	                    i = e;
	                    return w | 0
	                }
	                c[n >> 2] = gw(c[g >> 2] | 0, c[h >> 2] | 0, 132616) | 0;
	                if ((c[n >> 2] | 0) == 0 ? (c[n >> 2] = my(132624) | 0, (c[n >> 2] | 0) == 0) : 0) {
	                    c[f >> 2] = -1;
	                    w = c[f >> 2] | 0;
	                    i = e;
	                    return w | 0
	                }
	                if (!((d[c[n >> 2] >> 0] | 0 | 0) != 35 ? (d[c[n >> 2] >> 0] | 0 | 0) != 0 : 0))c[t >> 2] = 1;
	                c[o >> 2] = gw(c[g >> 2] | 0, c[h >> 2] | 0, 132632) | 0;
	                do if (c[o >> 2] | 0) {
	                    if (qy(c[o >> 2] | 0, 132640) | 0) {
	                        c[r >> 2] = 1;
	                        break
	                    }
	                    if (qy(c[o >> 2] | 0, 132648) | 0) {
	                        c[r >> 2] = 0;
	                        break
	                    }
	                    ew(c[g >> 2] | 0, c[h >> 2] | 0, 1601, 132656, c[o >> 2] | 0);
	                    if (c[n >> 2] | 0)zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                    if (c[o >> 2] | 0)zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                    c[f >> 2] = -1;
	                    w = c[f >> 2] | 0;
	                    i = e;
	                    return w | 0
	                } while (0);
	                c[p >> 2] = Xi(c[c[g >> 2] >> 2] | 0, c[h >> 2] | 0) | 0;
	                b = c[n >> 2] | 0;
	                if (!(c[p >> 2] | 0))c[q >> 2] = Hl(b, c[(c[c[g >> 2] >> 2] | 0) + 72 >> 2] | 0) | 0; else c[q >> 2] = Hl(b, c[p >> 2] | 0) | 0;
	                if (!(c[q >> 2] | 0)) {
	                    c[u >> 2] = Gl(c[p >> 2] | 0) | 0;
	                    c[v >> 2] = Gl(c[n >> 2] | 0) | 0;
	                    c[q >> 2] = Hl(c[v >> 2] | 0, c[u >> 2] | 0) | 0;
	                    if (c[u >> 2] | 0)zb[c[135736 >> 2] & 511](c[u >> 2] | 0);
	                    if (c[v >> 2] | 0)zb[c[135736 >> 2] & 511](c[v >> 2] | 0)
	                }
	                if (c[o >> 2] | 0)zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                if (c[n >> 2] | 0)zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                if (c[p >> 2] | 0)zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                p = c[g >> 2] | 0;
	                n = c[h >> 2] | 0;
	                if (!(c[q >> 2] | 0)) {
	                    ew(p, n, 1605, 132688, 0);
	                    c[f >> 2] = -1;
	                    w = c[f >> 2] | 0;
	                    i = e;
	                    return w | 0
	                }
	                c[m >> 2] = gw(p, n, 133496) | 0;
	                c[k >> 2] = yl(c[q >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    ew(c[g >> 2] | 0, c[h >> 2] | 0, 1605, 132840, c[q >> 2] | 0);
	                    if (c[m >> 2] | 0)zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                    zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                    c[f >> 2] = -1;
	                    w = c[f >> 2] | 0;
	                    i = e;
	                    return w | 0
	                }
	                do if (c[(c[k >> 2] | 0) + 32 >> 2] | 0)if (c[(c[g >> 2] | 0) + 56 >> 2] | 0) {
	                    if (!(c[m >> 2] | 0))c[m >> 2] = c[(c[k >> 2] | 0) + 32 >> 2]; else zb[c[135736 >> 2] & 511](c[(c[k >> 2] | 0) + 32 >> 2] | 0);
	                    c[(c[k >> 2] | 0) + 32 >> 2] = 0;
	                    break
	                } else {
	                    ew(c[g >> 2] | 0, c[h >> 2] | 0, 1618, 133512, c[q >> 2] | 0);
	                    if (c[m >> 2] | 0)zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                    Al(c[k >> 2] | 0);
	                    zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                    c[f >> 2] = -1;
	                    w = c[f >> 2] | 0;
	                    i = e;
	                    return w | 0
	                } while (0);
	                c[l >> 2] = Cl(c[k >> 2] | 0) | 0;
	                Al(c[k >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                if (!(c[l >> 2] | 0)) {
	                    ew(c[g >> 2] | 0, c[h >> 2] | 0, 1605, 132840, c[q >> 2] | 0);
	                    if (c[m >> 2] | 0)zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                    c[f >> 2] = -1;
	                    w = c[f >> 2] | 0;
	                    i = e;
	                    return w | 0
	                }
	                do if ((c[t >> 2] | 0) == 1 & (c[r >> 2] | 0) == 1) {
	                    if ((c[m >> 2] | 0) != 0 ? (d[c[m >> 2] >> 0] | 0 | 0) != 0 : 0)break;
	                    ew(c[g >> 2] | 0, c[h >> 2] | 0, 1600, 133584, c[l >> 2] | 0);
	                    if (c[m >> 2] | 0)zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                    c[f >> 2] = -1;
	                    w = c[f >> 2] | 0;
	                    i = e;
	                    return w | 0
	                } while (0);
	                a:do if ((c[t >> 2] | 0) == 0 & (c[r >> 2] | 0) == 1) {
	                    c[s >> 2] = 0;
	                    while (1) {
	                        if ((c[s >> 2] | 0) >= (c[(c[g >> 2] | 0) + 40 >> 2] | 0))break a;
	                        if (qy(c[l >> 2] | 0, c[(c[(c[g >> 2] | 0) + 48 >> 2] | 0) + (c[s >> 2] << 2) >> 2] | 0) | 0)break;
	                        c[s >> 2] = (c[s >> 2] | 0) + 1
	                    }
	                    ew(c[g >> 2] | 0, c[h >> 2] | 0, 1600, 133640, c[l >> 2] | 0);
	                    c[f >> 2] = -1;
	                    w = c[f >> 2] | 0;
	                    i = e;
	                    return w | 0
	                } while (0);
	                c[j >> 2] = lw(c[g >> 2] | 0, c[l >> 2] | 0, c[h >> 2] | 0) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    c[f >> 2] = -1;
	                    w = c[f >> 2] | 0;
	                    i = e;
	                    return w | 0
	                } else {
	                    c[(c[j >> 2] | 0) + 4 >> 2] = c[m >> 2];
	                    c[(c[j >> 2] | 0) + 8 >> 2] = 0;
	                    c[(c[j >> 2] | 0) + 20 >> 2] = c[r >> 2];
	                    c[(c[j >> 2] | 0) + 24 >> 2] = 1;
	                    zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                    c[f >> 2] = 0;
	                    w = c[f >> 2] | 0;
	                    i = e;
	                    return w | 0
	                }
	                return 0
	            }

	            function gw(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = Ui(c[h >> 2] | 0, 132728, c[j >> 2] | 0) | 0;
	                if (c[k >> 2] | 0) {
	                    c[f >> 2] = c[k >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                if ((c[(c[g >> 2] | 0) + 56 >> 2] | 0) != 0 ? (c[k >> 2] = Ui(c[h >> 2] | 0, 132760, c[j >> 2] | 0) | 0, (c[k >> 2] | 0) != 0) : 0) {
	                    c[f >> 2] = c[k >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[k >> 2] = Yi(c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                c[f >> 2] = c[k >> 2];
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function hw(a, b, e) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0;
	                f = i;
	                i = i + 80 | 0;
	                g = f + 68 | 0;
	                h = f + 64 | 0;
	                j = f + 60 | 0;
	                k = f + 56 | 0;
	                l = f + 52 | 0;
	                m = f + 48 | 0;
	                n = f + 44 | 0;
	                o = f + 40 | 0;
	                p = f + 36 | 0;
	                q = f + 32 | 0;
	                r = f + 28 | 0;
	                s = f + 24 | 0;
	                t = f + 20 | 0;
	                u = f + 16 | 0;
	                v = f + 12 | 0;
	                w = f + 8 | 0;
	                x = f + 4 | 0;
	                y = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[o >> 2] = 0;
	                c[p >> 2] = 0;
	                c[m >> 2] = yl(c[j >> 2] | 0) | 0;
	                if (!(c[m >> 2] | 0)) {
	                    ew(c[h >> 2] | 0, c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0, 1605, 132840, c[j >> 2] | 0);
	                    c[g >> 2] = -1;
	                    z = c[g >> 2] | 0;
	                    i = f;
	                    return z | 0
	                }
	                if (c[(c[m >> 2] | 0) + 32 >> 2] | 0) {
	                    c[o >> 2] = c[(c[m >> 2] | 0) + 32 >> 2];
	                    c[(c[m >> 2] | 0) + 32 >> 2] = 0
	                }
	                if (((c[(c[h >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) != 0 : 0) ? (c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                    if (c[o >> 2] | 0)zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                    c[o >> 2] = my(c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0) | 0
	                }
	                c[n >> 2] = Cl(c[m >> 2] | 0) | 0;
	                Al(c[m >> 2] | 0);
	                if (!(c[n >> 2] | 0)) {
	                    m = c[h >> 2] | 0;
	                    if (c[(c[h >> 2] | 0) + 16 >> 2] | 0)ew(m, c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0, 1605, 132840, c[j >> 2] | 0); else ew(m, 0, 1605, 132840, c[j >> 2] | 0);
	                    if (c[o >> 2] | 0)zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                    c[g >> 2] = -1;
	                    z = c[g >> 2] | 0;
	                    i = f;
	                    return z | 0
	                }
	                do if ((d[c[n >> 2] >> 0] | 0 | 0) != 0 ? (d[c[n >> 2] >> 0] | 0 | 0) != 35 : 0) {
	                    if ((c[c[h >> 2] >> 2] | 0) != 0 ? (qy(c[n >> 2] | 0, c[(c[c[h >> 2] >> 2] | 0) + 72 >> 2] | 0) | 0) != 0 : 0) {
	                        A = 22;
	                        break
	                    }
	                    c[p >> 2] = 0;
	                    while (1) {
	                        if ((c[p >> 2] | 0) >= (c[(c[h >> 2] | 0) + 8 >> 2] | 0))break;
	                        if ((qy(c[n >> 2] | 0, c[c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[p >> 2] << 2) >> 2] >> 2] | 0) | 0) != 0 ? (c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[p >> 2] << 2) >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                            A = 27;
	                            break
	                        }
	                        c[p >> 2] = (c[p >> 2] | 0) + 1
	                    }
	                    if ((A | 0) == 27) {
	                        c[l >> 2] = c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[p >> 2] << 2) >> 2] | 0) + 8 >> 2];
	                        break
	                    }
	                    c[q >> 2] = c[(c[h >> 2] | 0) + 60 >> 2];
	                    if (c[o >> 2] | 0) {
	                        j = (c[h >> 2] | 0) + 60 | 0;
	                        c[j >> 2] = c[j >> 2] | 2
	                    }
	                    c[l >> 2] = mw(c[h >> 2] | 0, c[n >> 2] | 0) | 0;
	                    c[(c[h >> 2] | 0) + 60 >> 2] = c[q >> 2];
	                    if (!(c[l >> 2] | 0)) {
	                        zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                        if (c[o >> 2] | 0)zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                        c[g >> 2] = -1;
	                        z = c[g >> 2] | 0;
	                        i = f;
	                        return z | 0
	                    }
	                    c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 8 >> 2] = c[l >> 2];
	                    if (!(qy(c[n >> 2] | 0, c[(c[l >> 2] | 0) + 72 >> 2] | 0) | 0)) {
	                        zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                        c[n >> 2] = my(c[(c[l >> 2] | 0) + 72 >> 2] | 0) | 0
	                    }
	                    c[p >> 2] = (c[k >> 2] | 0) + 1;
	                    while (1) {
	                        if ((c[p >> 2] | 0) >= (c[(c[h >> 2] | 0) + 8 >> 2] | 0))break;
	                        if (qy(c[n >> 2] | 0, c[c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[p >> 2] << 2) >> 2] >> 2] | 0) | 0) {
	                            A = 40;
	                            break
	                        }
	                        c[p >> 2] = (c[p >> 2] | 0) + 1
	                    }
	                    if ((A | 0) == 40) {
	                        j = (c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 24 | 0;
	                        c[j >> 2] = (c[j >> 2] | 0) + 1
	                    }
	                    nw(c[h >> 2] | 0, c[c[h >> 2] >> 2] | 0, c[l >> 2] | 0) | 0;
	                    ow(c[h >> 2] | 0, c[l >> 2] | 0, c[n >> 2] | 0)
	                } else A = 22; while (0);
	                if ((A | 0) == 22)c[l >> 2] = 0;
	                q = (c[l >> 2] | 0) == 0;
	                do if (!(c[o >> 2] | 0)) {
	                    j = c[h >> 2] | 0;
	                    if (q) {
	                        m = Ki(c[(c[j >> 2] | 0) + 12 >> 2] | 0) | 0;
	                        c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 16 >> 2] = m;
	                        break
	                    } else {
	                        m = pw(j, c[c[h >> 2] >> 2] | 0, c[l >> 2] | 0, c[(c[l >> 2] | 0) + 12 >> 2] | 0) | 0;
	                        c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 16 >> 2] = m;
	                        break
	                    }
	                } else {
	                    if (q)c[s >> 2] = iv(c[c[h >> 2] >> 2] | 0, c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0, 0) | 0; else c[s >> 2] = iv(c[l >> 2] | 0, 0, 0) | 0;
	                    if (!(c[s >> 2] | 0)) {
	                        ew(c[h >> 2] | 0, c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0, 1612, 133056, 0);
	                        zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                        c[g >> 2] = -1;
	                        z = c[g >> 2] | 0;
	                        i = f;
	                        return z | 0
	                    }
	                    c[r >> 2] = kv(c[o >> 2] | 0, c[s >> 2] | 0) | 0;
	                    if (!(c[r >> 2] | 0)) {
	                        ew(c[h >> 2] | 0, c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0, 1612, 133096, c[o >> 2] | 0);
	                        Nr(c[s >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                        c[g >> 2] = -1;
	                        z = c[g >> 2] | 0;
	                        i = f;
	                        return z | 0
	                    }
	                    switch (c[c[r >> 2] >> 2] | 0) {
	                        case 9:
	                        case 8:
	                        case 5:
	                        case 4:
	                        case 3:
	                        case 2:
	                        case 0:
	                        {
	                            ew(c[h >> 2] | 0, c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0, 1613, 133136, c[o >> 2] | 0);
	                            Nr(c[s >> 2] | 0);
	                            zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                            zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                            c[g >> 2] = -1;
	                            z = c[g >> 2] | 0;
	                            i = f;
	                            return z | 0
	                        }
	                        case 1:
	                        {
	                            A = 56;
	                            break
	                        }
	                        default:
	                        {
	                        }
	                    }
	                    do if ((A | 0) == 56) {
	                        if ((c[(c[r >> 2] | 0) + 4 >> 2] | 0) != 0 ? (c[c[(c[r >> 2] | 0) + 4 >> 2] >> 2] | 0) > 0 : 0)break;
	                        Nr(c[s >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                        c[g >> 2] = -1;
	                        z = c[g >> 2] | 0;
	                        i = f;
	                        return z | 0
	                    } while (0);
	                    c[t >> 2] = c[(c[r >> 2] | 0) + 4 >> 2];
	                    a:do if (c[t >> 2] | 0) {
	                        c[p >> 2] = 0;
	                        while (1) {
	                            if ((c[p >> 2] | 0) >= (c[c[t >> 2] >> 2] | 0))break a;
	                            b:do if (c[(c[(c[t >> 2] | 0) + 8 >> 2] | 0) + (c[p >> 2] << 2) >> 2] | 0)switch (c[(c[(c[(c[t >> 2] | 0) + 8 >> 2] | 0) + (c[p >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0) {
	                                case 10:
	                                case 11:
	                                case 12:
	                                case 14:
	                                case 15:
	                                case 16:
	                                case 17:
	                                case 19:
	                                case 20:
	                                {
	                                    ew(c[h >> 2] | 0, c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0, 1613, 133248, c[o >> 2] | 0);
	                                    c[(c[(c[t >> 2] | 0) + 8 >> 2] | 0) + (c[p >> 2] << 2) >> 2] = 0;
	                                    c[(c[(c[t >> 2] | 0) + 8 >> 2] | 0) + (c[p >> 2] << 2) >> 2] = 0;
	                                    break b;
	                                    break
	                                }
	                                case 18:
	                                {
	                                    ew(c[h >> 2] | 0, c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0, 1613, 133208, c[o >> 2] | 0);
	                                    c[(c[(c[t >> 2] | 0) + 8 >> 2] | 0) + (c[p >> 2] << 2) >> 2] = 0;
	                                    break b;
	                                    break
	                                }
	                                case 2:
	                                {
	                                    ew(c[h >> 2] | 0, c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0, 1613, 133168, c[o >> 2] | 0);
	                                    c[(c[(c[t >> 2] | 0) + 8 >> 2] | 0) + (c[p >> 2] << 2) >> 2] = 0;
	                                    break b;
	                                    break
	                                }
	                                default:
	                                    break b
	                            } while (0);
	                            c[p >> 2] = (c[p >> 2] | 0) + 1
	                        }
	                    } while (0);
	                    if (!(c[l >> 2] | 0)) {
	                        c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 28 >> 2] = c[r >> 2];
	                        c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 16 >> 2] = 0
	                    } else {
	                        m = kw(c[h >> 2] | 0, c[c[h >> 2] >> 2] | 0, c[l >> 2] | 0, c[r >> 2] | 0) | 0;
	                        c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 16 >> 2] = m;
	                        Qq(c[r >> 2] | 0)
	                    }
	                    Nr(c[s >> 2] | 0);
	                    zb[c[135736 >> 2] & 511](c[o >> 2] | 0)
	                } while (0);
	                if (((c[l >> 2] | 0) != 0 & (c[n >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 60 >> 2] & 262144 | 0) == 0 : 0) ? (c[(c[l >> 2] | 0) + 88 >> 2] & 262144 | 0) == 0 : 0) {
	                    c[v >> 2] = Ui(c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0, 133288, 133296) | 0;
	                    do if (!(c[v >> 2] | 0)) {
	                        c[w >> 2] = Il(c[n >> 2] | 0, c[(c[h >> 2] | 0) + 64 >> 2] | 0) | 0;
	                        if (!(c[w >> 2] | 0)) {
	                            ew(c[h >> 2] | 0, c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0, 1605, 133336, c[n >> 2] | 0);
	                            break
	                        }
	                        if (vy(c[w >> 2] | 0, 47) | 0) {
	                            c[v >> 2] = c[w >> 2];
	                            break
	                        } else {
	                            zb[c[135736 >> 2] & 511](c[w >> 2] | 0);
	                            break
	                        }
	                    } while (0);
	                    if (c[v >> 2] | 0) {
	                        c[u >> 2] = c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 16 >> 2];
	                        while (1) {
	                            if (!(c[u >> 2] | 0))break;
	                            do if ((c[(c[u >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                                c[w >> 2] = Xi(c[(c[u >> 2] | 0) + 32 >> 2] | 0, c[u >> 2] | 0) | 0;
	                                if (!(c[w >> 2] | 0)) {
	                                    Wi(c[u >> 2] | 0, c[v >> 2] | 0);
	                                    break
	                                }
	                                l = (qy(c[w >> 2] | 0, c[(c[(c[u >> 2] | 0) + 32 >> 2] | 0) + 72 >> 2] | 0) | 0) != 0;
	                                o = c[u >> 2] | 0;
	                                if (!l) {
	                                    c[x >> 2] = Ui(o, 133288, 133296) | 0;
	                                    if (c[x >> 2] | 0) {
	                                        c[y >> 2] = Hl(c[x >> 2] | 0, c[v >> 2] | 0) | 0;
	                                        if (!(c[y >> 2] | 0))ew(c[h >> 2] | 0, c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0, 1605, 133376, c[x >> 2] | 0); else {
	                                            Wi(c[u >> 2] | 0, c[y >> 2] | 0);
	                                            zb[c[135736 >> 2] & 511](c[y >> 2] | 0)
	                                        }
	                                        zb[c[135736 >> 2] & 511](c[x >> 2] | 0)
	                                    }
	                                } else Wi(o, c[v >> 2] | 0);
	                                zb[c[135736 >> 2] & 511](c[w >> 2] | 0)
	                            } while (0);
	                            c[u >> 2] = c[(c[u >> 2] | 0) + 24 >> 2]
	                        }
	                        zb[c[135736 >> 2] & 511](c[v >> 2] | 0)
	                    }
	                }
	                if (((c[k >> 2] | 0) < (c[(c[h >> 2] | 0) + 8 >> 2] | 0) ? (c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 24 >> 2] | 0) <= 1 : 0) {
	                    Th(c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 8 >> 2] | 0);
	                    c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 8 >> 2] = 0
	                }
	                zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                c[g >> 2] = 0;
	                z = c[g >> 2] | 0;
	                i = f;
	                return z | 0
	            }

	            function iw(a, b, e) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0;
	                f = i;
	                i = i + 80 | 0;
	                g = f + 68 | 0;
	                h = f + 64 | 0;
	                j = f + 60 | 0;
	                k = f + 56 | 0;
	                l = f + 52 | 0;
	                m = f + 48 | 0;
	                n = f + 44 | 0;
	                o = f + 40 | 0;
	                p = f + 36 | 0;
	                q = f + 32 | 0;
	                r = f + 28 | 0;
	                s = f + 24 | 0;
	                t = f + 20 | 0;
	                u = f + 16 | 0;
	                v = f + 12 | 0;
	                w = f + 8 | 0;
	                x = f + 4 | 0;
	                y = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[q >> 2] = 0;
	                c[r >> 2] = 0;
	                c[u >> 2] = 0;
	                c[n >> 2] = yl(c[j >> 2] | 0) | 0;
	                if (!(c[n >> 2] | 0)) {
	                    ew(c[h >> 2] | 0, c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0, 1605, 132840, c[j >> 2] | 0);
	                    c[g >> 2] = -1;
	                    z = c[g >> 2] | 0;
	                    i = f;
	                    return z | 0
	                }
	                if (c[(c[n >> 2] | 0) + 32 >> 2] | 0) {
	                    ew(c[h >> 2] | 0, c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0, 1606, 132864, c[(c[n >> 2] | 0) + 32 >> 2] | 0);
	                    Al(c[n >> 2] | 0);
	                    c[g >> 2] = -1;
	                    z = c[g >> 2] | 0;
	                    i = f;
	                    return z | 0
	                }
	                c[o >> 2] = Cl(c[n >> 2] | 0) | 0;
	                Al(c[n >> 2] | 0);
	                if (!(c[o >> 2] | 0)) {
	                    ew(c[h >> 2] | 0, c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0, 1605, 132840, c[j >> 2] | 0);
	                    c[g >> 2] = -1;
	                    z = c[g >> 2] | 0;
	                    i = f;
	                    return z | 0
	                }
	                if (!(d[c[o >> 2] >> 0] | 0)) {
	                    ew(c[h >> 2] | 0, c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0, 1607, 132912, 0);
	                    zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                    c[g >> 2] = -1;
	                    z = c[g >> 2] | 0;
	                    i = f;
	                    return z | 0
	                }
	                c[p >> 2] = 0;
	                while (1) {
	                    if ((c[p >> 2] | 0) >= (c[(c[h >> 2] | 0) + 20 >> 2] | 0)) {
	                        A = 14;
	                        break
	                    }
	                    j = (qy(c[o >> 2] | 0, c[(c[(c[h >> 2] | 0) + 32 >> 2] | 0) + (c[p >> 2] << 2) >> 2] | 0) | 0) != 0;
	                    B = c[p >> 2] | 0;
	                    if (j) {
	                        A = 12;
	                        break
	                    }
	                    c[p >> 2] = B + 1
	                }
	                do if ((A | 0) == 12)c[m >> 2] = Hi(c[(c[(c[h >> 2] | 0) + 28 >> 2] | 0) + (B << 2) >> 2] | 0, 1) | 0; else if ((A | 0) == 14) {
	                    if ((c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) != 0 ? (c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0) != 0 : 0)c[q >> 2] = Yi(c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0, 132960) | 0;
	                    do if (c[q >> 2] | 0) {
	                        c[r >> 2] = wd(c[q >> 2] | 0) | 0;
	                        if ((c[r >> 2] | 0) != -1) {
	                            zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                            break
	                        }
	                        ew(c[h >> 2] | 0, c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0, 1610, 132976, c[q >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                        c[g >> 2] = -1;
	                        z = c[g >> 2] | 0;
	                        i = f;
	                        return z | 0
	                    } while (0);
	                    c[s >> 2] = Be() | 0;
	                    c[t >> 2] = Vk(c[o >> 2] | 0, 0, c[s >> 2] | 0) | 0;
	                    if (!(c[t >> 2] | 0)) {
	                        Ae(c[s >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                        c[g >> 2] = -1;
	                        z = c[g >> 2] | 0;
	                        i = f;
	                        return z | 0
	                    }
	                    c[l >> 2] = c[c[t >> 2] >> 2];
	                    if (!(c[l >> 2] | 0)) {
	                        te(c[t >> 2] | 0);
	                        Ae(c[s >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                        c[g >> 2] = -1;
	                        z = c[g >> 2] | 0;
	                        i = f;
	                        return z | 0
	                    }
	                    if (c[(c[l >> 2] | 0) + 12 >> 2] | 0)Hd(c[(c[l >> 2] | 0) + 12 >> 2] | 0) | 0;
	                    j = Cd(c[r >> 2] | 0) | 0;
	                    c[(c[l >> 2] | 0) + 12 >> 2] = j;
	                    c[m >> 2] = li(0) | 0;
	                    while (1) {
	                        if ((Nk(c[l >> 2] | 0, 128) | 0) <= 0) {
	                            A = 41;
	                            break
	                        }
	                        c[w >> 2] = Vy(c[(c[l >> 2] | 0) + 16 >> 2] | 0) | 0;
	                        c[v >> 2] = Zy(c[(c[l >> 2] | 0) + 16 >> 2] | 0) | 0;
	                        c[p >> 2] = 0;
	                        while (1) {
	                            if ((c[p >> 2] | 0) >= (c[v >> 2] | 0)) {
	                                A = 40;
	                                break
	                            }
	                            c[x >> 2] = oe(0, (c[w >> 2] | 0) + (c[p >> 2] | 0) | 0, y) | 0;
	                            j = c[x >> 2] | 0;
	                            if ((c[x >> 2] | 0) < 256) {
	                                if (!(9 <= (j | 0) & (c[x >> 2] | 0) <= 10 | (c[x >> 2] | 0) == 13 | 32 <= (c[x >> 2] | 0)))break
	                            } else if ((!(256 <= (j | 0) & (c[x >> 2] | 0) <= 55295) ? !(57344 <= (c[x >> 2] | 0) & (c[x >> 2] | 0) <= 65533) : 0) ? !(65536 <= (c[x >> 2] | 0) & (c[x >> 2] | 0) <= 1114111) : 0)break;
	                            c[u >> 2] = 0;
	                            $i(c[m >> 2] | 0, (c[w >> 2] | 0) + (c[p >> 2] | 0) | 0, c[y >> 2] | 0);
	                            c[p >> 2] = (c[p >> 2] | 0) + (c[y >> 2] | 0)
	                        }
	                        if ((A | 0) == 40) {
	                            A = 0;
	                            Ty(c[(c[l >> 2] | 0) + 16 >> 2] | 0, c[v >> 2] | 0) | 0;
	                            continue
	                        }
	                        if ((c[u >> 2] | 0) != 0 ? 1 : ((c[v >> 2] | 0) - (c[p >> 2] | 0) | 0) >= 4)break;
	                        c[u >> 2] = 1;
	                        Ty(c[(c[l >> 2] | 0) + 16 >> 2] | 0, c[p >> 2] | 0) | 0
	                    }
	                    if ((A | 0) == 41) {
	                        Ae(c[s >> 2] | 0);
	                        qw(c[h >> 2] | 0, c[m >> 2] | 0, c[o >> 2] | 0);
	                        te(c[t >> 2] | 0);
	                        break
	                    }
	                    ew(c[h >> 2] | 0, c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0, 1608, 133008, c[o >> 2] | 0);
	                    yk(c[l >> 2] | 0);
	                    zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                    c[g >> 2] = -1;
	                    z = c[g >> 2] | 0;
	                    i = f;
	                    return z | 0
	                } while (0);
	                c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 16 >> 2] = c[m >> 2];
	                zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                c[g >> 2] = 0;
	                z = c[g >> 2] | 0;
	                i = f;
	                return z | 0
	            }

	            function jw(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[l >> 2] = 0;
	                if ((c[h >> 2] | 0) != 0 ? !((c[g >> 2] | 0) == 0 ? 1 : (c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 18) : 0) {
	                    if (c[(c[h >> 2] | 0) + 12 >> 2] | 0) {
	                        c[k >> 2] = Qv(c[c[g >> 2] >> 2] | 0) | 0;
	                        if (!(c[k >> 2] | 0)) {
	                            c[f >> 2] = -1;
	                            m = c[f >> 2] | 0;
	                            i = e;
	                            return m | 0
	                        }
	                        c[(c[k >> 2] | 0) + 68 >> 2] = c[(c[g >> 2] | 0) + 68 >> 2];
	                        d = my(c[(c[g >> 2] | 0) + 64 >> 2] | 0) | 0;
	                        c[(c[k >> 2] | 0) + 64 >> 2] = d;
	                        Sv(c[k >> 2] | 0, c[(c[g >> 2] | 0) + 60 >> 2] | 0) | 0;
	                        c[l >> 2] = _v(c[k >> 2] | 0, c[c[g >> 2] >> 2] | 0, c[(c[h >> 2] | 0) + 12 >> 2] | 0) | 0;
	                        if ((c[(c[g >> 2] | 0) + 52 >> 2] | 0) <= 0) {
	                            if ((c[l >> 2] | 0) > 0)c[l >> 2] = 0
	                        } else c[l >> 2] = -1;
	                        Rv(c[k >> 2] | 0);
	                        k = Ji(c[c[g >> 2] >> 2] | 0, c[(c[h >> 2] | 0) + 12 >> 2] | 0) | 0;
	                        c[(c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) + 16 >> 2] = k
	                    } else {
	                        c[(c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) + 16 >> 2] = 0;
	                        c[(c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) + 32 >> 2] = 1
	                    }
	                    c[f >> 2] = c[l >> 2];
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                c[f >> 2] = -1;
	                m = c[f >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function kw(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f + 44 | 0;
	                h = f + 40 | 0;
	                j = f + 36 | 0;
	                k = f + 32 | 0;
	                l = f + 28 | 0;
	                m = f + 24 | 0;
	                n = f + 20 | 0;
	                o = f + 16 | 0;
	                p = f + 12 | 0;
	                q = f + 8 | 0;
	                r = f + 4 | 0;
	                s = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = 0;
	                c[n >> 2] = 0;
	                if (!(c[k >> 2] | 0))c[k >> 2] = c[c[h >> 2] >> 2];
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0) {
	                    c[g >> 2] = 0;
	                    t = c[g >> 2] | 0;
	                    i = f;
	                    return t | 0
	                }
	                e = c[c[l >> 2] >> 2] | 0;
	                a:do if ((e | 0) == 6) {
	                    c[g >> 2] = sw(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0;
	                    t = c[g >> 2] | 0;
	                    i = f;
	                    return t | 0
	                } else if ((e | 0) == 1) {
	                    c[p >> 2] = c[(c[l >> 2] | 0) + 4 >> 2];
	                    if (!(c[p >> 2] | 0)) {
	                        c[g >> 2] = 0;
	                        t = c[g >> 2] | 0;
	                        i = f;
	                        return t | 0
	                    }
	                    c[o >> 2] = 0;
	                    while (1) {
	                        if ((c[o >> 2] | 0) >= (c[c[p >> 2] >> 2] | 0))break a;
	                        b:do if (c[(c[(c[p >> 2] | 0) + 8 >> 2] | 0) + (c[o >> 2] << 2) >> 2] | 0) {
	                            switch (c[(c[(c[(c[p >> 2] | 0) + 8 >> 2] | 0) + (c[o >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0) {
	                                case 2:
	                                case 18:
	                                case 10:
	                                case 11:
	                                case 12:
	                                case 14:
	                                case 15:
	                                case 16:
	                                case 17:
	                                {
	                                    break b;
	                                    break
	                                }
	                                case 19:
	                                    break;
	                                default:
	                                {
	                                    if (!(c[n >> 2] | 0)) {
	                                        d = rw(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[(c[(c[p >> 2] | 0) + 8 >> 2] | 0) + (c[o >> 2] << 2) >> 2] | 0) | 0;
	                                        c[n >> 2] = d;
	                                        c[m >> 2] = d;
	                                        break b
	                                    }
	                                    Xh(c[n >> 2] | 0, rw(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[(c[(c[p >> 2] | 0) + 8 >> 2] | 0) + (c[o >> 2] << 2) >> 2] | 0) | 0) | 0;
	                                    if (!(c[(c[n >> 2] | 0) + 24 >> 2] | 0))break b;
	                                    c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2];
	                                    break b
	                                }
	                            }
	                            c[r >> 2] = c[(c[(c[p >> 2] | 0) + 8 >> 2] | 0) + (c[o >> 2] << 2) >> 2];
	                            c[r >> 2] = c[(c[r >> 2] | 0) + 24 >> 2];
	                            while (1) {
	                                if (!(c[r >> 2] | 0))break b;
	                                switch (c[(c[r >> 2] | 0) + 4 >> 2] | 0) {
	                                    case 8:
	                                    case 7:
	                                    case 6:
	                                    case 5:
	                                    case 1:
	                                    case 4:
	                                    case 3:
	                                        break;
	                                    default:
	                                        break b
	                                }
	                                c[q >> 2] = rw(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[r >> 2] | 0) | 0;
	                                if (!(c[n >> 2] | 0)) {
	                                    d = c[q >> 2] | 0;
	                                    c[n >> 2] = d;
	                                    c[m >> 2] = d
	                                } else {
	                                    Xh(c[n >> 2] | 0, c[q >> 2] | 0) | 0;
	                                    c[n >> 2] = c[q >> 2]
	                                }
	                                c[r >> 2] = c[(c[r >> 2] | 0) + 24 >> 2]
	                            }
	                        } while (0);
	                        c[o >> 2] = (c[o >> 2] | 0) + 1
	                    }
	                } else if ((e | 0) == 7) {
	                    c[s >> 2] = c[(c[l >> 2] | 0) + 28 >> 2];
	                    if (!(c[s >> 2] | 0)) {
	                        c[g >> 2] = 0;
	                        t = c[g >> 2] | 0;
	                        i = f;
	                        return t | 0
	                    }
	                    c[o >> 2] = 0;
	                    while (1) {
	                        if ((c[o >> 2] | 0) >= (c[c[s >> 2] >> 2] | 0))break a;
	                        if (!(c[n >> 2] | 0)) {
	                            d = kw(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[(c[(c[s >> 2] | 0) + 8 >> 2] | 0) + (c[o >> 2] << 2) >> 2] | 0) | 0;
	                            c[n >> 2] = d;
	                            c[m >> 2] = d
	                        } else {
	                            d = c[n >> 2] | 0;
	                            Xh(d, kw(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[(c[(c[s >> 2] | 0) + 8 >> 2] | 0) + (c[o >> 2] << 2) >> 2] | 0) | 0) | 0
	                        }
	                        c:do if (c[n >> 2] | 0)while (1) {
	                            if (!(c[(c[n >> 2] | 0) + 24 >> 2] | 0))break c;
	                            c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2]
	                        } while (0);
	                        c[o >> 2] = (c[o >> 2] | 0) + 1
	                    }
	                } while (0);
	                c[g >> 2] = c[m >> 2];
	                t = c[g >> 2] | 0;
	                i = f;
	                return t | 0
	            }

	            function lw(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = Cb[c[135744 >> 2] & 511](36) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    Xv(c[g >> 2] | 0, c[j >> 2] | 0, 133672);
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                d = (c[k >> 2] | 0) + 0 | 0;
	                b = d + 36 | 0;
	                do {
	                    c[d >> 2] = 0;
	                    d = d + 4 | 0
	                } while ((d | 0) < (b | 0));
	                if (!(c[h >> 2] | 0))c[c[k >> 2] >> 2] = 0; else {
	                    d = my(c[h >> 2] | 0) | 0;
	                    c[c[k >> 2] >> 2] = d
	                }
	                c[(c[k >> 2] | 0) + 4 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 12 >> 2] = c[j >> 2];
	                c[(c[k >> 2] | 0) + 8 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 24 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 20 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 16 >> 2] = 0;
	                if ((c[(c[g >> 2] | 0) + 12 >> 2] | 0) == 0 ? (c[(c[g >> 2] | 0) + 12 >> 2] = 4, d = Cb[c[135744 >> 2] & 511](c[(c[g >> 2] | 0) + 12 >> 2] << 2) | 0, c[(c[g >> 2] | 0) + 16 >> 2] = d, (c[(c[g >> 2] | 0) + 16 >> 2] | 0) == 0) : 0) {
	                    Xv(c[g >> 2] | 0, c[j >> 2] | 0, 133672);
	                    Zv(c[k >> 2] | 0);
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                if ((c[(c[g >> 2] | 0) + 8 >> 2] | 0) >= (c[(c[g >> 2] | 0) + 12 >> 2] | 0) ? (d = (c[g >> 2] | 0) + 12 | 0, c[d >> 2] = c[d >> 2] << 1, d = Hb[c[135760 >> 2] & 511](c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] << 2) | 0, c[(c[g >> 2] | 0) + 16 >> 2] = d, (c[(c[g >> 2] | 0) + 16 >> 2] | 0) == 0) : 0) {
	                    Xv(c[g >> 2] | 0, c[j >> 2] | 0, 133672);
	                    Zv(c[k >> 2] | 0);
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                j = c[k >> 2] | 0;
	                d = (c[g >> 2] | 0) + 8 | 0;
	                h = c[d >> 2] | 0;
	                c[d >> 2] = h + 1;
	                c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + (h << 2) >> 2] = j;
	                c[f >> 2] = c[k >> 2];
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function mw(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                Rf();
	                c[j >> 2] = Be() | 0;
	                b = c[f >> 2] | 0;
	                if (!(c[j >> 2] | 0)) {
	                    Xv(b, 0, 133464);
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                c[(c[j >> 2] | 0) + 272 >> 2] = c[b + 68 >> 2];
	                if ((c[c[f >> 2] >> 2] | 0) != 0 ? (c[(c[c[f >> 2] >> 2] | 0) + 80 >> 2] | 0) != 0 : 0) {
	                    if (c[(c[j >> 2] | 0) + 296 >> 2] | 0)zP(c[(c[j >> 2] | 0) + 296 >> 2] | 0);
	                    c[(c[j >> 2] | 0) + 296 >> 2] = c[(c[c[f >> 2] >> 2] | 0) + 80 >> 2];
	                    yP(c[(c[j >> 2] | 0) + 296 >> 2] | 0) | 0
	                }
	                fg(c[j >> 2] | 0, c[(c[f >> 2] | 0) + 60 >> 2] | 4) | 0;
	                c[k >> 2] = Vk(c[g >> 2] | 0, 0, c[j >> 2] | 0) | 0;
	                f = c[j >> 2] | 0;
	                if (!(c[k >> 2] | 0)) {
	                    Ae(f);
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                Oe(f, c[k >> 2] | 0) | 0;
	                if (!(c[(c[j >> 2] | 0) + 180 >> 2] | 0)) {
	                    k = Rk(c[g >> 2] | 0) | 0;
	                    c[(c[j >> 2] | 0) + 180 >> 2] = k
	                }
	                k = (c[j >> 2] | 0) + 276 | 0;
	                c[k >> 2] = c[k >> 2] | 2;
	                Qf(c[j >> 2] | 0) | 0;
	                if (c[(c[j >> 2] | 0) + 12 >> 2] | 0)c[h >> 2] = c[(c[j >> 2] | 0) + 8 >> 2]; else {
	                    c[h >> 2] = 0;
	                    if (c[(c[j >> 2] | 0) + 8 >> 2] | 0)Th(c[(c[j >> 2] | 0) + 8 >> 2] | 0);
	                    c[(c[j >> 2] | 0) + 8 >> 2] = 0
	                }
	                Ae(c[j >> 2] | 0);
	                c[e >> 2] = c[h >> 2];
	                l = c[e >> 2] | 0;
	                i = d;
	                return l | 0
	            }

	            function nw(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 40 | 0;
	                g = e + 36 | 0;
	                h = e + 32 | 0;
	                j = e + 28 | 0;
	                k = e + 24 | 0;
	                l = e + 20 | 0;
	                m = e + 16 | 0;
	                n = e + 8 | 0;
	                o = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = -1;
	                    p = c[f >> 2] | 0;
	                    i = e;
	                    return p | 0
	                }
	                if ((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 44 >> 2] | 0) != 0 : 0) {
	                    c[l >> 2] = c[(c[h >> 2] | 0) + 44 >> 2];
	                    if (!(c[l >> 2] | 0)) {
	                        c[k >> 2] = Pi(c[h >> 2] | 0) | 0;
	                        if (!(c[k >> 2] | 0)) {
	                            c[f >> 2] = -1;
	                            p = c[f >> 2] | 0;
	                            i = e;
	                            return p | 0
	                        }
	                        c[l >> 2] = Oh(c[h >> 2] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0, 0, 0) | 0;
	                        if (!(c[l >> 2] | 0)) {
	                            c[f >> 2] = -1;
	                            p = c[f >> 2] | 0;
	                            i = e;
	                            return p | 0
	                        }
	                    }
	                    c[m >> 2] = c[(c[j >> 2] | 0) + 44 >> 2];
	                    if ((c[m >> 2] | 0) != 0 ? (c[(c[m >> 2] | 0) + 48 >> 2] | 0) != 0 : 0) {
	                        c[n + 4 >> 2] = c[g >> 2];
	                        c[n >> 2] = c[h >> 2];
	                        Wj(c[(c[m >> 2] | 0) + 48 >> 2] | 0, 314, n)
	                    }
	                    c[m >> 2] = c[(c[j >> 2] | 0) + 48 >> 2];
	                    if ((((c[m >> 2] | 0) != 0 ? (c[(c[m >> 2] | 0) + 48 >> 2] | 0) != 0 : 0) ? (c[o + 4 >> 2] = c[g >> 2], c[o >> 2] = c[h >> 2], (qy(c[(c[l >> 2] | 0) + 52 >> 2] | 0, c[(c[m >> 2] | 0) + 52 >> 2] | 0) | 0) == 0) : 0) ? (qy(c[(c[l >> 2] | 0) + 56 >> 2] | 0, c[(c[m >> 2] | 0) + 56 >> 2] | 0) | 0) == 0 : 0)Wj(c[(c[m >> 2] | 0) + 48 >> 2] | 0, 314, o);
	                    c[f >> 2] = 0;
	                    p = c[f >> 2] | 0;
	                    i = e;
	                    return p | 0
	                }
	                c[f >> 2] = 0;
	                p = c[f >> 2] | 0;
	                i = e;
	                return p | 0
	            }

	            function ow(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[e + 8 >> 2] = d;
	                c[h >> 2] = Qv(c[g >> 2] | 0) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                c[(c[h >> 2] | 0) + 68 >> 2] = c[(c[f >> 2] | 0) + 68 >> 2];
	                c[(c[h >> 2] | 0) + 12 >> 2] = c[(c[f >> 2] | 0) + 12 >> 2];
	                c[(c[h >> 2] | 0) + 8 >> 2] = c[(c[f >> 2] | 0) + 8 >> 2];
	                d = Cb[c[135744 >> 2] & 511](c[(c[h >> 2] | 0) + 12 >> 2] << 2) | 0;
	                c[(c[h >> 2] | 0) + 16 >> 2] = d;
	                d = c[f >> 2] | 0;
	                if (!(c[(c[h >> 2] | 0) + 16 >> 2] | 0)) {
	                    Xv(d, c[g >> 2] | 0, 133408);
	                    zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                    i = e;
	                    return
	                }
	                c[(c[h >> 2] | 0) + 44 >> 2] = c[d + 44 >> 2];
	                c[(c[h >> 2] | 0) + 40 >> 2] = c[(c[f >> 2] | 0) + 40 >> 2];
	                c[(c[h >> 2] | 0) + 48 >> 2] = c[(c[f >> 2] | 0) + 48 >> 2];
	                d = my(c[(c[f >> 2] | 0) + 64 >> 2] | 0) | 0;
	                c[(c[h >> 2] | 0) + 64 >> 2] = d;
	                c[(c[h >> 2] | 0) + 4 >> 2] = c[(c[f >> 2] | 0) + 8 >> 2];
	                c[j >> 2] = 0;
	                while (1) {
	                    if ((c[j >> 2] | 0) >= (c[(c[f >> 2] | 0) + 8 >> 2] | 0))break;
	                    c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[j >> 2] << 2) >> 2] = c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + (c[j >> 2] << 2) >> 2];
	                    d = (c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) + 24 | 0;
	                    c[d >> 2] = (c[d >> 2] | 0) + 1;
	                    c[j >> 2] = (c[j >> 2] | 0) + 1
	                }
	                c[(c[h >> 2] | 0) + 60 >> 2] = c[(c[f >> 2] | 0) + 60 >> 2];
	                d = c[h >> 2] | 0;
	                b = c[g >> 2] | 0;
	                _v(d, b, Pi(c[g >> 2] | 0) | 0) | 0;
	                c[j >> 2] = 0;
	                while (1) {
	                    if ((c[j >> 2] | 0) >= (c[(c[f >> 2] | 0) + 8 >> 2] | 0))break;
	                    g = (c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) + 24 | 0;
	                    c[g >> 2] = (c[g >> 2] | 0) + -1;
	                    c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + (c[j >> 2] << 2) >> 2] = 0;
	                    c[j >> 2] = (c[j >> 2] | 0) + 1
	                }
	                c[(c[f >> 2] | 0) + 48 >> 2] = c[(c[h >> 2] | 0) + 48 >> 2];
	                c[(c[f >> 2] | 0) + 44 >> 2] = c[(c[h >> 2] | 0) + 44 >> 2];
	                c[(c[h >> 2] | 0) + 44 >> 2] = 0;
	                c[(c[h >> 2] | 0) + 40 >> 2] = 0;
	                c[(c[h >> 2] | 0) + 48 >> 2] = 0;
	                Rv(c[h >> 2] | 0);
	                i = e;
	                return
	            }

	            function pw(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f + 32 | 0;
	                h = f + 28 | 0;
	                j = f + 24 | 0;
	                k = f + 20 | 0;
	                l = f + 16 | 0;
	                m = f + 12 | 0;
	                n = f + 8 | 0;
	                o = f + 4 | 0;
	                p = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[o >> 2] = 0;
	                c[p >> 2] = 0;
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0) {
	                    c[g >> 2] = 0;
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                c[m >> 2] = c[l >> 2];
	                while (1) {
	                    if (!(c[m >> 2] | 0))break;
	                    c[n >> 2] = rw(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[m >> 2] | 0) | 0;
	                    do if (c[n >> 2] | 0) {
	                        l = c[n >> 2] | 0;
	                        if (!(c[o >> 2] | 0)) {
	                            c[p >> 2] = l;
	                            c[o >> 2] = l;
	                            break
	                        } else {
	                            c[(c[p >> 2] | 0) + 24 >> 2] = l;
	                            c[(c[n >> 2] | 0) + 28 >> 2] = c[p >> 2];
	                            c[p >> 2] = c[n >> 2];
	                            break
	                        }
	                    } while (0);
	                    c[m >> 2] = c[(c[m >> 2] | 0) + 24 >> 2]
	                }
	                c[g >> 2] = c[o >> 2];
	                q = c[g >> 2] | 0;
	                i = f;
	                return q | 0
	            }

	            function qw(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if (!(c[(c[f >> 2] | 0) + 24 >> 2] | 0)) {
	                    c[(c[f >> 2] | 0) + 24 >> 2] = 4;
	                    d = Cb[c[135744 >> 2] & 511](c[(c[f >> 2] | 0) + 24 >> 2] << 2) | 0;
	                    c[(c[f >> 2] | 0) + 28 >> 2] = d;
	                    if (!(c[(c[f >> 2] | 0) + 28 >> 2] | 0)) {
	                        Xv(c[f >> 2] | 0, 0, 133040);
	                        i = e;
	                        return
	                    }
	                    d = Cb[c[135744 >> 2] & 511](c[(c[f >> 2] | 0) + 24 >> 2] << 2) | 0;
	                    c[(c[f >> 2] | 0) + 32 >> 2] = d;
	                    if (!(c[(c[f >> 2] | 0) + 32 >> 2] | 0)) {
	                        Xv(c[f >> 2] | 0, 0, 133040);
	                        i = e;
	                        return
	                    }
	                }
	                if ((c[(c[f >> 2] | 0) + 20 >> 2] | 0) >= (c[(c[f >> 2] | 0) + 24 >> 2] | 0)) {
	                    d = (c[f >> 2] | 0) + 24 | 0;
	                    c[d >> 2] = c[d >> 2] << 1;
	                    d = Hb[c[135760 >> 2] & 511](c[(c[f >> 2] | 0) + 28 >> 2] | 0, c[(c[f >> 2] | 0) + 24 >> 2] << 2) | 0;
	                    c[(c[f >> 2] | 0) + 28 >> 2] = d;
	                    if (!(c[(c[f >> 2] | 0) + 28 >> 2] | 0)) {
	                        Xv(c[f >> 2] | 0, 0, 133040);
	                        i = e;
	                        return
	                    }
	                    d = Hb[c[135760 >> 2] & 511](c[(c[f >> 2] | 0) + 32 >> 2] | 0, c[(c[f >> 2] | 0) + 24 >> 2] << 2) | 0;
	                    c[(c[f >> 2] | 0) + 32 >> 2] = d;
	                    if (!(c[(c[f >> 2] | 0) + 32 >> 2] | 0)) {
	                        Xv(c[f >> 2] | 0, 0, 133040);
	                        i = e;
	                        return
	                    }
	                }
	                c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + (c[(c[f >> 2] | 0) + 20 >> 2] << 2) >> 2] = c[g >> 2];
	                g = my(c[h >> 2] | 0) | 0;
	                c[(c[(c[f >> 2] | 0) + 32 >> 2] | 0) + (c[(c[f >> 2] | 0) + 20 >> 2] << 2) >> 2] = g;
	                g = (c[f >> 2] | 0) + 20 | 0;
	                c[g >> 2] = (c[g >> 2] | 0) + 1;
	                i = e;
	                return
	            }

	            function rw(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = 0;
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0) {
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                if ((c[(c[l >> 2] | 0) + 4 >> 2] | 0) == 14) {
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                if ((c[(c[l >> 2] | 0) + 4 >> 2] | 0) == 9)c[m >> 2] = pw(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[(c[l >> 2] | 0) + 12 >> 2] | 0) | 0; else c[m >> 2] = Ii(c[l >> 2] | 0, c[j >> 2] | 0, 1) | 0;
	                c[g >> 2] = c[m >> 2];
	                n = c[g >> 2] | 0;
	                i = f;
	                return n | 0
	            }

	            function sw(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0;
	                f = i;
	                i = i + 96 | 0;
	                g = f + 84 | 0;
	                h = f + 80 | 0;
	                j = f + 76 | 0;
	                k = f + 72 | 0;
	                l = f + 68 | 0;
	                m = f + 64 | 0;
	                n = f + 60 | 0;
	                o = f + 56 | 0;
	                p = f + 52 | 0;
	                q = f + 48 | 0;
	                r = f + 44 | 0;
	                s = f + 40 | 0;
	                t = f + 36 | 0;
	                u = f + 32 | 0;
	                v = f + 28 | 0;
	                w = f + 24 | 0;
	                x = f + 20 | 0;
	                y = f + 16 | 0;
	                z = f + 12 | 0;
	                A = f + 8 | 0;
	                B = f + 4 | 0;
	                C = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = 0;
	                c[n >> 2] = 0;
	                c[o >> 2] = 0;
	                c[w >> 2] = 0;
	                c[x >> 2] = 0;
	                c[y >> 2] = 0;
	                c[z >> 2] = 0;
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0) {
	                    c[g >> 2] = 0;
	                    D = c[g >> 2] | 0;
	                    i = f;
	                    return D | 0
	                }
	                if ((c[c[l >> 2] >> 2] | 0) != 6) {
	                    c[g >> 2] = 0;
	                    D = c[g >> 2] | 0;
	                    i = f;
	                    return D | 0
	                }
	                c[r >> 2] = c[(c[l >> 2] | 0) + 28 >> 2];
	                if ((c[r >> 2] | 0) != 0 ? (c[(c[r >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                    c[t >> 2] = c[(c[l >> 2] | 0) + 36 >> 2];
	                    if (!(c[t >> 2] | 0)) {
	                        c[g >> 2] = Ii(c[r >> 2] | 0, c[j >> 2] | 0, 1) | 0;
	                        D = c[g >> 2] | 0;
	                        i = f;
	                        return D | 0
	                    }
	                    if ((c[(c[t >> 2] | 0) + 4 >> 2] | 0) == 18) {
	                        c[g >> 2] = 0;
	                        D = c[g >> 2] | 0;
	                        i = f;
	                        return D | 0
	                    }
	                    c[s >> 2] = c[r >> 2];
	                    c[u >> 2] = c[(c[l >> 2] | 0) + 32 >> 2];
	                    c[v >> 2] = c[(c[l >> 2] | 0) + 40 >> 2];
	                    a:while (1) {
	                        if (!(c[s >> 2] | 0)) {
	                            E = 65;
	                            break
	                        }
	                        b:while (1) {
	                            if ((c[w >> 2] | 0) < 0) {
	                                while (1) {
	                                    if ((c[w >> 2] | 0) >= 0)break;
	                                    c[q >> 2] = Ii(c[o >> 2] | 0, c[j >> 2] | 0, 2) | 0;
	                                    zi(c[q >> 2] | 0, c[m >> 2] | 0) | 0;
	                                    c[m >> 2] = c[q >> 2];
	                                    c[o >> 2] = c[(c[o >> 2] | 0) + 20 >> 2];
	                                    c[w >> 2] = (c[w >> 2] | 0) + 1
	                                }
	                                c[n >> 2] = c[m >> 2];
	                                c[x >> 2] = 0
	                            }
	                            while (1) {
	                                if ((c[w >> 2] | 0) >= (c[x >> 2] | 0))break;
	                                c[n >> 2] = c[(c[n >> 2] | 0) + 20 >> 2];
	                                c[x >> 2] = (c[x >> 2] | 0) + -1
	                            }
	                            F = c[s >> 2] | 0;
	                            if ((c[s >> 2] | 0) == (c[t >> 2] | 0))break;
	                            do if ((F | 0) != (c[r >> 2] | 0)) {
	                                c[p >> 2] = 0;
	                                switch (c[(c[s >> 2] | 0) + 4 >> 2] | 0) {
	                                    case 2:
	                                    case 20:
	                                    case 19:
	                                    case 17:
	                                    case 6:
	                                    case 16:
	                                    case 15:
	                                    case 14:
	                                        break;
	                                    default:
	                                        c[p >> 2] = Ii(c[s >> 2] | 0, c[j >> 2] | 0, 2) | 0
	                                }
	                                if (c[p >> 2] | 0) {
	                                    l = c[n >> 2] | 0;
	                                    k = c[p >> 2] | 0;
	                                    if ((c[w >> 2] | 0) == (c[x >> 2] | 0))Xh(l, k) | 0; else {
	                                        zi(l, k) | 0;
	                                        c[x >> 2] = c[w >> 2]
	                                    }
	                                    c[n >> 2] = c[p >> 2]
	                                }
	                            } else {
	                                if ((c[(c[s >> 2] | 0) + 4 >> 2] | 0) != 3 ? (c[(c[s >> 2] | 0) + 4 >> 2] | 0) != 4 : 0) {
	                                    c[p >> 2] = Ii(c[s >> 2] | 0, c[j >> 2] | 0, 2) | 0;
	                                    k = c[p >> 2] | 0;
	                                    c[n >> 2] = k;
	                                    c[m >> 2] = k;
	                                    c[o >> 2] = c[(c[s >> 2] | 0) + 20 >> 2];
	                                    if ((c[u >> 2] | 0) > 1) {
	                                        E = 55;
	                                        break b
	                                    } else break
	                                }
	                                c[C >> 2] = c[(c[s >> 2] | 0) + 40 >> 2];
	                                if (!(c[C >> 2] | 0))c[p >> 2] = ni(0, 0) | 0; else {
	                                    if ((c[u >> 2] | 0) > 1) {
	                                        c[C >> 2] = (c[C >> 2] | 0) + ((c[u >> 2] | 0) - 1);
	                                        c[u >> 2] = 0
	                                    }
	                                    c[p >> 2] = li(c[C >> 2] | 0) | 0
	                                }
	                                k = c[p >> 2] | 0;
	                                c[m >> 2] = k;
	                                c[n >> 2] = k;
	                                c[o >> 2] = c[(c[s >> 2] | 0) + 20 >> 2]
	                            } while (0);
	                            c[s >> 2] = lv(c[s >> 2] | 0, w) | 0;
	                            if (!(c[z >> 2] | 0))continue a;
	                            if (!((c[s >> 2] | 0) != 0 ? (c[w >> 2] | 0) < (c[y >> 2] | 0) : 0)) {
	                                E = 65;
	                                break a
	                            }
	                        }
	                        if ((E | 0) == 55) {
	                            E = 0;
	                            c[s >> 2] = uw(c[s >> 2] | 0, (c[u >> 2] | 0) - 1 | 0) | 0;
	                            c[x >> 2] = 1;
	                            c[w >> 2] = 1;
	                            c[u >> 2] = 0;
	                            continue
	                        }
	                        if ((c[F + 4 >> 2] | 0) == 3)break;
	                        c[y >> 2] = c[w >> 2];
	                        c[z >> 2] = 1;
	                        c[p >> 2] = Ii(c[s >> 2] | 0, c[j >> 2] | 0, 2) | 0;
	                        do if (c[m >> 2] | 0) {
	                            k = c[n >> 2] | 0;
	                            l = c[p >> 2] | 0;
	                            if ((c[w >> 2] | 0) == (c[x >> 2] | 0)) {
	                                Xh(k, l) | 0;
	                                break
	                            } else {
	                                zi(k, l) | 0;
	                                c[x >> 2] = c[w >> 2];
	                                break
	                            }
	                        } else {
	                            c[m >> 2] = c[p >> 2];
	                            c[o >> 2] = c[(c[s >> 2] | 0) + 20 >> 2]
	                        } while (0);
	                        c[n >> 2] = c[p >> 2];
	                        if ((c[v >> 2] | 0) > 1) {
	                            c[t >> 2] = uw(c[s >> 2] | 0, (c[v >> 2] | 0) - 1 | 0) | 0;
	                            c[v >> 2] = 0
	                        }
	                        l = c[s >> 2] | 0;
	                        if ((c[u >> 2] | 0) > 1 ? (c[s >> 2] | 0) == (c[r >> 2] | 0) : 0) {
	                            c[s >> 2] = uw(l, (c[u >> 2] | 0) - 1 | 0) | 0;
	                            c[u >> 2] = 0
	                        } else c[s >> 2] = c[l + 12 >> 2];
	                        c[w >> 2] = (c[w >> 2] | 0) + 1
	                    }
	                    if ((E | 0) == 65) {
	                        c[g >> 2] = c[m >> 2];
	                        D = c[g >> 2] | 0;
	                        i = f;
	                        return D | 0
	                    }
	                    c[A >> 2] = c[(c[s >> 2] | 0) + 40 >> 2];
	                    if (!(c[A >> 2] | 0))c[p >> 2] = ni(0, 0) | 0; else {
	                        c[B >> 2] = c[v >> 2];
	                        if ((c[u >> 2] | 0) > 1 ? (c[s >> 2] | 0) == (c[r >> 2] | 0) : 0) {
	                            c[A >> 2] = (c[A >> 2] | 0) + ((c[u >> 2] | 0) - 1);
	                            c[B >> 2] = (c[B >> 2] | 0) - ((c[u >> 2] | 0) - 1)
	                        } else c[B >> 2] = c[v >> 2];
	                        c[p >> 2] = ni(c[A >> 2] | 0, c[B >> 2] | 0) | 0
	                    }
	                    if (!(c[m >> 2] | 0)) {
	                        c[g >> 2] = c[p >> 2];
	                        D = c[g >> 2] | 0;
	                        i = f;
	                        return D | 0
	                    }
	                    B = c[n >> 2] | 0;
	                    n = c[p >> 2] | 0;
	                    if ((c[w >> 2] | 0) == (c[x >> 2] | 0))Xh(B, n) | 0; else zi(B, n) | 0;
	                    c[g >> 2] = c[m >> 2];
	                    D = c[g >> 2] | 0;
	                    i = f;
	                    return D | 0
	                }
	                c[g >> 2] = 0;
	                D = c[g >> 2] | 0;
	                i = f;
	                return D | 0
	            }

	            function tw(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 20 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[e + 16 >> 2] = d;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    i = e;
	                    return
	                }
	                c[l >> 2] = c[(c[g >> 2] | 0) + 4 >> 2];
	                c[k >> 2] = c[c[g >> 2] >> 2];
	                if ((c[l >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0) {
	                    i = e;
	                    return
	                }
	                if (((c[(c[f >> 2] | 0) + 48 >> 2] | 0) + -4 | 0) >>> 0 < 3) {
	                    i = e;
	                    return
	                }
	                c[h >> 2] = _c(c[k >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0, c[(c[f >> 2] | 0) + 48 >> 2] | 0, c[(c[f >> 2] | 0) + 52 >> 2] | 0, c[(c[f >> 2] | 0) + 56 >> 2] | 0, c[(c[f >> 2] | 0) + 40 >> 2] | 0) | 0;
	                if (c[h >> 2] | 0) {
	                    if (!(c[(c[f >> 2] | 0) + 64 >> 2] | 0)) {
	                        i = e;
	                        return
	                    }
	                    g = my(c[(c[f >> 2] | 0) + 64 >> 2] | 0) | 0;
	                    c[(c[h >> 2] | 0) + 64 >> 2] = g;
	                    i = e;
	                    return
	                }
	                c[j >> 2] = ad(c[k >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                do if ((c[(c[f >> 2] | 0) + 48 >> 2] | 0) == (c[(c[j >> 2] | 0) + 48 >> 2] | 0)) {
	                    if ((c[(c[f >> 2] | 0) + 56 >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 56 >> 2] | 0) != 0 : 0) {
	                        if (!(qy(c[(c[f >> 2] | 0) + 56 >> 2] | 0, c[(c[j >> 2] | 0) + 56 >> 2] | 0) | 0))break;
	                        i = e;
	                        return
	                    }
	                    if ((c[(c[f >> 2] | 0) + 52 >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 52 >> 2] | 0) != 0 : 0) {
	                        if (!(qy(c[(c[f >> 2] | 0) + 52 >> 2] | 0, c[(c[j >> 2] | 0) + 52 >> 2] | 0) | 0))break;
	                        i = e;
	                        return
	                    }
	                    if (((c[(c[f >> 2] | 0) + 40 >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) ? (qy(c[(c[f >> 2] | 0) + 40 >> 2] | 0, c[(c[j >> 2] | 0) + 40 >> 2] | 0) | 0) != 0 : 0) {
	                        i = e;
	                        return
	                    }
	                } while (0);
	                switch (c[(c[f >> 2] | 0) + 48 >> 2] | 0) {
	                    case 2:
	                    case 1:
	                    case 6:
	                    case 5:
	                    case 4:
	                    {
	                        i = e;
	                        return
	                    }
	                    default:
	                    {
	                    }
	                }
	                ew(c[l >> 2] | 0, c[f >> 2] | 0, 1602, 133424, c[(c[f >> 2] | 0) + 8 >> 2] | 0);
	                i = e;
	                return
	            }

	            function uw(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                    c[f >> 2] = c[(c[f >> 2] | 0) + 12 >> 2];
	                    c[h >> 2] = 0;
	                    while (1) {
	                        if ((c[h >> 2] | 0) > (c[g >> 2] | 0)) {
	                            j = 13;
	                            break
	                        }
	                        k = c[f >> 2] | 0;
	                        if (!(c[f >> 2] | 0)) {
	                            j = 7;
	                            break
	                        }
	                        if (!(((c[k + 4 >> 2] | 0) != 1 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 9 : 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 13 : 0))j = 11;
	                        if ((j | 0) == 11 ? (j = 0, c[h >> 2] = (c[h >> 2] | 0) + 1, (c[h >> 2] | 0) == (c[g >> 2] | 0)) : 0) {
	                            j = 13;
	                            break
	                        }
	                        c[f >> 2] = c[(c[f >> 2] | 0) + 24 >> 2]
	                    }
	                    if ((j | 0) == 7) {
	                        c[e >> 2] = k;
	                        l = c[e >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    } else if ((j | 0) == 13) {
	                        c[e >> 2] = c[f >> 2];
	                        l = c[e >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    }
	                }
	                c[e >> 2] = 0;
	                l = c[e >> 2] | 0;
	                i = d;
	                return l | 0
	            }

	            function vw(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 60 >> 2] | 0)Lw(c[(c[d >> 2] | 0) + 60 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 52 >> 2] | 0)Kj(c[(c[d >> 2] | 0) + 52 >> 2] | 0, 315);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function ww(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b;
	                e = b + 28 | 0;
	                f = b + 24 | 0;
	                g = b + 20 | 0;
	                h = b + 16 | 0;
	                j = b + 12 | 0;
	                k = b + 8 | 0;
	                l = b + 4 | 0;
	                c[f >> 2] = a;
	                c[j >> 2] = 0;
	                c[h >> 2] = Be() | 0;
	                if (!(c[h >> 2] | 0)) {
	                    if (c[34014] | 0)Db[c[135968 + 88 >> 2] & 511](0, 133880, d);
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = b;
	                    return m | 0
	                }
	                c[l >> 2] = Ck(c[f >> 2] | 0, 0) | 0;
	                d = c[h >> 2] | 0;
	                if (!(c[l >> 2] | 0)) {
	                    Ae(d);
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = b;
	                    return m | 0
	                }
	                c[k >> 2] = ue(d) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    Ae(c[h >> 2] | 0);
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = b;
	                    return m | 0
	                }
	                d = Jl(c[f >> 2] | 0) | 0;
	                c[(c[k >> 2] | 0) + 4 >> 2] = d;
	                c[c[k >> 2] >> 2] = c[l >> 2];
	                iz(c[(c[l >> 2] | 0) + 16 >> 2] | 0, c[k >> 2] | 0) | 0;
	                Oe(c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                if ((c[j >> 2] | 0) == 0 ? (c[(c[h >> 2] | 0) + 180 >> 2] | 0) == 0 : 0)c[j >> 2] = Rk(c[f >> 2] | 0) | 0;
	                if ((c[j >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 180 >> 2] | 0) == 0 : 0)c[(c[h >> 2] | 0) + 180 >> 2] = c[j >> 2];
	                c[(c[h >> 2] | 0) + 100 >> 2] = 0;
	                c[(c[h >> 2] | 0) + 104 >> 2] = 0;
	                c[(c[h >> 2] | 0) + 276 >> 2] = 0;
	                c[(c[h >> 2] | 0) + 268 >> 2] = 0;
	                c[(c[h >> 2] | 0) + 364 >> 2] = 1;
	                Qf(c[h >> 2] | 0) | 0;
	                if (c[(c[h >> 2] | 0) + 12 >> 2] | 0)c[g >> 2] = c[(c[h >> 2] | 0) + 8 >> 2]; else {
	                    c[g >> 2] = 0;
	                    Th(c[(c[h >> 2] | 0) + 8 >> 2] | 0);
	                    c[(c[h >> 2] | 0) + 8 >> 2] = 0
	                }
	                Ae(c[h >> 2] | 0);
	                c[e >> 2] = c[g >> 2];
	                m = c[e >> 2] | 0;
	                i = b;
	                return m | 0
	            }

	            function xw(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                b = i;
	                i = i + 32 | 0;
	                e = b + 20 | 0;
	                f = b + 16 | 0;
	                g = b + 12 | 0;
	                h = b + 8 | 0;
	                j = b + 4 | 0;
	                k = b;
	                c[f >> 2] = a;
	                c[g >> 2] = Nw(c[f >> 2] | 0) | 0;
	                if (!(c[g >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = b;
	                    return l | 0
	                }
	                c[h >> 2] = c[g >> 2];
	                while (1) {
	                    if (((d[c[h >> 2] >> 0] | 0 | 0) != 0 ? (d[c[h >> 2] >> 0] | 0 | 0) != 45 : 0) ? (d[c[h >> 2] >> 0] | 0 | 0) != 60 : 0) {
	                        if ((d[c[h >> 2] >> 0] | 0 | 0) >= 65 ? (d[c[h >> 2] >> 0] | 0 | 0) <= 90 : 0)m = 1; else if ((d[c[h >> 2] >> 0] | 0 | 0) >= 97)m = (d[c[h >> 2] >> 0] | 0 | 0) <= 122; else m = 0;
	                        n = m ^ 1
	                    } else n = 0;
	                    o = c[h >> 2] | 0;
	                    if (!n)break;
	                    c[h >> 2] = o + 1
	                }
	                h = c[33474] | 0;
	                do if ((d[o >> 0] | 0 | 0) != 60) {
	                    c[j >> 2] = Ow(2, h) | 0;
	                    if (!(c[j >> 2] | 0)) {
	                        zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                        c[e >> 2] = 0;
	                        l = c[e >> 2] | 0;
	                        i = b;
	                        return l | 0
	                    }
	                    c[k >> 2] = Pw(c[j >> 2] | 0, c[g >> 2] | 0, c[f >> 2] | 0, 0) | 0;
	                    if ((c[k >> 2] | 0) < 0) {
	                        vw(c[j >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                        c[e >> 2] = 0;
	                        l = c[e >> 2] | 0;
	                        i = b;
	                        return l | 0
	                    }
	                } else {
	                    c[j >> 2] = Ow(1, h) | 0;
	                    if (c[j >> 2] | 0) {
	                        n = Qw(1, 0, 0, c[f >> 2] | 0, c[33474] | 0, 0) | 0;
	                        c[(c[j >> 2] | 0) + 60 >> 2] = n;
	                        break
	                    }
	                    zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = b;
	                    return l | 0
	                } while (0);
	                zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                c[e >> 2] = c[j >> 2];
	                l = c[e >> 2] | 0;
	                i = b;
	                return l | 0
	            }

	            function yw(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e;
	                g = e + 28 | 0;
	                h = e + 24 | 0;
	                j = e + 20 | 0;
	                k = e + 16 | 0;
	                l = e + 12 | 0;
	                m = e + 8 | 0;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = 0;
	                if ((c[j >> 2] | 0) == 0 & (c[k >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) {
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                do if (c[33468] | 0) {
	                    if ((c[j >> 2] | 0) != 0 & (c[k >> 2] | 0) != 0) {
	                        d = c[33976] | 0;
	                        b = c[33980] | 0;
	                        a = c[k >> 2] | 0;
	                        c[f >> 2] = c[j >> 2];
	                        c[f + 4 >> 2] = a;
	                        Db[d & 511](b, 133904, f);
	                        break
	                    }
	                    b = c[33976] | 0;
	                    d = c[33980] | 0;
	                    if (c[j >> 2] | 0) {
	                        c[f >> 2] = c[j >> 2];
	                        Db[b & 511](d, 133936, f);
	                        break
	                    } else {
	                        c[f >> 2] = c[k >> 2];
	                        Db[b & 511](d, 133960, f);
	                        break
	                    }
	                } while (0);
	                f = c[h >> 2] | 0;
	                if ((c[c[h >> 2] >> 2] | 0) != 1) {
	                    c[m >> 2] = Uw(f, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                    if (c[m >> 2] | 0)c[l >> 2] = my(c[m >> 2] | 0) | 0
	                } else {
	                    m = Rw(c[f + 60 >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                    c[l >> 2] = m;
	                    c[l >> 2] = (c[l >> 2] | 0) == (-1 | 0) ? 0 : m
	                }
	                c[g >> 2] = c[l >> 2];
	                n = c[g >> 2] | 0;
	                i = e;
	                return n | 0
	            }

	            function zw(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = 0;
	                if ((c[h >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                if (c[33468] | 0) {
	                    b = c[33976] | 0;
	                    a = c[33980] | 0;
	                    c[e >> 2] = c[h >> 2];
	                    Db[b & 511](a, 133984, e)
	                }
	                e = c[g >> 2] | 0;
	                if ((c[c[g >> 2] >> 2] | 0) != 1) {
	                    c[k >> 2] = Uw(e, 0, c[h >> 2] | 0) | 0;
	                    if (c[k >> 2] | 0)c[j >> 2] = my(c[k >> 2] | 0) | 0
	                } else {
	                    k = Vw(c[e + 60 >> 2] | 0, c[h >> 2] | 0) | 0;
	                    c[j >> 2] = k;
	                    c[j >> 2] = (c[j >> 2] | 0) == (-1 | 0) ? 0 : k
	                }
	                c[f >> 2] = c[j >> 2];
	                l = c[f >> 2] | 0;
	                i = d;
	                return l | 0
	            }

	            function Aw() {
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 20 | 0;
	                e = b + 16 | 0;
	                f = b + 12 | 0;
	                g = b + 8 | 0;
	                h = b + 4 | 0;
	                j = b;
	                if (c[33500] | 0) {
	                    i = b;
	                    return
	                }
	                Ww();
	                vx(c[33502] | 0);
	                if (cb(134016) | 0)c[33468] = 1;
	                if ((c[33510] | 0) == 0 ? (k = cb(134048) | 0, c[d >> 2] = k, c[d >> 2] = (c[d >> 2] | 0) == 0 ? 134072 : k, c[h >> 2] = Ow(1, c[33474] | 0) | 0, (c[h >> 2] | 0) != 0) : 0) {
	                    c[f >> 2] = c[d >> 2];
	                    c[j >> 2] = (c[h >> 2] | 0) + 60;
	                    while (1) {
	                        if (!(a[c[f >> 2] >> 0] | 0))break;
	                        while (1) {
	                            do if ((a[c[f >> 2] >> 0] | 0) == 32)l = 1; else {
	                                if (9 <= (a[c[f >> 2] >> 0] | 0) ? (a[c[f >> 2] >> 0] | 0) <= 10 : 0) {
	                                    l = 1;
	                                    break
	                                }
	                                l = (a[c[f >> 2] >> 0] | 0) == 13
	                            } while (0);
	                            m = c[f >> 2] | 0;
	                            if (!l)break;
	                            c[f >> 2] = m + 1
	                        }
	                        if (!(a[m >> 0] | 0))continue;
	                        c[g >> 2] = c[f >> 2];
	                        while (1) {
	                            if (!(a[c[f >> 2] >> 0] | 0))break;
	                            do if ((a[c[f >> 2] >> 0] | 0) == 32)n = 1; else {
	                                if (9 <= (a[c[f >> 2] >> 0] | 0) ? (a[c[f >> 2] >> 0] | 0) <= 10 : 0) {
	                                    n = 1;
	                                    break
	                                }
	                                n = (a[c[f >> 2] >> 0] | 0) == 13
	                            } while (0);
	                            if (!(n ^ 1))break;
	                            c[f >> 2] = (c[f >> 2] | 0) + 1
	                        }
	                        c[e >> 2] = ly(c[g >> 2] | 0, (c[f >> 2] | 0) - (c[g >> 2] | 0) | 0) | 0;
	                        if (!(c[e >> 2] | 0))continue;
	                        d = Qw(1, 0, 0, c[e >> 2] | 0, c[33474] | 0, 0) | 0;
	                        c[c[j >> 2] >> 2] = d;
	                        if (c[c[j >> 2] >> 2] | 0)c[j >> 2] = c[c[j >> 2] >> 2];
	                        zb[c[135736 >> 2] & 511](c[e >> 2] | 0)
	                    }
	                    c[33510] = c[h >> 2]
	                }
	                wx(c[33502] | 0);
	                i = b;
	                return
	            }

	            function Bw(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                if (!(c[33500] | 0))Ww();
	                vx(c[33502] | 0);
	                if (c[33510] | 0) {
	                    c[f >> 2] = Xw(c[33510] | 0, c[e >> 2] | 0) | 0;
	                    wx(c[33502] | 0);
	                    c[d >> 2] = c[f >> 2];
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                c[g >> 2] = xw(c[e >> 2] | 0) | 0;
	                if (!(c[g >> 2] | 0)) {
	                    wx(c[33502] | 0);
	                    c[d >> 2] = -1;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                } else {
	                    c[33510] = c[g >> 2];
	                    wx(c[33502] | 0);
	                    c[d >> 2] = 0;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                return 0
	            }

	            function Cw(b) {
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[e >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                c[f >> 2] = c[e >> 2];
	                a:while (1) {
	                    if (!(a[c[f >> 2] >> 0] | 0))break;
	                    while (1) {
	                        do if ((a[c[f >> 2] >> 0] | 0) == 32)j = 1; else {
	                            if (9 <= (a[c[f >> 2] >> 0] | 0) ? (a[c[f >> 2] >> 0] | 0) <= 10 : 0) {
	                                j = 1;
	                                break
	                            }
	                            j = (a[c[f >> 2] >> 0] | 0) == 13
	                        } while (0);
	                        k = c[f >> 2] | 0;
	                        if (!j)break;
	                        c[f >> 2] = k + 1
	                    }
	                    if (a[k >> 0] | 0) {
	                        c[g >> 2] = c[f >> 2];
	                        while (1) {
	                            if (!(a[c[f >> 2] >> 0] | 0))break;
	                            if ((a[c[f >> 2] >> 0] | 0) == 58)break;
	                            do if ((a[c[f >> 2] >> 0] | 0) == 32)l = 1; else {
	                                if (9 <= (a[c[f >> 2] >> 0] | 0) ? (a[c[f >> 2] >> 0] | 0) <= 10 : 0) {
	                                    l = 1;
	                                    break
	                                }
	                                l = (a[c[f >> 2] >> 0] | 0) == 13
	                            } while (0);
	                            if (!(l ^ 1))break;
	                            c[f >> 2] = (c[f >> 2] | 0) + 1
	                        }
	                        c[h >> 2] = ly(c[g >> 2] | 0, (c[f >> 2] | 0) - (c[g >> 2] | 0) | 0) | 0;
	                        if (c[h >> 2] | 0) {
	                            Bw(c[h >> 2] | 0) | 0;
	                            zb[c[135736 >> 2] & 511](c[h >> 2] | 0)
	                        }
	                    }
	                    while (1) {
	                        if ((a[c[f >> 2] >> 0] | 0) != 58)continue a;
	                        c[f >> 2] = (c[f >> 2] | 0) + 1
	                    }
	                }
	                i = d;
	                return
	            }

	            function Dw() {
	                var a = 0;
	                a = i;
	                i = i + 16 | 0;
	                if (!(c[33500] | 0)) {
	                    i = a;
	                    return
	                }
	                vx(c[33502] | 0);
	                if (c[33468] | 0)Db[c[135904 >> 2] & 511](c[33980] | 0, 134096, a);
	                if (c[33530] | 0)Kj(c[33530] | 0, 316);
	                c[33530] = 0;
	                if (c[33510] | 0)vw(c[33510] | 0);
	                c[33510] = 0;
	                c[33468] = 0;
	                c[33500] = 0;
	                wx(c[33502] | 0);
	                ux(c[33502] | 0);
	                i = a;
	                return
	            }

	            function Ew(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[33500] | 0))Aw();
	                c[g >> 2] = yw(c[33510] | 0, c[e >> 2] | 0, c[f >> 2] | 0) | 0;
	                i = d;
	                return c[g >> 2] | 0
	            }

	            function Fw(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                if (!(c[33500] | 0))Aw();
	                c[e >> 2] = zw(c[33510] | 0, c[d >> 2] | 0) | 0;
	                i = b;
	                return c[e >> 2] | 0
	            }

	            function Gw() {
	                return c[33534] | 0
	            }

	            function Hw(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                if (!(c[33500] | 0))Aw();
	                c[e >> 2] = c[d >> 2];
	                if (!(c[e >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                Lw(c[e >> 2] | 0);
	                i = b;
	                return
	            }

	            function Iw(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                if (!(c[33500] | 0))Aw();
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = c[g >> 2];
	                    l = c[f >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                if (c[33468] | 0) {
	                    b = c[33976] | 0;
	                    a = c[33980] | 0;
	                    c[e >> 2] = c[h >> 2];
	                    Db[b & 511](a, 134144, e)
	                }
	                c[k >> 2] = Qw(1, 0, c[h >> 2] | 0, 0, c[33474] | 0, 0) | 0;
	                h = c[g >> 2] | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[f >> 2] = h;
	                    l = c[f >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                c[j >> 2] = h;
	                if (!(c[j >> 2] | 0)) {
	                    c[f >> 2] = c[k >> 2];
	                    l = c[f >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                while (1) {
	                    if (!(c[c[j >> 2] >> 2] | 0))break;
	                    c[j >> 2] = c[c[j >> 2] >> 2]
	                }
	                c[c[j >> 2] >> 2] = c[k >> 2];
	                c[f >> 2] = c[g >> 2];
	                l = c[f >> 2] | 0;
	                i = d;
	                return l | 0
	            }

	            function Jw(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e;
	                g = e + 28 | 0;
	                h = e + 24 | 0;
	                j = e + 20 | 0;
	                k = e + 16 | 0;
	                l = e + 12 | 0;
	                m = e + 8 | 0;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                if (!(c[33500] | 0))Aw();
	                if ((c[j >> 2] | 0) == 0 & (c[k >> 2] | 0) == 0) {
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                do if (c[33468] | 0) {
	                    if ((c[j >> 2] | 0) != 0 & (c[k >> 2] | 0) != 0) {
	                        d = c[33976] | 0;
	                        b = c[33980] | 0;
	                        a = c[k >> 2] | 0;
	                        c[f >> 2] = c[j >> 2];
	                        c[f + 4 >> 2] = a;
	                        Db[d & 511](b, 134176, f);
	                        break
	                    }
	                    b = c[33976] | 0;
	                    d = c[33980] | 0;
	                    if (c[j >> 2] | 0) {
	                        c[f >> 2] = c[j >> 2];
	                        Db[b & 511](d, 134216, f);
	                        break
	                    } else {
	                        c[f >> 2] = c[k >> 2];
	                        Db[b & 511](d, 134248, f);
	                        break
	                    }
	                } while (0);
	                c[l >> 2] = c[h >> 2];
	                if (!(c[l >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                c[m >> 2] = Rw(c[l >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                if ((c[m >> 2] | 0) != 0 & (c[m >> 2] | 0) != (-1 | 0)) {
	                    c[g >> 2] = c[m >> 2];
	                    n = c[g >> 2] | 0;
	                    i = e;
	                    return n | 0
	                } else {
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                return 0
	            }

	            function Kw(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                if (!(c[33500] | 0))Aw();
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                if (c[33468] | 0) {
	                    b = c[33976] | 0;
	                    a = c[33980] | 0;
	                    c[e >> 2] = c[h >> 2];
	                    Db[b & 511](a, 133984, e)
	                }
	                c[j >> 2] = c[g >> 2];
	                if (!(c[j >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                c[k >> 2] = Vw(c[j >> 2] | 0, c[h >> 2] | 0) | 0;
	                if ((c[k >> 2] | 0) != 0 & (c[k >> 2] | 0) != (-1 | 0)) {
	                    c[f >> 2] = c[k >> 2];
	                    l = c[f >> 2] | 0;
	                    i = d;
	                    return l | 0
	                } else {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                return 0
	            }

	            function Lw(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                while (1) {
	                    if (!(c[d >> 2] | 0))break;
	                    c[e >> 2] = c[c[d >> 2] >> 2];
	                    Mw(c[d >> 2] | 0);
	                    c[d >> 2] = c[e >> 2]
	                }
	                i = b;
	                return
	            }

	            function Mw(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                e = b + 4 | 0;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if ((c[(c[e >> 2] | 0) + 32 >> 2] | 0) == 1) {
	                    i = b;
	                    return
	                }
	                do if (c[33468] | 0) {
	                    if (c[(c[e >> 2] | 0) + 16 >> 2] | 0) {
	                        a = c[33976] | 0;
	                        f = c[33980] | 0;
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 16 >> 2];
	                        Db[a & 511](f, 135680, d);
	                        break
	                    }
	                    f = c[33976] | 0;
	                    a = c[33980] | 0;
	                    if (c[(c[e >> 2] | 0) + 20 >> 2] | 0) {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 20 >> 2];
	                        Db[f & 511](a, 135680, d);
	                        break
	                    } else {
	                        Db[f & 511](a, 135704, d);
	                        break
	                    }
	                } while (0);
	                if (c[(c[e >> 2] | 0) + 16 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[e >> 2] | 0) + 16 >> 2] | 0);
	                if (c[(c[e >> 2] | 0) + 20 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[e >> 2] | 0) + 20 >> 2] | 0);
	                if (c[(c[e >> 2] | 0) + 24 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[e >> 2] | 0) + 24 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[e >> 2] | 0);
	                i = b;
	                return
	            }

	            function Nw(b) {
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 112 | 0;
	                e = d + 100 | 0;
	                f = d + 96 | 0;
	                g = d + 92 | 0;
	                h = d + 88 | 0;
	                j = d + 84 | 0;
	                k = d + 8 | 0;
	                l = d + 4 | 0;
	                c[f >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                if (($a(c[f >> 2] | 0, k | 0) | 0) < 0) {
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                b = La(c[f >> 2] | 0, 0, d | 0) | 0;
	                c[g >> 2] = b;
	                if ((b | 0) < 0) {
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                c[j >> 2] = c[k + 36 >> 2];
	                c[l >> 2] = Cb[c[135752 >> 2] & 511]((c[j >> 2] | 0) + 10 | 0) | 0;
	                if (!(c[l >> 2] | 0)) {
	                    Zw(135656);
	                    Ra(c[g >> 2] | 0) | 0;
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                c[h >> 2] = eb(c[g >> 2] | 0, c[l >> 2] | 0, c[j >> 2] | 0) | 0;
	                Ra(c[g >> 2] | 0) | 0;
	                if ((c[h >> 2] | 0) < 0) {
	                    zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                } else {
	                    a[(c[l >> 2] | 0) + (c[h >> 2] | 0) >> 0] = 0;
	                    c[e >> 2] = c[l >> 2];
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                return 0
	            }

	            function Ow(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = Cb[c[135744 >> 2] & 511](64) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    Zw(135632);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                b = (c[h >> 2] | 0) + 0 | 0;
	                a = b + 64 | 0;
	                do {
	                    c[b >> 2] = 0;
	                    b = b + 4 | 0
	                } while ((b | 0) < (a | 0));
	                c[c[h >> 2] >> 2] = c[f >> 2];
	                c[(c[h >> 2] | 0) + 44 >> 2] = 0;
	                c[(c[h >> 2] | 0) + 48 >> 2] = 10;
	                c[(c[h >> 2] | 0) + 56 >> 2] = c[g >> 2];
	                if ((c[c[h >> 2] >> 2] | 0) == 2) {
	                    g = Ij(10) | 0;
	                    c[(c[h >> 2] | 0) + 52 >> 2] = g
	                }
	                c[e >> 2] = c[h >> 2];
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function Pw(a, b, e, f) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0;
	                g = i;
	                i = i + 64 | 0;
	                h = g + 60 | 0;
	                j = g + 56 | 0;
	                k = g + 52 | 0;
	                l = g + 48 | 0;
	                m = g + 44 | 0;
	                n = g + 40 | 0;
	                o = g + 36 | 0;
	                p = g + 32 | 0;
	                q = g + 28 | 0;
	                r = g + 24 | 0;
	                s = g + 20 | 0;
	                t = g + 16 | 0;
	                u = g + 12 | 0;
	                v = g + 8 | 0;
	                w = g + 4 | 0;
	                x = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                c[n >> 2] = c[k >> 2];
	                c[o >> 2] = 0;
	                if ((c[n >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0) {
	                    c[h >> 2] = -1;
	                    y = c[h >> 2] | 0;
	                    i = g;
	                    return y | 0
	                }
	                c[o >> 2] = my(c[l >> 2] | 0) | 0;
	                a:while (1) {
	                    if (!(c[n >> 2] | 0))break;
	                    while (1) {
	                        if (!(d[c[n >> 2] >> 0] | 0))break a;
	                        while (1) {
	                            do if ((d[c[n >> 2] >> 0] | 0 | 0) == 32)z = 1; else {
	                                if (9 <= (d[c[n >> 2] >> 0] | 0 | 0) ? (d[c[n >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                    z = 1;
	                                    break
	                                }
	                                z = (d[c[n >> 2] >> 0] | 0 | 0) == 13
	                            } while (0);
	                            A = c[n >> 2] | 0;
	                            if (!z)break;
	                            c[n >> 2] = A + 1
	                        }
	                        if (!(d[A >> 0] | 0))break a;
	                        if ((d[c[n >> 2] >> 0] | 0 | 0) != 45)break;
	                        if ((d[(c[n >> 2] | 0) + 1 >> 0] | 0 | 0) != 45)break;
	                        c[n >> 2] = _w(c[n >> 2] | 0) | 0;
	                        if (!((c[n >> 2] | 0) != 0 & (c[n >> 2] | 0) != 0))break a
	                    }
	                    c[q >> 2] = 0;
	                    c[r >> 2] = 0;
	                    c[s >> 2] = 0;
	                    c[n >> 2] = $w(c[n >> 2] | 0, r) | 0;
	                    if (!(c[r >> 2] | 0))break;
	                    do if ((d[c[n >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[n >> 2] >> 0] | 0 | 0) ? (d[c[n >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[n >> 2] >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    b:while (1) {
	                        do if ((d[c[n >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[n >> 2] >> 0] | 0 | 0) ? (d[c[n >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[n >> 2] >> 0] | 0 | 0) != 13)break b
	                        } while (0);
	                        c[n >> 2] = (c[n >> 2] | 0) + 1
	                    }
	                    do if (!(qy(c[r >> 2] | 0, 134936) | 0)) {
	                        if (qy(c[r >> 2] | 0, 134944) | 0) {
	                            c[s >> 2] = 14;
	                            break
	                        }
	                        if (qy(c[r >> 2] | 0, 134952) | 0) {
	                            c[s >> 2] = 20;
	                            break
	                        }
	                        if (qy(c[r >> 2] | 0, 134968) | 0) {
	                            c[s >> 2] = 15;
	                            break
	                        }
	                        if (qy(c[r >> 2] | 0, 134976) | 0) {
	                            c[s >> 2] = 17;
	                            break
	                        }
	                        if (qy(c[r >> 2] | 0, 134984) | 0) {
	                            c[s >> 2] = 18;
	                            break
	                        }
	                        if (qy(c[r >> 2] | 0, 135e3) | 0) {
	                            c[s >> 2] = 19;
	                            break
	                        }
	                        if (qy(c[r >> 2] | 0, 135016) | 0) {
	                            c[s >> 2] = 24;
	                            break
	                        }
	                        if (qy(c[r >> 2] | 0, 135032) | 0) {
	                            c[s >> 2] = 23;
	                            break
	                        }
	                        if (qy(c[r >> 2] | 0, 135048) | 0) {
	                            c[s >> 2] = 22;
	                            break
	                        }
	                        if (qy(c[r >> 2] | 0, 135056) | 0) {
	                            c[s >> 2] = 21;
	                            break
	                        }
	                        if (qy(c[r >> 2] | 0, 135592) | 0) {
	                            zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                            c[n >> 2] = $w(c[n >> 2] | 0, r) | 0;
	                            if (!(c[r >> 2] | 0))break a;
	                            zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                            continue a
	                        }
	                    } else c[s >> 2] = 13; while (0);
	                    zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                    c[r >> 2] = 0;
	                    c:do switch (c[s >> 2] | 0) {
	                        case 24:
	                        case 23:
	                        case 22:
	                        case 21:
	                        {
	                            c[n >> 2] = ax(c[n >> 2] | 0, q) | 0;
	                            break
	                        }
	                        case 19:
	                        case 18:
	                        case 17:
	                        case 16:
	                        {
	                            B = 54;
	                            break
	                        }
	                        case 20:
	                        case 13:
	                        case 14:
	                        {
	                            c[n >> 2] = ax(c[n >> 2] | 0, r) | 0;
	                            if (c[n >> 2] | 0) {
	                                do if ((c[s >> 2] | 0) != 13 ? (c[t >> 2] = bx(c[r >> 2] | 0) | 0, (c[t >> 2] | 0) != 0) : 0) {
	                                    if (c[r >> 2] | 0)zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                                    if (d[c[t >> 2] >> 0] | 0) {
	                                        c[r >> 2] = c[t >> 2];
	                                        break
	                                    } else {
	                                        zb[c[135736 >> 2] & 511](c[t >> 2] | 0);
	                                        c[r >> 2] = 0;
	                                        break
	                                    }
	                                } while (0);
	                                do if ((d[c[n >> 2] >> 0] | 0 | 0) != 32) {
	                                    if (9 <= (d[c[n >> 2] >> 0] | 0 | 0) ? (d[c[n >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                                    if ((d[c[n >> 2] >> 0] | 0 | 0) != 13)break c
	                                } while (0);
	                                while (1) {
	                                    do if ((d[c[n >> 2] >> 0] | 0 | 0) == 32)C = 1; else {
	                                        if (9 <= (d[c[n >> 2] >> 0] | 0 | 0) ? (d[c[n >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                            C = 1;
	                                            break
	                                        }
	                                        C = (d[c[n >> 2] >> 0] | 0 | 0) == 13
	                                    } while (0);
	                                    D = c[n >> 2] | 0;
	                                    if (!C)break;
	                                    c[n >> 2] = D + 1
	                                }
	                                c[n >> 2] = ax(D, q) | 0
	                            }
	                            break
	                        }
	                        case 15:
	                        {
	                            if ((d[c[n >> 2] >> 0] | 0 | 0) == 37) {
	                                c[s >> 2] = 16;
	                                B = 54
	                            } else B = 54;
	                            break
	                        }
	                        default:
	                        {
	                        }
	                    } while (0);
	                    d:do if ((B | 0) == 54 ? (B = 0, c[n >> 2] = $w(c[n >> 2] | 0, r) | 0, (c[n >> 2] | 0) != 0) : 0) {
	                        do if ((d[c[n >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[n >> 2] >> 0] | 0 | 0) ? (d[c[n >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[n >> 2] >> 0] | 0 | 0) != 13)break d
	                        } while (0);
	                        while (1) {
	                            do if ((d[c[n >> 2] >> 0] | 0 | 0) == 32)E = 1; else {
	                                if (9 <= (d[c[n >> 2] >> 0] | 0 | 0) ? (d[c[n >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                    E = 1;
	                                    break
	                                }
	                                E = (d[c[n >> 2] >> 0] | 0 | 0) == 13
	                            } while (0);
	                            F = c[n >> 2] | 0;
	                            if (!E)break;
	                            c[n >> 2] = F + 1
	                        }
	                        c[n >> 2] = ax(F, q) | 0
	                    } while (0);
	                    if (!(c[n >> 2] | 0)) {
	                        B = 87;
	                        break
	                    }
	                    do if ((c[s >> 2] | 0) != 21) {
	                        if ((c[s >> 2] | 0) == 14 | (c[s >> 2] | 0) == 13) {
	                            c[u >> 2] = Hl(c[q >> 2] | 0, c[o >> 2] | 0) | 0;
	                            if (!(c[u >> 2] | 0))break;
	                            c[v >> 2] = Qw(c[s >> 2] | 0, c[r >> 2] | 0, c[u >> 2] | 0, 0, 0, 0) | 0;
	                            c[p >> 2] = Lj(c[(c[j >> 2] | 0) + 52 >> 2] | 0, c[r >> 2] | 0, c[v >> 2] | 0) | 0;
	                            if ((c[p >> 2] | 0) < 0)Mw(c[v >> 2] | 0);
	                            zb[c[135736 >> 2] & 511](c[u >> 2] | 0);
	                            break
	                        }
	                        if ((c[s >> 2] | 0) == 22)if (c[m >> 2] | 0) {
	                            c[w >> 2] = Qw(c[s >> 2] | 0, c[q >> 2] | 0, 0, 0, 0, 0) | 0;
	                            c[p >> 2] = Lj(c[(c[j >> 2] | 0) + 52 >> 2] | 0, c[q >> 2] | 0, c[w >> 2] | 0) | 0;
	                            if ((c[p >> 2] | 0) >= 0)break;
	                            Mw(c[w >> 2] | 0);
	                            break
	                        } else {
	                            c[x >> 2] = Hl(c[q >> 2] | 0, c[o >> 2] | 0) | 0;
	                            if (!(c[x >> 2] | 0))break;
	                            Xw(c[j >> 2] | 0, c[x >> 2] | 0) | 0;
	                            zb[c[135736 >> 2] & 511](c[x >> 2] | 0);
	                            break
	                        }
	                    } else {
	                        if (c[o >> 2] | 0)zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                        c[o >> 2] = my(c[q >> 2] | 0) | 0
	                    } while (0);
	                    if (c[r >> 2] | 0)zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                    if (!(c[q >> 2] | 0))continue;
	                    zb[c[135736 >> 2] & 511](c[q >> 2] | 0)
	                }
	                if ((B | 0) == 87) {
	                    if (c[r >> 2] | 0)zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                    if (c[q >> 2] | 0)zb[c[135736 >> 2] & 511](c[q >> 2] | 0)
	                }
	                if (c[o >> 2] | 0)zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                if (!(c[n >> 2] | 0)) {
	                    c[h >> 2] = -1;
	                    y = c[h >> 2] | 0;
	                    i = g;
	                    return y | 0
	                } else {
	                    c[h >> 2] = 0;
	                    y = c[h >> 2] | 0;
	                    i = g;
	                    return y | 0
	                }
	                return 0
	            }

	            function Qw(a, b, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                j = i;
	                i = i + 48 | 0;
	                k = j + 32 | 0;
	                l = j + 28 | 0;
	                m = j + 24 | 0;
	                n = j + 20 | 0;
	                o = j + 16 | 0;
	                p = j + 12 | 0;
	                q = j + 8 | 0;
	                r = j + 4 | 0;
	                s = j;
	                c[l >> 2] = a;
	                c[m >> 2] = b;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                c[q >> 2] = h;
	                c[s >> 2] = 0;
	                c[r >> 2] = Cb[c[135744 >> 2] & 511](44) | 0;
	                if (!(c[r >> 2] | 0)) {
	                    Zw(135528);
	                    c[k >> 2] = 0;
	                    t = c[k >> 2] | 0;
	                    i = j;
	                    return t | 0
	                }
	                c[c[r >> 2] >> 2] = 0;
	                c[(c[r >> 2] | 0) + 4 >> 2] = 0;
	                c[(c[r >> 2] | 0) + 8 >> 2] = 0;
	                c[(c[r >> 2] | 0) + 12 >> 2] = c[l >> 2];
	                if ((c[l >> 2] | 0) == 5 | (c[l >> 2] | 0) == 8 ? (c[s >> 2] = bx(c[m >> 2] | 0) | 0, (c[s >> 2] | 0) != 0) : 0)c[m >> 2] = (d[c[s >> 2] >> 0] | 0 | 0) != 0 ? c[s >> 2] | 0 : 0;
	                if (c[m >> 2] | 0) {
	                    l = my(c[m >> 2] | 0) | 0;
	                    c[(c[r >> 2] | 0) + 16 >> 2] = l
	                } else c[(c[r >> 2] | 0) + 16 >> 2] = 0;
	                if (c[s >> 2] | 0)zb[c[135736 >> 2] & 511](c[s >> 2] | 0);
	                if (c[n >> 2] | 0) {
	                    s = my(c[n >> 2] | 0) | 0;
	                    c[(c[r >> 2] | 0) + 20 >> 2] = s
	                } else c[(c[r >> 2] | 0) + 20 >> 2] = 0;
	                if (!(c[o >> 2] | 0))c[o >> 2] = c[n >> 2];
	                if (c[o >> 2] | 0) {
	                    n = my(c[o >> 2] | 0) | 0;
	                    c[(c[r >> 2] | 0) + 24 >> 2] = n
	                } else c[(c[r >> 2] | 0) + 24 >> 2] = 0;
	                c[(c[r >> 2] | 0) + 28 >> 2] = c[p >> 2];
	                c[(c[r >> 2] | 0) + 32 >> 2] = 0;
	                c[(c[r >> 2] | 0) + 36 >> 2] = 0;
	                c[(c[r >> 2] | 0) + 40 >> 2] = c[q >> 2];
	                c[k >> 2] = c[r >> 2];
	                t = c[k >> 2] | 0;
	                i = j;
	                return t | 0
	            }

	            function Rw(a, b, e) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f;
	                h = f + 28 | 0;
	                j = f + 24 | 0;
	                k = f + 20 | 0;
	                l = f + 16 | 0;
	                m = f + 12 | 0;
	                n = f + 8 | 0;
	                o = f + 4 | 0;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = e;
	                c[m >> 2] = 0;
	                c[n >> 2] = 0;
	                if (!(c[j >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    p = c[h >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                if ((c[k >> 2] | 0) == 0 & (c[l >> 2] | 0) == 0) {
	                    c[h >> 2] = 0;
	                    p = c[h >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                c[o >> 2] = bx(c[k >> 2] | 0) | 0;
	                if (c[o >> 2] | 0)c[k >> 2] = (d[c[o >> 2] >> 0] | 0 | 0) != 0 ? c[o >> 2] | 0 : 0;
	                if (!(sy(c[k >> 2] | 0, 135064, 13) | 0)) {
	                    c[n >> 2] = cx(c[k >> 2] | 0) | 0;
	                    do if (c[33468] | 0) {
	                        e = c[33976] | 0;
	                        b = c[33980] | 0;
	                        if (!(c[n >> 2] | 0)) {
	                            c[g >> 2] = c[k >> 2];
	                            Db[e & 511](b, 135256, g);
	                            break
	                        } else {
	                            c[g >> 2] = c[n >> 2];
	                            Db[e & 511](b, 135296, g);
	                            break
	                        }
	                    } while (0);
	                    c[m >> 2] = Rw(c[j >> 2] | 0, c[n >> 2] | 0, c[l >> 2] | 0) | 0;
	                    if (c[n >> 2] | 0)zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                    if (c[o >> 2] | 0)zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                    c[h >> 2] = c[m >> 2];
	                    p = c[h >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                if (sy(c[l >> 2] | 0, 135064, 13) | 0) {
	                    while (1) {
	                        if (!(c[j >> 2] | 0))break;
	                        if ((c[(c[j >> 2] | 0) + 12 >> 2] | 0) == 1) {
	                            if (!(c[(c[j >> 2] | 0) + 8 >> 2] | 0))dx(c[j >> 2] | 0) | 0;
	                            if (c[(c[j >> 2] | 0) + 8 >> 2] | 0) {
	                                c[m >> 2] = ex(c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0;
	                                if (c[m >> 2] | 0)break;
	                                if ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) != 0 ? (c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + 36 >> 2] | 0) > 50 : 0) {
	                                    q = 40;
	                                    break
	                                }
	                            }
	                        }
	                        c[j >> 2] = c[c[j >> 2] >> 2]
	                    }
	                    if ((q | 0) == 40)c[m >> 2] = 0;
	                    if (c[o >> 2] | 0)zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                    c[h >> 2] = c[m >> 2];
	                    p = c[h >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                c[n >> 2] = cx(c[l >> 2] | 0) | 0;
	                do if (c[33468] | 0) {
	                    q = c[33976] | 0;
	                    b = c[33980] | 0;
	                    if (!(c[n >> 2] | 0)) {
	                        c[g >> 2] = c[l >> 2];
	                        Db[q & 511](b, 135328, g);
	                        break
	                    } else {
	                        c[g >> 2] = c[n >> 2];
	                        Db[q & 511](b, 135368, g);
	                        break
	                    }
	                } while (0);
	                do if (c[k >> 2] | 0) {
	                    g = (qy(c[k >> 2] | 0, c[n >> 2] | 0) | 0) != 0;
	                    l = c[j >> 2] | 0;
	                    b = c[k >> 2] | 0;
	                    if (g) {
	                        c[m >> 2] = Rw(l, b, 0) | 0;
	                        break
	                    } else {
	                        c[m >> 2] = Rw(l, b, c[n >> 2] | 0) | 0;
	                        break
	                    }
	                } else c[m >> 2] = Rw(c[j >> 2] | 0, c[n >> 2] | 0, 0) | 0; while (0);
	                if (c[n >> 2] | 0)zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                if (c[o >> 2] | 0)zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                c[h >> 2] = c[m >> 2];
	                p = c[h >> 2] | 0;
	                i = f;
	                return p | 0
	            }

	            function Sw(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                do if (c[f >> 2] | 0) {
	                    c[h >> 2] = Rj(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                    if (!(c[h >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        break
	                    }
	                    if ((c[(c[h >> 2] | 0) + 12 >> 2] | 0) == 13) {
	                        c[e >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                        break
	                    } else {
	                        c[e >> 2] = 0;
	                        break
	                    }
	                } else c[e >> 2] = 0; while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function Tw(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[k >> 2] = bx(c[h >> 2] | 0) | 0;
	                if (c[k >> 2] | 0)c[h >> 2] = (d[c[k >> 2] >> 0] | 0 | 0) != 0 ? c[k >> 2] | 0 : 0;
	                c[j >> 2] = Rj(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    if (c[k >> 2] | 0)zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                h = (c[k >> 2] | 0) != 0;
	                if ((c[(c[j >> 2] | 0) + 12 >> 2] | 0) == 14) {
	                    if (h)zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    c[f >> 2] = c[(c[j >> 2] | 0) + 24 >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } else {
	                    if (h)zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                return 0
	            }

	            function Uw(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 0;
	                if (!(c[(c[g >> 2] | 0) + 52 >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                if (c[h >> 2] | 0)c[k >> 2] = Tw(c[(c[g >> 2] | 0) + 52 >> 2] | 0, c[h >> 2] | 0) | 0;
	                if (c[k >> 2] | 0) {
	                    c[f >> 2] = c[k >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                if (c[j >> 2] | 0)c[k >> 2] = Sw(c[(c[g >> 2] | 0) + 52 >> 2] | 0, c[j >> 2] | 0) | 0;
	                if (c[k >> 2] | 0) {
	                    c[f >> 2] = c[k >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } else {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                return 0
	            }

	            function Vw(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = 0;
	                c[k >> 2] = 0;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                if (!(sy(c[h >> 2] | 0, 135064, 13) | 0)) {
	                    c[k >> 2] = cx(c[h >> 2] | 0) | 0;
	                    do if (c[33468] | 0) {
	                        b = c[33976] | 0;
	                        a = c[33980] | 0;
	                        if (!(c[k >> 2] | 0)) {
	                            c[e >> 2] = c[h >> 2];
	                            Db[b & 511](a, 135080, e);
	                            break
	                        } else {
	                            c[e >> 2] = c[k >> 2];
	                            Db[b & 511](a, 135112, e);
	                            break
	                        }
	                    } while (0);
	                    c[j >> 2] = Rw(c[g >> 2] | 0, c[k >> 2] | 0, 0) | 0;
	                    if (c[k >> 2] | 0)zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    c[f >> 2] = c[j >> 2];
	                    l = c[f >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                while (1) {
	                    if (!(c[g >> 2] | 0)) {
	                        m = 21;
	                        break
	                    }
	                    if ((c[(c[g >> 2] | 0) + 12 >> 2] | 0) == 1) {
	                        if (!(c[(c[g >> 2] | 0) + 8 >> 2] | 0))dx(c[g >> 2] | 0) | 0;
	                        if ((c[(c[g >> 2] | 0) + 8 >> 2] | 0) != 0 ? (c[j >> 2] = fx(c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[h >> 2] | 0) | 0, (c[j >> 2] | 0) != 0) : 0) {
	                            m = 19;
	                            break
	                        }
	                    }
	                    c[g >> 2] = c[c[g >> 2] >> 2]
	                }
	                if ((m | 0) == 19) {
	                    c[f >> 2] = c[j >> 2];
	                    l = c[f >> 2] | 0;
	                    i = d;
	                    return l | 0
	                } else if ((m | 0) == 21) {
	                    c[f >> 2] = c[j >> 2];
	                    l = c[f >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                return 0
	            }

	            function Ww() {
	                var a = 0;
	                a = i;
	                if (c[33500] | 0) {
	                    i = a;
	                    return
	                }
	                if (cb(134016) | 0)c[33468] = 1;
	                c[33502] = tx() | 0;
	                c[33500] = 1;
	                i = a;
	                return
	            }

	            function Xw(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 24 | 0;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                l = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = -1;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                b = c[g >> 2] | 0;
	                do if ((c[c[f >> 2] >> 2] | 0) == 2) {
	                    c[j >> 2] = Nw(b) | 0;
	                    if (!(c[j >> 2] | 0)) {
	                        c[e >> 2] = -1;
	                        m = c[e >> 2] | 0;
	                        i = d;
	                        return m | 0
	                    }
	                    c[h >> 2] = Pw(c[f >> 2] | 0, c[j >> 2] | 0, c[g >> 2] | 0, 0) | 0;
	                    a = (c[h >> 2] | 0) < 0;
	                    zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                    if (a) {
	                        c[e >> 2] = -1;
	                        m = c[e >> 2] | 0;
	                        i = d;
	                        return m | 0
	                    }
	                } else {
	                    c[k >> 2] = Qw(1, 0, 0, b, c[33474] | 0, 0) | 0;
	                    c[l >> 2] = c[(c[f >> 2] | 0) + 60 >> 2];
	                    if (!(c[l >> 2] | 0)) {
	                        c[(c[f >> 2] | 0) + 60 >> 2] = c[k >> 2];
	                        break
	                    }
	                    while (1) {
	                        if (!(c[c[l >> 2] >> 2] | 0))break;
	                        c[l >> 2] = c[c[l >> 2] >> 2]
	                    }
	                    c[c[l >> 2] >> 2] = c[k >> 2]
	                } while (0);
	                c[e >> 2] = 0;
	                m = c[e >> 2] | 0;
	                i = d;
	                return m | 0
	            }

	            function Yw(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                c[e >> 2] = c[(c[d >> 2] | 0) + 8 >> 2];
	                while (1) {
	                    if (!(c[e >> 2] | 0))break;
	                    c[f >> 2] = c[c[e >> 2] >> 2];
	                    c[(c[e >> 2] | 0) + 32 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 8 >> 2] = 0;
	                    Mw(c[e >> 2] | 0);
	                    c[e >> 2] = c[f >> 2]
	                }
	                c[(c[d >> 2] | 0) + 32 >> 2] = 0;
	                Mw(c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function Zw(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                e = b + 4 | 0;
	                c[e >> 2] = a;
	                a = c[e >> 2] | 0;
	                c[d >> 2] = c[e >> 2];
	                Xd(0, 0, 0, 0, 0, 20, 2, 2, 0, 0, a, 0, 0, 0, 0, 135560, d);
	                i = b;
	                return
	            }

	            function _w(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[f >> 2] = a;
	                if ((d[c[f >> 2] >> 0] | 0 | 0) == 45 ? (d[(c[f >> 2] | 0) + 1 >> 0] | 0 | 0) == 45 : 0) {
	                    c[f >> 2] = (c[f >> 2] | 0) + 2;
	                    while (1) {
	                        if (d[c[f >> 2] >> 0] | 0)if ((d[c[f >> 2] >> 0] | 0 | 0) != 45)g = 1; else g = (d[(c[f >> 2] | 0) + 1 >> 0] | 0 | 0) != 45; else g = 0;
	                        h = c[f >> 2] | 0;
	                        if (!g)break;
	                        c[f >> 2] = h + 1
	                    }
	                    if (!(d[h >> 0] | 0)) {
	                        c[e >> 2] = 0;
	                        j = c[e >> 2] | 0;
	                        i = b;
	                        return j | 0
	                    } else {
	                        c[e >> 2] = (c[f >> 2] | 0) + 2;
	                        j = c[e >> 2] | 0;
	                        i = b;
	                        return j | 0
	                    }
	                }
	                c[e >> 2] = c[f >> 2];
	                j = c[e >> 2] | 0;
	                i = b;
	                return j | 0
	            }

	            function $w(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                f = i;
	                i = i + 128 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 20 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[h >> 2] = b;
	                c[j >> 2] = e;
	                c[l >> 2] = 0;
	                c[c[j >> 2] >> 2] = 0;
	                c[m >> 2] = d[c[h >> 2] >> 0];
	                e = c[m >> 2] | 0;
	                if ((c[m >> 2] | 0) < 256) {
	                    if (((!(65 <= (e | 0) & (c[m >> 2] | 0) <= 90) ? !(97 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 122) : 0) ? !(192 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 214) : 0) ? !(216 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 246 | 248 <= (c[m >> 2] | 0)) : 0)n = 7
	                } else if (!(DQ(e, 199744) | 0))n = 7;
	                do if ((n | 0) == 7) {
	                    e = c[m >> 2] | 0;
	                    if ((c[m >> 2] | 0) < 256) {
	                        if (!((e | 0) != 95 & (c[m >> 2] | 0) != 58))break
	                    } else {
	                        if (19968 <= (e | 0) & (c[m >> 2] | 0) <= 40869 | (c[m >> 2] | 0) == 12295)break;
	                        if (!((12321 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 12329 ^ 1) & (c[m >> 2] | 0) != 95 & (c[m >> 2] | 0) != 58))break
	                    }
	                    c[g >> 2] = 0;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                } while (0);
	                a:while (1) {
	                    e = c[m >> 2] | 0;
	                    if ((c[m >> 2] | 0) < 256) {
	                        if (((!(65 <= (e | 0) & (c[m >> 2] | 0) <= 90) ? !(97 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 122) : 0) ? !(192 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 214) : 0) ? !(216 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 246 | 248 <= (c[m >> 2] | 0)) : 0)n = 18
	                    } else if (!(DQ(e, 199744) | 0))n = 18;
	                    do if ((n | 0) == 18) {
	                        n = 0;
	                        if ((c[m >> 2] | 0) >= 256) {
	                            if (19968 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 40869 | (c[m >> 2] | 0) == 12295)break;
	                            if (12321 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 12329)break
	                        }
	                        e = c[m >> 2] | 0;
	                        if ((c[m >> 2] | 0) < 256)if (48 <= (e | 0) & (c[m >> 2] | 0) <= 57 | (c[m >> 2] | 0) == 46 | (c[m >> 2] | 0) == 45 | (c[m >> 2] | 0) == 95 | (c[m >> 2] | 0) == 58)break; else {
	                            n = 26;
	                            break a
	                        } else {
	                            b = (DQ(e, 200216) | 0) != 0;
	                            if (b | (c[m >> 2] | 0) == 46 | (c[m >> 2] | 0) == 45 | (c[m >> 2] | 0) == 95 | (c[m >> 2] | 0) == 58)break; else {
	                                n = 26;
	                                break a
	                            }
	                        }
	                    } while (0);
	                    b = c[m >> 2] & 255;
	                    e = c[l >> 2] | 0;
	                    c[l >> 2] = e + 1;
	                    a[k + e >> 0] = b;
	                    c[h >> 2] = (c[h >> 2] | 0) + 1;
	                    c[m >> 2] = d[c[h >> 2] >> 0];
	                    if ((c[l >> 2] | 0) >= 100) {
	                        n = 25;
	                        break
	                    }
	                }
	                if ((n | 0) == 25) {
	                    c[g >> 2] = 0;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                } else if ((n | 0) == 26) {
	                    n = ly(k, c[l >> 2] | 0) | 0;
	                    c[c[j >> 2] >> 2] = n;
	                    c[g >> 2] = c[h >> 2];
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                return 0
	            }

	            function ax(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f + 28 | 0;
	                h = f + 24 | 0;
	                j = f + 20 | 0;
	                k = f + 16 | 0;
	                l = f + 12 | 0;
	                m = f + 8 | 0;
	                n = f + 4 | 0;
	                o = f + 32 | 0;
	                p = f;
	                c[h >> 2] = b;
	                c[j >> 2] = e;
	                c[k >> 2] = 0;
	                c[m >> 2] = 0;
	                c[n >> 2] = 50;
	                c[p >> 2] = 0;
	                c[c[j >> 2] >> 2] = 0;
	                e = c[h >> 2] | 0;
	                do if ((d[c[h >> 2] >> 0] | 0 | 0) != 34)if ((d[e >> 0] | 0 | 0) == 39) {
	                    c[h >> 2] = (c[h >> 2] | 0) + 1;
	                    a[o >> 0] = 39;
	                    break
	                } else {
	                    a[o >> 0] = 32;
	                    break
	                } else {
	                    c[h >> 2] = e + 1;
	                    a[o >> 0] = 34
	                } while (0);
	                c[k >> 2] = Cb[c[135752 >> 2] & 511](c[n >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    Zw(135608);
	                    c[g >> 2] = 0;
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                while (1) {
	                    if ((d[198696 + (d[c[h >> 2] >> 0] | 0) >> 0] | 0 | 0) == 0 ? (d[c[h >> 2] >> 0] | 0 | 0) != 63 : 0)break;
	                    if ((d[c[h >> 2] >> 0] | 0 | 0) == (d[o >> 0] | 0 | 0) ? (d[o >> 0] | 0 | 0) != 32 : 0)break;
	                    if ((d[o >> 0] | 0 | 0) == 32) {
	                        if ((d[c[h >> 2] >> 0] | 0 | 0) == 32)break;
	                        if (9 <= (d[c[h >> 2] >> 0] | 0 | 0) ? (d[c[h >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[h >> 2] >> 0] | 0 | 0) == 13)break
	                    }
	                    if (((c[m >> 2] | 0) + 1 | 0) >= (c[n >> 2] | 0)) {
	                        c[n >> 2] = c[n >> 2] << 1;
	                        c[l >> 2] = Hb[c[135760 >> 2] & 511](c[k >> 2] | 0, c[n >> 2] | 0) | 0;
	                        if (!(c[l >> 2] | 0)) {
	                            r = 19;
	                            break
	                        }
	                        c[k >> 2] = c[l >> 2]
	                    }
	                    e = a[c[h >> 2] >> 0] | 0;
	                    b = c[m >> 2] | 0;
	                    c[m >> 2] = b + 1;
	                    a[(c[k >> 2] | 0) + b >> 0] = e;
	                    c[p >> 2] = (c[p >> 2] | 0) + 1;
	                    c[h >> 2] = (c[h >> 2] | 0) + 1
	                }
	                if ((r | 0) == 19) {
	                    Zw(135608);
	                    zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    c[g >> 2] = 0;
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                a[(c[k >> 2] | 0) + (c[m >> 2] | 0) >> 0] = 0;
	                m = d[c[h >> 2] >> 0] | 0;
	                do if ((d[o >> 0] | 0 | 0) == 32) {
	                    if ((m | 0) != 32) {
	                        if (9 <= (d[c[h >> 2] >> 0] | 0 | 0) ? (d[c[h >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[h >> 2] >> 0] | 0 | 0) != 13) {
	                            zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                            c[g >> 2] = 0;
	                            q = c[g >> 2] | 0;
	                            i = f;
	                            return q | 0
	                        }
	                    }
	                } else {
	                    if ((m | 0) == (d[o >> 0] | 0 | 0)) {
	                        c[h >> 2] = (c[h >> 2] | 0) + 1;
	                        break
	                    }
	                    zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    c[g >> 2] = 0;
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                } while (0);
	                c[c[j >> 2] >> 2] = c[k >> 2];
	                c[g >> 2] = c[h >> 2];
	                q = c[g >> 2] | 0;
	                i = f;
	                return q | 0
	            }

	            function bx(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 20 | 0;
	                h = e + 16 | 0;
	                j = e + 12 | 0;
	                k = e + 8 | 0;
	                l = e + 4 | 0;
	                m = e;
	                c[g >> 2] = b;
	                c[h >> 2] = 1;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                c[j >> 2] = 1;
	                c[k >> 2] = c[g >> 2];
	                while (1) {
	                    if (!((c[h >> 2] | 0) != 0 ? (d[c[k >> 2] >> 0] | 0 | 0) != 0 : 0))break;
	                    do if ((d[c[k >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[k >> 2] >> 0] | 0 | 0) ? (d[c[k >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            o = 10;
	                            break
	                        }
	                        if ((d[c[k >> 2] >> 0] | 0 | 0) != 13)c[j >> 2] = 0; else o = 10
	                    } else o = 10; while (0);
	                    do if ((o | 0) == 10) {
	                        o = 0;
	                        if ((c[j >> 2] | 0) != 0 ? 1 : (d[c[k >> 2] >> 0] | 0 | 0) != 32) {
	                            c[h >> 2] = 0;
	                            break
	                        } else {
	                            c[j >> 2] = 1;
	                            break
	                        }
	                    } while (0);
	                    c[k >> 2] = (c[k >> 2] | 0) + 1
	                }
	                if (!((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) != 0)) {
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                c[l >> 2] = my(c[g >> 2] | 0) | 0;
	                c[m >> 2] = c[l >> 2];
	                c[j >> 2] = 0;
	                c[k >> 2] = c[g >> 2];
	                while (1) {
	                    if (!(d[c[k >> 2] >> 0] | 0))break;
	                    do if ((d[c[k >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[k >> 2] >> 0] | 0 | 0) ? (d[c[k >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            o = 22;
	                            break
	                        }
	                        if ((d[c[k >> 2] >> 0] | 0 | 0) != 13) {
	                            if (c[j >> 2] | 0) {
	                                g = c[m >> 2] | 0;
	                                c[m >> 2] = g + 1;
	                                a[g >> 0] = 32;
	                                c[j >> 2] = 0
	                            }
	                            g = a[c[k >> 2] >> 0] | 0;
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = g
	                        } else o = 22
	                    } else o = 22; while (0);
	                    if ((o | 0) == 22 ? (o = 0, (c[m >> 2] | 0) != (c[l >> 2] | 0)) : 0)c[j >> 2] = 1;
	                    c[k >> 2] = (c[k >> 2] | 0) + 1
	                }
	                a[c[m >> 2] >> 0] = 0;
	                c[f >> 2] = c[l >> 2];
	                n = c[f >> 2] | 0;
	                i = e;
	                return n | 0
	            }

	            function cx(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 2016 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e + 16 | 0;
	                j = e;
	                c[g >> 2] = b;
	                c[j >> 2] = 0;
	                if (sy(c[g >> 2] | 0, 135064, 13) | 0) {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                c[g >> 2] = (c[g >> 2] | 0) + 13;
	                a:while (1) {
	                    if ((c[j >> 2] | 0) >>> 0 > 1996 ? 1 : (d[c[g >> 2] >> 0] | 0 | 0) == 0)break;
	                    if ((d[c[g >> 2] >> 0] | 0 | 0) == 43) {
	                        b = c[j >> 2] | 0;
	                        c[j >> 2] = b + 1;
	                        a[h + b >> 0] = 32;
	                        c[g >> 2] = (c[g >> 2] | 0) + 1;
	                        continue
	                    }
	                    if ((d[c[g >> 2] >> 0] | 0 | 0) == 58) {
	                        b = c[j >> 2] | 0;
	                        c[j >> 2] = b + 1;
	                        a[h + b >> 0] = 47;
	                        b = c[j >> 2] | 0;
	                        c[j >> 2] = b + 1;
	                        a[h + b >> 0] = 47;
	                        c[g >> 2] = (c[g >> 2] | 0) + 1;
	                        continue
	                    }
	                    if ((d[c[g >> 2] >> 0] | 0 | 0) == 59) {
	                        b = c[j >> 2] | 0;
	                        c[j >> 2] = b + 1;
	                        a[h + b >> 0] = 58;
	                        b = c[j >> 2] | 0;
	                        c[j >> 2] = b + 1;
	                        a[h + b >> 0] = 58;
	                        c[g >> 2] = (c[g >> 2] | 0) + 1;
	                        continue
	                    }
	                    b = c[g >> 2] | 0;
	                    if ((d[c[g >> 2] >> 0] | 0 | 0) != 37) {
	                        l = a[b >> 0] | 0;
	                        m = c[j >> 2] | 0;
	                        c[j >> 2] = m + 1;
	                        a[h + m >> 0] = l;
	                        c[g >> 2] = (c[g >> 2] | 0) + 1;
	                        continue
	                    }
	                    if ((d[b + 1 >> 0] | 0 | 0) == 50 ? (d[(c[g >> 2] | 0) + 2 >> 0] | 0 | 0) == 66 : 0) {
	                        b = c[j >> 2] | 0;
	                        c[j >> 2] = b + 1;
	                        a[h + b >> 0] = 43
	                    } else n = 15;
	                    do if ((n | 0) == 15) {
	                        n = 0;
	                        if ((d[(c[g >> 2] | 0) + 1 >> 0] | 0 | 0) == 51 ? (d[(c[g >> 2] | 0) + 2 >> 0] | 0 | 0) == 65 : 0) {
	                            b = c[j >> 2] | 0;
	                            c[j >> 2] = b + 1;
	                            a[h + b >> 0] = 58;
	                            break
	                        }
	                        if ((d[(c[g >> 2] | 0) + 1 >> 0] | 0 | 0) == 50 ? (d[(c[g >> 2] | 0) + 2 >> 0] | 0 | 0) == 70 : 0) {
	                            b = c[j >> 2] | 0;
	                            c[j >> 2] = b + 1;
	                            a[h + b >> 0] = 47;
	                            break
	                        }
	                        if ((d[(c[g >> 2] | 0) + 1 >> 0] | 0 | 0) == 51 ? (d[(c[g >> 2] | 0) + 2 >> 0] | 0 | 0) == 66 : 0) {
	                            b = c[j >> 2] | 0;
	                            c[j >> 2] = b + 1;
	                            a[h + b >> 0] = 59;
	                            break
	                        }
	                        if ((d[(c[g >> 2] | 0) + 1 >> 0] | 0 | 0) == 50 ? (d[(c[g >> 2] | 0) + 2 >> 0] | 0 | 0) == 55 : 0) {
	                            b = c[j >> 2] | 0;
	                            c[j >> 2] = b + 1;
	                            a[h + b >> 0] = 39;
	                            break
	                        }
	                        if ((d[(c[g >> 2] | 0) + 1 >> 0] | 0 | 0) == 51 ? (d[(c[g >> 2] | 0) + 2 >> 0] | 0 | 0) == 70 : 0) {
	                            b = c[j >> 2] | 0;
	                            c[j >> 2] = b + 1;
	                            a[h + b >> 0] = 63;
	                            break
	                        }
	                        if ((d[(c[g >> 2] | 0) + 1 >> 0] | 0 | 0) == 50 ? (d[(c[g >> 2] | 0) + 2 >> 0] | 0 | 0) == 51 : 0) {
	                            b = c[j >> 2] | 0;
	                            c[j >> 2] = b + 1;
	                            a[h + b >> 0] = 35;
	                            break
	                        }
	                        if ((d[(c[g >> 2] | 0) + 1 >> 0] | 0 | 0) == 50 ? (d[(c[g >> 2] | 0) + 2 >> 0] | 0 | 0) == 53 : 0) {
	                            b = c[j >> 2] | 0;
	                            c[j >> 2] = b + 1;
	                            a[h + b >> 0] = 37;
	                            break
	                        }
	                        b = a[c[g >> 2] >> 0] | 0;
	                        l = c[j >> 2] | 0;
	                        c[j >> 2] = l + 1;
	                        a[h + l >> 0] = b;
	                        c[g >> 2] = (c[g >> 2] | 0) + 1;
	                        continue a
	                    } while (0);
	                    c[g >> 2] = (c[g >> 2] | 0) + 3
	                }
	                a[h + (c[j >> 2] | 0) >> 0] = 0;
	                c[f >> 2] = my(h) | 0;
	                k = c[f >> 2] | 0;
	                i = e;
	                return k | 0
	            }

	            function dx(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                g = b + 4 | 0;
	                c[f >> 2] = a;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    h = c[e >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                if (!(c[(c[f >> 2] | 0) + 24 >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    h = c[e >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                vx(c[33502] | 0);
	                if (c[(c[f >> 2] | 0) + 8 >> 2] | 0) {
	                    wx(c[33502] | 0);
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                do if (c[33530] | 0) {
	                    c[g >> 2] = Rj(c[33530] | 0, c[(c[f >> 2] | 0) + 24 >> 2] | 0) | 0;
	                    a = (c[33468] | 0) != 0;
	                    if (!(c[g >> 2] | 0)) {
	                        if (!a)break;
	                        j = c[33976] | 0;
	                        k = c[33980] | 0;
	                        c[d >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                        Db[j & 511](k, 134304, d);
	                        break
	                    }
	                    if (a) {
	                        a = c[33976] | 0;
	                        k = c[33980] | 0;
	                        c[d >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                        Db[a & 511](k, 134280, d)
	                    }
	                    k = c[g >> 2] | 0;
	                    if ((c[(c[f >> 2] | 0) + 12 >> 2] | 0) == 1)c[(c[f >> 2] | 0) + 8 >> 2] = c[k + 8 >> 2]; else c[(c[f >> 2] | 0) + 8 >> 2] = k;
	                    c[(c[f >> 2] | 0) + 32 >> 2] = 0;
	                    wx(c[33502] | 0);
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = b;
	                    return h | 0
	                } while (0);
	                c[g >> 2] = gx(c[(c[f >> 2] | 0) + 28 >> 2] | 0, c[(c[f >> 2] | 0) + 24 >> 2] | 0) | 0;
	                k = (c[f >> 2] | 0) + 12 | 0;
	                if (!(c[g >> 2] | 0)) {
	                    c[k >> 2] = 2;
	                    wx(c[33502] | 0);
	                    c[e >> 2] = -1;
	                    h = c[e >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                a = c[g >> 2] | 0;
	                if ((c[k >> 2] | 0) == 1)c[(c[f >> 2] | 0) + 8 >> 2] = c[a + 8 >> 2]; else c[(c[f >> 2] | 0) + 8 >> 2] = a;
	                c[(c[g >> 2] | 0) + 32 >> 2] = 1;
	                if (!(c[33530] | 0))c[33530] = Ij(10) | 0;
	                if (c[33530] | 0) {
	                    if (c[33468] | 0) {
	                        a = c[33976] | 0;
	                        k = c[33980] | 0;
	                        c[d >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                        Db[a & 511](k, 134336, d)
	                    }
	                    Lj(c[33530] | 0, c[(c[f >> 2] | 0) + 24 >> 2] | 0, c[g >> 2] | 0) | 0
	                }
	                wx(c[33502] | 0);
	                c[e >> 2] = 0;
	                h = c[e >> 2] | 0;
	                i = b;
	                return h | 0
	            }

	            function ex(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0;
	                e = i;
	                i = i + 480 | 0;
	                f = e;
	                g = e + 464 | 0;
	                h = e + 460 | 0;
	                j = e + 456 | 0;
	                k = e + 452 | 0;
	                l = e + 448 | 0;
	                m = e + 444 | 0;
	                n = e + 440 | 0;
	                o = e + 436 | 0;
	                p = e + 432 | 0;
	                q = e + 428 | 0;
	                r = e + 424 | 0;
	                s = e + 224 | 0;
	                t = e + 220 | 0;
	                u = e + 216 | 0;
	                v = e + 16 | 0;
	                w = e + 12 | 0;
	                x = e + 8 | 0;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = 0;
	                c[n >> 2] = 0;
	                c[o >> 2] = 0;
	                d = c[h >> 2] | 0;
	                if ((c[(c[h >> 2] | 0) + 36 >> 2] | 0) > 50) {
	                    hx(d, 0, 1654, 135136, c[(c[h >> 2] | 0) + 16 >> 2] | 0, 0, 0);
	                    c[g >> 2] = 0;
	                    y = c[g >> 2] | 0;
	                    i = e;
	                    return y | 0
	                }
	                b = d + 36 | 0;
	                c[b >> 2] = (c[b >> 2] | 0) + 1;
	                if (c[k >> 2] | 0) {
	                    c[p >> 2] = 0;
	                    c[q >> 2] = 0;
	                    c[m >> 2] = c[h >> 2];
	                    c[n >> 2] = 0;
	                    while (1) {
	                        if (!(c[m >> 2] | 0))break;
	                        b = c[(c[m >> 2] | 0) + 12 >> 2] | 0;
	                        if ((b | 0) == 7) {
	                            c[r >> 2] = xy(c[(c[m >> 2] | 0) + 16 >> 2] | 0) | 0;
	                            if ((c[r >> 2] | 0) > (c[q >> 2] | 0) ? (sy(c[k >> 2] | 0, c[(c[m >> 2] | 0) + 16 >> 2] | 0, c[r >> 2] | 0) | 0) == 0 : 0) {
	                                c[q >> 2] = c[r >> 2];
	                                c[p >> 2] = c[m >> 2]
	                            }
	                        } else if ((b | 0) == 3)c[o >> 2] = (c[o >> 2] | 0) + 1; else if ((b | 0) == 6) {
	                            if (qy(c[k >> 2] | 0, c[(c[m >> 2] | 0) + 16 >> 2] | 0) | 0) {
	                                z = 8;
	                                break
	                            }
	                        } else if ((b | 0) == 9 ? (b = c[k >> 2] | 0, d = c[(c[m >> 2] | 0) + 16 >> 2] | 0, (sy(b, d, xy(c[(c[m >> 2] | 0) + 16 >> 2] | 0) | 0) | 0) == 0) : 0)c[n >> 2] = (c[n >> 2] | 0) + 1;
	                        c[m >> 2] = c[c[m >> 2] >> 2]
	                    }
	                    if ((z | 0) == 8) {
	                        if (c[33468] | 0) {
	                            r = c[33976] | 0;
	                            d = c[33980] | 0;
	                            b = c[(c[m >> 2] | 0) + 24 >> 2] | 0;
	                            c[f >> 2] = c[(c[m >> 2] | 0) + 16 >> 2];
	                            c[f + 4 >> 2] = b;
	                            Db[r & 511](d, 135400, f)
	                        }
	                        d = (c[h >> 2] | 0) + 36 | 0;
	                        c[d >> 2] = (c[d >> 2] | 0) + -1;
	                        c[g >> 2] = my(c[(c[m >> 2] | 0) + 24 >> 2] | 0) | 0;
	                        y = c[g >> 2] | 0;
	                        i = e;
	                        return y | 0
	                    }
	                    if (c[p >> 2] | 0) {
	                        if (c[33468] | 0) {
	                            d = c[33976] | 0;
	                            r = c[33980] | 0;
	                            c[f >> 2] = c[(c[p >> 2] | 0) + 16 >> 2];
	                            Db[d & 511](r, 135200, f)
	                        }
	                        c[l >> 2] = my(c[(c[p >> 2] | 0) + 24 >> 2] | 0) | 0;
	                        if (c[l >> 2] | 0)c[l >> 2] = By(c[l >> 2] | 0, (c[k >> 2] | 0) + (c[q >> 2] | 0) | 0) | 0;
	                        q = (c[h >> 2] | 0) + 36 | 0;
	                        c[q >> 2] = (c[q >> 2] | 0) + -1;
	                        c[g >> 2] = c[l >> 2];
	                        y = c[g >> 2] | 0;
	                        i = e;
	                        return y | 0
	                    }
	                    if (c[n >> 2] | 0) {
	                        c[t >> 2] = 0;
	                        c[m >> 2] = c[h >> 2];
	                        while (1) {
	                            if (!(c[m >> 2] | 0)) {
	                                z = 45;
	                                break
	                            }
	                            if ((c[(c[m >> 2] | 0) + 12 >> 2] | 0) == 9 ? (q = c[k >> 2] | 0, p = c[(c[m >> 2] | 0) + 16 >> 2] | 0, (sy(q, p, xy(c[(c[m >> 2] | 0) + 16 >> 2] | 0) | 0) | 0) == 0) : 0) {
	                                c[u >> 2] = 0;
	                                while (1) {
	                                    if ((c[u >> 2] | 0) >= (c[t >> 2] | 0))break;
	                                    if (qy(c[(c[m >> 2] | 0) + 24 >> 2] | 0, c[s + (c[u >> 2] << 2) >> 2] | 0) | 0)break;
	                                    c[u >> 2] = (c[u >> 2] | 0) + 1
	                                }
	                                if ((c[u >> 2] | 0) < (c[t >> 2] | 0)) {
	                                    c[m >> 2] = c[c[m >> 2] >> 2];
	                                    continue
	                                }
	                                if ((c[t >> 2] | 0) < 50) {
	                                    p = c[(c[m >> 2] | 0) + 24 >> 2] | 0;
	                                    q = c[t >> 2] | 0;
	                                    c[t >> 2] = q + 1;
	                                    c[s + (q << 2) >> 2] = p
	                                }
	                                if (!(c[(c[m >> 2] | 0) + 8 >> 2] | 0))dx(c[m >> 2] | 0) | 0;
	                                if (c[(c[m >> 2] | 0) + 8 >> 2] | 0) {
	                                    if (c[33468] | 0) {
	                                        p = c[33976] | 0;
	                                        q = c[33980] | 0;
	                                        c[f >> 2] = c[(c[m >> 2] | 0) + 24 >> 2];
	                                        Db[p & 511](q, 135440, f)
	                                    }
	                                    c[l >> 2] = Rw(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 0, c[k >> 2] | 0) | 0;
	                                    if (c[l >> 2] | 0) {
	                                        z = 43;
	                                        break
	                                    }
	                                }
	                            }
	                            c[m >> 2] = c[c[m >> 2] >> 2]
	                        }
	                        if ((z | 0) == 43) {
	                            s = (c[h >> 2] | 0) + 36 | 0;
	                            c[s >> 2] = (c[s >> 2] | 0) + -1;
	                            c[g >> 2] = c[l >> 2];
	                            y = c[g >> 2] | 0;
	                            i = e;
	                            return y | 0
	                        } else if ((z | 0) == 45) {
	                            s = (c[h >> 2] | 0) + 36 | 0;
	                            c[s >> 2] = (c[s >> 2] | 0) + -1;
	                            c[g >> 2] = -1;
	                            y = c[g >> 2] | 0;
	                            i = e;
	                            return y | 0
	                        }
	                    }
	                }
	                if (c[j >> 2] | 0) {
	                    c[m >> 2] = c[h >> 2];
	                    c[n >> 2] = 0;
	                    while (1) {
	                        if (!(c[m >> 2] | 0))break;
	                        s = c[(c[m >> 2] | 0) + 12 >> 2] | 0;
	                        if ((s | 0) == 8) {
	                            t = c[j >> 2] | 0;
	                            u = c[(c[m >> 2] | 0) + 16 >> 2] | 0;
	                            if ((sy(t, u, xy(c[(c[m >> 2] | 0) + 16 >> 2] | 0) | 0) | 0) == 0 ? (c[(c[m >> 2] | 0) + 28 >> 2] | 0) == 1 : 0)c[n >> 2] = (c[n >> 2] | 0) + 1
	                        } else if ((s | 0) == 3) {
	                            if (!(c[k >> 2] | 0))c[o >> 2] = (c[o >> 2] | 0) + 1
	                        } else if ((s | 0) == 5 ? (qy(c[j >> 2] | 0, c[(c[m >> 2] | 0) + 16 >> 2] | 0) | 0) != 0 : 0) {
	                            z = 51;
	                            break
	                        }
	                        c[m >> 2] = c[c[m >> 2] >> 2]
	                    }
	                    if ((z | 0) == 51) {
	                        if (c[33468] | 0) {
	                            s = c[33976] | 0;
	                            u = c[33980] | 0;
	                            c[f >> 2] = c[(c[m >> 2] | 0) + 16 >> 2];
	                            Db[s & 511](u, 135472, f)
	                        }
	                        u = (c[h >> 2] | 0) + 36 | 0;
	                        c[u >> 2] = (c[u >> 2] | 0) + -1;
	                        c[g >> 2] = my(c[(c[m >> 2] | 0) + 24 >> 2] | 0) | 0;
	                        y = c[g >> 2] | 0;
	                        i = e;
	                        return y | 0
	                    }
	                    if (c[n >> 2] | 0) {
	                        c[w >> 2] = 0;
	                        c[m >> 2] = c[h >> 2];
	                        while (1) {
	                            if (!(c[m >> 2] | 0)) {
	                                z = 82;
	                                break
	                            }
	                            if (((c[(c[m >> 2] | 0) + 12 >> 2] | 0) == 8 ? (c[(c[m >> 2] | 0) + 28 >> 2] | 0) == 1 : 0) ? (n = c[j >> 2] | 0, u = c[(c[m >> 2] | 0) + 16 >> 2] | 0, (sy(n, u, xy(c[(c[m >> 2] | 0) + 16 >> 2] | 0) | 0) | 0) == 0) : 0) {
	                                c[x >> 2] = 0;
	                                while (1) {
	                                    if ((c[x >> 2] | 0) >= (c[w >> 2] | 0))break;
	                                    if (qy(c[(c[m >> 2] | 0) + 24 >> 2] | 0, c[v + (c[x >> 2] << 2) >> 2] | 0) | 0)break;
	                                    c[x >> 2] = (c[x >> 2] | 0) + 1
	                                }
	                                if ((c[x >> 2] | 0) < (c[w >> 2] | 0)) {
	                                    c[m >> 2] = c[c[m >> 2] >> 2];
	                                    continue
	                                }
	                                if ((c[w >> 2] | 0) < 50) {
	                                    u = c[(c[m >> 2] | 0) + 24 >> 2] | 0;
	                                    n = c[w >> 2] | 0;
	                                    c[w >> 2] = n + 1;
	                                    c[v + (n << 2) >> 2] = u
	                                }
	                                if (!(c[(c[m >> 2] | 0) + 8 >> 2] | 0))dx(c[m >> 2] | 0) | 0;
	                                if (c[(c[m >> 2] | 0) + 8 >> 2] | 0) {
	                                    if (c[33468] | 0) {
	                                        u = c[33976] | 0;
	                                        n = c[33980] | 0;
	                                        c[f >> 2] = c[(c[m >> 2] | 0) + 24 >> 2];
	                                        Db[u & 511](n, 135496, f)
	                                    }
	                                    c[l >> 2] = Rw(c[(c[m >> 2] | 0) + 8 >> 2] | 0, c[j >> 2] | 0, 0) | 0;
	                                    if (c[l >> 2] | 0) {
	                                        z = 80;
	                                        break
	                                    }
	                                }
	                            }
	                            c[m >> 2] = c[c[m >> 2] >> 2]
	                        }
	                        if ((z | 0) == 80) {
	                            f = (c[h >> 2] | 0) + 36 | 0;
	                            c[f >> 2] = (c[f >> 2] | 0) + -1;
	                            c[g >> 2] = c[l >> 2];
	                            y = c[g >> 2] | 0;
	                            i = e;
	                            return y | 0
	                        } else if ((z | 0) == 82) {
	                            f = (c[h >> 2] | 0) + 36 | 0;
	                            c[f >> 2] = (c[f >> 2] | 0) + -1;
	                            c[g >> 2] = -1;
	                            y = c[g >> 2] | 0;
	                            i = e;
	                            return y | 0
	                        }
	                    }
	                }
	                a:do if (c[o >> 2] | 0) {
	                    c[m >> 2] = c[h >> 2];
	                    while (1) {
	                        if (!(c[m >> 2] | 0))break a;
	                        if ((c[(c[m >> 2] | 0) + 12 >> 2] | 0) == 3) {
	                            if (!(c[(c[m >> 2] | 0) + 8 >> 2] | 0))dx(c[m >> 2] | 0) | 0;
	                            if (c[(c[m >> 2] | 0) + 8 >> 2] | 0) {
	                                c[l >> 2] = Rw(c[(c[m >> 2] | 0) + 8 >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                                A = (c[h >> 2] | 0) + 36 | 0;
	                                B = c[A >> 2] | 0;
	                                if (c[l >> 2] | 0) {
	                                    z = 91;
	                                    break
	                                }
	                                if ((B | 0) > 50) {
	                                    z = 93;
	                                    break
	                                }
	                            }
	                        }
	                        c[m >> 2] = c[c[m >> 2] >> 2]
	                    }
	                    if ((z | 0) == 91) {
	                        c[A >> 2] = B + -1;
	                        c[g >> 2] = c[l >> 2];
	                        y = c[g >> 2] | 0;
	                        i = e;
	                        return y | 0
	                    } else if ((z | 0) == 93) {
	                        c[g >> 2] = 0;
	                        y = c[g >> 2] | 0;
	                        i = e;
	                        return y | 0
	                    }
	                } while (0);
	                z = (c[h >> 2] | 0) + 36 | 0;
	                c[z >> 2] = (c[z >> 2] | 0) + -1;
	                c[g >> 2] = 0;
	                y = c[g >> 2] | 0;
	                i = e;
	                return y | 0
	            }

	            function fx(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                d = i;
	                i = i + 256 | 0;
	                e = d;
	                f = d + 252 | 0;
	                g = d + 248 | 0;
	                h = d + 244 | 0;
	                j = d + 240 | 0;
	                k = d + 236 | 0;
	                l = d + 232 | 0;
	                m = d + 228 | 0;
	                n = d + 224 | 0;
	                o = d + 220 | 0;
	                p = d + 216 | 0;
	                q = d + 16 | 0;
	                r = d + 8 | 0;
	                s = d + 4 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = 0;
	                c[l >> 2] = 0;
	                c[m >> 2] = 0;
	                c[n >> 2] = 0;
	                c[o >> 2] = 0;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    t = c[f >> 2] | 0;
	                    i = d;
	                    return t | 0
	                }
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    t = c[f >> 2] | 0;
	                    i = d;
	                    return t | 0
	                }
	                b = c[g >> 2] | 0;
	                if ((c[(c[g >> 2] | 0) + 36 >> 2] | 0) > 50) {
	                    hx(b, 0, 1654, 135136, c[(c[g >> 2] | 0) + 16 >> 2] | 0, 0, 0);
	                    c[f >> 2] = 0;
	                    t = c[f >> 2] | 0;
	                    i = d;
	                    return t | 0
	                }
	                c[k >> 2] = b;
	                c[l >> 2] = 0;
	                while (1) {
	                    if (!(c[k >> 2] | 0))break;
	                    b = c[(c[k >> 2] | 0) + 12 >> 2] | 0;
	                    if ((b | 0) == 10) {
	                        if (qy(c[h >> 2] | 0, c[(c[k >> 2] | 0) + 16 >> 2] | 0) | 0) {
	                            u = 11;
	                            break
	                        }
	                    } else if ((b | 0) == 12) {
	                        a = c[h >> 2] | 0;
	                        v = c[(c[k >> 2] | 0) + 16 >> 2] | 0;
	                        if (!(sy(a, v, xy(c[(c[k >> 2] | 0) + 16 >> 2] | 0) | 0) | 0))c[l >> 2] = (c[l >> 2] | 0) + 1
	                    } else if ((b | 0) == 11) {
	                        c[p >> 2] = xy(c[(c[k >> 2] | 0) + 16 >> 2] | 0) | 0;
	                        if ((c[p >> 2] | 0) > (c[o >> 2] | 0) ? (sy(c[h >> 2] | 0, c[(c[k >> 2] | 0) + 16 >> 2] | 0, c[p >> 2] | 0) | 0) == 0 : 0) {
	                            c[o >> 2] = c[p >> 2];
	                            c[n >> 2] = c[k >> 2]
	                        }
	                    } else if ((b | 0) == 3)c[m >> 2] = (c[m >> 2] | 0) + 1;
	                    c[k >> 2] = c[c[k >> 2] >> 2]
	                }
	                if ((u | 0) == 11) {
	                    if (c[33468] | 0) {
	                        p = c[33976] | 0;
	                        b = c[33980] | 0;
	                        c[e >> 2] = c[(c[k >> 2] | 0) + 16 >> 2];
	                        Db[p & 511](b, 135176, e)
	                    }
	                    c[f >> 2] = my(c[(c[k >> 2] | 0) + 24 >> 2] | 0) | 0;
	                    t = c[f >> 2] | 0;
	                    i = d;
	                    return t | 0
	                }
	                if (c[n >> 2] | 0) {
	                    if (c[33468] | 0) {
	                        b = c[33976] | 0;
	                        p = c[33980] | 0;
	                        c[e >> 2] = c[(c[n >> 2] | 0) + 16 >> 2];
	                        Db[b & 511](p, 135200, e)
	                    }
	                    c[j >> 2] = my(c[(c[n >> 2] | 0) + 24 >> 2] | 0) | 0;
	                    if (c[j >> 2] | 0)c[j >> 2] = By(c[j >> 2] | 0, (c[h >> 2] | 0) + (c[o >> 2] | 0) | 0) | 0;
	                    c[f >> 2] = c[j >> 2];
	                    t = c[f >> 2] | 0;
	                    i = d;
	                    return t | 0
	                }
	                if (!(c[l >> 2] | 0)) {
	                    a:do if (c[m >> 2] | 0) {
	                        c[k >> 2] = c[g >> 2];
	                        while (1) {
	                            if (!(c[k >> 2] | 0))break a;
	                            if ((c[(c[k >> 2] | 0) + 12 >> 2] | 0) == 3) {
	                                if (!(c[(c[k >> 2] | 0) + 8 >> 2] | 0))dx(c[k >> 2] | 0) | 0;
	                                if ((c[(c[k >> 2] | 0) + 8 >> 2] | 0) != 0 ? (c[j >> 2] = Vw(c[(c[k >> 2] | 0) + 8 >> 2] | 0, c[h >> 2] | 0) | 0, (c[j >> 2] | 0) != 0) : 0)break
	                            }
	                            c[k >> 2] = c[c[k >> 2] >> 2]
	                        }
	                        c[f >> 2] = c[j >> 2];
	                        t = c[f >> 2] | 0;
	                        i = d;
	                        return t | 0
	                    } while (0);
	                    c[f >> 2] = 0;
	                    t = c[f >> 2] | 0;
	                    i = d;
	                    return t | 0
	                }
	                c[r >> 2] = 0;
	                c[k >> 2] = c[g >> 2];
	                while (1) {
	                    if (!(c[k >> 2] | 0)) {
	                        u = 49;
	                        break
	                    }
	                    if (!((c[(c[k >> 2] | 0) + 12 >> 2] | 0) != 9 ? (c[(c[k >> 2] | 0) + 12 >> 2] | 0) != 12 : 0))u = 32;
	                    if ((u | 0) == 32 ? (u = 0, g = c[h >> 2] | 0, m = c[(c[k >> 2] | 0) + 16 >> 2] | 0, (sy(g, m, xy(c[(c[k >> 2] | 0) + 16 >> 2] | 0) | 0) | 0) == 0) : 0) {
	                        c[s >> 2] = 0;
	                        while (1) {
	                            if ((c[s >> 2] | 0) >= (c[r >> 2] | 0))break;
	                            if (qy(c[(c[k >> 2] | 0) + 24 >> 2] | 0, c[q + (c[s >> 2] << 2) >> 2] | 0) | 0)break;
	                            c[s >> 2] = (c[s >> 2] | 0) + 1
	                        }
	                        if ((c[s >> 2] | 0) < (c[r >> 2] | 0)) {
	                            c[k >> 2] = c[c[k >> 2] >> 2];
	                            continue
	                        }
	                        if ((c[r >> 2] | 0) < 50) {
	                            m = c[(c[k >> 2] | 0) + 24 >> 2] | 0;
	                            g = c[r >> 2] | 0;
	                            c[r >> 2] = g + 1;
	                            c[q + (g << 2) >> 2] = m
	                        }
	                        if (!(c[(c[k >> 2] | 0) + 8 >> 2] | 0))dx(c[k >> 2] | 0) | 0;
	                        if (c[(c[k >> 2] | 0) + 8 >> 2] | 0) {
	                            if (c[33468] | 0) {
	                                m = c[33976] | 0;
	                                g = c[33980] | 0;
	                                c[e >> 2] = c[(c[k >> 2] | 0) + 24 >> 2];
	                                Db[m & 511](g, 135232, e)
	                            }
	                            c[j >> 2] = Vw(c[(c[k >> 2] | 0) + 8 >> 2] | 0, c[h >> 2] | 0) | 0;
	                            if (c[j >> 2] | 0) {
	                                u = 47;
	                                break
	                            }
	                        }
	                    }
	                    c[k >> 2] = c[c[k >> 2] >> 2]
	                }
	                if ((u | 0) == 47) {
	                    c[f >> 2] = c[j >> 2];
	                    t = c[f >> 2] | 0;
	                    i = d;
	                    return t | 0
	                } else if ((u | 0) == 49) {
	                    c[f >> 2] = -1;
	                    t = c[f >> 2] | 0;
	                    i = d;
	                    return t | 0
	                }
	                return 0
	            }

	            function gx(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                d = i;
	                i = i + 48 | 0;
	                e = d;
	                f = d + 32 | 0;
	                g = d + 28 | 0;
	                h = d + 24 | 0;
	                j = d + 20 | 0;
	                k = d + 16 | 0;
	                l = d + 12 | 0;
	                m = d + 8 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[m >> 2] = 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                c[j >> 2] = ww(c[h >> 2] | 0) | 0;
	                b = (c[33468] | 0) != 0;
	                if (!(c[j >> 2] | 0)) {
	                    if (b) {
	                        a = c[33976] | 0;
	                        o = c[33980] | 0;
	                        c[e >> 2] = c[h >> 2];
	                        Db[a & 511](o, 134360, e)
	                    }
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                if (b) {
	                    b = c[33976] | 0;
	                    o = c[33980] | 0;
	                    a = yx() | 0;
	                    p = c[h >> 2] | 0;
	                    c[e >> 2] = a;
	                    c[e + 4 >> 2] = p;
	                    Db[b & 511](o, 134392, e)
	                }
	                c[k >> 2] = Pi(c[j >> 2] | 0) | 0;
	                if (((((c[k >> 2] | 0) != 0 ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 134128) | 0) != 0 : 0) ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, 134416) | 0) != 0 : 0) {
	                    c[m >> 2] = Qw(1, 0, c[h >> 2] | 0, 0, c[g >> 2] | 0, 0) | 0;
	                    if (!(c[m >> 2] | 0)) {
	                        Th(c[j >> 2] | 0);
	                        c[f >> 2] = 0;
	                        n = c[f >> 2] | 0;
	                        i = d;
	                        return n | 0
	                    }
	                    c[l >> 2] = Yi(c[k >> 2] | 0, 134464) | 0;
	                    if (c[l >> 2] | 0) {
	                        do if (!(qy(c[l >> 2] | 0, 134472) | 0))if (qy(c[l >> 2] | 0, 134480) | 0) {
	                            c[g >> 2] = 1;
	                            break
	                        } else {
	                            hx(0, c[k >> 2] | 0, 1652, 134488, c[l >> 2] | 0, 0, 0);
	                            break
	                        } else c[g >> 2] = 2; while (0);
	                        zb[c[135736 >> 2] & 511](c[l >> 2] | 0)
	                    }
	                    c[k >> 2] = c[(c[k >> 2] | 0) + 12 >> 2];
	                    ix(c[k >> 2] | 0, c[g >> 2] | 0, c[m >> 2] | 0, 0);
	                    Th(c[j >> 2] | 0);
	                    c[f >> 2] = c[m >> 2];
	                    n = c[f >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                hx(0, c[j >> 2] | 0, 1653, 134520, c[h >> 2] | 0, 0, 0);
	                Th(c[j >> 2] | 0);
	                c[f >> 2] = 0;
	                n = c[f >> 2] | 0;
	                i = d;
	                return n | 0
	            }

	            function hx(a, b, d, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                j = i;
	                i = i + 48 | 0;
	                k = j;
	                l = j + 36 | 0;
	                m = j + 32 | 0;
	                n = j + 28 | 0;
	                o = j + 24 | 0;
	                p = j + 20 | 0;
	                q = j + 16 | 0;
	                r = j + 12 | 0;
	                c[l >> 2] = a;
	                c[m >> 2] = b;
	                c[n >> 2] = d;
	                c[o >> 2] = e;
	                c[p >> 2] = f;
	                c[q >> 2] = g;
	                c[r >> 2] = h;
	                h = c[l >> 2] | 0;
	                l = c[m >> 2] | 0;
	                m = c[n >> 2] | 0;
	                n = c[p >> 2] | 0;
	                g = c[q >> 2] | 0;
	                f = c[r >> 2] | 0;
	                e = c[o >> 2] | 0;
	                o = c[q >> 2] | 0;
	                q = c[r >> 2] | 0;
	                c[k >> 2] = c[p >> 2];
	                c[k + 4 >> 2] = o;
	                c[k + 8 >> 2] = q;
	                Xd(0, 0, 0, h, l, 20, m, 2, 0, 0, n, g, f, 0, 0, e, k);
	                i = j;
	                return
	            }

	            function ix(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 12 | 0;
	                h = f + 8 | 0;
	                j = f + 4 | 0;
	                k = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                while (1) {
	                    if (!(c[g >> 2] | 0))break;
	                    if (((c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, 134416) | 0) != 0 : 0)jx(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0);
	                    c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2]
	                }
	                i = f;
	                return
	            }

	            function jx(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f + 32 | 0;
	                h = f + 28 | 0;
	                j = f + 24 | 0;
	                k = f + 20 | 0;
	                l = f + 16 | 0;
	                m = f + 12 | 0;
	                n = f + 8 | 0;
	                o = f + 4 | 0;
	                p = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[l >> 2] = 0;
	                c[m >> 2] = 0;
	                if (!(c[g >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                do if (!(qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 134552) | 0)) {
	                    e = (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 134480) | 0) != 0;
	                    d = c[g >> 2] | 0;
	                    if (e) {
	                        c[m >> 2] = kx(d, 5, 134480, 134616, 134632, c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                        break
	                    }
	                    e = (qy(c[d + 8 >> 2] | 0, 134472) | 0) != 0;
	                    d = c[g >> 2] | 0;
	                    if (e) {
	                        c[m >> 2] = kx(d, 6, 134472, 134640, 134632, c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                        break
	                    }
	                    e = (qy(c[d + 8 >> 2] | 0, 134656) | 0) != 0;
	                    d = c[g >> 2] | 0;
	                    if (e) {
	                        c[m >> 2] = kx(d, 7, 134656, 134672, 134696, c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                        break
	                    }
	                    e = (qy(c[d + 8 >> 2] | 0, 134712) | 0) != 0;
	                    d = c[g >> 2] | 0;
	                    if (e) {
	                        c[m >> 2] = kx(d, 8, 134712, 134728, 134128, c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                        break
	                    }
	                    e = (qy(c[d + 8 >> 2] | 0, 134752) | 0) != 0;
	                    d = c[g >> 2] | 0;
	                    if (e) {
	                        c[m >> 2] = kx(d, 9, 134752, 134672, 134128, c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                        break
	                    }
	                    e = (qy(c[d + 8 >> 2] | 0, 134632) | 0) != 0;
	                    d = c[g >> 2] | 0;
	                    if (e) {
	                        c[m >> 2] = kx(d, 10, 134632, 134768, 134632, c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                        break
	                    }
	                    e = (qy(c[d + 8 >> 2] | 0, 134776) | 0) != 0;
	                    d = c[g >> 2] | 0;
	                    if (e) {
	                        c[m >> 2] = kx(d, 11, 134776, 134792, 134696, c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                        break
	                    }
	                    e = (qy(c[d + 8 >> 2] | 0, 134808) | 0) != 0;
	                    d = c[g >> 2] | 0;
	                    if (e) {
	                        c[m >> 2] = kx(d, 12, 134808, 134792, 134128, c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                        break
	                    }
	                    if (qy(c[d + 8 >> 2] | 0, 134824) | 0)c[m >> 2] = kx(c[g >> 2] | 0, 3, 134824, 0, 134128, c[h >> 2] | 0, c[k >> 2] | 0) | 0
	                } else {
	                    c[o >> 2] = 0;
	                    c[n >> 2] = Yi(c[g >> 2] | 0, 134464) | 0;
	                    if (c[n >> 2] | 0) {
	                        do if (!(qy(c[n >> 2] | 0, 134472) | 0))if (qy(c[n >> 2] | 0, 134480) | 0) {
	                            c[h >> 2] = 1;
	                            break
	                        } else {
	                            hx(c[j >> 2] | 0, c[g >> 2] | 0, 1652, 134488, c[n >> 2] | 0, 0, 0);
	                            break
	                        } else c[h >> 2] = 2; while (0);
	                        zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                        c[o >> 2] = c[h >> 2]
	                    }
	                    c[n >> 2] = Yi(c[g >> 2] | 0, 134560) | 0;
	                    c[l >> 2] = Ui(c[g >> 2] | 0, 134568, 134576) | 0;
	                    c[m >> 2] = Qw(4, c[n >> 2] | 0, c[l >> 2] | 0, 0, c[o >> 2] | 0, c[k >> 2] | 0) | 0;
	                    zb[c[135736 >> 2] & 511](c[n >> 2] | 0)
	                } while (0);
	                if (c[m >> 2] | 0) {
	                    do if (c[j >> 2] | 0) {
	                        c[(c[m >> 2] | 0) + 4 >> 2] = c[j >> 2];
	                        if (!(c[(c[j >> 2] | 0) + 8 >> 2] | 0)) {
	                            c[(c[j >> 2] | 0) + 8 >> 2] = c[m >> 2];
	                            break
	                        }
	                        c[p >> 2] = c[(c[j >> 2] | 0) + 8 >> 2];
	                        while (1) {
	                            if (!(c[c[p >> 2] >> 2] | 0))break;
	                            c[p >> 2] = c[c[p >> 2] >> 2]
	                        }
	                        c[c[p >> 2] >> 2] = c[m >> 2]
	                    } while (0);
	                    if ((c[(c[m >> 2] | 0) + 12 >> 2] | 0) == 4)ix(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[m >> 2] | 0)
	                }
	                if (!(c[l >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                i = f;
	                return
	            }

	            function kx(a, b, d, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0;
	                j = i;
	                i = i + 80 | 0;
	                k = j;
	                l = j + 64 | 0;
	                m = j + 60 | 0;
	                n = j + 56 | 0;
	                o = j + 52 | 0;
	                p = j + 48 | 0;
	                q = j + 44 | 0;
	                r = j + 40 | 0;
	                s = j + 36 | 0;
	                t = j + 32 | 0;
	                u = j + 28 | 0;
	                v = j + 24 | 0;
	                w = j + 20 | 0;
	                x = j + 16 | 0;
	                y = j + 12 | 0;
	                c[m >> 2] = a;
	                c[n >> 2] = b;
	                c[o >> 2] = d;
	                c[p >> 2] = e;
	                c[q >> 2] = f;
	                c[r >> 2] = g;
	                c[s >> 2] = h;
	                c[t >> 2] = 1;
	                c[v >> 2] = 0;
	                c[w >> 2] = 0;
	                c[x >> 2] = 0;
	                c[y >> 2] = 0;
	                if ((c[p >> 2] | 0) != 0 ? (c[v >> 2] = Yi(c[m >> 2] | 0, c[p >> 2] | 0) | 0, (c[v >> 2] | 0) == 0) : 0) {
	                    hx(c[y >> 2] | 0, c[m >> 2] | 0, 1650, 134840, c[o >> 2] | 0, c[p >> 2] | 0, 0);
	                    c[t >> 2] = 0
	                }
	                c[u >> 2] = Yi(c[m >> 2] | 0, c[q >> 2] | 0) | 0;
	                if (!(c[u >> 2] | 0)) {
	                    hx(c[y >> 2] | 0, c[m >> 2] | 0, 1650, 134840, c[o >> 2] | 0, c[q >> 2] | 0, 0);
	                    c[t >> 2] = 0
	                }
	                if (!(c[t >> 2] | 0)) {
	                    if (c[v >> 2] | 0)zb[c[135736 >> 2] & 511](c[v >> 2] | 0);
	                    if (c[u >> 2] | 0)zb[c[135736 >> 2] & 511](c[u >> 2] | 0);
	                    c[l >> 2] = 0;
	                    z = c[l >> 2] | 0;
	                    i = j;
	                    return z | 0
	                }
	                c[w >> 2] = Xi(c[(c[m >> 2] | 0) + 32 >> 2] | 0, c[m >> 2] | 0) | 0;
	                c[x >> 2] = Hl(c[u >> 2] | 0, c[w >> 2] | 0) | 0;
	                if (c[x >> 2] | 0) {
	                    do if ((c[33468] | 0) > 1) {
	                        t = c[33976] | 0;
	                        p = c[33980] | 0;
	                        h = c[o >> 2] | 0;
	                        if (c[v >> 2] | 0) {
	                            g = c[v >> 2] | 0;
	                            f = c[x >> 2] | 0;
	                            c[k >> 2] = h;
	                            c[k + 4 >> 2] = g;
	                            c[k + 8 >> 2] = f;
	                            Db[t & 511](p, 134864, k);
	                            break
	                        } else {
	                            f = c[x >> 2] | 0;
	                            c[k >> 2] = h;
	                            c[k + 4 >> 2] = f;
	                            Db[t & 511](p, 134888, k);
	                            break
	                        }
	                    } while (0);
	                    c[y >> 2] = Qw(c[n >> 2] | 0, c[v >> 2] | 0, c[u >> 2] | 0, c[x >> 2] | 0, c[r >> 2] | 0, c[s >> 2] | 0) | 0
	                } else hx(c[y >> 2] | 0, c[m >> 2] | 0, 1651, 134904, c[o >> 2] | 0, c[q >> 2] | 0, c[u >> 2] | 0);
	                if (c[v >> 2] | 0)zb[c[135736 >> 2] & 511](c[v >> 2] | 0);
	                if (c[u >> 2] | 0)zb[c[135736 >> 2] & 511](c[u >> 2] | 0);
	                if (c[w >> 2] | 0)zb[c[135736 >> 2] & 511](c[w >> 2] | 0);
	                if (c[x >> 2] | 0)zb[c[135736 >> 2] & 511](c[x >> 2] | 0);
	                c[l >> 2] = c[y >> 2];
	                z = c[l >> 2] | 0;
	                i = j;
	                return z | 0
	            }

	            function lx() {
	                var a = 0;
	                a = i;
	                if (c[33932] | 0) {
	                    i = a;
	                    return
	                }
	                c[33932] = px() | 0;
	                i = a;
	                return
	            }

	            function mx() {
	                var a = 0;
	                a = i;
	                if (c[33932] | 0) {
	                    qx(c[33932] | 0);
	                    c[33932] = 0
	                }
	                xx();
	                i = a;
	                return
	            }

	            function nx(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                c[e >> 2] = c[33968];
	                c[18774] = 1;
	                c[33968] = c[d >> 2];
	                i = b;
	                return c[e >> 2] | 0
	            }

	            function ox(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                c[e >> 2] = c[33970];
	                c[18774] = 1;
	                c[33970] = c[d >> 2];
	                i = b;
	                return c[e >> 2] | 0
	            }

	            function px() {
	                var a = 0, b = 0, d = 0, e = 0;
	                a = i;
	                i = i + 16 | 0;
	                b = a + 4 | 0;
	                d = a;
	                e = iT(4) | 0;
	                c[d >> 2] = e;
	                if (!e)c[b >> 2] = 0; else c[b >> 2] = c[d >> 2];
	                i = a;
	                return c[b >> 2] | 0
	            }

	            function qx(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                jT(c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function rx(a) {
	                a = a | 0;
	                var b = 0;
	                b = i;
	                i = i + 16 | 0;
	                c[b >> 2] = a;
	                i = b;
	                return
	            }

	            function sx(a) {
	                a = a | 0;
	                var b = 0;
	                b = i;
	                i = i + 16 | 0;
	                c[b >> 2] = a;
	                i = b;
	                return
	            }

	            function tx() {
	                var a = 0, b = 0, d = 0, e = 0;
	                a = i;
	                i = i + 16 | 0;
	                b = a + 4 | 0;
	                d = a;
	                e = iT(4) | 0;
	                c[d >> 2] = e;
	                if (!e)c[b >> 2] = 0; else c[b >> 2] = c[d >> 2];
	                i = a;
	                return c[b >> 2] | 0
	            }

	            function ux(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                jT(c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function vx(a) {
	                a = a | 0;
	                var b = 0;
	                b = i;
	                i = i + 16 | 0;
	                c[b >> 2] = a;
	                i = b;
	                return
	            }

	            function wx(a) {
	                a = a | 0;
	                var b = 0;
	                b = i;
	                i = i + 16 | 0;
	                c[b >> 2] = a;
	                i = b;
	                return
	            }

	            function xx() {
	                return
	            }

	            function yx() {
	                return 0
	            }

	            function zx() {
	                return
	            }

	            function Ax() {
	                return
	            }

	            function Bx(a, b, d, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                j = i;
	                i = i + 48 | 0;
	                k = j + 40 | 0;
	                l = j + 36 | 0;
	                m = j + 32 | 0;
	                n = j + 28 | 0;
	                o = j + 24 | 0;
	                p = j + 20 | 0;
	                q = j + 16 | 0;
	                r = j + 12 | 0;
	                s = j + 8 | 0;
	                t = j + 4 | 0;
	                u = j;
	                c[l >> 2] = a;
	                c[m >> 2] = b;
	                c[n >> 2] = d;
	                c[o >> 2] = e;
	                c[p >> 2] = f;
	                c[q >> 2] = g;
	                c[r >> 2] = h;
	                c[t >> 2] = 0;
	                if ((c[r >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0) {
	                    Ex(136264);
	                    c[k >> 2] = -1;
	                    v = c[k >> 2] | 0;
	                    i = j;
	                    return v | 0
	                }
	                if ((c[o >> 2] | 0) >>> 0 >= 3) {
	                    Ex(136280);
	                    c[k >> 2] = -1;
	                    v = c[k >> 2] | 0;
	                    i = j;
	                    return v | 0
	                }
	                c[t >> 2] = c[o >> 2];
	                o = c[l >> 2] | 0;
	                if (c[(c[r >> 2] | 0) + 12 >> 2] | 0) {
	                    Fx(0, o, 1951, 136312);
	                    c[k >> 2] = -1;
	                    v = c[k >> 2] | 0;
	                    i = j;
	                    return v | 0
	                }
	                c[s >> 2] = Gx(o, c[m >> 2] | 0, c[n >> 2] | 0, c[t >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0, c[r >> 2] | 0) | 0;
	                q = c[l >> 2] | 0;
	                if (!(c[s >> 2] | 0)) {
	                    Fx(0, q, 1950, 136392);
	                    c[k >> 2] = -1;
	                    v = c[k >> 2] | 0;
	                    i = j;
	                    return v | 0
	                }
	                if ((c[q + 12 >> 2] | 0) != 0 ? (c[u >> 2] = Hx(c[s >> 2] | 0, c[(c[l >> 2] | 0) + 12 >> 2] | 0) | 0, (c[u >> 2] | 0) < 0) : 0) {
	                    Ix(136440);
	                    Jx(c[s >> 2] | 0);
	                    c[k >> 2] = -1;
	                    v = c[k >> 2] | 0;
	                    i = j;
	                    return v | 0
	                }
	                c[u >> 2] = Ak(c[r >> 2] | 0) | 0;
	                if ((c[u >> 2] | 0) < 0) {
	                    Ix(136472);
	                    Jx(c[s >> 2] | 0);
	                    c[k >> 2] = -1;
	                    v = c[k >> 2] | 0;
	                    i = j;
	                    return v | 0
	                } else {
	                    Jx(c[s >> 2] | 0);
	                    c[k >> 2] = c[u >> 2];
	                    v = c[k >> 2] | 0;
	                    i = j;
	                    return v | 0
	                }
	                return 0
	            }

	            function Cx(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                h = i;
	                i = i + 32 | 0;
	                j = h + 20 | 0;
	                k = h + 16 | 0;
	                l = h + 12 | 0;
	                m = h + 8 | 0;
	                n = h + 4 | 0;
	                o = h;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                g = Bx(c[j >> 2] | 0, 317, c[k >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0) | 0;
	                i = h;
	                return g | 0
	            }

	            function Dx(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h + 32 | 0;
	                k = h + 28 | 0;
	                l = h + 24 | 0;
	                m = h + 20 | 0;
	                n = h + 16 | 0;
	                o = h + 12 | 0;
	                p = h + 8 | 0;
	                q = h + 4 | 0;
	                r = h;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                if (!(c[p >> 2] | 0)) {
	                    Ex(136496);
	                    c[j >> 2] = -1;
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                }
	                c[c[p >> 2] >> 2] = 0;
	                c[r >> 2] = wk(0) | 0;
	                if (!(c[r >> 2] | 0)) {
	                    Lx(136520);
	                    c[j >> 2] = -1;
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                }
	                c[q >> 2] = Cx(c[k >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, c[r >> 2] | 0) | 0;
	                if ((c[q >> 2] | 0) < 0) {
	                    Ix(136544);
	                    zk(c[r >> 2] | 0) | 0;
	                    c[j >> 2] = -1;
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                }
	                c[q >> 2] = _y(c[(c[r >> 2] | 0) + 16 >> 2] | 0) | 0;
	                if ((c[q >> 2] | 0) > 0) {
	                    o = Vy(c[(c[r >> 2] | 0) + 16 >> 2] | 0) | 0;
	                    n = ly(o, c[q >> 2] | 0) | 0;
	                    c[c[p >> 2] >> 2] = n
	                }
	                zk(c[r >> 2] | 0) | 0;
	                if ((c[q >> 2] | 0) > 0 ? (c[c[p >> 2] >> 2] | 0) == 0 : 0) {
	                    Lx(136576);
	                    c[j >> 2] = -1;
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                } else {
	                    c[j >> 2] = c[q >> 2];
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                }
	                return 0
	            }

	            function Ex(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                e = b + 4 | 0;
	                c[e >> 2] = a;
	                a = c[e >> 2] | 0;
	                c[d >> 2] = c[e >> 2];
	                Xd(0, 0, 0, 0, 0, 21, 1, 2, 0, 0, a, 0, 0, 0, 0, 138632, d);
	                i = b;
	                return
	            }

	            function Fx(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if (c[h >> 2] | 0)c[(c[h >> 2] | 0) + 40 >> 2] = c[k >> 2];
	                e = c[h >> 2] | 0;
	                h = c[j >> 2] | 0;
	                j = c[k >> 2] | 0;
	                c[g >> 2] = c[l >> 2];
	                Xd(0, 0, 0, e, h, 21, j, 2, 0, 0, 0, 0, 0, 0, 0, 138624, g);
	                i = f;
	                return
	            }

	            function Gx(a, b, d, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                j = i;
	                i = i + 48 | 0;
	                k = j + 32 | 0;
	                l = j + 28 | 0;
	                m = j + 24 | 0;
	                n = j + 20 | 0;
	                o = j + 16 | 0;
	                p = j + 12 | 0;
	                q = j + 8 | 0;
	                r = j + 4 | 0;
	                s = j;
	                c[l >> 2] = a;
	                c[m >> 2] = b;
	                c[n >> 2] = d;
	                c[o >> 2] = e;
	                c[p >> 2] = f;
	                c[q >> 2] = g;
	                c[r >> 2] = h;
	                c[s >> 2] = 0;
	                if ((c[l >> 2] | 0) == 0 | (c[r >> 2] | 0) == 0) {
	                    Ex(138360);
	                    c[k >> 2] = 0;
	                    t = c[k >> 2] | 0;
	                    i = j;
	                    return t | 0
	                }
	                if (c[(c[r >> 2] | 0) + 12 >> 2] | 0) {
	                    Fx(c[s >> 2] | 0, c[l >> 2] | 0, 1951, 138384);
	                    c[k >> 2] = 0;
	                    t = c[k >> 2] | 0;
	                    i = j;
	                    return t | 0
	                }
	                if ((c[(c[l >> 2] | 0) + 76 >> 2] | 0) != 1) {
	                    Fx(c[s >> 2] | 0, c[l >> 2] | 0, 1951, 138464);
	                    c[k >> 2] = 0;
	                    t = c[k >> 2] | 0;
	                    i = j;
	                    return t | 0
	                }
	                c[s >> 2] = Cb[c[135744 >> 2] & 511](44) | 0;
	                if (!(c[s >> 2] | 0)) {
	                    Lx(138512);
	                    c[k >> 2] = 0;
	                    t = c[k >> 2] | 0;
	                    i = j;
	                    return t | 0
	                }
	                h = (c[s >> 2] | 0) + 0 | 0;
	                g = h + 44 | 0;
	                do {
	                    c[h >> 2] = 0;
	                    h = h + 4 | 0
	                } while ((h | 0) < (g | 0));
	                c[c[s >> 2] >> 2] = c[l >> 2];
	                c[(c[s >> 2] | 0) + 12 >> 2] = c[q >> 2];
	                c[(c[s >> 2] | 0) + 4 >> 2] = c[m >> 2];
	                c[(c[s >> 2] | 0) + 8 >> 2] = c[n >> 2];
	                c[(c[s >> 2] | 0) + 16 >> 2] = c[r >> 2];
	                c[(c[s >> 2] | 0) + 24 >> 2] = 1;
	                c[(c[s >> 2] | 0) + 20 >> 2] = 0;
	                r = Mx() | 0;
	                c[(c[s >> 2] | 0) + 28 >> 2] = r;
	                if (!(c[(c[s >> 2] | 0) + 28 >> 2] | 0)) {
	                    Fx(c[s >> 2] | 0, c[l >> 2] | 0, 1952, 138536);
	                    Jx(c[s >> 2] | 0);
	                    c[k >> 2] = 0;
	                    t = c[k >> 2] | 0;
	                    i = j;
	                    return t | 0
	                }
	                c[(c[s >> 2] | 0) + 32 >> 2] = c[o >> 2];
	                if ((c[(c[s >> 2] | 0) + 32 >> 2] | 0) == 1)c[(c[s >> 2] | 0) + 36 >> 2] = c[p >> 2];
	                c[k >> 2] = c[s >> 2];
	                t = c[k >> 2] | 0;
	                i = j;
	                return t | 0
	            }

	            function Hx(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    Ex(136712);
	                    c[e >> 2] = -1;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[h >> 2] = 0;
	                while (1) {
	                    if (!((c[g >> 2] | 0) != 0 & (c[h >> 2] | 0) >= 0))break;
	                    c[h >> 2] = Nx(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                    c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2]
	                }
	                c[e >> 2] = c[h >> 2];
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function Ix(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                e = b + 4 | 0;
	                c[e >> 2] = a;
	                a = c[e >> 2] | 0;
	                c[d >> 2] = c[e >> 2];
	                Xd(0, 0, 0, 0, 0, 21, 1, 2, 0, 0, a, 0, 0, 0, 0, 136688, d);
	                i = b;
	                return
	            }

	            function Jx(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    Ex(136640);
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 28 >> 2] | 0)Ox(c[(c[d >> 2] | 0) + 28 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function Kx(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 36 | 0;
	                g = e + 32 | 0;
	                h = e + 28 | 0;
	                j = e + 24 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (!((c[g >> 2] | 0) != 0 & (c[h >> 2] | 0) != 0)) {
	                    c[f >> 2] = 1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 18) {
	                    c[f >> 2] = ar(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                d = c[h >> 2] | 0;
	                c[k + 0 >> 2] = c[d + 0 >> 2];
	                c[k + 4 >> 2] = c[d + 4 >> 2];
	                c[k + 8 >> 2] = c[d + 8 >> 2];
	                c[k + 12 >> 2] = c[d + 12 >> 2];
	                c[k + 16 >> 2] = c[d + 16 >> 2];
	                c[k + 20 >> 2] = c[d + 20 >> 2];
	                if ((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) == 2 : 0)c[k >> 2] = c[(c[j >> 2] | 0) + 20 >> 2]; else c[k >> 2] = c[j >> 2];
	                c[f >> 2] = ar(c[g >> 2] | 0, k) | 0;
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function Lx(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                e = b + 4 | 0;
	                c[e >> 2] = a;
	                a = c[e >> 2] | 0;
	                c[d >> 2] = c[e >> 2];
	                Xd(0, 0, 0, 0, 0, 21, 2, 2, 0, 0, a, 0, 0, 0, 0, 136608, d);
	                i = b;
	                return
	            }

	            function Mx() {
	                var a = 0, b = 0, d = 0, e = 0, f = 0;
	                a = i;
	                i = i + 16 | 0;
	                b = a + 4 | 0;
	                d = a;
	                c[d >> 2] = Cb[c[135744 >> 2] & 511](24) | 0;
	                if (!(c[d >> 2] | 0)) {
	                    Lx(138592);
	                    c[b >> 2] = 0;
	                    e = c[b >> 2] | 0;
	                    i = a;
	                    return e | 0
	                } else {
	                    f = c[d >> 2] | 0;
	                    c[f + 0 >> 2] = 0;
	                    c[f + 4 >> 2] = 0;
	                    c[f + 8 >> 2] = 0;
	                    c[f + 12 >> 2] = 0;
	                    c[f + 16 >> 2] = 0;
	                    c[f + 20 >> 2] = 0;
	                    c[b >> 2] = c[d >> 2];
	                    e = c[b >> 2] | 0;
	                    i = a;
	                    return e | 0
	                }
	                return 0
	            }

	            function Nx(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 28 | 0;
	                g = e + 24 | 0;
	                h = e + 20 | 0;
	                j = e + 16 | 0;
	                k = e + 12 | 0;
	                l = e + 8 | 0;
	                m = e + 4 | 0;
	                n = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = 0;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) {
	                    Ex(136736);
	                    c[f >> 2] = -1;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                if (c[(c[g >> 2] | 0) + 4 >> 2] | 0)p = vb[c[(c[g >> 2] | 0) + 4 >> 2] & 511](c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[h >> 2] | 0, c[(c[h >> 2] | 0) + 20 >> 2] | 0) | 0; else p = 1;
	                c[k >> 2] = p;
	                a:do switch (c[(c[h >> 2] | 0) + 4 >> 2] | 0) {
	                    case 8:
	                    {
	                        if ((c[k >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                            p = c[(c[g >> 2] | 0) + 16 >> 2] | 0;
	                            if ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) == 2)Qk(p, 136840) | 0; else Qk(p, 136848) | 0;
	                            do if (c[(c[h >> 2] | 0) + 40 >> 2] | 0) {
	                                c[n >> 2] = Qx(c[(c[h >> 2] | 0) + 40 >> 2] | 0, 1) | 0;
	                                if (c[n >> 2] | 0) {
	                                    Qk(c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[n >> 2] | 0) | 0;
	                                    zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                                    break
	                                }
	                                Ix(136856);
	                                c[f >> 2] = -1;
	                                o = c[f >> 2] | 0;
	                                i = e;
	                                return o | 0
	                            } while (0);
	                            p = c[(c[g >> 2] | 0) + 16 >> 2] | 0;
	                            if (!(c[(c[g >> 2] | 0) + 20 >> 2] | 0)) {
	                                Qk(p, 136888) | 0;
	                                break a
	                            } else {
	                                Qk(p, 136896) | 0;
	                                break a
	                            }
	                        }
	                        break
	                    }
	                    case 18:
	                    {
	                        Rx(136928, 136736);
	                        c[f >> 2] = -1;
	                        o = c[f >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    }
	                    case 7:
	                    {
	                        if (c[k >> 2] | 0) {
	                            p = c[(c[g >> 2] | 0) + 16 >> 2] | 0;
	                            if ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) == 2)Qk(p, 136776) | 0; else Qk(p, 136784) | 0;
	                            Qk(c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0) | 0;
	                            do if ((c[(c[h >> 2] | 0) + 40 >> 2] | 0) != 0 ? (d[c[(c[h >> 2] | 0) + 40 >> 2] >> 0] | 0 | 0) != 0 : 0) {
	                                Qk(c[(c[g >> 2] | 0) + 16 >> 2] | 0, 136792) | 0;
	                                c[m >> 2] = Qx(c[(c[h >> 2] | 0) + 40 >> 2] | 0, 2) | 0;
	                                if (c[m >> 2] | 0) {
	                                    Qk(c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[m >> 2] | 0) | 0;
	                                    zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                                    break
	                                }
	                                Ix(136800);
	                                c[f >> 2] = -1;
	                                o = c[f >> 2] | 0;
	                                i = e;
	                                return o | 0
	                            } while (0);
	                            p = c[(c[g >> 2] | 0) + 16 >> 2] | 0;
	                            if (!(c[(c[g >> 2] | 0) + 20 >> 2] | 0)) {
	                                Qk(p, 136824) | 0;
	                                break a
	                            } else {
	                                Qk(p, 136832) | 0;
	                                break a
	                            }
	                        }
	                        break
	                    }
	                    case 3:
	                    case 4:
	                    {
	                        if ((c[k >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) {
	                            c[l >> 2] = Qx(c[(c[h >> 2] | 0) + 40 >> 2] | 0, 3) | 0;
	                            if (c[l >> 2] | 0) {
	                                Qk(c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[l >> 2] | 0) | 0;
	                                zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                                break a
	                            }
	                            Ix(136752);
	                            c[f >> 2] = -1;
	                            o = c[f >> 2] | 0;
	                            i = e;
	                            return o | 0
	                        }
	                        break
	                    }
	                    case 1:
	                    {
	                        c[j >> 2] = Px(c[g >> 2] | 0, c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                        break
	                    }
	                    case 2:
	                    {
	                        Rx(136904, 136736);
	                        c[f >> 2] = -1;
	                        o = c[f >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    }
	                    case 13:
	                    case 21:
	                    case 11:
	                    case 9:
	                    {
	                        if (c[(c[h >> 2] | 0) + 12 >> 2] | 0) {
	                            c[(c[g >> 2] | 0) + 20 >> 2] = 0;
	                            c[(c[g >> 2] | 0) + 24 >> 2] = 1;
	                            c[j >> 2] = Hx(c[g >> 2] | 0, c[(c[h >> 2] | 0) + 12 >> 2] | 0) | 0
	                        }
	                        break
	                    }
	                    case 6:
	                    {
	                        Rx(136976, 136736);
	                        c[f >> 2] = -1;
	                        o = c[f >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    }
	                    case 20:
	                    case 19:
	                    case 17:
	                    case 16:
	                    case 15:
	                    case 14:
	                    case 12:
	                    case 10:
	                        break;
	                    case 5:
	                    {
	                        Rx(136952, 136736);
	                        c[f >> 2] = -1;
	                        o = c[f >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    }
	                    default:
	                    {
	                        Sx(c[(c[h >> 2] | 0) + 4 >> 2] | 0, 136736);
	                        c[f >> 2] = -1;
	                        o = c[f >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    }
	                } while (0);
	                c[f >> 2] = c[j >> 2];
	                o = c[f >> 2] | 0;
	                i = e;
	                return o | 0
	            }

	            function Ox(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    Ex(136656);
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 16 >> 2] | 0) {
	                    cU(c[(c[d >> 2] | 0) + 16 >> 2] | 0, 0, c[(c[d >> 2] | 0) + 12 >> 2] << 2 | 0) | 0;
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 16 >> 2] | 0)
	                }
	                if (c[(c[d >> 2] | 0) + 20 >> 2] | 0) {
	                    cU(c[(c[d >> 2] | 0) + 20 >> 2] | 0, 0, c[(c[d >> 2] | 0) + 12 >> 2] << 2 | 0) | 0;
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 20 >> 2] | 0)
	                }
	                a = c[d >> 2] | 0;
	                c[a + 0 >> 2] = 0;
	                c[a + 4 >> 2] = 0;
	                c[a + 8 >> 2] = 0;
	                c[a + 12 >> 2] = 0;
	                c[a + 16 >> 2] = 0;
	                c[a + 20 >> 2] = 0;
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function Px(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 64 | 0;
	                f = e + 48 | 0;
	                g = e + 44 | 0;
	                h = e + 40 | 0;
	                j = e + 36 | 0;
	                k = e + 32 | 0;
	                l = e + 8 | 0;
	                m = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[m >> 2] = 0;
	                if (!((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) {
	                    if ((Tx(c[g >> 2] | 0, c[h >> 2] | 0) | 0) < 0) {
	                        Ix(137128);
	                        c[f >> 2] = -1;
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    }
	                    ;
	                    c[l + 0 >> 2] = 0;
	                    c[l + 4 >> 2] = 0;
	                    c[l + 8 >> 2] = 0;
	                    c[l + 12 >> 2] = 0;
	                    c[l + 16 >> 2] = 0;
	                    c[l + 20 >> 2] = 0;
	                    Ux(c[(c[g >> 2] | 0) + 28 >> 2] | 0, l);
	                    if (c[j >> 2] | 0) {
	                        if (c[(c[g >> 2] | 0) + 24 >> 2] | 0) {
	                            c[m >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                            c[(c[g >> 2] | 0) + 24 >> 2] = 0;
	                            c[(c[g >> 2] | 0) + 20 >> 2] = 1
	                        }
	                        Qk(c[(c[g >> 2] | 0) + 16 >> 2] | 0, 137168) | 0;
	                        if ((c[(c[h >> 2] | 0) + 36 >> 2] | 0) != 0 ? (xy(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 0 : 0) {
	                            Qk(c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0;
	                            Qk(c[(c[g >> 2] | 0) + 16 >> 2] | 0, 137176) | 0
	                        }
	                        Qk(c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0) | 0
	                    }
	                    d = c[g >> 2] | 0;
	                    b = c[h >> 2] | 0;
	                    a = c[j >> 2] | 0;
	                    if ((c[(c[g >> 2] | 0) + 32 >> 2] | 0) == 1)c[k >> 2] = Wx(d, b, a) | 0; else c[k >> 2] = Vx(d, b, a) | 0;
	                    if ((c[k >> 2] | 0) < 0) {
	                        Ix(137184);
	                        c[f >> 2] = -1;
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    }
	                    if (c[j >> 2] | 0)Xx(c[(c[g >> 2] | 0) + 28 >> 2] | 0);
	                    c[k >> 2] = Yx(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                    if ((c[k >> 2] | 0) < 0) {
	                        Ix(137216);
	                        c[f >> 2] = -1;
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    }
	                    if (c[j >> 2] | 0)Qk(c[(c[g >> 2] | 0) + 16 >> 2] | 0, 137248) | 0;
	                    if ((c[(c[h >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[k >> 2] = Hx(c[g >> 2] | 0, c[(c[h >> 2] | 0) + 12 >> 2] | 0) | 0, (c[k >> 2] | 0) < 0) : 0) {
	                        Ix(137256);
	                        c[f >> 2] = -1;
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    }
	                    if (c[j >> 2] | 0) {
	                        Qk(c[(c[g >> 2] | 0) + 16 >> 2] | 0, 137288) | 0;
	                        if ((c[(c[h >> 2] | 0) + 36 >> 2] | 0) != 0 ? (xy(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 0 : 0) {
	                            Qk(c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0;
	                            Qk(c[(c[g >> 2] | 0) + 16 >> 2] | 0, 137176) | 0
	                        }
	                        Qk(c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        Qk(c[(c[g >> 2] | 0) + 16 >> 2] | 0, 137248) | 0;
	                        if (c[m >> 2] | 0) {
	                            c[(c[g >> 2] | 0) + 24 >> 2] = c[m >> 2];
	                            c[(c[g >> 2] | 0) + 20 >> 2] = 2
	                        }
	                    }
	                    Zx(c[(c[g >> 2] | 0) + 28 >> 2] | 0, l);
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                Ex(137104);
	                c[f >> 2] = -1;
	                n = c[f >> 2] | 0;
	                i = e;
	                return n | 0
	            }

	            function Qx(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 28 | 0;
	                h = f + 24 | 0;
	                j = f + 20 | 0;
	                k = f + 16 | 0;
	                l = f + 12 | 0;
	                m = f + 8 | 0;
	                n = f + 4 | 0;
	                o = f;
	                c[h >> 2] = b;
	                c[j >> 2] = e;
	                c[k >> 2] = c[h >> 2];
	                c[l >> 2] = 0;
	                c[m >> 2] = 0;
	                c[n >> 2] = 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                c[n >> 2] = 1e3;
	                c[l >> 2] = Cb[c[135752 >> 2] & 511](c[n >> 2] | 0) | 0;
	                if (!(c[l >> 2] | 0)) {
	                    Lx(137064);
	                    c[g >> 2] = 0;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                c[m >> 2] = c[l >> 2];
	                while (1) {
	                    q = c[m >> 2] | 0;
	                    if (!(d[c[k >> 2] >> 0] | 0)) {
	                        r = 30;
	                        break
	                    }
	                    if ((q - (c[l >> 2] | 0) | 0) > ((c[n >> 2] | 0) - 10 | 0)) {
	                        c[o >> 2] = (c[m >> 2] | 0) - (c[l >> 2] | 0);
	                        c[n >> 2] = c[n >> 2] << 1;
	                        c[l >> 2] = Hb[c[135760 >> 2] & 511](c[l >> 2] | 0, c[n >> 2] | 0) | 0;
	                        if (!(c[l >> 2] | 0)) {
	                            r = 9;
	                            break
	                        }
	                        c[m >> 2] = (c[l >> 2] | 0) + (c[o >> 2] | 0)
	                    }
	                    if ((d[c[k >> 2] >> 0] | 0 | 0) == 60 ? (c[j >> 2] | 0) == 0 | (c[j >> 2] | 0) == 3 : 0) {
	                        h = c[m >> 2] | 0;
	                        c[m >> 2] = h + 1;
	                        a[h >> 0] = 38;
	                        h = c[m >> 2] | 0;
	                        c[m >> 2] = h + 1;
	                        a[h >> 0] = 108;
	                        h = c[m >> 2] | 0;
	                        c[m >> 2] = h + 1;
	                        a[h >> 0] = 116;
	                        h = c[m >> 2] | 0;
	                        c[m >> 2] = h + 1;
	                        a[h >> 0] = 59
	                    } else r = 14;
	                    do if ((r | 0) == 14) {
	                        r = 0;
	                        if ((c[j >> 2] | 0) == 3 ? (d[c[k >> 2] >> 0] | 0 | 0) == 62 : 0) {
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 38;
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 103;
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 116;
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 59;
	                            break
	                        }
	                        if ((d[c[k >> 2] >> 0] | 0 | 0) == 38 ? (c[j >> 2] | 0) == 0 | (c[j >> 2] | 0) == 3 : 0) {
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 38;
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 97;
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 109;
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 112;
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 59;
	                            break
	                        }
	                        if ((c[j >> 2] | 0) == 0 ? (d[c[k >> 2] >> 0] | 0 | 0) == 34 : 0) {
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 38;
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 113;
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 117;
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 111;
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 116;
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 59;
	                            break
	                        }
	                        if ((c[j >> 2] | 0) == 0 ? (d[c[k >> 2] >> 0] | 0 | 0) == 9 : 0) {
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 38;
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 35;
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 120;
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 57;
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 59;
	                            break
	                        }
	                        if ((c[j >> 2] | 0) == 0 ? (d[c[k >> 2] >> 0] | 0 | 0) == 10 : 0) {
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 38;
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 35;
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 120;
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 65;
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 59;
	                            break
	                        }
	                        if ((d[c[k >> 2] >> 0] | 0 | 0) == 13 ? (c[j >> 2] | 0) == 0 | (c[j >> 2] | 0) == 3 | (c[j >> 2] | 0) == 1 | (c[j >> 2] | 0) == 2 : 0) {
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 38;
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 35;
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 120;
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 68;
	                            h = c[m >> 2] | 0;
	                            c[m >> 2] = h + 1;
	                            a[h >> 0] = 59;
	                            break
	                        }
	                        h = a[c[k >> 2] >> 0] | 0;
	                        e = c[m >> 2] | 0;
	                        c[m >> 2] = e + 1;
	                        a[e >> 0] = h
	                    } while (0);
	                    c[k >> 2] = (c[k >> 2] | 0) + 1
	                }
	                if ((r | 0) == 9) {
	                    Lx(137088);
	                    c[g >> 2] = 0;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                } else if ((r | 0) == 30) {
	                    a[q >> 0] = 0;
	                    c[g >> 2] = c[l >> 2];
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                return 0
	            }

	            function Rx(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                b = c[g >> 2] | 0;
	                a = c[g >> 2] | 0;
	                c[e >> 2] = c[f >> 2];
	                c[e + 4 >> 2] = a;
	                Xd(0, 0, 0, 0, 0, 21, 1953, 2, 0, 0, b, 0, 0, 0, 0, 137032, e);
	                i = d;
	                return
	            }

	            function Sx(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                b = c[g >> 2] | 0;
	                a = c[g >> 2] | 0;
	                c[e >> 2] = c[f >> 2];
	                c[e + 4 >> 2] = a;
	                Xd(0, 0, 0, 0, 0, 21, 1954, 2, 0, 0, b, 0, 0, 0, 0, 136992, e);
	                i = d;
	                return
	            }

	            function Tx(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) {
	                    c[h >> 2] = c[(c[g >> 2] | 0) + 48 >> 2];
	                    while (1) {
	                        if (!(c[h >> 2] | 0)) {
	                            k = 17;
	                            break
	                        }
	                        if ((xy(c[(c[h >> 2] | 0) + 8 >> 2] | 0) | 0) > 0) {
	                            c[j >> 2] = yl(c[(c[h >> 2] | 0) + 8 >> 2] | 0) | 0;
	                            if (!(c[j >> 2] | 0)) {
	                                k = 8;
	                                break
	                            }
	                            g = (xy(c[c[j >> 2] >> 2] | 0) | 0) == 0;
	                            l = c[c[j >> 2] >> 2] | 0;
	                            if (g) {
	                                k = 10;
	                                break
	                            }
	                            if (((ty(l, 138296) | 0) != 0 ? (ty(c[c[j >> 2] >> 2] | 0, 138304) | 0) != 0 : 0) ? (xy(c[(c[j >> 2] | 0) + 12 >> 2] | 0) | 0) == 0 : 0) {
	                                k = 14;
	                                break
	                            }
	                            Al(c[j >> 2] | 0)
	                        }
	                        c[h >> 2] = c[c[h >> 2] >> 2]
	                    }
	                    if ((k | 0) == 8) {
	                        Ix(138272);
	                        c[e >> 2] = -1;
	                        m = c[e >> 2] | 0;
	                        i = d;
	                        return m | 0
	                    } else if ((k | 0) == 10) {
	                        _x(l);
	                        Al(c[j >> 2] | 0);
	                        c[e >> 2] = -1;
	                        m = c[e >> 2] | 0;
	                        i = d;
	                        return m | 0
	                    } else if ((k | 0) == 14) {
	                        _x(c[c[j >> 2] >> 2] | 0);
	                        Al(c[j >> 2] | 0);
	                        c[e >> 2] = -1;
	                        m = c[e >> 2] | 0;
	                        i = d;
	                        return m | 0
	                    } else if ((k | 0) == 17) {
	                        c[e >> 2] = 0;
	                        m = c[e >> 2] | 0;
	                        i = d;
	                        return m | 0
	                    }
	                }
	                Ex(137128);
	                c[e >> 2] = -1;
	                m = c[e >> 2] | 0;
	                i = d;
	                return m | 0
	            }

	            function Ux(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if ((c[e >> 2] | 0) == 0 | (c[f >> 2] | 0) == 0) {
	                    Ex(138248);
	                    i = d;
	                    return
	                } else {
	                    c[c[f >> 2] >> 2] = c[c[e >> 2] >> 2];
	                    c[(c[f >> 2] | 0) + 4 >> 2] = c[(c[e >> 2] | 0) + 4 >> 2];
	                    c[(c[f >> 2] | 0) + 8 >> 2] = c[(c[e >> 2] | 0) + 8 >> 2];
	                    i = d;
	                    return
	                }
	            }

	            function Vx(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 36 | 0;
	                g = e + 32 | 0;
	                h = e + 28 | 0;
	                j = e + 24 | 0;
	                k = e + 20 | 0;
	                l = e + 16 | 0;
	                m = e + 12 | 0;
	                n = e + 8 | 0;
	                o = e + 4 | 0;
	                p = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[p >> 2] = 0;
	                if (!((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) {
	                    c[n >> 2] = IS(0, 318) | 0;
	                    if (!(c[n >> 2] | 0)) {
	                        Ix(138192);
	                        c[f >> 2] = -1;
	                        q = c[f >> 2] | 0;
	                        i = e;
	                        return q | 0
	                    }
	                    c[k >> 2] = c[h >> 2];
	                    while (1) {
	                        if (!(c[k >> 2] | 0))break;
	                        c[l >> 2] = c[(c[k >> 2] | 0) + 48 >> 2];
	                        while (1) {
	                            if (!(c[l >> 2] | 0))break;
	                            c[m >> 2] = cj(c[(c[h >> 2] | 0) + 32 >> 2] | 0, c[h >> 2] | 0, c[(c[l >> 2] | 0) + 12 >> 2] | 0) | 0;
	                            do if ((c[m >> 2] | 0) == (c[l >> 2] | 0) ? (ay(c[l >> 2] | 0) | 0) == 0 : 0) {
	                                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 0 ? (vb[c[(c[g >> 2] | 0) + 4 >> 2] & 511](c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[l >> 2] | 0, c[h >> 2] | 0) | 0) == 0 : 0)break;
	                                c[o >> 2] = by(c[(c[g >> 2] | 0) + 28 >> 2] | 0, c[l >> 2] | 0) | 0;
	                                if (c[j >> 2] | 0)cy(c[(c[g >> 2] | 0) + 28 >> 2] | 0, c[l >> 2] | 0, c[h >> 2] | 0);
	                                if (!(c[o >> 2] | 0))KS(c[n >> 2] | 0, c[l >> 2] | 0) | 0;
	                                if (!(xy(c[(c[l >> 2] | 0) + 12 >> 2] | 0) | 0))c[p >> 2] = 1
	                            } while (0);
	                            c[l >> 2] = c[c[l >> 2] >> 2]
	                        }
	                        c[k >> 2] = c[(c[k >> 2] | 0) + 20 >> 2]
	                    }
	                    if (!((c[j >> 2] | 0) == 0 | (c[p >> 2] | 0) != 0) ? (c[34556] = 0, c[34557] = 0, c[34558] = 0, c[34559] = 0, c[34560] = 0, c[34561] = 0, (by(c[(c[g >> 2] | 0) + 28 >> 2] | 0, 138224) | 0) == 0) : 0)dy(138224, c[g >> 2] | 0) | 0;
	                    PS(c[n >> 2] | 0, 319, c[g >> 2] | 0);
	                    MS(c[n >> 2] | 0);
	                    c[f >> 2] = 0;
	                    q = c[f >> 2] | 0;
	                    i = e;
	                    return q | 0
	                }
	                Ex(138152);
	                c[f >> 2] = -1;
	                q = c[f >> 2] | 0;
	                i = e;
	                return q | 0
	            }

	            function Wx(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                e = i;
	                i = i + 64 | 0;
	                f = e + 48 | 0;
	                g = e + 44 | 0;
	                h = e + 40 | 0;
	                j = e + 36 | 0;
	                k = e + 32 | 0;
	                l = e + 28 | 0;
	                m = e + 24 | 0;
	                n = e + 20 | 0;
	                o = e + 16 | 0;
	                p = e + 12 | 0;
	                q = e + 8 | 0;
	                r = e + 4 | 0;
	                s = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[o >> 2] = 0;
	                c[p >> 2] = 0;
	                c[q >> 2] = 0;
	                if (!((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) {
	                    if ((c[(c[g >> 2] | 0) + 32 >> 2] | 0) != 1) {
	                        Ex(137816);
	                        c[f >> 2] = -1;
	                        t = c[f >> 2] | 0;
	                        i = e;
	                        return t | 0
	                    }
	                    c[l >> 2] = IS(0, 318) | 0;
	                    if (!(c[l >> 2] | 0)) {
	                        Ix(137856);
	                        c[f >> 2] = -1;
	                        t = c[f >> 2] | 0;
	                        i = e;
	                        return t | 0
	                    }
	                    a:do if (c[(c[g >> 2] | 0) + 36 >> 2] | 0) {
	                        c[s >> 2] = 0;
	                        while (1) {
	                            if (!(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + (c[s >> 2] << 2) >> 2] | 0))break a;
	                            c[r >> 2] = c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + (c[s >> 2] << 2) >> 2];
	                            if (!((qy(c[r >> 2] | 0, 137896) | 0) == 0 ? (qy(c[r >> 2] | 0, 137704) | 0) == 0 : 0)) {
	                                c[r >> 2] = 0;
	                                c[q >> 2] = 1
	                            }
	                            c[k >> 2] = cj(c[(c[h >> 2] | 0) + 32 >> 2] | 0, c[h >> 2] | 0, c[r >> 2] | 0) | 0;
	                            do if ((c[k >> 2] | 0) != 0 ? (ay(c[k >> 2] | 0) | 0) == 0 : 0) {
	                                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 0 ? (vb[c[(c[g >> 2] | 0) + 4 >> 2] & 511](c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[k >> 2] | 0, c[h >> 2] | 0) | 0) == 0 : 0)break;
	                                c[n >> 2] = by(c[(c[g >> 2] | 0) + 28 >> 2] | 0, c[k >> 2] | 0) | 0;
	                                if (c[j >> 2] | 0)cy(c[(c[g >> 2] | 0) + 28 >> 2] | 0, c[k >> 2] | 0, c[h >> 2] | 0);
	                                if (!(c[n >> 2] | 0))KS(c[l >> 2] | 0, c[k >> 2] | 0) | 0;
	                                if (!(xy(c[(c[k >> 2] | 0) + 12 >> 2] | 0) | 0))c[o >> 2] = 1
	                            } while (0);
	                            c[s >> 2] = (c[s >> 2] | 0) + 1
	                        }
	                    } while (0);
	                    s = c[h >> 2] | 0;
	                    if (c[(c[h >> 2] | 0) + 36 >> 2] | 0)c[k >> 2] = c[s + 36 >> 2]; else {
	                        c[k >> 2] = cj(c[s + 32 >> 2] | 0, c[h >> 2] | 0, 0) | 0;
	                        c[p >> 2] = 1
	                    }
	                    if ((c[k >> 2] | 0) != 0 ? (ay(c[k >> 2] | 0) | 0) == 0 : 0) {
	                        do if (c[j >> 2] | 0) {
	                            if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 0 ? (vb[c[(c[g >> 2] | 0) + 4 >> 2] & 511](c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[k >> 2] | 0, c[h >> 2] | 0) | 0) == 0 : 0)break;
	                            if (!(ey(c[(c[g >> 2] | 0) + 28 >> 2] | 0, c[k >> 2] | 0, c[g >> 2] | 0) | 0))KS(c[l >> 2] | 0, c[k >> 2] | 0) | 0
	                        } while (0);
	                        if (c[j >> 2] | 0)cy(c[(c[g >> 2] | 0) + 28 >> 2] | 0, c[k >> 2] | 0, c[h >> 2] | 0);
	                        if (!(xy(c[(c[k >> 2] | 0) + 12 >> 2] | 0) | 0))c[o >> 2] = 1
	                    }
	                    c[m >> 2] = c[(c[h >> 2] | 0) + 44 >> 2];
	                    while (1) {
	                        if (!(c[m >> 2] | 0))break;
	                        do if ((c[(c[m >> 2] | 0) + 36 >> 2] | 0) != 0 ? (ay(c[(c[m >> 2] | 0) + 36 >> 2] | 0) | 0) == 0 : 0) {
	                            if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 0 ? (vb[c[(c[g >> 2] | 0) + 4 >> 2] & 511](c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[m >> 2] | 0, c[h >> 2] | 0) | 0) == 0 : 0) {
	                                u = 49;
	                                break
	                            }
	                            c[n >> 2] = ey(c[(c[g >> 2] | 0) + 28 >> 2] | 0, c[(c[m >> 2] | 0) + 36 >> 2] | 0, c[g >> 2] | 0) | 0;
	                            cy(c[(c[g >> 2] | 0) + 28 >> 2] | 0, c[(c[m >> 2] | 0) + 36 >> 2] | 0, c[h >> 2] | 0);
	                            if ((c[n >> 2] | 0) == 0 & (c[j >> 2] | 0) != 0)KS(c[l >> 2] | 0, c[(c[m >> 2] | 0) + 36 >> 2] | 0) | 0;
	                            if (!(xy(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0))c[o >> 2] = 1
	                        } else u = 49; while (0);
	                        if ((((u | 0) == 49 ? (u = 0, (c[(c[m >> 2] | 0) + 36 >> 2] | 0) != 0) : 0) ? (xy(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) == 0 : 0) ? (xy(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) | 0) == 0 : 0)c[p >> 2] = 1;
	                        c[m >> 2] = c[(c[m >> 2] | 0) + 24 >> 2]
	                    }
	                    if ((c[j >> 2] | 0) != 0 & (c[p >> 2] | 0) != 0 ^ 1 | (c[o >> 2] | 0) != 0 | (c[q >> 2] | 0) != 0) {
	                        if ((((c[j >> 2] | 0) == 0 | (c[o >> 2] | 0) != 0) ^ 1) & (c[q >> 2] | 0) != 0 ? (c[34484] = 0, c[34485] = 0, c[34486] = 0, c[34487] = 0, c[34488] = 0, c[34489] = 0, (by(c[(c[g >> 2] | 0) + 28 >> 2] | 0, 137936) | 0) == 0) : 0)dy(137936, c[g >> 2] | 0) | 0
	                    } else {
	                        c[34478] = 0;
	                        c[34479] = 0;
	                        c[34480] = 0;
	                        c[34481] = 0;
	                        c[34482] = 0;
	                        c[34483] = 0;
	                        c[n >> 2] = ey(c[(c[g >> 2] | 0) + 28 >> 2] | 0, 137912, c[g >> 2] | 0) | 0;
	                        if (!(c[n >> 2] | 0))dy(137912, c[g >> 2] | 0) | 0
	                    }
	                    PS(c[l >> 2] | 0, 319, c[g >> 2] | 0);
	                    MS(c[l >> 2] | 0);
	                    c[f >> 2] = 0;
	                    t = c[f >> 2] | 0;
	                    i = e;
	                    return t | 0
	                }
	                Ex(137816);
	                c[f >> 2] = -1;
	                t = c[f >> 2] | 0;
	                i = e;
	                return t | 0
	            }

	            function Xx(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    Ex(137784);
	                    i = b;
	                    return
	                } else {
	                    c[(c[d >> 2] | 0) + 4 >> 2] = c[(c[d >> 2] | 0) + 8 >> 2];
	                    c[(c[d >> 2] | 0) + 8 >> 2] = c[c[d >> 2] >> 2];
	                    i = b;
	                    return
	                }
	            }

	            function Yx(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 44 | 0;
	                g = e + 40 | 0;
	                h = e + 36 | 0;
	                j = e + 32 | 0;
	                k = e + 28 | 0;
	                l = e + 24 | 0;
	                m = e + 20 | 0;
	                n = e + 16 | 0;
	                o = e + 12 | 0;
	                p = e + 8 | 0;
	                q = e + 4 | 0;
	                r = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[m >> 2] = 0;
	                c[n >> 2] = 0;
	                c[o >> 2] = 0;
	                c[p >> 2] = 0;
	                if (!((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) {
	                    c[l >> 2] = IS(0, 320) | 0;
	                    if (!(c[l >> 2] | 0)) {
	                        Ix(137328);
	                        c[f >> 2] = -1;
	                        s = c[f >> 2] | 0;
	                        i = e;
	                        return s | 0
	                    }
	                    d = c[(c[g >> 2] | 0) + 32 >> 2] | 0;
	                    a:do if ((d | 0) == 2) {
	                        c[k >> 2] = c[(c[h >> 2] | 0) + 44 >> 2];
	                        while (1) {
	                            t = (c[j >> 2] | 0) != 0;
	                            if (!(c[k >> 2] | 0))break;
	                            do if (t ? (gy(c[k >> 2] | 0) | 0) != 0 : 0) {
	                                c[r >> 2] = 0;
	                                if ((c[r >> 2] | 0) == 0 & (c[o >> 2] | 0) == 0 ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 137360) | 0) != 0 : 0) {
	                                    c[o >> 2] = c[k >> 2];
	                                    c[r >> 2] = 1
	                                }
	                                if ((c[r >> 2] | 0) == 0 & (c[p >> 2] | 0) == 0 ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 137368) | 0) != 0 : 0) {
	                                    c[p >> 2] = c[k >> 2];
	                                    c[r >> 2] = 1
	                                }
	                                if ((c[r >> 2] | 0) == 0 & (c[n >> 2] | 0) == 0 ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 137376) | 0) != 0 : 0) {
	                                    c[n >> 2] = c[k >> 2];
	                                    c[r >> 2] = 1
	                                }
	                                if (!(c[r >> 2] | 0)) {
	                                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 0 ? (vb[c[(c[g >> 2] | 0) + 4 >> 2] & 511](c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[k >> 2] | 0, c[h >> 2] | 0) | 0) == 0 : 0)break;
	                                    KS(c[l >> 2] | 0, c[k >> 2] | 0) | 0
	                                }
	                            } else u = 36; while (0);
	                            do if ((u | 0) == 36) {
	                                u = 0;
	                                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 0 ? (vb[c[(c[g >> 2] | 0) + 4 >> 2] & 511](c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[k >> 2] | 0, c[h >> 2] | 0) | 0) == 0 : 0)break;
	                                KS(c[l >> 2] | 0, c[k >> 2] | 0) | 0
	                            } while (0);
	                            c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                        }
	                        if (t) {
	                            if (!(c[o >> 2] | 0))c[o >> 2] = hy(c[g >> 2] | 0, c[(c[h >> 2] | 0) + 20 >> 2] | 0, 137360, 137384) | 0;
	                            if (c[o >> 2] | 0)KS(c[l >> 2] | 0, c[o >> 2] | 0) | 0;
	                            if (!(c[p >> 2] | 0))c[p >> 2] = hy(c[g >> 2] | 0, c[(c[h >> 2] | 0) + 20 >> 2] | 0, 137368, 137384) | 0;
	                            if (c[p >> 2] | 0)KS(c[l >> 2] | 0, c[p >> 2] | 0) | 0;
	                            if (!(c[n >> 2] | 0))c[n >> 2] = hy(c[g >> 2] | 0, c[(c[h >> 2] | 0) + 20 >> 2] | 0, 137376, 137384) | 0;
	                            if ((c[n >> 2] | 0) != 0 ? (c[n >> 2] = iy(c[g >> 2] | 0, c[n >> 2] | 0) | 0, (c[n >> 2] | 0) != 0) : 0) {
	                                KS(c[l >> 2] | 0, c[n >> 2] | 0) | 0;
	                                c[(c[n >> 2] | 0) + 24 >> 2] = c[m >> 2];
	                                c[m >> 2] = c[n >> 2]
	                            }
	                        }
	                    } else if (!d) {
	                        c[k >> 2] = c[(c[h >> 2] | 0) + 44 >> 2];
	                        while (1) {
	                            if (!(c[k >> 2] | 0))break;
	                            if (!((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 0 ? (vb[c[(c[g >> 2] | 0) + 4 >> 2] & 511](c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[k >> 2] | 0, c[h >> 2] | 0) | 0) == 0 : 0))KS(c[l >> 2] | 0, c[k >> 2] | 0) | 0;
	                            c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                        }
	                        if ((((c[j >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) ? (vb[c[(c[g >> 2] | 0) + 4 >> 2] & 511](c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[(c[h >> 2] | 0) + 20 >> 2] | 0, c[(c[(c[h >> 2] | 0) + 20 >> 2] | 0) + 20 >> 2] | 0) | 0) == 0 : 0) {
	                            c[q >> 2] = c[(c[h >> 2] | 0) + 20 >> 2];
	                            while (1) {
	                                if (!(c[q >> 2] | 0))break a;
	                                c[k >> 2] = c[(c[q >> 2] | 0) + 44 >> 2];
	                                while (1) {
	                                    if (!(c[k >> 2] | 0))break;
	                                    if ((gy(c[k >> 2] | 0) | 0) != 0 ? (JS(c[l >> 2] | 0, c[k >> 2] | 0) | 0) == 0 : 0)KS(c[l >> 2] | 0, c[k >> 2] | 0) | 0;
	                                    c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                                }
	                                c[q >> 2] = c[(c[q >> 2] | 0) + 20 >> 2]
	                            }
	                        }
	                    } else if ((d | 0) == 1) {
	                        c[k >> 2] = c[(c[h >> 2] | 0) + 44 >> 2];
	                        while (1) {
	                            if (!(c[k >> 2] | 0))break a;
	                            if (!((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 0 ? (vb[c[(c[g >> 2] | 0) + 4 >> 2] & 511](c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[k >> 2] | 0, c[h >> 2] | 0) | 0) == 0 : 0))KS(c[l >> 2] | 0, c[k >> 2] | 0) | 0;
	                            c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                        }
	                    } while (0);
	                    PS(c[l >> 2] | 0, 321, c[g >> 2] | 0);
	                    di(c[m >> 2] | 0);
	                    MS(c[l >> 2] | 0);
	                    c[f >> 2] = 0;
	                    s = c[f >> 2] | 0;
	                    i = e;
	                    return s | 0
	                }
	                Ex(137216);
	                c[f >> 2] = -1;
	                s = c[f >> 2] | 0;
	                i = e;
	                return s | 0
	            }

	            function Zx(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if ((c[e >> 2] | 0) == 0 | (c[f >> 2] | 0) == 0) {
	                    Ex(137296);
	                    i = d;
	                    return
	                } else {
	                    c[c[e >> 2] >> 2] = c[c[f >> 2] >> 2];
	                    c[(c[e >> 2] | 0) + 4 >> 2] = c[(c[f >> 2] | 0) + 4 >> 2];
	                    c[(c[e >> 2] | 0) + 8 >> 2] = c[(c[f >> 2] | 0) + 8 >> 2];
	                    i = d;
	                    return
	                }
	            }

	            function _x(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                e = b + 4 | 0;
	                c[e >> 2] = a;
	                c[d >> 2] = c[e >> 2];
	                Xd(0, 0, 0, 0, 0, 21, 1955, 2, 0, 0, 0, 0, 0, 0, 0, 138312, d);
	                i = b;
	                return
	            }

	            function $x(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                do if ((c[f >> 2] | 0) != (c[g >> 2] | 0)) {
	                    if (!(c[f >> 2] | 0)) {
	                        c[e >> 2] = -1;
	                        break
	                    }
	                    if (!(c[g >> 2] | 0)) {
	                        c[e >> 2] = 1;
	                        break
	                    } else {
	                        c[e >> 2] = py(c[(c[f >> 2] | 0) + 12 >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] | 0) | 0;
	                        break
	                    }
	                } else c[e >> 2] = 0; while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function ay(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) != 0 ? (qy(c[(c[d >> 2] | 0) + 12 >> 2] | 0, 137776) | 0) != 0 : 0)e = (qy(c[(c[d >> 2] | 0) + 8 >> 2] | 0, 137384) | 0) != 0; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function by(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                d = i;
	                i = i + 48 | 0;
	                e = d + 32 | 0;
	                f = d + 28 | 0;
	                g = d + 24 | 0;
	                h = d + 20 | 0;
	                j = d + 16 | 0;
	                k = d + 12 | 0;
	                l = d + 8 | 0;
	                m = d + 4 | 0;
	                n = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    Ex(138112);
	                    c[e >> 2] = 0;
	                    o = c[e >> 2] | 0;
	                    i = d;
	                    return o | 0
	                }
	                if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 12 >> 2] | 0) != 0 : 0)p = c[(c[g >> 2] | 0) + 12 >> 2] | 0; else p = 137704;
	                c[j >> 2] = p;
	                if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 8 >> 2] | 0) != 0 : 0)q = c[(c[g >> 2] | 0) + 8 >> 2] | 0; else q = 137704;
	                c[k >> 2] = q;
	                if (ky(c[j >> 2] | 0, 0) | 0)r = (ky(c[k >> 2] | 0, 0) | 0) != 0; else r = 0;
	                c[l >> 2] = r & 1;
	                a:do if (c[(c[f >> 2] | 0) + 16 >> 2] | 0) {
	                    if (c[l >> 2] | 0)s = 0; else s = c[(c[f >> 2] | 0) + 4 >> 2] | 0;
	                    c[m >> 2] = s;
	                    c[h >> 2] = (c[c[f >> 2] >> 2] | 0) - 1;
	                    while (1) {
	                        if ((c[h >> 2] | 0) < (c[m >> 2] | 0))break a;
	                        c[n >> 2] = c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + (c[h >> 2] << 2) >> 2];
	                        if (c[n >> 2] | 0)t = c[(c[n >> 2] | 0) + 12 >> 2] | 0; else t = 0;
	                        if (ky(c[j >> 2] | 0, t) | 0)break;
	                        c[h >> 2] = (c[h >> 2] | 0) + -1
	                    }
	                    if (c[n >> 2] | 0)u = c[(c[n >> 2] | 0) + 8 >> 2] | 0; else u = 0;
	                    c[e >> 2] = ky(c[k >> 2] | 0, u) | 0;
	                    o = c[e >> 2] | 0;
	                    i = d;
	                    return o | 0
	                } while (0);
	                c[e >> 2] = c[l >> 2];
	                o = c[e >> 2] | 0;
	                i = d;
	                return o | 0
	            }

	            function cy(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                do if (c[f >> 2] | 0) {
	                    if ((c[(c[f >> 2] | 0) + 16 >> 2] | 0) == 0 ? (c[(c[f >> 2] | 0) + 20 >> 2] | 0) != 0 : 0)break;
	                    if ((c[(c[f >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 20 >> 2] | 0) == 0 : 0)break;
	                    do if ((c[(c[f >> 2] | 0) + 16 >> 2] | 0) == 0 ? (c[(c[f >> 2] | 0) + 20 >> 2] | 0) == 0 : 0) {
	                        d = Cb[c[135744 >> 2] & 511](64) | 0;
	                        c[(c[f >> 2] | 0) + 16 >> 2] = d;
	                        d = Cb[c[135744 >> 2] & 511](64) | 0;
	                        c[(c[f >> 2] | 0) + 20 >> 2] = d;
	                        if ((c[(c[f >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) {
	                            d = (c[(c[f >> 2] | 0) + 16 >> 2] | 0) + 0 | 0;
	                            b = d + 64 | 0;
	                            do {
	                                c[d >> 2] = 0;
	                                d = d + 4 | 0
	                            } while ((d | 0) < (b | 0));
	                            d = (c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 0 | 0;
	                            b = d + 64 | 0;
	                            do {
	                                c[d >> 2] = 0;
	                                d = d + 4 | 0
	                            } while ((d | 0) < (b | 0));
	                            c[(c[f >> 2] | 0) + 12 >> 2] = 16;
	                            break
	                        }
	                        Lx(138088);
	                        i = e;
	                        return
	                    } else l = 13; while (0);
	                    do if ((l | 0) == 13 ? (c[(c[f >> 2] | 0) + 12 >> 2] | 0) == (c[c[f >> 2] >> 2] | 0) : 0) {
	                        c[k >> 2] = c[(c[f >> 2] | 0) + 12 >> 2] << 1;
	                        c[j >> 2] = Hb[c[135760 >> 2] & 511](c[(c[f >> 2] | 0) + 16 >> 2] | 0, c[k >> 2] << 2) | 0;
	                        if (!(c[j >> 2] | 0)) {
	                            Lx(138088);
	                            i = e;
	                            return
	                        }
	                        c[(c[f >> 2] | 0) + 16 >> 2] = c[j >> 2];
	                        c[j >> 2] = Hb[c[135760 >> 2] & 511](c[(c[f >> 2] | 0) + 20 >> 2] | 0, c[k >> 2] << 2) | 0;
	                        if (c[j >> 2] | 0) {
	                            c[(c[f >> 2] | 0) + 20 >> 2] = c[j >> 2];
	                            c[(c[f >> 2] | 0) + 12 >> 2] = c[k >> 2];
	                            break
	                        }
	                        Lx(138088);
	                        i = e;
	                        return
	                    } while (0);
	                    c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + (c[c[f >> 2] >> 2] << 2) >> 2] = c[g >> 2];
	                    c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + (c[c[f >> 2] >> 2] << 2) >> 2] = c[h >> 2];
	                    d = c[f >> 2] | 0;
	                    c[d >> 2] = (c[d >> 2] | 0) + 1;
	                    i = e;
	                    return
	                } while (0);
	                Ex(138056);
	                i = e;
	                return
	            }

	            function dy(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    Ex(137960);
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                b = c[(c[g >> 2] | 0) + 16 >> 2] | 0;
	                if (c[(c[f >> 2] | 0) + 12 >> 2] | 0) {
	                    Qk(b, 137984) | 0;
	                    Qk(c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[(c[f >> 2] | 0) + 12 >> 2] | 0) | 0;
	                    Qk(c[(c[g >> 2] | 0) + 16 >> 2] | 0, 137992) | 0
	                } else Qk(b, 138e3) | 0;
	                b = c[(c[g >> 2] | 0) + 16 >> 2] | 0;
	                if (c[(c[f >> 2] | 0) + 8 >> 2] | 0)gz(c[b + 16 >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0) | 0; else Qk(b, 138008) | 0;
	                c[e >> 2] = 1;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function ey(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 36 | 0;
	                g = e + 32 | 0;
	                h = e + 28 | 0;
	                j = e + 24 | 0;
	                k = e + 20 | 0;
	                l = e + 16 | 0;
	                m = e + 12 | 0;
	                n = e + 8 | 0;
	                o = e + 4 | 0;
	                p = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (!(c[g >> 2] | 0)) {
	                    Ex(138016);
	                    c[f >> 2] = 0;
	                    q = c[f >> 2] | 0;
	                    i = e;
	                    return q | 0
	                }
	                if ((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 12 >> 2] | 0) != 0 : 0)r = c[(c[h >> 2] | 0) + 12 >> 2] | 0; else r = 137704;
	                c[l >> 2] = r;
	                if ((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 8 >> 2] | 0) != 0 : 0)s = c[(c[h >> 2] | 0) + 8 >> 2] | 0; else s = 137704;
	                c[m >> 2] = s;
	                if (ky(c[l >> 2] | 0, 0) | 0)t = (ky(c[m >> 2] | 0, 0) | 0) != 0; else t = 0;
	                c[n >> 2] = t & 1;
	                a:do if (c[(c[g >> 2] | 0) + 16 >> 2] | 0) {
	                    c[o >> 2] = 0;
	                    c[k >> 2] = (c[c[g >> 2] >> 2] | 0) - 1;
	                    while (1) {
	                        if ((c[k >> 2] | 0) < (c[o >> 2] | 0))break a;
	                        c[p >> 2] = c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + (c[k >> 2] << 2) >> 2];
	                        if (c[p >> 2] | 0)u = c[(c[p >> 2] | 0) + 12 >> 2] | 0; else u = 0;
	                        if (ky(c[l >> 2] | 0, u) | 0)break;
	                        c[k >> 2] = (c[k >> 2] | 0) + -1
	                    }
	                    if (c[p >> 2] | 0)v = c[(c[p >> 2] | 0) + 8 >> 2] | 0; else v = 0;
	                    if (!(ky(c[m >> 2] | 0, v) | 0)) {
	                        c[f >> 2] = 0;
	                        q = c[f >> 2] | 0;
	                        i = e;
	                        return q | 0
	                    }
	                    if (c[(c[j >> 2] | 0) + 4 >> 2] | 0)w = vb[c[(c[j >> 2] | 0) + 4 >> 2] & 511](c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[p >> 2] | 0, c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) | 0; else w = 1;
	                    c[f >> 2] = w;
	                    q = c[f >> 2] | 0;
	                    i = e;
	                    return q | 0
	                } while (0);
	                c[f >> 2] = c[n >> 2];
	                q = c[f >> 2] | 0;
	                i = e;
	                return q | 0
	            }

	            function fy(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                do if ((c[f >> 2] | 0) == (c[g >> 2] | 0))c[e >> 2] = 0; else {
	                    if (!(c[f >> 2] | 0)) {
	                        c[e >> 2] = -1;
	                        break
	                    }
	                    if (!(c[g >> 2] | 0)) {
	                        c[e >> 2] = 1;
	                        break
	                    }
	                    b = c[f >> 2] | 0;
	                    if ((c[(c[f >> 2] | 0) + 36 >> 2] | 0) == (c[(c[g >> 2] | 0) + 36 >> 2] | 0)) {
	                        c[e >> 2] = py(c[b + 8 >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        break
	                    }
	                    if (!(c[b + 36 >> 2] | 0)) {
	                        c[e >> 2] = -1;
	                        break
	                    }
	                    if (!(c[(c[g >> 2] | 0) + 36 >> 2] | 0)) {
	                        c[e >> 2] = 1;
	                        break
	                    }
	                    if (!(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0)) {
	                        c[e >> 2] = -1;
	                        break
	                    }
	                    if (!(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0)) {
	                        c[e >> 2] = 1;
	                        break
	                    }
	                    c[h >> 2] = py(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) | 0;
	                    if (!(c[h >> 2] | 0))c[h >> 2] = py(c[(c[f >> 2] | 0) + 8 >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0) | 0;
	                    c[e >> 2] = c[h >> 2]
	                } while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function gy(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[(c[d >> 2] | 0) + 36 >> 2] | 0)) {
	                    e = 0;
	                    f = e & 1;
	                    i = b;
	                    return f | 0
	                }
	                e = (ay(c[(c[d >> 2] | 0) + 36 >> 2] | 0) | 0) != 0;
	                f = e & 1;
	                i = b;
	                return f | 0
	            }

	            function hy(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                while (1) {
	                    if (!(c[j >> 2] | 0)) {
	                        n = 9;
	                        break
	                    }
	                    if (c[(c[h >> 2] | 0) + 4 >> 2] | 0)o = vb[c[(c[h >> 2] | 0) + 4 >> 2] & 511](c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[j >> 2] | 0, c[(c[j >> 2] | 0) + 20 >> 2] | 0) | 0; else o = 1;
	                    if (!((o | 0) != 0 ^ 1)) {
	                        n = 9;
	                        break
	                    }
	                    c[m >> 2] = Ai(c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0;
	                    if (c[m >> 2] | 0) {
	                        n = 7;
	                        break
	                    }
	                    c[j >> 2] = c[(c[j >> 2] | 0) + 20 >> 2]
	                }
	                if ((n | 0) == 7) {
	                    c[g >> 2] = c[m >> 2];
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                } else if ((n | 0) == 9) {
	                    c[g >> 2] = 0;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                return 0
	            }

	            function iy(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 32 | 0;
	                g = e + 28 | 0;
	                h = e + 24 | 0;
	                j = e + 20 | 0;
	                k = e + 16 | 0;
	                l = e + 12 | 0;
	                m = e + 8 | 0;
	                n = e + 4 | 0;
	                o = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = 0;
	                if (!((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) ? (c[(c[h >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) {
	                    c[j >> 2] = _h(c[c[g >> 2] >> 2] | 0, c[(c[h >> 2] | 0) + 12 >> 2] | 0, 1) | 0;
	                    if (!(c[j >> 2] | 0)) {
	                        Ix(137528);
	                        c[f >> 2] = 0;
	                        p = c[f >> 2] | 0;
	                        i = e;
	                        return p | 0
	                    }
	                    c[k >> 2] = c[(c[(c[h >> 2] | 0) + 20 >> 2] | 0) + 20 >> 2];
	                    while (1) {
	                        if (!(c[k >> 2] | 0)) {
	                            q = 23;
	                            break
	                        }
	                        if (c[(c[g >> 2] | 0) + 4 >> 2] | 0)r = vb[c[(c[g >> 2] | 0) + 4 >> 2] & 511](c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[k >> 2] | 0, c[(c[k >> 2] | 0) + 20 >> 2] | 0) | 0; else r = 1;
	                        if (!((r | 0) != 0 ^ 1)) {
	                            q = 23;
	                            break
	                        }
	                        c[l >> 2] = Ai(c[k >> 2] | 0, 137376, 137384) | 0;
	                        if (c[l >> 2] | 0) {
	                            c[m >> 2] = _h(c[c[g >> 2] >> 2] | 0, c[(c[l >> 2] | 0) + 12 >> 2] | 0, 1) | 0;
	                            if (!(c[m >> 2] | 0)) {
	                                q = 13;
	                                break
	                            }
	                            c[o >> 2] = xy(c[m >> 2] | 0) | 0;
	                            if ((c[o >> 2] | 0) > 1 ? (d[(c[m >> 2] | 0) + ((c[o >> 2] | 0) - 2) >> 0] | 0 | 0) == 46 : 0) {
	                                c[n >> 2] = By(c[m >> 2] | 0, 137584) | 0;
	                                if (!(c[n >> 2] | 0)) {
	                                    q = 17;
	                                    break
	                                }
	                                c[m >> 2] = c[n >> 2]
	                            }
	                            c[n >> 2] = Hl(c[j >> 2] | 0, c[m >> 2] | 0) | 0;
	                            b = (c[n >> 2] | 0) == 0;
	                            zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                            zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                            if (b) {
	                                q = 20;
	                                break
	                            }
	                            c[j >> 2] = c[n >> 2]
	                        }
	                        c[k >> 2] = c[(c[k >> 2] | 0) + 20 >> 2]
	                    }
	                    if ((q | 0) == 13) {
	                        zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                        Ix(137528);
	                        c[f >> 2] = 0;
	                        p = c[f >> 2] | 0;
	                        i = e;
	                        return p | 0
	                    } else if ((q | 0) == 17) {
	                        zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                        Ix(137592);
	                        c[f >> 2] = 0;
	                        p = c[f >> 2] | 0;
	                        i = e;
	                        return p | 0
	                    } else if ((q | 0) == 20) {
	                        Ix(137648);
	                        c[f >> 2] = 0;
	                        p = c[f >> 2] | 0;
	                        i = e;
	                        return p | 0
	                    } else if ((q | 0) == 23) {
	                        if ((c[j >> 2] | 0) != 0 ? (qy(c[j >> 2] | 0, 137704) | 0) == 0 : 0) {
	                            c[l >> 2] = ai(0, c[(c[h >> 2] | 0) + 36 >> 2] | 0, 137376, c[j >> 2] | 0) | 0;
	                            h = (c[l >> 2] | 0) == 0;
	                            zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                            if (h) {
	                                Ix(137712);
	                                c[f >> 2] = 0;
	                                p = c[f >> 2] | 0;
	                                i = e;
	                                return p | 0
	                            } else {
	                                c[f >> 2] = c[l >> 2];
	                                p = c[f >> 2] | 0;
	                                i = e;
	                                return p | 0
	                            }
	                        }
	                        zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                        c[f >> 2] = 0;
	                        p = c[f >> 2] | 0;
	                        i = e;
	                        return p | 0
	                    }
	                }
	                Ex(137496);
	                c[f >> 2] = 0;
	                p = c[f >> 2] | 0;
	                i = e;
	                return p | 0
	            }

	            function jy(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    Ex(137424);
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                Qk(c[(c[g >> 2] | 0) + 16 >> 2] | 0, 136792) | 0;
	                if ((c[(c[f >> 2] | 0) + 36 >> 2] | 0) != 0 ? (xy(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 0 : 0) {
	                    Qk(c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0;
	                    Qk(c[(c[g >> 2] | 0) + 16 >> 2] | 0, 137176) | 0
	                }
	                Qk(c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0) | 0;
	                Qk(c[(c[g >> 2] | 0) + 16 >> 2] | 0, 137448) | 0;
	                c[h >> 2] = _h(c[c[g >> 2] >> 2] | 0, c[(c[f >> 2] | 0) + 12 >> 2] | 0, 1) | 0;
	                do if (c[h >> 2] | 0) {
	                    c[j >> 2] = Qx(c[h >> 2] | 0, 0) | 0;
	                    zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                    if (c[j >> 2] | 0) {
	                        Qk(c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[j >> 2] | 0) | 0;
	                        zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                        break
	                    }
	                    Ix(137456);
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                } while (0);
	                Qk(c[(c[g >> 2] | 0) + 16 >> 2] | 0, 137488) | 0;
	                c[e >> 2] = 1;
	                k = c[e >> 2] | 0;
	                i = d;
	                return k | 0
	            }

	            function ky(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 8 | 0;
	                h = f + 4 | 0;
	                j = f;
	                c[h >> 2] = b;
	                c[j >> 2] = e;
	                do if ((c[h >> 2] | 0) != (c[j >> 2] | 0)) {
	                    e = c[j >> 2] | 0;
	                    if (!(c[h >> 2] | 0)) {
	                        c[g >> 2] = (d[e >> 0] | 0) == 0 & 1;
	                        break
	                    }
	                    if (!e) {
	                        c[g >> 2] = (d[c[h >> 2] >> 0] | 0) == 0 & 1;
	                        break
	                    }
	                    while (1) {
	                        e = c[h >> 2] | 0;
	                        c[h >> 2] = e + 1;
	                        if ((d[e >> 0] | 0) != (d[c[j >> 2] >> 0] | 0)) {
	                            k = 8;
	                            break
	                        }
	                        e = c[j >> 2] | 0;
	                        c[j >> 2] = e + 1;
	                        if (!(a[e >> 0] | 0)) {
	                            k = 10;
	                            break
	                        }
	                    }
	                    if ((k | 0) == 8) {
	                        c[g >> 2] = 0;
	                        break
	                    } else if ((k | 0) == 10) {
	                        c[g >> 2] = 1;
	                        break
	                    }
	                } else c[g >> 2] = 1; while (0);
	                i = f;
	                return c[g >> 2] | 0
	            }

	            function ly(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) < 0) {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                c[j >> 2] = Cb[c[135752 >> 2] & 511]((c[h >> 2] | 0) + 1 | 0) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    ie(0, 0);
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                } else {
	                    eU(c[j >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                    a[(c[j >> 2] | 0) + (c[h >> 2] | 0) >> 0] = 0;
	                    c[f >> 2] = c[j >> 2];
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                return 0
	            }

	            function my(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[f >> 2] = a;
	                c[g >> 2] = c[f >> 2];
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                while (1) {
	                    if (!(d[c[g >> 2] >> 0] | 0))break;
	                    c[g >> 2] = (c[g >> 2] | 0) + 1
	                }
	                c[e >> 2] = ly(c[f >> 2] | 0, (c[g >> 2] | 0) - (c[f >> 2] | 0) | 0) | 0;
	                h = c[e >> 2] | 0;
	                i = b;
	                return h | 0
	            }

	            function ny(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[h >> 2] = b;
	                c[j >> 2] = e;
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) < 0) {
	                    c[g >> 2] = 0;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                c[l >> 2] = Cb[c[135752 >> 2] & 511]((c[j >> 2] | 0) + 1 | 0) | 0;
	                if (!(c[l >> 2] | 0)) {
	                    ie(0, 0);
	                    c[g >> 2] = 0;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                c[k >> 2] = 0;
	                while (1) {
	                    if ((c[k >> 2] | 0) >= (c[j >> 2] | 0)) {
	                        n = 10;
	                        break
	                    }
	                    a[(c[l >> 2] | 0) + (c[k >> 2] | 0) >> 0] = a[(c[h >> 2] | 0) + (c[k >> 2] | 0) >> 0] | 0;
	                    if (!(d[(c[l >> 2] | 0) + (c[k >> 2] | 0) >> 0] | 0)) {
	                        n = 8;
	                        break
	                    }
	                    c[k >> 2] = (c[k >> 2] | 0) + 1
	                }
	                if ((n | 0) == 8) {
	                    c[g >> 2] = c[l >> 2];
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                } else if ((n | 0) == 10) {
	                    a[(c[l >> 2] | 0) + (c[j >> 2] | 0) >> 0] = 0;
	                    c[g >> 2] = c[l >> 2];
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                return 0
	            }

	            function oy(b) {
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = b;
	                c[g >> 2] = c[f >> 2];
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                while (1) {
	                    if (!(a[c[g >> 2] >> 0] | 0))break;
	                    c[g >> 2] = (c[g >> 2] | 0) + 1
	                }
	                c[e >> 2] = ny(c[f >> 2] | 0, (c[g >> 2] | 0) - (c[f >> 2] | 0) | 0) | 0;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function py(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                do if ((c[g >> 2] | 0) != (c[h >> 2] | 0)) {
	                    if (!(c[g >> 2] | 0)) {
	                        c[f >> 2] = -1;
	                        break
	                    }
	                    if (!(c[h >> 2] | 0)) {
	                        c[f >> 2] = 1;
	                        break
	                    }
	                    while (1) {
	                        b = c[g >> 2] | 0;
	                        c[g >> 2] = b + 1;
	                        c[j >> 2] = (d[b >> 0] | 0) - (d[c[h >> 2] >> 0] | 0);
	                        if (c[j >> 2] | 0) {
	                            k = 8;
	                            break
	                        }
	                        b = c[h >> 2] | 0;
	                        c[h >> 2] = b + 1;
	                        if (!(d[b >> 0] | 0)) {
	                            k = 10;
	                            break
	                        }
	                    }
	                    if ((k | 0) == 8) {
	                        c[f >> 2] = c[j >> 2];
	                        break
	                    } else if ((k | 0) == 10) {
	                        c[f >> 2] = 0;
	                        break
	                    }
	                } else c[f >> 2] = 0; while (0);
	                i = e;
	                return c[f >> 2] | 0
	            }

	            function qy(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 8 | 0;
	                h = f + 4 | 0;
	                j = f;
	                c[h >> 2] = b;
	                c[j >> 2] = e;
	                do if ((c[h >> 2] | 0) != (c[j >> 2] | 0)) {
	                    if (!(c[h >> 2] | 0)) {
	                        c[g >> 2] = 0;
	                        break
	                    }
	                    if (!(c[j >> 2] | 0)) {
	                        c[g >> 2] = 0;
	                        break
	                    }
	                    while (1) {
	                        e = c[h >> 2] | 0;
	                        c[h >> 2] = e + 1;
	                        if ((d[e >> 0] | 0) != (d[c[j >> 2] >> 0] | 0)) {
	                            k = 8;
	                            break
	                        }
	                        e = c[j >> 2] | 0;
	                        c[j >> 2] = e + 1;
	                        if (!(a[e >> 0] | 0)) {
	                            k = 10;
	                            break
	                        }
	                    }
	                    if ((k | 0) == 8) {
	                        c[g >> 2] = 0;
	                        break
	                    } else if ((k | 0) == 10) {
	                        c[g >> 2] = 1;
	                        break
	                    }
	                } else c[g >> 2] = 1; while (0);
	                i = f;
	                return c[g >> 2] | 0
	            }

	            function ry(b, e, f) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                g = i;
	                i = i + 16 | 0;
	                h = g + 12 | 0;
	                j = g + 8 | 0;
	                k = g + 4 | 0;
	                l = g;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[l >> 2] = f;
	                f = c[k >> 2] | 0;
	                do if (c[j >> 2] | 0) {
	                    if (!f) {
	                        c[h >> 2] = 0;
	                        break
	                    }
	                    if (!(c[l >> 2] | 0)) {
	                        c[h >> 2] = 0;
	                        break
	                    }
	                    do {
	                        e = c[j >> 2] | 0;
	                        c[j >> 2] = e + 1;
	                        if ((d[e >> 0] | 0) != (d[c[l >> 2] >> 0] | 0)) {
	                            m = 8;
	                            break
	                        }
	                        e = c[l >> 2] | 0;
	                        c[l >> 2] = e + 1;
	                        if (!(d[e >> 0] | 0))break
	                    } while ((d[c[j >> 2] >> 0] | 0) != 0);
	                    if ((m | 0) == 8) {
	                        c[h >> 2] = 0;
	                        break
	                    }
	                    e = c[l >> 2] | 0;
	                    c[l >> 2] = e + 1;
	                    if ((d[e >> 0] | 0) != 58) {
	                        c[h >> 2] = 0;
	                        break
	                    }
	                    while (1) {
	                        e = c[k >> 2] | 0;
	                        c[k >> 2] = e + 1;
	                        if ((d[e >> 0] | 0) != (d[c[l >> 2] >> 0] | 0)) {
	                            m = 14;
	                            break
	                        }
	                        e = c[l >> 2] | 0;
	                        c[l >> 2] = e + 1;
	                        if (!(a[e >> 0] | 0)) {
	                            m = 16;
	                            break
	                        }
	                    }
	                    if ((m | 0) == 14) {
	                        c[h >> 2] = 0;
	                        break
	                    } else if ((m | 0) == 16) {
	                        c[h >> 2] = 1;
	                        break
	                    }
	                } else c[h >> 2] = qy(f, c[l >> 2] | 0) | 0; while (0);
	                i = g;
	                return c[h >> 2] | 0
	            }

	            function sy(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                do if ((c[j >> 2] | 0) > 0) {
	                    if ((c[g >> 2] | 0) == (c[h >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        break
	                    }
	                    if (!(c[g >> 2] | 0)) {
	                        c[f >> 2] = -1;
	                        break
	                    }
	                    if (!(c[h >> 2] | 0)) {
	                        c[f >> 2] = 1;
	                        break
	                    } else {
	                        c[k >> 2] = QT(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                        c[f >> 2] = c[k >> 2];
	                        break
	                    }
	                } else c[f >> 2] = 0; while (0);
	                i = e;
	                return c[f >> 2] | 0
	            }

	            function ty(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                do if ((c[g >> 2] | 0) != (c[h >> 2] | 0)) {
	                    if (!(c[g >> 2] | 0)) {
	                        c[f >> 2] = -1;
	                        break
	                    }
	                    if (!(c[h >> 2] | 0)) {
	                        c[f >> 2] = 1;
	                        break
	                    }
	                    while (1) {
	                        b = c[g >> 2] | 0;
	                        c[g >> 2] = b + 1;
	                        c[j >> 2] = (d[138656 + (d[b >> 0] | 0) >> 0] | 0) - (d[138656 + (d[c[h >> 2] >> 0] | 0) >> 0] | 0);
	                        if (c[j >> 2] | 0) {
	                            k = 8;
	                            break
	                        }
	                        b = c[h >> 2] | 0;
	                        c[h >> 2] = b + 1;
	                        if (!(d[b >> 0] | 0)) {
	                            k = 10;
	                            break
	                        }
	                    }
	                    if ((k | 0) == 8) {
	                        c[f >> 2] = c[j >> 2];
	                        break
	                    } else if ((k | 0) == 10) {
	                        c[f >> 2] = 0;
	                        break
	                    }
	                } else c[f >> 2] = 0; while (0);
	                i = e;
	                return c[f >> 2] | 0
	            }

	            function uy(a, b, e) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                do if ((c[k >> 2] | 0) > 0) {
	                    if ((c[h >> 2] | 0) == (c[j >> 2] | 0)) {
	                        c[g >> 2] = 0;
	                        break
	                    }
	                    if (!(c[h >> 2] | 0)) {
	                        c[g >> 2] = -1;
	                        break
	                    }
	                    if (!(c[j >> 2] | 0)) {
	                        c[g >> 2] = 1;
	                        break
	                    }
	                    while (1) {
	                        e = c[h >> 2] | 0;
	                        c[h >> 2] = e + 1;
	                        c[l >> 2] = (d[138656 + (d[e >> 0] | 0) >> 0] | 0) - (d[138656 + (d[c[j >> 2] >> 0] | 0) >> 0] | 0);
	                        if (c[l >> 2] | 0) {
	                            m = 11;
	                            break
	                        }
	                        e = (c[k >> 2] | 0) + -1 | 0;
	                        c[k >> 2] = e;
	                        if (!e) {
	                            m = 11;
	                            break
	                        }
	                        e = c[j >> 2] | 0;
	                        c[j >> 2] = e + 1;
	                        if (!(d[e >> 0] | 0)) {
	                            m = 13;
	                            break
	                        }
	                    }
	                    if ((m | 0) == 11) {
	                        c[g >> 2] = c[l >> 2];
	                        break
	                    } else if ((m | 0) == 13) {
	                        c[g >> 2] = 0;
	                        break
	                    }
	                } else c[g >> 2] = 0; while (0);
	                i = f;
	                return c[g >> 2] | 0
	            }

	            function vy(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 4 | 0;
	                h = f;
	                j = f + 8 | 0;
	                c[h >> 2] = b;
	                a[j >> 0] = e;
	                do if (c[h >> 2] | 0) {
	                    while (1) {
	                        if (!(d[c[h >> 2] >> 0] | 0)) {
	                            k = 7;
	                            break
	                        }
	                        l = c[h >> 2] | 0;
	                        if ((d[c[h >> 2] >> 0] | 0 | 0) == (d[j >> 0] | 0 | 0)) {
	                            k = 5;
	                            break
	                        }
	                        c[h >> 2] = l + 1
	                    }
	                    if ((k | 0) == 5) {
	                        c[g >> 2] = l;
	                        break
	                    } else if ((k | 0) == 7) {
	                        c[g >> 2] = 0;
	                        break
	                    }
	                } else c[g >> 2] = 0; while (0);
	                i = f;
	                return c[g >> 2] | 0
	            }

	            function wy(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                do if (c[g >> 2] | 0) {
	                    if (!(c[h >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        break
	                    }
	                    c[j >> 2] = xy(c[h >> 2] | 0) | 0;
	                    if (!(c[j >> 2] | 0)) {
	                        c[f >> 2] = c[g >> 2];
	                        break
	                    }
	                    while (1) {
	                        if (!(d[c[g >> 2] >> 0] | 0)) {
	                            k = 12;
	                            break
	                        }
	                        if ((d[c[g >> 2] >> 0] | 0 | 0) == (d[c[h >> 2] >> 0] | 0 | 0) ? (sy(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0) == 0 : 0) {
	                            k = 10;
	                            break
	                        }
	                        c[g >> 2] = (c[g >> 2] | 0) + 1
	                    }
	                    if ((k | 0) == 10) {
	                        c[f >> 2] = c[g >> 2];
	                        break
	                    } else if ((k | 0) == 12) {
	                        c[f >> 2] = 0;
	                        break
	                    }
	                } else c[f >> 2] = 0; while (0);
	                i = e;
	                return c[f >> 2] | 0
	            }

	            function xy(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[f >> 2] = a;
	                c[g >> 2] = 0;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                while (1) {
	                    if (!(d[c[f >> 2] >> 0] | 0))break;
	                    c[f >> 2] = (c[f >> 2] | 0) + 1;
	                    c[g >> 2] = (c[g >> 2] | 0) + 1
	                }
	                c[e >> 2] = c[g >> 2];
	                h = c[e >> 2] | 0;
	                i = b;
	                return h | 0
	            }

	            function yy(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                do if (c[g >> 2] | 0) {
	                    if (!(c[h >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        break
	                    }
	                    c[j >> 2] = xy(c[h >> 2] | 0) | 0;
	                    if (!(c[j >> 2] | 0)) {
	                        c[f >> 2] = c[g >> 2];
	                        break
	                    }
	                    while (1) {
	                        if (!(d[c[g >> 2] >> 0] | 0)) {
	                            k = 12;
	                            break
	                        }
	                        if ((d[138656 + (d[c[g >> 2] >> 0] | 0) >> 0] | 0 | 0) == (d[138656 + (d[c[h >> 2] >> 0] | 0) >> 0] | 0 | 0) ? (uy(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0) == 0 : 0) {
	                            k = 10;
	                            break
	                        }
	                        c[g >> 2] = (c[g >> 2] | 0) + 1
	                    }
	                    if ((k | 0) == 10) {
	                        c[f >> 2] = c[g >> 2];
	                        break
	                    } else if ((k | 0) == 12) {
	                        c[f >> 2] = 0;
	                        break
	                    }
	                } else c[f >> 2] = 0; while (0);
	                i = e;
	                return c[f >> 2] | 0
	            }

	            function zy(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                if ((c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0) {
	                    c[g >> 2] = c[h >> 2];
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                if ((c[k >> 2] | 0) < 0) {
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                if (!(c[h >> 2] | 0)) {
	                    c[g >> 2] = ly(c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                c[l >> 2] = xy(c[h >> 2] | 0) | 0;
	                c[m >> 2] = Hb[c[135760 >> 2] & 511](c[h >> 2] | 0, (c[l >> 2] | 0) + (c[k >> 2] | 0) + 1 | 0) | 0;
	                if (!(c[m >> 2] | 0)) {
	                    ie(0, 0);
	                    c[g >> 2] = c[h >> 2];
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                } else {
	                    eU((c[m >> 2] | 0) + (c[l >> 2] | 0) | 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                    a[(c[m >> 2] | 0) + ((c[l >> 2] | 0) + (c[k >> 2] | 0)) >> 0] = 0;
	                    c[g >> 2] = c[m >> 2];
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                return 0
	            }

	            function Ay(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                if ((c[k >> 2] | 0) < 0)c[k >> 2] = xy(c[j >> 2] | 0) | 0;
	                e = c[h >> 2] | 0;
	                if ((c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0) {
	                    c[g >> 2] = my(e) | 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                if (!e) {
	                    c[g >> 2] = ly(c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                c[l >> 2] = xy(c[h >> 2] | 0) | 0;
	                c[m >> 2] = Cb[c[135744 >> 2] & 511]((c[l >> 2] | 0) + (c[k >> 2] | 0) + 1 | 0) | 0;
	                if (!(c[m >> 2] | 0)) {
	                    ie(0, 0);
	                    c[g >> 2] = ly(c[h >> 2] | 0, c[l >> 2] | 0) | 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                } else {
	                    eU(c[m >> 2] | 0, c[h >> 2] | 0, c[l >> 2] | 0) | 0;
	                    eU((c[m >> 2] | 0) + (c[l >> 2] | 0) | 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                    a[(c[m >> 2] | 0) + ((c[l >> 2] | 0) + (c[k >> 2] | 0)) >> 0] = 0;
	                    c[g >> 2] = c[m >> 2];
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                return 0
	            }

	            function By(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = c[h >> 2];
	                b = c[g >> 2] | 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = b;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                if (!b) {
	                    c[f >> 2] = my(c[h >> 2] | 0) | 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                while (1) {
	                    if (!(d[c[j >> 2] >> 0] | 0))break;
	                    c[j >> 2] = (c[j >> 2] | 0) + 1
	                }
	                c[f >> 2] = zy(c[g >> 2] | 0, c[h >> 2] | 0, (c[j >> 2] | 0) - (c[h >> 2] | 0) | 0) | 0;
	                k = c[f >> 2] | 0;
	                i = e;
	                return k | 0
	            }

	            function Cy(b, d, e, f) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                g = i;
	                i = i + 48 | 0;
	                h = g + 36 | 0;
	                j = g + 32 | 0;
	                k = g + 28 | 0;
	                l = g + 24 | 0;
	                m = g + 8 | 0;
	                n = g;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if ((c[j >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0) {
	                    c[h >> 2] = -1;
	                    o = c[h >> 2] | 0;
	                    i = g;
	                    return o | 0
	                } else {
	                    c[m >> 2] = f;
	                    c[n >> 2] = LT(c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, m) | 0;
	                    a[(c[j >> 2] | 0) + ((c[k >> 2] | 0) - 1) >> 0] = 0;
	                    c[h >> 2] = c[n >> 2];
	                    o = c[h >> 2] | 0;
	                    i = g;
	                    return o | 0
	                }
	                return 0
	            }

	            function Dy(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[f >> 2] = a;
	                c[g >> 2] = 0;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    h = c[e >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                a:while (1) {
	                    if (!(d[c[f >> 2] >> 0] | 0)) {
	                        j = 19;
	                        break
	                    }
	                    a = (c[f >> 2] | 0) + 1 | 0;
	                    do if ((d[c[f >> 2] >> 0] | 0) & 128) {
	                        if (((d[a >> 0] | 0) & 192 | 0) != 128) {
	                            j = 6;
	                            break a
	                        }
	                        k = (c[f >> 2] | 0) + 2 | 0;
	                        if (((d[c[f >> 2] >> 0] | 0) & 224 | 0) != 224) {
	                            c[f >> 2] = k;
	                            break
	                        }
	                        if (((d[k >> 0] | 0) & 192 | 0) != 128) {
	                            j = 9;
	                            break a
	                        }
	                        k = c[f >> 2] | 0;
	                        if (((d[c[f >> 2] >> 0] | 0) & 240 | 0) != 240) {
	                            c[f >> 2] = k + 3;
	                            break
	                        }
	                        if (((d[k >> 0] | 0) & 248 | 0) != 240) {
	                            j = 13;
	                            break a
	                        }
	                        if (((d[(c[f >> 2] | 0) + 3 >> 0] | 0) & 192 | 0) != 128) {
	                            j = 13;
	                            break a
	                        }
	                        c[f >> 2] = (c[f >> 2] | 0) + 4
	                    } else c[f >> 2] = a; while (0);
	                    c[g >> 2] = (c[g >> 2] | 0) + 1
	                }
	                if ((j | 0) == 6) {
	                    c[e >> 2] = -1;
	                    h = c[e >> 2] | 0;
	                    i = b;
	                    return h | 0
	                } else if ((j | 0) == 9) {
	                    c[e >> 2] = -1;
	                    h = c[e >> 2] | 0;
	                    i = b;
	                    return h | 0
	                } else if ((j | 0) == 13) {
	                    c[e >> 2] = -1;
	                    h = c[e >> 2] | 0;
	                    i = b;
	                    return h | 0
	                } else if ((j | 0) == 19) {
	                    c[e >> 2] = c[g >> 2];
	                    h = c[e >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                return 0
	            }

	            function Ey(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                a:do if (!((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) ? (c[c[h >> 2] >> 2] | 0) >= 1 : 0) {
	                    c[j >> 2] = d[c[g >> 2] >> 0];
	                    b = c[h >> 2] | 0;
	                    do if (c[j >> 2] & 128) {
	                        if ((c[b >> 2] | 0) < 2)break a;
	                        if (((d[(c[g >> 2] | 0) + 1 >> 0] | 0) & 192 | 0) != 128)break a;
	                        a = c[h >> 2] | 0;
	                        if ((c[j >> 2] & 224 | 0) != 224) {
	                            c[a >> 2] = 2;
	                            c[j >> 2] = ((d[c[g >> 2] >> 0] | 0) & 31) << 6;
	                            c[j >> 2] = c[j >> 2] | (d[(c[g >> 2] | 0) + 1 >> 0] | 0) & 63;
	                            break
	                        }
	                        if ((c[a >> 2] | 0) < 3)break a;
	                        if (((d[(c[g >> 2] | 0) + 2 >> 0] | 0) & 192 | 0) != 128)break a;
	                        a = c[h >> 2] | 0;
	                        if ((c[j >> 2] & 240 | 0) != 240) {
	                            c[a >> 2] = 3;
	                            c[j >> 2] = ((d[c[g >> 2] >> 0] | 0) & 15) << 12;
	                            c[j >> 2] = c[j >> 2] | ((d[(c[g >> 2] | 0) + 1 >> 0] | 0) & 63) << 6;
	                            c[j >> 2] = c[j >> 2] | (d[(c[g >> 2] | 0) + 2 >> 0] | 0) & 63;
	                            break
	                        }
	                        if ((c[a >> 2] | 0) < 4)break a;
	                        if ((c[j >> 2] & 248 | 0) != 240)break a;
	                        if (((d[(c[g >> 2] | 0) + 3 >> 0] | 0) & 192 | 0) != 128)break a;
	                        c[c[h >> 2] >> 2] = 4;
	                        c[j >> 2] = ((d[c[g >> 2] >> 0] | 0) & 7) << 18;
	                        c[j >> 2] = c[j >> 2] | ((d[(c[g >> 2] | 0) + 1 >> 0] | 0) & 63) << 12;
	                        c[j >> 2] = c[j >> 2] | ((d[(c[g >> 2] | 0) + 2 >> 0] | 0) & 63) << 6;
	                        c[j >> 2] = c[j >> 2] | (d[(c[g >> 2] | 0) + 3 >> 0] | 0) & 63
	                    } else c[b >> 2] = 1; while (0);
	                    c[f >> 2] = c[j >> 2];
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                } while (0);
	                if (c[h >> 2] | 0)c[c[h >> 2] >> 2] = 0;
	                c[f >> 2] = -1;
	                k = c[f >> 2] | 0;
	                i = e;
	                return k | 0
	            }

	            function Fy(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                j = e + 12 | 0;
	                c[g >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                c[h >> 2] = 0;
	                while (1) {
	                    b = a[(c[g >> 2] | 0) + (c[h >> 2] | 0) >> 0] | 0;
	                    a[j >> 0] = b;
	                    if (!(b << 24 >> 24)) {
	                        l = 23;
	                        break
	                    }
	                    if (!((d[j >> 0] | 0) & 128)) {
	                        c[h >> 2] = (c[h >> 2] | 0) + 1;
	                        continue
	                    }
	                    if (((d[j >> 0] | 0) & 224 | 0) == 192) {
	                        if (((d[(c[g >> 2] | 0) + ((c[h >> 2] | 0) + 1) >> 0] | 0) & 192 | 0) != 128) {
	                            l = 9;
	                            break
	                        }
	                        c[h >> 2] = (c[h >> 2] | 0) + 2;
	                        continue
	                    }
	                    if (((d[j >> 0] | 0) & 240 | 0) == 224) {
	                        if (((d[(c[g >> 2] | 0) + ((c[h >> 2] | 0) + 1) >> 0] | 0) & 192 | 0) != 128) {
	                            l = 14;
	                            break
	                        }
	                        if (((d[(c[g >> 2] | 0) + ((c[h >> 2] | 0) + 2) >> 0] | 0) & 192 | 0) != 128) {
	                            l = 14;
	                            break
	                        }
	                        c[h >> 2] = (c[h >> 2] | 0) + 3;
	                        continue
	                    }
	                    if (((d[j >> 0] | 0) & 248 | 0) != 240) {
	                        l = 22;
	                        break
	                    }
	                    if (((d[(c[g >> 2] | 0) + ((c[h >> 2] | 0) + 1) >> 0] | 0) & 192 | 0) != 128) {
	                        l = 20;
	                        break
	                    }
	                    if (((d[(c[g >> 2] | 0) + ((c[h >> 2] | 0) + 2) >> 0] | 0) & 192 | 0) != 128) {
	                        l = 20;
	                        break
	                    }
	                    if (((d[(c[g >> 2] | 0) + ((c[h >> 2] | 0) + 3) >> 0] | 0) & 192 | 0) != 128) {
	                        l = 20;
	                        break
	                    }
	                    c[h >> 2] = (c[h >> 2] | 0) + 4
	                }
	                if ((l | 0) == 9) {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                } else if ((l | 0) == 14) {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                } else if ((l | 0) == 20) {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                } else if ((l | 0) == 22) {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                } else if ((l | 0) == 23) {
	                    c[f >> 2] = 1;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                return 0
	            }

	            function Gy(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 12 | 0;
	                h = f + 8 | 0;
	                j = f + 4 | 0;
	                k = f;
	                l = f + 16 | 0;
	                c[h >> 2] = b;
	                c[j >> 2] = e;
	                c[k >> 2] = c[h >> 2];
	                if (!(c[h >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                if ((c[j >> 2] | 0) <= 0) {
	                    c[g >> 2] = 0;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                a:while (1) {
	                    e = c[j >> 2] | 0;
	                    c[j >> 2] = e + -1;
	                    if ((e | 0) <= 0)break;
	                    if (!(a[c[k >> 2] >> 0] | 0))break;
	                    e = c[k >> 2] | 0;
	                    c[k >> 2] = e + 1;
	                    b = a[e >> 0] | 0;
	                    a[l >> 0] = b;
	                    if (!(b & 128))continue;
	                    while (1) {
	                        b = d[l >> 0] << 1 & 255;
	                        a[l >> 0] = b;
	                        if (!(b & 128))continue a;
	                        c[k >> 2] = (c[k >> 2] | 0) + 1;
	                        if (!(d[c[k >> 2] >> 0] | 0))continue a
	                    }
	                }
	                c[g >> 2] = (c[k >> 2] | 0) - (c[h >> 2] | 0);
	                m = c[g >> 2] | 0;
	                i = f;
	                return m | 0
	            }

	            function Hy(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e;
	                g = e + 20 | 0;
	                h = e + 16 | 0;
	                j = e + 12 | 0;
	                k = e + 8 | 0;
	                l = e + 4 | 0;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) < 0) {
	                    c[g >> 2] = 0;
	                    m = c[g >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                c[l >> 2] = Gy(c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                c[k >> 2] = Cb[c[135752 >> 2] & 511]((c[l >> 2] | 0) + 1 | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    d = c[33976] | 0;
	                    b = c[33980] | 0;
	                    c[f >> 2] = (c[j >> 2] | 0) + 1;
	                    Db[d & 511](b, 138912, f);
	                    c[g >> 2] = 0;
	                    m = c[g >> 2] | 0;
	                    i = e;
	                    return m | 0
	                } else {
	                    eU(c[k >> 2] | 0, c[h >> 2] | 0, c[l >> 2] | 0) | 0;
	                    a[(c[k >> 2] | 0) + (c[l >> 2] | 0) >> 0] = 0;
	                    c[g >> 2] = c[k >> 2];
	                    m = c[g >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                return 0
	            }

	            function Iy(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 8 | 0;
	                h = f + 4 | 0;
	                j = f;
	                k = f + 12 | 0;
	                c[h >> 2] = b;
	                c[j >> 2] = e;
	                do if (c[h >> 2] | 0) {
	                    if ((c[j >> 2] | 0) < 0) {
	                        c[g >> 2] = 0;
	                        break
	                    }
	                    a:while (1) {
	                        e = c[j >> 2] | 0;
	                        c[j >> 2] = e + -1;
	                        l = c[h >> 2] | 0;
	                        if (!e) {
	                            m = 14;
	                            break
	                        }
	                        c[h >> 2] = l + 1;
	                        e = a[l >> 0] | 0;
	                        a[k >> 0] = e;
	                        if (!(e & 255)) {
	                            m = 7;
	                            break
	                        }
	                        if (!((d[k >> 0] | 0) & 128))continue;
	                        if (((d[k >> 0] | 0) & 192 | 0) != 192) {
	                            m = 10;
	                            break
	                        }
	                        while (1) {
	                            e = (d[k >> 0] | 0) << 1 & 255;
	                            a[k >> 0] = e;
	                            if (!(e & 128))continue a;
	                            e = c[h >> 2] | 0;
	                            c[h >> 2] = e + 1;
	                            if (((d[e >> 0] | 0) & 192 | 0) != 128) {
	                                m = 13;
	                                break a
	                            }
	                        }
	                    }
	                    if ((m | 0) == 7) {
	                        c[g >> 2] = 0;
	                        break
	                    } else if ((m | 0) == 10) {
	                        c[g >> 2] = 0;
	                        break
	                    } else if ((m | 0) == 13) {
	                        c[g >> 2] = 0;
	                        break
	                    } else if ((m | 0) == 14) {
	                        c[g >> 2] = l;
	                        break
	                    }
	                } else c[g >> 2] = 0; while (0);
	                i = f;
	                return c[g >> 2] | 0
	            }

	            function Jy(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                m = f + 20 | 0;
	                c[h >> 2] = b;
	                c[j >> 2] = e;
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    c[g >> 2] = -1;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                c[l >> 2] = Gy(c[j >> 2] | 0, 1) | 0;
	                c[k >> 2] = 0;
	                a:while (1) {
	                    e = a[c[h >> 2] >> 0] | 0;
	                    a[m >> 0] = e;
	                    if (!(e & 255)) {
	                        o = 14;
	                        break
	                    }
	                    if (!(sy(c[h >> 2] | 0, c[j >> 2] | 0, c[l >> 2] | 0) | 0)) {
	                        o = 6;
	                        break
	                    }
	                    c[h >> 2] = (c[h >> 2] | 0) + 1;
	                    b:do if ((d[m >> 0] | 0) & 128) {
	                        if (((d[m >> 0] | 0) & 192 | 0) != 192) {
	                            o = 9;
	                            break a
	                        }
	                        while (1) {
	                            e = (d[m >> 0] | 0) << 1 & 255;
	                            a[m >> 0] = e;
	                            if (!(e & 128))break b;
	                            e = c[h >> 2] | 0;
	                            c[h >> 2] = e + 1;
	                            if (((d[e >> 0] | 0) & 192 | 0) != 128) {
	                                o = 12;
	                                break a
	                            }
	                        }
	                    } while (0);
	                    c[k >> 2] = (c[k >> 2] | 0) + 1
	                }
	                if ((o | 0) == 6) {
	                    c[g >> 2] = c[k >> 2];
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                } else if ((o | 0) == 9) {
	                    c[g >> 2] = -1;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                } else if ((o | 0) == 12) {
	                    c[g >> 2] = -1;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                } else if ((o | 0) == 14) {
	                    c[g >> 2] = -1;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                return 0
	            }

	            function Ky(b, e, f) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 16 | 0;
	                j = g + 12 | 0;
	                k = g + 8 | 0;
	                l = g + 4 | 0;
	                m = g;
	                n = g + 20 | 0;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[l >> 2] = f;
	                do if (c[j >> 2] | 0) {
	                    if ((c[k >> 2] | 0) < 0) {
	                        c[h >> 2] = 0;
	                        break
	                    }
	                    if ((c[l >> 2] | 0) < 0) {
	                        c[h >> 2] = 0;
	                        break
	                    }
	                    c[m >> 2] = 0;
	                    a:while (1) {
	                        o = c[j >> 2] | 0;
	                        if ((c[m >> 2] | 0) >= (c[k >> 2] | 0)) {
	                            p = 18;
	                            break
	                        }
	                        c[j >> 2] = o + 1;
	                        f = a[o >> 0] | 0;
	                        a[n >> 0] = f;
	                        if (!(f & 255)) {
	                            p = 10;
	                            break
	                        }
	                        b:do if ((d[n >> 0] | 0) & 128) {
	                            if (((d[n >> 0] | 0) & 192 | 0) != 192) {
	                                p = 13;
	                                break a
	                            }
	                            while (1) {
	                                f = (d[n >> 0] | 0) << 1 & 255;
	                                a[n >> 0] = f;
	                                if (!(f & 128))break b;
	                                f = c[j >> 2] | 0;
	                                c[j >> 2] = f + 1;
	                                if (((d[f >> 0] | 0) & 192 | 0) != 128) {
	                                    p = 16;
	                                    break a
	                                }
	                            }
	                        } while (0);
	                        c[m >> 2] = (c[m >> 2] | 0) + 1
	                    }
	                    if ((p | 0) == 10) {
	                        c[h >> 2] = 0;
	                        break
	                    } else if ((p | 0) == 13) {
	                        c[h >> 2] = 0;
	                        break
	                    } else if ((p | 0) == 16) {
	                        c[h >> 2] = 0;
	                        break
	                    } else if ((p | 0) == 18) {
	                        c[h >> 2] = Hy(o, c[l >> 2] | 0) | 0;
	                        break
	                    }
	                } else c[h >> 2] = 0; while (0);
	                i = g;
	                return c[h >> 2] | 0
	            }

	            function Ly() {
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = Cb[c[135744 >> 2] & 511](36) | 0;
	                if (!(c[e >> 2] | 0)) {
	                    lz(0, 138944);
	                    c[d >> 2] = 0;
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                }
	                c[(c[e >> 2] | 0) + 4 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 20 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 32 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 28 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 24 >> 2] = c[33950];
	                c[(c[e >> 2] | 0) + 8 >> 2] = c[33950];
	                c[(c[e >> 2] | 0) + 12 >> 2] = c[33948];
	                g = Cb[c[135752 >> 2] & 511](c[(c[e >> 2] | 0) + 24 >> 2] | 0) | 0;
	                c[c[e >> 2] >> 2] = g;
	                g = c[e >> 2] | 0;
	                if (!(c[c[e >> 2] >> 2] | 0)) {
	                    lz(g, 138944);
	                    zb[c[135736 >> 2] & 511](c[e >> 2] | 0);
	                    c[d >> 2] = 0;
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                } else {
	                    a[c[g >> 2] >> 0] = 0;
	                    c[(c[e >> 2] | 0) + 16 >> 2] = 0;
	                    c[d >> 2] = c[e >> 2];
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                }
	                return 0
	            }

	            function My(b) {
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = b;
	                c[g >> 2] = Cb[c[135744 >> 2] & 511](36) | 0;
	                if (!(c[g >> 2] | 0)) {
	                    lz(0, 138944);
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                c[(c[g >> 2] | 0) + 4 >> 2] = 0;
	                c[(c[g >> 2] | 0) + 20 >> 2] = 0;
	                c[(c[g >> 2] | 0) + 32 >> 2] = 0;
	                c[(c[g >> 2] | 0) + 28 >> 2] = 0;
	                c[(c[g >> 2] | 0) + 12 >> 2] = c[33948];
	                if (c[f >> 2] | 0)j = (c[f >> 2] | 0) + 2 | 0; else j = 0;
	                c[(c[g >> 2] | 0) + 24 >> 2] = j;
	                c[(c[g >> 2] | 0) + 8 >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                do if (c[(c[g >> 2] | 0) + 24 >> 2] | 0) {
	                    j = Cb[c[135752 >> 2] & 511](c[(c[g >> 2] | 0) + 24 >> 2] | 0) | 0;
	                    c[c[g >> 2] >> 2] = j;
	                    j = c[g >> 2] | 0;
	                    if (c[c[g >> 2] >> 2] | 0) {
	                        a[c[j >> 2] >> 0] = 0;
	                        break
	                    }
	                    lz(j, 138944);
	                    zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                } else c[c[g >> 2] >> 2] = 0; while (0);
	                c[(c[g >> 2] | 0) + 16 >> 2] = 0;
	                c[e >> 2] = c[g >> 2];
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function Ny(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                do if (c[e >> 2] | 0) {
	                    if ((c[(c[e >> 2] | 0) + 12 >> 2] | 0) == 2) {
	                        c[d >> 2] = 0;
	                        break
	                    }
	                    if (c[(c[e >> 2] | 0) + 28 >> 2] | 0) {
	                        c[d >> 2] = 0;
	                        break
	                    }
	                    if (c[(c[e >> 2] | 0) + 32 >> 2] | 0) {
	                        c[d >> 2] = 0;
	                        break
	                    } else {
	                        c[f >> 2] = c[c[e >> 2] >> 2];
	                        c[c[e >> 2] >> 2] = 0;
	                        c[(c[e >> 2] | 0) + 24 >> 2] = 0;
	                        c[(c[e >> 2] | 0) + 20 >> 2] = 0;
	                        c[(c[e >> 2] | 0) + 4 >> 2] = 0;
	                        c[(c[e >> 2] | 0) + 8 >> 2] = 0;
	                        c[d >> 2] = c[f >> 2];
	                        break
	                    }
	                } else c[d >> 2] = 0; while (0);
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function Oy(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[h >> 2] = Cb[c[135744 >> 2] & 511](36) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    lz(0, 138944);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                if ((c[g >> 2] | 0) >>> 0 < 2147483647) {
	                    c[(c[h >> 2] | 0) + 4 >> 2] = c[g >> 2];
	                    c[(c[h >> 2] | 0) + 8 >> 2] = c[g >> 2]
	                } else {
	                    c[(c[h >> 2] | 0) + 4 >> 2] = 2147483647;
	                    c[(c[h >> 2] | 0) + 8 >> 2] = 2147483647
	                }
	                c[(c[h >> 2] | 0) + 20 >> 2] = c[g >> 2];
	                c[(c[h >> 2] | 0) + 24 >> 2] = c[g >> 2];
	                c[(c[h >> 2] | 0) + 12 >> 2] = 2;
	                c[c[h >> 2] >> 2] = c[f >> 2];
	                c[(c[h >> 2] | 0) + 32 >> 2] = 0;
	                c[(c[h >> 2] | 0) + 28 >> 2] = 0;
	                c[e >> 2] = c[h >> 2];
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function Py(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0))c[d >> 2] = -1; else c[d >> 2] = c[(c[e >> 2] | 0) + 12 >> 2];
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function Qy(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 32 >> 2] | 0) == 0 : 0) {
	                    if ((c[(c[f >> 2] | 0) + 12 >> 2] | 0) != 2 ? (c[(c[f >> 2] | 0) + 12 >> 2] | 0) != 3 : 0) {
	                        b = c[g >> 2] | 0;
	                        if ((c[g >> 2] | 0) == 0 | (c[g >> 2] | 0) == 1 | (c[g >> 2] | 0) == 4 | (c[g >> 2] | 0) == 2) {
	                            c[(c[f >> 2] | 0) + 12 >> 2] = b;
	                            if (c[(c[f >> 2] | 0) + 28 >> 2] | 0)c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 12 >> 2] = c[g >> 2];
	                            c[e >> 2] = 0;
	                            h = c[e >> 2] | 0;
	                            i = d;
	                            return h | 0
	                        } else {
	                            if ((b | 0) == 3) {
	                                c[(c[f >> 2] | 0) + 12 >> 2] = 3;
	                                c[(c[f >> 2] | 0) + 16 >> 2] = c[c[f >> 2] >> 2]
	                            }
	                            c[e >> 2] = -1;
	                            h = c[e >> 2] | 0;
	                            i = d;
	                            return h | 0
	                        }
	                    }
	                    c[e >> 2] = -1;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                c[e >> 2] = -1;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function Ry(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if ((c[(c[d >> 2] | 0) + 12 >> 2] | 0) == 3 ? (c[(c[d >> 2] | 0) + 16 >> 2] | 0) != 0 : 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 16 >> 2] | 0); else e = 5;
	                if (((e | 0) == 5 ? (c[c[d >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[d >> 2] | 0) + 12 >> 2] | 0) != 2 : 0)zb[c[135736 >> 2] & 511](c[c[d >> 2] >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function Sy(b) {
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if (c[(c[e >> 2] | 0) + 32 >> 2] | 0) {
	                    i = d;
	                    return
	                }
	                if (!(c[c[e >> 2] >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if ((c[(c[e >> 2] | 0) + 24 >> 2] | 0) != (c[(c[e >> 2] | 0) + 8 >> 2] | 0) ? (c[(c[e >> 2] | 0) + 8 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[e >> 2] | 0) + 24 >> 2] = c[(c[e >> 2] | 0) + 8 >> 2];
	                if ((c[(c[e >> 2] | 0) + 20 >> 2] | 0) != (c[(c[e >> 2] | 0) + 4 >> 2] | 0) ? (c[(c[e >> 2] | 0) + 4 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[e >> 2] | 0) + 20 >> 2] = c[(c[e >> 2] | 0) + 4 >> 2];
	                c[(c[e >> 2] | 0) + 20 >> 2] = 0;
	                b = c[e >> 2] | 0;
	                do if ((c[(c[e >> 2] | 0) + 12 >> 2] | 0) == 2)c[b >> 2] = 138960; else {
	                    if ((c[b + 12 >> 2] | 0) == 3 ? (c[(c[e >> 2] | 0) + 16 >> 2] | 0) != 0 : 0) {
	                        c[f >> 2] = (c[c[e >> 2] >> 2] | 0) - (c[(c[e >> 2] | 0) + 16 >> 2] | 0);
	                        g = (c[e >> 2] | 0) + 24 | 0;
	                        c[g >> 2] = (c[g >> 2] | 0) + (c[f >> 2] | 0);
	                        c[c[e >> 2] >> 2] = c[(c[e >> 2] | 0) + 16 >> 2];
	                        a[c[c[e >> 2] >> 2] >> 0] = 0;
	                        break
	                    }
	                    a[c[c[e >> 2] >> 2] >> 0] = 0
	                } while (0);
	                f = c[e >> 2] | 0;
	                if ((c[(c[e >> 2] | 0) + 24 >> 2] | 0) >>> 0 < 2147483647)c[(c[e >> 2] | 0) + 8 >> 2] = c[f + 24 >> 2]; else c[f + 8 >> 2] = 2147483647;
	                f = c[e >> 2] | 0;
	                if ((c[(c[e >> 2] | 0) + 20 >> 2] | 0) >>> 0 < 2147483647) {
	                    c[(c[e >> 2] | 0) + 4 >> 2] = c[f + 20 >> 2];
	                    i = d;
	                    return
	                } else {
	                    c[f + 4 >> 2] = 2147483647;
	                    i = d;
	                    return
	                }
	            }

	            function Ty(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 32 >> 2] | 0) == 0 : 0) {
	                    if ((c[(c[g >> 2] | 0) + 24 >> 2] | 0) != (c[(c[g >> 2] | 0) + 8 >> 2] | 0) ? (c[(c[g >> 2] | 0) + 8 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[g >> 2] | 0) + 24 >> 2] = c[(c[g >> 2] | 0) + 8 >> 2];
	                    if ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) != (c[(c[g >> 2] | 0) + 4 >> 2] | 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[g >> 2] | 0) + 20 >> 2] = c[(c[g >> 2] | 0) + 4 >> 2];
	                    if (!(c[h >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        k = c[f >> 2] | 0;
	                        i = e;
	                        return k | 0
	                    }
	                    if ((c[h >> 2] | 0) >>> 0 > (c[(c[g >> 2] | 0) + 20 >> 2] | 0) >>> 0) {
	                        c[f >> 2] = 0;
	                        k = c[f >> 2] | 0;
	                        i = e;
	                        return k | 0
	                    }
	                    d = (c[g >> 2] | 0) + 20 | 0;
	                    c[d >> 2] = (c[d >> 2] | 0) - (c[h >> 2] | 0);
	                    do if ((c[(c[g >> 2] | 0) + 12 >> 2] | 0) == 2)l = 17; else {
	                        if ((c[(c[g >> 2] | 0) + 12 >> 2] | 0) == 3 ? (c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 : 0) {
	                            l = 17;
	                            break
	                        }
	                        fU(c[c[g >> 2] >> 2] | 0, (c[c[g >> 2] >> 2] | 0) + (c[h >> 2] | 0) | 0, c[(c[g >> 2] | 0) + 20 >> 2] | 0) | 0;
	                        a[(c[c[g >> 2] >> 2] | 0) + (c[(c[g >> 2] | 0) + 20 >> 2] | 0) >> 0] = 0
	                    } while (0);
	                    if ((((l | 0) == 17 ? (l = c[g >> 2] | 0, c[l >> 2] = (c[l >> 2] | 0) + (c[h >> 2] | 0), l = (c[g >> 2] | 0) + 24 | 0, c[l >> 2] = (c[l >> 2] | 0) - (c[h >> 2] | 0), (c[(c[g >> 2] | 0) + 12 >> 2] | 0) == 3) : 0) ? (c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 : 0) ? (c[j >> 2] = (c[c[g >> 2] >> 2] | 0) - (c[(c[g >> 2] | 0) + 16 >> 2] | 0), (c[j >> 2] | 0) >>> 0 >= (c[(c[g >> 2] | 0) + 24 >> 2] | 0) >>> 0) : 0) {
	                        fU(c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[c[g >> 2] >> 2] | 0, c[(c[g >> 2] | 0) + 20 >> 2] | 0) | 0;
	                        c[c[g >> 2] >> 2] = c[(c[g >> 2] | 0) + 16 >> 2];
	                        a[(c[c[g >> 2] >> 2] | 0) + (c[(c[g >> 2] | 0) + 20 >> 2] | 0) >> 0] = 0;
	                        l = (c[g >> 2] | 0) + 24 | 0;
	                        c[l >> 2] = (c[l >> 2] | 0) + (c[j >> 2] | 0)
	                    }
	                    j = c[g >> 2] | 0;
	                    if ((c[(c[g >> 2] | 0) + 24 >> 2] | 0) >>> 0 < 2147483647)c[(c[g >> 2] | 0) + 8 >> 2] = c[j + 24 >> 2]; else c[j + 8 >> 2] = 2147483647;
	                    j = c[g >> 2] | 0;
	                    if ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) >>> 0 < 2147483647)c[(c[g >> 2] | 0) + 4 >> 2] = c[j + 20 >> 2]; else c[j + 4 >> 2] = 2147483647;
	                    c[f >> 2] = c[h >> 2];
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                c[f >> 2] = 0;
	                k = c[f >> 2] | 0;
	                i = e;
	                return k | 0
	            }

	            function Uy(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                do if (!((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) < 0)) {
	                    if (!(c[g >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        break
	                    }
	                    c[h >> 2] = mz(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                    if (c[(c[f >> 2] | 0) + 32 >> 2] | 0) {
	                        c[e >> 2] = -1;
	                        break
	                    } else {
	                        c[e >> 2] = c[h >> 2];
	                        break
	                    }
	                } else c[e >> 2] = -1; while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function Vy(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 32 >> 2] | 0) == 0 : 0) {
	                    c[d >> 2] = c[c[e >> 2] >> 2];
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                }
	                c[d >> 2] = 0;
	                f = c[d >> 2] | 0;
	                i = b;
	                return f | 0
	            }

	            function Wy(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 32 >> 2] | 0) == 0 : 0) {
	                    if ((c[(c[e >> 2] | 0) + 24 >> 2] | 0) != (c[(c[e >> 2] | 0) + 8 >> 2] | 0) ? (c[(c[e >> 2] | 0) + 8 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[e >> 2] | 0) + 24 >> 2] = c[(c[e >> 2] | 0) + 8 >> 2];
	                    if ((c[(c[e >> 2] | 0) + 20 >> 2] | 0) != (c[(c[e >> 2] | 0) + 4 >> 2] | 0) ? (c[(c[e >> 2] | 0) + 4 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[e >> 2] | 0) + 20 >> 2] = c[(c[e >> 2] | 0) + 4 >> 2];
	                    c[d >> 2] = (c[c[e >> 2] >> 2] | 0) + (c[(c[e >> 2] | 0) + 20 >> 2] | 0);
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                }
	                c[d >> 2] = 0;
	                f = c[d >> 2] | 0;
	                i = b;
	                return f | 0
	            }

	            function Xy(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 32 >> 2] | 0) == 0 : 0) {
	                    if ((c[(c[g >> 2] | 0) + 24 >> 2] | 0) != (c[(c[g >> 2] | 0) + 8 >> 2] | 0) ? (c[(c[g >> 2] | 0) + 8 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[g >> 2] | 0) + 24 >> 2] = c[(c[g >> 2] | 0) + 8 >> 2];
	                    if ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) != (c[(c[g >> 2] | 0) + 4 >> 2] | 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[g >> 2] | 0) + 20 >> 2] = c[(c[g >> 2] | 0) + 4 >> 2];
	                    if ((c[h >> 2] | 0) >>> 0 > ((c[(c[g >> 2] | 0) + 24 >> 2] | 0) - (c[(c[g >> 2] | 0) + 20 >> 2] | 0) | 0) >>> 0) {
	                        c[f >> 2] = -1;
	                        j = c[f >> 2] | 0;
	                        i = e;
	                        return j | 0
	                    }
	                    d = (c[g >> 2] | 0) + 20 | 0;
	                    c[d >> 2] = (c[d >> 2] | 0) + (c[h >> 2] | 0);
	                    h = c[g >> 2] | 0;
	                    if ((c[(c[g >> 2] | 0) + 24 >> 2] | 0) >>> 0 < 2147483647)c[(c[g >> 2] | 0) + 8 >> 2] = c[h + 24 >> 2]; else c[h + 8 >> 2] = 2147483647;
	                    h = c[g >> 2] | 0;
	                    if ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) >>> 0 < 2147483647)c[(c[g >> 2] | 0) + 4 >> 2] = c[h + 20 >> 2]; else c[h + 4 >> 2] = 2147483647;
	                    if ((c[(c[g >> 2] | 0) + 24 >> 2] | 0) >>> 0 > (c[(c[g >> 2] | 0) + 20 >> 2] | 0) >>> 0) {
	                        a[(c[c[g >> 2] >> 2] | 0) + (c[(c[g >> 2] | 0) + 20 >> 2] | 0) >> 0] = 0;
	                        c[f >> 2] = 0;
	                        j = c[f >> 2] | 0;
	                        i = e;
	                        return j | 0
	                    } else {
	                        c[f >> 2] = -1;
	                        j = c[f >> 2] | 0;
	                        i = e;
	                        return j | 0
	                    }
	                }
	                c[f >> 2] = -1;
	                j = c[f >> 2] | 0;
	                i = e;
	                return j | 0
	            }

	            function Yy(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 32 >> 2] | 0) == 0 : 0) {
	                    if ((c[(c[g >> 2] | 0) + 24 >> 2] | 0) != (c[(c[g >> 2] | 0) + 8 >> 2] | 0) ? (c[(c[g >> 2] | 0) + 8 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[g >> 2] | 0) + 24 >> 2] = c[(c[g >> 2] | 0) + 8 >> 2];
	                    if ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) != (c[(c[g >> 2] | 0) + 4 >> 2] | 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[g >> 2] | 0) + 20 >> 2] = c[(c[g >> 2] | 0) + 4 >> 2];
	                    if ((c[h >> 2] | 0) >>> 0 > (c[(c[g >> 2] | 0) + 20 >> 2] | 0) >>> 0) {
	                        c[f >> 2] = -1;
	                        j = c[f >> 2] | 0;
	                        i = e;
	                        return j | 0
	                    }
	                    d = (c[g >> 2] | 0) + 20 | 0;
	                    c[d >> 2] = (c[d >> 2] | 0) - (c[h >> 2] | 0);
	                    a[(c[c[g >> 2] >> 2] | 0) + (c[(c[g >> 2] | 0) + 20 >> 2] | 0) >> 0] = 0;
	                    h = c[g >> 2] | 0;
	                    if ((c[(c[g >> 2] | 0) + 24 >> 2] | 0) >>> 0 < 2147483647)c[(c[g >> 2] | 0) + 8 >> 2] = c[h + 24 >> 2]; else c[h + 8 >> 2] = 2147483647;
	                    h = c[g >> 2] | 0;
	                    if ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) >>> 0 < 2147483647)c[(c[g >> 2] | 0) + 4 >> 2] = c[h + 20 >> 2]; else c[h + 4 >> 2] = 2147483647;
	                    c[f >> 2] = 0;
	                    j = c[f >> 2] | 0;
	                    i = e;
	                    return j | 0
	                }
	                c[f >> 2] = -1;
	                j = c[f >> 2] | 0;
	                i = e;
	                return j | 0
	            }

	            function Zy(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 32 >> 2] | 0) == 0 : 0) {
	                    if ((c[(c[e >> 2] | 0) + 24 >> 2] | 0) != (c[(c[e >> 2] | 0) + 8 >> 2] | 0) ? (c[(c[e >> 2] | 0) + 8 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[e >> 2] | 0) + 24 >> 2] = c[(c[e >> 2] | 0) + 8 >> 2];
	                    if ((c[(c[e >> 2] | 0) + 20 >> 2] | 0) != (c[(c[e >> 2] | 0) + 4 >> 2] | 0) ? (c[(c[e >> 2] | 0) + 4 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[e >> 2] | 0) + 20 >> 2] = c[(c[e >> 2] | 0) + 4 >> 2];
	                    c[d >> 2] = c[(c[e >> 2] | 0) + 20 >> 2];
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                }
	                c[d >> 2] = 0;
	                f = c[d >> 2] | 0;
	                i = b;
	                return f | 0
	            }

	            function _y(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 32 >> 2] | 0) == 0 : 0) {
	                    if ((c[(c[e >> 2] | 0) + 24 >> 2] | 0) != (c[(c[e >> 2] | 0) + 8 >> 2] | 0) ? (c[(c[e >> 2] | 0) + 8 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[e >> 2] | 0) + 24 >> 2] = c[(c[e >> 2] | 0) + 8 >> 2];
	                    if ((c[(c[e >> 2] | 0) + 20 >> 2] | 0) != (c[(c[e >> 2] | 0) + 4 >> 2] | 0) ? (c[(c[e >> 2] | 0) + 4 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[e >> 2] | 0) + 20 >> 2] = c[(c[e >> 2] | 0) + 4 >> 2];
	                    c[d >> 2] = c[(c[e >> 2] | 0) + 20 >> 2];
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                }
	                c[d >> 2] = 0;
	                f = c[d >> 2] | 0;
	                i = b;
	                return f | 0
	            }

	            function $y(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 32 >> 2] | 0) == 0 : 0) {
	                    if ((c[(c[e >> 2] | 0) + 24 >> 2] | 0) != (c[(c[e >> 2] | 0) + 8 >> 2] | 0) ? (c[(c[e >> 2] | 0) + 8 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[e >> 2] | 0) + 24 >> 2] = c[(c[e >> 2] | 0) + 8 >> 2];
	                    if ((c[(c[e >> 2] | 0) + 20 >> 2] | 0) != (c[(c[e >> 2] | 0) + 4 >> 2] | 0) ? (c[(c[e >> 2] | 0) + 4 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[e >> 2] | 0) + 20 >> 2] = c[(c[e >> 2] | 0) + 4 >> 2];
	                    c[d >> 2] = (c[(c[e >> 2] | 0) + 24 >> 2] | 0) - (c[(c[e >> 2] | 0) + 20 >> 2] | 0);
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                }
	                c[d >> 2] = 0;
	                f = c[d >> 2] | 0;
	                i = b;
	                return f | 0
	            }

	            function az(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 32 >> 2] | 0) == 0 : 0) {
	                    if ((c[(c[e >> 2] | 0) + 24 >> 2] | 0) != (c[(c[e >> 2] | 0) + 8 >> 2] | 0) ? (c[(c[e >> 2] | 0) + 8 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[e >> 2] | 0) + 24 >> 2] = c[(c[e >> 2] | 0) + 8 >> 2];
	                    if ((c[(c[e >> 2] | 0) + 20 >> 2] | 0) != (c[(c[e >> 2] | 0) + 4 >> 2] | 0) ? (c[(c[e >> 2] | 0) + 4 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[e >> 2] | 0) + 20 >> 2] = c[(c[e >> 2] | 0) + 4 >> 2];
	                    c[d >> 2] = (c[(c[e >> 2] | 0) + 20 >> 2] | 0) == 0 & 1;
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                }
	                c[d >> 2] = -1;
	                f = c[d >> 2] | 0;
	                i = b;
	                return f | 0
	            }

	            function bz(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[k >> 2] = 0;
	                if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 32 >> 2] | 0) == 0 : 0) {
	                    if ((c[(c[g >> 2] | 0) + 24 >> 2] | 0) != (c[(c[g >> 2] | 0) + 8 >> 2] | 0) ? (c[(c[g >> 2] | 0) + 8 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[g >> 2] | 0) + 24 >> 2] = c[(c[g >> 2] | 0) + 8 >> 2];
	                    if ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) != (c[(c[g >> 2] | 0) + 4 >> 2] | 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[g >> 2] | 0) + 20 >> 2] = c[(c[g >> 2] | 0) + 4 >> 2];
	                    if ((c[(c[g >> 2] | 0) + 12 >> 2] | 0) == 2) {
	                        c[f >> 2] = 0;
	                        m = c[f >> 2] | 0;
	                        i = e;
	                        return m | 0
	                    }
	                    if ((c[h >> 2] | 0) >>> 0 < (c[(c[g >> 2] | 0) + 24 >> 2] | 0) >>> 0) {
	                        c[f >> 2] = 1;
	                        m = c[f >> 2] | 0;
	                        i = e;
	                        return m | 0
	                    }
	                    d = c[(c[g >> 2] | 0) + 12 >> 2] | 0;
	                    a:do if ((d | 0) == 4) {
	                        if ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) >>> 0 < 4096) {
	                            c[j >> 2] = c[h >> 2];
	                            break
	                        }
	                        c[j >> 2] = c[(c[g >> 2] | 0) + 24 >> 2] << 1;
	                        while (1) {
	                            if ((c[h >> 2] | 0) >>> 0 <= (c[j >> 2] | 0) >>> 0)break a;
	                            if ((c[j >> 2] | 0) >>> 0 > 2147483647)break;
	                            c[j >> 2] = c[j >> 2] << 1
	                        }
	                        lz(c[g >> 2] | 0, 138968);
	                        c[f >> 2] = 0;
	                        m = c[f >> 2] | 0;
	                        i = e;
	                        return m | 0
	                    } else if ((d | 0) == 0 | (d | 0) == 3) {
	                        if (c[(c[g >> 2] | 0) + 24 >> 2] | 0)n = c[(c[g >> 2] | 0) + 24 >> 2] << 1; else n = (c[h >> 2] | 0) + 10 | 0;
	                        c[j >> 2] = n;
	                        while (1) {
	                            if ((c[h >> 2] | 0) >>> 0 <= (c[j >> 2] | 0) >>> 0)break a;
	                            if ((c[j >> 2] | 0) >>> 0 > 2147483647)break;
	                            c[j >> 2] = c[j >> 2] << 1
	                        }
	                        lz(c[g >> 2] | 0, 138968);
	                        c[f >> 2] = 0;
	                        m = c[f >> 2] | 0;
	                        i = e;
	                        return m | 0
	                    } else if ((d | 0) == 1)c[j >> 2] = (c[h >> 2] | 0) + 10; else c[j >> 2] = (c[h >> 2] | 0) + 10; while (0);
	                    do if ((c[(c[g >> 2] | 0) + 12 >> 2] | 0) == 3 ? (c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 : 0) {
	                        c[l >> 2] = (c[c[g >> 2] >> 2] | 0) - (c[(c[g >> 2] | 0) + 16 >> 2] | 0);
	                        if ((c[l >> 2] | 0) >>> 0 > (c[j >> 2] | 0) >>> 0) {
	                            fU(c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[c[g >> 2] >> 2] | 0, c[(c[g >> 2] | 0) + 20 >> 2] | 0) | 0;
	                            c[c[g >> 2] >> 2] = c[(c[g >> 2] | 0) + 16 >> 2];
	                            a[(c[c[g >> 2] >> 2] | 0) + (c[(c[g >> 2] | 0) + 20 >> 2] | 0) >> 0] = 0;
	                            h = (c[g >> 2] | 0) + 24 | 0;
	                            c[h >> 2] = (c[h >> 2] | 0) + (c[l >> 2] | 0);
	                            break
	                        }
	                        c[k >> 2] = Hb[c[135760 >> 2] & 511](c[(c[g >> 2] | 0) + 16 >> 2] | 0, (c[l >> 2] | 0) + (c[j >> 2] | 0) | 0) | 0;
	                        if (c[k >> 2] | 0) {
	                            c[(c[g >> 2] | 0) + 16 >> 2] = c[k >> 2];
	                            c[c[g >> 2] >> 2] = (c[k >> 2] | 0) + (c[l >> 2] | 0);
	                            break
	                        }
	                        lz(c[g >> 2] | 0, 138968);
	                        c[f >> 2] = 0;
	                        m = c[f >> 2] | 0;
	                        i = e;
	                        return m | 0
	                    } else o = 39; while (0);
	                    do if ((o | 0) == 39) {
	                        do if (c[c[g >> 2] >> 2] | 0) {
	                            if (((c[(c[g >> 2] | 0) + 24 >> 2] | 0) - (c[(c[g >> 2] | 0) + 20 >> 2] | 0) | 0) >>> 0 < 100) {
	                                c[k >> 2] = Hb[c[135760 >> 2] & 511](c[c[g >> 2] >> 2] | 0, c[j >> 2] | 0) | 0;
	                                break
	                            }
	                            c[k >> 2] = Cb[c[135752 >> 2] & 511](c[j >> 2] | 0) | 0;
	                            if (c[k >> 2] | 0) {
	                                eU(c[k >> 2] | 0, c[c[g >> 2] >> 2] | 0, c[(c[g >> 2] | 0) + 20 >> 2] | 0) | 0;
	                                zb[c[135736 >> 2] & 511](c[c[g >> 2] >> 2] | 0);
	                                a[(c[k >> 2] | 0) + (c[(c[g >> 2] | 0) + 20 >> 2] | 0) >> 0] = 0
	                            }
	                        } else c[k >> 2] = Cb[c[135752 >> 2] & 511](c[j >> 2] | 0) | 0; while (0);
	                        if (c[k >> 2] | 0) {
	                            c[c[g >> 2] >> 2] = c[k >> 2];
	                            break
	                        }
	                        lz(c[g >> 2] | 0, 138968);
	                        c[f >> 2] = 0;
	                        m = c[f >> 2] | 0;
	                        i = e;
	                        return m | 0
	                    } while (0);
	                    c[(c[g >> 2] | 0) + 24 >> 2] = c[j >> 2];
	                    j = c[g >> 2] | 0;
	                    if ((c[(c[g >> 2] | 0) + 24 >> 2] | 0) >>> 0 < 2147483647)c[(c[g >> 2] | 0) + 8 >> 2] = c[j + 24 >> 2]; else c[j + 8 >> 2] = 2147483647;
	                    j = c[g >> 2] | 0;
	                    if ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) >>> 0 < 2147483647)c[(c[g >> 2] | 0) + 4 >> 2] = c[j + 20 >> 2]; else c[j + 4 >> 2] = 2147483647;
	                    c[f >> 2] = 1;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                c[f >> 2] = 0;
	                m = c[f >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function cz(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                if (!((c[j >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) ? (c[(c[h >> 2] | 0) + 32 >> 2] | 0) == 0 : 0) {
	                    if ((c[(c[h >> 2] | 0) + 24 >> 2] | 0) != (c[(c[h >> 2] | 0) + 8 >> 2] | 0) ? (c[(c[h >> 2] | 0) + 8 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[h >> 2] | 0) + 24 >> 2] = c[(c[h >> 2] | 0) + 8 >> 2];
	                    if ((c[(c[h >> 2] | 0) + 20 >> 2] | 0) != (c[(c[h >> 2] | 0) + 4 >> 2] | 0) ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[h >> 2] | 0) + 20 >> 2] = c[(c[h >> 2] | 0) + 4 >> 2];
	                    if ((c[(c[h >> 2] | 0) + 12 >> 2] | 0) == 2) {
	                        c[g >> 2] = -1;
	                        m = c[g >> 2] | 0;
	                        i = f;
	                        return m | 0
	                    }
	                    if ((c[k >> 2] | 0) < -1) {
	                        c[g >> 2] = -1;
	                        m = c[g >> 2] | 0;
	                        i = f;
	                        return m | 0
	                    }
	                    if (!(c[k >> 2] | 0)) {
	                        c[g >> 2] = 0;
	                        m = c[g >> 2] | 0;
	                        i = f;
	                        return m | 0
	                    }
	                    if ((c[k >> 2] | 0) < 0)c[k >> 2] = xy(c[j >> 2] | 0) | 0;
	                    if ((c[k >> 2] | 0) < 0) {
	                        c[g >> 2] = -1;
	                        m = c[g >> 2] | 0;
	                        i = f;
	                        return m | 0
	                    }
	                    if (!(c[k >> 2] | 0)) {
	                        c[g >> 2] = 0;
	                        m = c[g >> 2] | 0;
	                        i = f;
	                        return m | 0
	                    }
	                    c[l >> 2] = (c[(c[h >> 2] | 0) + 20 >> 2] | 0) + (c[k >> 2] | 0) + 2;
	                    if ((c[l >> 2] | 0) >>> 0 > (c[(c[h >> 2] | 0) + 24 >> 2] | 0) >>> 0 ? (bz(c[h >> 2] | 0, c[l >> 2] | 0) | 0) == 0 : 0) {
	                        lz(c[h >> 2] | 0, 138968);
	                        c[g >> 2] = 2;
	                        m = c[g >> 2] | 0;
	                        i = f;
	                        return m | 0
	                    }
	                    fU((c[c[h >> 2] >> 2] | 0) + (c[(c[h >> 2] | 0) + 20 >> 2] | 0) | 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                    j = (c[h >> 2] | 0) + 20 | 0;
	                    c[j >> 2] = (c[j >> 2] | 0) + (c[k >> 2] | 0);
	                    a[(c[c[h >> 2] >> 2] | 0) + (c[(c[h >> 2] | 0) + 20 >> 2] | 0) >> 0] = 0;
	                    k = c[h >> 2] | 0;
	                    if ((c[(c[h >> 2] | 0) + 24 >> 2] | 0) >>> 0 < 2147483647)c[(c[h >> 2] | 0) + 8 >> 2] = c[k + 24 >> 2]; else c[k + 8 >> 2] = 2147483647;
	                    k = c[h >> 2] | 0;
	                    if ((c[(c[h >> 2] | 0) + 20 >> 2] | 0) >>> 0 < 2147483647)c[(c[h >> 2] | 0) + 4 >> 2] = c[k + 20 >> 2]; else c[k + 4 >> 2] = 2147483647;
	                    c[g >> 2] = 0;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                c[g >> 2] = -1;
	                m = c[g >> 2] | 0;
	                i = f;
	                return m | 0
	            }

	            function dz(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                if ((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 32 >> 2] | 0) == 0 : 0) {
	                    if ((c[(c[h >> 2] | 0) + 24 >> 2] | 0) != (c[(c[h >> 2] | 0) + 8 >> 2] | 0) ? (c[(c[h >> 2] | 0) + 8 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[h >> 2] | 0) + 24 >> 2] = c[(c[h >> 2] | 0) + 8 >> 2];
	                    if ((c[(c[h >> 2] | 0) + 20 >> 2] | 0) != (c[(c[h >> 2] | 0) + 4 >> 2] | 0) ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[h >> 2] | 0) + 20 >> 2] = c[(c[h >> 2] | 0) + 4 >> 2];
	                    if ((c[(c[h >> 2] | 0) + 12 >> 2] | 0) == 2) {
	                        c[g >> 2] = -1;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    if (!(c[j >> 2] | 0)) {
	                        c[g >> 2] = -1;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    if ((c[k >> 2] | 0) < -1) {
	                        c[g >> 2] = -1;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    if (!(c[k >> 2] | 0)) {
	                        c[g >> 2] = 0;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    if ((c[k >> 2] | 0) < 0)c[k >> 2] = xy(c[j >> 2] | 0) | 0;
	                    if ((c[k >> 2] | 0) <= 0) {
	                        c[g >> 2] = -1;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    if (((c[(c[h >> 2] | 0) + 12 >> 2] | 0) == 3 ? (c[(c[h >> 2] | 0) + 16 >> 2] | 0) != 0 : 0) ? (c[m >> 2] = (c[c[h >> 2] >> 2] | 0) - (c[(c[h >> 2] | 0) + 16 >> 2] | 0), (c[m >> 2] | 0) >>> 0 > (c[k >> 2] | 0) >>> 0) : 0) {
	                        m = c[h >> 2] | 0;
	                        c[m >> 2] = (c[m >> 2] | 0) + (0 - (c[k >> 2] | 0));
	                        fU(c[c[h >> 2] >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                        m = (c[h >> 2] | 0) + 20 | 0;
	                        c[m >> 2] = (c[m >> 2] | 0) + (c[k >> 2] | 0);
	                        m = (c[h >> 2] | 0) + 24 | 0;
	                        c[m >> 2] = (c[m >> 2] | 0) + (c[k >> 2] | 0);
	                        m = c[h >> 2] | 0;
	                        if ((c[(c[h >> 2] | 0) + 24 >> 2] | 0) >>> 0 < 2147483647)c[(c[h >> 2] | 0) + 8 >> 2] = c[m + 24 >> 2]; else c[m + 8 >> 2] = 2147483647;
	                        m = c[h >> 2] | 0;
	                        if ((c[(c[h >> 2] | 0) + 20 >> 2] | 0) >>> 0 < 2147483647)c[(c[h >> 2] | 0) + 4 >> 2] = c[m + 20 >> 2]; else c[m + 4 >> 2] = 2147483647;
	                        c[g >> 2] = 0;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    c[l >> 2] = (c[(c[h >> 2] | 0) + 20 >> 2] | 0) + (c[k >> 2] | 0) + 2;
	                    if ((c[l >> 2] | 0) >>> 0 > (c[(c[h >> 2] | 0) + 24 >> 2] | 0) >>> 0 ? (bz(c[h >> 2] | 0, c[l >> 2] | 0) | 0) == 0 : 0) {
	                        lz(c[h >> 2] | 0, 138968);
	                        c[g >> 2] = 2;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    fU((c[c[h >> 2] >> 2] | 0) + (c[k >> 2] | 0) | 0, c[c[h >> 2] >> 2] | 0, c[(c[h >> 2] | 0) + 20 >> 2] | 0) | 0;
	                    fU(c[c[h >> 2] >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                    j = (c[h >> 2] | 0) + 20 | 0;
	                    c[j >> 2] = (c[j >> 2] | 0) + (c[k >> 2] | 0);
	                    a[(c[c[h >> 2] >> 2] | 0) + (c[(c[h >> 2] | 0) + 20 >> 2] | 0) >> 0] = 0;
	                    k = c[h >> 2] | 0;
	                    if ((c[(c[h >> 2] | 0) + 24 >> 2] | 0) >>> 0 < 2147483647)c[(c[h >> 2] | 0) + 8 >> 2] = c[k + 24 >> 2]; else c[k + 8 >> 2] = 2147483647;
	                    k = c[h >> 2] | 0;
	                    if ((c[(c[h >> 2] | 0) + 20 >> 2] | 0) >>> 0 < 2147483647)c[(c[h >> 2] | 0) + 4 >> 2] = c[k + 20 >> 2]; else c[k + 4 >> 2] = 2147483647;
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                c[g >> 2] = -1;
	                n = c[g >> 2] | 0;
	                i = f;
	                return n | 0
	            }

	            function ez(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 32 >> 2] | 0) == 0 : 0) {
	                    if ((c[(c[f >> 2] | 0) + 24 >> 2] | 0) != (c[(c[f >> 2] | 0) + 8 >> 2] | 0) ? (c[(c[f >> 2] | 0) + 8 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[f >> 2] | 0) + 24 >> 2] = c[(c[f >> 2] | 0) + 8 >> 2];
	                    if ((c[(c[f >> 2] | 0) + 20 >> 2] | 0) != (c[(c[f >> 2] | 0) + 4 >> 2] | 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[f >> 2] | 0) + 20 >> 2] = c[(c[f >> 2] | 0) + 4 >> 2];
	                    if ((c[(c[f >> 2] | 0) + 12 >> 2] | 0) == 2) {
	                        c[e >> 2] = -1;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                    if (!(c[g >> 2] | 0)) {
	                        c[e >> 2] = -1;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    } else {
	                        c[e >> 2] = cz(c[f >> 2] | 0, c[g >> 2] | 0, -1) | 0;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                }
	                c[e >> 2] = -1;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function fz(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 32 >> 2] | 0) == 0 : 0) {
	                    if ((c[(c[g >> 2] | 0) + 24 >> 2] | 0) != (c[(c[g >> 2] | 0) + 8 >> 2] | 0) ? (c[(c[g >> 2] | 0) + 8 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[g >> 2] | 0) + 24 >> 2] = c[(c[g >> 2] | 0) + 8 >> 2];
	                    if ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) != (c[(c[g >> 2] | 0) + 4 >> 2] | 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[g >> 2] | 0) + 20 >> 2] = c[(c[g >> 2] | 0) + 4 >> 2];
	                    if ((c[(c[g >> 2] | 0) + 12 >> 2] | 0) == 2) {
	                        c[f >> 2] = -1;
	                        k = c[f >> 2] | 0;
	                        i = e;
	                        return k | 0
	                    }
	                    if (!(c[h >> 2] | 0)) {
	                        c[f >> 2] = -1;
	                        k = c[f >> 2] | 0;
	                        i = e;
	                        return k | 0
	                    }
	                    c[j >> 2] = c[h >> 2];
	                    while (1) {
	                        l = c[(c[g >> 2] | 0) + 20 >> 2] | 0;
	                        if (!(a[c[j >> 2] >> 0] | 0))break;
	                        if ((l + 10 | 0) >>> 0 >= (c[(c[g >> 2] | 0) + 24 >> 2] | 0) >>> 0 ? (bz(c[g >> 2] | 0, (c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 10 | 0) | 0) == 0 : 0) {
	                            m = 18;
	                            break
	                        }
	                        h = a[c[j >> 2] >> 0] | 0;
	                        d = (c[g >> 2] | 0) + 20 | 0;
	                        b = c[d >> 2] | 0;
	                        c[d >> 2] = b + 1;
	                        a[(c[c[g >> 2] >> 2] | 0) + b >> 0] = h;
	                        c[j >> 2] = (c[j >> 2] | 0) + 1
	                    }
	                    if ((m | 0) == 18) {
	                        lz(c[g >> 2] | 0, 138968);
	                        c[f >> 2] = 2;
	                        k = c[f >> 2] | 0;
	                        i = e;
	                        return k | 0
	                    }
	                    a[(c[c[g >> 2] >> 2] | 0) + l >> 0] = 0;
	                    l = c[g >> 2] | 0;
	                    if ((c[(c[g >> 2] | 0) + 24 >> 2] | 0) >>> 0 < 2147483647)c[(c[g >> 2] | 0) + 8 >> 2] = c[l + 24 >> 2]; else c[l + 8 >> 2] = 2147483647;
	                    l = c[g >> 2] | 0;
	                    if ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) >>> 0 < 2147483647)c[(c[g >> 2] | 0) + 4 >> 2] = c[l + 20 >> 2]; else c[l + 4 >> 2] = 2147483647;
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                c[f >> 2] = -1;
	                k = c[f >> 2] | 0;
	                i = e;
	                return k | 0
	            }

	            function gz(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 32 >> 2] | 0) == 0 : 0) {
	                    if ((c[(c[g >> 2] | 0) + 24 >> 2] | 0) != (c[(c[g >> 2] | 0) + 8 >> 2] | 0) ? (c[(c[g >> 2] | 0) + 8 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[g >> 2] | 0) + 24 >> 2] = c[(c[g >> 2] | 0) + 8 >> 2];
	                    if ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) != (c[(c[g >> 2] | 0) + 4 >> 2] | 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[g >> 2] | 0) + 20 >> 2] = c[(c[g >> 2] | 0) + 4 >> 2];
	                    if ((c[(c[g >> 2] | 0) + 12 >> 2] | 0) == 2) {
	                        c[f >> 2] = -1;
	                        l = c[f >> 2] | 0;
	                        i = e;
	                        return l | 0
	                    }
	                    do if (vy(c[h >> 2] | 0, 34) | 0) {
	                        b = (vy(c[h >> 2] | 0, 39) | 0) != 0;
	                        a = c[g >> 2] | 0;
	                        if (!b) {
	                            fz(a, 139e3) | 0;
	                            ez(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                            fz(c[g >> 2] | 0, 139e3) | 0;
	                            break
	                        }
	                        fz(a, 138984) | 0;
	                        a = c[h >> 2] | 0;
	                        c[j >> 2] = a;
	                        c[k >> 2] = a;
	                        while (1) {
	                            if (!(d[c[j >> 2] >> 0] | 0))break;
	                            if ((d[c[j >> 2] >> 0] | 0 | 0) != 34) {
	                                c[j >> 2] = (c[j >> 2] | 0) + 1;
	                                continue
	                            }
	                            if ((c[k >> 2] | 0) != (c[j >> 2] | 0))cz(c[g >> 2] | 0, c[k >> 2] | 0, (c[j >> 2] | 0) - (c[k >> 2] | 0) | 0) | 0;
	                            cz(c[g >> 2] | 0, 138992, 6) | 0;
	                            c[j >> 2] = (c[j >> 2] | 0) + 1;
	                            c[k >> 2] = c[j >> 2]
	                        }
	                        if ((c[k >> 2] | 0) != (c[j >> 2] | 0))cz(c[g >> 2] | 0, c[k >> 2] | 0, (c[j >> 2] | 0) - (c[k >> 2] | 0) | 0) | 0;
	                        fz(c[g >> 2] | 0, 138984) | 0
	                    } else {
	                        fz(c[g >> 2] | 0, 138984) | 0;
	                        ez(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                        fz(c[g >> 2] | 0, 138984) | 0
	                    } while (0);
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[f >> 2] = -1;
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function hz(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 32 >> 2] | 0) == 0 : 0) {
	                    if ((c[(c[f >> 2] | 0) + 24 >> 2] | 0) != (c[(c[f >> 2] | 0) + 8 >> 2] | 0) ? (c[(c[f >> 2] | 0) + 8 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[f >> 2] | 0) + 24 >> 2] = c[(c[f >> 2] | 0) + 8 >> 2];
	                    if ((c[(c[f >> 2] | 0) + 20 >> 2] | 0) != (c[(c[f >> 2] | 0) + 4 >> 2] | 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[f >> 2] | 0) + 20 >> 2] = c[(c[f >> 2] | 0) + 4 >> 2];
	                    if (((c[g >> 2] | 0) != 0 ? (c[c[g >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) >>> 0 > 0 : 0)c[h >> 2] = cz(c[f >> 2] | 0, c[c[g >> 2] >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] | 0) | 0;
	                    lj(c[g >> 2] | 0);
	                    c[e >> 2] = c[h >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                lj(c[g >> 2] | 0);
	                c[e >> 2] = -1;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function iz(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!((c[g >> 2] | 0) == 0 | (c[f >> 2] | 0) == 0) ? (c[(c[f >> 2] | 0) + 32 >> 2] | 0) == 0 : 0) {
	                    if ((c[(c[f >> 2] | 0) + 24 >> 2] | 0) != (c[(c[f >> 2] | 0) + 8 >> 2] | 0) ? (c[(c[f >> 2] | 0) + 8 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[f >> 2] | 0) + 24 >> 2] = c[(c[f >> 2] | 0) + 8 >> 2];
	                    if ((c[(c[f >> 2] | 0) + 20 >> 2] | 0) != (c[(c[f >> 2] | 0) + 4 >> 2] | 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[f >> 2] | 0) + 20 >> 2] = c[(c[f >> 2] | 0) + 4 >> 2];
	                    b = c[c[f >> 2] >> 2] | 0;
	                    c[(c[g >> 2] | 0) + 16 >> 2] = b;
	                    c[(c[g >> 2] | 0) + 12 >> 2] = b;
	                    c[(c[g >> 2] | 0) + 20 >> 2] = (c[c[f >> 2] >> 2] | 0) + (c[(c[f >> 2] | 0) + 20 >> 2] | 0);
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                c[e >> 2] = -1;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function jz(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!((c[g >> 2] | 0) == 0 | (c[f >> 2] | 0) == 0) ? (c[(c[f >> 2] | 0) + 32 >> 2] | 0) == 0 : 0) {
	                    if ((c[(c[f >> 2] | 0) + 24 >> 2] | 0) != (c[(c[f >> 2] | 0) + 8 >> 2] | 0) ? (c[(c[f >> 2] | 0) + 8 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[f >> 2] | 0) + 24 >> 2] = c[(c[f >> 2] | 0) + 8 >> 2];
	                    if ((c[(c[f >> 2] | 0) + 20 >> 2] | 0) != (c[(c[f >> 2] | 0) + 4 >> 2] | 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[f >> 2] | 0) + 20 >> 2] = c[(c[f >> 2] | 0) + 4 >> 2];
	                    c[h >> 2] = (c[(c[g >> 2] | 0) + 12 >> 2] | 0) - (c[c[f >> 2] >> 2] | 0);
	                    if ((c[h >> 2] | 0) >>> 0 > (c[(c[f >> 2] | 0) + 24 >> 2] | 0) >>> 0) {
	                        nz(c[f >> 2] | 0, 139008);
	                        c[h >> 2] = 0
	                    }
	                    c[e >> 2] = c[h >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[e >> 2] = -1;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function kz(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if (!((c[j >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) ? (c[(c[h >> 2] | 0) + 32 >> 2] | 0) == 0 : 0) {
	                    if ((c[(c[h >> 2] | 0) + 24 >> 2] | 0) != (c[(c[h >> 2] | 0) + 8 >> 2] | 0) ? (c[(c[h >> 2] | 0) + 8 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[h >> 2] | 0) + 24 >> 2] = c[(c[h >> 2] | 0) + 8 >> 2];
	                    if ((c[(c[h >> 2] | 0) + 20 >> 2] | 0) != (c[(c[h >> 2] | 0) + 4 >> 2] | 0) ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[h >> 2] | 0) + 20 >> 2] = c[(c[h >> 2] | 0) + 4 >> 2];
	                    c[(c[j >> 2] | 0) + 12 >> 2] = (c[c[h >> 2] >> 2] | 0) + (c[k >> 2] | 0);
	                    c[(c[j >> 2] | 0) + 16 >> 2] = (c[(c[j >> 2] | 0) + 12 >> 2] | 0) + (c[l >> 2] | 0);
	                    c[(c[j >> 2] | 0) + 20 >> 2] = (c[c[h >> 2] >> 2] | 0) + (c[(c[h >> 2] | 0) + 20 >> 2] | 0);
	                    c[g >> 2] = 0;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                c[g >> 2] = -1;
	                m = c[g >> 2] | 0;
	                i = f;
	                return m | 0
	            }

	            function lz(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                ce(29, 2, 0, 0, c[f >> 2] | 0);
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if (c[(c[e >> 2] | 0) + 32 >> 2] | 0) {
	                    i = d;
	                    return
	                }
	                c[(c[e >> 2] | 0) + 32 >> 2] = 2;
	                i = d;
	                return
	            }

	            function mz(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 32 >> 2] | 0) == 0 : 0) {
	                    if ((c[(c[f >> 2] | 0) + 24 >> 2] | 0) != (c[(c[f >> 2] | 0) + 8 >> 2] | 0) ? (c[(c[f >> 2] | 0) + 8 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[f >> 2] | 0) + 24 >> 2] = c[(c[f >> 2] | 0) + 8 >> 2];
	                    if ((c[(c[f >> 2] | 0) + 20 >> 2] | 0) != (c[(c[f >> 2] | 0) + 4 >> 2] | 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) >>> 0 < 2147483647 : 0)c[(c[f >> 2] | 0) + 20 >> 2] = c[(c[f >> 2] | 0) + 4 >> 2];
	                    if ((c[(c[f >> 2] | 0) + 12 >> 2] | 0) == 2) {
	                        c[e >> 2] = 0;
	                        l = c[e >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    }
	                    b = c[(c[f >> 2] | 0) + 24 >> 2] | 0;
	                    if (((c[(c[f >> 2] | 0) + 20 >> 2] | 0) + (c[g >> 2] | 0) | 0) >>> 0 < (c[(c[f >> 2] | 0) + 24 >> 2] | 0) >>> 0) {
	                        c[e >> 2] = b - (c[(c[f >> 2] | 0) + 20 >> 2] | 0);
	                        l = c[e >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    }
	                    a = c[f >> 2] | 0;
	                    if (b >>> 0 > (c[g >> 2] | 0) >>> 0)c[h >> 2] = c[a + 24 >> 2] << 1; else c[h >> 2] = (c[a + 20 >> 2] | 0) + (c[g >> 2] | 0) + 100;
	                    do if ((c[(c[f >> 2] | 0) + 12 >> 2] | 0) == 3 ? (c[(c[f >> 2] | 0) + 16 >> 2] | 0) != 0 : 0) {
	                        c[k >> 2] = (c[c[f >> 2] >> 2] | 0) - (c[(c[f >> 2] | 0) + 16 >> 2] | 0);
	                        c[j >> 2] = Hb[c[135760 >> 2] & 511](c[(c[f >> 2] | 0) + 16 >> 2] | 0, (c[k >> 2] | 0) + (c[h >> 2] | 0) | 0) | 0;
	                        if (c[j >> 2] | 0) {
	                            c[(c[f >> 2] | 0) + 16 >> 2] = c[j >> 2];
	                            c[c[f >> 2] >> 2] = (c[j >> 2] | 0) + (c[k >> 2] | 0);
	                            break
	                        }
	                        lz(c[f >> 2] | 0, 138968);
	                        c[e >> 2] = 0;
	                        l = c[e >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    } else m = 22; while (0);
	                    do if ((m | 0) == 22) {
	                        c[j >> 2] = Hb[c[135760 >> 2] & 511](c[c[f >> 2] >> 2] | 0, c[h >> 2] | 0) | 0;
	                        if (c[j >> 2] | 0) {
	                            c[c[f >> 2] >> 2] = c[j >> 2];
	                            break
	                        }
	                        lz(c[f >> 2] | 0, 138968);
	                        c[e >> 2] = 0;
	                        l = c[e >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    } while (0);
	                    c[(c[f >> 2] | 0) + 24 >> 2] = c[h >> 2];
	                    h = c[f >> 2] | 0;
	                    if ((c[(c[f >> 2] | 0) + 24 >> 2] | 0) >>> 0 < 2147483647)c[(c[f >> 2] | 0) + 8 >> 2] = c[h + 24 >> 2]; else c[h + 8 >> 2] = 2147483647;
	                    h = c[f >> 2] | 0;
	                    if ((c[(c[f >> 2] | 0) + 20 >> 2] | 0) >>> 0 < 2147483647)c[(c[f >> 2] | 0) + 4 >> 2] = c[h + 20 >> 2]; else c[h + 4 >> 2] = 2147483647;
	                    c[e >> 2] = (c[(c[f >> 2] | 0) + 24 >> 2] | 0) - (c[(c[f >> 2] | 0) + 20 >> 2] | 0);
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                c[e >> 2] = 0;
	                l = c[e >> 2] | 0;
	                i = d;
	                return l | 0
	            }

	            function nz(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                ce(29, 7e3, 0, 0, c[f >> 2] | 0);
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if (c[(c[e >> 2] | 0) + 32 >> 2] | 0) {
	                    i = d;
	                    return
	                }
	                c[(c[e >> 2] | 0) + 32 >> 2] = 7e3;
	                i = d;
	                return
	            }

	            function oz(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                if ((c[(c[g >> 2] | 0) + 40 >> 2] | 0) == 0 ? (c[(c[g >> 2] | 0) + 8 >> 2] | 0) == 0 : 0) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[k >> 2] = Cb[c[135744 >> 2] & 511](92) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    Qz(0, 139048);
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                d = (c[k >> 2] | 0) + 0 | 0;
	                b = d + 92 | 0;
	                do {
	                    c[d >> 2] = 0;
	                    d = d + 4 | 0
	                } while ((d | 0) < (b | 0));
	                c[(c[k >> 2] | 0) + 64 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 56 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 4 >> 2] = 1;
	                c[(c[k >> 2] | 0) + 32 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 36 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 40 >> 2] = 0;
	                c[c[k >> 2] >> 2] = 0;
	                c[(c[k >> 2] | 0) + 8 >> 2] = c[g >> 2];
	                if (!(c[(c[g >> 2] | 0) + 40 >> 2] | 0))c[(c[k >> 2] | 0) + 20 >> 2] = c[c[(c[g >> 2] | 0) + 8 >> 2] >> 2];
	                c[(c[k >> 2] | 0) + 24 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 28 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 12 >> 2] = c[h >> 2];
	                c[(c[k >> 2] | 0) + 16 >> 2] = c[j >> 2];
	                do if ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) > 0) {
	                    j = Cb[c[135744 >> 2] & 511](c[(c[g >> 2] | 0) + 20 >> 2] << 2 << 1) | 0;
	                    c[(c[k >> 2] | 0) + 44 >> 2] = j;
	                    if (c[(c[k >> 2] | 0) + 44 >> 2] | 0) {
	                        cU(c[(c[k >> 2] | 0) + 44 >> 2] | 0, 0, c[(c[g >> 2] | 0) + 20 >> 2] << 2 << 1 | 0) | 0;
	                        c[(c[k >> 2] | 0) + 84 >> 2] = (c[(c[k >> 2] | 0) + 44 >> 2] | 0) + (c[(c[g >> 2] | 0) + 20 >> 2] << 2);
	                        break
	                    }
	                    Qz(0, 139048);
	                    zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } else {
	                    c[(c[k >> 2] | 0) + 44 >> 2] = 0;
	                    c[(c[k >> 2] | 0) + 84 >> 2] = 0
	                } while (0);
	                c[(c[k >> 2] | 0) + 48 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 52 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 68 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 72 >> 2] = -1;
	                c[(c[k >> 2] | 0) + 80 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 88 >> 2] = 0;
	                c[f >> 2] = c[k >> 2];
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function pz(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 40 >> 2] | 0) {
	                    a:do if (c[(c[d >> 2] | 0) + 44 >> 2] | 0) {
	                        c[e >> 2] = 0;
	                        while (1) {
	                            if ((c[e >> 2] | 0) >= (c[(c[d >> 2] | 0) + 32 >> 2] | 0))break a;
	                            if (c[(c[(c[d >> 2] | 0) + 40 >> 2] | 0) + (c[e >> 2] << 4) + 12 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[(c[d >> 2] | 0) + 40 >> 2] | 0) + (c[e >> 2] << 4) + 12 >> 2] | 0);
	                            c[e >> 2] = (c[e >> 2] | 0) + 1
	                        }
	                    } while (0);
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 40 >> 2] | 0)
	                }
	                if (c[(c[d >> 2] | 0) + 44 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 44 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 68 >> 2] | 0) {
	                    c[f >> 2] = 0;
	                    while (1) {
	                        if ((c[f >> 2] | 0) >= (c[(c[d >> 2] | 0) + 52 >> 2] | 0))break;
	                        if (c[(c[(c[d >> 2] | 0) + 68 >> 2] | 0) + (c[f >> 2] << 3) >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[(c[d >> 2] | 0) + 68 >> 2] | 0) + (c[f >> 2] << 3) >> 2] | 0);
	                        c[f >> 2] = (c[f >> 2] | 0) + 1
	                    }
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 68 >> 2] | 0)
	                }
	                if (c[(c[d >> 2] | 0) + 80 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 80 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function qz(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                d = Rz(c[f >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0, 0) | 0;
	                i = e;
	                return d | 0
	            }

	            function rz(b, d, e, f) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                g = i;
	                i = i + 192 | 0;
	                h = g + 32 | 0;
	                j = g + 28 | 0;
	                k = g + 24 | 0;
	                l = g + 20 | 0;
	                m = g + 16 | 0;
	                n = g + 36 | 0;
	                o = g + 12 | 0;
	                p = g + 8 | 0;
	                q = g + 4 | 0;
	                r = g;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                if (!(c[j >> 2] | 0)) {
	                    c[h >> 2] = -1;
	                    s = c[h >> 2] | 0;
	                    i = g;
	                    return s | 0
	                }
	                if (!(c[(c[j >> 2] | 0) + 8 >> 2] | 0)) {
	                    c[h >> 2] = -1;
	                    s = c[h >> 2] | 0;
	                    i = g;
	                    return s | 0
	                }
	                if (c[c[j >> 2] >> 2] | 0) {
	                    c[h >> 2] = c[c[j >> 2] >> 2];
	                    s = c[h >> 2] | 0;
	                    i = g;
	                    return s | 0
	                }
	                if (!(c[l >> 2] | 0)) {
	                    c[h >> 2] = qz(c[j >> 2] | 0, c[k >> 2] | 0, c[m >> 2] | 0) | 0;
	                    s = c[h >> 2] | 0;
	                    i = g;
	                    return s | 0
	                }
	                c[o >> 2] = ZT(c[l >> 2] | 0) | 0;
	                c[p >> 2] = ZT(c[k >> 2] | 0) | 0;
	                if (150 < ((c[o >> 2] | 0) + (c[p >> 2] | 0) + 2 | 0)) {
	                    c[r >> 2] = Cb[c[135752 >> 2] & 511]((c[o >> 2] | 0) + (c[p >> 2] | 0) + 2 | 0) | 0;
	                    if (!(c[r >> 2] | 0)) {
	                        c[c[j >> 2] >> 2] = -1;
	                        c[h >> 2] = -1;
	                        s = c[h >> 2] | 0;
	                        i = g;
	                        return s | 0
	                    }
	                } else c[r >> 2] = n;
	                eU(c[r >> 2] | 0, c[k >> 2] | 0, c[p >> 2] | 0) | 0;
	                a[(c[r >> 2] | 0) + (c[p >> 2] | 0) >> 0] = 124;
	                eU((c[r >> 2] | 0) + ((c[p >> 2] | 0) + 1) | 0, c[l >> 2] | 0, c[o >> 2] | 0) | 0;
	                a[(c[r >> 2] | 0) + ((c[o >> 2] | 0) + (c[p >> 2] | 0) + 1) >> 0] = 0;
	                p = c[j >> 2] | 0;
	                if (c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + 40 >> 2] | 0)c[q >> 2] = Sz(p, c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[r >> 2] | 0, c[m >> 2] | 0) | 0; else c[q >> 2] = Rz(p, c[r >> 2] | 0, c[m >> 2] | 0, 1) | 0;
	                if ((c[r >> 2] | 0) != (n | 0))zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                c[h >> 2] = c[q >> 2];
	                s = c[h >> 2] | 0;
	                i = g;
	                return s | 0
	            }

	            function sz(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 16 | 0;
	                j = g + 12 | 0;
	                k = g + 8 | 0;
	                l = g + 4 | 0;
	                m = g;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                f = Tz(c[h >> 2] | 0, 0, c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0) | 0;
	                i = g;
	                return f | 0
	            }

	            function tz(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                h = i;
	                i = i + 32 | 0;
	                j = h + 24 | 0;
	                k = h + 20 | 0;
	                l = h + 16 | 0;
	                m = h + 12 | 0;
	                n = h + 8 | 0;
	                o = h + 4 | 0;
	                p = h;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                if (!(c[k >> 2] | 0)) {
	                    c[j >> 2] = -1;
	                    q = c[j >> 2] | 0;
	                    i = h;
	                    return q | 0
	                }
	                do if (c[l >> 2] | 0)if (c[c[k >> 2] >> 2] | 0) {
	                    c[c[l >> 2] >> 2] = c[(c[k >> 2] | 0) + 80 >> 2];
	                    break
	                } else {
	                    c[c[l >> 2] >> 2] = 0;
	                    break
	                } while (0);
	                c[j >> 2] = Tz(c[k >> 2] | 0, 1, c[m >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0) | 0;
	                q = c[j >> 2] | 0;
	                i = h;
	                return q | 0
	            }

	            function uz(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                g = b + 4 | 0;
	                h = b;
	                c[f >> 2] = a;
	                c[h >> 2] = Uz(c[f >> 2] | 0) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                c[(c[h >> 2] | 0) + 20 >> 2] = 0;
	                f = Vz(c[h >> 2] | 0) | 0;
	                c[(c[h >> 2] | 0) + 24 >> 2] = f;
	                c[(c[h >> 2] | 0) + 16 >> 2] = f;
	                Wz(c[h >> 2] | 0, c[(c[h >> 2] | 0) + 16 >> 2] | 0) | 0;
	                Xz(c[h >> 2] | 0, 1);
	                if (d[c[(c[h >> 2] | 0) + 4 >> 2] >> 0] | 0) {
	                    c[(c[h >> 2] | 0) + 8 >> 2] = 1450;
	                    Yz(c[h >> 2] | 0, 139080)
	                }
	                f = c[h >> 2] | 0;
	                if (c[(c[h >> 2] | 0) + 8 >> 2] | 0) {
	                    Zz(f);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                c[(c[h >> 2] | 0) + 20 >> 2] = c[f + 24 >> 2];
	                c[c[(c[h >> 2] | 0) + 16 >> 2] >> 2] = 1;
	                c[c[(c[h >> 2] | 0) + 20 >> 2] >> 2] = 2;
	                _z(c[h >> 2] | 0);
	                f = c[h >> 2] | 0;
	                if (c[(c[h >> 2] | 0) + 8 >> 2] | 0) {
	                    Zz(f);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = b;
	                    return j | 0
	                } else {
	                    c[g >> 2] = $z(f) | 0;
	                    Zz(c[h >> 2] | 0);
	                    c[e >> 2] = c[g >> 2];
	                    j = c[e >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                return 0
	            }

	            function vz(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = -1;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                } else {
	                    c[e >> 2] = aA(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                return 0
	            }

	            function wz(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 16 | 0;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                g = b + 4 | 0;
	                h = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = -1;
	                    j = c[d >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                if ((c[(c[e >> 2] | 0) + 28 >> 2] | 0) != -1) {
	                    c[d >> 2] = c[(c[e >> 2] | 0) + 28 >> 2];
	                    j = c[d >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                c[f >> 2] = xz() | 0;
	                if (c[(c[f >> 2] | 0) + 52 >> 2] | 0) {
	                    c[h >> 2] = 0;
	                    while (1) {
	                        if ((c[h >> 2] | 0) >= (c[(c[f >> 2] | 0) + 48 >> 2] | 0))break;
	                        bA(c[(c[(c[f >> 2] | 0) + 52 >> 2] | 0) + (c[h >> 2] << 2) >> 2] | 0);
	                        c[h >> 2] = (c[h >> 2] | 0) + 1
	                    }
	                    zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 52 >> 2] | 0)
	                }
	                c[(c[f >> 2] | 0) + 36 >> 2] = c[(c[e >> 2] | 0) + 12 >> 2];
	                c[(c[f >> 2] | 0) + 40 >> 2] = c[(c[e >> 2] | 0) + 16 >> 2];
	                c[(c[f >> 2] | 0) + 48 >> 2] = c[(c[e >> 2] | 0) + 4 >> 2];
	                c[(c[f >> 2] | 0) + 52 >> 2] = c[(c[e >> 2] | 0) + 8 >> 2];
	                c[(c[f >> 2] | 0) + 68 >> 2] = -1;
	                c[(c[f >> 2] | 0) + 76 >> 2] = c[(c[e >> 2] | 0) + 32 >> 2];
	                c[g >> 2] = cA(c[f >> 2] | 0) | 0;
	                c[(c[f >> 2] | 0) + 40 >> 2] = 0;
	                c[(c[f >> 2] | 0) + 52 >> 2] = 0;
	                yz(c[f >> 2] | 0);
	                c[(c[e >> 2] | 0) + 28 >> 2] = c[g >> 2];
	                c[d >> 2] = c[g >> 2];
	                j = c[d >> 2] | 0;
	                i = b;
	                return j | 0
	            }

	            function xz() {
	                var a = 0, b = 0, d = 0, e = 0, f = 0, g = 0;
	                a = i;
	                i = i + 16 | 0;
	                b = a + 4 | 0;
	                d = a;
	                c[d >> 2] = Uz(0) | 0;
	                if (!(c[d >> 2] | 0)) {
	                    c[b >> 2] = 0;
	                    e = c[b >> 2] | 0;
	                    i = a;
	                    return e | 0
	                }
	                c[(c[d >> 2] | 0) + 20 >> 2] = 0;
	                f = Vz(c[d >> 2] | 0) | 0;
	                c[(c[d >> 2] | 0) + 24 >> 2] = f;
	                c[(c[d >> 2] | 0) + 16 >> 2] = f;
	                f = c[d >> 2] | 0;
	                if (!(c[(c[d >> 2] | 0) + 16 >> 2] | 0)) {
	                    yz(f);
	                    c[b >> 2] = 0;
	                    e = c[b >> 2] | 0;
	                    i = a;
	                    return e | 0
	                }
	                c[c[f + 16 >> 2] >> 2] = 1;
	                f = (Wz(c[d >> 2] | 0, c[(c[d >> 2] | 0) + 16 >> 2] | 0) | 0) < 0;
	                g = c[d >> 2] | 0;
	                if (f) {
	                    bA(c[g + 16 >> 2] | 0);
	                    yz(c[d >> 2] | 0);
	                    c[b >> 2] = 0;
	                    e = c[b >> 2] | 0;
	                    i = a;
	                    return e | 0
	                } else {
	                    c[g + 76 >> 2] = 0;
	                    c[b >> 2] = c[d >> 2];
	                    e = c[b >> 2] | 0;
	                    i = a;
	                    return e | 0
	                }
	                return 0
	            }

	            function yz(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                Zz(c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function zz(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[c[d >> 2] >> 2] | 0)zb[c[135736 >> 2] & 511](c[c[d >> 2] >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 8 >> 2] | 0) {
	                    c[e >> 2] = 0;
	                    while (1) {
	                        if ((c[e >> 2] | 0) >= (c[(c[d >> 2] | 0) + 4 >> 2] | 0))break;
	                        bA(c[(c[(c[d >> 2] | 0) + 8 >> 2] | 0) + (c[e >> 2] << 2) >> 2] | 0);
	                        c[e >> 2] = (c[e >> 2] | 0) + 1
	                    }
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 8 >> 2] | 0)
	                }
	                if (c[(c[d >> 2] | 0) + 16 >> 2] | 0) {
	                    c[e >> 2] = 0;
	                    while (1) {
	                        if ((c[e >> 2] | 0) >= (c[(c[d >> 2] | 0) + 12 >> 2] | 0))break;
	                        dA(c[(c[(c[d >> 2] | 0) + 16 >> 2] | 0) + (c[e >> 2] << 2) >> 2] | 0);
	                        c[e >> 2] = (c[e >> 2] | 0) + 1
	                    }
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 16 >> 2] | 0)
	                }
	                if (c[(c[d >> 2] | 0) + 24 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 24 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 40 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 40 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 44 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 44 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 52 >> 2] | 0) {
	                    c[e >> 2] = 0;
	                    while (1) {
	                        f = c[33934] | 0;
	                        if ((c[e >> 2] | 0) >= (c[(c[d >> 2] | 0) + 48 >> 2] | 0))break;
	                        zb[f & 511](c[(c[(c[d >> 2] | 0) + 52 >> 2] | 0) + (c[e >> 2] << 2) >> 2] | 0);
	                        c[e >> 2] = (c[e >> 2] | 0) + 1
	                    }
	                    zb[f & 511](c[(c[d >> 2] | 0) + 52 >> 2] | 0)
	                }
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function Az(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                b = (c[e >> 2] | 0) + 76 | 0;
	                c[b >> 2] = c[b >> 2] | c[f >> 2];
	                i = d;
	                return
	            }

	            function Bz(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0))c[d >> 2] = 0; else c[d >> 2] = c[(c[e >> 2] | 0) + 16 >> 2];
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function Cz(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = -1;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                } else {
	                    c[c[g >> 2] >> 2] = 2;
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                return 0
	            }

	            function Dz(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 24 | 0;
	                j = g + 20 | 0;
	                k = g + 16 | 0;
	                l = g + 12 | 0;
	                m = g + 8 | 0;
	                n = g + 4 | 0;
	                o = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                if ((c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0 | (c[m >> 2] | 0) == 0) {
	                    c[h >> 2] = 0;
	                    p = c[h >> 2] | 0;
	                    i = g;
	                    return p | 0
	                }
	                c[o >> 2] = eA(c[j >> 2] | 0, 5) | 0;
	                if (!(c[o >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    p = c[h >> 2] | 0;
	                    i = g;
	                    return p | 0
	                }
	                c[(c[o >> 2] | 0) + 60 >> 2] = c[n >> 2];
	                n = my(c[m >> 2] | 0) | 0;
	                c[(c[o >> 2] | 0) + 20 >> 2] = n;
	                if ((fA(c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[o >> 2] | 0) | 0) < 0) {
	                    dA(c[o >> 2] | 0);
	                    c[h >> 2] = 0;
	                    p = c[h >> 2] | 0;
	                    i = g;
	                    return p | 0
	                }
	                if (!(c[l >> 2] | 0)) {
	                    c[h >> 2] = c[(c[j >> 2] | 0) + 24 >> 2];
	                    p = c[h >> 2] | 0;
	                    i = g;
	                    return p | 0
	                } else {
	                    c[h >> 2] = c[l >> 2];
	                    p = c[h >> 2] | 0;
	                    i = g;
	                    return p | 0
	                }
	                return 0
	            }

	            function Ez(b, e, f, g, h, j) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                var k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0;
	                k = i;
	                i = i + 48 | 0;
	                l = k + 40 | 0;
	                m = k + 36 | 0;
	                n = k + 32 | 0;
	                o = k + 28 | 0;
	                p = k + 24 | 0;
	                q = k + 20 | 0;
	                r = k + 16 | 0;
	                s = k + 12 | 0;
	                t = k + 8 | 0;
	                u = k + 4 | 0;
	                v = k;
	                c[m >> 2] = b;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                c[q >> 2] = h;
	                c[r >> 2] = j;
	                if ((c[m >> 2] | 0) == 0 | (c[n >> 2] | 0) == 0 | (c[p >> 2] | 0) == 0) {
	                    c[l >> 2] = 0;
	                    w = c[l >> 2] | 0;
	                    i = k;
	                    return w | 0
	                }
	                c[s >> 2] = eA(c[m >> 2] | 0, 5) | 0;
	                if (!(c[s >> 2] | 0)) {
	                    c[l >> 2] = 0;
	                    w = c[l >> 2] | 0;
	                    i = k;
	                    return w | 0
	                }
	                c[(c[s >> 2] | 0) + 60 >> 2] = c[r >> 2];
	                do if ((c[q >> 2] | 0) != 0 ? (d[c[q >> 2] >> 0] | 0 | 0) != 0 : 0) {
	                    c[t >> 2] = ZT(c[q >> 2] | 0) | 0;
	                    c[u >> 2] = ZT(c[p >> 2] | 0) | 0;
	                    c[v >> 2] = Cb[c[135752 >> 2] & 511]((c[t >> 2] | 0) + (c[u >> 2] | 0) + 2 | 0) | 0;
	                    if (c[v >> 2] | 0) {
	                        eU(c[v >> 2] | 0, c[p >> 2] | 0, c[u >> 2] | 0) | 0;
	                        a[(c[v >> 2] | 0) + (c[u >> 2] | 0) >> 0] = 124;
	                        eU((c[v >> 2] | 0) + ((c[u >> 2] | 0) + 1) | 0, c[q >> 2] | 0, c[t >> 2] | 0) | 0;
	                        a[(c[v >> 2] | 0) + ((c[t >> 2] | 0) + (c[u >> 2] | 0) + 1) >> 0] = 0;
	                        c[(c[s >> 2] | 0) + 20 >> 2] = c[v >> 2];
	                        break
	                    }
	                    dA(c[s >> 2] | 0);
	                    c[l >> 2] = 0;
	                    w = c[l >> 2] | 0;
	                    i = k;
	                    return w | 0
	                } else x = 7; while (0);
	                if ((x | 0) == 7) {
	                    x = my(c[p >> 2] | 0) | 0;
	                    c[(c[s >> 2] | 0) + 20 >> 2] = x
	                }
	                if ((fA(c[m >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, c[s >> 2] | 0) | 0) < 0) {
	                    dA(c[s >> 2] | 0);
	                    c[l >> 2] = 0;
	                    w = c[l >> 2] | 0;
	                    i = k;
	                    return w | 0
	                }
	                if (!(c[o >> 2] | 0)) {
	                    c[l >> 2] = c[(c[m >> 2] | 0) + 24 >> 2];
	                    w = c[l >> 2] | 0;
	                    i = k;
	                    return w | 0
	                } else {
	                    c[l >> 2] = c[o >> 2];
	                    w = c[l >> 2] | 0;
	                    i = k;
	                    return w | 0
	                }
	                return 0
	            }

	            function Fz(b, e, f, g, h, j) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                var k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0;
	                k = i;
	                i = i + 256 | 0;
	                l = k;
	                m = k + 44 | 0;
	                n = k + 40 | 0;
	                o = k + 36 | 0;
	                p = k + 32 | 0;
	                q = k + 28 | 0;
	                r = k + 24 | 0;
	                s = k + 20 | 0;
	                t = k + 16 | 0;
	                u = k + 48 | 0;
	                v = k + 12 | 0;
	                w = k + 8 | 0;
	                x = k + 4 | 0;
	                c[n >> 2] = b;
	                c[o >> 2] = e;
	                c[p >> 2] = f;
	                c[q >> 2] = g;
	                c[r >> 2] = h;
	                c[s >> 2] = j;
	                if ((c[n >> 2] | 0) == 0 | (c[o >> 2] | 0) == 0 | (c[q >> 2] | 0) == 0) {
	                    c[m >> 2] = 0;
	                    y = c[m >> 2] | 0;
	                    i = k;
	                    return y | 0
	                }
	                c[t >> 2] = eA(c[n >> 2] | 0, 5) | 0;
	                if (!(c[t >> 2] | 0)) {
	                    c[m >> 2] = 0;
	                    y = c[m >> 2] | 0;
	                    i = k;
	                    return y | 0
	                }
	                c[(c[t >> 2] | 0) + 60 >> 2] = c[s >> 2];
	                c[(c[t >> 2] | 0) + 28 >> 2] = 1;
	                do if ((c[r >> 2] | 0) != 0 ? (d[c[r >> 2] >> 0] | 0 | 0) != 0 : 0) {
	                    c[v >> 2] = ZT(c[r >> 2] | 0) | 0;
	                    c[w >> 2] = ZT(c[q >> 2] | 0) | 0;
	                    c[x >> 2] = Cb[c[135752 >> 2] & 511]((c[v >> 2] | 0) + (c[w >> 2] | 0) + 2 | 0) | 0;
	                    if (c[x >> 2] | 0) {
	                        eU(c[x >> 2] | 0, c[q >> 2] | 0, c[w >> 2] | 0) | 0;
	                        a[(c[x >> 2] | 0) + (c[w >> 2] | 0) >> 0] = 124;
	                        eU((c[x >> 2] | 0) + ((c[w >> 2] | 0) + 1) | 0, c[r >> 2] | 0, c[v >> 2] | 0) | 0;
	                        a[(c[x >> 2] | 0) + ((c[v >> 2] | 0) + (c[w >> 2] | 0) + 1) >> 0] = 0;
	                        c[(c[t >> 2] | 0) + 20 >> 2] = c[x >> 2];
	                        break
	                    }
	                    dA(c[t >> 2] | 0);
	                    c[m >> 2] = 0;
	                    y = c[m >> 2] | 0;
	                    i = k;
	                    return y | 0
	                } else z = 7; while (0);
	                if ((z | 0) == 7) {
	                    z = my(c[q >> 2] | 0) | 0;
	                    c[(c[t >> 2] | 0) + 20 >> 2] = z
	                }
	                c[l >> 2] = c[(c[t >> 2] | 0) + 20 >> 2];
	                JT(u, 199, 139120, l) | 0;
	                a[u + 199 >> 0] = 0;
	                l = my(u) | 0;
	                c[(c[t >> 2] | 0) + 24 >> 2] = l;
	                if ((fA(c[n >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0, c[t >> 2] | 0) | 0) < 0) {
	                    dA(c[t >> 2] | 0);
	                    c[m >> 2] = 0;
	                    y = c[m >> 2] | 0;
	                    i = k;
	                    return y | 0
	                }
	                t = (c[n >> 2] | 0) + 72 | 0;
	                c[t >> 2] = (c[t >> 2] | 0) + 1;
	                if (!(c[p >> 2] | 0)) {
	                    c[m >> 2] = c[(c[n >> 2] | 0) + 24 >> 2];
	                    y = c[m >> 2] | 0;
	                    i = k;
	                    return y | 0
	                } else {
	                    c[m >> 2] = c[p >> 2];
	                    y = c[m >> 2] | 0;
	                    i = k;
	                    return y | 0
	                }
	                return 0
	            }

	            function Gz(b, e, f, g, h, j, k, l) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                k = k | 0;
	                l = l | 0;
	                var m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0;
	                m = i;
	                i = i + 64 | 0;
	                n = m + 52 | 0;
	                o = m + 48 | 0;
	                p = m + 44 | 0;
	                q = m + 40 | 0;
	                r = m + 36 | 0;
	                s = m + 32 | 0;
	                t = m + 28 | 0;
	                u = m + 24 | 0;
	                v = m + 20 | 0;
	                w = m + 16 | 0;
	                x = m + 12 | 0;
	                y = m + 8 | 0;
	                z = m + 4 | 0;
	                A = m;
	                c[o >> 2] = b;
	                c[p >> 2] = e;
	                c[q >> 2] = f;
	                c[r >> 2] = g;
	                c[s >> 2] = h;
	                c[t >> 2] = j;
	                c[u >> 2] = k;
	                c[v >> 2] = l;
	                if ((c[o >> 2] | 0) == 0 | (c[p >> 2] | 0) == 0 | (c[r >> 2] | 0) == 0) {
	                    c[n >> 2] = 0;
	                    B = c[n >> 2] | 0;
	                    i = m;
	                    return B | 0
	                }
	                if ((c[t >> 2] | 0) < 0) {
	                    c[n >> 2] = 0;
	                    B = c[n >> 2] | 0;
	                    i = m;
	                    return B | 0
	                }
	                if ((c[u >> 2] | 0) < 1 ? 1 : (c[u >> 2] | 0) < (c[t >> 2] | 0)) {
	                    c[n >> 2] = 0;
	                    B = c[n >> 2] | 0;
	                    i = m;
	                    return B | 0
	                }
	                c[w >> 2] = eA(c[o >> 2] | 0, 5) | 0;
	                if (!(c[w >> 2] | 0)) {
	                    c[n >> 2] = 0;
	                    B = c[n >> 2] | 0;
	                    i = m;
	                    return B | 0
	                }
	                do if ((c[s >> 2] | 0) != 0 ? (d[c[s >> 2] >> 0] | 0 | 0) != 0 : 0) {
	                    c[y >> 2] = ZT(c[s >> 2] | 0) | 0;
	                    c[z >> 2] = ZT(c[r >> 2] | 0) | 0;
	                    c[A >> 2] = Cb[c[135752 >> 2] & 511]((c[y >> 2] | 0) + (c[z >> 2] | 0) + 2 | 0) | 0;
	                    if (c[A >> 2] | 0) {
	                        eU(c[A >> 2] | 0, c[r >> 2] | 0, c[z >> 2] | 0) | 0;
	                        a[(c[A >> 2] | 0) + (c[z >> 2] | 0) >> 0] = 124;
	                        eU((c[A >> 2] | 0) + ((c[z >> 2] | 0) + 1) | 0, c[s >> 2] | 0, c[y >> 2] | 0) | 0;
	                        a[(c[A >> 2] | 0) + ((c[y >> 2] | 0) + (c[z >> 2] | 0) + 1) >> 0] = 0;
	                        c[(c[w >> 2] | 0) + 20 >> 2] = c[A >> 2];
	                        break
	                    }
	                    dA(c[w >> 2] | 0);
	                    c[n >> 2] = 0;
	                    B = c[n >> 2] | 0;
	                    i = m;
	                    return B | 0
	                } else C = 11; while (0);
	                if ((C | 0) == 11) {
	                    C = my(c[r >> 2] | 0) | 0;
	                    c[(c[w >> 2] | 0) + 20 >> 2] = C
	                }
	                c[(c[w >> 2] | 0) + 60 >> 2] = c[v >> 2];
	                if (!(c[t >> 2] | 0))c[(c[w >> 2] | 0) + 12 >> 2] = 1; else c[(c[w >> 2] | 0) + 12 >> 2] = c[t >> 2];
	                c[(c[w >> 2] | 0) + 16 >> 2] = c[u >> 2];
	                c[x >> 2] = gA(c[o >> 2] | 0) | 0;
	                c[(c[(c[o >> 2] | 0) + 64 >> 2] | 0) + (c[x >> 2] << 3) >> 2] = c[t >> 2];
	                c[(c[(c[o >> 2] | 0) + 64 >> 2] | 0) + (c[x >> 2] << 3) + 4 >> 2] = c[u >> 2];
	                if (!(c[q >> 2] | 0)) {
	                    c[q >> 2] = Vz(c[o >> 2] | 0) | 0;
	                    Wz(c[o >> 2] | 0, c[q >> 2] | 0) | 0
	                }
	                hA(c[o >> 2] | 0, c[p >> 2] | 0, c[w >> 2] | 0, c[q >> 2] | 0, c[x >> 2] | 0, -1);
	                iA(c[o >> 2] | 0, c[w >> 2] | 0) | 0;
	                c[(c[o >> 2] | 0) + 24 >> 2] = c[q >> 2];
	                if (!(c[q >> 2] | 0))c[q >> 2] = c[(c[o >> 2] | 0) + 24 >> 2];
	                if (!(c[q >> 2] | 0)) {
	                    c[n >> 2] = 0;
	                    B = c[n >> 2] | 0;
	                    i = m;
	                    return B | 0
	                }
	                if (!(c[t >> 2] | 0))jA(c[o >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0);
	                c[n >> 2] = c[q >> 2];
	                B = c[n >> 2] | 0;
	                i = m;
	                return B | 0
	            }

	            function Hz(b, e, f, g, h, j, k, l) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                k = k | 0;
	                l = l | 0;
	                var m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0;
	                m = i;
	                i = i + 64 | 0;
	                n = m + 52 | 0;
	                o = m + 48 | 0;
	                p = m + 44 | 0;
	                q = m + 40 | 0;
	                r = m + 36 | 0;
	                s = m + 32 | 0;
	                t = m + 28 | 0;
	                u = m + 24 | 0;
	                v = m + 20 | 0;
	                w = m + 16 | 0;
	                x = m + 12 | 0;
	                y = m + 8 | 0;
	                z = m + 4 | 0;
	                A = m;
	                c[o >> 2] = b;
	                c[p >> 2] = e;
	                c[q >> 2] = f;
	                c[r >> 2] = g;
	                c[s >> 2] = h;
	                c[t >> 2] = j;
	                c[u >> 2] = k;
	                c[v >> 2] = l;
	                if ((c[o >> 2] | 0) == 0 | (c[p >> 2] | 0) == 0 | (c[r >> 2] | 0) == 0) {
	                    c[n >> 2] = 0;
	                    B = c[n >> 2] | 0;
	                    i = m;
	                    return B | 0
	                }
	                if ((c[t >> 2] | 0) < 1) {
	                    c[n >> 2] = 0;
	                    B = c[n >> 2] | 0;
	                    i = m;
	                    return B | 0
	                }
	                if ((c[u >> 2] | 0) < 1 ? 1 : (c[u >> 2] | 0) < (c[t >> 2] | 0)) {
	                    c[n >> 2] = 0;
	                    B = c[n >> 2] | 0;
	                    i = m;
	                    return B | 0
	                }
	                c[w >> 2] = eA(c[o >> 2] | 0, 5) | 0;
	                if (!(c[w >> 2] | 0)) {
	                    c[n >> 2] = 0;
	                    B = c[n >> 2] | 0;
	                    i = m;
	                    return B | 0
	                }
	                do if ((c[s >> 2] | 0) != 0 ? (d[c[s >> 2] >> 0] | 0 | 0) != 0 : 0) {
	                    c[y >> 2] = ZT(c[s >> 2] | 0) | 0;
	                    c[z >> 2] = ZT(c[r >> 2] | 0) | 0;
	                    c[A >> 2] = Cb[c[135752 >> 2] & 511]((c[y >> 2] | 0) + (c[z >> 2] | 0) + 2 | 0) | 0;
	                    if (c[A >> 2] | 0) {
	                        eU(c[A >> 2] | 0, c[r >> 2] | 0, c[z >> 2] | 0) | 0;
	                        a[(c[A >> 2] | 0) + (c[z >> 2] | 0) >> 0] = 124;
	                        eU((c[A >> 2] | 0) + ((c[z >> 2] | 0) + 1) | 0, c[s >> 2] | 0, c[y >> 2] | 0) | 0;
	                        a[(c[A >> 2] | 0) + ((c[y >> 2] | 0) + (c[z >> 2] | 0) + 1) >> 0] = 0;
	                        c[(c[w >> 2] | 0) + 20 >> 2] = c[A >> 2];
	                        break
	                    }
	                    dA(c[w >> 2] | 0);
	                    c[n >> 2] = 0;
	                    B = c[n >> 2] | 0;
	                    i = m;
	                    return B | 0
	                } else C = 11; while (0);
	                if ((C | 0) == 11) {
	                    C = my(c[r >> 2] | 0) | 0;
	                    c[(c[w >> 2] | 0) + 20 >> 2] = C
	                }
	                c[(c[w >> 2] | 0) + 60 >> 2] = c[v >> 2];
	                c[(c[w >> 2] | 0) + 8 >> 2] = 6;
	                c[(c[w >> 2] | 0) + 12 >> 2] = c[t >> 2];
	                c[(c[w >> 2] | 0) + 16 >> 2] = c[u >> 2];
	                c[x >> 2] = gA(c[o >> 2] | 0) | 0;
	                c[(c[(c[o >> 2] | 0) + 64 >> 2] | 0) + (c[x >> 2] << 3) >> 2] = 1;
	                c[(c[(c[o >> 2] | 0) + 64 >> 2] | 0) + (c[x >> 2] << 3) + 4 >> 2] = 1;
	                if (!(c[q >> 2] | 0)) {
	                    c[q >> 2] = Vz(c[o >> 2] | 0) | 0;
	                    Wz(c[o >> 2] | 0, c[q >> 2] | 0) | 0
	                }
	                hA(c[o >> 2] | 0, c[p >> 2] | 0, c[w >> 2] | 0, c[q >> 2] | 0, c[x >> 2] | 0, -1);
	                iA(c[o >> 2] | 0, c[w >> 2] | 0) | 0;
	                c[(c[o >> 2] | 0) + 24 >> 2] = c[q >> 2];
	                c[n >> 2] = c[q >> 2];
	                B = c[n >> 2] | 0;
	                i = m;
	                return B | 0
	            }

	            function Iz(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    c[f >> 2] = Vz(c[e >> 2] | 0) | 0;
	                    Wz(c[e >> 2] | 0, c[f >> 2] | 0) | 0;
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function Jz(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                jA(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0);
	                if (!(c[j >> 2] | 0)) {
	                    c[f >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                } else {
	                    c[f >> 2] = c[j >> 2];
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                return 0
	            }

	            function Kz(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    c[g >> 2] = 0;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                kA(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0);
	                if (!(c[k >> 2] | 0)) {
	                    c[g >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                } else {
	                    c[g >> 2] = c[k >> 2];
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                return 0
	            }

	            function Lz(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = -1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[k >> 2] = gA(c[g >> 2] | 0) | 0;
	                if ((c[k >> 2] | 0) < 0) {
	                    c[f >> 2] = -1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } else {
	                    c[(c[(c[g >> 2] | 0) + 64 >> 2] | 0) + (c[k >> 2] << 3) >> 2] = c[h >> 2];
	                    c[(c[(c[g >> 2] | 0) + 64 >> 2] | 0) + (c[k >> 2] << 3) + 4 >> 2] = c[j >> 2];
	                    c[f >> 2] = c[k >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                return 0
	            }

	            function Mz(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0 | (c[l >> 2] | 0) < 0) {
	                    c[g >> 2] = 0;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                lA(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0);
	                if (!(c[k >> 2] | 0)) {
	                    c[g >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                } else {
	                    c[g >> 2] = c[k >> 2];
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                return 0
	            }

	            function Nz(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0 | (c[l >> 2] | 0) < 0) {
	                    c[g >> 2] = 0;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                mA(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0);
	                if (!(c[k >> 2] | 0)) {
	                    c[g >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                } else {
	                    c[g >> 2] = c[k >> 2];
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                return 0
	            }

	            function Oz(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 8 >> 2] | 0) == 0 : 0) {
	                    _z(c[e >> 2] | 0);
	                    c[f >> 2] = $z(c[e >> 2] | 0) | 0;
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[d >> 2] = 0;
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function Pz(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = -1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    c[f >> 2] = cA(c[e >> 2] | 0) | 0;
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function Qz(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                if (c[f >> 2] | 0) {
	                    c[h >> 2] = c[c[f >> 2] >> 2];
	                    c[(c[f >> 2] | 0) + 8 >> 2] = 2
	                }
	                f = c[g >> 2] | 0;
	                b = c[h >> 2] | 0;
	                c[e >> 2] = c[g >> 2];
	                Xd(0, 0, 0, 0, 0, 14, 2, 3, 0, 0, f, b, 0, 0, 0, 140264, e);
	                i = d;
	                return
	            }

	            function Rz(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0, J = 0, K = 0, L = 0;
	                f = i;
	                i = i + 112 | 0;
	                g = f;
	                h = f + 100 | 0;
	                j = f + 96 | 0;
	                k = f + 92 | 0;
	                l = f + 88 | 0;
	                m = f + 84 | 0;
	                n = f + 80 | 0;
	                p = f + 76 | 0;
	                q = f + 72 | 0;
	                r = f + 68 | 0;
	                s = f + 64 | 0;
	                t = f + 60 | 0;
	                u = f + 56 | 0;
	                v = f + 52 | 0;
	                w = f + 48 | 0;
	                x = f + 44 | 0;
	                y = f + 40 | 0;
	                z = f + 36 | 0;
	                A = f + 32 | 0;
	                B = f + 28 | 0;
	                C = f + 24 | 0;
	                D = f + 20 | 0;
	                E = f + 16 | 0;
	                F = f + 12 | 0;
	                G = f + 8 | 0;
	                H = f + 4 | 0;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[r >> 2] = 0;
	                c[s >> 2] = 1;
	                if (!(c[j >> 2] | 0)) {
	                    c[h >> 2] = -1;
	                    I = c[h >> 2] | 0;
	                    i = f;
	                    return I | 0
	                }
	                if (!(c[(c[j >> 2] | 0) + 8 >> 2] | 0)) {
	                    c[h >> 2] = -1;
	                    I = c[h >> 2] | 0;
	                    i = f;
	                    return I | 0
	                }
	                e = c[j >> 2] | 0;
	                if (c[c[j >> 2] >> 2] | 0) {
	                    c[h >> 2] = c[e >> 2];
	                    I = c[h >> 2] | 0;
	                    i = f;
	                    return I | 0
	                }
	                if (c[(c[e + 8 >> 2] | 0) + 40 >> 2] | 0) {
	                    c[h >> 2] = Sz(c[j >> 2] | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0;
	                    I = c[h >> 2] | 0;
	                    i = f;
	                    return I | 0
	                }
	                do if (!(c[k >> 2] | 0)) {
	                    if ((c[c[(c[j >> 2] | 0) + 20 >> 2] >> 2] | 0) != 2) {
	                        c[r >> 2] = 1;
	                        break
	                    }
	                    c[h >> 2] = 1;
	                    I = c[h >> 2] | 0;
	                    i = f;
	                    return I | 0
	                } while (0);
	                if ((c[k >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 52 >> 2] | 0) > 0 : 0) {
	                    nA(c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0);
	                    c[k >> 2] = c[(c[(c[j >> 2] | 0) + 68 >> 2] | 0) + (c[(c[j >> 2] | 0) + 56 >> 2] << 3) >> 2];
	                    c[l >> 2] = c[(c[(c[j >> 2] | 0) + 68 >> 2] | 0) + (c[(c[j >> 2] | 0) + 56 >> 2] << 3) + 4 >> 2]
	                }
	                a:while (1) {
	                    if (c[c[j >> 2] >> 2] | 0)break;
	                    if (!(c[k >> 2] | 0)) {
	                        if ((c[r >> 2] | 0) != 1)break;
	                        if ((c[c[(c[j >> 2] | 0) + 20 >> 2] >> 2] | 0) == 2)break
	                    }
	                    if (!((c[k >> 2] | 0) == 0 ? (c[(c[j >> 2] | 0) + 44 >> 2] | 0) == 0 : 0))J = 22;
	                    b:do if ((J | 0) == 22) {
	                        J = 0;
	                        c[(c[j >> 2] | 0) + 28 >> 2] = 0;
	                        c:while (1) {
	                            if ((c[(c[j >> 2] | 0) + 24 >> 2] | 0) >= (c[(c[(c[j >> 2] | 0) + 20 >> 2] | 0) + 24 >> 2] | 0))break;
	                            c[n >> 2] = (c[(c[(c[j >> 2] | 0) + 20 >> 2] | 0) + 28 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 24 >> 2] | 0) * 20 | 0);
	                            if ((c[(c[n >> 2] | 0) + 4 >> 2] | 0) >= 0) {
	                                c[p >> 2] = c[c[n >> 2] >> 2];
	                                c[q >> 2] = 0;
	                                d:do if ((c[(c[n >> 2] | 0) + 12 >> 2] | 0) == 1193047) {
	                                    c[q >> 2] = 0;
	                                    if ((c[k >> 2] | 0) == 0 & (c[r >> 2] | 0) != 0) {
	                                        c[q >> 2] = 1;
	                                        break
	                                    }
	                                    if (c[k >> 2] | 0) {
	                                        c[t >> 2] = 0;
	                                        e:while (1) {
	                                            if ((c[t >> 2] | 0) >= (c[(c[(c[j >> 2] | 0) + 20 >> 2] | 0) + 24 >> 2] | 0))break d;
	                                            c[v >> 2] = (c[(c[(c[j >> 2] | 0) + 20 >> 2] | 0) + 28 >> 2] | 0) + ((c[t >> 2] | 0) * 20 | 0);
	                                            do if ((c[(c[v >> 2] | 0) + 8 >> 2] | 0) >= 0) {
	                                                if ((c[v >> 2] | 0) == (c[n >> 2] | 0))break;
	                                                c[w >> 2] = (c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + 24 >> 2] | 0) + (c[(c[v >> 2] | 0) + 8 >> 2] << 3);
	                                                c[u >> 2] = c[(c[(c[j >> 2] | 0) + 44 >> 2] | 0) + (c[(c[v >> 2] | 0) + 8 >> 2] << 2) >> 2];
	                                                do if ((c[u >> 2] | 0) < (c[(c[w >> 2] | 0) + 4 >> 2] | 0)) {
	                                                    if (!(c[c[v >> 2] >> 2] | 0))break;
	                                                    if (qy(c[k >> 2] | 0, c[(c[c[v >> 2] >> 2] | 0) + 20 >> 2] | 0) | 0) {
	                                                        J = 36;
	                                                        break e
	                                                    }
	                                                } while (0);
	                                                if ((c[u >> 2] | 0) < (c[c[w >> 2] >> 2] | 0))break;
	                                                if ((c[u >> 2] | 0) >= (c[(c[w >> 2] | 0) + 4 >> 2] | 0))break;
	                                                if (!(c[c[v >> 2] >> 2] | 0))break;
	                                                if (qy(c[k >> 2] | 0, c[(c[c[v >> 2] >> 2] | 0) + 20 >> 2] | 0) | 0) {
	                                                    J = 41;
	                                                    break e
	                                                }
	                                            } while (0);
	                                            c[t >> 2] = (c[t >> 2] | 0) + 1
	                                        }
	                                        if ((J | 0) == 36) {
	                                            J = 0;
	                                            c[q >> 2] = 0;
	                                            break
	                                        } else if ((J | 0) == 41) {
	                                            J = 0;
	                                            c[q >> 2] = 1;
	                                            break
	                                        }
	                                    }
	                                } else {
	                                    if ((c[(c[n >> 2] | 0) + 12 >> 2] | 0) == 1193046) {
	                                        c[q >> 2] = 1;
	                                        c[x >> 2] = 0;
	                                        f:while (1) {
	                                            if ((c[x >> 2] | 0) >= (c[(c[(c[j >> 2] | 0) + 20 >> 2] | 0) + 24 >> 2] | 0))break d;
	                                            c[z >> 2] = (c[(c[(c[j >> 2] | 0) + 20 >> 2] | 0) + 28 >> 2] | 0) + ((c[x >> 2] | 0) * 20 | 0);
	                                            do if ((c[(c[z >> 2] | 0) + 8 >> 2] | 0) >= 0) {
	                                                if ((c[z >> 2] | 0) == (c[n >> 2] | 0))break;
	                                                c[A >> 2] = (c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + 24 >> 2] | 0) + (c[(c[z >> 2] | 0) + 8 >> 2] << 3);
	                                                c[y >> 2] = c[(c[(c[j >> 2] | 0) + 44 >> 2] | 0) + (c[(c[z >> 2] | 0) + 8 >> 2] << 2) >> 2];
	                                                if ((c[y >> 2] | 0) < (c[c[A >> 2] >> 2] | 0))break f;
	                                                if ((c[y >> 2] | 0) > (c[(c[A >> 2] | 0) + 4 >> 2] | 0))break f
	                                            } while (0);
	                                            c[x >> 2] = (c[x >> 2] | 0) + 1
	                                        }
	                                        c[q >> 2] = 0;
	                                        break
	                                    }
	                                    if ((c[(c[n >> 2] | 0) + 12 >> 2] | 0) >= 0) {
	                                        c[B >> 2] = c[(c[(c[j >> 2] | 0) + 44 >> 2] | 0) + (c[(c[n >> 2] | 0) + 12 >> 2] << 2) >> 2];
	                                        c[C >> 2] = (c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + 24 >> 2] | 0) + (c[(c[n >> 2] | 0) + 12 >> 2] << 3);
	                                        if ((c[B >> 2] | 0) >= (c[c[C >> 2] >> 2] | 0))K = (c[B >> 2] | 0) <= (c[(c[C >> 2] | 0) + 4 >> 2] | 0); else K = 0;
	                                        c[q >> 2] = K & 1;
	                                        break
	                                    }
	                                    if (!(c[p >> 2] | 0)) {
	                                        J = 57;
	                                        break c
	                                    }
	                                    if (!(c[k >> 2] | 0))break;
	                                    c[q >> 2] = oA(c[(c[p >> 2] | 0) + 20 >> 2] | 0, c[k >> 2] | 0) | 0;
	                                    if (c[(c[p >> 2] | 0) + 28 >> 2] | 0) {
	                                        e = ((c[q >> 2] | 0) != 0 ^ 1) & 1;
	                                        c[q >> 2] = e;
	                                        c[q >> 2] = (c[m >> 2] | 0) != 0 ? e : 0
	                                    }
	                                    do if ((c[q >> 2] | 0) == 1) {
	                                        if ((c[(c[n >> 2] | 0) + 8 >> 2] | 0) < 0)break;
	                                        c[E >> 2] = c[(c[(c[j >> 2] | 0) + 44 >> 2] | 0) + (c[(c[n >> 2] | 0) + 8 >> 2] << 2) >> 2];
	                                        c[D >> 2] = (c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + 24 >> 2] | 0) + (c[(c[n >> 2] | 0) + 8 >> 2] << 3);
	                                        if ((c[E >> 2] | 0) < (c[(c[D >> 2] | 0) + 4 >> 2] | 0))break;
	                                        c[q >> 2] = 0
	                                    } while (0);
	                                    if ((c[q >> 2] | 0) != 1)break;
	                                    if ((c[(c[p >> 2] | 0) + 12 >> 2] | 0) <= 0)break;
	                                    if ((c[(c[p >> 2] | 0) + 16 >> 2] | 0) <= 0)break;
	                                    c[F >> 2] = c[(c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + 8 >> 2] | 0) + (c[(c[n >> 2] | 0) + 4 >> 2] << 2) >> 2];
	                                    if ((c[(c[(c[j >> 2] | 0) + 20 >> 2] | 0) + 24 >> 2] | 0) > ((c[(c[j >> 2] | 0) + 24 >> 2] | 0) + 1 | 0)) {
	                                        if ((c[(c[j >> 2] | 0) + 52 >> 2] | 0) <= 0)nA(c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0);
	                                        pA(c[j >> 2] | 0)
	                                    }
	                                    c[(c[j >> 2] | 0) + 28 >> 2] = 1;
	                                    do {
	                                        if ((c[(c[j >> 2] | 0) + 28 >> 2] | 0) == (c[(c[p >> 2] | 0) + 16 >> 2] | 0))break;
	                                        e = (c[j >> 2] | 0) + 56 | 0;
	                                        c[e >> 2] = (c[e >> 2] | 0) + 1;
	                                        c[k >> 2] = c[(c[(c[j >> 2] | 0) + 68 >> 2] | 0) + (c[(c[j >> 2] | 0) + 56 >> 2] << 3) >> 2];
	                                        c[l >> 2] = c[(c[(c[j >> 2] | 0) + 68 >> 2] | 0) + (c[(c[j >> 2] | 0) + 56 >> 2] << 3) + 4 >> 2];
	                                        L = c[j >> 2] | 0;
	                                        if (!(c[k >> 2] | 0)) {
	                                            J = 75;
	                                            break
	                                        }
	                                        if ((c[L + 28 >> 2] | 0) >= (c[(c[p >> 2] | 0) + 12 >> 2] | 0)) {
	                                            c[G >> 2] = c[(c[j >> 2] | 0) + 24 >> 2];
	                                            c[H >> 2] = c[(c[j >> 2] | 0) + 20 >> 2];
	                                            c[(c[j >> 2] | 0) + 24 >> 2] = -1;
	                                            c[(c[j >> 2] | 0) + 20 >> 2] = c[F >> 2];
	                                            if ((c[(c[j >> 2] | 0) + 52 >> 2] | 0) <= 0)nA(c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0);
	                                            pA(c[j >> 2] | 0);
	                                            c[(c[j >> 2] | 0) + 24 >> 2] = c[G >> 2];
	                                            c[(c[j >> 2] | 0) + 20 >> 2] = c[H >> 2]
	                                        }
	                                        c[q >> 2] = qy(c[k >> 2] | 0, c[(c[p >> 2] | 0) + 20 >> 2] | 0) | 0;
	                                        e = (c[j >> 2] | 0) + 28 | 0;
	                                        c[e >> 2] = (c[e >> 2] | 0) + 1
	                                    } while ((c[q >> 2] | 0) == 1);
	                                    if ((J | 0) == 75) {
	                                        J = 0;
	                                        e = L + 56 | 0;
	                                        c[e >> 2] = (c[e >> 2] | 0) + -1
	                                    }
	                                    if ((c[(c[j >> 2] | 0) + 28 >> 2] | 0) < (c[(c[p >> 2] | 0) + 12 >> 2] | 0))c[q >> 2] = 0;
	                                    if ((c[q >> 2] | 0) < 0)c[q >> 2] = 0;
	                                    if (!(c[q >> 2] | 0))break b
	                                } while (0);
	                                if ((c[q >> 2] | 0) == 1) {
	                                    J = 87;
	                                    break
	                                }
	                                if ((c[q >> 2] | 0) < 0) {
	                                    J = 110;
	                                    break
	                                }
	                            }
	                            e = (c[j >> 2] | 0) + 24 | 0;
	                            c[e >> 2] = (c[e >> 2] | 0) + 1
	                        }
	                        if ((J | 0) == 57) {
	                            J = 0;
	                            Ka(c[o >> 2] | 0, 139424, g | 0) | 0;
	                            c[c[j >> 2] >> 2] = -2
	                        } else if ((J | 0) == 87) {
	                            J = 0;
	                            if (((c[p >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) & (c[l >> 2] | 0) != 0)Jb[c[(c[j >> 2] | 0) + 12 >> 2] & 511](c[(c[j >> 2] | 0) + 16 >> 2] | 0, c[(c[p >> 2] | 0) + 20 >> 2] | 0, c[(c[p >> 2] | 0) + 60 >> 2] | 0, c[l >> 2] | 0);
	                            if ((c[(c[(c[j >> 2] | 0) + 20 >> 2] | 0) + 24 >> 2] | 0) > ((c[(c[j >> 2] | 0) + 24 >> 2] | 0) + 1 | 0)) {
	                                if ((c[(c[j >> 2] | 0) + 52 >> 2] | 0) <= 0)nA(c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0);
	                                pA(c[j >> 2] | 0)
	                            }
	                            if ((c[(c[n >> 2] | 0) + 8 >> 2] | 0) >= 0) {
	                                e = (c[(c[j >> 2] | 0) + 44 >> 2] | 0) + (c[(c[n >> 2] | 0) + 8 >> 2] << 2) | 0;
	                                c[e >> 2] = (c[e >> 2] | 0) + 1
	                            }
	                            if ((c[(c[n >> 2] | 0) + 12 >> 2] | 0) >= 0 ? (c[(c[n >> 2] | 0) + 12 >> 2] | 0) < 1193046 : 0)c[(c[(c[j >> 2] | 0) + 44 >> 2] | 0) + (c[(c[n >> 2] | 0) + 12 >> 2] << 2) >> 2] = 0;
	                            if ((c[(c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + 8 >> 2] | 0) + (c[(c[n >> 2] | 0) + 4 >> 2] << 2) >> 2] | 0) != 0 ? (c[c[(c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + 8 >> 2] | 0) + (c[(c[n >> 2] | 0) + 4 >> 2] << 2) >> 2] >> 2] | 0) == 4 : 0) {
	                                if (c[(c[j >> 2] | 0) + 80 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[j >> 2] | 0) + 80 >> 2] | 0);
	                                e = my(c[k >> 2] | 0) | 0;
	                                c[(c[j >> 2] | 0) + 80 >> 2] = e;
	                                c[(c[j >> 2] | 0) + 76 >> 2] = c[(c[j >> 2] | 0) + 20 >> 2];
	                                eU(c[(c[j >> 2] | 0) + 84 >> 2] | 0, c[(c[j >> 2] | 0) + 44 >> 2] | 0, c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + 20 >> 2] << 2 | 0) | 0
	                            }
	                            c[(c[j >> 2] | 0) + 20 >> 2] = c[(c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + 8 >> 2] | 0) + (c[(c[n >> 2] | 0) + 4 >> 2] << 2) >> 2];
	                            c[(c[j >> 2] | 0) + 24 >> 2] = 0;
	                            do if (c[c[n >> 2] >> 2] | 0) {
	                                if (!(c[(c[j >> 2] | 0) + 68 >> 2] | 0)) {
	                                    c[k >> 2] = 0;
	                                    c[l >> 2] = 0;
	                                    break
	                                }
	                                e = (c[j >> 2] | 0) + 56 | 0;
	                                c[e >> 2] = (c[e >> 2] | 0) + 1;
	                                if ((c[(c[j >> 2] | 0) + 56 >> 2] | 0) < (c[(c[j >> 2] | 0) + 52 >> 2] | 0)) {
	                                    c[k >> 2] = c[(c[(c[j >> 2] | 0) + 68 >> 2] | 0) + (c[(c[j >> 2] | 0) + 56 >> 2] << 3) >> 2];
	                                    c[l >> 2] = c[(c[(c[j >> 2] | 0) + 68 >> 2] | 0) + (c[(c[j >> 2] | 0) + 56 >> 2] << 3) + 4 >> 2];
	                                    break
	                                } else {
	                                    c[k >> 2] = 0;
	                                    c[l >> 2] = 0;
	                                    break
	                                }
	                            } while (0);
	                            c[s >> 2] = 1;
	                            continue a
	                        } else if ((J | 0) == 110) {
	                            J = 0;
	                            c[c[j >> 2] >> 2] = -4
	                        }
	                        if ((c[(c[j >> 2] | 0) + 24 >> 2] | 0) == 0 ? (c[(c[(c[j >> 2] | 0) + 20 >> 2] | 0) + 24 >> 2] | 0) != 0 : 0)continue a
	                    } while (0);
	                    if (((c[s >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) ? (c[c[(c[j >> 2] | 0) + 20 >> 2] >> 2] | 0) != 4 : 0) {
	                        c[s >> 2] = 0;
	                        if (c[(c[j >> 2] | 0) + 80 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[j >> 2] | 0) + 80 >> 2] | 0);
	                        e = my(c[k >> 2] | 0) | 0;
	                        c[(c[j >> 2] | 0) + 80 >> 2] = e;
	                        c[(c[j >> 2] | 0) + 76 >> 2] = c[(c[j >> 2] | 0) + 20 >> 2];
	                        eU(c[(c[j >> 2] | 0) + 84 >> 2] | 0, c[(c[j >> 2] | 0) + 44 >> 2] | 0, c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + 20 >> 2] << 2 | 0) | 0
	                    }
	                    c[(c[j >> 2] | 0) + 4 >> 2] = 0;
	                    qA(c[j >> 2] | 0);
	                    if (!(c[(c[j >> 2] | 0) + 68 >> 2] | 0))continue;
	                    if (c[c[j >> 2] >> 2] | 0)continue;
	                    c[k >> 2] = c[(c[(c[j >> 2] | 0) + 68 >> 2] | 0) + (c[(c[j >> 2] | 0) + 56 >> 2] << 3) >> 2];
	                    c[l >> 2] = c[(c[(c[j >> 2] | 0) + 68 >> 2] | 0) + (c[(c[j >> 2] | 0) + 56 >> 2] << 3) + 4 >> 2]
	                }
	                l = c[j >> 2] | 0;
	                if (!(c[c[j >> 2] >> 2] | 0)) {
	                    c[h >> 2] = (c[c[l + 20 >> 2] >> 2] | 0) == 2 & 1;
	                    I = c[h >> 2] | 0;
	                    i = f;
	                    return I | 0
	                } else {
	                    c[h >> 2] = c[l >> 2];
	                    I = c[h >> 2] | 0;
	                    i = f;
	                    return I | 0
	                }
	                return 0
	            }

	            function Sz(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 28 | 0;
	                h = f + 24 | 0;
	                j = f + 20 | 0;
	                k = f + 16 | 0;
	                l = f + 12 | 0;
	                m = f + 8 | 0;
	                n = f + 4 | 0;
	                o = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = c[(c[h >> 2] | 0) + 56 >> 2];
	                if (((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 52 >> 2] | 0) != 0 : 0) {
	                    if (!(c[k >> 2] | 0)) {
	                        e = ca(c[m >> 2] | 0, (c[(c[j >> 2] | 0) + 48 >> 2] | 0) + 1 | 0) | 0;
	                        if ((c[(c[(c[j >> 2] | 0) + 40 >> 2] | 0) + (e << 2) >> 2] | 0) == 2) {
	                            c[g >> 2] = 1;
	                            p = c[g >> 2] | 0;
	                            i = f;
	                            return p | 0
	                        } else {
	                            c[g >> 2] = 0;
	                            p = c[g >> 2] | 0;
	                            i = f;
	                            return p | 0
	                        }
	                    }
	                    c[n >> 2] = 0;
	                    while (1) {
	                        if ((c[n >> 2] | 0) >= (c[(c[j >> 2] | 0) + 48 >> 2] | 0))break;
	                        e = ca(c[m >> 2] | 0, (c[(c[j >> 2] | 0) + 48 >> 2] | 0) + 1 | 0) | 0;
	                        c[o >> 2] = c[(c[(c[j >> 2] | 0) + 40 >> 2] | 0) + (e + (c[n >> 2] | 0) + 1 << 2) >> 2];
	                        if (((c[o >> 2] | 0) > 0 ? (c[o >> 2] | 0) <= (c[(c[j >> 2] | 0) + 36 >> 2] | 0) : 0) ? (c[o >> 2] = (c[o >> 2] | 0) + -1, (oA(c[(c[(c[j >> 2] | 0) + 52 >> 2] | 0) + (c[n >> 2] << 2) >> 2] | 0, c[k >> 2] | 0) | 0) != 0) : 0) {
	                            q = 14;
	                            break
	                        }
	                        c[n >> 2] = (c[n >> 2] | 0) + 1
	                    }
	                    if ((q | 0) == 14) {
	                        c[(c[h >> 2] | 0) + 56 >> 2] = c[o >> 2];
	                        if ((c[(c[h >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 44 >> 2] | 0) != 0 : 0) {
	                            q = ca(c[m >> 2] | 0, c[(c[j >> 2] | 0) + 48 >> 2] | 0) | 0;
	                            Jb[c[(c[h >> 2] | 0) + 12 >> 2] & 511](c[(c[h >> 2] | 0) + 16 >> 2] | 0, c[k >> 2] | 0, c[(c[(c[j >> 2] | 0) + 44 >> 2] | 0) + (q + (c[n >> 2] | 0) << 2) >> 2] | 0, c[l >> 2] | 0)
	                        }
	                        l = ca(c[o >> 2] | 0, (c[(c[j >> 2] | 0) + 48 >> 2] | 0) + 1 | 0) | 0;
	                        if ((c[(c[(c[j >> 2] | 0) + 40 >> 2] | 0) + (l << 2) >> 2] | 0) != 4) {
	                            l = ca(c[o >> 2] | 0, (c[(c[j >> 2] | 0) + 48 >> 2] | 0) + 1 | 0) | 0;
	                            if ((c[(c[(c[j >> 2] | 0) + 40 >> 2] | 0) + (l << 2) >> 2] | 0) == 2) {
	                                c[g >> 2] = 1;
	                                p = c[g >> 2] | 0;
	                                i = f;
	                                return p | 0
	                            } else {
	                                c[g >> 2] = 0;
	                                p = c[g >> 2] | 0;
	                                i = f;
	                                return p | 0
	                            }
	                        }
	                    }
	                    if (c[(c[h >> 2] | 0) + 80 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[h >> 2] | 0) + 80 >> 2] | 0);
	                    l = my(c[k >> 2] | 0) | 0;
	                    c[(c[h >> 2] | 0) + 80 >> 2] = l;
	                    c[(c[h >> 2] | 0) + 72 >> 2] = c[m >> 2];
	                    c[c[h >> 2] >> 2] = -1;
	                    c[g >> 2] = -1;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                c[g >> 2] = -1;
	                p = c[g >> 2] | 0;
	                i = f;
	                return p | 0
	            }

	            function Tz(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0;
	                h = i;
	                i = i + 96 | 0;
	                j = h;
	                k = h + 80 | 0;
	                l = h + 76 | 0;
	                m = h + 72 | 0;
	                n = h + 68 | 0;
	                o = h + 64 | 0;
	                p = h + 60 | 0;
	                q = h + 56 | 0;
	                r = h + 52 | 0;
	                s = h + 48 | 0;
	                t = h + 44 | 0;
	                u = h + 40 | 0;
	                v = h + 36 | 0;
	                w = h + 32 | 0;
	                x = h + 28 | 0;
	                y = h + 24 | 0;
	                z = h + 20 | 0;
	                A = h + 16 | 0;
	                B = h + 12 | 0;
	                C = h + 8 | 0;
	                c[l >> 2] = a;
	                c[m >> 2] = b;
	                c[n >> 2] = d;
	                c[o >> 2] = e;
	                c[p >> 2] = f;
	                c[q >> 2] = g;
	                c[s >> 2] = 0;
	                if (!((c[l >> 2] | 0) == 0 | (c[n >> 2] | 0) == 0 | (c[o >> 2] | 0) == 0 | (c[p >> 2] | 0) == 0) ? (c[c[n >> 2] >> 2] | 0) > 0 : 0) {
	                    c[r >> 2] = c[c[n >> 2] >> 2];
	                    c[c[n >> 2] >> 2] = 0;
	                    c[c[o >> 2] >> 2] = 0;
	                    a:do if ((c[(c[l >> 2] | 0) + 8 >> 2] | 0) != 0 ? (c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) {
	                        c[t >> 2] = c[(c[l >> 2] | 0) + 8 >> 2];
	                        g = c[l >> 2] | 0;
	                        do if (c[m >> 2] | 0) {
	                            if ((c[g + 72 >> 2] | 0) != -1) {
	                                c[w >> 2] = c[(c[l >> 2] | 0) + 72 >> 2];
	                                break
	                            }
	                            c[k >> 2] = -1;
	                            D = c[k >> 2] | 0;
	                            i = h;
	                            return D | 0
	                        } else c[w >> 2] = c[g + 56 >> 2]; while (0);
	                        do if (c[q >> 2] | 0) {
	                            g = ca(c[w >> 2] | 0, (c[(c[t >> 2] | 0) + 48 >> 2] | 0) + 1 | 0) | 0;
	                            f = c[q >> 2] | 0;
	                            if ((c[(c[(c[t >> 2] | 0) + 40 >> 2] | 0) + (g << 2) >> 2] | 0) == 2) {
	                                c[f >> 2] = 1;
	                                break
	                            } else {
	                                c[f >> 2] = 0;
	                                break
	                            }
	                        } while (0);
	                        c[v >> 2] = 0;
	                        while (1) {
	                            if ((c[v >> 2] | 0) >= (c[(c[t >> 2] | 0) + 48 >> 2] | 0))break;
	                            if ((c[s >> 2] | 0) >= (c[r >> 2] | 0))break;
	                            f = ca(c[w >> 2] | 0, (c[(c[t >> 2] | 0) + 48 >> 2] | 0) + 1 | 0) | 0;
	                            c[u >> 2] = c[(c[(c[t >> 2] | 0) + 40 >> 2] | 0) + (f + (c[v >> 2] | 0) + 1 << 2) >> 2];
	                            if (((c[u >> 2] | 0) > 0 ? (c[u >> 2] | 0) <= (c[(c[t >> 2] | 0) + 36 >> 2] | 0) : 0) ? (f = ca((c[u >> 2] | 0) - 1 | 0, (c[(c[t >> 2] | 0) + 48 >> 2] | 0) + 1 | 0) | 0, (c[(c[(c[t >> 2] | 0) + 40 >> 2] | 0) + (f << 2) >> 2] | 0) != 4) : 0) {
	                                f = c[(c[(c[t >> 2] | 0) + 52 >> 2] | 0) + (c[v >> 2] << 2) >> 2] | 0;
	                                g = c[s >> 2] | 0;
	                                c[s >> 2] = g + 1;
	                                c[(c[p >> 2] | 0) + (g << 2) >> 2] = f;
	                                f = c[n >> 2] | 0;
	                                c[f >> 2] = (c[f >> 2] | 0) + 1
	                            }
	                            c[v >> 2] = (c[v >> 2] | 0) + 1
	                        }
	                        c[v >> 2] = 0;
	                        while (1) {
	                            if ((c[v >> 2] | 0) >= (c[(c[t >> 2] | 0) + 48 >> 2] | 0))break a;
	                            if ((c[s >> 2] | 0) >= (c[r >> 2] | 0))break a;
	                            f = ca(c[w >> 2] | 0, (c[(c[t >> 2] | 0) + 48 >> 2] | 0) + 1 | 0) | 0;
	                            c[u >> 2] = c[(c[(c[t >> 2] | 0) + 40 >> 2] | 0) + (f + (c[v >> 2] | 0) + 1 << 2) >> 2];
	                            if (((c[u >> 2] | 0) > 0 ? (c[u >> 2] | 0) <= (c[(c[t >> 2] | 0) + 36 >> 2] | 0) : 0) ? (f = ca((c[u >> 2] | 0) - 1 | 0, (c[(c[t >> 2] | 0) + 48 >> 2] | 0) + 1 | 0) | 0, (c[(c[(c[t >> 2] | 0) + 40 >> 2] | 0) + (f << 2) >> 2] | 0) == 4) : 0) {
	                                f = c[(c[(c[t >> 2] | 0) + 52 >> 2] | 0) + (c[v >> 2] << 2) >> 2] | 0;
	                                g = c[s >> 2] | 0;
	                                c[s >> 2] = g + 1;
	                                c[(c[p >> 2] | 0) + (g << 2) >> 2] = f;
	                                f = c[o >> 2] | 0;
	                                c[f >> 2] = (c[f >> 2] | 0) + 1
	                            }
	                            c[v >> 2] = (c[v >> 2] | 0) + 1
	                        }
	                    } else E = 31; while (0);
	                    b:do if ((E | 0) == 31) {
	                        do if (c[q >> 2] | 0) {
	                            v = c[q >> 2] | 0;
	                            if ((c[c[(c[l >> 2] | 0) + 20 >> 2] >> 2] | 0) == 2) {
	                                c[v >> 2] = 1;
	                                break
	                            } else {
	                                c[v >> 2] = 0;
	                                break
	                            }
	                        } while (0);
	                        v = c[l >> 2] | 0;
	                        do if (c[m >> 2] | 0) {
	                            if (c[v + 76 >> 2] | 0) {
	                                c[A >> 2] = c[(c[l >> 2] | 0) + 76 >> 2];
	                                break
	                            }
	                            c[k >> 2] = -1;
	                            D = c[k >> 2] | 0;
	                            i = h;
	                            return D | 0
	                        } else {
	                            if (c[v + 20 >> 2] | 0) {
	                                c[A >> 2] = c[(c[l >> 2] | 0) + 20 >> 2];
	                                break
	                            }
	                            c[k >> 2] = -1;
	                            D = c[k >> 2] | 0;
	                            i = h;
	                            return D | 0
	                        } while (0);
	                        c[x >> 2] = 0;
	                        while (1) {
	                            if ((c[x >> 2] | 0) >= (c[(c[A >> 2] | 0) + 24 >> 2] | 0))break;
	                            if ((c[s >> 2] | 0) >= (c[r >> 2] | 0))break;
	                            c[y >> 2] = (c[(c[A >> 2] | 0) + 28 >> 2] | 0) + ((c[x >> 2] | 0) * 20 | 0);
	                            do if (((c[(c[y >> 2] | 0) + 4 >> 2] | 0) >= 0 ? (c[z >> 2] = c[c[y >> 2] >> 2], (c[z >> 2] | 0) != 0) : 0) ? (c[(c[z >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) {
	                                if ((c[(c[y >> 2] | 0) + 12 >> 2] | 0) == 1193047) {
	                                    v = c[33976] | 0;
	                                    t = c[33980] | 0;
	                                    c[j >> 2] = 140216;
	                                    c[j + 4 >> 2] = 4289;
	                                    Db[v & 511](t, 140184, j);
	                                    break
	                                }
	                                if ((c[(c[y >> 2] | 0) + 12 >> 2] | 0) == 1193046) {
	                                    t = c[33976] | 0;
	                                    v = c[33980] | 0;
	                                    c[j >> 2] = 140216;
	                                    c[j + 4 >> 2] = 4292;
	                                    Db[t & 511](v, 140184, j);
	                                    break
	                                }
	                                if ((c[(c[y >> 2] | 0) + 8 >> 2] | 0) < 0) {
	                                    if (!(c[(c[l >> 2] | 0) + 8 >> 2] | 0))break;
	                                    if (!(c[(c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 8 >> 2] | 0) + (c[(c[y >> 2] | 0) + 4 >> 2] << 2) >> 2] | 0))break;
	                                    if ((c[c[(c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 8 >> 2] | 0) + (c[(c[y >> 2] | 0) + 4 >> 2] << 2) >> 2] >> 2] | 0) == 4)break;
	                                    v = c[z >> 2] | 0;
	                                    if (c[(c[z >> 2] | 0) + 28 >> 2] | 0) {
	                                        t = c[v + 24 >> 2] | 0;
	                                        u = c[s >> 2] | 0;
	                                        c[s >> 2] = u + 1;
	                                        c[(c[p >> 2] | 0) + (u << 2) >> 2] = t
	                                    } else {
	                                        t = c[v + 20 >> 2] | 0;
	                                        v = c[s >> 2] | 0;
	                                        c[s >> 2] = v + 1;
	                                        c[(c[p >> 2] | 0) + (v << 2) >> 2] = t
	                                    }
	                                    t = c[n >> 2] | 0;
	                                    c[t >> 2] = (c[t >> 2] | 0) + 1;
	                                    break
	                                }
	                                c[B >> 2] = 0;
	                                t = c[(c[y >> 2] | 0) + 8 >> 2] | 0;
	                                v = c[l >> 2] | 0;
	                                if (c[m >> 2] | 0)c[C >> 2] = c[(c[v + 84 >> 2] | 0) + (t << 2) >> 2]; else c[C >> 2] = c[(c[v + 44 >> 2] | 0) + (t << 2) >> 2];
	                                if (c[(c[l >> 2] | 0) + 8 >> 2] | 0)c[B >> 2] = (c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 24 >> 2] | 0) + (c[(c[y >> 2] | 0) + 8 >> 2] << 3);
	                                if ((c[B >> 2] | 0) != 0 ? (c[C >> 2] | 0) >= (c[(c[B >> 2] | 0) + 4 >> 2] | 0) : 0)break;
	                                t = c[z >> 2] | 0;
	                                if (c[(c[z >> 2] | 0) + 28 >> 2] | 0) {
	                                    v = c[t + 24 >> 2] | 0;
	                                    u = c[s >> 2] | 0;
	                                    c[s >> 2] = u + 1;
	                                    c[(c[p >> 2] | 0) + (u << 2) >> 2] = v
	                                } else {
	                                    v = c[t + 20 >> 2] | 0;
	                                    t = c[s >> 2] | 0;
	                                    c[s >> 2] = t + 1;
	                                    c[(c[p >> 2] | 0) + (t << 2) >> 2] = v
	                                }
	                                v = c[n >> 2] | 0;
	                                c[v >> 2] = (c[v >> 2] | 0) + 1
	                            } while (0);
	                            c[x >> 2] = (c[x >> 2] | 0) + 1
	                        }
	                        c[x >> 2] = 0;
	                        while (1) {
	                            if ((c[x >> 2] | 0) >= (c[(c[A >> 2] | 0) + 24 >> 2] | 0))break b;
	                            if ((c[s >> 2] | 0) >= (c[r >> 2] | 0))break b;
	                            c[y >> 2] = (c[(c[A >> 2] | 0) + 28 >> 2] | 0) + ((c[x >> 2] | 0) * 20 | 0);
	                            if ((((((((c[(c[y >> 2] | 0) + 4 >> 2] | 0) >= 0 ? (c[z >> 2] = c[c[y >> 2] >> 2], (c[z >> 2] | 0) != 0) : 0) ? (c[(c[z >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) ? (c[(c[y >> 2] | 0) + 12 >> 2] | 0) != 1193047 : 0) ? (c[(c[y >> 2] | 0) + 12 >> 2] | 0) != 1193046 : 0) ? (c[(c[y >> 2] | 0) + 8 >> 2] | 0) < 0 : 0) ? (c[(c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 8 >> 2] | 0) + (c[(c[y >> 2] | 0) + 4 >> 2] << 2) >> 2] | 0) != 0 : 0) ? (c[c[(c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 8 >> 2] | 0) + (c[(c[y >> 2] | 0) + 4 >> 2] << 2) >> 2] >> 2] | 0) == 4 : 0) {
	                                v = c[z >> 2] | 0;
	                                if (c[(c[z >> 2] | 0) + 28 >> 2] | 0) {
	                                    t = c[v + 24 >> 2] | 0;
	                                    u = c[s >> 2] | 0;
	                                    c[s >> 2] = u + 1;
	                                    c[(c[p >> 2] | 0) + (u << 2) >> 2] = t
	                                } else {
	                                    t = c[v + 20 >> 2] | 0;
	                                    v = c[s >> 2] | 0;
	                                    c[s >> 2] = v + 1;
	                                    c[(c[p >> 2] | 0) + (v << 2) >> 2] = t
	                                }
	                                t = c[o >> 2] | 0;
	                                c[t >> 2] = (c[t >> 2] | 0) + 1
	                            }
	                            c[x >> 2] = (c[x >> 2] | 0) + 1
	                        }
	                    } while (0);
	                    c[k >> 2] = 0;
	                    D = c[k >> 2] | 0;
	                    i = h;
	                    return D | 0
	                }
	                c[k >> 2] = -1;
	                D = c[k >> 2] | 0;
	                i = h;
	                return D | 0
	            }

	            function Uz(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](80) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = (c[f >> 2] | 0) + 0 | 0;
	                h = a + 80 | 0;
	                do {
	                    c[a >> 2] = 0;
	                    a = a + 4 | 0
	                } while ((a | 0) < (h | 0));
	                if (c[e >> 2] | 0) {
	                    a = my(c[e >> 2] | 0) | 0;
	                    c[c[f >> 2] >> 2] = a
	                }
	                c[(c[f >> 2] | 0) + 4 >> 2] = c[c[f >> 2] >> 2];
	                c[(c[f >> 2] | 0) + 12 >> 2] = 0;
	                c[(c[f >> 2] | 0) + 72 >> 2] = 0;
	                c[(c[f >> 2] | 0) + 8 >> 2] = 0;
	                c[(c[f >> 2] | 0) + 68 >> 2] = -1;
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function Vz(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](44) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    Qz(c[e >> 2] | 0, 140160);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    e = (c[f >> 2] | 0) + 0 | 0;
	                    a = e + 44 | 0;
	                    do {
	                        c[e >> 2] = 0;
	                        e = e + 4 | 0
	                    } while ((e | 0) < (a | 0));
	                    c[c[f >> 2] >> 2] = 3;
	                    c[(c[f >> 2] | 0) + 4 >> 2] = 0;
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function Wz(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                b = c[f >> 2] | 0;
	                do if (!(c[(c[f >> 2] | 0) + 44 >> 2] | 0)) {
	                    c[b + 44 >> 2] = 4;
	                    a = Cb[c[135744 >> 2] & 511](c[(c[f >> 2] | 0) + 44 >> 2] << 2) | 0;
	                    c[(c[f >> 2] | 0) + 52 >> 2] = a;
	                    if (!(c[(c[f >> 2] | 0) + 52 >> 2] | 0)) {
	                        Qz(c[f >> 2] | 0, 140144);
	                        c[(c[f >> 2] | 0) + 44 >> 2] = 0;
	                        c[e >> 2] = -1;
	                        j = c[e >> 2] | 0;
	                        i = d;
	                        return j | 0
	                    }
	                } else if ((c[b + 48 >> 2] | 0) >= (c[(c[f >> 2] | 0) + 44 >> 2] | 0)) {
	                    a = (c[f >> 2] | 0) + 44 | 0;
	                    c[a >> 2] = c[a >> 2] << 1;
	                    c[h >> 2] = Hb[c[135760 >> 2] & 511](c[(c[f >> 2] | 0) + 52 >> 2] | 0, c[(c[f >> 2] | 0) + 44 >> 2] << 2) | 0;
	                    if (c[h >> 2] | 0) {
	                        c[(c[f >> 2] | 0) + 52 >> 2] = c[h >> 2];
	                        break
	                    }
	                    Qz(c[f >> 2] | 0, 140144);
	                    a = (c[f >> 2] | 0) + 44 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) / 2 | 0;
	                    c[e >> 2] = -1;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } while (0);
	                c[(c[g >> 2] | 0) + 16 >> 2] = c[(c[f >> 2] | 0) + 48 >> 2];
	                h = c[g >> 2] | 0;
	                g = (c[f >> 2] | 0) + 48 | 0;
	                b = c[g >> 2] | 0;
	                c[g >> 2] = b + 1;
	                c[(c[(c[f >> 2] | 0) + 52 >> 2] | 0) + (b << 2) >> 2] = h;
	                c[e >> 2] = 0;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function Xz(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                c[(c[f >> 2] | 0) + 20 >> 2] = 0;
	                rA(c[f >> 2] | 0, 0) | 0;
	                if (c[g >> 2] | 0)c[c[(c[f >> 2] | 0) + 24 >> 2] >> 2] = 2;
	                b = c[(c[f >> 2] | 0) + 24 >> 2] | 0;
	                if ((d[c[(c[f >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) != 124) {
	                    c[(c[f >> 2] | 0) + 20 >> 2] = b;
	                    i = e;
	                    return
	                }
	                c[j >> 2] = b;
	                while (1) {
	                    if ((d[c[(c[f >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) != 124)break;
	                    if (c[(c[f >> 2] | 0) + 8 >> 2] | 0)break;
	                    b = (c[f >> 2] | 0) + 4 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 1;
	                    if (!(d[c[(c[f >> 2] | 0) + 4 >> 2] >> 0] | 0)) {
	                        k = 9;
	                        break
	                    }
	                    c[(c[f >> 2] | 0) + 24 >> 2] = c[h >> 2];
	                    c[(c[f >> 2] | 0) + 20 >> 2] = 0;
	                    rA(c[f >> 2] | 0, c[j >> 2] | 0) | 0
	                }
	                if ((k | 0) == 9) {
	                    c[(c[f >> 2] | 0) + 8 >> 2] = 1450;
	                    Yz(c[f >> 2] | 0, 139560);
	                    i = e;
	                    return
	                }
	                if (c[g >> 2] | 0) {
	                    i = e;
	                    return
	                }
	                c[(c[f >> 2] | 0) + 24 >> 2] = c[j >> 2];
	                c[(c[f >> 2] | 0) + 20 >> 2] = c[j >> 2];
	                i = e;
	                return
	            }

	            function Yz(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                c[j >> 2] = 0;
	                if (c[f >> 2] | 0) {
	                    c[h >> 2] = c[c[f >> 2] >> 2];
	                    c[j >> 2] = (c[(c[f >> 2] | 0) + 4 >> 2] | 0) - (c[c[f >> 2] >> 2] | 0);
	                    c[(c[f >> 2] | 0) + 8 >> 2] = 1450
	                }
	                f = c[g >> 2] | 0;
	                b = c[h >> 2] | 0;
	                h = c[j >> 2] | 0;
	                c[e >> 2] = c[g >> 2];
	                Xd(0, 0, 0, 0, 0, 14, 1450, 3, 0, 0, f, b, 0, h, 0, 139536, e);
	                i = d;
	                return
	            }

	            function Zz(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[c[d >> 2] >> 2] | 0)zb[c[135736 >> 2] & 511](c[c[d >> 2] >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 52 >> 2] | 0) {
	                    c[e >> 2] = 0;
	                    while (1) {
	                        if ((c[e >> 2] | 0) >= (c[(c[d >> 2] | 0) + 48 >> 2] | 0))break;
	                        bA(c[(c[(c[d >> 2] | 0) + 52 >> 2] | 0) + (c[e >> 2] << 2) >> 2] | 0);
	                        c[e >> 2] = (c[e >> 2] | 0) + 1
	                    }
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 52 >> 2] | 0)
	                }
	                if (c[(c[d >> 2] | 0) + 40 >> 2] | 0) {
	                    c[e >> 2] = 0;
	                    while (1) {
	                        if ((c[e >> 2] | 0) >= (c[(c[d >> 2] | 0) + 36 >> 2] | 0))break;
	                        dA(c[(c[(c[d >> 2] | 0) + 40 >> 2] | 0) + (c[e >> 2] << 2) >> 2] | 0);
	                        c[e >> 2] = (c[e >> 2] | 0) + 1
	                    }
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 40 >> 2] | 0)
	                }
	                if (c[(c[d >> 2] | 0) + 64 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 64 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function _z(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                b = i;
	                i = i + 48 | 0;
	                d = b + 32 | 0;
	                e = b + 28 | 0;
	                f = b + 24 | 0;
	                g = b + 20 | 0;
	                h = b + 16 | 0;
	                j = b + 12 | 0;
	                k = b + 8 | 0;
	                l = b + 4 | 0;
	                m = b;
	                c[d >> 2] = a;
	                if (!(c[(c[d >> 2] | 0) + 52 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                sA(c[d >> 2] | 0);
	                c[e >> 2] = 0;
	                while (1) {
	                    if ((c[e >> 2] | 0) >= (c[(c[d >> 2] | 0) + 48 >> 2] | 0))break;
	                    c[g >> 2] = c[(c[(c[d >> 2] | 0) + 52 >> 2] | 0) + (c[e >> 2] << 2) >> 2];
	                    if ((c[g >> 2] | 0) != 0 ? (c[c[g >> 2] >> 2] | 0) == 5 : 0) {
	                        bA(c[g >> 2] | 0);
	                        c[(c[(c[d >> 2] | 0) + 52 >> 2] | 0) + (c[e >> 2] << 2) >> 2] = 0
	                    }
	                    c[e >> 2] = (c[e >> 2] | 0) + 1
	                }
	                c[h >> 2] = 0;
	                c[e >> 2] = (c[(c[d >> 2] | 0) + 48 >> 2] | 0) - 1;
	                while (1) {
	                    if ((c[e >> 2] | 0) < 0)break;
	                    c[g >> 2] = c[(c[(c[d >> 2] | 0) + 52 >> 2] | 0) + (c[e >> 2] << 2) >> 2];
	                    a:do if (c[g >> 2] | 0) {
	                        if ((c[(c[g >> 2] | 0) + 24 >> 2] | 0) == 0 ? (c[c[g >> 2] >> 2] | 0) != 2 : 0)c[c[g >> 2] >> 2] = 4;
	                        c[f >> 2] = 0;
	                        while (1) {
	                            if ((c[f >> 2] | 0) >= (c[(c[g >> 2] | 0) + 24 >> 2] | 0))break a;
	                            do if ((c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + ((c[f >> 2] | 0) * 20 | 0) >> 2] | 0) == 0 ? (c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + ((c[f >> 2] | 0) * 20 | 0) + 4 >> 2] | 0) >= 0 : 0) {
	                                a = (c[(c[g >> 2] | 0) + 28 >> 2] | 0) + ((c[f >> 2] | 0) * 20 | 0) | 0;
	                                if ((c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + ((c[f >> 2] | 0) * 20 | 0) + 4 >> 2] | 0) == (c[e >> 2] | 0)) {
	                                    c[a + 4 >> 2] = -1;
	                                    break
	                                }
	                                if ((c[a + 12 >> 2] | 0) < 0) {
	                                    c[j >> 2] = c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + ((c[f >> 2] | 0) * 20 | 0) + 4 >> 2];
	                                    c[h >> 2] = 1;
	                                    c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + ((c[f >> 2] | 0) * 20 | 0) + 4 >> 2] = -2;
	                                    c[(c[g >> 2] | 0) + 4 >> 2] = 1;
	                                    tA(c[d >> 2] | 0, c[e >> 2] | 0, c[j >> 2] | 0, c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + ((c[f >> 2] | 0) * 20 | 0) + 8 >> 2] | 0);
	                                    c[(c[g >> 2] | 0) + 4 >> 2] = 0
	                                }
	                            } while (0);
	                            c[f >> 2] = (c[f >> 2] | 0) + 1
	                        }
	                    } while (0);
	                    c[e >> 2] = (c[e >> 2] | 0) + -1
	                }
	                b:do if (c[h >> 2] | 0) {
	                    c[e >> 2] = 0;
	                    while (1) {
	                        if ((c[e >> 2] | 0) >= (c[(c[d >> 2] | 0) + 48 >> 2] | 0))break b;
	                        c[g >> 2] = c[(c[(c[d >> 2] | 0) + 52 >> 2] | 0) + (c[e >> 2] << 2) >> 2];
	                        c:do if (c[g >> 2] | 0) {
	                            c[f >> 2] = 0;
	                            while (1) {
	                                if ((c[f >> 2] | 0) >= (c[(c[g >> 2] | 0) + 24 >> 2] | 0))break c;
	                                c[k >> 2] = (c[(c[g >> 2] | 0) + 28 >> 2] | 0) + ((c[f >> 2] | 0) * 20 | 0);
	                                if (((c[c[k >> 2] >> 2] | 0) == 0 ? (c[(c[k >> 2] | 0) + 12 >> 2] | 0) < 0 : 0) ? (c[(c[k >> 2] | 0) + 4 >> 2] | 0) >= 0 : 0)c[(c[k >> 2] | 0) + 4 >> 2] = -1;
	                                c[f >> 2] = (c[f >> 2] | 0) + 1
	                            }
	                        } while (0);
	                        c[e >> 2] = (c[e >> 2] | 0) + 1
	                    }
	                } while (0);
	                c[e >> 2] = 0;
	                while (1) {
	                    if ((c[e >> 2] | 0) >= (c[(c[d >> 2] | 0) + 48 >> 2] | 0))break;
	                    c[g >> 2] = c[(c[(c[d >> 2] | 0) + 52 >> 2] | 0) + (c[e >> 2] << 2) >> 2];
	                    if (c[g >> 2] | 0)c[(c[g >> 2] | 0) + 12 >> 2] = 0;
	                    c[e >> 2] = (c[e >> 2] | 0) + 1
	                }
	                c[g >> 2] = c[c[(c[d >> 2] | 0) + 52 >> 2] >> 2];
	                if (c[g >> 2] | 0)c[(c[g >> 2] | 0) + 12 >> 2] = 1;
	                while (1) {
	                    if (!(c[g >> 2] | 0))break;
	                    c[l >> 2] = 0;
	                    c[(c[g >> 2] | 0) + 12 >> 2] = 2;
	                    c[f >> 2] = 0;
	                    while (1) {
	                        if ((c[f >> 2] | 0) >= (c[(c[g >> 2] | 0) + 24 >> 2] | 0))break;
	                        do if ((c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + ((c[f >> 2] | 0) * 20 | 0) + 4 >> 2] | 0) >= 0) {
	                            if ((c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + ((c[f >> 2] | 0) * 20 | 0) >> 2] | 0) == 0 ? (c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + ((c[f >> 2] | 0) * 20 | 0) + 12 >> 2] | 0) < 0 : 0)break;
	                            c[m >> 2] = c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + ((c[f >> 2] | 0) * 20 | 0) + 4 >> 2];
	                            if ((c[(c[(c[d >> 2] | 0) + 52 >> 2] | 0) + (c[m >> 2] << 2) >> 2] | 0) != 0 ? (c[(c[(c[(c[d >> 2] | 0) + 52 >> 2] | 0) + (c[m >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0) == 0 : 0) {
	                                c[(c[(c[(c[d >> 2] | 0) + 52 >> 2] | 0) + (c[m >> 2] << 2) >> 2] | 0) + 12 >> 2] = 1;
	                                c[l >> 2] = c[(c[(c[d >> 2] | 0) + 52 >> 2] | 0) + (c[m >> 2] << 2) >> 2]
	                            }
	                        } while (0);
	                        c[f >> 2] = (c[f >> 2] | 0) + 1
	                    }
	                    d:do if (!(c[l >> 2] | 0)) {
	                        c[e >> 2] = 1;
	                        while (1) {
	                            if ((c[e >> 2] | 0) >= (c[(c[d >> 2] | 0) + 48 >> 2] | 0))break d;
	                            c[g >> 2] = c[(c[(c[d >> 2] | 0) + 52 >> 2] | 0) + (c[e >> 2] << 2) >> 2];
	                            if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 12 >> 2] | 0) == 1 : 0)break;
	                            c[e >> 2] = (c[e >> 2] | 0) + 1
	                        }
	                        c[l >> 2] = c[g >> 2]
	                    } while (0);
	                    c[g >> 2] = c[l >> 2]
	                }
	                c[e >> 2] = 0;
	                while (1) {
	                    if ((c[e >> 2] | 0) >= (c[(c[d >> 2] | 0) + 48 >> 2] | 0))break;
	                    c[g >> 2] = c[(c[(c[d >> 2] | 0) + 52 >> 2] | 0) + (c[e >> 2] << 2) >> 2];
	                    if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 12 >> 2] | 0) == 0 : 0) {
	                        bA(c[g >> 2] | 0);
	                        c[(c[(c[d >> 2] | 0) + 52 >> 2] | 0) + (c[e >> 2] << 2) >> 2] = 0
	                    }
	                    c[e >> 2] = (c[e >> 2] | 0) + 1
	                }
	                i = b;
	                return
	            }

	            function $z(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0;
	                b = i;
	                i = i + 80 | 0;
	                d = b + 72 | 0;
	                e = b + 68 | 0;
	                f = b + 64 | 0;
	                g = b + 60 | 0;
	                h = b + 56 | 0;
	                j = b + 52 | 0;
	                k = b + 48 | 0;
	                l = b + 44 | 0;
	                m = b + 40 | 0;
	                n = b + 36 | 0;
	                o = b + 32 | 0;
	                p = b + 28 | 0;
	                q = b + 24 | 0;
	                r = b + 20 | 0;
	                s = b + 16 | 0;
	                t = b + 12 | 0;
	                u = b + 8 | 0;
	                v = b + 4 | 0;
	                w = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](56) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    Qz(c[e >> 2] | 0, 139512);
	                    c[d >> 2] = 0;
	                    x = c[d >> 2] | 0;
	                    i = b;
	                    return x | 0
	                }
	                a = (c[f >> 2] | 0) + 0 | 0;
	                y = a + 56 | 0;
	                do {
	                    c[a >> 2] = 0;
	                    a = a + 4 | 0
	                } while ((a | 0) < (y | 0));
	                c[c[f >> 2] >> 2] = c[c[e >> 2] >> 2];
	                c[(c[f >> 2] | 0) + 4 >> 2] = c[(c[e >> 2] | 0) + 48 >> 2];
	                c[(c[f >> 2] | 0) + 8 >> 2] = c[(c[e >> 2] | 0) + 52 >> 2];
	                c[(c[f >> 2] | 0) + 12 >> 2] = c[(c[e >> 2] | 0) + 36 >> 2];
	                c[(c[f >> 2] | 0) + 16 >> 2] = c[(c[e >> 2] | 0) + 40 >> 2];
	                c[(c[f >> 2] | 0) + 20 >> 2] = c[(c[e >> 2] | 0) + 60 >> 2];
	                c[(c[f >> 2] | 0) + 24 >> 2] = c[(c[e >> 2] | 0) + 64 >> 2];
	                c[(c[f >> 2] | 0) + 28 >> 2] = c[(c[e >> 2] | 0) + 68 >> 2];
	                c[(c[f >> 2] | 0) + 32 >> 2] = c[(c[e >> 2] | 0) + 76 >> 2];
	                if ((c[(c[f >> 2] | 0) + 28 >> 2] | 0) == -1)wz(c[f >> 2] | 0) | 0;
	                do if ((((((c[(c[f >> 2] | 0) + 28 >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 20 >> 2] | 0) == 0 : 0) ? (c[(c[e >> 2] | 0) + 72 >> 2] | 0) == 0 : 0) ? (c[(c[f >> 2] | 0) + 16 >> 2] | 0) != 0 : 0) ? (c[c[(c[f >> 2] | 0) + 16 >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[c[(c[f >> 2] | 0) + 16 >> 2] >> 2] | 0) + 4 >> 2] | 0) == 5 : 0) {
	                    c[j >> 2] = 0;
	                    c[k >> 2] = 0;
	                    c[l >> 2] = Cb[c[135744 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] << 2) | 0;
	                    if (!(c[l >> 2] | 0)) {
	                        Qz(c[e >> 2] | 0, 139512);
	                        zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                        c[d >> 2] = 0;
	                        x = c[d >> 2] | 0;
	                        i = b;
	                        return x | 0
	                    }
	                    c[g >> 2] = 0;
	                    while (1) {
	                        if ((c[g >> 2] | 0) >= (c[(c[f >> 2] | 0) + 4 >> 2] | 0))break;
	                        if (c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0) {
	                            c[(c[l >> 2] | 0) + (c[g >> 2] << 2) >> 2] = c[j >> 2];
	                            c[j >> 2] = (c[j >> 2] | 0) + 1
	                        } else c[(c[l >> 2] | 0) + (c[g >> 2] << 2) >> 2] = -1;
	                        c[g >> 2] = (c[g >> 2] | 0) + 1
	                    }
	                    c[p >> 2] = Cb[c[135744 >> 2] & 511](c[(c[f >> 2] | 0) + 12 >> 2] << 2) | 0;
	                    if (!(c[p >> 2] | 0)) {
	                        Qz(c[e >> 2] | 0, 139512);
	                        zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                        c[d >> 2] = 0;
	                        x = c[d >> 2] | 0;
	                        i = b;
	                        return x | 0
	                    }
	                    c[m >> 2] = Cb[c[135744 >> 2] & 511](c[(c[f >> 2] | 0) + 12 >> 2] << 2) | 0;
	                    if (!(c[m >> 2] | 0)) {
	                        Qz(c[e >> 2] | 0, 139512);
	                        zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                        c[d >> 2] = 0;
	                        x = c[d >> 2] | 0;
	                        i = b;
	                        return x | 0
	                    }
	                    c[g >> 2] = 0;
	                    while (1) {
	                        if ((c[g >> 2] | 0) >= (c[(c[f >> 2] | 0) + 12 >> 2] | 0)) {
	                            z = 44;
	                            break
	                        }
	                        if ((c[(c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0) != 5) {
	                            z = 39;
	                            break
	                        }
	                        if ((c[(c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0) + 8 >> 2] | 0) != 2) {
	                            z = 39;
	                            break
	                        }
	                        c[q >> 2] = c[(c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0) + 20 >> 2];
	                        c[h >> 2] = 0;
	                        while (1) {
	                            if ((c[h >> 2] | 0) >= (c[k >> 2] | 0))break;
	                            a = (qy(c[(c[p >> 2] | 0) + (c[h >> 2] << 2) >> 2] | 0, c[q >> 2] | 0) | 0) != 0;
	                            A = c[h >> 2] | 0;
	                            if (a) {
	                                z = 30;
	                                break
	                            }
	                            c[h >> 2] = A + 1
	                        }
	                        if ((z | 0) == 30) {
	                            z = 0;
	                            c[(c[m >> 2] | 0) + (c[g >> 2] << 2) >> 2] = A
	                        }
	                        if ((c[h >> 2] | 0) >= (c[k >> 2] | 0)) {
	                            c[(c[m >> 2] | 0) + (c[g >> 2] << 2) >> 2] = c[k >> 2];
	                            a = my(c[q >> 2] | 0) | 0;
	                            c[(c[p >> 2] | 0) + (c[k >> 2] << 2) >> 2] = a;
	                            if (!(c[(c[p >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0)) {
	                                z = 34;
	                                break
	                            }
	                            c[k >> 2] = (c[k >> 2] | 0) + 1
	                        }
	                        c[g >> 2] = (c[g >> 2] | 0) + 1
	                    }
	                    if ((z | 0) == 34) {
	                        c[g >> 2] = 0;
	                        while (1) {
	                            B = c[33934] | 0;
	                            if ((c[g >> 2] | 0) >= (c[k >> 2] | 0))break;
	                            zb[B & 511](c[(c[p >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0);
	                            c[g >> 2] = (c[g >> 2] | 0) + 1
	                        }
	                        zb[B & 511](c[m >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                        c[d >> 2] = 0;
	                        x = c[d >> 2] | 0;
	                        i = b;
	                        return x | 0
	                    } else if ((z | 0) == 39) {
	                        zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                        c[g >> 2] = 0;
	                        while (1) {
	                            C = c[33934] | 0;
	                            if ((c[g >> 2] | 0) >= (c[k >> 2] | 0))break;
	                            zb[C & 511](c[(c[p >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0);
	                            c[g >> 2] = (c[g >> 2] | 0) + 1
	                        }
	                        zb[C & 511](c[p >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                        c[d >> 2] = 0;
	                        x = c[d >> 2] | 0;
	                        i = b;
	                        return x | 0
	                    } else if ((z | 0) == 44) {
	                        a = (ca((c[j >> 2] | 0) + 1 | 0, (c[k >> 2] | 0) + 1 | 0) | 0) << 2;
	                        c[n >> 2] = Cb[c[135744 >> 2] & 511](a) | 0;
	                        if (!(c[n >> 2] | 0)) {
	                            zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                            zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                            zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                            zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                            c[d >> 2] = 0;
	                            x = c[d >> 2] | 0;
	                            i = b;
	                            return x | 0
	                        }
	                        cU(c[n >> 2] | 0, 0, (ca((c[j >> 2] | 0) + 1 | 0, (c[k >> 2] | 0) + 1 | 0) | 0) << 2 | 0) | 0;
	                        c[o >> 2] = 0;
	                        c[g >> 2] = 0;
	                        a:while (1) {
	                            if ((c[g >> 2] | 0) >= (c[(c[f >> 2] | 0) + 4 >> 2] | 0))break;
	                            c[r >> 2] = c[(c[l >> 2] | 0) + (c[g >> 2] << 2) >> 2];
	                            b:do if ((c[r >> 2] | 0) != -1) {
	                                c[v >> 2] = c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + (c[g >> 2] << 2) >> 2];
	                                a = ca(c[r >> 2] | 0, (c[k >> 2] | 0) + 1 | 0) | 0;
	                                c[(c[n >> 2] | 0) + (a << 2) >> 2] = c[c[v >> 2] >> 2];
	                                c[h >> 2] = 0;
	                                c:while (1) {
	                                    if ((c[h >> 2] | 0) >= (c[(c[v >> 2] | 0) + 24 >> 2] | 0))break b;
	                                    c[w >> 2] = (c[(c[v >> 2] | 0) + 28 >> 2] | 0) + ((c[h >> 2] | 0) * 20 | 0);
	                                    do if ((c[(c[w >> 2] | 0) + 4 >> 2] | 0) != -1) {
	                                        if (!(c[c[w >> 2] >> 2] | 0))break;
	                                        c[s >> 2] = c[(c[m >> 2] | 0) + (c[c[c[w >> 2] >> 2] >> 2] << 2) >> 2];
	                                        if ((c[o >> 2] | 0) == 0 ? (c[(c[c[w >> 2] >> 2] | 0) + 60 >> 2] | 0) != 0 : 0) {
	                                            a = (ca(c[j >> 2] | 0, c[k >> 2] | 0) | 0) << 2;
	                                            c[o >> 2] = Cb[c[135744 >> 2] & 511](a) | 0;
	                                            if (!(c[o >> 2] | 0))break c;
	                                            cU(c[o >> 2] | 0, 0, (ca(c[j >> 2] | 0, c[k >> 2] | 0) | 0) << 2 | 0) | 0
	                                        }
	                                        c[t >> 2] = c[(c[l >> 2] | 0) + (c[(c[w >> 2] | 0) + 4 >> 2] << 2) >> 2];
	                                        a = ca(c[r >> 2] | 0, (c[k >> 2] | 0) + 1 | 0) | 0;
	                                        c[u >> 2] = c[(c[n >> 2] | 0) + (a + (c[s >> 2] | 0) + 1 << 2) >> 2];
	                                        if (c[u >> 2] | 0)if ((c[u >> 2] | 0) != ((c[t >> 2] | 0) + 1 | 0)) {
	                                            z = 59;
	                                            break a
	                                        } else break;
	                                        a = ca(c[r >> 2] | 0, (c[k >> 2] | 0) + 1 | 0) | 0;
	                                        c[(c[n >> 2] | 0) + (a + (c[s >> 2] | 0) + 1 << 2) >> 2] = (c[t >> 2] | 0) + 1;
	                                        if (!(c[o >> 2] | 0))break;
	                                        a = ca(c[r >> 2] | 0, c[k >> 2] | 0) | 0;
	                                        c[(c[o >> 2] | 0) + (a + (c[s >> 2] | 0) << 2) >> 2] = c[(c[c[w >> 2] >> 2] | 0) + 60 >> 2]
	                                    } while (0);
	                                    c[h >> 2] = (c[h >> 2] | 0) + 1
	                                }
	                                Qz(c[e >> 2] | 0, 139512)
	                            } while (0);
	                            c[g >> 2] = (c[g >> 2] | 0) + 1
	                        }
	                        if ((z | 0) == 59) {
	                            c[(c[f >> 2] | 0) + 28 >> 2] = 0;
	                            if (c[o >> 2] | 0)zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                            zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                            zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                            zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                            c[g >> 2] = 0;
	                            while (1) {
	                                D = c[33934] | 0;
	                                if ((c[g >> 2] | 0) >= (c[k >> 2] | 0))break;
	                                zb[D & 511](c[(c[p >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0);
	                                c[g >> 2] = (c[g >> 2] | 0) + 1
	                            }
	                            zb[D & 511](c[p >> 2] | 0);
	                            break
	                        }
	                        c[(c[f >> 2] | 0) + 28 >> 2] = 1;
	                        if (c[(c[f >> 2] | 0) + 8 >> 2] | 0) {
	                            c[g >> 2] = 0;
	                            while (1) {
	                                if ((c[g >> 2] | 0) >= (c[(c[f >> 2] | 0) + 4 >> 2] | 0))break;
	                                bA(c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0);
	                                c[g >> 2] = (c[g >> 2] | 0) + 1
	                            }
	                            zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 8 >> 2] | 0)
	                        }
	                        c[(c[f >> 2] | 0) + 8 >> 2] = 0;
	                        c[(c[f >> 2] | 0) + 4 >> 2] = 0;
	                        if (c[(c[f >> 2] | 0) + 16 >> 2] | 0) {
	                            c[g >> 2] = 0;
	                            while (1) {
	                                if ((c[g >> 2] | 0) >= (c[(c[f >> 2] | 0) + 12 >> 2] | 0))break;
	                                dA(c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0);
	                                c[g >> 2] = (c[g >> 2] | 0) + 1
	                            }
	                            zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 16 >> 2] | 0)
	                        }
	                        c[(c[f >> 2] | 0) + 16 >> 2] = 0;
	                        c[(c[f >> 2] | 0) + 12 >> 2] = 0;
	                        c[(c[f >> 2] | 0) + 40 >> 2] = c[n >> 2];
	                        c[(c[f >> 2] | 0) + 44 >> 2] = c[o >> 2];
	                        c[(c[f >> 2] | 0) + 52 >> 2] = c[p >> 2];
	                        c[(c[f >> 2] | 0) + 48 >> 2] = c[k >> 2];
	                        c[(c[f >> 2] | 0) + 36 >> 2] = c[j >> 2];
	                        zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                        break
	                    }
	                } while (0);
	                c[c[e >> 2] >> 2] = 0;
	                c[(c[e >> 2] | 0) + 48 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 52 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 36 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 40 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 60 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 64 >> 2] = 0;
	                c[d >> 2] = c[f >> 2];
	                x = c[d >> 2] | 0;
	                i = b;
	                return x | 0
	            }

	            function aA(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0;
	                e = i;
	                i = i + 176 | 0;
	                f = e;
	                g = e + 164 | 0;
	                h = e + 160 | 0;
	                j = e + 156 | 0;
	                k = e + 60 | 0;
	                l = e + 56 | 0;
	                m = e + 52 | 0;
	                n = e + 48 | 0;
	                p = e + 44 | 0;
	                q = e + 40 | 0;
	                r = e + 36 | 0;
	                s = e + 32 | 0;
	                t = e + 28 | 0;
	                u = e + 24 | 0;
	                v = e + 20 | 0;
	                w = e + 16 | 0;
	                x = e + 12 | 0;
	                y = e + 8 | 0;
	                z = e + 4 | 0;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = e + 64;
	                c[m >> 2] = 0;
	                c[(c[k >> 2] | 0) + 64 >> 2] = c[j >> 2];
	                c[(c[k >> 2] | 0) + 56 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 88 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 4 >> 2] = 1;
	                c[(c[k >> 2] | 0) + 32 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 36 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 40 >> 2] = 0;
	                c[c[k >> 2] >> 2] = 0;
	                c[(c[k >> 2] | 0) + 8 >> 2] = c[h >> 2];
	                c[(c[k >> 2] | 0) + 20 >> 2] = c[c[(c[h >> 2] | 0) + 8 >> 2] >> 2];
	                c[(c[k >> 2] | 0) + 24 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 28 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 68 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 48 >> 2] = 0;
	                do if ((c[(c[h >> 2] | 0) + 20 >> 2] | 0) > 0) {
	                    j = Cb[c[135744 >> 2] & 511](c[(c[h >> 2] | 0) + 20 >> 2] << 2) | 0;
	                    c[(c[k >> 2] | 0) + 44 >> 2] = j;
	                    if (c[(c[k >> 2] | 0) + 44 >> 2] | 0) {
	                        cU(c[(c[k >> 2] | 0) + 44 >> 2] | 0, 0, c[(c[h >> 2] | 0) + 20 >> 2] << 2 | 0) | 0;
	                        break
	                    }
	                    Qz(0, 139408);
	                    c[g >> 2] = -1;
	                    A = c[g >> 2] | 0;
	                    i = e;
	                    return A | 0
	                } else c[(c[k >> 2] | 0) + 44 >> 2] = 0; while (0);
	                a:while (1) {
	                    if (c[c[k >> 2] >> 2] | 0)break;
	                    if (!(c[(c[k >> 2] | 0) + 20 >> 2] | 0))break;
	                    if (!(d[(c[(c[k >> 2] | 0) + 64 >> 2] | 0) + (c[(c[k >> 2] | 0) + 56 >> 2] | 0) >> 0] | 0)) {
	                        if (!(c[(c[k >> 2] | 0) + 20 >> 2] | 0))break;
	                        if ((c[c[(c[k >> 2] | 0) + 20 >> 2] >> 2] | 0) == 2)break
	                    }
	                    c[n >> 2] = 1;
	                    if ((d[(c[(c[k >> 2] | 0) + 64 >> 2] | 0) + (c[(c[k >> 2] | 0) + 56 >> 2] | 0) >> 0] | 0 | 0) == 0 ? (c[(c[k >> 2] | 0) + 44 >> 2] | 0) == 0 : 0) {
	                        if ((c[(c[k >> 2] | 0) + 24 >> 2] | 0) < (c[(c[(c[k >> 2] | 0) + 20 >> 2] | 0) + 24 >> 2] | 0)) {
	                            c[q >> 2] = (c[(c[(c[k >> 2] | 0) + 20 >> 2] | 0) + 28 >> 2] | 0) + ((c[(c[k >> 2] | 0) + 24 >> 2] | 0) * 20 | 0);
	                            if ((c[(c[q >> 2] | 0) + 4 >> 2] | 0) >= 0) {
	                                c[r >> 2] = c[c[q >> 2] >> 2];
	                                if ((c[(c[r >> 2] | 0) + 12 >> 2] | 0) == 0 ? (c[(c[r >> 2] | 0) + 16 >> 2] | 0) > 0 : 0)B = 17
	                            } else B = 17
	                        }
	                    } else B = 17;
	                    b:do if ((B | 0) == 17) {
	                        B = 0;
	                        c[(c[k >> 2] | 0) + 28 >> 2] = 0;
	                        c:while (1) {
	                            if ((c[(c[k >> 2] | 0) + 24 >> 2] | 0) >= (c[(c[(c[k >> 2] | 0) + 20 >> 2] | 0) + 24 >> 2] | 0)) {
	                                B = 88;
	                                break
	                            }
	                            c[q >> 2] = (c[(c[(c[k >> 2] | 0) + 20 >> 2] | 0) + 28 >> 2] | 0) + ((c[(c[k >> 2] | 0) + 24 >> 2] | 0) * 20 | 0);
	                            d:do if ((c[(c[q >> 2] | 0) + 4 >> 2] | 0) >= 0) {
	                                c[r >> 2] = c[c[q >> 2] >> 2];
	                                c[l >> 2] = 0;
	                                c[p >> 2] = 1;
	                                do if ((c[(c[q >> 2] | 0) + 12 >> 2] | 0) >= 0) {
	                                    if (!(c[(c[k >> 2] | 0) + 44 >> 2] | 0)) {
	                                        B = 22;
	                                        break a
	                                    }
	                                    c[s >> 2] = c[(c[(c[k >> 2] | 0) + 44 >> 2] | 0) + (c[(c[q >> 2] | 0) + 12 >> 2] << 2) >> 2];
	                                    c[t >> 2] = (c[(c[(c[k >> 2] | 0) + 8 >> 2] | 0) + 24 >> 2] | 0) + (c[(c[q >> 2] | 0) + 12 >> 2] << 3);
	                                    if ((c[s >> 2] | 0) >= (c[c[t >> 2] >> 2] | 0))C = (c[s >> 2] | 0) <= (c[(c[t >> 2] | 0) + 4 >> 2] | 0); else C = 0;
	                                    c[l >> 2] = C & 1;
	                                    if ((c[l >> 2] | 0) != 0 ? (c[c[t >> 2] >> 2] | 0) != (c[(c[t >> 2] | 0) + 4 >> 2] | 0) : 0)c[p >> 2] = 0
	                                } else {
	                                    if (!(c[r >> 2] | 0)) {
	                                        B = 29;
	                                        break c
	                                    }
	                                    if (!(d[(c[(c[k >> 2] | 0) + 64 >> 2] | 0) + (c[(c[k >> 2] | 0) + 56 >> 2] | 0) >> 0] | 0)) {
	                                        if (c[(c[r >> 2] | 0) + 12 >> 2] | 0)break;
	                                        if ((c[(c[r >> 2] | 0) + 16 >> 2] | 0) <= 0)break;
	                                        c[(c[k >> 2] | 0) + 28 >> 2] = 1;
	                                        c[n >> 2] = 0;
	                                        c[l >> 2] = 1;
	                                        break
	                                    }
	                                    c[m >> 2] = oe(0, (c[(c[k >> 2] | 0) + 64 >> 2] | 0) + (c[(c[k >> 2] | 0) + 56 >> 2] | 0) | 0, n) | 0;
	                                    c[l >> 2] = uA(c[r >> 2] | 0, c[m >> 2] | 0) | 0;
	                                    if (((c[l >> 2] | 0) == 1 ? (c[(c[r >> 2] | 0) + 12 >> 2] | 0) >= 0 : 0) ? (c[(c[r >> 2] | 0) + 16 >> 2] | 0) > 0 : 0) {
	                                        c[u >> 2] = c[(c[(c[h >> 2] | 0) + 8 >> 2] | 0) + (c[(c[q >> 2] | 0) + 4 >> 2] << 2) >> 2];
	                                        if ((c[(c[q >> 2] | 0) + 8 >> 2] | 0) >= 0) {
	                                            if (!(c[(c[k >> 2] | 0) + 44 >> 2] | 0)) {
	                                                B = 38;
	                                                break a
	                                            }
	                                            if (!(c[(c[k >> 2] | 0) + 8 >> 2] | 0)) {
	                                                B = 38;
	                                                break a
	                                            }
	                                            if (!(c[(c[(c[k >> 2] | 0) + 8 >> 2] | 0) + 24 >> 2] | 0)) {
	                                                B = 38;
	                                                break a
	                                            }
	                                            c[v >> 2] = (c[(c[(c[k >> 2] | 0) + 8 >> 2] | 0) + 24 >> 2] | 0) + (c[(c[q >> 2] | 0) + 8 >> 2] << 3);
	                                            if ((c[(c[(c[k >> 2] | 0) + 44 >> 2] | 0) + (c[(c[q >> 2] | 0) + 8 >> 2] << 2) >> 2] | 0) >= (c[(c[v >> 2] | 0) + 4 >> 2] | 0))break d;
	                                            j = (c[(c[k >> 2] | 0) + 44 >> 2] | 0) + (c[(c[q >> 2] | 0) + 8 >> 2] << 2) | 0;
	                                            c[j >> 2] = (c[j >> 2] | 0) + 1
	                                        }
	                                        if ((c[(c[(c[k >> 2] | 0) + 20 >> 2] | 0) + 24 >> 2] | 0) > ((c[(c[k >> 2] | 0) + 24 >> 2] | 0) + 1 | 0))pA(c[k >> 2] | 0);
	                                        c[(c[k >> 2] | 0) + 28 >> 2] = 1;
	                                        do {
	                                            if ((c[(c[k >> 2] | 0) + 28 >> 2] | 0) == (c[(c[r >> 2] | 0) + 16 >> 2] | 0))break;
	                                            j = (c[k >> 2] | 0) + 56 | 0;
	                                            c[j >> 2] = (c[j >> 2] | 0) + (c[n >> 2] | 0);
	                                            if (!(d[(c[(c[k >> 2] | 0) + 64 >> 2] | 0) + (c[(c[k >> 2] | 0) + 56 >> 2] | 0) >> 0] | 0)) {
	                                                B = 46;
	                                                break
	                                            }
	                                            if ((c[(c[k >> 2] | 0) + 28 >> 2] | 0) >= (c[(c[r >> 2] | 0) + 12 >> 2] | 0)) {
	                                                c[w >> 2] = c[(c[k >> 2] | 0) + 24 >> 2];
	                                                c[x >> 2] = c[(c[k >> 2] | 0) + 20 >> 2];
	                                                c[(c[k >> 2] | 0) + 24 >> 2] = -1;
	                                                c[(c[k >> 2] | 0) + 20 >> 2] = c[u >> 2];
	                                                pA(c[k >> 2] | 0);
	                                                c[(c[k >> 2] | 0) + 24 >> 2] = c[w >> 2];
	                                                c[(c[k >> 2] | 0) + 20 >> 2] = c[x >> 2]
	                                            }
	                                            c[m >> 2] = oe(0, (c[(c[k >> 2] | 0) + 64 >> 2] | 0) + (c[(c[k >> 2] | 0) + 56 >> 2] | 0) | 0, n) | 0;
	                                            c[l >> 2] = uA(c[r >> 2] | 0, c[m >> 2] | 0) | 0;
	                                            j = (c[k >> 2] | 0) + 28 | 0;
	                                            c[j >> 2] = (c[j >> 2] | 0) + 1
	                                        } while ((c[l >> 2] | 0) == 1);
	                                        if ((B | 0) == 46) {
	                                            B = 0;
	                                            j = (c[k >> 2] | 0) + 56 | 0;
	                                            c[j >> 2] = (c[j >> 2] | 0) - (c[n >> 2] | 0)
	                                        }
	                                        if ((c[(c[k >> 2] | 0) + 28 >> 2] | 0) < (c[(c[r >> 2] | 0) + 12 >> 2] | 0))c[l >> 2] = 0;
	                                        if ((c[l >> 2] | 0) < 0)c[l >> 2] = 0;
	                                        if (!(c[l >> 2] | 0))break b;
	                                        if ((c[(c[q >> 2] | 0) + 8 >> 2] | 0) < 0)break;
	                                        if (!(c[(c[k >> 2] | 0) + 44 >> 2] | 0)) {
	                                            B = 57;
	                                            break a
	                                        }
	                                        j = (c[(c[k >> 2] | 0) + 44 >> 2] | 0) + (c[(c[q >> 2] | 0) + 8 >> 2] << 2) | 0;
	                                        c[j >> 2] = (c[j >> 2] | 0) + -1;
	                                        break
	                                    }
	                                    if (((c[l >> 2] | 0) == 0 ? (c[(c[r >> 2] | 0) + 12 >> 2] | 0) == 0 : 0) ? (c[(c[r >> 2] | 0) + 16 >> 2] | 0) > 0 : 0) {
	                                        c[(c[k >> 2] | 0) + 28 >> 2] = 1;
	                                        c[n >> 2] = 0;
	                                        c[l >> 2] = 1
	                                    }
	                                } while (0);
	                                if ((c[l >> 2] | 0) != 1)if ((c[l >> 2] | 0) < 0) {
	                                    B = 86;
	                                    break c
	                                } else break;
	                                if ((c[(c[q >> 2] | 0) + 16 >> 2] | 0) != 1) {
	                                    if (((c[p >> 2] | 0) == 0 ? (c[(c[q >> 2] | 0) + 12 >> 2] | 0) >= 0 : 0) ? (c[(c[(c[k >> 2] | 0) + 20 >> 2] | 0) + 24 >> 2] | 0) > ((c[(c[k >> 2] | 0) + 24 >> 2] | 0) + 1 | 0) : 0)B = 70
	                                } else B = 70;
	                                if ((B | 0) == 70) {
	                                    B = 0;
	                                    pA(c[k >> 2] | 0)
	                                }
	                                if ((c[(c[q >> 2] | 0) + 8 >> 2] | 0) < 0)break c;
	                                if (!(c[(c[k >> 2] | 0) + 44 >> 2] | 0)) {
	                                    B = 75;
	                                    break a
	                                }
	                                if (!(c[(c[k >> 2] | 0) + 8 >> 2] | 0)) {
	                                    B = 75;
	                                    break a
	                                }
	                                if (!(c[(c[(c[k >> 2] | 0) + 8 >> 2] | 0) + 24 >> 2] | 0)) {
	                                    B = 75;
	                                    break a
	                                }
	                                c[y >> 2] = (c[(c[(c[k >> 2] | 0) + 8 >> 2] | 0) + 24 >> 2] | 0) + (c[(c[q >> 2] | 0) + 8 >> 2] << 3);
	                                if ((c[(c[(c[k >> 2] | 0) + 44 >> 2] | 0) + (c[(c[q >> 2] | 0) + 8 >> 2] << 2) >> 2] | 0) < (c[(c[y >> 2] | 0) + 4 >> 2] | 0)) {
	                                    B = 77;
	                                    break c
	                                }
	                            } while (0);
	                            j = (c[k >> 2] | 0) + 24 | 0;
	                            c[j >> 2] = (c[j >> 2] | 0) + 1
	                        }
	                        if ((B | 0) == 29) {
	                            B = 0;
	                            Ka(c[o >> 2] | 0, 139424, f | 0) | 0;
	                            c[c[k >> 2] >> 2] = -2;
	                            B = 88
	                        } else if ((B | 0) == 77) {
	                            B = 0;
	                            j = (c[(c[k >> 2] | 0) + 44 >> 2] | 0) + (c[(c[q >> 2] | 0) + 8 >> 2] << 2) | 0;
	                            c[j >> 2] = (c[j >> 2] | 0) + 1
	                        } else if ((B | 0) == 86) {
	                            B = 0;
	                            c[c[k >> 2] >> 2] = -4;
	                            B = 88
	                        }
	                        if ((B | 0) == 88) {
	                            B = 0;
	                            if (c[(c[k >> 2] | 0) + 24 >> 2] | 0)break;
	                            if (!(c[(c[(c[k >> 2] | 0) + 20 >> 2] | 0) + 24 >> 2] | 0))break; else continue a
	                        }
	                        if ((c[(c[q >> 2] | 0) + 12 >> 2] | 0) >= 0 ? (c[(c[q >> 2] | 0) + 12 >> 2] | 0) < 1193046 : 0) {
	                            if (!(c[(c[k >> 2] | 0) + 44 >> 2] | 0)) {
	                                B = 81;
	                                break a
	                            }
	                            c[(c[(c[k >> 2] | 0) + 44 >> 2] | 0) + (c[(c[q >> 2] | 0) + 12 >> 2] << 2) >> 2] = 0
	                        }
	                        c[(c[k >> 2] | 0) + 20 >> 2] = c[(c[(c[h >> 2] | 0) + 8 >> 2] | 0) + (c[(c[q >> 2] | 0) + 4 >> 2] << 2) >> 2];
	                        c[(c[k >> 2] | 0) + 24 >> 2] = 0;
	                        if (!(c[c[q >> 2] >> 2] | 0))continue a;
	                        j = (c[k >> 2] | 0) + 56 | 0;
	                        c[j >> 2] = (c[j >> 2] | 0) + (c[n >> 2] | 0);
	                        continue a
	                    } while (0);
	                    c[(c[k >> 2] | 0) + 4 >> 2] = 0;
	                    qA(c[k >> 2] | 0)
	                }
	                if ((B | 0) == 22)c[c[k >> 2] >> 2] = -1; else if ((B | 0) == 38)c[c[k >> 2] >> 2] = -1; else if ((B | 0) == 57)c[c[k >> 2] >> 2] = -1; else if ((B | 0) == 75)c[c[k >> 2] >> 2] = -1; else if ((B | 0) == 81)c[c[k >> 2] >> 2] = -1;
	                if (c[(c[k >> 2] | 0) + 40 >> 2] | 0) {
	                    e:do if (c[(c[k >> 2] | 0) + 44 >> 2] | 0) {
	                        c[z >> 2] = 0;
	                        while (1) {
	                            if ((c[z >> 2] | 0) >= (c[(c[k >> 2] | 0) + 32 >> 2] | 0))break e;
	                            if (c[(c[(c[k >> 2] | 0) + 40 >> 2] | 0) + (c[z >> 2] << 4) + 12 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[(c[k >> 2] | 0) + 40 >> 2] | 0) + (c[z >> 2] << 4) + 12 >> 2] | 0);
	                            c[z >> 2] = (c[z >> 2] | 0) + 1
	                        }
	                    } while (0);
	                    zb[c[135736 >> 2] & 511](c[(c[k >> 2] | 0) + 40 >> 2] | 0)
	                }
	                if (!(c[(c[k >> 2] | 0) + 20 >> 2] | 0)) {
	                    c[g >> 2] = -1;
	                    A = c[g >> 2] | 0;
	                    i = e;
	                    return A | 0
	                }
	                if (c[(c[k >> 2] | 0) + 44 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[k >> 2] | 0) + 44 >> 2] | 0);
	                if (!(c[c[k >> 2] >> 2] | 0)) {
	                    c[g >> 2] = 1;
	                    A = c[g >> 2] | 0;
	                    i = e;
	                    return A | 0
	                }
	                z = c[k >> 2] | 0;
	                if ((c[c[k >> 2] >> 2] | 0) != -1) {
	                    c[g >> 2] = c[z >> 2];
	                    A = c[g >> 2] | 0;
	                    i = e;
	                    return A | 0
	                }
	                if ((c[z + 88 >> 2] | 0) > 1e7) {
	                    c[g >> 2] = -1;
	                    A = c[g >> 2] | 0;
	                    i = e;
	                    return A | 0
	                } else {
	                    c[g >> 2] = 0;
	                    A = c[g >> 2] | 0;
	                    i = e;
	                    return A | 0
	                }
	                return 0
	            }

	            function bA(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 28 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 28 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 40 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 40 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function cA(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                b = i;
	                i = i + 48 | 0;
	                d = b + 40 | 0;
	                e = b + 36 | 0;
	                f = b + 32 | 0;
	                g = b + 28 | 0;
	                h = b + 24 | 0;
	                j = b + 20 | 0;
	                k = b + 16 | 0;
	                l = b + 12 | 0;
	                m = b + 8 | 0;
	                n = b + 4 | 0;
	                o = b;
	                c[e >> 2] = a;
	                c[n >> 2] = 1;
	                c[o >> 2] = 1;
	                a = c[e >> 2] | 0;
	                if ((c[(c[e >> 2] | 0) + 68 >> 2] | 0) != -1) {
	                    c[d >> 2] = c[a + 68 >> 2];
	                    p = c[d >> 2] | 0;
	                    i = b;
	                    return p | 0
	                }
	                if (c[a + 76 >> 2] & 1)c[o >> 2] = 0;
	                c[f >> 2] = 0;
	                while (1) {
	                    if ((c[f >> 2] | 0) >= (c[(c[e >> 2] | 0) + 48 >> 2] | 0))break;
	                    c[h >> 2] = c[(c[(c[e >> 2] | 0) + 52 >> 2] | 0) + (c[f >> 2] << 2) >> 2];
	                    a:do if ((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 24 >> 2] | 0) >= 2 : 0) {
	                        c[g >> 2] = 0;
	                        while (1) {
	                            if ((c[g >> 2] | 0) >= (c[(c[h >> 2] | 0) + 24 >> 2] | 0))break a;
	                            c[j >> 2] = (c[(c[h >> 2] | 0) + 28 >> 2] | 0) + ((c[g >> 2] | 0) * 20 | 0);
	                            b:do if ((c[c[j >> 2] >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) != -1 : 0) {
	                                c[m >> 2] = 0;
	                                while (1) {
	                                    if ((c[m >> 2] | 0) >= (c[g >> 2] | 0))break b;
	                                    c[k >> 2] = (c[(c[h >> 2] | 0) + 28 >> 2] | 0) + ((c[m >> 2] | 0) * 20 | 0);
	                                    do if (((((c[(c[k >> 2] | 0) + 4 >> 2] | 0) != -1 ? (c[c[k >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) == (c[(c[k >> 2] | 0) + 4 >> 2] | 0) : 0) ? (vA(c[c[j >> 2] >> 2] | 0, c[c[k >> 2] >> 2] | 0, c[o >> 2] | 0) | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 8 >> 2] | 0) == (c[(c[k >> 2] | 0) + 8 >> 2] | 0) : 0) {
	                                        if ((c[(c[j >> 2] | 0) + 12 >> 2] | 0) != (c[(c[k >> 2] | 0) + 12 >> 2] | 0))break;
	                                        c[(c[k >> 2] | 0) + 4 >> 2] = -1
	                                    } while (0);
	                                    c[m >> 2] = (c[m >> 2] | 0) + 1
	                                }
	                            } while (0);
	                            c[g >> 2] = (c[g >> 2] | 0) + 1
	                        }
	                    } while (0);
	                    c[f >> 2] = (c[f >> 2] | 0) + 1
	                }
	                c[f >> 2] = 0;
	                while (1) {
	                    if ((c[f >> 2] | 0) >= (c[(c[e >> 2] | 0) + 48 >> 2] | 0))break;
	                    c[h >> 2] = c[(c[(c[e >> 2] | 0) + 52 >> 2] | 0) + (c[f >> 2] << 2) >> 2];
	                    if ((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 24 >> 2] | 0) >= 2 : 0) {
	                        c[l >> 2] = 0;
	                        c[g >> 2] = 0;
	                        while (1) {
	                            if ((c[g >> 2] | 0) >= (c[(c[h >> 2] | 0) + 24 >> 2] | 0))break;
	                            c[j >> 2] = (c[(c[h >> 2] | 0) + 28 >> 2] | 0) + ((c[g >> 2] | 0) * 20 | 0);
	                            c:do if ((c[c[j >> 2] >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) != -1 : 0) {
	                                c[m >> 2] = 0;
	                                while (1) {
	                                    if ((c[m >> 2] | 0) >= (c[g >> 2] | 0))break c;
	                                    c[k >> 2] = (c[(c[h >> 2] | 0) + 28 >> 2] | 0) + ((c[m >> 2] | 0) * 20 | 0);
	                                    do if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) != -1) {
	                                        o = c[j >> 2] | 0;
	                                        if (c[c[k >> 2] >> 2] | 0) {
	                                            if (!(wA(c[o >> 2] | 0, c[c[k >> 2] >> 2] | 0, 1) | 0))break;
	                                            c[n >> 2] = 0;
	                                            c[(c[j >> 2] | 0) + 16 >> 2] = 1;
	                                            c[(c[k >> 2] | 0) + 16 >> 2] = 1;
	                                            c[l >> 2] = c[j >> 2];
	                                            break
	                                        }
	                                        if ((c[o + 4 >> 2] | 0) != -1 ? (c[n >> 2] = xA(c[e >> 2] | 0, c[(c[(c[e >> 2] | 0) + 52 >> 2] | 0) + (c[(c[j >> 2] | 0) + 4 >> 2] << 2) >> 2] | 0, c[(c[k >> 2] | 0) + 4 >> 2] | 0, c[c[k >> 2] >> 2] | 0) | 0, (c[n >> 2] | 0) == 0) : 0) {
	                                            c[(c[j >> 2] | 0) + 16 >> 2] = 1;
	                                            c[l >> 2] = c[j >> 2]
	                                        }
	                                    } while (0);
	                                    c[m >> 2] = (c[m >> 2] | 0) + 1
	                                }
	                            } while (0);
	                            c[g >> 2] = (c[g >> 2] | 0) + 1
	                        }
	                        if (c[l >> 2] | 0)c[(c[l >> 2] | 0) + 16 >> 2] = 2
	                    }
	                    c[f >> 2] = (c[f >> 2] | 0) + 1
	                }
	                c[(c[e >> 2] | 0) + 68 >> 2] = c[n >> 2];
	                c[d >> 2] = c[n >> 2];
	                p = c[d >> 2] | 0;
	                i = b;
	                return p | 0
	            }

	            function dA(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                c[e >> 2] = 0;
	                while (1) {
	                    if ((c[e >> 2] | 0) >= (c[(c[d >> 2] | 0) + 52 >> 2] | 0))break;
	                    yA(c[(c[(c[d >> 2] | 0) + 56 >> 2] | 0) + (c[e >> 2] << 2) >> 2] | 0);
	                    c[e >> 2] = (c[e >> 2] | 0) + 1
	                }
	                if (c[(c[d >> 2] | 0) + 56 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 56 >> 2] | 0);
	                if ((c[(c[d >> 2] | 0) + 4 >> 2] | 0) == 5 ? (c[(c[d >> 2] | 0) + 20 >> 2] | 0) != 0 : 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 20 >> 2] | 0);
	                if ((c[(c[d >> 2] | 0) + 4 >> 2] | 0) == 5 ? (c[(c[d >> 2] | 0) + 24 >> 2] | 0) != 0 : 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 24 >> 2] | 0);
	                if ((c[(c[d >> 2] | 0) + 4 >> 2] | 0) == 136 ? (c[(c[d >> 2] | 0) + 20 >> 2] | 0) != 0 : 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 20 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function eA(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = Cb[c[135744 >> 2] & 511](64) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    Qz(c[f >> 2] | 0, 139360);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } else {
	                    f = (c[h >> 2] | 0) + 0 | 0;
	                    b = f + 64 | 0;
	                    do {
	                        c[f >> 2] = 0;
	                        f = f + 4 | 0
	                    } while ((f | 0) < (b | 0));
	                    c[(c[h >> 2] | 0) + 4 >> 2] = c[g >> 2];
	                    c[(c[h >> 2] | 0) + 8 >> 2] = 2;
	                    c[(c[h >> 2] | 0) + 12 >> 2] = 0;
	                    c[(c[h >> 2] | 0) + 16 >> 2] = 0;
	                    c[e >> 2] = c[h >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                return 0
	            }

	            function fA(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f + 40 | 0;
	                h = f + 36 | 0;
	                j = f + 32 | 0;
	                k = f + 28 | 0;
	                l = f + 24 | 0;
	                m = f + 20 | 0;
	                n = f + 16 | 0;
	                o = f + 12 | 0;
	                p = f + 8 | 0;
	                q = f + 4 | 0;
	                r = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if (!(c[l >> 2] | 0)) {
	                    c[(c[h >> 2] | 0) + 8 >> 2] = 1450;
	                    Yz(c[h >> 2] | 0, 139280);
	                    c[g >> 2] = -1;
	                    s = c[g >> 2] | 0;
	                    i = f;
	                    return s | 0
	                }
	                if ((c[(c[l >> 2] | 0) + 4 >> 2] | 0) == 4) {
	                    if ((iA(c[h >> 2] | 0, c[l >> 2] | 0) | 0) < 0) {
	                        c[g >> 2] = -1;
	                        s = c[g >> 2] | 0;
	                        i = f;
	                        return s | 0
	                    }
	                    if (((c[k >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 44 >> 2] | 0) != (c[k >> 2] | 0) : 0) ? (c[(c[l >> 2] | 0) + 8 >> 2] | 0) != 8 : 0)jA(c[h >> 2] | 0, c[(c[l >> 2] | 0) + 44 >> 2] | 0, c[k >> 2] | 0);
	                    e = c[(c[l >> 2] | 0) + 8 >> 2] | 0;
	                    do if ((e | 0) == 8) {
	                        if (c[k >> 2] | 0)c[p >> 2] = c[k >> 2]; else {
	                            c[p >> 2] = Vz(c[h >> 2] | 0) | 0;
	                            Wz(c[h >> 2] | 0, c[p >> 2] | 0) | 0
	                        }
	                        do if ((c[(c[l >> 2] | 0) + 12 >> 2] | 0) == 0 ? (c[(c[l >> 2] | 0) + 40 >> 2] | 0) == 0 : 0) {
	                            c[q >> 2] = zA(c[h >> 2] | 0, c[l >> 2] | 0) | 0;
	                            if (!(c[q >> 2] | 0)) {
	                                c[g >> 2] = -1;
	                                s = c[g >> 2] | 0;
	                                i = f;
	                                return s | 0
	                            }
	                            c[(c[q >> 2] | 0) + 8 >> 2] = 2;
	                            c[(c[q >> 2] | 0) + 12 >> 2] = 0;
	                            c[(c[q >> 2] | 0) + 16 >> 2] = 0;
	                            if ((fA(c[h >> 2] | 0, c[(c[l >> 2] | 0) + 36 >> 2] | 0, 0, c[q >> 2] | 0) | 0) >= 0) {
	                                c[o >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                                c[n >> 2] = gA(c[h >> 2] | 0) | 0;
	                                c[(c[(c[h >> 2] | 0) + 64 >> 2] | 0) + (c[n >> 2] << 3) >> 2] = (c[(c[l >> 2] | 0) + 12 >> 2] | 0) - 1;
	                                c[(c[(c[h >> 2] | 0) + 64 >> 2] | 0) + (c[n >> 2] << 3) + 4 >> 2] = (c[(c[l >> 2] | 0) + 16 >> 2] | 0) - 1;
	                                lA(c[h >> 2] | 0, c[o >> 2] | 0, c[(c[l >> 2] | 0) + 44 >> 2] | 0, c[n >> 2] | 0);
	                                mA(c[h >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0, c[n >> 2] | 0);
	                                jA(c[h >> 2] | 0, c[(c[l >> 2] | 0) + 36 >> 2] | 0, c[p >> 2] | 0);
	                                break
	                            }
	                            c[g >> 2] = -1;
	                            s = c[g >> 2] | 0;
	                            i = f;
	                            return s | 0
	                        } else t = 26; while (0);
	                        if ((t | 0) == 26 ? (c[n >> 2] = gA(c[h >> 2] | 0) | 0, c[(c[(c[h >> 2] | 0) + 64 >> 2] | 0) + (c[n >> 2] << 3) >> 2] = (c[(c[l >> 2] | 0) + 12 >> 2] | 0) - 1, c[(c[(c[h >> 2] | 0) + 64 >> 2] | 0) + (c[n >> 2] << 3) + 4 >> 2] = (c[(c[l >> 2] | 0) + 16 >> 2] | 0) - 1, lA(c[h >> 2] | 0, c[(c[l >> 2] | 0) + 44 >> 2] | 0, c[(c[l >> 2] | 0) + 36 >> 2] | 0, c[n >> 2] | 0), mA(c[h >> 2] | 0, c[(c[l >> 2] | 0) + 44 >> 2] | 0, c[p >> 2] | 0, c[n >> 2] | 0), (c[(c[l >> 2] | 0) + 12 >> 2] | 0) == 0) : 0)jA(c[h >> 2] | 0, c[(c[l >> 2] | 0) + 40 >> 2] | 0, c[p >> 2] | 0);
	                        c[(c[l >> 2] | 0) + 12 >> 2] = 0;
	                        c[(c[l >> 2] | 0) + 16 >> 2] = 0;
	                        c[(c[l >> 2] | 0) + 8 >> 2] = 2;
	                        c[(c[h >> 2] | 0) + 24 >> 2] = c[p >> 2]
	                    } else if ((e | 0) == 4) {
	                        c[(c[l >> 2] | 0) + 8 >> 2] = 2;
	                        jA(c[h >> 2] | 0, c[(c[l >> 2] | 0) + 36 >> 2] | 0, c[(c[l >> 2] | 0) + 44 >> 2] | 0);
	                        jA(c[h >> 2] | 0, c[(c[l >> 2] | 0) + 44 >> 2] | 0, c[(c[l >> 2] | 0) + 36 >> 2] | 0)
	                    } else if ((e | 0) == 3) {
	                        c[(c[l >> 2] | 0) + 8 >> 2] = 2;
	                        d = c[h >> 2] | 0;
	                        b = c[(c[l >> 2] | 0) + 36 >> 2] | 0;
	                        if (!(c[k >> 2] | 0)) {
	                            jA(d, b, 0);
	                            jA(c[h >> 2] | 0, c[(c[l >> 2] | 0) + 44 >> 2] | 0, c[(c[h >> 2] | 0) + 24 >> 2] | 0);
	                            break
	                        } else {
	                            jA(d, b, c[k >> 2] | 0);
	                            break
	                        }
	                    } else if ((e | 0) == 5) {
	                        c[(c[l >> 2] | 0) + 8 >> 2] = 2;
	                        jA(c[h >> 2] | 0, c[(c[l >> 2] | 0) + 44 >> 2] | 0, c[(c[l >> 2] | 0) + 36 >> 2] | 0)
	                    } while (0);
	                    c[g >> 2] = 0;
	                    s = c[g >> 2] | 0;
	                    i = f;
	                    return s | 0
	                } else {
	                    if (((c[(c[l >> 2] | 0) + 12 >> 2] | 0) == 0 ? (c[(c[l >> 2] | 0) + 16 >> 2] | 0) == 0 : 0) ? (c[(c[l >> 2] | 0) + 8 >> 2] | 0) == 8 : 0) {
	                        do if (!(c[k >> 2] | 0)) {
	                            c[k >> 2] = Vz(c[h >> 2] | 0) | 0;
	                            if (c[k >> 2] | 0) {
	                                Wz(c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                                break
	                            }
	                            c[g >> 2] = -1;
	                            s = c[g >> 2] | 0;
	                            i = f;
	                            return s | 0
	                        } while (0);
	                        jA(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0);
	                        c[(c[h >> 2] | 0) + 24 >> 2] = c[k >> 2];
	                        dA(c[l >> 2] | 0);
	                        c[g >> 2] = 0;
	                        s = c[g >> 2] | 0;
	                        i = f;
	                        return s | 0
	                    }
	                    do if (!(c[k >> 2] | 0)) {
	                        c[k >> 2] = Vz(c[h >> 2] | 0) | 0;
	                        if (c[k >> 2] | 0) {
	                            Wz(c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                            break
	                        }
	                        c[g >> 2] = -1;
	                        s = c[g >> 2] | 0;
	                        i = f;
	                        return s | 0
	                    } while (0);
	                    c[m >> 2] = c[k >> 2];
	                    if (!((c[(c[l >> 2] | 0) + 8 >> 2] | 0) != 4 ? (c[(c[l >> 2] | 0) + 8 >> 2] | 0) != 5 : 0))t = 44;
	                    do if ((t | 0) == 44) {
	                        c[r >> 2] = Vz(c[h >> 2] | 0) | 0;
	                        if (c[r >> 2] | 0) {
	                            Wz(c[h >> 2] | 0, c[r >> 2] | 0) | 0;
	                            jA(c[h >> 2] | 0, c[r >> 2] | 0, c[k >> 2] | 0);
	                            c[k >> 2] = c[r >> 2];
	                            break
	                        }
	                        c[g >> 2] = -1;
	                        s = c[g >> 2] | 0;
	                        i = f;
	                        return s | 0
	                    } while (0);
	                    if ((iA(c[h >> 2] | 0, c[l >> 2] | 0) | 0) < 0) {
	                        c[g >> 2] = -1;
	                        s = c[g >> 2] | 0;
	                        i = f;
	                        return s | 0
	                    }
	                    hA(c[h >> 2] | 0, c[j >> 2] | 0, c[l >> 2] | 0, c[k >> 2] | 0, -1, -1);
	                    c[(c[h >> 2] | 0) + 24 >> 2] = c[m >> 2];
	                    m = c[(c[l >> 2] | 0) + 8 >> 2] | 0;
	                    if ((m | 0) == 5) {
	                        c[(c[l >> 2] | 0) + 8 >> 2] = 2;
	                        hA(c[h >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[k >> 2] | 0, -1, -1)
	                    } else if ((m | 0) == 3) {
	                        c[(c[l >> 2] | 0) + 8 >> 2] = 2;
	                        jA(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0)
	                    } else if ((m | 0) == 4) {
	                        c[(c[l >> 2] | 0) + 8 >> 2] = 2;
	                        jA(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0);
	                        hA(c[h >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[k >> 2] | 0, -1, -1)
	                    }
	                    c[g >> 2] = 0;
	                    s = c[g >> 2] | 0;
	                    i = f;
	                    return s | 0
	                }
	                return 0
	            }

	            function gA(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                a = c[e >> 2] | 0;
	                do if (!(c[(c[e >> 2] | 0) + 56 >> 2] | 0)) {
	                    c[a + 56 >> 2] = 4;
	                    g = Cb[c[135744 >> 2] & 511](c[(c[e >> 2] | 0) + 56 >> 2] << 3) | 0;
	                    c[(c[e >> 2] | 0) + 64 >> 2] = g;
	                    if (!(c[(c[e >> 2] | 0) + 64 >> 2] | 0)) {
	                        Qz(c[e >> 2] | 0, 139168);
	                        c[(c[e >> 2] | 0) + 56 >> 2] = 0;
	                        c[d >> 2] = -1;
	                        h = c[d >> 2] | 0;
	                        i = b;
	                        return h | 0
	                    }
	                } else if ((c[a + 60 >> 2] | 0) >= (c[(c[e >> 2] | 0) + 56 >> 2] | 0)) {
	                    g = (c[e >> 2] | 0) + 56 | 0;
	                    c[g >> 2] = c[g >> 2] << 1;
	                    c[f >> 2] = Hb[c[135760 >> 2] & 511](c[(c[e >> 2] | 0) + 64 >> 2] | 0, c[(c[e >> 2] | 0) + 56 >> 2] << 3) | 0;
	                    if (c[f >> 2] | 0) {
	                        c[(c[e >> 2] | 0) + 64 >> 2] = c[f >> 2];
	                        break
	                    }
	                    Qz(c[e >> 2] | 0, 139168);
	                    g = (c[e >> 2] | 0) + 56 | 0;
	                    c[g >> 2] = (c[g >> 2] | 0) / 2 | 0;
	                    c[d >> 2] = -1;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                } while (0);
	                c[(c[(c[e >> 2] | 0) + 64 >> 2] | 0) + (c[(c[e >> 2] | 0) + 60 >> 2] << 3) >> 2] = -1;
	                c[(c[(c[e >> 2] | 0) + 64 >> 2] | 0) + (c[(c[e >> 2] | 0) + 60 >> 2] << 3) + 4 >> 2] = -1;
	                f = (c[e >> 2] | 0) + 60 | 0;
	                e = c[f >> 2] | 0;
	                c[f >> 2] = e + 1;
	                c[d >> 2] = e;
	                h = c[d >> 2] | 0;
	                i = b;
	                return h | 0
	            }

	            function hA(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h + 32 | 0;
	                k = h + 28 | 0;
	                l = h + 24 | 0;
	                m = h + 20 | 0;
	                n = h + 16 | 0;
	                o = h + 12 | 0;
	                p = h + 8 | 0;
	                q = h + 4 | 0;
	                r = h;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                if (!(c[k >> 2] | 0)) {
	                    c[(c[j >> 2] | 0) + 8 >> 2] = 1450;
	                    Yz(c[j >> 2] | 0, 139192);
	                    i = h;
	                    return
	                }
	                if (!(c[m >> 2] | 0)) {
	                    c[(c[j >> 2] | 0) + 8 >> 2] = 1450;
	                    Yz(c[j >> 2] | 0, 139224);
	                    i = h;
	                    return
	                }
	                c[p >> 2] = (c[(c[k >> 2] | 0) + 24 >> 2] | 0) - 1;
	                while (1) {
	                    if ((c[p >> 2] | 0) < 0)break;
	                    c[q >> 2] = (c[(c[k >> 2] | 0) + 28 >> 2] | 0) + ((c[p >> 2] | 0) * 20 | 0);
	                    if ((((c[c[q >> 2] >> 2] | 0) == (c[l >> 2] | 0) ? (c[(c[q >> 2] | 0) + 4 >> 2] | 0) == (c[(c[m >> 2] | 0) + 16 >> 2] | 0) : 0) ? (c[(c[q >> 2] | 0) + 8 >> 2] | 0) == (c[n >> 2] | 0) : 0) ? (c[(c[q >> 2] | 0) + 12 >> 2] | 0) == (c[o >> 2] | 0) : 0) {
	                        s = 20;
	                        break
	                    }
	                    c[p >> 2] = (c[p >> 2] | 0) + -1
	                }
	                if ((s | 0) == 20) {
	                    i = h;
	                    return
	                }
	                s = c[k >> 2] | 0;
	                do if (!(c[(c[k >> 2] | 0) + 20 >> 2] | 0)) {
	                    c[s + 20 >> 2] = 8;
	                    p = Cb[c[135744 >> 2] & 511]((c[(c[k >> 2] | 0) + 20 >> 2] | 0) * 20 | 0) | 0;
	                    c[(c[k >> 2] | 0) + 28 >> 2] = p;
	                    if (!(c[(c[k >> 2] | 0) + 28 >> 2] | 0)) {
	                        Qz(c[j >> 2] | 0, 139256);
	                        c[(c[k >> 2] | 0) + 20 >> 2] = 0;
	                        i = h;
	                        return
	                    }
	                } else if ((c[s + 24 >> 2] | 0) >= (c[(c[k >> 2] | 0) + 20 >> 2] | 0)) {
	                    p = (c[k >> 2] | 0) + 20 | 0;
	                    c[p >> 2] = c[p >> 2] << 1;
	                    c[r >> 2] = Hb[c[135760 >> 2] & 511](c[(c[k >> 2] | 0) + 28 >> 2] | 0, (c[(c[k >> 2] | 0) + 20 >> 2] | 0) * 20 | 0) | 0;
	                    if (c[r >> 2] | 0) {
	                        c[(c[k >> 2] | 0) + 28 >> 2] = c[r >> 2];
	                        break
	                    }
	                    Qz(c[j >> 2] | 0, 139256);
	                    p = (c[k >> 2] | 0) + 20 | 0;
	                    c[p >> 2] = (c[p >> 2] | 0) / 2 | 0;
	                    i = h;
	                    return
	                } while (0);
	                c[(c[(c[k >> 2] | 0) + 28 >> 2] | 0) + ((c[(c[k >> 2] | 0) + 24 >> 2] | 0) * 20 | 0) >> 2] = c[l >> 2];
	                c[(c[(c[k >> 2] | 0) + 28 >> 2] | 0) + ((c[(c[k >> 2] | 0) + 24 >> 2] | 0) * 20 | 0) + 4 >> 2] = c[(c[m >> 2] | 0) + 16 >> 2];
	                c[(c[(c[k >> 2] | 0) + 28 >> 2] | 0) + ((c[(c[k >> 2] | 0) + 24 >> 2] | 0) * 20 | 0) + 8 >> 2] = c[n >> 2];
	                c[(c[(c[k >> 2] | 0) + 28 >> 2] | 0) + ((c[(c[k >> 2] | 0) + 24 >> 2] | 0) * 20 | 0) + 12 >> 2] = c[o >> 2];
	                c[(c[(c[k >> 2] | 0) + 28 >> 2] | 0) + ((c[(c[k >> 2] | 0) + 24 >> 2] | 0) * 20 | 0) + 16 >> 2] = 0;
	                o = (c[k >> 2] | 0) + 24 | 0;
	                c[o >> 2] = (c[o >> 2] | 0) + 1;
	                AA(c[j >> 2] | 0, c[m >> 2] | 0, c[(c[k >> 2] | 0) + 16 >> 2] | 0);
	                i = h;
	                return
	            }

	            function iA(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                b = c[f >> 2] | 0;
	                if (!(c[g >> 2] | 0)) {
	                    c[b + 8 >> 2] = 1450;
	                    Yz(c[f >> 2] | 0, 139128);
	                    c[e >> 2] = -1;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                a = c[f >> 2] | 0;
	                do if (!(c[b + 32 >> 2] | 0)) {
	                    c[a + 32 >> 2] = 4;
	                    k = Cb[c[135744 >> 2] & 511](c[(c[f >> 2] | 0) + 32 >> 2] << 2) | 0;
	                    c[(c[f >> 2] | 0) + 40 >> 2] = k;
	                    if (!(c[(c[f >> 2] | 0) + 40 >> 2] | 0)) {
	                        Qz(c[f >> 2] | 0, 139152);
	                        c[(c[f >> 2] | 0) + 32 >> 2] = 0;
	                        c[e >> 2] = -1;
	                        j = c[e >> 2] | 0;
	                        i = d;
	                        return j | 0
	                    }
	                } else if ((c[a + 36 >> 2] | 0) >= (c[(c[f >> 2] | 0) + 32 >> 2] | 0)) {
	                    k = (c[f >> 2] | 0) + 32 | 0;
	                    c[k >> 2] = c[k >> 2] << 1;
	                    c[h >> 2] = Hb[c[135760 >> 2] & 511](c[(c[f >> 2] | 0) + 40 >> 2] | 0, c[(c[f >> 2] | 0) + 32 >> 2] << 2) | 0;
	                    if (c[h >> 2] | 0) {
	                        c[(c[f >> 2] | 0) + 40 >> 2] = c[h >> 2];
	                        break
	                    }
	                    Qz(c[f >> 2] | 0, 139168);
	                    k = (c[f >> 2] | 0) + 32 | 0;
	                    c[k >> 2] = (c[k >> 2] | 0) / 2 | 0;
	                    c[e >> 2] = -1;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } while (0);
	                c[c[g >> 2] >> 2] = c[(c[f >> 2] | 0) + 36 >> 2];
	                h = c[g >> 2] | 0;
	                g = (c[f >> 2] | 0) + 36 | 0;
	                a = c[g >> 2] | 0;
	                c[g >> 2] = a + 1;
	                c[(c[(c[f >> 2] | 0) + 40 >> 2] | 0) + (a << 2) >> 2] = h;
	                c[e >> 2] = 0;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function jA(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if (!(c[h >> 2] | 0)) {
	                    c[h >> 2] = Vz(c[f >> 2] | 0) | 0;
	                    Wz(c[f >> 2] | 0, c[h >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 24 >> 2] = c[h >> 2]
	                }
	                hA(c[f >> 2] | 0, c[g >> 2] | 0, 0, c[h >> 2] | 0, -1, -1);
	                i = e;
	                return
	            }

	            function kA(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 12 | 0;
	                h = f + 8 | 0;
	                j = f + 4 | 0;
	                k = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                if (!(c[j >> 2] | 0)) {
	                    c[j >> 2] = Vz(c[g >> 2] | 0) | 0;
	                    Wz(c[g >> 2] | 0, c[j >> 2] | 0) | 0;
	                    c[(c[g >> 2] | 0) + 24 >> 2] = c[j >> 2]
	                }
	                e = c[g >> 2] | 0;
	                g = c[h >> 2] | 0;
	                h = c[j >> 2] | 0;
	                if (c[k >> 2] | 0) {
	                    hA(e, g, 0, h, -1, 1193047);
	                    i = f;
	                    return
	                } else {
	                    hA(e, g, 0, h, -1, 1193046);
	                    i = f;
	                    return
	                }
	            }

	            function lA(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 12 | 0;
	                h = f + 8 | 0;
	                j = f + 4 | 0;
	                k = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                if (!(c[j >> 2] | 0)) {
	                    c[j >> 2] = Vz(c[g >> 2] | 0) | 0;
	                    Wz(c[g >> 2] | 0, c[j >> 2] | 0) | 0;
	                    c[(c[g >> 2] | 0) + 24 >> 2] = c[j >> 2]
	                }
	                hA(c[g >> 2] | 0, c[h >> 2] | 0, 0, c[j >> 2] | 0, c[k >> 2] | 0, -1);
	                i = f;
	                return
	            }

	            function mA(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 12 | 0;
	                h = f + 8 | 0;
	                j = f + 4 | 0;
	                k = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                if (!(c[j >> 2] | 0)) {
	                    c[j >> 2] = Vz(c[g >> 2] | 0) | 0;
	                    Wz(c[g >> 2] | 0, c[j >> 2] | 0) | 0;
	                    c[(c[g >> 2] | 0) + 24 >> 2] = c[j >> 2]
	                }
	                hA(c[g >> 2] | 0, c[h >> 2] | 0, 0, c[j >> 2] | 0, -1, c[k >> 2] | 0);
	                i = f;
	                return
	            }

	            function nA(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                d = c[f >> 2] | 0;
	                do if (!(c[(c[f >> 2] | 0) + 48 >> 2] | 0)) {
	                    c[d + 48 >> 2] = 4;
	                    b = Cb[c[135744 >> 2] & 511](c[(c[f >> 2] | 0) + 48 >> 2] << 3) | 0;
	                    c[(c[f >> 2] | 0) + 68 >> 2] = b;
	                    if (!(c[(c[f >> 2] | 0) + 68 >> 2] | 0)) {
	                        Qz(0, 140240);
	                        c[(c[f >> 2] | 0) + 48 >> 2] = 0;
	                        i = e;
	                        return
	                    }
	                } else if (((c[d + 52 >> 2] | 0) + 1 | 0) >= (c[(c[f >> 2] | 0) + 48 >> 2] | 0)) {
	                    b = (c[f >> 2] | 0) + 48 | 0;
	                    c[b >> 2] = c[b >> 2] << 1;
	                    c[j >> 2] = Hb[c[135760 >> 2] & 511](c[(c[f >> 2] | 0) + 68 >> 2] | 0, c[(c[f >> 2] | 0) + 48 >> 2] << 3) | 0;
	                    if (c[j >> 2] | 0) {
	                        c[(c[f >> 2] | 0) + 68 >> 2] = c[j >> 2];
	                        break
	                    }
	                    Qz(0, 140240);
	                    b = (c[f >> 2] | 0) + 48 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) / 2 | 0;
	                    i = e;
	                    return
	                } while (0);
	                j = my(c[g >> 2] | 0) | 0;
	                c[(c[(c[f >> 2] | 0) + 68 >> 2] | 0) + (c[(c[f >> 2] | 0) + 52 >> 2] << 3) >> 2] = j;
	                c[(c[(c[f >> 2] | 0) + 68 >> 2] | 0) + (c[(c[f >> 2] | 0) + 52 >> 2] << 3) + 4 >> 2] = c[h >> 2];
	                h = (c[f >> 2] | 0) + 52 | 0;
	                c[h >> 2] = (c[h >> 2] | 0) + 1;
	                c[(c[(c[f >> 2] | 0) + 68 >> 2] | 0) + (c[(c[f >> 2] | 0) + 52 >> 2] << 3) >> 2] = 0;
	                c[(c[(c[f >> 2] | 0) + 68 >> 2] | 0) + (c[(c[f >> 2] | 0) + 52 >> 2] << 3) + 4 >> 2] = 0;
	                i = e;
	                return
	            }

	            function oA(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                if ((c[g >> 2] | 0) == (c[h >> 2] | 0)) {
	                    c[f >> 2] = 1;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                a:do b:do if ((d[c[g >> 2] >> 0] | 0 | 0) != (d[c[h >> 2] >> 0] | 0 | 0)) {
	                    if ((d[c[h >> 2] >> 0] | 0 | 0) == 42) {
	                        c[j >> 2] = c[h >> 2];
	                        c[h >> 2] = c[g >> 2];
	                        c[g >> 2] = c[j >> 2]
	                    }
	                    if (!(d[c[h >> 2] >> 0] | 0)) {
	                        l = 15;
	                        break a
	                    }
	                    if (!(d[c[g >> 2] >> 0] | 0)) {
	                        l = 15;
	                        break a
	                    }
	                    b = c[g >> 2] | 0;
	                    c[g >> 2] = b + 1;
	                    if ((d[b >> 0] | 0 | 0) != 42) {
	                        l = 15;
	                        break a
	                    }
	                    do {
	                        if ((d[c[h >> 2] >> 0] | 0 | 0) == 124)break b;
	                        c[h >> 2] = (c[h >> 2] | 0) + 1
	                    } while ((d[c[h >> 2] >> 0] | 0 | 0) != 0)
	                } else {
	                    c[g >> 2] = (c[g >> 2] | 0) + 1;
	                    c[h >> 2] = (c[h >> 2] | 0) + 1
	                } while (0); while ((d[c[h >> 2] >> 0] | 0 | 0) != 0);
	                if ((l | 0) == 15) {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                if (d[c[g >> 2] >> 0] | 0) {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                } else {
	                    c[f >> 2] = 1;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                return 0
	            }

	            function pA(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[d >> 2] = a;
	                if ((c[(c[d >> 2] | 0) + 88 >> 2] | 0) > 1e7) {
	                    i = b;
	                    return
	                }
	                a = (c[d >> 2] | 0) + 88 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + 1;
	                a = c[d >> 2] | 0;
	                do if (c[(c[d >> 2] | 0) + 32 >> 2] | 0) {
	                    if ((c[a + 36 >> 2] | 0) >= (c[(c[d >> 2] | 0) + 32 >> 2] | 0)) {
	                        c[f >> 2] = c[(c[d >> 2] | 0) + 32 >> 2];
	                        g = (c[d >> 2] | 0) + 32 | 0;
	                        c[g >> 2] = c[g >> 2] << 1;
	                        c[e >> 2] = Hb[c[135760 >> 2] & 511](c[(c[d >> 2] | 0) + 40 >> 2] | 0, c[(c[d >> 2] | 0) + 32 >> 2] << 4) | 0;
	                        if (c[e >> 2] | 0) {
	                            c[(c[d >> 2] | 0) + 40 >> 2] = c[e >> 2];
	                            c[e >> 2] = (c[(c[d >> 2] | 0) + 40 >> 2] | 0) + (c[f >> 2] << 4);
	                            cU(c[e >> 2] | 0, 0, (c[(c[d >> 2] | 0) + 32 >> 2] | 0) - (c[f >> 2] | 0) << 4 | 0) | 0;
	                            break
	                        }
	                        Qz(0, 139496);
	                        g = (c[d >> 2] | 0) + 32 | 0;
	                        c[g >> 2] = (c[g >> 2] | 0) / 2 | 0;
	                        i = b;
	                        return
	                    }
	                } else {
	                    c[a + 32 >> 2] = 4;
	                    g = Cb[c[135744 >> 2] & 511](c[(c[d >> 2] | 0) + 32 >> 2] << 4) | 0;
	                    c[(c[d >> 2] | 0) + 40 >> 2] = g;
	                    if (c[(c[d >> 2] | 0) + 40 >> 2] | 0) {
	                        cU(c[(c[d >> 2] | 0) + 40 >> 2] | 0, 0, c[(c[d >> 2] | 0) + 32 >> 2] << 4 | 0) | 0;
	                        break
	                    }
	                    Qz(0, 139496);
	                    c[(c[d >> 2] | 0) + 32 >> 2] = 0;
	                    i = b;
	                    return
	                } while (0);
	                c[(c[(c[d >> 2] | 0) + 40 >> 2] | 0) + (c[(c[d >> 2] | 0) + 36 >> 2] << 4) >> 2] = c[(c[d >> 2] | 0) + 20 >> 2];
	                c[(c[(c[d >> 2] | 0) + 40 >> 2] | 0) + (c[(c[d >> 2] | 0) + 36 >> 2] << 4) + 4 >> 2] = c[(c[d >> 2] | 0) + 56 >> 2];
	                c[(c[(c[d >> 2] | 0) + 40 >> 2] | 0) + (c[(c[d >> 2] | 0) + 36 >> 2] << 4) + 8 >> 2] = (c[(c[d >> 2] | 0) + 24 >> 2] | 0) + 1;
	                if ((c[(c[(c[d >> 2] | 0) + 8 >> 2] | 0) + 20 >> 2] | 0) > 0) {
	                    if ((c[(c[(c[d >> 2] | 0) + 40 >> 2] | 0) + (c[(c[d >> 2] | 0) + 36 >> 2] << 4) + 12 >> 2] | 0) == 0 ? (a = Cb[c[135744 >> 2] & 511](c[(c[(c[d >> 2] | 0) + 8 >> 2] | 0) + 20 >> 2] << 2) | 0, c[(c[(c[d >> 2] | 0) + 40 >> 2] | 0) + (c[(c[d >> 2] | 0) + 36 >> 2] << 4) + 12 >> 2] = a, (c[(c[(c[d >> 2] | 0) + 40 >> 2] | 0) + (c[(c[d >> 2] | 0) + 36 >> 2] << 4) + 12 >> 2] | 0) == 0) : 0) {
	                        Qz(0, 139496);
	                        c[c[d >> 2] >> 2] = -5;
	                        i = b;
	                        return
	                    }
	                    eU(c[(c[(c[d >> 2] | 0) + 40 >> 2] | 0) + (c[(c[d >> 2] | 0) + 36 >> 2] << 4) + 12 >> 2] | 0, c[(c[d >> 2] | 0) + 44 >> 2] | 0, c[(c[(c[d >> 2] | 0) + 8 >> 2] | 0) + 20 >> 2] << 2 | 0) | 0
	                }
	                a = (c[d >> 2] | 0) + 36 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + 1;
	                i = b;
	                return
	            }

	            function qA(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                c[d >> 2] = a;
	                a = c[d >> 2] | 0;
	                if ((c[(c[d >> 2] | 0) + 36 >> 2] | 0) <= 0) {
	                    c[a >> 2] = -1;
	                    i = b;
	                    return
	                }
	                e = a + 36 | 0;
	                c[e >> 2] = (c[e >> 2] | 0) + -1;
	                c[(c[d >> 2] | 0) + 20 >> 2] = c[(c[(c[d >> 2] | 0) + 40 >> 2] | 0) + (c[(c[d >> 2] | 0) + 36 >> 2] << 4) >> 2];
	                c[(c[d >> 2] | 0) + 56 >> 2] = c[(c[(c[d >> 2] | 0) + 40 >> 2] | 0) + (c[(c[d >> 2] | 0) + 36 >> 2] << 4) + 4 >> 2];
	                c[(c[d >> 2] | 0) + 24 >> 2] = c[(c[(c[d >> 2] | 0) + 40 >> 2] | 0) + (c[(c[d >> 2] | 0) + 36 >> 2] << 4) + 8 >> 2];
	                if ((c[(c[(c[d >> 2] | 0) + 8 >> 2] | 0) + 20 >> 2] | 0) <= 0) {
	                    i = b;
	                    return
	                }
	                if (!(c[(c[(c[d >> 2] | 0) + 40 >> 2] | 0) + (c[(c[d >> 2] | 0) + 36 >> 2] << 4) + 12 >> 2] | 0)) {
	                    Ka(c[o >> 2] | 0, 139464, b | 0) | 0;
	                    c[c[d >> 2] >> 2] = -6;
	                    i = b;
	                    return
	                }
	                if (!(c[(c[d >> 2] | 0) + 44 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                eU(c[(c[d >> 2] | 0) + 44 >> 2] | 0, c[(c[(c[d >> 2] | 0) + 40 >> 2] | 0) + (c[(c[d >> 2] | 0) + 36 >> 2] << 4) + 12 >> 2] | 0, c[(c[(c[d >> 2] | 0) + 8 >> 2] | 0) + 20 >> 2] << 2 | 0) | 0;
	                i = b;
	                return
	            }

	            function rA(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                c[k >> 2] = BA(c[g >> 2] | 0) | 0;
	                do if (c[k >> 2] | 0) {
	                    b = c[g >> 2] | 0;
	                    a = c[j >> 2] | 0;
	                    if ((d[c[(c[g >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) != 124 ? (d[c[(c[g >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) != 41 : 0)l = 0; else l = c[h >> 2] | 0;
	                    if ((fA(b, a, l, c[(c[g >> 2] | 0) + 28 >> 2] | 0) | 0) >= 0) {
	                        c[j >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                        c[(c[g >> 2] | 0) + 28 >> 2] = 0;
	                        break
	                    }
	                    c[f >> 2] = -1;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                } while (0);
	                while (1) {
	                    if (!(c[k >> 2] | 0)) {
	                        n = 17;
	                        break
	                    }
	                    if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                        n = 17;
	                        break
	                    }
	                    c[k >> 2] = BA(c[g >> 2] | 0) | 0;
	                    if (!(c[k >> 2] | 0))continue;
	                    l = c[g >> 2] | 0;
	                    a = c[j >> 2] | 0;
	                    if ((d[c[(c[g >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) != 124 ? (d[c[(c[g >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) != 41 : 0)o = 0; else o = c[h >> 2] | 0;
	                    if ((fA(l, a, o, c[(c[g >> 2] | 0) + 28 >> 2] | 0) | 0) < 0) {
	                        n = 15;
	                        break
	                    }
	                    c[j >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                    c[(c[g >> 2] | 0) + 28 >> 2] = 0
	                }
	                if ((n | 0) == 15) {
	                    c[f >> 2] = -1;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                } else if ((n | 0) == 17) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                return 0
	            }

	            function sA(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 24 | 0;
	                e = b + 20 | 0;
	                f = b + 16 | 0;
	                g = b + 12 | 0;
	                h = b + 8 | 0;
	                j = b + 4 | 0;
	                k = b;
	                c[d >> 2] = a;
	                c[e >> 2] = 0;
	                while (1) {
	                    if ((c[e >> 2] | 0) >= (c[(c[d >> 2] | 0) + 48 >> 2] | 0))break;
	                    c[j >> 2] = c[(c[(c[d >> 2] | 0) + 52 >> 2] | 0) + (c[e >> 2] << 2) >> 2];
	                    if (((((((((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 24 >> 2] | 0) == 1 : 0) ? (c[c[j >> 2] >> 2] | 0) != 5 : 0) ? (c[c[(c[j >> 2] | 0) + 28 >> 2] >> 2] | 0) == 0 : 0) ? (c[(c[(c[j >> 2] | 0) + 28 >> 2] | 0) + 4 >> 2] | 0) >= 0 : 0) ? (c[(c[(c[j >> 2] | 0) + 28 >> 2] | 0) + 4 >> 2] | 0) != (c[e >> 2] | 0) : 0) ? (c[(c[(c[j >> 2] | 0) + 28 >> 2] | 0) + 8 >> 2] | 0) < 0 : 0) ? (c[(c[(c[j >> 2] | 0) + 28 >> 2] | 0) + 12 >> 2] | 0) < 0 : 0) ? (c[h >> 2] = c[(c[(c[j >> 2] | 0) + 28 >> 2] | 0) + 4 >> 2], (c[c[j >> 2] >> 2] | 0) != 1) : 0) {
	                        c[f >> 2] = 0;
	                        while (1) {
	                            if ((c[f >> 2] | 0) >= (c[(c[j >> 2] | 0) + 36 >> 2] | 0))break;
	                            c[k >> 2] = c[(c[(c[d >> 2] | 0) + 52 >> 2] | 0) + (c[(c[(c[j >> 2] | 0) + 40 >> 2] | 0) + (c[f >> 2] << 2) >> 2] << 2) >> 2];
	                            c[g >> 2] = 0;
	                            while (1) {
	                                if ((c[g >> 2] | 0) >= (c[(c[k >> 2] | 0) + 24 >> 2] | 0))break;
	                                if ((c[(c[(c[k >> 2] | 0) + 28 >> 2] | 0) + ((c[g >> 2] | 0) * 20 | 0) + 4 >> 2] | 0) == (c[e >> 2] | 0)) {
	                                    c[(c[(c[k >> 2] | 0) + 28 >> 2] | 0) + ((c[g >> 2] | 0) * 20 | 0) + 4 >> 2] = -1;
	                                    hA(c[d >> 2] | 0, c[k >> 2] | 0, c[(c[(c[k >> 2] | 0) + 28 >> 2] | 0) + ((c[g >> 2] | 0) * 20 | 0) >> 2] | 0, c[(c[(c[d >> 2] | 0) + 52 >> 2] | 0) + (c[h >> 2] << 2) >> 2] | 0, c[(c[(c[k >> 2] | 0) + 28 >> 2] | 0) + ((c[g >> 2] | 0) * 20 | 0) + 8 >> 2] | 0, c[(c[(c[k >> 2] | 0) + 28 >> 2] | 0) + ((c[g >> 2] | 0) * 20 | 0) + 12 >> 2] | 0)
	                                }
	                                c[g >> 2] = (c[g >> 2] | 0) + 1
	                            }
	                            c[f >> 2] = (c[f >> 2] | 0) + 1
	                        }
	                        if ((c[c[j >> 2] >> 2] | 0) == 2)c[c[(c[(c[d >> 2] | 0) + 52 >> 2] | 0) + (c[h >> 2] << 2) >> 2] >> 2] = 2;
	                        c[(c[j >> 2] | 0) + 24 >> 2] = 0;
	                        c[c[j >> 2] >> 2] = 5
	                    }
	                    c[e >> 2] = (c[e >> 2] | 0) + 1
	                }
	                i = b;
	                return
	            }

	            function tA(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f + 32 | 0;
	                h = f + 28 | 0;
	                j = f + 24 | 0;
	                k = f + 20 | 0;
	                l = f + 16 | 0;
	                m = f + 12 | 0;
	                n = f + 8 | 0;
	                o = f + 4 | 0;
	                p = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[m >> 2] = c[(c[(c[g >> 2] | 0) + 52 >> 2] | 0) + (c[h >> 2] << 2) >> 2];
	                if (!(c[m >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                c[n >> 2] = c[(c[(c[g >> 2] | 0) + 52 >> 2] | 0) + (c[j >> 2] << 2) >> 2];
	                if (!(c[n >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                if ((c[(c[n >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                    i = f;
	                    return
	                }
	                if ((c[(c[n >> 2] | 0) + 4 >> 2] | 0) == 2) {
	                    i = f;
	                    return
	                }
	                c[(c[n >> 2] | 0) + 4 >> 2] = 2;
	                if ((c[c[n >> 2] >> 2] | 0) == 2)c[c[m >> 2] >> 2] = 2;
	                c[l >> 2] = 0;
	                while (1) {
	                    if ((c[l >> 2] | 0) >= (c[(c[n >> 2] | 0) + 24 >> 2] | 0))break;
	                    do if ((c[(c[(c[n >> 2] | 0) + 28 >> 2] | 0) + ((c[l >> 2] | 0) * 20 | 0) + 4 >> 2] | 0) >= 0) {
	                        j = c[(c[(c[n >> 2] | 0) + 28 >> 2] | 0) + ((c[l >> 2] | 0) * 20 | 0) + 4 >> 2] | 0;
	                        if (c[(c[(c[n >> 2] | 0) + 28 >> 2] | 0) + ((c[l >> 2] | 0) * 20 | 0) >> 2] | 0) {
	                            c[p >> 2] = j;
	                            e = c[g >> 2] | 0;
	                            d = c[m >> 2] | 0;
	                            b = c[(c[(c[n >> 2] | 0) + 28 >> 2] | 0) + ((c[l >> 2] | 0) * 20 | 0) >> 2] | 0;
	                            a = c[(c[(c[g >> 2] | 0) + 52 >> 2] | 0) + (c[p >> 2] << 2) >> 2] | 0;
	                            if ((c[(c[(c[n >> 2] | 0) + 28 >> 2] | 0) + ((c[l >> 2] | 0) * 20 | 0) + 8 >> 2] | 0) >= 0) {
	                                hA(e, d, b, a, c[(c[(c[n >> 2] | 0) + 28 >> 2] | 0) + ((c[l >> 2] | 0) * 20 | 0) + 8 >> 2] | 0, -1);
	                                break
	                            } else {
	                                hA(e, d, b, a, c[k >> 2] | 0, -1);
	                                break
	                            }
	                        }
	                        if ((j | 0) != (c[h >> 2] | 0)) {
	                            j = (c[(c[n >> 2] | 0) + 28 >> 2] | 0) + ((c[l >> 2] | 0) * 20 | 0) | 0;
	                            if ((c[(c[(c[n >> 2] | 0) + 28 >> 2] | 0) + ((c[l >> 2] | 0) * 20 | 0) + 12 >> 2] | 0) >= 0) {
	                                c[o >> 2] = c[j + 4 >> 2];
	                                hA(c[g >> 2] | 0, c[m >> 2] | 0, 0, c[(c[(c[g >> 2] | 0) + 52 >> 2] | 0) + (c[o >> 2] << 2) >> 2] | 0, -1, c[(c[(c[n >> 2] | 0) + 28 >> 2] | 0) + ((c[l >> 2] | 0) * 20 | 0) + 12 >> 2] | 0);
	                                break
	                            }
	                            a = c[g >> 2] | 0;
	                            b = c[h >> 2] | 0;
	                            d = c[(c[(c[n >> 2] | 0) + 28 >> 2] | 0) + ((c[l >> 2] | 0) * 20 | 0) + 4 >> 2] | 0;
	                            if ((c[j + 8 >> 2] | 0) >= 0) {
	                                tA(a, b, d, c[(c[(c[n >> 2] | 0) + 28 >> 2] | 0) + ((c[l >> 2] | 0) * 20 | 0) + 8 >> 2] | 0);
	                                break
	                            } else {
	                                tA(a, b, d, c[k >> 2] | 0);
	                                break
	                            }
	                        }
	                    } while (0);
	                    c[l >> 2] = (c[l >> 2] | 0) + 1
	                }
	                c[(c[n >> 2] | 0) + 4 >> 2] = 0;
	                i = f;
	                return
	            }

	            function uA(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 28 | 0;
	                g = d + 24 | 0;
	                h = d + 20 | 0;
	                j = d + 16 | 0;
	                k = d + 12 | 0;
	                l = d + 8 | 0;
	                m = d + 4 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[k >> 2] = 0;
	                do if (c[g >> 2] | 0) {
	                    b = c[h >> 2] | 0;
	                    if ((c[h >> 2] | 0) < 256) {
	                        if (!(9 <= (b | 0) & (c[h >> 2] | 0) <= 10 | (c[h >> 2] | 0) == 13 | 32 <= (c[h >> 2] | 0)))break
	                    } else if ((!(256 <= (b | 0) & (c[h >> 2] | 0) <= 55295) ? !(57344 <= (c[h >> 2] | 0) & (c[h >> 2] | 0) <= 65533) : 0) ? !(65536 <= (c[h >> 2] | 0) & (c[h >> 2] | 0) <= 1114111) : 0)break;
	                    switch (c[(c[g >> 2] | 0) + 4 >> 2] | 0) {
	                        case 136:
	                        case 135:
	                        case 134:
	                        case 133:
	                        case 132:
	                        case 131:
	                        case 130:
	                        case 129:
	                        case 128:
	                        case 127:
	                        case 126:
	                        case 125:
	                        case 124:
	                        case 123:
	                        case 122:
	                        case 121:
	                        case 120:
	                        case 119:
	                        case 118:
	                        case 117:
	                        case 116:
	                        case 115:
	                        case 114:
	                        case 113:
	                        case 112:
	                        case 111:
	                        case 110:
	                        case 109:
	                        case 108:
	                        case 107:
	                        case 106:
	                        case 105:
	                        case 104:
	                        case 103:
	                        case 102:
	                        case 101:
	                        case 100:
	                        case 16:
	                        case 15:
	                        case 14:
	                        case 13:
	                        case 12:
	                        case 11:
	                        case 10:
	                        case 9:
	                        case 8:
	                        case 7:
	                        case 6:
	                        {
	                            c[k >> 2] = CA(c[(c[g >> 2] | 0) + 4 >> 2] | 0, c[h >> 2] | 0, 0, 0, 0, c[(c[g >> 2] | 0) + 20 >> 2] | 0) | 0;
	                            if (c[(c[g >> 2] | 0) + 28 >> 2] | 0)c[k >> 2] = ((c[k >> 2] | 0) != 0 ^ 1) & 1;
	                            break
	                        }
	                        case 2:
	                        {
	                            c[f >> 2] = (c[h >> 2] | 0) == (c[(c[g >> 2] | 0) + 32 >> 2] | 0) & 1;
	                            n = c[f >> 2] | 0;
	                            i = d;
	                            return n | 0
	                        }
	                        case 3:
	                        {
	                            c[m >> 2] = 0;
	                            c[j >> 2] = 0;
	                            a:while (1) {
	                                if ((c[j >> 2] | 0) >= (c[(c[g >> 2] | 0) + 52 >> 2] | 0)) {
	                                    o = 23;
	                                    break
	                                }
	                                c[l >> 2] = c[(c[(c[g >> 2] | 0) + 56 >> 2] | 0) + (c[j >> 2] << 2) >> 2];
	                                b = c[l >> 2] | 0;
	                                do if ((c[c[l >> 2] >> 2] | 0) == 2) {
	                                    c[k >> 2] = CA(c[b + 4 >> 2] | 0, c[h >> 2] | 0, 0, c[(c[l >> 2] | 0) + 8 >> 2] | 0, c[(c[l >> 2] | 0) + 12 >> 2] | 0, c[(c[l >> 2] | 0) + 16 >> 2] | 0) | 0;
	                                    if (c[k >> 2] | 0) {
	                                        o = 15;
	                                        break a
	                                    }
	                                } else {
	                                    a = (c[b >> 2] | 0) != 0;
	                                    c[k >> 2] = CA(c[(c[l >> 2] | 0) + 4 >> 2] | 0, c[h >> 2] | 0, 0, c[(c[l >> 2] | 0) + 8 >> 2] | 0, c[(c[l >> 2] | 0) + 12 >> 2] | 0, c[(c[l >> 2] | 0) + 16 >> 2] | 0) | 0;
	                                    p = c[k >> 2] | 0;
	                                    if (a) {
	                                        if (p) {
	                                            o = 19;
	                                            break a
	                                        }
	                                        c[m >> 2] = 1;
	                                        break
	                                    } else {
	                                        if (!p)break;
	                                        c[m >> 2] = 1;
	                                        break
	                                    }
	                                } while (0);
	                                c[j >> 2] = (c[j >> 2] | 0) + 1
	                            }
	                            if ((o | 0) == 15) {
	                                c[f >> 2] = 0;
	                                n = c[f >> 2] | 0;
	                                i = d;
	                                return n | 0
	                            } else if ((o | 0) == 19) {
	                                c[f >> 2] = 0;
	                                n = c[f >> 2] | 0;
	                                i = d;
	                                return n | 0
	                            } else if ((o | 0) == 23) {
	                                c[f >> 2] = c[m >> 2];
	                                n = c[f >> 2] | 0;
	                                i = d;
	                                return n | 0
	                            }
	                            break
	                        }
	                        case 5:
	                        {
	                            Wa(139376, e | 0) | 0;
	                            c[f >> 2] = -1;
	                            n = c[f >> 2] | 0;
	                            i = d;
	                            return n | 0
	                        }
	                        case 1:
	                        case 4:
	                        {
	                            c[f >> 2] = -1;
	                            n = c[f >> 2] | 0;
	                            i = d;
	                            return n | 0
	                        }
	                        default:
	                        {
	                        }
	                    }
	                    c[f >> 2] = c[k >> 2];
	                    n = c[f >> 2] | 0;
	                    i = d;
	                    return n | 0
	                } while (0);
	                c[f >> 2] = -1;
	                n = c[f >> 2] | 0;
	                i = d;
	                return n | 0
	            }

	            function vA(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 0;
	                if ((c[g >> 2] | 0) == (c[h >> 2] | 0)) {
	                    c[f >> 2] = 1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != (c[(c[h >> 2] | 0) + 4 >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                d = c[(c[g >> 2] | 0) + 4 >> 2] | 0;
	                do if ((d | 0) == 1)c[k >> 2] = 0; else if ((d | 0) == 2)c[k >> 2] = (c[(c[g >> 2] | 0) + 32 >> 2] | 0) == (c[(c[h >> 2] | 0) + 32 >> 2] | 0) & 1; else if ((d | 0) == 3)c[k >> 2] = 0; else if ((d | 0) == 5) {
	                    b = c[(c[g >> 2] | 0) + 20 >> 2] | 0;
	                    a = c[(c[h >> 2] | 0) + 20 >> 2] | 0;
	                    if (c[j >> 2] | 0) {
	                        c[k >> 2] = qy(b, a) | 0;
	                        break
	                    } else {
	                        c[k >> 2] = (b | 0) == (a | 0) & 1;
	                        break
	                    }
	                } while (0);
	                c[f >> 2] = c[k >> 2];
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function wA(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 40 | 0;
	                g = e + 36 | 0;
	                h = e + 32 | 0;
	                j = e + 28 | 0;
	                k = e + 24 | 0;
	                l = e + 20 | 0;
	                m = e + 16 | 0;
	                n = e + 12 | 0;
	                o = e + 8 | 0;
	                p = e + 4 | 0;
	                q = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 1;
	                if ((c[g >> 2] | 0) == (c[h >> 2] | 0)) {
	                    c[f >> 2] = 1;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                }
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                }
	                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 6 ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 6 : 0) {
	                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) >>> 0 > (c[(c[h >> 2] | 0) + 4 >> 2] | 0) >>> 0) {
	                        c[l >> 2] = c[g >> 2];
	                        c[g >> 2] = c[h >> 2];
	                        c[h >> 2] = c[l >> 2]
	                    }
	                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != (c[(c[h >> 2] | 0) + 4 >> 2] | 0) ? (c[k >> 2] = DA(c[(c[g >> 2] | 0) + 4 >> 2] | 0, c[(c[h >> 2] | 0) + 4 >> 2] | 0) | 0, (c[k >> 2] | 0) == 0) : 0) {
	                        c[f >> 2] = 0;
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    }
	                    l = c[(c[g >> 2] | 0) + 4 >> 2] | 0;
	                    do if ((l | 0) == 5) {
	                        d = c[(c[g >> 2] | 0) + 20 >> 2] | 0;
	                        b = c[(c[h >> 2] | 0) + 20 >> 2] | 0;
	                        if (c[j >> 2] | 0) {
	                            c[k >> 2] = oA(d, b) | 0;
	                            s = 30;
	                            break
	                        } else {
	                            c[k >> 2] = (d | 0) != (b | 0) & 1;
	                            s = 30;
	                            break
	                        }
	                    } else if ((l | 0) == 2)if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 2) {
	                        c[k >> 2] = (c[(c[g >> 2] | 0) + 32 >> 2] | 0) == (c[(c[h >> 2] | 0) + 32 >> 2] | 0) & 1;
	                        s = 30;
	                        break
	                    } else {
	                        b = uA(c[h >> 2] | 0, c[(c[g >> 2] | 0) + 32 >> 2] | 0) | 0;
	                        c[k >> 2] = b;
	                        c[k >> 2] = (c[k >> 2] | 0) < 0 ? 1 : b;
	                        s = 30;
	                        break
	                    } else if ((l | 0) == 3)if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 3) {
	                        c[m >> 2] = 0;
	                        a:while (1) {
	                            if ((c[m >> 2] | 0) >= (c[(c[g >> 2] | 0) + 52 >> 2] | 0)) {
	                                s = 29;
	                                break
	                            }
	                            c[n >> 2] = 0;
	                            while (1) {
	                                t = c[m >> 2] | 0;
	                                if ((c[n >> 2] | 0) >= (c[(c[h >> 2] | 0) + 52 >> 2] | 0))break;
	                                c[p >> 2] = c[(c[(c[g >> 2] | 0) + 56 >> 2] | 0) + (t << 2) >> 2];
	                                c[q >> 2] = c[(c[(c[h >> 2] | 0) + 56 >> 2] | 0) + (c[n >> 2] << 2) >> 2];
	                                c[o >> 2] = EA(c[p >> 2] | 0, c[q >> 2] | 0) | 0;
	                                if ((c[o >> 2] | 0) == 1) {
	                                    s = 26;
	                                    break a
	                                }
	                                c[n >> 2] = (c[n >> 2] | 0) + 1
	                            }
	                            c[m >> 2] = t + 1
	                        }
	                        if ((s | 0) == 26) {
	                            c[k >> 2] = 1;
	                            s = 30;
	                            break
	                        } else if ((s | 0) == 29) {
	                            c[k >> 2] = 0;
	                            s = 30;
	                            break
	                        }
	                    } else s = 30; while (0);
	                    if ((s | 0) == 30) {
	                        if ((c[(c[g >> 2] | 0) + 28 >> 2] | 0) != (c[(c[h >> 2] | 0) + 28 >> 2] | 0))c[k >> 2] = ((c[k >> 2] | 0) != 0 ^ 1) & 1;
	                        if (!(c[k >> 2] | 0)) {
	                            c[f >> 2] = 0;
	                            r = c[f >> 2] | 0;
	                            i = e;
	                            return r | 0
	                        }
	                    }
	                    c[f >> 2] = 1;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                }
	                c[f >> 2] = 1;
	                r = c[f >> 2] | 0;
	                i = e;
	                return r | 0
	            }

	            function xA(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f + 40 | 0;
	                h = f + 36 | 0;
	                j = f + 32 | 0;
	                k = f + 28 | 0;
	                l = f + 24 | 0;
	                m = f + 20 | 0;
	                n = f + 16 | 0;
	                o = f + 12 | 0;
	                p = f + 8 | 0;
	                q = f + 4 | 0;
	                r = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = 1;
	                c[r >> 2] = 1;
	                if (!(c[j >> 2] | 0)) {
	                    c[g >> 2] = c[m >> 2];
	                    s = c[g >> 2] | 0;
	                    i = f;
	                    return s | 0
	                }
	                if ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) == 2) {
	                    c[g >> 2] = c[m >> 2];
	                    s = c[g >> 2] | 0;
	                    i = f;
	                    return s | 0
	                }
	                if (c[(c[h >> 2] | 0) + 76 >> 2] & 1)c[r >> 2] = 0;
	                c[p >> 2] = c[(c[j >> 2] | 0) + 24 >> 2];
	                c[o >> 2] = 0;
	                while (1) {
	                    if ((c[o >> 2] | 0) >= (c[p >> 2] | 0))break;
	                    c[q >> 2] = (c[(c[j >> 2] | 0) + 28 >> 2] | 0) + ((c[o >> 2] | 0) * 20 | 0);
	                    e = c[(c[q >> 2] | 0) + 4 >> 2] | 0;
	                    if (!(c[c[q >> 2] >> 2] | 0)) {
	                        if ((e | 0) >= 0 ? (c[(c[j >> 2] | 0) + 8 >> 2] = 2, c[n >> 2] = xA(c[h >> 2] | 0, c[(c[(c[h >> 2] | 0) + 52 >> 2] | 0) + (c[(c[q >> 2] | 0) + 4 >> 2] << 2) >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0, c[(c[j >> 2] | 0) + 8 >> 2] = 0, (c[n >> 2] | 0) == 0) : 0)c[m >> 2] = 0
	                    } else if ((e | 0) == (c[k >> 2] | 0) ? (wA(c[c[q >> 2] >> 2] | 0, c[l >> 2] | 0, c[r >> 2] | 0) | 0) != 0 : 0) {
	                        c[m >> 2] = 0;
	                        c[(c[q >> 2] | 0) + 16 >> 2] = 1
	                    }
	                    c[o >> 2] = (c[o >> 2] | 0) + 1
	                }
	                c[g >> 2] = c[m >> 2];
	                s = c[g >> 2] | 0;
	                i = f;
	                return s | 0
	            }

	            function yA(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 16 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 16 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function zA(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = Cb[c[135744 >> 2] & 511](64) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    Qz(c[f >> 2] | 0, 139320);
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                b = (c[h >> 2] | 0) + 0 | 0;
	                a = b + 64 | 0;
	                do {
	                    c[b >> 2] = 0;
	                    b = b + 4 | 0
	                } while ((b | 0) < (a | 0));
	                c[(c[h >> 2] | 0) + 4 >> 2] = c[(c[g >> 2] | 0) + 4 >> 2];
	                c[(c[h >> 2] | 0) + 8 >> 2] = c[(c[g >> 2] | 0) + 8 >> 2];
	                c[(c[h >> 2] | 0) + 12 >> 2] = c[(c[g >> 2] | 0) + 12 >> 2];
	                c[(c[h >> 2] | 0) + 16 >> 2] = c[(c[g >> 2] | 0) + 16 >> 2];
	                a:do if ((c[(c[g >> 2] | 0) + 52 >> 2] | 0) > 0) {
	                    b = Cb[c[135744 >> 2] & 511](c[(c[g >> 2] | 0) + 52 >> 2] << 2) | 0;
	                    c[(c[h >> 2] | 0) + 56 >> 2] = b;
	                    b:do if (!(c[(c[h >> 2] | 0) + 56 >> 2] | 0))Qz(c[f >> 2] | 0, 139320); else {
	                        c[j >> 2] = 0;
	                        while (1) {
	                            if ((c[j >> 2] | 0) >= (c[(c[g >> 2] | 0) + 52 >> 2] | 0))break a;
	                            b = FA(c[f >> 2] | 0, c[(c[(c[g >> 2] | 0) + 56 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) | 0;
	                            c[(c[(c[h >> 2] | 0) + 56 >> 2] | 0) + (c[j >> 2] << 2) >> 2] = b;
	                            if (!(c[(c[(c[h >> 2] | 0) + 56 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0))break b;
	                            c[(c[h >> 2] | 0) + 52 >> 2] = (c[j >> 2] | 0) + 1;
	                            c[j >> 2] = (c[j >> 2] | 0) + 1
	                        }
	                    } while (0);
	                    dA(c[h >> 2] | 0);
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                } while (0);
	                c[e >> 2] = c[h >> 2];
	                k = c[e >> 2] | 0;
	                i = d;
	                return k | 0
	            }

	            function AA(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                d = c[g >> 2] | 0;
	                do if (!(c[(c[g >> 2] | 0) + 32 >> 2] | 0)) {
	                    c[d + 32 >> 2] = 8;
	                    b = Cb[c[135744 >> 2] & 511](c[(c[g >> 2] | 0) + 32 >> 2] << 2) | 0;
	                    c[(c[g >> 2] | 0) + 40 >> 2] = b;
	                    if (!(c[(c[g >> 2] | 0) + 40 >> 2] | 0)) {
	                        Qz(c[f >> 2] | 0, 139256);
	                        c[(c[g >> 2] | 0) + 32 >> 2] = 0;
	                        i = e;
	                        return
	                    }
	                } else if ((c[d + 36 >> 2] | 0) >= (c[(c[g >> 2] | 0) + 32 >> 2] | 0)) {
	                    b = (c[g >> 2] | 0) + 32 | 0;
	                    c[b >> 2] = c[b >> 2] << 1;
	                    c[j >> 2] = Hb[c[135760 >> 2] & 511](c[(c[g >> 2] | 0) + 40 >> 2] | 0, c[(c[g >> 2] | 0) + 32 >> 2] << 2) | 0;
	                    if (c[j >> 2] | 0) {
	                        c[(c[g >> 2] | 0) + 40 >> 2] = c[j >> 2];
	                        break
	                    }
	                    Qz(c[f >> 2] | 0, 139256);
	                    b = (c[g >> 2] | 0) + 32 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) / 2 | 0;
	                    i = e;
	                    return
	                } while (0);
	                c[(c[(c[g >> 2] | 0) + 40 >> 2] | 0) + (c[(c[g >> 2] | 0) + 36 >> 2] << 2) >> 2] = c[h >> 2];
	                h = (c[g >> 2] | 0) + 36 | 0;
	                c[h >> 2] = (c[h >> 2] | 0) + 1;
	                i = e;
	                return
	            }

	            function BA(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[(c[e >> 2] | 0) + 28 >> 2] = 0;
	                c[f >> 2] = GA(c[e >> 2] | 0) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                if (!(c[(c[e >> 2] | 0) + 28 >> 2] | 0)) {
	                    c[(c[e >> 2] | 0) + 8 >> 2] = 1450;
	                    Yz(c[e >> 2] | 0, 139592)
	                }
	                HA(c[e >> 2] | 0) | 0;
	                c[d >> 2] = 1;
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function CA(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0;
	                h = i;
	                i = i + 32 | 0;
	                j = h + 28 | 0;
	                k = h + 24 | 0;
	                l = h + 20 | 0;
	                m = h + 16 | 0;
	                n = h + 12 | 0;
	                o = h + 8 | 0;
	                p = h + 4 | 0;
	                q = h;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                c[q >> 2] = 0;
	                do switch (c[k >> 2] | 0) {
	                    case 128:
	                    {
	                        c[q >> 2] = HL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 104:
	                    {
	                        c[q >> 2] = mL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 109:
	                    {
	                        c[q >> 2] = sL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 108:
	                    {
	                        c[q >> 2] = rL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 10:
	                    {
	                        c[m >> 2] = ((c[m >> 2] | 0) != 0 ^ 1) & 1;
	                        r = 14;
	                        break
	                    }
	                    case 112:
	                    {
	                        c[q >> 2] = wL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 105:
	                    {
	                        c[q >> 2] = nL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 9:
	                    {
	                        r = 14;
	                        break
	                    }
	                    case 113:
	                    {
	                        c[q >> 2] = xL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 110:
	                    {
	                        c[q >> 2] = uL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 116:
	                    {
	                        c[q >> 2] = AL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 115:
	                    {
	                        c[q >> 2] = zL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 102:
	                    {
	                        c[q >> 2] = lL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 15:
	                    {
	                        c[m >> 2] = ((c[m >> 2] | 0) != 0 ^ 1) & 1;
	                        r = 49;
	                        break
	                    }
	                    case 121:
	                    {
	                        c[q >> 2] = EL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 136:
	                    {
	                        c[q >> 2] = fL(c[l >> 2] | 0, c[p >> 2] | 0) | 0;
	                        break
	                    }
	                    case 134:
	                    {
	                        c[q >> 2] = jL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 135:
	                    {
	                        c[q >> 2] = 0;
	                        break
	                    }
	                    case 122:
	                    {
	                        c[q >> 2] = LL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 6:
	                    {
	                        if ((c[l >> 2] | 0) != 10)s = (c[l >> 2] | 0) != 13; else s = 0;
	                        c[q >> 2] = s & 1;
	                        break
	                    }
	                    case 13:
	                    {
	                        r = 47;
	                        break
	                    }
	                    case 111:
	                    {
	                        c[q >> 2] = vL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 11:
	                    {
	                        r = 27;
	                        break
	                    }
	                    case 12:
	                    {
	                        c[m >> 2] = ((c[m >> 2] | 0) != 0 ^ 1) & 1;
	                        r = 27;
	                        break
	                    }
	                    case 107:
	                    {
	                        c[q >> 2] = tL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 123:
	                    {
	                        c[q >> 2] = OL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 7:
	                    {
	                        r = 10;
	                        break
	                    }
	                    case 8:
	                    {
	                        c[m >> 2] = ((c[m >> 2] | 0) != 0 ^ 1) & 1;
	                        r = 10;
	                        break
	                    }
	                    case 2:
	                    {
	                        if ((c[l >> 2] | 0) >= (c[n >> 2] | 0))t = (c[l >> 2] | 0) <= (c[o >> 2] | 0); else t = 0;
	                        c[q >> 2] = t & 1;
	                        break
	                    }
	                    case 133:
	                    {
	                        c[q >> 2] = iL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 118:
	                    {
	                        c[q >> 2] = BL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 124:
	                    {
	                        c[q >> 2] = ML(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 131:
	                    {
	                        c[q >> 2] = gL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 132:
	                    {
	                        c[q >> 2] = hL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 100:
	                    {
	                        c[q >> 2] = kL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 103:
	                    {
	                        c[q >> 2] = oL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 14:
	                    {
	                        c[m >> 2] = ((c[m >> 2] | 0) != 0 ^ 1) & 1;
	                        r = 47;
	                        break
	                    }
	                    case 1:
	                    case 3:
	                    case 4:
	                    case 5:
	                    {
	                        c[j >> 2] = -1;
	                        u = c[j >> 2] | 0;
	                        i = h;
	                        return u | 0
	                    }
	                    case 129:
	                    {
	                        c[q >> 2] = IL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 130:
	                    {
	                        c[q >> 2] = KL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 106:
	                    {
	                        c[q >> 2] = qL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 125:
	                    {
	                        c[q >> 2] = NL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 117:
	                    {
	                        c[q >> 2] = FL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 101:
	                    {
	                        c[q >> 2] = pL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 16:
	                    {
	                        r = 49;
	                        break
	                    }
	                    case 126:
	                    {
	                        c[q >> 2] = GL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 127:
	                    {
	                        c[q >> 2] = JL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 120:
	                    {
	                        c[q >> 2] = CL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 119:
	                    {
	                        c[q >> 2] = DL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    case 114:
	                    {
	                        c[q >> 2] = yL(c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    default:
	                    {
	                    }
	                } while (0);
	                if ((r | 0) == 10) {
	                    if ((c[l >> 2] | 0) == 10 | (c[l >> 2] | 0) == 13 | (c[l >> 2] | 0) == 9)v = 1; else v = (c[l >> 2] | 0) == 32;
	                    c[q >> 2] = v & 1
	                } else if ((r | 0) == 14) {
	                    v = c[l >> 2] | 0;
	                    if ((c[l >> 2] | 0) < 256)if (((!(65 <= (v | 0) & (c[l >> 2] | 0) <= 90) ? !(97 <= (c[l >> 2] | 0) & (c[l >> 2] | 0) <= 122) : 0) ? !(192 <= (c[l >> 2] | 0) & (c[l >> 2] | 0) <= 214) : 0) ? !(216 <= (c[l >> 2] | 0) & (c[l >> 2] | 0) <= 246 | 248 <= (c[l >> 2] | 0)) : 0)r = 20; else w = 1; else if (DQ(v, 199744) | 0)w = 1; else r = 20;
	                    do if ((r | 0) == 20) {
	                        v = c[l >> 2] | 0;
	                        if ((c[l >> 2] | 0) < 256) {
	                            if ((v | 0) == 95) {
	                                w = 1;
	                                break
	                            }
	                        } else {
	                            if (19968 <= (v | 0) & (c[l >> 2] | 0) <= 40869 | (c[l >> 2] | 0) == 12295) {
	                                w = 1;
	                                break
	                            }
	                            if (12321 <= (c[l >> 2] | 0) & (c[l >> 2] | 0) <= 12329 | (c[l >> 2] | 0) == 95) {
	                                w = 1;
	                                break
	                            }
	                        }
	                        w = (c[l >> 2] | 0) == 58
	                    } while (0);
	                    c[q >> 2] = w & 1
	                } else if ((r | 0) == 27) {
	                    w = c[l >> 2] | 0;
	                    if ((c[l >> 2] | 0) < 256)if (((!(65 <= (w | 0) & (c[l >> 2] | 0) <= 90) ? !(97 <= (c[l >> 2] | 0) & (c[l >> 2] | 0) <= 122) : 0) ? !(192 <= (c[l >> 2] | 0) & (c[l >> 2] | 0) <= 214) : 0) ? !(216 <= (c[l >> 2] | 0) & (c[l >> 2] | 0) <= 246 | 248 <= (c[l >> 2] | 0)) : 0)r = 33; else x = 1; else if (DQ(w, 199744) | 0)x = 1; else r = 33;
	                    do if ((r | 0) == 33) {
	                        if ((c[l >> 2] | 0) >= 256) {
	                            if (19968 <= (c[l >> 2] | 0) & (c[l >> 2] | 0) <= 40869 | (c[l >> 2] | 0) == 12295) {
	                                x = 1;
	                                break
	                            }
	                            if (12321 <= (c[l >> 2] | 0) & (c[l >> 2] | 0) <= 12329) {
	                                x = 1;
	                                break
	                            }
	                        }
	                        w = c[l >> 2] | 0;
	                        if ((c[l >> 2] | 0) < 256) {
	                            if (48 <= (w | 0) & (c[l >> 2] | 0) <= 57 | (c[l >> 2] | 0) == 46 | (c[l >> 2] | 0) == 45 | (c[l >> 2] | 0) == 95 | (c[l >> 2] | 0) == 58) {
	                                x = 1;
	                                break
	                            }
	                        } else {
	                            v = (DQ(w, 200216) | 0) != 0;
	                            if (v | (c[l >> 2] | 0) == 46 | (c[l >> 2] | 0) == 45 | (c[l >> 2] | 0) == 95 | (c[l >> 2] | 0) == 58) {
	                                x = 1;
	                                break
	                            }
	                        }
	                        if ((c[l >> 2] | 0) >= 256 ? (DQ(c[l >> 2] | 0, 200144) | 0) != 0 : 0) {
	                            x = 1;
	                            break
	                        }
	                        v = c[l >> 2] | 0;
	                        if ((c[l >> 2] | 0) < 256)y = (v | 0) == 183 & 1; else y = DQ(v, 200272) | 0;
	                        x = (y | 0) != 0
	                    } while (0);
	                    c[q >> 2] = x & 1
	                } else if ((r | 0) == 47)c[q >> 2] = vL(c[l >> 2] | 0) | 0; else if ((r | 0) == 49) {
	                    c[q >> 2] = yL(c[l >> 2] | 0) | 0;
	                    if (!(c[q >> 2] | 0))c[q >> 2] = LL(c[l >> 2] | 0) | 0;
	                    if (!(c[q >> 2] | 0))c[q >> 2] = gL(c[l >> 2] | 0) | 0
	                }
	                l = c[q >> 2] | 0;
	                if (c[m >> 2] | 0) {
	                    c[j >> 2] = ((l | 0) != 0 ^ 1) & 1;
	                    u = c[j >> 2] | 0;
	                    i = h;
	                    return u | 0
	                } else {
	                    c[j >> 2] = l;
	                    u = c[j >> 2] | 0;
	                    i = h;
	                    return u | 0
	                }
	                return 0
	            }

	            function DA(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                a:do if ((c[f >> 2] | 0) == 1 | (c[f >> 2] | 0) == 2 | (c[f >> 2] | 0) == 3 | (c[f >> 2] | 0) == 4 | (c[f >> 2] | 0) == 5 | (c[f >> 2] | 0) == 6)c[e >> 2] = 1; else {
	                    if ((c[g >> 2] | 0) == 1 | (c[g >> 2] | 0) == 2 | (c[g >> 2] | 0) == 3 | (c[g >> 2] | 0) == 4 | (c[g >> 2] | 0) == 5 | (c[g >> 2] | 0) == 6) {
	                        c[e >> 2] = 1;
	                        break
	                    }
	                    if ((c[f >> 2] | 0) == (c[g >> 2] | 0)) {
	                        c[e >> 2] = 1;
	                        break
	                    }
	                    if ((c[f >> 2] | 0) >>> 0 > (c[g >> 2] | 0) >>> 0) {
	                        c[h >> 2] = c[f >> 2];
	                        c[f >> 2] = c[g >> 2];
	                        c[g >> 2] = c[h >> 2]
	                    }
	                    b:do switch (c[f >> 2] | 0) {
	                        case 100:
	                        {
	                            if ((c[g >> 2] | 0) >>> 0 <= 105) {
	                                c[e >> 2] = 1;
	                                break a
	                            } else {
	                                c[e >> 2] = 0;
	                                break a
	                            }
	                            break
	                        }
	                        case 132:
	                        case 133:
	                        case 134:
	                        case 135:
	                        {
	                            c[e >> 2] = 0;
	                            break a;
	                            break
	                        }
	                        case 126:
	                        {
	                            if ((c[g >> 2] | 0) >>> 0 <= 130) {
	                                c[e >> 2] = 1;
	                                break a
	                            } else {
	                                c[e >> 2] = 0;
	                                break a
	                            }
	                            break
	                        }
	                        case 106:
	                        {
	                            if ((c[g >> 2] | 0) >>> 0 <= 109) {
	                                c[e >> 2] = 1;
	                                break a
	                            } else {
	                                c[e >> 2] = 0;
	                                break a
	                            }
	                            break
	                        }
	                        case 13:
	                        {
	                            if ((((((!((c[g >> 2] | 0) == 14 | (c[g >> 2] | 0) == 15) ? !((c[g >> 2] | 0) >>> 0 >= 100 & (c[g >> 2] | 0) >>> 0 <= 105) : 0) ? !((c[g >> 2] | 0) >>> 0 >= 106 & (c[g >> 2] | 0) >>> 0 <= 109) : 0) ? !((c[g >> 2] | 0) >>> 0 >= 114 & (c[g >> 2] | 0) >>> 0 <= 121) : 0) ? !((c[g >> 2] | 0) >>> 0 >= 122 & (c[g >> 2] | 0) >>> 0 <= 125) : 0) ? !((c[g >> 2] | 0) >>> 0 >= 126 & (c[g >> 2] | 0) >>> 0 <= 130) : 0) ? !((c[g >> 2] | 0) >>> 0 >= 131 & (c[g >> 2] | 0) >>> 0 <= 135) : 0)break b;
	                            c[e >> 2] = 0;
	                            break a;
	                            break
	                        }
	                        case 131:
	                        {
	                            if ((c[g >> 2] | 0) >>> 0 <= 135) {
	                                c[e >> 2] = 1;
	                                break a
	                            } else {
	                                c[e >> 2] = 0;
	                                break a
	                            }
	                            break
	                        }
	                        case 15:
	                        {
	                            if ((((((c[g >> 2] | 0) != 14 ? !((c[g >> 2] | 0) >>> 0 >= 106 & (c[g >> 2] | 0) >>> 0 <= 109) : 0) ? !((c[g >> 2] | 0) >>> 0 >= 114 & (c[g >> 2] | 0) >>> 0 <= 121) : 0) ? !((c[g >> 2] | 0) >>> 0 >= 122 & (c[g >> 2] | 0) >>> 0 <= 125) : 0) ? !((c[g >> 2] | 0) >>> 0 >= 126 & (c[g >> 2] | 0) >>> 0 <= 130) : 0) ? !((c[g >> 2] | 0) >>> 0 >= 131 & (c[g >> 2] | 0) >>> 0 <= 135) : 0)break b;
	                            c[e >> 2] = 0;
	                            break a;
	                            break
	                        }
	                        case 7:
	                        {
	                            if ((((((c[g >> 2] | 0) != 8 ? !((c[g >> 2] | 0) >>> 0 >= 100 & (c[g >> 2] | 0) >>> 0 <= 105) : 0) ? !((c[g >> 2] | 0) >>> 0 >= 110 & (c[g >> 2] | 0) >>> 0 <= 113) : 0) ? !((c[g >> 2] | 0) >>> 0 >= 106 & (c[g >> 2] | 0) >>> 0 <= 109) : 0) ? !((c[g >> 2] | 0) >>> 0 >= 114 & (c[g >> 2] | 0) >>> 0 <= 121) : 0) ? !((c[g >> 2] | 0) >>> 0 >= 126 & (c[g >> 2] | 0) >>> 0 <= 130) : 0)break b;
	                            c[e >> 2] = 0;
	                            break a;
	                            break
	                        }
	                        case 125:
	                        case 124:
	                        case 123:
	                        {
	                            c[e >> 2] = 0;
	                            break a;
	                            break
	                        }
	                        case 105:
	                        case 104:
	                        case 103:
	                        case 102:
	                        case 101:
	                        {
	                            c[e >> 2] = 0;
	                            break a;
	                            break
	                        }
	                        case 11:
	                        {
	                            if ((((((c[g >> 2] | 0) != 12 ? !((c[g >> 2] | 0) >>> 0 >= 106 & (c[g >> 2] | 0) >>> 0 <= 109) : 0) ? !((c[g >> 2] | 0) >>> 0 >= 114 & (c[g >> 2] | 0) >>> 0 <= 121) : 0) ? !((c[g >> 2] | 0) >>> 0 >= 122 & (c[g >> 2] | 0) >>> 0 <= 125) : 0) ? !((c[g >> 2] | 0) >>> 0 >= 126 & (c[g >> 2] | 0) >>> 0 <= 130) : 0) ? !((c[g >> 2] | 0) >>> 0 >= 131 & (c[g >> 2] | 0) >>> 0 <= 135) : 0)break b;
	                            c[e >> 2] = 0;
	                            break a;
	                            break
	                        }
	                        case 110:
	                        {
	                            if ((c[g >> 2] | 0) >>> 0 <= 113) {
	                                c[e >> 2] = 1;
	                                break a
	                            } else {
	                                c[e >> 2] = 0;
	                                break a
	                            }
	                            break
	                        }
	                        case 121:
	                        case 120:
	                        case 119:
	                        case 118:
	                        case 117:
	                        case 116:
	                        case 115:
	                        {
	                            c[e >> 2] = 0;
	                            break a;
	                            break
	                        }
	                        case 9:
	                        {
	                            if (((((((c[g >> 2] | 0) != 10 ? !((c[g >> 2] | 0) >>> 0 >= 110 & (c[g >> 2] | 0) >>> 0 <= 113) : 0) ? !((c[g >> 2] | 0) >>> 0 >= 106 & (c[g >> 2] | 0) >>> 0 <= 109) : 0) ? !((c[g >> 2] | 0) >>> 0 >= 122 & (c[g >> 2] | 0) >>> 0 <= 125) : 0) ? !((c[g >> 2] | 0) >>> 0 >= 114 & (c[g >> 2] | 0) >>> 0 <= 121) : 0) ? !((c[g >> 2] | 0) >>> 0 >= 126 & (c[g >> 2] | 0) >>> 0 <= 130) : 0) ? !((c[g >> 2] | 0) >>> 0 >= 131 & (c[g >> 2] | 0) >>> 0 <= 135) : 0)break b;
	                            c[e >> 2] = 0;
	                            break a;
	                            break
	                        }
	                        case 122:
	                        {
	                            if ((c[g >> 2] | 0) >>> 0 <= 125) {
	                                c[e >> 2] = 1;
	                                break a
	                            } else {
	                                c[e >> 2] = 0;
	                                break a
	                            }
	                            break
	                        }
	                        case 114:
	                        {
	                            if ((c[g >> 2] | 0) >>> 0 <= 121) {
	                                c[e >> 2] = 1;
	                                break a
	                            } else {
	                                c[e >> 2] = 0;
	                                break a
	                            }
	                            break
	                        }
	                        case 130:
	                        case 129:
	                        case 128:
	                        case 127:
	                        {
	                            c[e >> 2] = 0;
	                            break a;
	                            break
	                        }
	                        case 113:
	                        case 112:
	                        case 111:
	                        {
	                            c[e >> 2] = 0;
	                            break a;
	                            break
	                        }
	                        case 109:
	                        case 108:
	                        case 107:
	                        {
	                            c[e >> 2] = 0;
	                            break a;
	                            break
	                        }
	                        default:
	                        {
	                        }
	                    } while (0);
	                    c[e >> 2] = 1
	                } while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function EA(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 24 | 0;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                l = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                if ((((((c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 3 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 3 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 4 : 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 4 : 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 5 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 5 : 0) {
	                    if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) >>> 0 > (c[(c[g >> 2] | 0) + 4 >> 2] | 0) >>> 0) {
	                        c[j >> 2] = c[f >> 2];
	                        c[f >> 2] = c[g >> 2];
	                        c[g >> 2] = c[j >> 2]
	                    }
	                    a:do if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 6 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 6 : 0) {
	                        if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 1 : 0) {
	                            j = c[(c[f >> 2] | 0) + 4 >> 2] | 0;
	                            if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == (c[(c[g >> 2] | 0) + 4 >> 2] | 0)) {
	                                if ((j | 0) != 2) {
	                                    c[h >> 2] = 1;
	                                    break
	                                }
	                                if ((c[(c[f >> 2] | 0) + 12 >> 2] | 0) >= (c[(c[g >> 2] | 0) + 8 >> 2] | 0) ? (c[(c[g >> 2] | 0) + 12 >> 2] | 0) >= (c[(c[f >> 2] | 0) + 8 >> 2] | 0) : 0) {
	                                    c[h >> 2] = 1;
	                                    break
	                                }
	                                c[h >> 2] = 0;
	                                break
	                            }
	                            if ((j | 0) == 2) {
	                                c[l >> 2] = 0;
	                                if ((c[c[f >> 2] >> 2] | 0) == 0 ? (c[c[g >> 2] >> 2] | 0) != 0 : 0)m = 28; else m = 26;
	                                if (((m | 0) == 26 ? (c[c[f >> 2] >> 2] | 0) != 0 : 0) ? (c[c[g >> 2] >> 2] | 0) == 0 : 0)m = 28;
	                                if ((m | 0) == 28)c[l >> 2] = 1;
	                                c[k >> 2] = c[(c[f >> 2] | 0) + 8 >> 2];
	                                while (1) {
	                                    if ((c[k >> 2] | 0) > (c[(c[f >> 2] | 0) + 12 >> 2] | 0)) {
	                                        m = 37;
	                                        break
	                                    }
	                                    c[h >> 2] = CA(c[(c[g >> 2] | 0) + 4 >> 2] | 0, c[k >> 2] | 0, 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[(c[g >> 2] | 0) + 16 >> 2] | 0) | 0;
	                                    if ((c[h >> 2] | 0) < 0) {
	                                        m = 32;
	                                        break
	                                    }
	                                    if ((c[l >> 2] | 0) == 1 & (c[h >> 2] | 0) == 0) {
	                                        m = 35;
	                                        break
	                                    }
	                                    if ((c[l >> 2] | 0) == 0 & (c[h >> 2] | 0) == 1) {
	                                        m = 35;
	                                        break
	                                    }
	                                    c[k >> 2] = (c[k >> 2] | 0) + 1
	                                }
	                                if ((m | 0) == 32) {
	                                    c[e >> 2] = -1;
	                                    n = c[e >> 2] | 0;
	                                    i = d;
	                                    return n | 0
	                                } else if ((m | 0) == 35) {
	                                    c[e >> 2] = 1;
	                                    n = c[e >> 2] | 0;
	                                    i = d;
	                                    return n | 0
	                                } else if ((m | 0) == 37) {
	                                    c[e >> 2] = 0;
	                                    n = c[e >> 2] | 0;
	                                    i = d;
	                                    return n | 0
	                                }
	                            }
	                            if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 136 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 136 : 0) {
	                                do if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) >>> 0 >= 100) {
	                                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) >>> 0 < 100)break;
	                                    c[h >> 2] = 0;
	                                    switch (c[(c[f >> 2] | 0) + 4 >> 2] | 0) {
	                                        case 106:
	                                        {
	                                            do if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 107) {
	                                                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 108)break;
	                                                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 109)break a
	                                            } while (0);
	                                            c[h >> 2] = 1;
	                                            break a;
	                                            break
	                                        }
	                                        case 110:
	                                        {
	                                            do if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 111) {
	                                                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 112)break;
	                                                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 113)break a
	                                            } while (0);
	                                            c[h >> 2] = 1;
	                                            break a;
	                                            break
	                                        }
	                                        case 114:
	                                        {
	                                            do if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 115) {
	                                                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 116)break;
	                                                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 117)break;
	                                                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 118)break;
	                                                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 119)break;
	                                                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 120)break;
	                                                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 121)break a
	                                            } while (0);
	                                            c[h >> 2] = 1;
	                                            break a;
	                                            break
	                                        }
	                                        case 100:
	                                        {
	                                            do if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 101) {
	                                                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 102)break;
	                                                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 103)break;
	                                                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 104)break;
	                                                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 105)break a
	                                            } while (0);
	                                            c[h >> 2] = 1;
	                                            break a;
	                                            break
	                                        }
	                                        case 131:
	                                        {
	                                            do if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 132) {
	                                                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 133)break;
	                                                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 134)break a
	                                            } while (0);
	                                            c[h >> 2] = 1;
	                                            break a;
	                                            break
	                                        }
	                                        case 126:
	                                        {
	                                            do if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 127) {
	                                                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 128)break;
	                                                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 129)break;
	                                                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 130)break a
	                                            } while (0);
	                                            c[h >> 2] = 1;
	                                            break a;
	                                            break
	                                        }
	                                        case 122:
	                                        {
	                                            do if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 123) {
	                                                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 124)break;
	                                                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 125)break a
	                                            } while (0);
	                                            c[h >> 2] = 1;
	                                            break a;
	                                            break
	                                        }
	                                        default:
	                                        {
	                                            do if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) >>> 0 >= 100) {
	                                                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) >>> 0 >= 136)break;
	                                                c[h >> 2] = 0;
	                                                break a
	                                            } while (0);
	                                            c[e >> 2] = 1;
	                                            n = c[e >> 2] | 0;
	                                            i = d;
	                                            return n | 0
	                                        }
	                                    }
	                                } while (0);
	                                do if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 7) {
	                                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 8)break;
	                                    c[h >> 2] = 0;
	                                    break a
	                                } while (0);
	                                do if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 9) {
	                                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 10)break;
	                                    c[h >> 2] = 0;
	                                    break a
	                                } while (0);
	                                do if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 11) {
	                                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 12)break;
	                                    c[h >> 2] = 0;
	                                    break a
	                                } while (0);
	                                do if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 13) {
	                                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 14)break;
	                                    c[h >> 2] = 0;
	                                    break a
	                                } while (0);
	                                do if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 15) {
	                                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 16)break;
	                                    c[h >> 2] = 0;
	                                    break a
	                                } while (0);
	                                c[e >> 2] = 1;
	                                n = c[e >> 2] | 0;
	                                i = d;
	                                return n | 0
	                            }
	                            if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == (c[(c[g >> 2] | 0) + 4 >> 2] | 0)) {
	                                c[h >> 2] = qy(c[(c[f >> 2] | 0) + 16 >> 2] | 0, c[(c[g >> 2] | 0) + 16 >> 2] | 0) | 0;
	                                break
	                            }
	                            c[e >> 2] = 1;
	                            n = c[e >> 2] | 0;
	                            i = d;
	                            return n | 0
	                        }
	                        c[e >> 2] = 0;
	                        n = c[e >> 2] | 0;
	                        i = d;
	                        return n | 0
	                    } else m = 12; while (0);
	                    if ((m | 0) == 12)c[h >> 2] = 1;
	                    if ((c[c[f >> 2] >> 2] | 0) == 0 ? (c[c[g >> 2] >> 2] | 0) != 0 : 0)m = 105; else m = 103;
	                    if (((m | 0) == 103 ? (c[c[f >> 2] >> 2] | 0) != 0 : 0) ? (c[c[g >> 2] >> 2] | 0) == 0 : 0)m = 105;
	                    if ((m | 0) == 105)c[h >> 2] = ((c[h >> 2] | 0) != 0 ^ 1) & 1;
	                    c[e >> 2] = c[h >> 2];
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                c[e >> 2] = -1;
	                n = c[e >> 2] | 0;
	                i = d;
	                return n | 0
	            }

	            function FA(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[h >> 2] = IA(c[f >> 2] | 0, c[c[g >> 2] >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] | 0) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 ? (b = my(c[(c[g >> 2] | 0) + 16 >> 2] | 0) | 0, c[(c[h >> 2] | 0) + 16 >> 2] = b, (c[(c[h >> 2] | 0) + 16 >> 2] | 0) == 0) : 0) {
	                    Qz(c[f >> 2] | 0, 139336);
	                    yA(c[h >> 2] | 0);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[e >> 2] = c[h >> 2];
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function GA(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                b = i;
	                i = i + 32 | 0;
	                e = b + 24 | 0;
	                f = b + 20 | 0;
	                g = b + 16 | 0;
	                h = b + 12 | 0;
	                j = b + 8 | 0;
	                k = b + 4 | 0;
	                l = b;
	                c[f >> 2] = a;
	                c[g >> 2] = JA(c[f >> 2] | 0) | 0;
	                a = c[f >> 2] | 0;
	                if ((c[g >> 2] | 0) > 0) {
	                    m = eA(a, 2) | 0;
	                    c[(c[f >> 2] | 0) + 28 >> 2] = m;
	                    if (!(c[(c[f >> 2] | 0) + 28 >> 2] | 0)) {
	                        c[e >> 2] = -1;
	                        n = c[e >> 2] | 0;
	                        i = b;
	                        return n | 0
	                    } else {
	                        c[g >> 2] = oe(0, c[(c[f >> 2] | 0) + 4 >> 2] | 0, h) | 0;
	                        c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 32 >> 2] = c[g >> 2];
	                        g = (c[f >> 2] | 0) + 4 | 0;
	                        c[g >> 2] = (c[g >> 2] | 0) + (c[h >> 2] | 0);
	                        c[e >> 2] = 1;
	                        n = c[e >> 2] | 0;
	                        i = b;
	                        return n | 0
	                    }
	                }
	                if ((d[c[a + 4 >> 2] >> 0] | 0 | 0) == 124) {
	                    c[e >> 2] = 0;
	                    n = c[e >> 2] | 0;
	                    i = b;
	                    return n | 0
	                }
	                if (!(d[c[(c[f >> 2] | 0) + 4 >> 2] >> 0] | 0)) {
	                    c[e >> 2] = 0;
	                    n = c[e >> 2] | 0;
	                    i = b;
	                    return n | 0
	                }
	                if ((d[c[(c[f >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) == 41) {
	                    c[e >> 2] = 0;
	                    n = c[e >> 2] | 0;
	                    i = b;
	                    return n | 0
	                }
	                a = (c[f >> 2] | 0) + 4 | 0;
	                h = c[a >> 2] | 0;
	                if ((d[c[(c[f >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) != 40) {
	                    if (((d[h >> 0] | 0 | 0) != 91 ? (d[c[(c[f >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) != 92 : 0) ? (d[c[(c[f >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) != 46 : 0) {
	                        c[e >> 2] = 0;
	                        n = c[e >> 2] | 0;
	                        i = b;
	                        return n | 0
	                    }
	                    KA(c[f >> 2] | 0);
	                    c[e >> 2] = 1;
	                    n = c[e >> 2] | 0;
	                    i = b;
	                    return n | 0
	                }
	                c[a >> 2] = h + 1;
	                jA(c[f >> 2] | 0, c[(c[f >> 2] | 0) + 24 >> 2] | 0, 0);
	                c[l >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                jA(c[f >> 2] | 0, c[(c[f >> 2] | 0) + 24 >> 2] | 0, 0);
	                c[j >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                c[k >> 2] = c[(c[f >> 2] | 0) + 20 >> 2];
	                c[(c[f >> 2] | 0) + 20 >> 2] = 0;
	                c[(c[f >> 2] | 0) + 28 >> 2] = 0;
	                Xz(c[f >> 2] | 0, 0);
	                h = c[f >> 2] | 0;
	                if ((d[c[(c[f >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) == 41) {
	                    a = h + 4 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1
	                } else {
	                    c[h + 8 >> 2] = 1450;
	                    Yz(c[f >> 2] | 0, 139672)
	                }
	                h = eA(c[f >> 2] | 0, 4) | 0;
	                c[(c[f >> 2] | 0) + 28 >> 2] = h;
	                if (!(c[(c[f >> 2] | 0) + 28 >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    n = c[e >> 2] | 0;
	                    i = b;
	                    return n | 0
	                } else {
	                    c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 36 >> 2] = c[j >> 2];
	                    c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 40 >> 2] = c[l >> 2];
	                    c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 44 >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                    c[(c[f >> 2] | 0) + 20 >> 2] = c[k >> 2];
	                    c[e >> 2] = 1;
	                    n = c[e >> 2] | 0;
	                    i = b;
	                    return n | 0
	                }
	                return 0
	            }

	            function HA(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                b = i;
	                i = i + 32 | 0;
	                e = b + 16 | 0;
	                f = b + 12 | 0;
	                g = b + 8 | 0;
	                h = b + 4 | 0;
	                j = b;
	                c[f >> 2] = a;
	                c[g >> 2] = d[c[(c[f >> 2] | 0) + 4 >> 2] >> 0];
	                if ((c[g >> 2] | 0) == 63 | (c[g >> 2] | 0) == 42 | (c[g >> 2] | 0) == 43) {
	                    do if (c[(c[f >> 2] | 0) + 28 >> 2] | 0) {
	                        if ((c[g >> 2] | 0) == 63) {
	                            c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 8 >> 2] = 3;
	                            break
	                        }
	                        if ((c[g >> 2] | 0) == 42) {
	                            c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 8 >> 2] = 4;
	                            break
	                        }
	                        if ((c[g >> 2] | 0) == 43)c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 8 >> 2] = 5
	                    } while (0);
	                    a = (c[f >> 2] | 0) + 4 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1;
	                    c[e >> 2] = 1;
	                    k = c[e >> 2] | 0;
	                    i = b;
	                    return k | 0
	                }
	                if ((c[g >> 2] | 0) != 123) {
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = b;
	                    return k | 0
	                }
	                c[h >> 2] = 0;
	                c[j >> 2] = 0;
	                a = (c[f >> 2] | 0) + 4 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + 1;
	                c[g >> 2] = LA(c[f >> 2] | 0) | 0;
	                if ((c[g >> 2] | 0) >= 0)c[h >> 2] = c[g >> 2];
	                do if ((d[c[(c[f >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) == 44) {
	                    a = (c[f >> 2] | 0) + 4 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1;
	                    if ((d[c[(c[f >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) == 125) {
	                        c[j >> 2] = 2147483647;
	                        break
	                    }
	                    c[g >> 2] = LA(c[f >> 2] | 0) | 0;
	                    if ((c[g >> 2] | 0) >= 0) {
	                        c[j >> 2] = c[g >> 2];
	                        break
	                    } else {
	                        c[(c[f >> 2] | 0) + 8 >> 2] = 1450;
	                        Yz(c[f >> 2] | 0, 139624);
	                        break
	                    }
	                } while (0);
	                g = c[f >> 2] | 0;
	                if ((d[c[(c[f >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) == 125) {
	                    a = g + 4 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1
	                } else {
	                    c[g + 8 >> 2] = 1450;
	                    Yz(c[f >> 2] | 0, 139648)
	                }
	                if (!(c[j >> 2] | 0))c[j >> 2] = c[h >> 2];
	                if (c[(c[f >> 2] | 0) + 28 >> 2] | 0) {
	                    c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 8 >> 2] = 8;
	                    c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 12 >> 2] = c[h >> 2];
	                    c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] = c[j >> 2]
	                }
	                c[e >> 2] = 1;
	                k = c[e >> 2] | 0;
	                i = b;
	                return k | 0
	            }

	            function IA(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 24 | 0;
	                j = g + 20 | 0;
	                k = g + 16 | 0;
	                l = g + 12 | 0;
	                m = g + 8 | 0;
	                n = g + 4 | 0;
	                o = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = Cb[c[135744 >> 2] & 511](20) | 0;
	                if (!(c[o >> 2] | 0)) {
	                    Qz(c[j >> 2] | 0, 139336);
	                    c[h >> 2] = 0;
	                    p = c[h >> 2] | 0;
	                    i = g;
	                    return p | 0
	                } else {
	                    c[c[o >> 2] >> 2] = c[k >> 2];
	                    c[(c[o >> 2] | 0) + 4 >> 2] = c[l >> 2];
	                    c[(c[o >> 2] | 0) + 8 >> 2] = c[m >> 2];
	                    c[(c[o >> 2] | 0) + 12 >> 2] = c[n >> 2];
	                    c[h >> 2] = c[o >> 2];
	                    p = c[h >> 2] | 0;
	                    i = g;
	                    return p | 0
	                }
	                return 0
	            }

	            function JA(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                c[e >> 2] = a;
	                c[f >> 2] = oe(0, c[(c[e >> 2] | 0) + 4 >> 2] | 0, b) | 0;
	                if ((c[f >> 2] | 0) == 46 | (c[f >> 2] | 0) == 92 | (c[f >> 2] | 0) == 63 | (c[f >> 2] | 0) == 42 | (c[f >> 2] | 0) == 43 | (c[f >> 2] | 0) == 40 | (c[f >> 2] | 0) == 41 | (c[f >> 2] | 0) == 124 | (c[f >> 2] | 0) == 91 | (c[f >> 2] | 0) == 93 | (c[f >> 2] | 0) == 0) {
	                    c[d >> 2] = -1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function KA(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b;
	                c[e >> 2] = a;
	                a = c[e >> 2] | 0;
	                if ((d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) != 91) {
	                    NA(a);
	                    i = b;
	                    return
	                }
	                f = a + 4 | 0;
	                c[f >> 2] = (c[f >> 2] | 0) + 1;
	                f = eA(c[e >> 2] | 0, 3) | 0;
	                c[(c[e >> 2] | 0) + 28 >> 2] = f;
	                if (!(c[(c[e >> 2] | 0) + 28 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                MA(c[e >> 2] | 0);
	                f = c[e >> 2] | 0;
	                if ((d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) == 93) {
	                    a = f + 4 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1;
	                    i = b;
	                    return
	                } else {
	                    c[f + 8 >> 2] = 1450;
	                    Yz(c[e >> 2] | 0, 139704);
	                    i = b;
	                    return
	                }
	            }

	            function LA(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                g = b + 4 | 0;
	                h = b;
	                c[f >> 2] = a;
	                c[g >> 2] = 0;
	                c[h >> 2] = 0;
	                while (1) {
	                    if ((d[c[(c[f >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) < 48)break;
	                    if ((d[c[(c[f >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) > 57)break;
	                    c[g >> 2] = ((c[g >> 2] | 0) * 10 | 0) + ((d[c[(c[f >> 2] | 0) + 4 >> 2] >> 0] | 0) - 48);
	                    c[h >> 2] = 1;
	                    a = (c[f >> 2] | 0) + 4 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1
	                }
	                if ((c[h >> 2] | 0) != 1) {
	                    c[e >> 2] = -1;
	                    j = c[e >> 2] | 0;
	                    i = b;
	                    return j | 0
	                } else {
	                    c[e >> 2] = c[g >> 2];
	                    j = c[e >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                return 0
	            }

	            function MA(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                g = b + 4 | 0;
	                h = b;
	                c[e >> 2] = a;
	                c[f >> 2] = c[(c[e >> 2] | 0) + 12 >> 2];
	                while (1) {
	                    if ((d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) == 93) {
	                        j = 13;
	                        break
	                    }
	                    if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                        j = 13;
	                        break
	                    }
	                    a = c[e >> 2] | 0;
	                    if ((d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) == 94) {
	                        c[g >> 2] = c[a + 12 >> 2];
	                        k = (c[e >> 2] | 0) + 4 | 0;
	                        c[k >> 2] = (c[k >> 2] | 0) + 1;
	                        c[(c[e >> 2] | 0) + 12 >> 2] = ((c[(c[e >> 2] | 0) + 12 >> 2] | 0) != 0 ^ 1) & 1;
	                        OA(c[e >> 2] | 0);
	                        c[(c[e >> 2] | 0) + 12 >> 2] = c[g >> 2];
	                        continue
	                    }
	                    if ((d[c[a + 4 >> 2] >> 0] | 0 | 0) == 45 ? (d[(c[(c[e >> 2] | 0) + 4 >> 2] | 0) + 1 >> 0] | 0 | 0) == 91 : 0) {
	                        j = 8;
	                        break
	                    }
	                    if ((d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) == 93)continue;
	                    OA(c[e >> 2] | 0)
	                }
	                if ((j | 0) == 8) {
	                    c[h >> 2] = c[(c[e >> 2] | 0) + 12 >> 2];
	                    c[(c[e >> 2] | 0) + 12 >> 2] = 2;
	                    g = (c[e >> 2] | 0) + 4 | 0;
	                    c[g >> 2] = (c[g >> 2] | 0) + 1;
	                    g = (c[e >> 2] | 0) + 4 | 0;
	                    c[g >> 2] = (c[g >> 2] | 0) + 1;
	                    MA(c[e >> 2] | 0);
	                    g = c[e >> 2] | 0;
	                    if ((d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) == 93) {
	                        a = g + 4 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1;
	                        c[(c[e >> 2] | 0) + 12 >> 2] = c[h >> 2];
	                        l = c[f >> 2] | 0;
	                        m = c[e >> 2] | 0;
	                        n = m + 12 | 0;
	                        c[n >> 2] = l;
	                        i = b;
	                        return
	                    } else {
	                        c[g + 8 >> 2] = 1450;
	                        Yz(c[e >> 2] | 0, 139968);
	                        l = c[f >> 2] | 0;
	                        m = c[e >> 2] | 0;
	                        n = m + 12 | 0;
	                        c[n >> 2] = l;
	                        i = b;
	                        return
	                    }
	                } else if ((j | 0) == 13) {
	                    l = c[f >> 2] | 0;
	                    m = c[e >> 2] | 0;
	                    n = m + 12 | 0;
	                    c[n >> 2] = l;
	                    i = b;
	                    return
	                }
	            }

	            function NA(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                a = c[e >> 2] | 0;
	                if ((d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) == 46) {
	                    h = c[e >> 2] | 0;
	                    if (c[a + 28 >> 2] | 0) {
	                        if ((c[(c[h + 28 >> 2] | 0) + 4 >> 2] | 0) == 3)PA(c[e >> 2] | 0, c[(c[e >> 2] | 0) + 28 >> 2] | 0, c[(c[e >> 2] | 0) + 12 >> 2] | 0, 6, 0, 0, 0)
	                    } else {
	                        j = eA(h, 6) | 0;
	                        c[(c[e >> 2] | 0) + 28 >> 2] = j
	                    }
	                    j = (c[e >> 2] | 0) + 4 | 0;
	                    c[j >> 2] = (c[j >> 2] | 0) + 1;
	                    i = b;
	                    return
	                }
	                j = c[e >> 2] | 0;
	                if ((d[c[a + 4 >> 2] >> 0] | 0 | 0) != 92) {
	                    c[j + 8 >> 2] = 1450;
	                    Yz(c[e >> 2] | 0, 139744);
	                    i = b;
	                    return
	                }
	                a = j + 4 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + 1;
	                c[f >> 2] = d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0];
	                if ((c[f >> 2] | 0) == 112) {
	                    a = (c[e >> 2] | 0) + 4 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1;
	                    a = c[e >> 2] | 0;
	                    if ((d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) != 123) {
	                        c[a + 8 >> 2] = 1450;
	                        Yz(c[e >> 2] | 0, 139776);
	                        i = b;
	                        return
	                    }
	                    j = a + 4 | 0;
	                    c[j >> 2] = (c[j >> 2] | 0) + 1;
	                    QA(c[e >> 2] | 0);
	                    j = c[e >> 2] | 0;
	                    if ((d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) != 125) {
	                        c[j + 8 >> 2] = 1450;
	                        Yz(c[e >> 2] | 0, 139792);
	                        i = b;
	                        return
	                    } else {
	                        a = j + 4 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1;
	                        i = b;
	                        return
	                    }
	                }
	                if ((c[f >> 2] | 0) == 80) {
	                    a = (c[e >> 2] | 0) + 4 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1;
	                    a = c[e >> 2] | 0;
	                    if ((d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) != 123) {
	                        c[a + 8 >> 2] = 1450;
	                        Yz(c[e >> 2] | 0, 139776);
	                        i = b;
	                        return
	                    }
	                    j = a + 4 | 0;
	                    c[j >> 2] = (c[j >> 2] | 0) + 1;
	                    QA(c[e >> 2] | 0);
	                    c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + 28 >> 2] = 1;
	                    j = c[e >> 2] | 0;
	                    if ((d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) != 125) {
	                        c[j + 8 >> 2] = 1450;
	                        Yz(c[e >> 2] | 0, 139792);
	                        i = b;
	                        return
	                    } else {
	                        a = j + 4 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1;
	                        i = b;
	                        return
	                    }
	                }
	                if ((c[f >> 2] | 0) == 110 | (c[f >> 2] | 0) == 114 | (c[f >> 2] | 0) == 116 | (c[f >> 2] | 0) == 92 | (c[f >> 2] | 0) == 124 | (c[f >> 2] | 0) == 46 | (c[f >> 2] | 0) == 63 | (c[f >> 2] | 0) == 42 | (c[f >> 2] | 0) == 43 | (c[f >> 2] | 0) == 40 | (c[f >> 2] | 0) == 41 | (c[f >> 2] | 0) == 123 | (c[f >> 2] | 0) == 125 | (c[f >> 2] | 0) == 45 | (c[f >> 2] | 0) == 91 | (c[f >> 2] | 0) == 93 | (c[f >> 2] | 0) == 94) {
	                    a = c[e >> 2] | 0;
	                    do if (!(c[(c[e >> 2] | 0) + 28 >> 2] | 0)) {
	                        j = eA(a, 2) | 0;
	                        c[(c[e >> 2] | 0) + 28 >> 2] = j;
	                        if (c[(c[e >> 2] | 0) + 28 >> 2] | 0) {
	                            j = c[f >> 2] | 0;
	                            if ((j | 0) == 116) {
	                                c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + 32 >> 2] = 9;
	                                break
	                            } else if ((j | 0) == 110) {
	                                c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + 32 >> 2] = 10;
	                                break
	                            } else if ((j | 0) == 114) {
	                                c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + 32 >> 2] = 13;
	                                break
	                            } else {
	                                c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + 32 >> 2] = c[f >> 2];
	                                break
	                            }
	                        }
	                    } else if ((c[(c[a + 28 >> 2] | 0) + 4 >> 2] | 0) == 3) {
	                        j = c[f >> 2] | 0;
	                        if ((j | 0) == 110)c[f >> 2] = 10; else if ((j | 0) == 114)c[f >> 2] = 13; else if ((j | 0) == 116)c[f >> 2] = 9;
	                        PA(c[e >> 2] | 0, c[(c[e >> 2] | 0) + 28 >> 2] | 0, c[(c[e >> 2] | 0) + 12 >> 2] | 0, 2, c[f >> 2] | 0, c[f >> 2] | 0, 0)
	                    } while (0);
	                    a = (c[e >> 2] | 0) + 4 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1;
	                    i = b;
	                    return
	                }
	                if (!((c[f >> 2] | 0) == 115 | (c[f >> 2] | 0) == 83 | (c[f >> 2] | 0) == 105 | (c[f >> 2] | 0) == 73 | (c[f >> 2] | 0) == 99 | (c[f >> 2] | 0) == 67 | (c[f >> 2] | 0) == 100 | (c[f >> 2] | 0) == 68 | (c[f >> 2] | 0) == 119 | (c[f >> 2] | 0) == 87)) {
	                    c[(c[e >> 2] | 0) + 8 >> 2] = 1450;
	                    Yz(c[e >> 2] | 0, 139808);
	                    i = b;
	                    return
	                }
	                c[g >> 2] = 7;
	                do switch (c[f >> 2] | 0) {
	                    case 115:
	                    {
	                        c[g >> 2] = 7;
	                        break
	                    }
	                    case 83:
	                    {
	                        c[g >> 2] = 8;
	                        break
	                    }
	                    case 99:
	                    {
	                        c[g >> 2] = 11;
	                        break
	                    }
	                    case 67:
	                    {
	                        c[g >> 2] = 12;
	                        break
	                    }
	                    case 119:
	                    {
	                        c[g >> 2] = 15;
	                        break
	                    }
	                    case 87:
	                    {
	                        c[g >> 2] = 16;
	                        break
	                    }
	                    case 105:
	                    {
	                        c[g >> 2] = 9;
	                        break
	                    }
	                    case 73:
	                    {
	                        c[g >> 2] = 10;
	                        break
	                    }
	                    case 100:
	                    {
	                        c[g >> 2] = 13;
	                        break
	                    }
	                    case 68:
	                    {
	                        c[g >> 2] = 14;
	                        break
	                    }
	                    default:
	                    {
	                    }
	                } while (0);
	                f = (c[e >> 2] | 0) + 4 | 0;
	                c[f >> 2] = (c[f >> 2] | 0) + 1;
	                f = c[e >> 2] | 0;
	                if (!(c[(c[e >> 2] | 0) + 28 >> 2] | 0)) {
	                    a = eA(f, c[g >> 2] | 0) | 0;
	                    c[(c[e >> 2] | 0) + 28 >> 2] = a;
	                    i = b;
	                    return
	                }
	                if ((c[(c[f + 28 >> 2] | 0) + 4 >> 2] | 0) != 3) {
	                    i = b;
	                    return
	                }
	                PA(c[e >> 2] | 0, c[(c[e >> 2] | 0) + 28 >> 2] | 0, c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[g >> 2] | 0, 0, 0, 0);
	                i = b;
	                return
	            }

	            function OA(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b;
	                c[e >> 2] = a;
	                while (1) {
	                    a = c[e >> 2] | 0;
	                    if ((d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) == 92)NA(a); else RA(a);
	                    if ((d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) == 93) {
	                        f = 10;
	                        break
	                    }
	                    if ((d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) == 94) {
	                        f = 10;
	                        break
	                    }
	                    if ((d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) == 45) {
	                        f = 10;
	                        break
	                    }
	                    if (!(d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0] | 0)) {
	                        f = 10;
	                        break
	                    }
	                    if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                        f = 10;
	                        break
	                    }
	                }
	                if ((f | 0) == 10) {
	                    i = b;
	                    return
	                }
	            }

	            function PA(a, b, d, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                j = i;
	                i = i + 48 | 0;
	                k = j + 32 | 0;
	                l = j + 28 | 0;
	                m = j + 24 | 0;
	                n = j + 20 | 0;
	                o = j + 16 | 0;
	                p = j + 12 | 0;
	                q = j + 8 | 0;
	                r = j + 4 | 0;
	                s = j;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                c[q >> 2] = h;
	                if (!(c[l >> 2] | 0)) {
	                    c[(c[k >> 2] | 0) + 8 >> 2] = 1450;
	                    Yz(c[k >> 2] | 0, 139896);
	                    i = j;
	                    return
	                }
	                if ((c[(c[l >> 2] | 0) + 4 >> 2] | 0) != 3) {
	                    c[(c[k >> 2] | 0) + 8 >> 2] = 1450;
	                    Yz(c[k >> 2] | 0, 139920);
	                    i = j;
	                    return
	                }
	                h = c[l >> 2] | 0;
	                do if (!(c[(c[l >> 2] | 0) + 48 >> 2] | 0)) {
	                    c[h + 48 >> 2] = 4;
	                    g = Cb[c[135744 >> 2] & 511](c[(c[l >> 2] | 0) + 48 >> 2] << 2) | 0;
	                    c[(c[l >> 2] | 0) + 56 >> 2] = g;
	                    if (!(c[(c[l >> 2] | 0) + 56 >> 2] | 0)) {
	                        Qz(c[k >> 2] | 0, 139952);
	                        c[(c[l >> 2] | 0) + 48 >> 2] = 0;
	                        i = j;
	                        return
	                    }
	                } else if ((c[h + 52 >> 2] | 0) >= (c[(c[l >> 2] | 0) + 48 >> 2] | 0)) {
	                    g = (c[l >> 2] | 0) + 48 | 0;
	                    c[g >> 2] = c[g >> 2] << 1;
	                    c[s >> 2] = Hb[c[135760 >> 2] & 511](c[(c[l >> 2] | 0) + 56 >> 2] | 0, c[(c[l >> 2] | 0) + 48 >> 2] << 2) | 0;
	                    if (c[s >> 2] | 0) {
	                        c[(c[l >> 2] | 0) + 56 >> 2] = c[s >> 2];
	                        break
	                    }
	                    Qz(c[k >> 2] | 0, 139952);
	                    g = (c[l >> 2] | 0) + 48 | 0;
	                    c[g >> 2] = (c[g >> 2] | 0) / 2 | 0;
	                    i = j;
	                    return
	                } while (0);
	                c[r >> 2] = IA(c[k >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0) | 0;
	                if (!(c[r >> 2] | 0)) {
	                    i = j;
	                    return
	                }
	                c[(c[r >> 2] | 0) + 16 >> 2] = c[q >> 2];
	                q = c[r >> 2] | 0;
	                r = (c[l >> 2] | 0) + 52 | 0;
	                p = c[r >> 2] | 0;
	                c[r >> 2] = p + 1;
	                c[(c[(c[l >> 2] | 0) + 56 >> 2] | 0) + (p << 2) >> 2] = q;
	                i = j;
	                return
	            }

	            function QA(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                b = i;
	                i = i + 32 | 0;
	                e = b + 16 | 0;
	                f = b + 12 | 0;
	                g = b + 8 | 0;
	                h = b + 4 | 0;
	                j = b;
	                c[e >> 2] = a;
	                c[g >> 2] = 0;
	                c[h >> 2] = 0;
	                c[f >> 2] = d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0];
	                do if ((c[f >> 2] | 0) == 76) {
	                    a = (c[e >> 2] | 0) + 4 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1;
	                    c[f >> 2] = d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0];
	                    if ((c[f >> 2] | 0) == 117) {
	                        a = (c[e >> 2] | 0) + 4 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1;
	                        c[g >> 2] = 101;
	                        break
	                    }
	                    if ((c[f >> 2] | 0) == 108) {
	                        a = (c[e >> 2] | 0) + 4 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1;
	                        c[g >> 2] = 102;
	                        break
	                    }
	                    if ((c[f >> 2] | 0) == 116) {
	                        a = (c[e >> 2] | 0) + 4 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1;
	                        c[g >> 2] = 103;
	                        break
	                    }
	                    if ((c[f >> 2] | 0) == 109) {
	                        a = (c[e >> 2] | 0) + 4 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1;
	                        c[g >> 2] = 104;
	                        break
	                    }
	                    if ((c[f >> 2] | 0) == 111) {
	                        a = (c[e >> 2] | 0) + 4 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1;
	                        c[g >> 2] = 105;
	                        break
	                    } else {
	                        c[g >> 2] = 100;
	                        break
	                    }
	                } else {
	                    if ((c[f >> 2] | 0) == 77) {
	                        a = (c[e >> 2] | 0) + 4 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1;
	                        c[f >> 2] = d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0];
	                        if ((c[f >> 2] | 0) == 110) {
	                            a = (c[e >> 2] | 0) + 4 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1;
	                            c[g >> 2] = 107;
	                            break
	                        }
	                        if ((c[f >> 2] | 0) == 99) {
	                            a = (c[e >> 2] | 0) + 4 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1;
	                            c[g >> 2] = 108;
	                            break
	                        }
	                        if ((c[f >> 2] | 0) == 101) {
	                            a = (c[e >> 2] | 0) + 4 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1;
	                            c[g >> 2] = 109;
	                            break
	                        } else {
	                            c[g >> 2] = 106;
	                            break
	                        }
	                    }
	                    if ((c[f >> 2] | 0) == 78) {
	                        a = (c[e >> 2] | 0) + 4 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1;
	                        c[f >> 2] = d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0];
	                        if ((c[f >> 2] | 0) == 100) {
	                            a = (c[e >> 2] | 0) + 4 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1;
	                            c[g >> 2] = 111;
	                            break
	                        }
	                        if ((c[f >> 2] | 0) == 108) {
	                            a = (c[e >> 2] | 0) + 4 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1;
	                            c[g >> 2] = 112;
	                            break
	                        }
	                        if ((c[f >> 2] | 0) == 111) {
	                            a = (c[e >> 2] | 0) + 4 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1;
	                            c[g >> 2] = 113;
	                            break
	                        } else {
	                            c[g >> 2] = 110;
	                            break
	                        }
	                    }
	                    if ((c[f >> 2] | 0) == 80) {
	                        a = (c[e >> 2] | 0) + 4 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1;
	                        c[f >> 2] = d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0];
	                        if ((c[f >> 2] | 0) == 99) {
	                            a = (c[e >> 2] | 0) + 4 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1;
	                            c[g >> 2] = 115;
	                            break
	                        }
	                        if ((c[f >> 2] | 0) == 100) {
	                            a = (c[e >> 2] | 0) + 4 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1;
	                            c[g >> 2] = 116;
	                            break
	                        }
	                        if ((c[f >> 2] | 0) == 115) {
	                            a = (c[e >> 2] | 0) + 4 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1;
	                            c[g >> 2] = 117;
	                            break
	                        }
	                        if ((c[f >> 2] | 0) == 101) {
	                            a = (c[e >> 2] | 0) + 4 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1;
	                            c[g >> 2] = 118;
	                            break
	                        }
	                        if ((c[f >> 2] | 0) == 105) {
	                            a = (c[e >> 2] | 0) + 4 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1;
	                            c[g >> 2] = 119;
	                            break
	                        }
	                        if ((c[f >> 2] | 0) == 102) {
	                            a = (c[e >> 2] | 0) + 4 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1;
	                            c[g >> 2] = 120;
	                            break
	                        }
	                        if ((c[f >> 2] | 0) == 111) {
	                            a = (c[e >> 2] | 0) + 4 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1;
	                            c[g >> 2] = 121;
	                            break
	                        } else {
	                            c[g >> 2] = 114;
	                            break
	                        }
	                    }
	                    if ((c[f >> 2] | 0) == 90) {
	                        a = (c[e >> 2] | 0) + 4 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1;
	                        c[f >> 2] = d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0];
	                        if ((c[f >> 2] | 0) == 115) {
	                            a = (c[e >> 2] | 0) + 4 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1;
	                            c[g >> 2] = 123;
	                            break
	                        }
	                        if ((c[f >> 2] | 0) == 108) {
	                            a = (c[e >> 2] | 0) + 4 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1;
	                            c[g >> 2] = 124;
	                            break
	                        }
	                        if ((c[f >> 2] | 0) == 112) {
	                            a = (c[e >> 2] | 0) + 4 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1;
	                            c[g >> 2] = 125;
	                            break
	                        } else {
	                            c[g >> 2] = 122;
	                            break
	                        }
	                    }
	                    if ((c[f >> 2] | 0) == 83) {
	                        a = (c[e >> 2] | 0) + 4 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1;
	                        c[f >> 2] = d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0];
	                        if ((c[f >> 2] | 0) == 109) {
	                            a = (c[e >> 2] | 0) + 4 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1;
	                            c[g >> 2] = 127;
	                            break
	                        }
	                        if ((c[f >> 2] | 0) == 99) {
	                            a = (c[e >> 2] | 0) + 4 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1;
	                            c[g >> 2] = 128;
	                            break
	                        }
	                        if ((c[f >> 2] | 0) == 107) {
	                            a = (c[e >> 2] | 0) + 4 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1;
	                            c[g >> 2] = 129;
	                            break
	                        }
	                        if ((c[f >> 2] | 0) == 111) {
	                            a = (c[e >> 2] | 0) + 4 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1;
	                            c[g >> 2] = 130;
	                            break
	                        } else {
	                            c[g >> 2] = 126;
	                            break
	                        }
	                    }
	                    if ((c[f >> 2] | 0) == 67) {
	                        a = (c[e >> 2] | 0) + 4 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1;
	                        c[f >> 2] = d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0];
	                        if ((c[f >> 2] | 0) == 99) {
	                            a = (c[e >> 2] | 0) + 4 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1;
	                            c[g >> 2] = 132;
	                            break
	                        }
	                        if ((c[f >> 2] | 0) == 102) {
	                            a = (c[e >> 2] | 0) + 4 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1;
	                            c[g >> 2] = 133;
	                            break
	                        }
	                        if ((c[f >> 2] | 0) == 111) {
	                            a = (c[e >> 2] | 0) + 4 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1;
	                            c[g >> 2] = 134;
	                            break
	                        }
	                        if ((c[f >> 2] | 0) == 110) {
	                            a = (c[e >> 2] | 0) + 4 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1;
	                            c[g >> 2] = 135;
	                            break
	                        } else {
	                            c[g >> 2] = 131;
	                            break
	                        }
	                    }
	                    a = c[e >> 2] | 0;
	                    if ((c[f >> 2] | 0) != 73) {
	                        c[a + 8 >> 2] = 1450;
	                        Yz(c[e >> 2] | 0, 139872);
	                        i = b;
	                        return
	                    }
	                    k = a + 4 | 0;
	                    c[k >> 2] = (c[k >> 2] | 0) + 1;
	                    c[f >> 2] = d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0];
	                    k = c[e >> 2] | 0;
	                    if ((c[f >> 2] | 0) != 115) {
	                        c[k + 8 >> 2] = 1450;
	                        Yz(c[e >> 2] | 0, 139856);
	                        i = b;
	                        return
	                    }
	                    a = k + 4 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1;
	                    c[j >> 2] = c[(c[e >> 2] | 0) + 4 >> 2];
	                    c[f >> 2] = d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0];
	                    if (!((!((c[f >> 2] | 0) >= 97 & (c[f >> 2] | 0) <= 122) ? !((c[f >> 2] | 0) >= 65 & (c[f >> 2] | 0) <= 90) : 0) ? !((c[f >> 2] | 0) >= 48 & (c[f >> 2] | 0) <= 57 | (c[f >> 2] | 0) == 45) : 0))l = 79;
	                    a:do if ((l | 0) == 79) {
	                        a = (c[e >> 2] | 0) + 4 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1;
	                        c[f >> 2] = d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0];
	                        while (1) {
	                            if ((!((c[f >> 2] | 0) >= 97 & (c[f >> 2] | 0) <= 122) ? !((c[f >> 2] | 0) >= 65 & (c[f >> 2] | 0) <= 90) : 0) ? !((c[f >> 2] | 0) >= 48 & (c[f >> 2] | 0) <= 57 | (c[f >> 2] | 0) == 45) : 0)break a;
	                            a = (c[e >> 2] | 0) + 4 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1;
	                            c[f >> 2] = d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0]
	                        }
	                    } while (0);
	                    c[g >> 2] = 136;
	                    c[h >> 2] = ly(c[j >> 2] | 0, (c[(c[e >> 2] | 0) + 4 >> 2] | 0) - (c[j >> 2] | 0) | 0) | 0
	                } while (0);
	                j = c[e >> 2] | 0;
	                if (!(c[(c[e >> 2] | 0) + 28 >> 2] | 0)) {
	                    f = eA(j, c[g >> 2] | 0) | 0;
	                    c[(c[e >> 2] | 0) + 28 >> 2] = f;
	                    if (!(c[(c[e >> 2] | 0) + 28 >> 2] | 0)) {
	                        i = b;
	                        return
	                    }
	                    c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + 20 >> 2] = c[h >> 2];
	                    i = b;
	                    return
	                } else {
	                    if ((c[(c[j + 28 >> 2] | 0) + 4 >> 2] | 0) != 3) {
	                        i = b;
	                        return
	                    }
	                    PA(c[e >> 2] | 0, c[(c[e >> 2] | 0) + 28 >> 2] | 0, c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[g >> 2] | 0, 0, 0, c[h >> 2] | 0);
	                    i = b;
	                    return
	                }
	            }

	            function RA(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                b = i;
	                i = i + 32 | 0;
	                e = b + 16 | 0;
	                f = b + 12 | 0;
	                g = b + 8 | 0;
	                h = b + 4 | 0;
	                j = b;
	                c[e >> 2] = a;
	                c[h >> 2] = -1;
	                c[j >> 2] = -1;
	                a = c[e >> 2] | 0;
	                if (!(d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0] | 0)) {
	                    c[a + 8 >> 2] = 1450;
	                    Yz(c[e >> 2] | 0, 14e4);
	                    i = b;
	                    return
	                }
	                c[f >> 2] = d[c[a + 4 >> 2] >> 0];
	                do if ((c[f >> 2] | 0) == 92) {
	                    a = (c[e >> 2] | 0) + 4 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1;
	                    c[f >> 2] = d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0];
	                    switch (c[f >> 2] | 0) {
	                        case 93:
	                        case 91:
	                        case 41:
	                        case 40:
	                        case 125:
	                        case 123:
	                        case 43:
	                        case 42:
	                        case 63:
	                        case 94:
	                        case 45:
	                        case 46:
	                        case 124:
	                        case 92:
	                        {
	                            c[h >> 2] = c[f >> 2];
	                            break
	                        }
	                        case 114:
	                        {
	                            c[h >> 2] = 13;
	                            break
	                        }
	                        case 116:
	                        {
	                            c[h >> 2] = 9;
	                            break
	                        }
	                        case 110:
	                        {
	                            c[h >> 2] = 10;
	                            break
	                        }
	                        default:
	                        {
	                            c[(c[e >> 2] | 0) + 8 >> 2] = 1450;
	                            Yz(c[e >> 2] | 0, 140016);
	                            i = b;
	                            return
	                        }
	                    }
	                    c[j >> 2] = c[h >> 2];
	                    c[g >> 2] = 1
	                } else {
	                    a = c[e >> 2] | 0;
	                    if ((c[f >> 2] | 0) != 91 & (c[f >> 2] | 0) != 93) {
	                        k = oe(0, c[a + 4 >> 2] | 0, g) | 0;
	                        c[h >> 2] = k;
	                        c[j >> 2] = k;
	                        break
	                    }
	                    c[a + 8 >> 2] = 1450;
	                    Yz(c[e >> 2] | 0, 140040);
	                    i = b;
	                    return
	                } while (0);
	                if ((((c[h >> 2] | 0) == 45 ? (d[(c[(c[e >> 2] | 0) + 4 >> 2] | 0) + 1 >> 0] | 0 | 0) != 93 : 0) ? (d[(c[(c[e >> 2] | 0) + 4 >> 2] | 0) + -1 >> 0] | 0 | 0) != 91 : 0) ? (d[(c[(c[e >> 2] | 0) + 4 >> 2] | 0) + -1 >> 0] | 0 | 0) != 94 : 0) {
	                    a = (c[e >> 2] | 0) + 4 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + (c[g >> 2] | 0);
	                    i = b;
	                    return
	                }
	                a = (c[e >> 2] | 0) + 4 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + (c[g >> 2] | 0);
	                c[f >> 2] = d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0];
	                if ((c[f >> 2] | 0) == 45 ? (d[(c[(c[e >> 2] | 0) + 4 >> 2] | 0) + 1 >> 0] | 0 | 0) != 93 : 0) {
	                    a = (c[e >> 2] | 0) + 4 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1;
	                    c[f >> 2] = d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0];
	                    do if ((c[f >> 2] | 0) == 92) {
	                        a = (c[e >> 2] | 0) + 4 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1;
	                        c[f >> 2] = d[c[(c[e >> 2] | 0) + 4 >> 2] >> 0];
	                        switch (c[f >> 2] | 0) {
	                            case 93:
	                            case 91:
	                            case 41:
	                            case 40:
	                            case 125:
	                            case 123:
	                            case 43:
	                            case 42:
	                            case 63:
	                            case 94:
	                            case 45:
	                            case 46:
	                            case 124:
	                            case 92:
	                            {
	                                c[j >> 2] = c[f >> 2];
	                                break
	                            }
	                            case 110:
	                            {
	                                c[j >> 2] = 10;
	                                break
	                            }
	                            case 114:
	                            {
	                                c[j >> 2] = 13;
	                                break
	                            }
	                            case 116:
	                            {
	                                c[j >> 2] = 9;
	                                break
	                            }
	                            default:
	                            {
	                                c[(c[e >> 2] | 0) + 8 >> 2] = 1450;
	                                Yz(c[e >> 2] | 0, 140016);
	                                i = b;
	                                return
	                            }
	                        }
	                        c[g >> 2] = 1
	                    } else {
	                        a = c[e >> 2] | 0;
	                        if ((c[f >> 2] | 0) != 91 & (c[f >> 2] | 0) != 93) {
	                            c[j >> 2] = oe(0, c[a + 4 >> 2] | 0, g) | 0;
	                            break
	                        }
	                        c[a + 8 >> 2] = 1450;
	                        Yz(c[e >> 2] | 0, 140064);
	                        i = b;
	                        return
	                    } while (0);
	                    f = (c[e >> 2] | 0) + 4 | 0;
	                    c[f >> 2] = (c[f >> 2] | 0) + (c[g >> 2] | 0);
	                    g = c[e >> 2] | 0;
	                    if ((c[j >> 2] | 0) < (c[h >> 2] | 0)) {
	                        c[g + 8 >> 2] = 1450;
	                        Yz(c[e >> 2] | 0, 140104);
	                        i = b;
	                        return
	                    } else {
	                        PA(g, c[(c[e >> 2] | 0) + 28 >> 2] | 0, c[(c[e >> 2] | 0) + 12 >> 2] | 0, 2, c[h >> 2] | 0, c[j >> 2] | 0, 0);
	                        i = b;
	                        return
	                    }
	                }
	                PA(c[e >> 2] | 0, c[(c[e >> 2] | 0) + 28 >> 2] | 0, c[(c[e >> 2] | 0) + 12 >> 2] | 0, 2, c[h >> 2] | 0, c[j >> 2] | 0, 0);
	                i = b;
	                return
	            }

	            function SA() {
	                var a = 0, b = 0, d = 0, e = 0, f = 0, g = 0;
	                a = i;
	                i = i + 16 | 0;
	                b = a + 4 | 0;
	                d = a;
	                c[d >> 2] = Cb[c[135744 >> 2] & 511](40) | 0;
	                if (!(c[d >> 2] | 0)) {
	                    c[b >> 2] = 0;
	                    e = c[b >> 2] | 0;
	                    i = a;
	                    return e | 0
	                } else {
	                    f = (c[d >> 2] | 0) + 0 | 0;
	                    g = f + 40 | 0;
	                    do {
	                        c[f >> 2] = 0;
	                        f = f + 4 | 0
	                    } while ((f | 0) < (g | 0));
	                    c[b >> 2] = c[d >> 2];
	                    e = c[b >> 2] | 0;
	                    i = a;
	                    return e | 0
	                }
	                return 0
	            }

	            function TA(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 8 >> 2] | 0)mB(c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 32 >> 2] | 0)nB(c[(c[d >> 2] | 0) + 32 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 36 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 36 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function UA(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 32 >> 2] | 0)PH(c[(c[d >> 2] | 0) + 32 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 36 >> 2] | 0)zz(c[(c[d >> 2] | 0) + 36 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 16 >> 2] | 0)mB(c[(c[d >> 2] | 0) + 16 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function VA(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 16 | 0;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                g = b + 4 | 0;
	                h = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 24 >> 2] | 0)mB(c[(c[d >> 2] | 0) + 24 >> 2] | 0);
	                a:do if (c[(c[d >> 2] | 0) + 68 >> 2] | 0) {
	                    c[e >> 2] = c[(c[d >> 2] | 0) + 68 >> 2];
	                    while (1) {
	                        if (!(c[e >> 2] | 0))break a;
	                        c[f >> 2] = c[(c[e >> 2] | 0) + 4 >> 2];
	                        UA(c[e >> 2] | 0);
	                        c[e >> 2] = c[f >> 2]
	                    }
	                } while (0);
	                if (c[(c[d >> 2] | 0) + 116 >> 2] | 0)oB(c[(c[d >> 2] | 0) + 116 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 92 >> 2] | 0)pB(c[(c[d >> 2] | 0) + 92 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 96 >> 2] | 0) {
	                    c[h >> 2] = c[(c[d >> 2] | 0) + 96 >> 2];
	                    do {
	                        c[g >> 2] = c[c[h >> 2] >> 2];
	                        zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                        c[h >> 2] = c[g >> 2]
	                    } while ((c[h >> 2] | 0) != 0)
	                }
	                if (c[(c[d >> 2] | 0) + 108 >> 2] | 0)zz(c[(c[d >> 2] | 0) + 108 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function WA(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b;
	                e = b + 16 | 0;
	                f = b + 12 | 0;
	                g = b + 8 | 0;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[e >> 2] | 0) + 80 >> 2] | 0) {
	                    a = c[33976] | 0;
	                    h = c[33980] | 0;
	                    c[d >> 2] = 140328;
	                    c[d + 4 >> 2] = 4118;
	                    Db[a & 511](h, 140296, d)
	                }
	                if (c[(c[e >> 2] | 0) + 44 >> 2] | 0)Kj(c[(c[e >> 2] | 0) + 44 >> 2] | 0, 0);
	                if (c[(c[e >> 2] | 0) + 32 >> 2] | 0)Kj(c[(c[e >> 2] | 0) + 32 >> 2] | 0, 0);
	                if (c[(c[e >> 2] | 0) + 36 >> 2] | 0)Kj(c[(c[e >> 2] | 0) + 36 >> 2] | 0, 0);
	                if (c[(c[e >> 2] | 0) + 40 >> 2] | 0)Kj(c[(c[e >> 2] | 0) + 40 >> 2] | 0, 0);
	                if (c[(c[e >> 2] | 0) + 28 >> 2] | 0)Kj(c[(c[e >> 2] | 0) + 28 >> 2] | 0, 0);
	                if (c[(c[e >> 2] | 0) + 56 >> 2] | 0)Kj(c[(c[e >> 2] | 0) + 56 >> 2] | 0, 0);
	                if (c[(c[e >> 2] | 0) + 76 >> 2] | 0)Kj(c[(c[e >> 2] | 0) + 76 >> 2] | 0, 0);
	                if (c[(c[e >> 2] | 0) + 48 >> 2] | 0)Kj(c[(c[e >> 2] | 0) + 48 >> 2] | 0, 322);
	                if (c[(c[e >> 2] | 0) + 64 >> 2] | 0) {
	                    c[f >> 2] = c[(c[e >> 2] | 0) + 64 >> 2];
	                    c[g >> 2] = 0;
	                    while (1) {
	                        if ((c[g >> 2] | 0) >= (c[(c[f >> 2] | 0) + 4 >> 2] | 0))break;
	                        qB(c[(c[c[f >> 2] >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0);
	                        c[g >> 2] = (c[g >> 2] | 0) + 1
	                    }
	                    oB(c[f >> 2] | 0)
	                }
	                if (c[(c[e >> 2] | 0) + 20 >> 2] | 0)mB(c[(c[e >> 2] | 0) + 20 >> 2] | 0);
	                zP(c[(c[e >> 2] | 0) + 60 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[e >> 2] | 0);
	                i = b;
	                return
	            }

	            function XA(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[f >> 2] = rB() | 0;
	                if (!(c[f >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    a = xP() | 0;
	                    c[(c[f >> 2] | 0) + 80 >> 2] = a;
	                    a = AP(c[(c[f >> 2] | 0) + 80 >> 2] | 0, c[e >> 2] | 0, -1) | 0;
	                    c[(c[f >> 2] | 0) + 44 >> 2] = a;
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function YA(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if ((c[(c[d >> 2] | 0) + 48 >> 2] | 0) != 0 ? (c[(c[d >> 2] | 0) + 52 >> 2] | 0) == 0 : 0)Th(c[(c[d >> 2] | 0) + 48 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 92 >> 2] | 0)ZA(c[(c[d >> 2] | 0) + 92 >> 2] | 0);
	                if ((c[(c[d >> 2] | 0) + 32 >> 2] | 0) != 0 ? (c[(c[d >> 2] | 0) + 28 >> 2] | 0) != 0 : 0) {
	                    sB(c[(c[d >> 2] | 0) + 28 >> 2] | 0);
	                    c[(c[d >> 2] | 0) + 28 >> 2] = 0;
	                    c[(c[d >> 2] | 0) + 32 >> 2] = 0
	                }
	                if (c[(c[d >> 2] | 0) + 128 >> 2] | 0)oB(c[(c[d >> 2] | 0) + 128 >> 2] | 0);
	                zP(c[(c[d >> 2] | 0) + 80 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function ZA(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                b = i;
	                i = i + 48 | 0;
	                d = b + 36 | 0;
	                e = b + 32 | 0;
	                f = b + 28 | 0;
	                g = b + 24 | 0;
	                h = b + 20 | 0;
	                j = b + 16 | 0;
	                k = b + 12 | 0;
	                l = b + 8 | 0;
	                m = b + 4 | 0;
	                n = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 72 >> 2] | 0)PH(c[(c[d >> 2] | 0) + 72 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 88 >> 2] | 0)YA(c[(c[d >> 2] | 0) + 88 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 128 >> 2] | 0) {
	                    c[e >> 2] = 0;
	                    while (1) {
	                        if ((c[e >> 2] | 0) >= (c[(c[d >> 2] | 0) + 132 >> 2] | 0))break;
	                        c[f >> 2] = c[(c[(c[d >> 2] | 0) + 128 >> 2] | 0) + (c[e >> 2] << 2) >> 2];
	                        zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                        c[e >> 2] = (c[e >> 2] | 0) + 1
	                    }
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 128 >> 2] | 0)
	                }
	                if (c[(c[d >> 2] | 0) + 140 >> 2] | 0) {
	                    c[g >> 2] = 0;
	                    while (1) {
	                        if ((c[g >> 2] | 0) >= (c[(c[d >> 2] | 0) + 144 >> 2] | 0))break;
	                        tB(c[(c[(c[d >> 2] | 0) + 140 >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0);
	                        c[g >> 2] = (c[g >> 2] | 0) + 1
	                    }
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 140 >> 2] | 0)
	                }
	                if (c[(c[d >> 2] | 0) + 116 >> 2] | 0) {
	                    uB(c[(c[d >> 2] | 0) + 116 >> 2] | 0);
	                    c[(c[d >> 2] | 0) + 116 >> 2] = 0
	                }
	                if (c[(c[d >> 2] | 0) + 120 >> 2] | 0) {
	                    uB(c[(c[d >> 2] | 0) + 120 >> 2] | 0);
	                    c[(c[d >> 2] | 0) + 120 >> 2] = 0
	                }
	                if (c[(c[d >> 2] | 0) + 112 >> 2] | 0) {
	                    c[h >> 2] = c[(c[d >> 2] | 0) + 112 >> 2];
	                    do {
	                        c[j >> 2] = c[c[h >> 2] >> 2];
	                        zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                        c[h >> 2] = c[j >> 2]
	                    } while ((c[h >> 2] | 0) != 0)
	                }
	                if (c[(c[d >> 2] | 0) + 164 >> 2] | 0) {
	                    if (c[(c[d >> 2] | 0) + 168 >> 2] | 0)vB(c[d >> 2] | 0);
	                    c[k >> 2] = 0;
	                    while (1) {
	                        if ((c[k >> 2] | 0) >= (c[(c[d >> 2] | 0) + 172 >> 2] | 0))break;
	                        c[l >> 2] = c[(c[(c[d >> 2] | 0) + 164 >> 2] | 0) + (c[k >> 2] << 2) >> 2];
	                        zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                        c[k >> 2] = (c[k >> 2] | 0) + 1
	                    }
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 164 >> 2] | 0)
	                }
	                if (c[(c[d >> 2] | 0) + 100 >> 2] | 0) {
	                    c[m >> 2] = 0;
	                    while (1) {
	                        if ((c[m >> 2] | 0) >= (c[(c[d >> 2] | 0) + 104 >> 2] | 0))break;
	                        c[n >> 2] = c[(c[(c[d >> 2] | 0) + 100 >> 2] | 0) + (c[m >> 2] << 2) >> 2];
	                        if (!(c[n >> 2] | 0))break;
	                        wB(c[d >> 2] | 0, c[n >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                        c[m >> 2] = (c[m >> 2] | 0) + 1
	                    }
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 100 >> 2] | 0)
	                }
	                if (c[(c[d >> 2] | 0) + 180 >> 2] | 0)oB(c[(c[d >> 2] | 0) + 180 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 156 >> 2] | 0)zP(c[(c[d >> 2] | 0) + 156 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 48 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 48 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function _A(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f;
	                h = f + 40 | 0;
	                j = f + 36 | 0;
	                k = f + 32 | 0;
	                l = f + 28 | 0;
	                m = f + 20 | 0;
	                n = f + 16 | 0;
	                o = f + 12 | 0;
	                p = f + 8 | 0;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[f + 24 >> 2] = e;
	                c[m >> 2] = 0;
	                if ((c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0) {
	                    c[h >> 2] = -1;
	                    q = c[h >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                if (!(c[l >> 2] | 0))c[n >> 2] = 0; else c[n >> 2] = 1;
	                a:do switch (c[c[j >> 2] >> 2] | 0) {
	                    case 1007:
	                    case 1003:
	                    case 1002:
	                    case 1001:
	                    case 1e3:
	                    {
	                        e = c[k >> 2] | 0;
	                        if ((c[c[k >> 2] >> 2] | 0) != 1) {
	                            c[o >> 2] = c[e + 64 >> 2];
	                            if (!(c[o >> 2] | 0)) {
	                                xB(c[l >> 2] | 0, 140360, 140384);
	                                c[h >> 2] = -1;
	                                q = c[h >> 2] | 0;
	                                i = f;
	                                return q | 0
	                            }
	                        } else c[o >> 2] = e;
	                        if ((c[n >> 2] | 0) == 0 ? (c[l >> 2] = XA(140432) | 0, (c[l >> 2] | 0) == 0) : 0) {
	                            c[h >> 2] = -1;
	                            q = c[h >> 2] | 0;
	                            i = f;
	                            return q | 0
	                        }
	                        c[m >> 2] = yB(c[l >> 2] | 0, c[(c[j >> 2] | 0) + 20 >> 2] | 0, c[o >> 2] | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0, (c[j >> 2] | 0) + 32 | 0, 1, 1, 0) | 0;
	                        if (!(c[m >> 2] | 0)) {
	                            if (c[(c[j >> 2] | 0) + 32 >> 2] | 0) {
	                                r = 45;
	                                break a
	                            }
	                            if (c[n >> 2] | 0)xB(c[l >> 2] | 0, 140360, 140632);
	                            e = c[33976] | 0;
	                            d = c[33980] | 0;
	                            c[g >> 2] = 140328;
	                            c[g + 4 >> 2] = 18739;
	                            Db[e & 511](d, 140296, g);
	                            r = 45;
	                            break a
	                        }
	                        if ((c[m >> 2] | 0) < 0) {
	                            if (!(c[n >> 2] | 0)) {
	                                r = 48;
	                                break a
	                            }
	                            d = c[l >> 2] | 0;
	                            e = c[(c[j >> 2] | 0) + 20 >> 2] | 0;
	                            b = c[(c[j >> 2] | 0) + 8 >> 2] | 0;
	                            AB(d, 3069, e, 0, 140440, b, zB(c[c[j >> 2] >> 2] | 0) | 0);
	                            r = 48;
	                            break a
	                        }
	                        c[m >> 2] = 1717;
	                        if ((c[n >> 2] | 0) != 0 ? (c[p >> 2] = 0, b = c[l >> 2] | 0, e = c[m >> 2] | 0, d = c[(c[j >> 2] | 0) + 20 >> 2] | 0, a = c[j >> 2] | 0, s = c[(c[j >> 2] | 0) + 8 >> 2] | 0, AB(b, e, d, a, 140552, s, BB(p, c[(c[o >> 2] | 0) + 112 >> 2] | 0, c[(c[o >> 2] | 0) + 8 >> 2] | 0) | 0), (c[p >> 2] | 0) != 0) : 0) {
	                            zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                            c[p >> 2] = 0;
	                            r = 45
	                        } else r = 45;
	                        break
	                    }
	                    case 1011:
	                    case 1010:
	                    case 1009:
	                    case 1005:
	                    case 1004:
	                    {
	                        if ((c[c[j >> 2] >> 2] | 0) == 1004) {
	                            s = IH(34) | 0;
	                            c[m >> 2] = VH(s, c[(c[j >> 2] | 0) + 8 >> 2] | 0, (c[j >> 2] | 0) + 32 | 0) | 0
	                        } else {
	                            s = IH(33) | 0;
	                            c[m >> 2] = VH(s, c[(c[j >> 2] | 0) + 8 >> 2] | 0, (c[j >> 2] | 0) + 32 | 0) | 0
	                        }
	                        if (c[m >> 2] | 0)if ((c[m >> 2] | 0) < 0) {
	                            if (!(c[n >> 2] | 0)) {
	                                r = 48;
	                                break a
	                            }
	                            xB(c[l >> 2] | 0, 140360, 140728);
	                            r = 48;
	                            break a
	                        } else {
	                            c[m >> 2] = 1717;
	                            if (!(c[n >> 2] | 0)) {
	                                r = 45;
	                                break a
	                            }
	                            s = c[l >> 2] | 0;
	                            a = c[m >> 2] | 0;
	                            d = c[(c[j >> 2] | 0) + 20 >> 2] | 0;
	                            e = c[k >> 2] | 0;
	                            b = c[(c[j >> 2] | 0) + 8 >> 2] | 0;
	                            t = zB(c[c[j >> 2] >> 2] | 0) | 0;
	                            CB(s, a, d, e, 140752, b, t, (c[c[j >> 2] >> 2] | 0) != 1004 ? 140808 : 140832, 0);
	                            r = 45;
	                            break a
	                        } else r = 45;
	                        break
	                    }
	                    case 1006:
	                    {
	                        t = uz(c[(c[j >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        c[(c[j >> 2] | 0) + 36 >> 2] = t;
	                        if ((c[(c[j >> 2] | 0) + 36 >> 2] | 0) == 0 ? (c[m >> 2] = 1756, (c[n >> 2] | 0) != 0) : 0) {
	                            AB(c[l >> 2] | 0, c[m >> 2] | 0, c[(c[j >> 2] | 0) + 20 >> 2] | 0, c[k >> 2] | 0, 140656, c[(c[j >> 2] | 0) + 8 >> 2] | 0, 0);
	                            r = 45
	                        } else r = 45;
	                        break
	                    }
	                    case 1008:
	                    {
	                        t = (qy(c[(c[j >> 2] | 0) + 8 >> 2] | 0, 140848) | 0) != 0;
	                        b = c[j >> 2] | 0;
	                        if (t) {
	                            c[b + 28 >> 2] = 1;
	                            r = 45;
	                            break a
	                        }
	                        t = (qy(c[b + 8 >> 2] | 0, 140864) | 0) != 0;
	                        b = c[j >> 2] | 0;
	                        if (t) {
	                            c[b + 28 >> 2] = 2;
	                            r = 45;
	                            break a
	                        }
	                        if (qy(c[b + 8 >> 2] | 0, 140872) | 0) {
	                            c[(c[j >> 2] | 0) + 28 >> 2] = 3;
	                            r = 45;
	                            break a
	                        }
	                        c[m >> 2] = 1717;
	                        if (c[n >> 2] | 0) {
	                            AB(c[l >> 2] | 0, c[m >> 2] | 0, c[(c[j >> 2] | 0) + 20 >> 2] | 0, c[k >> 2] | 0, 140888, c[(c[j >> 2] | 0) + 8 >> 2] | 0, 0);
	                            r = 45
	                        } else r = 45;
	                        break
	                    }
	                    default:
	                        r = 45
	                } while (0);
	                if ((r | 0) == 45) {
	                    if ((c[n >> 2] | 0) == 0 & (c[l >> 2] | 0) != 0)YA(c[l >> 2] | 0);
	                    c[h >> 2] = c[m >> 2];
	                    q = c[h >> 2] | 0;
	                    i = f;
	                    return q | 0
	                } else if ((r | 0) == 48) {
	                    if ((c[n >> 2] | 0) == 0 & (c[l >> 2] | 0) != 0)YA(c[l >> 2] | 0);
	                    c[h >> 2] = -1;
	                    q = c[h >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                return 0
	            }

	            function $A(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 16 | 0;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                g = b + 4 | 0;
	                h = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                c[g >> 2] = 0;
	                FH();
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    j = c[d >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                c[(c[e >> 2] | 0) + 20 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 16 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 40 >> 2] = 0;
	                c[f >> 2] = DB(c[e >> 2] | 0) | 0;
	                a:do if (c[f >> 2] | 0) {
	                    do if (!(c[(c[e >> 2] | 0) + 28 >> 2] | 0)) {
	                        a = EB(c[(c[e >> 2] | 0) + 80 >> 2] | 0) | 0;
	                        c[(c[e >> 2] | 0) + 28 >> 2] = a;
	                        if (c[(c[e >> 2] | 0) + 28 >> 2] | 0) {
	                            c[(c[e >> 2] | 0) + 32 >> 2] = 1;
	                            break
	                        }
	                        c[d >> 2] = 0;
	                        j = c[d >> 2] | 0;
	                        i = b;
	                        return j | 0
	                    } while (0);
	                    c[c[(c[e >> 2] | 0) + 28 >> 2] >> 2] = c[f >> 2];
	                    c[h >> 2] = FB(c[e >> 2] | 0, 0, c[(c[e >> 2] | 0) + 44 >> 2] | 0, c[(c[e >> 2] | 0) + 48 >> 2] | 0, c[(c[e >> 2] | 0) + 56 >> 2] | 0, c[(c[e >> 2] | 0) + 60 >> 2] | 0, 0, 0, 0, g) | 0;
	                    if ((c[h >> 2] | 0) != -1) {
	                        do if (!(c[h >> 2] | 0)) {
	                            a = c[e >> 2] | 0;
	                            if (!(c[g >> 2] | 0)) {
	                                k = c[e >> 2] | 0;
	                                if (c[a + 44 >> 2] | 0) {
	                                    AB(k, 1757, 0, 0, 140944, c[(c[e >> 2] | 0) + 44 >> 2] | 0, 0);
	                                    break
	                                } else {
	                                    AB(k, 1757, 0, 0, 141e3, 0, 0);
	                                    break
	                                }
	                            } else {
	                                if ((GB(a, c[f >> 2] | 0, c[g >> 2] | 0) | 0) == -1)break a;
	                                if (c[(c[e >> 2] | 0) + 20 >> 2] | 0)break;
	                                c[(c[f >> 2] | 0) + 16 >> 2] = c[(c[g >> 2] | 0) + 20 >> 2];
	                                c[(c[f >> 2] | 0) + 68 >> 2] = c[(c[e >> 2] | 0) + 52 >> 2];
	                                c[(c[e >> 2] | 0) + 36 >> 2] = c[f >> 2];
	                                if ((HB(c[e >> 2] | 0, c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + 4 >> 2] | 0) | 0) == -1)break a; else break
	                            }
	                        } while (0);
	                        if (c[(c[e >> 2] | 0) + 20 >> 2] | 0) {
	                            if (c[f >> 2] | 0) {
	                                WA(c[f >> 2] | 0);
	                                c[f >> 2] = 0
	                            }
	                            if (c[(c[e >> 2] | 0) + 28 >> 2] | 0) {
	                                sB(c[(c[e >> 2] | 0) + 28 >> 2] | 0);
	                                c[(c[e >> 2] | 0) + 28 >> 2] = 0;
	                                c[(c[e >> 2] | 0) + 32 >> 2] = 0
	                            }
	                        }
	                        c[(c[e >> 2] | 0) + 36 >> 2] = 0;
	                        c[d >> 2] = c[f >> 2];
	                        j = c[d >> 2] | 0;
	                        i = b;
	                        return j | 0
	                    }
	                } while (0);
	                if (c[f >> 2] | 0) {
	                    WA(c[f >> 2] | 0);
	                    c[f >> 2] = 0
	                }
	                if (c[(c[e >> 2] | 0) + 28 >> 2] | 0) {
	                    sB(c[(c[e >> 2] | 0) + 28 >> 2] | 0);
	                    c[(c[e >> 2] | 0) + 28 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 32 >> 2] = 0
	                }
	                xB(c[e >> 2] | 0, 141048, 141064);
	                c[(c[e >> 2] | 0) + 36 >> 2] = 0;
	                c[d >> 2] = 0;
	                j = c[d >> 2] | 0;
	                i = b;
	                return j | 0
	            }

	            function aB(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 12 | 0;
	                h = f + 8 | 0;
	                j = f + 4 | 0;
	                k = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                if (!(c[g >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                c[(c[g >> 2] | 0) + 8 >> 2] = c[h >> 2];
	                c[(c[g >> 2] | 0) + 12 >> 2] = c[j >> 2];
	                c[(c[g >> 2] | 0) + 4 >> 2] = c[k >> 2];
	                if (!(c[(c[g >> 2] | 0) + 92 >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                bB(c[(c[g >> 2] | 0) + 92 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0);
	                i = f;
	                return
	            }

	            function bB(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 12 | 0;
	                h = f + 8 | 0;
	                j = f + 4 | 0;
	                k = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                if (!(c[g >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                c[(c[g >> 2] | 0) + 8 >> 2] = c[h >> 2];
	                c[(c[g >> 2] | 0) + 12 >> 2] = c[j >> 2];
	                c[(c[g >> 2] | 0) + 4 >> 2] = c[k >> 2];
	                if (!(c[(c[g >> 2] | 0) + 88 >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                aB(c[(c[g >> 2] | 0) + 88 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0);
	                i = f;
	                return
	            }

	            function cB(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if (!(c[f >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                c[(c[f >> 2] | 0) + 24 >> 2] = c[g >> 2];
	                c[(c[f >> 2] | 0) + 4 >> 2] = c[h >> 2];
	                if (!(c[(c[f >> 2] | 0) + 92 >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                dB(c[(c[f >> 2] | 0) + 92 >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0);
	                i = e;
	                return
	            }

	            function dB(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if (!(c[f >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                c[(c[f >> 2] | 0) + 16 >> 2] = c[g >> 2];
	                c[(c[f >> 2] | 0) + 8 >> 2] = 0;
	                c[(c[f >> 2] | 0) + 12 >> 2] = 0;
	                c[(c[f >> 2] | 0) + 4 >> 2] = c[h >> 2];
	                if (!(c[(c[f >> 2] | 0) + 88 >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                cB(c[(c[f >> 2] | 0) + 88 >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0);
	                i = e;
	                return
	            }

	            function eB(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](204) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    IB(0, 141096, 0);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    cU(c[f >> 2] | 0, 0, 204) | 0;
	                    c[c[f >> 2] >> 2] = 2;
	                    a = xP() | 0;
	                    c[(c[f >> 2] | 0) + 156 >> 2] = a;
	                    a = JB() | 0;
	                    c[(c[f >> 2] | 0) + 180 >> 2] = a;
	                    c[(c[f >> 2] | 0) + 20 >> 2] = c[e >> 2];
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function fB(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if (c[(c[e >> 2] | 0) + 48 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[e >> 2] | 0) + 48 >> 2] | 0);
	                if (c[f >> 2] | 0) {
	                    b = my(c[f >> 2] | 0) | 0;
	                    c[(c[e >> 2] | 0) + 48 >> 2] = b;
	                    i = d;
	                    return
	                } else {
	                    c[(c[e >> 2] | 0) + 48 >> 2] = 0;
	                    i = d;
	                    return
	                }
	            }

	            function gB(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = -1;
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                } else {
	                    c[d >> 2] = (c[(c[e >> 2] | 0) + 52 >> 2] | 0) == 0 & 1;
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                }
	                return 0
	            }

	            function hB(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = -1;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                c[(c[f >> 2] | 0) + 24 >> 2] = c[g >> 2];
	                b = Pi(c[g >> 2] | 0) | 0;
	                c[(c[f >> 2] | 0) + 60 >> 2] = b;
	                b = c[f >> 2] | 0;
	                if (!(c[(c[f >> 2] | 0) + 60 >> 2] | 0)) {
	                    AB(b, 1872, c[g >> 2] | 0, 0, 141128, 0, 0);
	                    c[e >> 2] = c[(c[f >> 2] | 0) + 52 >> 2];
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                } else {
	                    c[(c[f >> 2] | 0) + 84 >> 2] = c[b + 60 >> 2];
	                    c[e >> 2] = KB(c[f >> 2] | 0) | 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                return 0
	            }

	            function iB(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                c[l >> 2] = c[c[h >> 2] >> 2];
	                if ((c[l >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 108 >> 2] | 0) != -554844497 : 0) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                do if (((c[l >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 116 >> 2] | 0) == 0 : 0) ? (c[(c[l >> 2] | 0) + 120 >> 2] | 0) == 0 : 0) {
	                    if ((c[(c[l >> 2] | 0) + 56 >> 2] | 0) == 0 ? (c[(c[l >> 2] | 0) + 60 >> 2] | 0) == 0 : 0)break;
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                } while (0);
	                c[k >> 2] = Cb[c[135744 >> 2] & 511](152) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                cU(c[k >> 2] | 0, 0, 152) | 0;
	                c[c[k >> 2] >> 2] = -599541215;
	                c[(c[k >> 2] | 0) + 128 >> 2] = -554844497;
	                c[(c[k >> 2] | 0) + 148 >> 2] = c[g >> 2];
	                c[(c[k >> 2] | 0) + 4 >> 2] = c[h >> 2];
	                c[(c[k >> 2] | 0) + 8 >> 2] = c[l >> 2];
	                if (!(c[l >> 2] | 0)) {
	                    c[(c[k >> 2] | 0) + 136 >> 2] = 323;
	                    c[(c[k >> 2] | 0) + 140 >> 2] = 324;
	                    c[(c[k >> 2] | 0) + 92 >> 2] = 325;
	                    c[(c[k >> 2] | 0) + 88 >> 2] = 325;
	                    c[(c[k >> 2] | 0) + 120 >> 2] = 326;
	                    c[(c[k >> 2] | 0) + 84 >> 2] = 327;
	                    c[(c[k >> 2] | 0) + 16 >> 2] = c[g >> 2];
	                    c[c[j >> 2] >> 2] = c[g >> 2]
	                } else {
	                    if (c[c[l >> 2] >> 2] | 0)c[(c[k >> 2] | 0) + 20 >> 2] = 328;
	                    if (c[(c[l >> 2] | 0) + 4 >> 2] | 0)c[(c[k >> 2] | 0) + 24 >> 2] = 329;
	                    if (c[(c[l >> 2] | 0) + 8 >> 2] | 0)c[(c[k >> 2] | 0) + 28 >> 2] = 330;
	                    if (c[(c[l >> 2] | 0) + 12 >> 2] | 0)c[(c[k >> 2] | 0) + 32 >> 2] = 331;
	                    if (c[(c[l >> 2] | 0) + 16 >> 2] | 0)c[(c[k >> 2] | 0) + 36 >> 2] = 332;
	                    if (c[(c[l >> 2] | 0) + 20 >> 2] | 0)c[(c[k >> 2] | 0) + 40 >> 2] = 333;
	                    if (c[(c[l >> 2] | 0) + 24 >> 2] | 0)c[(c[k >> 2] | 0) + 44 >> 2] = 334;
	                    if (c[(c[l >> 2] | 0) + 28 >> 2] | 0)c[(c[k >> 2] | 0) + 48 >> 2] = 335;
	                    if (c[(c[l >> 2] | 0) + 32 >> 2] | 0)c[(c[k >> 2] | 0) + 52 >> 2] = 336;
	                    if (c[(c[l >> 2] | 0) + 36 >> 2] | 0)c[(c[k >> 2] | 0) + 56 >> 2] = 337;
	                    if (c[(c[l >> 2] | 0) + 40 >> 2] | 0)c[(c[k >> 2] | 0) + 60 >> 2] = 338;
	                    if (c[(c[l >> 2] | 0) + 44 >> 2] | 0)c[(c[k >> 2] | 0) + 64 >> 2] = 339;
	                    if (c[(c[l >> 2] | 0) + 48 >> 2] | 0)c[(c[k >> 2] | 0) + 68 >> 2] = 340;
	                    if (c[(c[l >> 2] | 0) + 52 >> 2] | 0)c[(c[k >> 2] | 0) + 72 >> 2] = 341;
	                    if (c[(c[l >> 2] | 0) + 76 >> 2] | 0)c[(c[k >> 2] | 0) + 96 >> 2] = 342;
	                    if (c[(c[l >> 2] | 0) + 80 >> 2] | 0)c[(c[k >> 2] | 0) + 100 >> 2] = 343;
	                    if (c[(c[l >> 2] | 0) + 84 >> 2] | 0)c[(c[k >> 2] | 0) + 104 >> 2] = 344;
	                    if (c[(c[l >> 2] | 0) + 88 >> 2] | 0)c[(c[k >> 2] | 0) + 108 >> 2] = 345;
	                    if (c[(c[l >> 2] | 0) + 92 >> 2] | 0)c[(c[k >> 2] | 0) + 112 >> 2] = 346;
	                    if (c[(c[l >> 2] | 0) + 96 >> 2] | 0)c[(c[k >> 2] | 0) + 116 >> 2] = 347;
	                    if (c[(c[l >> 2] | 0) + 104 >> 2] | 0)c[(c[k >> 2] | 0) + 124 >> 2] = 348;
	                    c[(c[k >> 2] | 0) + 88 >> 2] = 349;
	                    do if (c[(c[l >> 2] | 0) + 72 >> 2] | 0) {
	                        if ((c[(c[l >> 2] | 0) + 72 >> 2] | 0) == (c[(c[l >> 2] | 0) + 68 >> 2] | 0)) {
	                            n = 61;
	                            break
	                        }
	                        c[(c[k >> 2] | 0) + 92 >> 2] = 350
	                    } else n = 61; while (0);
	                    if ((n | 0) == 61)c[(c[k >> 2] | 0) + 92 >> 2] = 349;
	                    c[(c[k >> 2] | 0) + 120 >> 2] = 351;
	                    c[(c[k >> 2] | 0) + 84 >> 2] = 352;
	                    c[(c[k >> 2] | 0) + 136 >> 2] = 353;
	                    c[(c[k >> 2] | 0) + 140 >> 2] = 354;
	                    c[(c[k >> 2] | 0) + 12 >> 2] = c[j >> 2];
	                    c[(c[k >> 2] | 0) + 16 >> 2] = c[c[j >> 2] >> 2];
	                    c[c[j >> 2] >> 2] = c[k >> 2]
	                }
	                c[c[h >> 2] >> 2] = (c[k >> 2] | 0) + 20;
	                c[(c[g >> 2] | 0) + 36 >> 2] = c[c[h >> 2] >> 2];
	                h = (c[g >> 2] | 0) + 152 | 0;
	                c[h >> 2] = c[h >> 2] | 1;
	                pC(c[g >> 2] | 0) | 0;
	                c[f >> 2] = c[k >> 2];
	                m = c[f >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function jB(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                if ((c[e >> 2] | 0) != 0 ? (c[c[e >> 2] >> 2] | 0) == -599541215 : 0) {
	                    c[c[e >> 2] >> 2] = 0;
	                    qC(c[(c[e >> 2] | 0) + 148 >> 2] | 0);
	                    c[f >> 2] = c[(c[e >> 2] | 0) + 4 >> 2];
	                    c[c[f >> 2] >> 2] = c[(c[e >> 2] | 0) + 8 >> 2];
	                    if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                        c[g >> 2] = c[(c[e >> 2] | 0) + 12 >> 2];
	                        c[c[g >> 2] >> 2] = c[(c[e >> 2] | 0) + 16 >> 2]
	                    }
	                    zb[c[135736 >> 2] & 511](c[e >> 2] | 0);
	                    c[d >> 2] = 0;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                c[d >> 2] = -1;
	                h = c[d >> 2] | 0;
	                i = b;
	                return h | 0
	            }

	            function kB(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if (!(c[f >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                c[(c[f >> 2] | 0) + 196 >> 2] = c[g >> 2];
	                c[(c[f >> 2] | 0) + 200 >> 2] = c[h >> 2];
	                i = e;
	                return
	            }

	            function lB(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                g = i;
	                i = i + 48 | 0;
	                h = g + 40 | 0;
	                j = g + 36 | 0;
	                k = g + 32 | 0;
	                l = g + 28 | 0;
	                m = g + 24 | 0;
	                n = g + 20 | 0;
	                o = g + 16 | 0;
	                p = g + 12 | 0;
	                q = g + 8 | 0;
	                r = g + 4 | 0;
	                s = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = 0;
	                c[p >> 2] = 0;
	                c[q >> 2] = 0;
	                c[r >> 2] = 0;
	                if ((c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0) {
	                    c[h >> 2] = -1;
	                    t = c[h >> 2] | 0;
	                    i = g;
	                    return t | 0
	                }
	                c[q >> 2] = Be() | 0;
	                if (!(c[q >> 2] | 0)) {
	                    c[h >> 2] = -1;
	                    t = c[h >> 2] | 0;
	                    i = g;
	                    return t | 0
	                }
	                c[p >> 2] = c[c[q >> 2] >> 2];
	                c[c[q >> 2] >> 2] = c[m >> 2];
	                c[(c[q >> 2] | 0) + 4 >> 2] = c[n >> 2];
	                c[(c[q >> 2] | 0) + 280 >> 2] = 1;
	                kB(c[j >> 2] | 0, 355, c[q >> 2] | 0);
	                c[r >> 2] = ve(c[q >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0;
	                do if (c[r >> 2] | 0) {
	                    Oe(c[q >> 2] | 0, c[r >> 2] | 0) | 0;
	                    c[(c[j >> 2] | 0) + 40 >> 2] = c[q >> 2];
	                    c[(c[j >> 2] | 0) + 28 >> 2] = c[k >> 2];
	                    c[o >> 2] = iB(c[j >> 2] | 0, c[q >> 2] | 0, (c[q >> 2] | 0) + 4 | 0) | 0;
	                    if (!(c[o >> 2] | 0)) {
	                        c[s >> 2] = -1;
	                        break
	                    }
	                    c[(c[j >> 2] | 0) + 28 >> 2] = c[k >> 2];
	                    c[(c[j >> 2] | 0) + 32 >> 2] = c[l >> 2];
	                    c[(c[j >> 2] | 0) + 36 >> 2] = c[c[q >> 2] >> 2];
	                    n = (c[j >> 2] | 0) + 152 | 0;
	                    c[n >> 2] = c[n >> 2] | 1;
	                    c[s >> 2] = KB(c[j >> 2] | 0) | 0;
	                    if ((c[s >> 2] | 0) == 0 ? (c[(c[(c[j >> 2] | 0) + 40 >> 2] | 0) + 12 >> 2] | 0) == 0 : 0) {
	                        n = c[(c[(c[j >> 2] | 0) + 40 >> 2] | 0) + 84 >> 2] | 0;
	                        c[s >> 2] = n;
	                        c[s >> 2] = (c[s >> 2] | 0) == 0 ? 1 : n
	                    }
	                } else c[s >> 2] = -1; while (0);
	                c[(c[j >> 2] | 0) + 40 >> 2] = 0;
	                c[(c[j >> 2] | 0) + 36 >> 2] = 0;
	                c[(c[j >> 2] | 0) + 28 >> 2] = 0;
	                if (c[o >> 2] | 0)jB(c[o >> 2] | 0) | 0;
	                if (c[q >> 2] | 0) {
	                    c[c[q >> 2] >> 2] = c[p >> 2];
	                    Ae(c[q >> 2] | 0)
	                }
	                c[h >> 2] = c[s >> 2];
	                t = c[h >> 2] | 0;
	                i = g;
	                return t | 0
	            }

	            function mB(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (!(c[c[d >> 2] >> 2] | 0)) {
	                    zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                    i = b;
	                    return
	                } else {
	                    do {
	                        c[e >> 2] = c[d >> 2];
	                        c[d >> 2] = c[c[d >> 2] >> 2];
	                        zb[c[135736 >> 2] & 511](c[e >> 2] | 0)
	                    } while ((c[d >> 2] | 0) != 0);
	                    i = b;
	                    return
	                }
	            }

	            function nB(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                while (1) {
	                    if (!(c[d >> 2] | 0))break;
	                    c[e >> 2] = c[c[d >> 2] >> 2];
	                    zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                    c[d >> 2] = c[e >> 2]
	                }
	                i = b;
	                return
	            }

	            function oB(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[c[d >> 2] >> 2] | 0)zb[c[135736 >> 2] & 511](c[c[d >> 2] >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function pB(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                while (1) {
	                    if (!(c[d >> 2] | 0))break;
	                    c[e >> 2] = c[c[d >> 2] >> 2];
	                    zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                    c[d >> 2] = c[e >> 2]
	                }
	                i = b;
	                return
	            }

	            function qB(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 44 >> 2] | 0) {
	                    sC(c[(c[d >> 2] | 0) + 44 >> 2] | 0);
	                    oB(c[(c[d >> 2] | 0) + 44 >> 2] | 0)
	                }
	                if (c[(c[d >> 2] | 0) + 48 >> 2] | 0) {
	                    sC(c[(c[d >> 2] | 0) + 48 >> 2] | 0);
	                    oB(c[(c[d >> 2] | 0) + 48 >> 2] | 0)
	                }
	                if (c[(c[d >> 2] | 0) + 24 >> 2] | 0) {
	                    c[f >> 2] = c[(c[d >> 2] | 0) + 24 >> 2];
	                    do {
	                        c[e >> 2] = c[f >> 2];
	                        c[f >> 2] = c[c[f >> 2] >> 2];
	                        zb[c[135736 >> 2] & 511](c[e >> 2] | 0)
	                    } while ((c[f >> 2] | 0) != 0)
	                }
	                if ((c[(c[d >> 2] | 0) + 40 >> 2] | 0) == 0 ? (c[(c[d >> 2] | 0) + 20 >> 2] | 0) != 0 : 0)Th(c[(c[d >> 2] | 0) + 20 >> 2] | 0);
	                if ((c[c[d >> 2] >> 2] | 0) == 1 ? (c[(c[d >> 2] | 0) + 52 >> 2] | 0) != 0 : 0)WA(c[(c[d >> 2] | 0) + 52 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function rB() {
	                var a = 0, b = 0, d = 0, e = 0, f = 0;
	                a = i;
	                i = i + 16 | 0;
	                b = a + 4 | 0;
	                d = a;
	                c[d >> 2] = Cb[c[135744 >> 2] & 511](132) | 0;
	                if (!(c[d >> 2] | 0)) {
	                    tC(0, 170240, 0);
	                    c[b >> 2] = 0;
	                    e = c[b >> 2] | 0;
	                    i = a;
	                    return e | 0
	                }
	                cU(c[d >> 2] | 0, 0, 132) | 0;
	                c[c[d >> 2] >> 2] = 1;
	                f = JB() | 0;
	                c[(c[d >> 2] | 0) + 128 >> 2] = f;
	                if (!(c[(c[d >> 2] | 0) + 128 >> 2] | 0)) {
	                    zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                    c[b >> 2] = 0;
	                    e = c[b >> 2] | 0;
	                    i = a;
	                    return e | 0
	                } else {
	                    c[b >> 2] = c[d >> 2];
	                    e = c[b >> 2] | 0;
	                    i = a;
	                    return e | 0
	                }
	                return 0
	            }

	            function sB(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (c[(c[d >> 2] | 0) + 12 >> 2] | 0)oB(c[(c[d >> 2] | 0) + 12 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 20 >> 2] | 0)oB(c[(c[d >> 2] | 0) + 20 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 24 >> 2] | 0)Kj(c[(c[d >> 2] | 0) + 24 >> 2] | 0, 356);
	                if (c[(c[d >> 2] | 0) + 28 >> 2] | 0)vC(c[(c[d >> 2] | 0) + 28 >> 2] | 0);
	                if (!(c[(c[d >> 2] | 0) + 8 >> 2] | 0)) {
	                    e = c[33934] | 0;
	                    f = c[d >> 2] | 0;
	                    zb[e & 511](f);
	                    i = b;
	                    return
	                }
	                zP(c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                e = c[33934] | 0;
	                f = c[d >> 2] | 0;
	                zb[e & 511](f);
	                i = b;
	                return
	            }

	            function tB(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (c[(c[d >> 2] | 0) + 4 >> 2] | 0)PH(c[(c[d >> 2] | 0) + 4 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function uB(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                while (1) {
	                    if (!(c[d >> 2] | 0))break;
	                    c[e >> 2] = c[(c[d >> 2] | 0) + 4 >> 2];
	                    if (c[(c[d >> 2] | 0) + 12 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 12 >> 2] | 0);
	                    if (c[(c[d >> 2] | 0) + 32 >> 2] | 0)GQ(c[(c[d >> 2] | 0) + 32 >> 2] | 0);
	                    zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                    c[d >> 2] = c[e >> 2]
	                }
	                i = b;
	                return
	            }

	            function vB(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[d >> 2] = a;
	                if (!(c[(c[d >> 2] | 0) + 168 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                c[e >> 2] = 0;
	                while (1) {
	                    if ((c[e >> 2] | 0) >= (c[(c[d >> 2] | 0) + 168 >> 2] | 0))break;
	                    c[f >> 2] = c[(c[(c[d >> 2] | 0) + 164 >> 2] | 0) + (c[e >> 2] << 2) >> 2];
	                    if (c[(c[f >> 2] | 0) + 32 >> 2] & 1) {
	                        if (c[(c[f >> 2] | 0) + 12 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 12 >> 2] | 0);
	                        if (c[(c[f >> 2] | 0) + 16 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 16 >> 2] | 0)
	                    }
	                    if ((c[(c[f >> 2] | 0) + 32 >> 2] & 2 | 0) != 0 ? (c[(c[f >> 2] | 0) + 20 >> 2] | 0) != 0 : 0)zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 20 >> 2] | 0);
	                    if (c[(c[f >> 2] | 0) + 24 >> 2] | 0) {
	                        PH(c[(c[f >> 2] | 0) + 24 >> 2] | 0);
	                        c[(c[f >> 2] | 0) + 24 >> 2] = 0
	                    }
	                    a = (c[f >> 2] | 0) + 0 | 0;
	                    g = a + 60 | 0;
	                    do {
	                        c[a >> 2] = 0;
	                        a = a + 4 | 0
	                    } while ((a | 0) < (g | 0));
	                    c[e >> 2] = (c[e >> 2] | 0) + 1
	                }
	                c[(c[d >> 2] | 0) + 168 >> 2] = 0;
	                i = b;
	                return
	            }

	            function wB(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[(c[f >> 2] | 0) + 76 >> 2] = 0;
	                c[(c[f >> 2] | 0) + 80 >> 2] = 0;
	                b = (c[f >> 2] | 0) + 12 | 0;
	                if (c[(c[f >> 2] | 0) + 32 >> 2] & 1) {
	                    if (c[b >> 2] | 0) {
	                        zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 12 >> 2] | 0);
	                        c[(c[f >> 2] | 0) + 12 >> 2] = 0
	                    }
	                    if (c[(c[f >> 2] | 0) + 16 >> 2] | 0) {
	                        zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 16 >> 2] | 0);
	                        c[(c[f >> 2] | 0) + 16 >> 2] = 0
	                    }
	                } else {
	                    c[b >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 16 >> 2] = 0
	                }
	                b = (c[f >> 2] | 0) + 20 | 0;
	                if (c[(c[f >> 2] | 0) + 32 >> 2] & 2) {
	                    if (c[b >> 2] | 0) {
	                        zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 20 >> 2] | 0);
	                        c[(c[f >> 2] | 0) + 20 >> 2] = 0
	                    }
	                } else c[b >> 2] = 0;
	                if (c[(c[f >> 2] | 0) + 24 >> 2] | 0) {
	                    PH(c[(c[f >> 2] | 0) + 24 >> 2] | 0);
	                    c[(c[f >> 2] | 0) + 24 >> 2] = 0
	                }
	                if (c[(c[f >> 2] | 0) + 56 >> 2] | 0) {
	                    wC(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 56 >> 2] | 0);
	                    c[(c[f >> 2] | 0) + 56 >> 2] = 0
	                }
	                if (c[(c[f >> 2] | 0) + 52 >> 2] | 0) {
	                    xC(c[(c[f >> 2] | 0) + 52 >> 2] | 0);
	                    c[(c[f >> 2] | 0) + 52 >> 2] = 0
	                }
	                if (c[(c[f >> 2] | 0) + 60 >> 2] | 0) {
	                    pz(c[(c[f >> 2] | 0) + 60 >> 2] | 0);
	                    c[(c[f >> 2] | 0) + 60 >> 2] = 0
	                }
	                if (!(c[(c[f >> 2] | 0) + 64 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 64 >> 2] | 0);
	                c[(c[f >> 2] | 0) + 64 >> 2] = 0;
	                c[(c[f >> 2] | 0) + 68 >> 2] = 0;
	                c[(c[f >> 2] | 0) + 72 >> 2] = 0;
	                i = d;
	                return
	            }

	            function xB(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                yC(c[f >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0, 0, 0);
	                i = e;
	                return
	            }

	            function yB(a, b, e, f, g, h, j, k) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                k = k | 0;
	                var l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0, J = 0, K = 0, L = 0, M = 0, N = 0, O = 0, P = 0, Q = 0;
	                l = i;
	                i = i + 96 | 0;
	                m = l;
	                n = l + 92 | 0;
	                o = l + 88 | 0;
	                p = l + 84 | 0;
	                q = l + 80 | 0;
	                r = l + 76 | 0;
	                s = l + 72 | 0;
	                t = l + 68 | 0;
	                u = l + 64 | 0;
	                v = l + 60 | 0;
	                w = l + 56 | 0;
	                x = l + 52 | 0;
	                y = l + 48 | 0;
	                z = l + 44 | 0;
	                A = l + 40 | 0;
	                B = l + 36 | 0;
	                C = l + 32 | 0;
	                D = l + 28 | 0;
	                E = l + 24 | 0;
	                F = l + 20 | 0;
	                G = l + 16 | 0;
	                H = l + 12 | 0;
	                I = l + 8 | 0;
	                c[o >> 2] = a;
	                c[p >> 2] = b;
	                c[q >> 2] = e;
	                c[r >> 2] = f;
	                c[s >> 2] = g;
	                c[t >> 2] = h;
	                c[u >> 2] = j;
	                c[v >> 2] = k;
	                c[w >> 2] = 0;
	                c[x >> 2] = (c[s >> 2] | 0) != 0 ? 1 : 0;
	                c[y >> 2] = 0;
	                c[z >> 2] = 0;
	                if ((c[s >> 2] | 0) != 0 ? (c[c[s >> 2] >> 2] | 0) != 0 : 0) {
	                    PH(c[c[s >> 2] >> 2] | 0);
	                    c[c[s >> 2] >> 2] = 0
	                }
	                if ((c[x >> 2] | 0) == 0 ? (c[(c[q >> 2] | 0) + 48 >> 2] & 2097152 | 0) != 0 : 0)c[x >> 2] = 1;
	                if (!(c[r >> 2] | 0))c[r >> 2] = 142672;
	                if ((c[c[q >> 2] >> 2] | 0) == 1 ? (c[(c[q >> 2] | 0) + 88 >> 2] | 0) == 46 : 0)J = 12; else J = 11;
	                a:do if ((J | 0) == 11)if (!(c[(c[q >> 2] | 0) + 48 >> 2] & 256)) {
	                    if (!(c[(c[q >> 2] | 0) + 48 >> 2] & 64)) {
	                        if (!(c[(c[q >> 2] | 0) + 48 >> 2] & 128))break;
	                        c[I >> 2] = EC(c[q >> 2] | 0) | 0;
	                        if (!(c[I >> 2] | 0)) {
	                            xB(c[o >> 2] | 0, 156240, 156464);
	                            J = 149;
	                            break
	                        }
	                        while (1) {
	                            if (!(c[I >> 2] | 0))break;
	                            k = c[o >> 2] | 0;
	                            j = c[p >> 2] | 0;
	                            h = c[(c[I >> 2] | 0) + 4 >> 2] | 0;
	                            g = c[r >> 2] | 0;
	                            if (c[x >> 2] | 0)c[w >> 2] = yB(k, j, h, g, y, 0, 1, 0) | 0; else c[w >> 2] = yB(k, j, h, g, 0, 0, 1, 0) | 0;
	                            if ((c[w >> 2] | 0) <= 0)break;
	                            c[I >> 2] = c[c[I >> 2] >> 2]
	                        }
	                        do if (c[w >> 2] | 0)if ((c[w >> 2] | 0) < 0) {
	                            xB(c[o >> 2] | 0, 156240, 156504);
	                            J = 149;
	                            break a
	                        } else {
	                            c[w >> 2] = 1826;
	                            break
	                        } while (0);
	                        do if ((c[w >> 2] | 0) == 0 ? (c[(c[q >> 2] | 0) + 48 >> 2] & 134217728 | 0) != 0 : 0) {
	                            do if (!(c[v >> 2] | 0)) {
	                                if ((c[u >> 2] | 0) == 0 ? (c[(c[q >> 2] | 0) + 48 >> 2] & 268435456 | 0) == 0 : 0)break;
	                                c[z >> 2] = zC(c[(c[I >> 2] | 0) + 4 >> 2] | 0, c[r >> 2] | 0) | 0;
	                                if (c[z >> 2] | 0)c[r >> 2] = c[z >> 2];
	                                c[v >> 2] = 1
	                            } while (0);
	                            c[w >> 2] = CC(c[o >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0, 0, c[r >> 2] | 0, c[y >> 2] | 0, 0, c[t >> 2] | 0) | 0;
	                            if (c[w >> 2] | 0)if ((c[w >> 2] | 0) < 0) {
	                                xB(c[o >> 2] | 0, 156240, 156544);
	                                J = 149;
	                                break a
	                            } else {
	                                c[w >> 2] = 1826;
	                                break
	                            }
	                        } while (0);
	                        if (!((c[t >> 2] | 0) != 0 & (c[w >> 2] | 0) > 0))break;
	                        DC(c[o >> 2] | 0, c[w >> 2] | 0, c[p >> 2] | 0, c[r >> 2] | 0, c[q >> 2] | 0, 1);
	                        break
	                    }
	                    c[E >> 2] = 0;
	                    c[F >> 2] = 0;
	                    c[G >> 2] = 0;
	                    c[H >> 2] = 0;
	                    do if (!(c[v >> 2] | 0)) {
	                        if ((c[u >> 2] | 0) == 0 ? (c[(c[q >> 2] | 0) + 48 >> 2] & 268435456 | 0) == 0 : 0)break;
	                        c[z >> 2] = zC(c[q >> 2] | 0, c[r >> 2] | 0) | 0;
	                        if (c[z >> 2] | 0)c[r >> 2] = c[z >> 2];
	                        c[v >> 2] = 1
	                    } while (0);
	                    c[B >> 2] = c[(c[q >> 2] | 0) + 28 >> 2];
	                    c[C >> 2] = c[r >> 2];
	                    while (1) {
	                        do if ((d[c[C >> 2] >> 0] | 0 | 0) == 32)K = 1; else {
	                            if (9 <= (d[c[C >> 2] >> 0] | 0 | 0) ? (d[c[C >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                K = 1;
	                                break
	                            }
	                            K = (d[c[C >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        g = c[C >> 2] | 0;
	                        if (K) {
	                            c[C >> 2] = g + 1;
	                            continue
	                        }
	                        c[D >> 2] = g;
	                        while (1) {
	                            if (d[c[D >> 2] >> 0] | 0) {
	                                do if ((d[c[D >> 2] >> 0] | 0 | 0) == 32)L = 1; else {
	                                    if (9 <= (d[c[D >> 2] >> 0] | 0 | 0) ? (d[c[D >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                        L = 1;
	                                        break
	                                    }
	                                    L = (d[c[D >> 2] >> 0] | 0 | 0) == 13
	                                } while (0);
	                                M = L ^ 1
	                            } else M = 0;
	                            N = c[D >> 2] | 0;
	                            if (!M)break;
	                            c[D >> 2] = N + 1
	                        }
	                        if ((N | 0) == (c[C >> 2] | 0))break;
	                        c[E >> 2] = ly(c[C >> 2] | 0, (c[D >> 2] | 0) - (c[C >> 2] | 0) | 0) | 0;
	                        c[F >> 2] = (c[F >> 2] | 0) + 1;
	                        g = c[o >> 2] | 0;
	                        h = c[p >> 2] | 0;
	                        j = c[B >> 2] | 0;
	                        k = c[E >> 2] | 0;
	                        f = c[t >> 2] | 0;
	                        if (c[x >> 2] | 0)c[w >> 2] = yB(g, h, j, k, H, f, 0, 1) | 0; else c[w >> 2] = yB(g, h, j, k, 0, f, 0, 1) | 0;
	                        if (c[E >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[E >> 2] | 0);
	                            c[E >> 2] = 0
	                        }
	                        if (c[H >> 2] | 0) {
	                            if (!(c[y >> 2] | 0))c[y >> 2] = c[H >> 2]; else JH(c[G >> 2] | 0, c[H >> 2] | 0) | 0;
	                            c[G >> 2] = c[H >> 2];
	                            c[H >> 2] = 0
	                        }
	                        if (c[w >> 2] | 0) {
	                            J = 92;
	                            break
	                        }
	                        c[C >> 2] = c[D >> 2];
	                        if (!(d[c[C >> 2] >> 0] | 0))break
	                    }
	                    do if ((J | 0) == 92)if ((c[w >> 2] | 0) < 0) {
	                        xB(c[o >> 2] | 0, 156240, 156384);
	                        J = 149;
	                        break a
	                    } else {
	                        c[w >> 2] = 1825;
	                        break
	                    } while (0);
	                    if (c[E >> 2] | 0) {
	                        zb[c[135736 >> 2] & 511](c[E >> 2] | 0);
	                        c[E >> 2] = 0
	                    }
	                    do if (((c[w >> 2] | 0) == 0 ? (c[(c[q >> 2] | 0) + 48 >> 2] & 134217728 | 0) != 0 : 0) ? (c[w >> 2] = CC(c[o >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0, 0, c[r >> 2] | 0, c[y >> 2] | 0, c[F >> 2] | 0, c[t >> 2] | 0) | 0, (c[w >> 2] | 0) != 0) : 0)if ((c[w >> 2] | 0) < 0) {
	                        xB(c[o >> 2] | 0, 156240, 156424);
	                        J = 149;
	                        break a
	                    } else {
	                        c[w >> 2] = 1825;
	                        break
	                    } while (0);
	                    if ((c[t >> 2] | 0) != 0 & (c[w >> 2] | 0) > 0) {
	                        c[u >> 2] = 1;
	                        do if (!(c[v >> 2] | 0)) {
	                            if ((c[u >> 2] | 0) == 0 ? (c[(c[q >> 2] | 0) + 48 >> 2] & 268435456 | 0) == 0 : 0)break;
	                            c[z >> 2] = zC(c[q >> 2] | 0, c[r >> 2] | 0) | 0;
	                            if (c[z >> 2] | 0)c[r >> 2] = c[z >> 2];
	                            c[v >> 2] = 1
	                        } while (0);
	                        DC(c[o >> 2] | 0, c[w >> 2] | 0, c[p >> 2] | 0, c[r >> 2] | 0, c[q >> 2] | 0, 1)
	                    }
	                } else J = 12; while (0);
	                b:do if ((J | 0) == 12) {
	                    do if (!(c[v >> 2] | 0)) {
	                        if ((c[u >> 2] | 0) == 0 ? (c[(c[q >> 2] | 0) + 48 >> 2] & 268435456 | 0) == 0 : 0)break;
	                        c[z >> 2] = zC(c[q >> 2] | 0, c[r >> 2] | 0) | 0;
	                        if (c[z >> 2] | 0)c[r >> 2] = c[z >> 2];
	                        c[v >> 2] = 1
	                    } while (0);
	                    F = c[q >> 2] | 0;
	                    if ((c[c[q >> 2] >> 2] | 0) != 1) {
	                        c[A >> 2] = c[F + 64 >> 2];
	                        while (1) {
	                            if (c[A >> 2] | 0)O = (c[c[A >> 2] >> 2] | 0) != 1; else O = 0;
	                            P = c[A >> 2] | 0;
	                            if (!O)break;
	                            c[A >> 2] = c[P + 64 >> 2]
	                        }
	                        if (!P) {
	                            xB(c[o >> 2] | 0, 156240, 156272);
	                            J = 149;
	                            break
	                        }
	                    } else c[A >> 2] = F;
	                    do if ((c[c[o >> 2] >> 2] | 0) == 2) {
	                        E = c[(c[A >> 2] | 0) + 88 >> 2] | 0;
	                        if ((E | 0) == 21) {
	                            c[w >> 2] = BC(c[o >> 2] | 0, c[r >> 2] | 0, y, c[x >> 2] | 0) | 0;
	                            break
	                        } else if ((E | 0) != 28) {
	                            E = c[A >> 2] | 0;
	                            C = c[r >> 2] | 0;
	                            D = c[p >> 2] | 0;
	                            if (c[x >> 2] | 0) {
	                                c[w >> 2] = UH(E, C, y, D) | 0;
	                                break
	                            } else {
	                                c[w >> 2] = UH(E, C, 0, D) | 0;
	                                break
	                            }
	                        } else {
	                            c[w >> 2] = AC(c[o >> 2] | 0, c[(c[o >> 2] | 0) + 20 >> 2] | 0, 0, c[r >> 2] | 0, y, c[x >> 2] | 0) | 0;
	                            break
	                        }
	                    } else {
	                        if ((c[c[o >> 2] >> 2] | 0) != 1) {
	                            D = c[33976] | 0;
	                            C = c[33980] | 0;
	                            c[m >> 2] = 140328;
	                            c[m + 4 >> 2] = 24593;
	                            Db[D & 511](C, 140296, m);
	                            J = 149;
	                            break b
	                        }
	                        if ((c[(c[A >> 2] | 0) + 88 >> 2] | 0) == 28) {
	                            c[w >> 2] = AC(0, c[(c[o >> 2] | 0) + 36 >> 2] | 0, c[p >> 2] | 0, c[r >> 2] | 0, y, c[x >> 2] | 0) | 0;
	                            break
	                        }
	                        C = c[A >> 2] | 0;
	                        D = c[r >> 2] | 0;
	                        E = c[p >> 2] | 0;
	                        if (c[x >> 2] | 0) {
	                            c[w >> 2] = UH(C, D, y, E) | 0;
	                            break
	                        } else {
	                            c[w >> 2] = UH(C, D, 0, E) | 0;
	                            break
	                        }
	                    } while (0);
	                    do if (c[w >> 2] | 0) {
	                        if ((c[w >> 2] | 0) < 0) {
	                            xB(c[o >> 2] | 0, 156240, 156304);
	                            J = 149;
	                            break b
	                        }
	                        if (c[(c[q >> 2] | 0) + 48 >> 2] & 64) {
	                            c[w >> 2] = 1825;
	                            break
	                        } else {
	                            c[w >> 2] = 1824;
	                            break
	                        }
	                    } while (0);
	                    do if (((c[w >> 2] | 0) == 0 ? (c[(c[q >> 2] | 0) + 48 >> 2] & 134217728 | 0) != 0 : 0) ? (c[w >> 2] = CC(c[o >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0, c[(c[A >> 2] | 0) + 88 >> 2] | 0, c[r >> 2] | 0, c[y >> 2] | 0, 0, c[t >> 2] | 0) | 0, (c[w >> 2] | 0) != 0) : 0) {
	                        if ((c[w >> 2] | 0) < 0) {
	                            xB(c[o >> 2] | 0, 156240, 156344);
	                            J = 149;
	                            break b
	                        }
	                        if (c[(c[q >> 2] | 0) + 48 >> 2] & 64) {
	                            c[w >> 2] = 1825;
	                            break
	                        } else {
	                            c[w >> 2] = 1824;
	                            break
	                        }
	                    } while (0);
	                    if ((c[t >> 2] | 0) != 0 & (c[w >> 2] | 0) > 0)DC(c[o >> 2] | 0, c[w >> 2] | 0, c[p >> 2] | 0, c[r >> 2] | 0, c[q >> 2] | 0, 1)
	                } while (0);
	                if ((J | 0) == 149) {
	                    if (c[z >> 2] | 0)zb[c[135736 >> 2] & 511](c[z >> 2] | 0);
	                    if (c[y >> 2] | 0)PH(c[y >> 2] | 0);
	                    c[n >> 2] = -1;
	                    Q = c[n >> 2] | 0;
	                    i = l;
	                    return Q | 0
	                }
	                if (c[z >> 2] | 0)zb[c[135736 >> 2] & 511](c[z >> 2] | 0);
	                do if (!(c[w >> 2] | 0)) {
	                    z = c[y >> 2] | 0;
	                    if (c[s >> 2] | 0) {
	                        c[c[s >> 2] >> 2] = z;
	                        break
	                    }
	                    if (z)PH(c[y >> 2] | 0)
	                } else if (c[y >> 2] | 0)PH(c[y >> 2] | 0); while (0);
	                c[n >> 2] = c[w >> 2];
	                Q = c[n >> 2] | 0;
	                i = l;
	                return Q | 0
	            }

	            function zB(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                do switch (c[e >> 2] | 0) {
	                    case 1e3:
	                    {
	                        c[d >> 2] = 157848;
	                        break
	                    }
	                    case 1010:
	                    {
	                        c[d >> 2] = 157904;
	                        break
	                    }
	                    case 1002:
	                    {
	                        c[d >> 2] = 157816;
	                        break
	                    }
	                    case 1001:
	                    {
	                        c[d >> 2] = 157832;
	                        break
	                    }
	                    case 1003:
	                    {
	                        c[d >> 2] = 157800;
	                        break
	                    }
	                    case 1004:
	                    {
	                        c[d >> 2] = 157936;
	                        break
	                    }
	                    case 1009:
	                    {
	                        c[d >> 2] = 157896;
	                        break
	                    }
	                    case 1005:
	                    {
	                        c[d >> 2] = 157952;
	                        break
	                    }
	                    case 1007:
	                    {
	                        c[d >> 2] = 157880;
	                        break
	                    }
	                    case 1006:
	                    {
	                        c[d >> 2] = 157792;
	                        break
	                    }
	                    case 1011:
	                    {
	                        c[d >> 2] = 157920;
	                        break
	                    }
	                    case 1008:
	                    {
	                        c[d >> 2] = 157864;
	                        break
	                    }
	                    default:
	                        c[d >> 2] = 157968
	                } while (0);
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function AB(a, b, d, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                j = i;
	                i = i + 32 | 0;
	                k = j + 24 | 0;
	                l = j + 20 | 0;
	                m = j + 16 | 0;
	                n = j + 12 | 0;
	                o = j + 8 | 0;
	                p = j + 4 | 0;
	                q = j;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                c[q >> 2] = h;
	                CB(c[k >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0, 0, 0);
	                i = j;
	                return
	            }

	            function BB(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (c[c[g >> 2] >> 2] | 0) {
	                    zb[c[135736 >> 2] & 511](c[c[g >> 2] >> 2] | 0);
	                    c[c[g >> 2] >> 2] = 0
	                }
	                if (c[h >> 2] | 0) {
	                    d = my(144432) | 0;
	                    c[c[g >> 2] >> 2] = d;
	                    d = By(c[c[g >> 2] >> 2] | 0, c[h >> 2] | 0) | 0;
	                    c[c[g >> 2] >> 2] = d;
	                    d = By(c[c[g >> 2] >> 2] | 0, 144440) | 0;
	                    c[c[g >> 2] >> 2] = d
	                }
	                do if (c[j >> 2] | 0) {
	                    if (c[h >> 2] | 0) {
	                        d = By(c[c[g >> 2] >> 2] | 0, c[j >> 2] | 0) | 0;
	                        c[c[g >> 2] >> 2] = d;
	                        break
	                    }
	                    c[f >> 2] = c[j >> 2];
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                } else {
	                    d = By(c[c[g >> 2] >> 2] | 0, 170232) | 0;
	                    c[c[g >> 2] >> 2] = d
	                } while (0);
	                c[f >> 2] = c[c[g >> 2] >> 2];
	                k = c[f >> 2] | 0;
	                i = e;
	                return k | 0
	            }

	            function CB(a, b, d, e, f, g, h, j, k) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                k = k | 0;
	                var l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                l = i;
	                i = i + 48 | 0;
	                m = l + 36 | 0;
	                n = l + 32 | 0;
	                o = l + 28 | 0;
	                p = l + 24 | 0;
	                q = l + 20 | 0;
	                r = l + 16 | 0;
	                s = l + 12 | 0;
	                t = l + 8 | 0;
	                u = l + 4 | 0;
	                v = l;
	                c[m >> 2] = a;
	                c[n >> 2] = b;
	                c[o >> 2] = d;
	                c[p >> 2] = e;
	                c[q >> 2] = f;
	                c[r >> 2] = g;
	                c[s >> 2] = h;
	                c[t >> 2] = j;
	                c[u >> 2] = k;
	                c[v >> 2] = 0;
	                if ((c[o >> 2] | 0) == 0 & (c[p >> 2] | 0) != 0 ? (c[c[m >> 2] >> 2] | 0) == 1 : 0) {
	                    c[o >> 2] = FC(c[p >> 2] | 0) | 0;
	                    GC(v, 0, c[p >> 2] | 0, 0) | 0;
	                    c[v >> 2] = By(c[v >> 2] | 0, 152080) | 0
	                } else HC(v, c[m >> 2] | 0, c[o >> 2] | 0) | 0;
	                c[v >> 2] = By(c[v >> 2] | 0, c[q >> 2] | 0) | 0;
	                c[v >> 2] = By(c[v >> 2] | 0, 142704) | 0;
	                IC(c[m >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, c[v >> 2] | 0, c[r >> 2] | 0, c[s >> 2] | 0, c[t >> 2] | 0, c[u >> 2] | 0);
	                if (!(c[v >> 2] | 0)) {
	                    i = l;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[v >> 2] | 0);
	                c[v >> 2] = 0;
	                i = l;
	                return
	            }

	            function DB(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](84) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    tC(c[e >> 2] | 0, 170208, 0);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    a = (c[f >> 2] | 0) + 0 | 0;
	                    h = a + 84 | 0;
	                    do {
	                        c[a >> 2] = 0;
	                        a = a + 4 | 0
	                    } while ((a | 0) < (h | 0));
	                    c[(c[f >> 2] | 0) + 60 >> 2] = c[(c[e >> 2] | 0) + 80 >> 2];
	                    yP(c[(c[f >> 2] | 0) + 60 >> 2] | 0) | 0;
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function EB(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](36) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    tC(0, 170080, 0);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = (c[f >> 2] | 0) + 0 | 0;
	                h = a + 36 | 0;
	                do {
	                    c[a >> 2] = 0;
	                    a = a + 4 | 0
	                } while ((a | 0) < (h | 0));
	                a = JB() | 0;
	                c[(c[f >> 2] | 0) + 12 >> 2] = a;
	                if (!(c[(c[f >> 2] | 0) + 12 >> 2] | 0)) {
	                    tC(0, 170120, 0);
	                    zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = JB() | 0;
	                c[(c[f >> 2] | 0) + 20 >> 2] = a;
	                if (!(c[(c[f >> 2] | 0) + 20 >> 2] | 0)) {
	                    tC(0, 170160, 0);
	                    sB(c[f >> 2] | 0);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    c[(c[f >> 2] | 0) + 8 >> 2] = c[e >> 2];
	                    yP(c[e >> 2] | 0) | 0;
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function FB(a, b, d, e, f, g, h, j, k, l) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                k = k | 0;
	                l = l | 0;
	                var m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0, J = 0, K = 0, L = 0;
	                m = i;
	                i = i + 96 | 0;
	                n = m + 88 | 0;
	                o = m + 84 | 0;
	                p = m + 80 | 0;
	                q = m + 76 | 0;
	                r = m + 72 | 0;
	                s = m + 68 | 0;
	                t = m + 64 | 0;
	                u = m + 60 | 0;
	                v = m + 56 | 0;
	                w = m + 52 | 0;
	                x = m + 48 | 0;
	                y = m + 44 | 0;
	                z = m + 40 | 0;
	                A = m + 36 | 0;
	                B = m + 32 | 0;
	                C = m + 28 | 0;
	                D = m + 24 | 0;
	                E = m + 20 | 0;
	                F = m + 16 | 0;
	                G = m + 12 | 0;
	                H = m + 8 | 0;
	                I = m + 4 | 0;
	                J = m;
	                c[o >> 2] = a;
	                c[p >> 2] = b;
	                c[q >> 2] = d;
	                c[r >> 2] = e;
	                c[s >> 2] = f;
	                c[t >> 2] = g;
	                c[u >> 2] = h;
	                c[v >> 2] = j;
	                c[w >> 2] = k;
	                c[x >> 2] = l;
	                c[y >> 2] = 0;
	                c[z >> 2] = 0;
	                c[A >> 2] = 0;
	                c[B >> 2] = 0;
	                c[C >> 2] = 0;
	                c[D >> 2] = 0;
	                c[E >> 2] = 0;
	                c[F >> 2] = 0;
	                if (c[x >> 2] | 0)c[c[x >> 2] >> 2] = 0;
	                l = c[p >> 2] | 0;
	                if ((l | 0) == 2)c[C >> 2] = 3050; else if ((l | 0) == 3)c[C >> 2] = 3081; else if ((l | 0) == 0 | (l | 0) == 1)c[C >> 2] = 3082;
	                a:do if (((c[p >> 2] | 0) != 0 ? (c[(c[(c[o >> 2] | 0) + 28 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[(c[(c[(c[o >> 2] | 0) + 28 >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) > 0 : 0) {
	                    if (((c[q >> 2] | 0) != 0 ? (c[F >> 2] = JC(c[o >> 2] | 0, c[q >> 2] | 0) | 0, (c[F >> 2] | 0) != 0) : 0) ? (c[(c[(c[o >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] | 0) == (c[F >> 2] | 0) : 0) {
	                        AB(c[o >> 2] | 0, c[C >> 2] | 0, c[u >> 2] | 0, 0, 169048, 0, 0);
	                        K = 92;
	                        break
	                    }
	                    c[z >> 2] = KC() | 0;
	                    if (!(c[z >> 2] | 0)) {
	                        c[n >> 2] = -1;
	                        L = c[n >> 2] | 0;
	                        i = m;
	                        return L | 0
	                    }
	                    LC(c[(c[(c[o >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] | 0, c[z >> 2] | 0);
	                    c[(c[z >> 2] | 0) + 4 >> 2] = c[p >> 2];
	                    if ((c[p >> 2] | 0) == 0 | (c[p >> 2] | 0) == 1) {
	                        c[(c[z >> 2] | 0) + 8 >> 2] = c[w >> 2];
	                        if (!(c[q >> 2] | 0)) {
	                            K = 92;
	                            break
	                        }
	                        c[y >> 2] = c[w >> 2]
	                    }
	                    do if (c[F >> 2] | 0) {
	                        if ((c[p >> 2] | 0) == 0 | (c[p >> 2] | 0) == 1 ? (c[(c[F >> 2] | 0) + 36 >> 2] | 0) == 0 : 0) {
	                            if (!(c[q >> 2] | 0))c[q >> 2] = 169104;
	                            if (qy(c[q >> 2] | 0, c[(c[F >> 2] | 0) + 8 >> 2] | 0) | 0)break;
	                            AB(c[o >> 2] | 0, c[C >> 2] | 0, c[u >> 2] | 0, 0, 169128, c[q >> 2] | 0, 0);
	                            K = 92;
	                            break a
	                        }
	                        if (!((c[p >> 2] | 0) == 0 | (c[p >> 2] | 0) == 1) ? (c[(c[F >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) {
	                            if (!(c[q >> 2] | 0))c[q >> 2] = 169104;
	                            if (!(qy(c[q >> 2] | 0, c[(c[F >> 2] | 0) + 8 >> 2] | 0) | 0)) {
	                                AB(c[o >> 2] | 0, c[C >> 2] | 0, c[u >> 2] | 0, 0, 169216, c[q >> 2] | 0, 0);
	                                K = 92;
	                                break a
	                            }
	                        }
	                    } while (0);
	                    l = (c[F >> 2] | 0) != 0;
	                    do if ((c[p >> 2] | 0) == 0 | (c[p >> 2] | 0) == 1) {
	                        if (l) {
	                            c[(c[z >> 2] | 0) + 12 >> 2] = c[F >> 2];
	                            K = 92;
	                            break a
	                        }
	                        c[F >> 2] = MC(c[o >> 2] | 0, c[w >> 2] | 0, 1) | 0;
	                        if (c[F >> 2] | 0) {
	                            c[(c[z >> 2] | 0) + 12 >> 2] = c[F >> 2];
	                            k = c[q >> 2] | 0;
	                            j = (c[F >> 2] | 0) + 8 | 0;
	                            if (!(c[(c[F >> 2] | 0) + 8 >> 2] | 0)) {
	                                c[j >> 2] = k;
	                                break
	                            }
	                            if (qy(k, c[j >> 2] | 0) | 0) {
	                                K = 92;
	                                break a
	                            }
	                            if (!(c[q >> 2] | 0))c[q >> 2] = 169104;
	                            NC(c[o >> 2] | 0, 3083, c[u >> 2] | 0, 0, 169304, c[q >> 2] | 0, c[w >> 2] | 0, c[(c[F >> 2] | 0) + 8 >> 2] | 0);
	                            K = 92;
	                            break a
	                        }
	                    } else if (l) {
	                        if ((c[(c[F >> 2] | 0) + 12 >> 2] | 0) == 0 ? (c[(c[F >> 2] | 0) + 16 >> 2] | 0) != (c[v >> 2] | 0) : 0) {
	                            c[G >> 2] = OC(c[o >> 2] | 0, c[q >> 2] | 0, c[v >> 2] | 0) | 0;
	                            if (c[G >> 2] | 0) {
	                                c[(c[z >> 2] | 0) + 12 >> 2] = c[G >> 2];
	                                K = 92;
	                                break a
	                            } else {
	                                c[F >> 2] = 0;
	                                break
	                            }
	                        }
	                        c[(c[z >> 2] | 0) + 12 >> 2] = c[F >> 2];
	                        K = 92;
	                        break a
	                    } while (0);
	                    if ((c[F >> 2] | 0) != 0 ? (c[(c[F >> 2] | 0) + 20 >> 2] | 0) != 0 : 0)xB(c[o >> 2] | 0, 169448, 169472); else K = 52
	                } else K = 52; while (0);
	                b:do if ((K | 0) == 52) {
	                    do if (c[r >> 2] | 0) {
	                        c[A >> 2] = c[r >> 2];
	                        c[E >> 2] = 1;
	                        if (c[(c[r >> 2] | 0) + 72 >> 2] | 0) {
	                            c[q >> 2] = AP(c[(c[o >> 2] | 0) + 80 >> 2] | 0, c[(c[r >> 2] | 0) + 72 >> 2] | 0, -1) | 0;
	                            K = 73;
	                            break
	                        } else {
	                            c[q >> 2] = 169104;
	                            K = 73;
	                            break
	                        }
	                    } else {
	                        if (!((c[q >> 2] | 0) != 0 | (c[s >> 2] | 0) != 0)) {
	                            PC(c[o >> 2] | 0, 0, 1758, 169640, 0, 0);
	                            break b
	                        }
	                        c[H >> 2] = Be() | 0;
	                        if (!(c[H >> 2] | 0)) {
	                            tC(0, 169552, 0);
	                            break b
	                        }
	                        if ((c[(c[o >> 2] | 0) + 80 >> 2] | 0) != 0 ? (c[(c[H >> 2] | 0) + 296 >> 2] | 0) != 0 : 0) {
	                            zP(c[(c[H >> 2] | 0) + 296 >> 2] | 0);
	                            c[(c[H >> 2] | 0) + 296 >> 2] = c[(c[o >> 2] | 0) + 80 >> 2];
	                            yP(c[(c[H >> 2] | 0) + 296 >> 2] | 0) | 0
	                        }
	                        if (!(c[q >> 2] | 0)) {
	                            if ((c[s >> 2] | 0) != 0 ? (c[A >> 2] = lg(c[H >> 2] | 0, c[s >> 2] | 0, c[t >> 2] | 0, 0, 0, 2) | 0, c[q >> 2] = 169104, (c[A >> 2] | 0) != 0) : 0) {
	                                G = my(c[q >> 2] | 0) | 0;
	                                c[(c[A >> 2] | 0) + 72 >> 2] = G
	                            }
	                        } else c[A >> 2] = kg(c[H >> 2] | 0, c[q >> 2] | 0, 0, 2) | 0;
	                        do if (!(c[A >> 2] | 0)) {
	                            c[I >> 2] = de() | 0;
	                            if ((c[I >> 2] | 0) != 0 ? (c[c[I >> 2] >> 2] | 0) == 8 : 0)break;
	                            c[D >> 2] = 1;
	                            c[B >> 2] = 3067;
	                            AB(c[o >> 2] | 0, c[B >> 2] | 0, c[u >> 2] | 0, 0, 169600, c[q >> 2] | 0, 0)
	                        } while (0);
	                        Ae(c[H >> 2] | 0);
	                        if (!((c[A >> 2] | 0) == 0 & (c[D >> 2] | 0) != 0))K = 73
	                    } while (0);
	                    c:do if ((K | 0) == 73) {
	                        do if (c[A >> 2] | 0) {
	                            c[J >> 2] = 0;
	                            c[D >> 2] = 1;
	                            c[J >> 2] = Pi(c[A >> 2] | 0) | 0;
	                            G = c[o >> 2] | 0;
	                            if (!(c[J >> 2] | 0)) {
	                                AB(G, 1759, c[u >> 2] | 0, 0, 169720, c[q >> 2] | 0, 0);
	                                break c
	                            }
	                            QC(G, c[J >> 2] | 0);
	                            if ((((c[J >> 2] | 0) != 0 ? (c[(c[J >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[J >> 2] | 0) + 8 >> 2] | 0, 169768) | 0) != 0 : 0) ? (qy(c[(c[(c[J >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                                c[y >> 2] = RC(c[o >> 2] | 0, c[J >> 2] | 0, 168888) | 0;
	                                break
	                            }
	                            AB(c[o >> 2] | 0, 1772, c[u >> 2] | 0, 0, 169776, c[q >> 2] | 0, 0);
	                            break c
	                        } while (0);
	                        if ((c[F >> 2] | 0) == 0 & (c[D >> 2] | 0) != 0 ? (c[F >> 2] = SC(c[o >> 2] | 0, c[p >> 2] | 0, c[y >> 2] | 0) | 0, (c[F >> 2] | 0) == 0) : 0)break b;
	                        if (!(c[F >> 2] | 0)) {
	                            K = 92;
	                            break b
	                        }
	                        c[(c[F >> 2] | 0) + 8 >> 2] = c[q >> 2];
	                        c[(c[F >> 2] | 0) + 28 >> 2] = c[D >> 2];
	                        if ((c[A >> 2] | 0) != 0 ? (c[(c[F >> 2] | 0) + 20 >> 2] = c[A >> 2], c[(c[F >> 2] | 0) + 16 >> 2] = c[y >> 2], c[(c[F >> 2] | 0) + 12 >> 2] = c[y >> 2], (c[E >> 2] | 0) != 0) : 0)c[(c[F >> 2] | 0) + 40 >> 2] = 1;
	                        if ((c[p >> 2] | 0) == 0 | (c[p >> 2] | 0) == 1) {
	                            G = (c[F >> 2] | 0) + 36 | 0;
	                            c[G >> 2] = (c[G >> 2] | 0) + 1
	                        }
	                        if (!(c[z >> 2] | 0)) {
	                            K = 92;
	                            break b
	                        }
	                        c[(c[z >> 2] | 0) + 12 >> 2] = c[F >> 2];
	                        K = 92;
	                        break b
	                    } while (0);
	                    if (!((c[A >> 2] | 0) == 0 | (c[E >> 2] | 0) != 0) ? (Th(c[A >> 2] | 0), (c[F >> 2] | 0) != 0) : 0)c[(c[F >> 2] | 0) + 20 >> 2] = 0;
	                    c[n >> 2] = c[(c[o >> 2] | 0) + 16 >> 2];
	                    L = c[n >> 2] | 0;
	                    i = m;
	                    return L | 0
	                } while (0);
	                if ((K | 0) == 92) {
	                    if (c[x >> 2] | 0)c[c[x >> 2] >> 2] = c[F >> 2];
	                    c[n >> 2] = 0;
	                    L = c[n >> 2] | 0;
	                    i = m;
	                    return L | 0
	                }
	                if (!((c[A >> 2] | 0) == 0 | (c[E >> 2] | 0) != 0) ? (Th(c[A >> 2] | 0), (c[F >> 2] | 0) != 0) : 0)c[(c[F >> 2] | 0) + 20 >> 2] = 0;
	                c[n >> 2] = -1;
	                L = c[n >> 2] | 0;
	                i = m;
	                return L | 0
	            }

	            function GB(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 32 | 0;
	                g = e + 28 | 0;
	                h = e + 24 | 0;
	                j = e + 20 | 0;
	                k = e + 16 | 0;
	                l = e + 12 | 0;
	                m = e + 8 | 0;
	                n = e + 4 | 0;
	                o = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[o >> 2] = c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2];
	                c[j >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                c[k >> 2] = c[(c[g >> 2] | 0) + 16 >> 2];
	                if (c[(c[g >> 2] | 0) + 24 >> 2] | 0)TC(c[g >> 2] | 0);
	                c[(c[g >> 2] | 0) + 16 >> 2] = c[(c[h >> 2] | 0) + 20 >> 2];
	                c[(c[f >> 2] | 0) + 36 >> 2] = c[g >> 2];
	                c[(c[f >> 2] | 0) + 112 >> 2] = c[(c[h >> 2] | 0) + 16 >> 2];
	                c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] = c[h >> 2];
	                if ((c[(c[h >> 2] | 0) + 16 >> 2] | 0) != 0 ? (qy(c[(c[h >> 2] | 0) + 16 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0)c[(c[f >> 2] | 0) + 96 >> 2] = 1;
	                d = (c[h >> 2] | 0) + 32 | 0;
	                c[d >> 2] = (c[d >> 2] | 0) + 1;
	                c[l >> 2] = Pi(c[(c[h >> 2] | 0) + 20 >> 2] | 0) | 0;
	                c[m >> 2] = UC(c[f >> 2] | 0, c[g >> 2] | 0, c[l >> 2] | 0) | 0;
	                if ((((c[m >> 2] | 0) == 0 ? (c[(c[l >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[n >> 2] = c[(c[f >> 2] | 0) + 20 >> 2], c[m >> 2] = VC(c[f >> 2] | 0, c[g >> 2] | 0, c[(c[l >> 2] | 0) + 12 >> 2] | 0) | 0, (c[m >> 2] | 0) == 0 & (c[m >> 2] | 0) == 0) : 0) ? (c[n >> 2] | 0) != (c[(c[f >> 2] | 0) + 20 >> 2] | 0) : 0)c[m >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] = c[o >> 2];
	                c[(c[g >> 2] | 0) + 16 >> 2] = c[k >> 2];
	                c[(c[g >> 2] | 0) + 24 >> 2] = c[j >> 2];
	                i = e;
	                return c[m >> 2] | 0
	            }

	            function HB(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                d = i;
	                i = i + 48 | 0;
	                e = d + 40 | 0;
	                f = d + 36 | 0;
	                g = d + 32 | 0;
	                h = d + 28 | 0;
	                j = d + 24 | 0;
	                k = d + 20 | 0;
	                l = d + 16 | 0;
	                m = d + 12 | 0;
	                n = d + 8 | 0;
	                o = d + 4 | 0;
	                p = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = c[(c[f >> 2] | 0) + 28 >> 2];
	                c[n >> 2] = 0;
	                c[o >> 2] = c[(c[h >> 2] | 0) + 16 >> 2];
	                if ((c[(c[h >> 2] | 0) + 20 >> 2] | 0) != 0 ? (c[(c[(c[h >> 2] | 0) + 20 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                    if (!(c[(c[h >> 2] | 0) + 16 >> 2] | 0))c[(c[h >> 2] | 0) + 16 >> 2] = c[g >> 2];
	                    WC(c[f >> 2] | 0) | 0;
	                    XC(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 84 >> 2] = 0;
	                    c[k >> 2] = c[c[(c[h >> 2] | 0) + 20 >> 2] >> 2];
	                    c[l >> 2] = c[(c[(c[h >> 2] | 0) + 20 >> 2] | 0) + 4 >> 2];
	                    c[m >> 2] = 0;
	                    a:while (1) {
	                        if ((c[m >> 2] | 0) >= (c[l >> 2] | 0)) {
	                            q = 20;
	                            break
	                        }
	                        c[j >> 2] = c[(c[k >> 2] | 0) + (c[m >> 2] << 2) >> 2];
	                        switch (c[c[j >> 2] >> 2] | 0) {
	                            case 26:
	                            {
	                                $C(c[j >> 2] | 0, c[f >> 2] | 0) | 0;
	                                if ((c[(c[f >> 2] | 0) + 16 >> 2] | 0) == 3069) {
	                                    q = 115;
	                                    break a
	                                }
	                                break
	                            }
	                            case 8:
	                            case 7:
	                            case 6:
	                            {
	                                bD(c[f >> 2] | 0, c[j >> 2] | 0);
	                                if ((c[(c[f >> 2] | 0) + 16 >> 2] | 0) == 3069) {
	                                    q = 115;
	                                    break a
	                                }
	                                break
	                            }
	                            case 4:
	                            case 5:
	                            {
	                                ZC(c[j >> 2] | 0, c[f >> 2] | 0);
	                                if ((c[(c[f >> 2] | 0) + 16 >> 2] | 0) == 3069) {
	                                    q = 115;
	                                    break a
	                                }
	                                break
	                            }
	                            case 14:
	                            {
	                                YC(c[j >> 2] | 0, c[f >> 2] | 0);
	                                if ((c[(c[f >> 2] | 0) + 16 >> 2] | 0) == 3069) {
	                                    q = 115;
	                                    break a
	                                }
	                                break
	                            }
	                            case 15:
	                            {
	                                _C(c[j >> 2] | 0, c[f >> 2] | 0) | 0;
	                                if ((c[(c[f >> 2] | 0) + 16 >> 2] | 0) == 3069) {
	                                    q = 115;
	                                    break a
	                                }
	                                break
	                            }
	                            case 2e3:
	                            {
	                                if ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) == 16)aD(c[j >> 2] | 0, c[f >> 2] | 0) | 0;
	                                if ((c[(c[f >> 2] | 0) + 16 >> 2] | 0) == 3069) {
	                                    q = 115;
	                                    break a
	                                }
	                                break
	                            }
	                            case 2001:
	                            {
	                                dD(c[j >> 2] | 0, c[f >> 2] | 0) | 0;
	                                if ((c[(c[f >> 2] | 0) + 16 >> 2] | 0) == 3069) {
	                                    q = 115;
	                                    break a
	                                }
	                                break
	                            }
	                            case 24:
	                            case 22:
	                            case 23:
	                            {
	                                cD(c[j >> 2] | 0, c[f >> 2] | 0) | 0;
	                                if ((c[(c[f >> 2] | 0) + 16 >> 2] | 0) == 3069) {
	                                    q = 115;
	                                    break a
	                                }
	                                break
	                            }
	                            default:
	                            {
	                            }
	                        }
	                        c[m >> 2] = (c[m >> 2] | 0) + 1
	                    }
	                    b:do if ((q | 0) == 20) {
	                        c:do if (!(c[(c[f >> 2] | 0) + 20 >> 2] | 0)) {
	                            c[m >> 2] = 0;
	                            while (1) {
	                                if ((c[m >> 2] | 0) >= (c[l >> 2] | 0))break;
	                                c[j >> 2] = c[(c[k >> 2] | 0) + (c[m >> 2] << 2) >> 2];
	                                g = c[c[j >> 2] >> 2] | 0;
	                                if ((g | 0) == 16) {
	                                    gD(c[j >> 2] | 0, c[f >> 2] | 0) | 0;
	                                    if ((c[(c[f >> 2] | 0) + 16 >> 2] | 0) == 3069) {
	                                        q = 115;
	                                        break b
	                                    }
	                                    if (c[(c[f >> 2] | 0) + 20 >> 2] | 0)break c
	                                } else if ((g | 0) == 4 | (g | 0) == 5) {
	                                    eD(c[j >> 2] | 0, c[f >> 2] | 0);
	                                    if ((c[(c[f >> 2] | 0) + 16 >> 2] | 0) == 3069) {
	                                        q = 115;
	                                        break b
	                                    }
	                                    if (c[(c[f >> 2] | 0) + 20 >> 2] | 0)break c
	                                } else if ((g | 0) == 17) {
	                                    fD(c[j >> 2] | 0, c[f >> 2] | 0);
	                                    if ((c[(c[f >> 2] | 0) + 16 >> 2] | 0) == 3069) {
	                                        q = 115;
	                                        break b
	                                    }
	                                    if (c[(c[f >> 2] | 0) + 20 >> 2] | 0)break c
	                                }
	                                c[m >> 2] = (c[m >> 2] | 0) + 1
	                            }
	                            if (!(c[(c[f >> 2] | 0) + 20 >> 2] | 0)) {
	                                c[m >> 2] = 0;
	                                while (1) {
	                                    if ((c[m >> 2] | 0) >= (c[l >> 2] | 0))break;
	                                    c[j >> 2] = c[(c[k >> 2] | 0) + (c[m >> 2] << 2) >> 2];
	                                    if (((c[c[j >> 2] >> 2] | 0) + -6 | 0) >>> 0 < 2)hD(c[f >> 2] | 0, c[j >> 2] | 0);
	                                    c[m >> 2] = (c[m >> 2] | 0) + 1
	                                }
	                                if (!(c[(c[f >> 2] | 0) + 20 >> 2] | 0)) {
	                                    c[m >> 2] = 0;
	                                    while (1) {
	                                        if ((c[m >> 2] | 0) >= (c[l >> 2] | 0))break;
	                                        c[j >> 2] = c[(c[k >> 2] | 0) + (c[m >> 2] << 2) >> 2];
	                                        if ((((c[c[j >> 2] >> 2] | 0) == 16 ? (c[(c[j >> 2] | 0) + 36 >> 2] & 1 | 0) == 0 : 0) ? (c[(c[j >> 2] | 0) + 36 >> 2] & 16 | 0) != 0 : 0) ? (iD(c[f >> 2] | 0, c[j >> 2] | 0) | 0, (c[(c[f >> 2] | 0) + 16 >> 2] | 0) == 3069) : 0) {
	                                            q = 115;
	                                            break b
	                                        }
	                                        c[m >> 2] = (c[m >> 2] | 0) + 1
	                                    }
	                                    if (!(c[(c[f >> 2] | 0) + 20 >> 2] | 0)) {
	                                        c[m >> 2] = 0;
	                                        while (1) {
	                                            if ((c[m >> 2] | 0) >= (c[l >> 2] | 0))break;
	                                            c[j >> 2] = c[(c[k >> 2] | 0) + (c[m >> 2] << 2) >> 2];
	                                            if ((((c[c[j >> 2] >> 2] | 0) == 4 ? (c[c[j >> 2] >> 2] | 0) != 1 : 0) ? (c[(c[j >> 2] | 0) + 48 >> 2] & 536870912 | 0) == 0 : 0) ? (jD(c[f >> 2] | 0, c[j >> 2] | 0) | 0, (c[(c[f >> 2] | 0) + 16 >> 2] | 0) == 3069) : 0) {
	                                                q = 115;
	                                                break b
	                                            }
	                                            c[m >> 2] = (c[m >> 2] | 0) + 1
	                                        }
	                                        if (!(c[(c[f >> 2] | 0) + 20 >> 2] | 0)) {
	                                            c[m >> 2] = 0;
	                                            while (1) {
	                                                if ((c[m >> 2] | 0) >= (c[l >> 2] | 0))break;
	                                                c[j >> 2] = c[(c[k >> 2] | 0) + (c[m >> 2] << 2) >> 2];
	                                                if (((c[c[j >> 2] >> 2] | 0) == 4 ? (c[(c[j >> 2] | 0) + 92 >> 2] | 0) != 0 : 0) ? (kD(c[f >> 2] | 0, c[j >> 2] | 0) | 0, (c[(c[f >> 2] | 0) + 16 >> 2] | 0) == 3069) : 0) {
	                                                    q = 115;
	                                                    break b
	                                                }
	                                                c[m >> 2] = (c[m >> 2] | 0) + 1
	                                            }
	                                            if (!(c[(c[f >> 2] | 0) + 20 >> 2] | 0)) {
	                                                c[m >> 2] = 0;
	                                                while (1) {
	                                                    if ((c[m >> 2] | 0) >= (c[l >> 2] | 0))break;
	                                                    c[j >> 2] = c[(c[k >> 2] | 0) + (c[m >> 2] << 2) >> 2];
	                                                    if ((((c[c[j >> 2] >> 2] | 0) == 4 ? (c[c[j >> 2] >> 2] | 0) != 1 : 0) ? (c[(c[j >> 2] | 0) + 48 >> 2] & 4194304 | 0) == 0 : 0) ? (lD(c[f >> 2] | 0, c[j >> 2] | 0) | 0, (c[(c[f >> 2] | 0) + 16 >> 2] | 0) == 3069) : 0) {
	                                                        q = 115;
	                                                        break b
	                                                    }
	                                                    c[m >> 2] = (c[m >> 2] | 0) + 1
	                                                }
	                                                if (!(c[(c[f >> 2] | 0) + 20 >> 2] | 0)) {
	                                                    c[m >> 2] = 0;
	                                                    while (1) {
	                                                        if ((c[m >> 2] | 0) >= (c[l >> 2] | 0))break;
	                                                        c[j >> 2] = c[(c[k >> 2] | 0) + (c[m >> 2] << 2) >> 2];
	                                                        if ((c[c[j >> 2] >> 2] | 0) == 15 ? (mD(c[f >> 2] | 0, c[j >> 2] | 0) | 0, (c[(c[f >> 2] | 0) + 16 >> 2] | 0) == 3069) : 0) {
	                                                            q = 115;
	                                                            break b
	                                                        }
	                                                        c[m >> 2] = (c[m >> 2] | 0) + 1
	                                                    }
	                                                    if (!(c[(c[f >> 2] | 0) + 20 >> 2] | 0)) {
	                                                        c[m >> 2] = 0;
	                                                        while (1) {
	                                                            if ((c[m >> 2] | 0) >= (c[l >> 2] | 0))break;
	                                                            c[j >> 2] = c[(c[k >> 2] | 0) + (c[m >> 2] << 2) >> 2];
	                                                            if (((c[c[j >> 2] >> 2] | 0) == 26 ? (c[(c[j >> 2] | 0) + 28 >> 2] | 0) != 0 : 0) ? (nD(c[f >> 2] | 0, c[j >> 2] | 0) | 0, (c[(c[f >> 2] | 0) + 16 >> 2] | 0) == 3069) : 0) {
	                                                                q = 115;
	                                                                break b
	                                                            }
	                                                            c[m >> 2] = (c[m >> 2] | 0) + 1
	                                                        }
	                                                        if (!(c[(c[f >> 2] | 0) + 20 >> 2] | 0)) {
	                                                            c[m >> 2] = 0;
	                                                            while (1) {
	                                                                if ((c[m >> 2] | 0) >= (c[l >> 2] | 0))break;
	                                                                c[j >> 2] = c[(c[k >> 2] | 0) + (c[m >> 2] << 2) >> 2];
	                                                                do if ((c[c[j >> 2] >> 2] | 0) == 16 ? (c[(c[j >> 2] | 0) + 56 >> 2] | 0) != 0 : 0) {
	                                                                    if ((c[(c[(c[j >> 2] | 0) + 56 >> 2] | 0) + 4 >> 2] | 0) <= 1)break;
	                                                                    oD(c[f >> 2] | 0, c[j >> 2] | 0) | 0;
	                                                                    if ((c[(c[f >> 2] | 0) + 16 >> 2] | 0) == 3069) {
	                                                                        q = 115;
	                                                                        break b
	                                                                    }
	                                                                } while (0);
	                                                                c[m >> 2] = (c[m >> 2] | 0) + 1
	                                                            }
	                                                            if (!(c[(c[f >> 2] | 0) + 20 >> 2] | 0)) {
	                                                                if (c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 28 >> 2] | 0)pD(c[f >> 2] | 0) | 0;
	                                                                if (!(c[(c[f >> 2] | 0) + 20 >> 2] | 0)) {
	                                                                    c[m >> 2] = 0;
	                                                                    while (1) {
	                                                                        if ((c[m >> 2] | 0) >= (c[l >> 2] | 0))break;
	                                                                        c[j >> 2] = c[(c[c[(c[h >> 2] | 0) + 20 >> 2] >> 2] | 0) + (c[m >> 2] << 2) >> 2];
	                                                                        do if ((c[c[j >> 2] >> 2] | 0) == 5) {
	                                                                            if ((c[c[j >> 2] >> 2] | 0) == 1)break;
	                                                                            if (c[(c[j >> 2] | 0) + 48 >> 2] & 4194304)break;
	                                                                            qD(c[f >> 2] | 0, c[j >> 2] | 0) | 0;
	                                                                            if ((c[(c[f >> 2] | 0) + 16 >> 2] | 0) == 3069) {
	                                                                                q = 115;
	                                                                                break b
	                                                                            }
	                                                                        } while (0);
	                                                                        c[m >> 2] = (c[m >> 2] | 0) + 1
	                                                                    }
	                                                                    if (!(c[(c[f >> 2] | 0) + 20 >> 2] | 0)) {
	                                                                        c[k >> 2] = c[c[(c[h >> 2] | 0) + 20 >> 2] >> 2];
	                                                                        c[l >> 2] = c[(c[(c[h >> 2] | 0) + 20 >> 2] | 0) + 4 >> 2];
	                                                                        c[m >> 2] = 0;
	                                                                        while (1) {
	                                                                            if ((c[m >> 2] | 0) >= (c[l >> 2] | 0))break;
	                                                                            c[j >> 2] = c[(c[k >> 2] | 0) + (c[m >> 2] << 2) >> 2];
	                                                                            do if ((c[c[j >> 2] >> 2] | 0) == 14) {
	                                                                                c[p >> 2] = c[j >> 2];
	                                                                                if (c[(c[p >> 2] | 0) + 48 >> 2] & 262144)break;
	                                                                                rD(c[p >> 2] | 0, c[f >> 2] | 0);
	                                                                                if ((c[(c[f >> 2] | 0) + 16 >> 2] | 0) == 3069) {
	                                                                                    q = 115;
	                                                                                    break b
	                                                                                }
	                                                                            } while (0);
	                                                                            c[m >> 2] = (c[m >> 2] | 0) + 1
	                                                                        }
	                                                                        if (!(c[(c[f >> 2] | 0) + 20 >> 2] | 0)) {
	                                                                            c[m >> 2] = 0;
	                                                                            while (1) {
	                                                                                if ((c[m >> 2] | 0) >= (c[l >> 2] | 0))break;
	                                                                                c[j >> 2] = c[(c[k >> 2] | 0) + (c[m >> 2] << 2) >> 2];
	                                                                                if ((c[c[j >> 2] >> 2] | 0) == 5)sD(c[j >> 2] | 0, c[f >> 2] | 0);
	                                                                                c[m >> 2] = (c[m >> 2] | 0) + 1
	                                                                            }
	                                                                            if (!(c[(c[f >> 2] | 0) + 20 >> 2] | 0))break b
	                                                                        }
	                                                                    }
	                                                                }
	                                                            }
	                                                        }
	                                                    }
	                                                }
	                                            }
	                                        }
	                                    }
	                                }
	                            }
	                        } while (0);
	                        c[n >> 2] = c[(c[f >> 2] | 0) + 16 >> 2]
	                    } while (0);
	                    if ((q | 0) == 115)c[n >> 2] = -1;
	                    c[(c[h >> 2] | 0) + 16 >> 2] = c[o >> 2];
	                    c[(c[(c[h >> 2] | 0) + 20 >> 2] | 0) + 4 >> 2] = 0;
	                    if (c[(c[h >> 2] | 0) + 24 >> 2] | 0) {
	                        Kj(c[(c[h >> 2] | 0) + 24 >> 2] | 0, 356);
	                        c[(c[h >> 2] | 0) + 24 >> 2] = 0
	                    }
	                    if (c[(c[h >> 2] | 0) + 28 >> 2] | 0) {
	                        vC(c[(c[h >> 2] | 0) + 28 >> 2] | 0);
	                        c[(c[h >> 2] | 0) + 28 >> 2] = 0
	                    }
	                    c[e >> 2] = c[n >> 2];
	                    r = c[e >> 2] | 0;
	                    i = d;
	                    return r | 0
	                }
	                c[e >> 2] = 0;
	                r = c[e >> 2] | 0;
	                i = d;
	                return r | 0
	            }

	            function IB(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if (c[f >> 2] | 0) {
	                    d = (c[f >> 2] | 0) + 56 | 0;
	                    c[d >> 2] = (c[d >> 2] | 0) + 1;
	                    c[(c[f >> 2] | 0) + 52 >> 2] = 1818
	                }
	                ce(17, 2, c[h >> 2] | 0, 0, c[g >> 2] | 0);
	                i = e;
	                return
	            }

	            function JB() {
	                var a = 0, b = 0, d = 0, e = 0, f = 0;
	                a = i;
	                i = i + 16 | 0;
	                b = a + 4 | 0;
	                d = a;
	                c[d >> 2] = Cb[c[135744 >> 2] & 511](12) | 0;
	                if (!(c[d >> 2] | 0)) {
	                    tC(0, 156200, 0);
	                    c[b >> 2] = 0;
	                    e = c[b >> 2] | 0;
	                    i = a;
	                    return e | 0
	                } else {
	                    f = c[d >> 2] | 0;
	                    c[f + 0 >> 2] = 0;
	                    c[f + 4 >> 2] = 0;
	                    c[f + 8 >> 2] = 0;
	                    c[b >> 2] = c[d >> 2];
	                    e = c[b >> 2] | 0;
	                    i = a;
	                    return e | 0
	                }
	                return 0
	            }

	            function KB(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                if ((pC(c[e >> 2] | 0) | 0) < 0) {
	                    c[d >> 2] = -1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = c[e >> 2] | 0;
	                do if (!(c[(c[e >> 2] | 0) + 24 >> 2] | 0)) {
	                    if (!(c[a + 160 >> 2] | 0)) {
	                        if ((c[(c[e >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) {
	                            c[f >> 2] = Qf(c[(c[e >> 2] | 0) + 40 >> 2] | 0) | 0;
	                            break
	                        }
	                        xB(c[e >> 2] | 0, 155872, 155888);
	                        c[f >> 2] = -1
	                    }
	                } else c[f >> 2] = tD(a) | 0; while (0);
	                qC(c[e >> 2] | 0);
	                if (!(c[f >> 2] | 0))c[f >> 2] = c[(c[e >> 2] | 0) + 52 >> 2];
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function LB(a, b, e, f, g, h, j, k, l) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                k = k | 0;
	                l = l | 0;
	                var m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0;
	                m = i;
	                i = i + 64 | 0;
	                n = m + 56 | 0;
	                o = m + 52 | 0;
	                p = m + 44 | 0;
	                q = m + 40 | 0;
	                r = m + 36 | 0;
	                s = m + 32 | 0;
	                t = m + 24 | 0;
	                u = m + 20 | 0;
	                v = m + 16 | 0;
	                w = m + 12 | 0;
	                x = m + 8 | 0;
	                y = m + 4 | 0;
	                z = m;
	                c[n >> 2] = a;
	                c[o >> 2] = b;
	                c[m + 48 >> 2] = e;
	                c[p >> 2] = f;
	                c[q >> 2] = g;
	                c[r >> 2] = h;
	                c[s >> 2] = j;
	                c[m + 28 >> 2] = k;
	                c[t >> 2] = l;
	                c[u >> 2] = c[n >> 2];
	                n = (c[u >> 2] | 0) + 96 | 0;
	                c[n >> 2] = (c[n >> 2] | 0) + 1;
	                if ((c[(c[u >> 2] | 0) + 176 >> 2] | 0) != -1 ? (c[(c[u >> 2] | 0) + 96 >> 2] | 0) >= (c[(c[u >> 2] | 0) + 176 >> 2] | 0) : 0) {
	                    i = m;
	                    return
	                }
	                n = (uD(c[u >> 2] | 0) | 0) == -1;
	                l = c[u >> 2] | 0;
	                a:do if (!n) {
	                    c[w >> 2] = c[l + 108 >> 2];
	                    k = NP(c[(c[u >> 2] | 0) + 40 >> 2] | 0) | 0;
	                    c[(c[w >> 2] | 0) + 8 >> 2] = k;
	                    c[(c[w >> 2] | 0) + 12 >> 2] = c[o >> 2];
	                    c[(c[w >> 2] | 0) + 16 >> 2] = c[p >> 2];
	                    k = (c[w >> 2] | 0) + 32 | 0;
	                    c[k >> 2] = c[k >> 2] | 32;
	                    b:do if (c[q >> 2] | 0) {
	                        c[x >> 2] = 0;
	                        c[y >> 2] = 0;
	                        while (1) {
	                            if ((c[x >> 2] | 0) >= (c[q >> 2] | 0))break b;
	                            if (c[(c[w >> 2] | 0) + 64 >> 2] | 0) {
	                                if ((c[(c[w >> 2] | 0) + 72 >> 2] | 0) <= (c[(c[w >> 2] | 0) + 68 >> 2] | 0) ? (k = (c[w >> 2] | 0) + 72 | 0, c[k >> 2] = c[k >> 2] << 1, k = Hb[c[135760 >> 2] & 511](c[(c[w >> 2] | 0) + 64 >> 2] | 0, c[(c[w >> 2] | 0) + 72 >> 2] << 1 << 2) | 0, c[(c[w >> 2] | 0) + 64 >> 2] = k, (c[(c[w >> 2] | 0) + 64 >> 2] | 0) == 0) : 0) {
	                                    A = 14;
	                                    break
	                                }
	                            } else {
	                                k = Cb[c[135744 >> 2] & 511](40) | 0;
	                                c[(c[w >> 2] | 0) + 64 >> 2] = k;
	                                if (!(c[(c[w >> 2] | 0) + 64 >> 2] | 0)) {
	                                    A = 10;
	                                    break
	                                }
	                                c[(c[w >> 2] | 0) + 68 >> 2] = 0;
	                                c[(c[w >> 2] | 0) + 72 >> 2] = 5
	                            }
	                            c[(c[(c[w >> 2] | 0) + 64 >> 2] | 0) + (c[(c[w >> 2] | 0) + 68 >> 2] << 1 << 2) >> 2] = c[(c[r >> 2] | 0) + (c[y >> 2] << 2) >> 2];
	                            if (!(d[c[(c[r >> 2] | 0) + ((c[y >> 2] | 0) + 1 << 2) >> 2] >> 0] | 0))c[(c[(c[w >> 2] | 0) + 64 >> 2] | 0) + ((c[(c[w >> 2] | 0) + 68 >> 2] << 1) + 1 << 2) >> 2] = 0; else c[(c[(c[w >> 2] | 0) + 64 >> 2] | 0) + ((c[(c[w >> 2] | 0) + 68 >> 2] << 1) + 1 << 2) >> 2] = c[(c[r >> 2] | 0) + ((c[y >> 2] | 0) + 1 << 2) >> 2];
	                            k = (c[w >> 2] | 0) + 68 | 0;
	                            c[k >> 2] = (c[k >> 2] | 0) + 1;
	                            c[x >> 2] = (c[x >> 2] | 0) + 1;
	                            c[y >> 2] = (c[y >> 2] | 0) + 2
	                        }
	                        if ((A | 0) == 10) {
	                            IB(c[u >> 2] | 0, 144584, 0);
	                            break a
	                        } else if ((A | 0) == 14) {
	                            IB(c[u >> 2] | 0, 144640, 0);
	                            break a
	                        }
	                    } while (0);
	                    c:do if (c[s >> 2] | 0) {
	                        c[y >> 2] = 0;
	                        c[x >> 2] = 0;
	                        while (1) {
	                            if ((c[x >> 2] | 0) >= (c[s >> 2] | 0))break c;
	                            c[z >> 2] = ly(c[(c[t >> 2] | 0) + ((c[y >> 2] | 0) + 3 << 2) >> 2] | 0, (c[(c[t >> 2] | 0) + ((c[y >> 2] | 0) + 4 << 2) >> 2] | 0) - (c[(c[t >> 2] | 0) + ((c[y >> 2] | 0) + 3 << 2) >> 2] | 0) | 0) | 0;
	                            c[v >> 2] = vD(c[u >> 2] | 0, 0, c[(c[w >> 2] | 0) + 8 >> 2] | 0, c[(c[t >> 2] | 0) + (c[y >> 2] << 2) >> 2] | 0, c[(c[t >> 2] | 0) + ((c[y >> 2] | 0) + 2 << 2) >> 2] | 0, 0, c[z >> 2] | 0, 1) | 0;
	                            if ((c[v >> 2] | 0) == -1)break;
	                            c[x >> 2] = (c[x >> 2] | 0) + 1;
	                            c[y >> 2] = (c[y >> 2] | 0) + 5
	                        }
	                        xB(c[u >> 2] | 0, 144504, 144696);
	                        break a
	                    } while (0);
	                    c[v >> 2] = wD(c[u >> 2] | 0) | 0;
	                    if ((c[v >> 2] | 0) != 0 & (c[v >> 2] | 0) == -1) {
	                        xB(c[u >> 2] | 0, 144504, 144744);
	                        break
	                    } else {
	                        i = m;
	                        return
	                    }
	                } else xB(l, 144504, 144544); while (0);
	                c[(c[u >> 2] | 0) + 52 >> 2] = -1;
	                Uf(c[(c[u >> 2] | 0) + 40 >> 2] | 0);
	                i = m;
	                return
	            }

	            function MB(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[f + 12 >> 2] = d;
	                c[j >> 2] = e;
	                c[k >> 2] = c[g >> 2];
	                do if ((c[(c[k >> 2] | 0) + 176 >> 2] | 0) != -1) {
	                    g = c[k >> 2] | 0;
	                    if ((c[(c[k >> 2] | 0) + 96 >> 2] | 0) <= (c[(c[k >> 2] | 0) + 176 >> 2] | 0)) {
	                        c[g + 176 >> 2] = -1;
	                        break
	                    }
	                    e = g + 96 | 0;
	                    c[e >> 2] = (c[e >> 2] | 0) + -1;
	                    i = f;
	                    return
	                } while (0);
	                if (!((qy(c[(c[(c[k >> 2] | 0) + 108 >> 2] | 0) + 12 >> 2] | 0, c[h >> 2] | 0) | 0) != 0 ? (qy(c[(c[(c[k >> 2] | 0) + 108 >> 2] | 0) + 16 >> 2] | 0, c[j >> 2] | 0) | 0) != 0 : 0))xB(c[k >> 2] | 0, 141632, 141664);
	                c[l >> 2] = xD(c[k >> 2] | 0) | 0;
	                if (!((c[l >> 2] | 0) != 0 & (c[l >> 2] | 0) < 0)) {
	                    i = f;
	                    return
	                }
	                xB(c[k >> 2] | 0, 141632, 141688);
	                c[(c[k >> 2] | 0) + 52 >> 2] = -1;
	                Uf(c[(c[k >> 2] | 0) + 40 >> 2] | 0);
	                i = f;
	                return
	            }

	            function NB(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = c[f >> 2];
	                if ((c[(c[j >> 2] | 0) + 96 >> 2] | 0) < 0) {
	                    i = e;
	                    return
	                }
	                if ((c[(c[j >> 2] | 0) + 176 >> 2] | 0) != -1 ? (c[(c[j >> 2] | 0) + 96 >> 2] | 0) >= (c[(c[j >> 2] | 0) + 176 >> 2] | 0) : 0) {
	                    i = e;
	                    return
	                }
	                if (c[(c[(c[j >> 2] | 0) + 108 >> 2] | 0) + 32 >> 2] & 32) {
	                    f = (c[(c[j >> 2] | 0) + 108 >> 2] | 0) + 32 | 0;
	                    c[f >> 2] = c[f >> 2] ^ 32
	                }
	                if ((yD(c[j >> 2] | 0, 3, c[g >> 2] | 0, c[h >> 2] | 0, 3, 0) | 0) != -1) {
	                    i = e;
	                    return
	                }
	                xB(c[j >> 2] | 0, 141304, 141336);
	                c[(c[j >> 2] | 0) + 52 >> 2] = -1;
	                Uf(c[(c[j >> 2] | 0) + 40 >> 2] | 0);
	                i = e;
	                return
	            }

	            function OB(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = c[f >> 2];
	                if ((c[(c[j >> 2] | 0) + 96 >> 2] | 0) < 0) {
	                    i = e;
	                    return
	                }
	                if ((c[(c[j >> 2] | 0) + 176 >> 2] | 0) != -1 ? (c[(c[j >> 2] | 0) + 96 >> 2] | 0) >= (c[(c[j >> 2] | 0) + 176 >> 2] | 0) : 0) {
	                    i = e;
	                    return
	                }
	                if (c[(c[(c[j >> 2] | 0) + 108 >> 2] | 0) + 32 >> 2] & 32) {
	                    f = (c[(c[j >> 2] | 0) + 108 >> 2] | 0) + 32 | 0;
	                    c[f >> 2] = c[f >> 2] ^ 32
	                }
	                if ((yD(c[j >> 2] | 0, 4, c[g >> 2] | 0, c[h >> 2] | 0, 3, 0) | 0) != -1) {
	                    i = e;
	                    return
	                }
	                xB(c[j >> 2] | 0, 141304, 141336);
	                c[(c[j >> 2] | 0) + 52 >> 2] = -1;
	                Uf(c[(c[j >> 2] | 0) + 40 >> 2] | 0);
	                i = e;
	                return
	            }

	            function PB(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 16 | 0;
	                g = d + 8 | 0;
	                c[f >> 2] = a;
	                c[d + 12 >> 2] = b;
	                c[g >> 2] = c[f >> 2];
	                if ((c[(c[g >> 2] | 0) + 96 >> 2] | 0) < 0) {
	                    i = d;
	                    return
	                }
	                if ((c[(c[g >> 2] | 0) + 176 >> 2] | 0) != -1 ? (c[(c[g >> 2] | 0) + 96 >> 2] | 0) >= (c[(c[g >> 2] | 0) + 176 >> 2] | 0) : 0) {
	                    i = d;
	                    return
	                }
	                g = c[33976] | 0;
	                f = c[33980] | 0;
	                c[e >> 2] = 140328;
	                c[e + 4 >> 2] = 27281;
	                Db[g & 511](f, 140296, e);
	                i = d;
	                return
	            }

	            function QB(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[l >> 2] = c[g >> 2];
	                if (!(c[l >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                if (!(c[(c[l >> 2] | 0) + 8 >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                if (!(c[c[(c[l >> 2] | 0) + 8 >> 2] >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                Jb[c[c[(c[l >> 2] | 0) + 8 >> 2] >> 2] & 511](c[(c[l >> 2] | 0) + 16 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0);
	                i = f;
	                return
	            }

	            function RB(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = c[e >> 2];
	                if (((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                    c[d >> 2] = Cb[c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + 4 >> 2] & 511](c[(c[f >> 2] | 0) + 16 >> 2] | 0) | 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[d >> 2] = 0;
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function SB(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = c[e >> 2];
	                if (((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                    c[d >> 2] = Cb[c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + 8 >> 2] & 511](c[(c[f >> 2] | 0) + 16 >> 2] | 0) | 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[d >> 2] = 0;
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function TB(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = c[e >> 2];
	                if (((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                    c[d >> 2] = Cb[c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + 12 >> 2] & 511](c[(c[f >> 2] | 0) + 16 >> 2] | 0) | 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[d >> 2] = 0;
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function UB(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = c[g >> 2];
	                if (((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (c[(c[(c[k >> 2] | 0) + 8 >> 2] | 0) + 16 >> 2] | 0) != 0 : 0) {
	                    c[f >> 2] = vb[c[(c[(c[k >> 2] | 0) + 8 >> 2] | 0) + 16 >> 2] & 511](c[(c[k >> 2] | 0) + 16 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[f >> 2] = 0;
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function VB(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = c[f >> 2];
	                if (((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (c[(c[(c[h >> 2] | 0) + 8 >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) {
	                    c[e >> 2] = Hb[c[(c[(c[h >> 2] | 0) + 8 >> 2] | 0) + 20 >> 2] & 511](c[(c[h >> 2] | 0) + 16 >> 2] | 0, c[g >> 2] | 0) | 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[e >> 2] = 0;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function WB(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                h = i;
	                i = i + 32 | 0;
	                j = h + 24 | 0;
	                k = h + 20 | 0;
	                l = h + 16 | 0;
	                m = h + 12 | 0;
	                n = h + 8 | 0;
	                o = h + 4 | 0;
	                p = h;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                c[p >> 2] = c[j >> 2];
	                if (!(c[p >> 2] | 0)) {
	                    i = h;
	                    return
	                }
	                if (!(c[(c[p >> 2] | 0) + 8 >> 2] | 0)) {
	                    i = h;
	                    return
	                }
	                if (!(c[(c[(c[p >> 2] | 0) + 8 >> 2] | 0) + 24 >> 2] | 0)) {
	                    i = h;
	                    return
	                }
	                Gb[c[(c[(c[p >> 2] | 0) + 8 >> 2] | 0) + 24 >> 2] & 511](c[(c[p >> 2] | 0) + 16 >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0);
	                i = h;
	                return
	            }

	            function XB(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[l >> 2] = c[g >> 2];
	                if (!(c[l >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                if (!(c[(c[l >> 2] | 0) + 8 >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                if (!(c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 28 >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                Jb[c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 28 >> 2] & 511](c[(c[l >> 2] | 0) + 16 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0);
	                i = f;
	                return
	            }

	            function YB(a, b, d, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                j = i;
	                i = i + 32 | 0;
	                k = j + 28 | 0;
	                l = j + 24 | 0;
	                m = j + 20 | 0;
	                n = j + 16 | 0;
	                o = j + 12 | 0;
	                p = j + 8 | 0;
	                q = j + 4 | 0;
	                r = j;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                c[q >> 2] = h;
	                c[r >> 2] = c[k >> 2];
	                if (((c[r >> 2] | 0) != 0 ? (c[(c[r >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (c[(c[(c[r >> 2] | 0) + 8 >> 2] | 0) + 32 >> 2] | 0) != 0 : 0) {
	                    wb[c[(c[(c[r >> 2] | 0) + 8 >> 2] | 0) + 32 >> 2] & 511](c[(c[r >> 2] | 0) + 16 >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0);
	                    i = j;
	                    return
	                }
	                rm(c[q >> 2] | 0);
	                i = j;
	                return
	            }

	            function ZB(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[l >> 2] = c[g >> 2];
	                if (!(c[l >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                if (!(c[(c[l >> 2] | 0) + 8 >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                if (!(c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 36 >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                Jb[c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 36 >> 2] & 511](c[(c[l >> 2] | 0) + 16 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0);
	                i = f;
	                return
	            }

	            function _B(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 20 | 0;
	                j = g + 16 | 0;
	                k = g + 12 | 0;
	                l = g + 8 | 0;
	                m = g + 4 | 0;
	                n = g;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                c[n >> 2] = c[h >> 2];
	                if (!(c[n >> 2] | 0)) {
	                    i = g;
	                    return
	                }
	                if (!(c[(c[n >> 2] | 0) + 8 >> 2] | 0)) {
	                    i = g;
	                    return
	                }
	                if (!(c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + 40 >> 2] | 0)) {
	                    i = g;
	                    return
	                }
	                xb[c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + 40 >> 2] & 511](c[(c[n >> 2] | 0) + 16 >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0);
	                i = g;
	                return
	            }

	            function $B(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[g >> 2] = c[e >> 2];
	                if (!(c[g >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if (!(c[(c[g >> 2] | 0) + 8 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if (!(c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                Ab[c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] & 511](c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[f >> 2] | 0);
	                i = d;
	                return
	            }

	            function aC(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                c[e >> 2] = c[d >> 2];
	                if (!(c[e >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (!(c[(c[e >> 2] | 0) + 8 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (!(c[(c[(c[e >> 2] | 0) + 8 >> 2] | 0) + 48 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                zb[c[(c[(c[e >> 2] | 0) + 8 >> 2] | 0) + 48 >> 2] & 511](c[(c[e >> 2] | 0) + 16 >> 2] | 0);
	                i = b;
	                return
	            }

	            function bC(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                c[e >> 2] = c[d >> 2];
	                if (!(c[e >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (!(c[(c[e >> 2] | 0) + 8 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (!(c[(c[(c[e >> 2] | 0) + 8 >> 2] | 0) + 52 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                zb[c[(c[(c[e >> 2] | 0) + 8 >> 2] | 0) + 52 >> 2] & 511](c[(c[e >> 2] | 0) + 16 >> 2] | 0);
	                i = b;
	                return
	            }

	            function cC(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = c[f >> 2];
	                if (!(c[j >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                if (!(c[(c[j >> 2] | 0) + 8 >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                if (!(c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + 76 >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                Db[c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + 76 >> 2] & 511](c[(c[j >> 2] | 0) + 16 >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0);
	                i = e;
	                return
	            }

	            function dC(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[g >> 2] = c[e >> 2];
	                if (!(c[g >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if (!(c[(c[g >> 2] | 0) + 8 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if (!(c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 80 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                Ab[c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 80 >> 2] & 511](c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[f >> 2] | 0);
	                i = d;
	                return
	            }

	            function eC(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 16 | 0;
	                g = d + 8 | 0;
	                c[f >> 2] = a;
	                c[d + 12 >> 2] = b;
	                c[g >> 2] = c[f >> 2];
	                if (!(c[g >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if (!(c[(c[g >> 2] | 0) + 8 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if (!(c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 84 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                g = c[33976] | 0;
	                f = c[33980] | 0;
	                c[e >> 2] = 140328;
	                c[e + 4 >> 2] = 28421;
	                Db[g & 511](f, 140296, e);
	                i = d;
	                return
	            }

	            function fC(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 16 | 0;
	                g = d + 8 | 0;
	                c[f >> 2] = a;
	                c[d + 12 >> 2] = b;
	                c[g >> 2] = c[f >> 2];
	                if (!(c[g >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if (!(c[(c[g >> 2] | 0) + 8 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if (!(c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 88 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                g = c[33976] | 0;
	                f = c[33980] | 0;
	                c[e >> 2] = 140328;
	                c[e + 4 >> 2] = 28429;
	                Db[g & 511](f, 140296, e);
	                i = d;
	                return
	            }

	            function gC(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 16 | 0;
	                g = d + 8 | 0;
	                c[f >> 2] = a;
	                c[d + 12 >> 2] = b;
	                c[g >> 2] = c[f >> 2];
	                if (!(c[g >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if (!(c[(c[g >> 2] | 0) + 8 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if (!(c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 92 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                g = c[33976] | 0;
	                f = c[33980] | 0;
	                c[e >> 2] = 140328;
	                c[e + 4 >> 2] = 28437;
	                Db[g & 511](f, 140296, e);
	                i = d;
	                return
	            }

	            function hC(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = c[f >> 2];
	                if (((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (c[(c[(c[h >> 2] | 0) + 8 >> 2] | 0) + 96 >> 2] | 0) != 0 : 0) {
	                    c[e >> 2] = Hb[c[(c[(c[h >> 2] | 0) + 8 >> 2] | 0) + 96 >> 2] & 511](c[(c[h >> 2] | 0) + 16 >> 2] | 0, c[g >> 2] | 0) | 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[e >> 2] = 0;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function iC(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[l >> 2] = c[g >> 2];
	                if (!(c[l >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                if (!(c[(c[l >> 2] | 0) + 8 >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                if (!(c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 104 >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                Jb[c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 104 >> 2] & 511](c[(c[l >> 2] | 0) + 16 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0);
	                i = f;
	                return
	            }

	            function jC(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = c[f >> 2];
	                if (!(c[j >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                if ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) != 0 ? (c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + 68 >> 2] | 0) != 0 : 0)Db[c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + 68 >> 2] & 511](c[(c[j >> 2] | 0) + 16 >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0);
	                if (!(c[(c[j >> 2] | 0) + 148 >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                NB(c[(c[j >> 2] | 0) + 148 >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0);
	                i = e;
	                return
	            }

	            function kC(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = c[f >> 2];
	                if (!(c[j >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                if ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) != 0 ? (c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + 72 >> 2] | 0) != 0 : 0)Db[c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + 72 >> 2] & 511](c[(c[j >> 2] | 0) + 16 >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0);
	                if (!(c[(c[j >> 2] | 0) + 148 >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                NB(c[(c[j >> 2] | 0) + 148 >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0);
	                i = e;
	                return
	            }

	            function lC(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = c[f >> 2];
	                if (!(c[j >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                if ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) != 0 ? (c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + 100 >> 2] | 0) != 0 : 0)Db[c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + 100 >> 2] & 511](c[(c[j >> 2] | 0) + 16 >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0);
	                if (!(c[(c[j >> 2] | 0) + 148 >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                OB(c[(c[j >> 2] | 0) + 148 >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0);
	                i = e;
	                return
	            }

	            function mC(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[g >> 2] = c[e >> 2];
	                if (!(c[g >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if (((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 64 >> 2] | 0) != 0 : 0)Ab[c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 64 >> 2] & 511](c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[f >> 2] | 0);
	                if (!(c[(c[g >> 2] | 0) + 148 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                PB(c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[f >> 2] | 0);
	                i = d;
	                return
	            }

	            function nC(a, b, d, e, f, g, h, j, k) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                k = k | 0;
	                var l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                l = i;
	                i = i + 48 | 0;
	                m = l + 36 | 0;
	                n = l + 32 | 0;
	                o = l + 28 | 0;
	                p = l + 24 | 0;
	                q = l + 20 | 0;
	                r = l + 16 | 0;
	                s = l + 12 | 0;
	                t = l + 8 | 0;
	                u = l + 4 | 0;
	                v = l;
	                c[m >> 2] = a;
	                c[n >> 2] = b;
	                c[o >> 2] = d;
	                c[p >> 2] = e;
	                c[q >> 2] = f;
	                c[r >> 2] = g;
	                c[s >> 2] = h;
	                c[t >> 2] = j;
	                c[u >> 2] = k;
	                c[v >> 2] = c[m >> 2];
	                if (!(c[v >> 2] | 0)) {
	                    i = l;
	                    return
	                }
	                if ((c[(c[v >> 2] | 0) + 8 >> 2] | 0) != 0 ? (c[(c[(c[v >> 2] | 0) + 8 >> 2] | 0) + 116 >> 2] | 0) != 0 : 0)Eb[c[(c[(c[v >> 2] | 0) + 8 >> 2] | 0) + 116 >> 2] & 511](c[(c[v >> 2] | 0) + 16 >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0, c[r >> 2] | 0, c[s >> 2] | 0, c[t >> 2] | 0, c[u >> 2] | 0);
	                if (!(c[(c[v >> 2] | 0) + 148 >> 2] | 0)) {
	                    i = l;
	                    return
	                }
	                LB(c[(c[v >> 2] | 0) + 148 >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0, c[r >> 2] | 0, c[s >> 2] | 0, c[t >> 2] | 0, c[u >> 2] | 0);
	                i = l;
	                return
	            }

	            function oC(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[l >> 2] = c[g >> 2];
	                if (!(c[l >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                if ((c[(c[l >> 2] | 0) + 8 >> 2] | 0) != 0 ? (c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 120 >> 2] | 0) != 0 : 0)Jb[c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 120 >> 2] & 511](c[(c[l >> 2] | 0) + 16 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0);
	                if (!(c[(c[l >> 2] | 0) + 148 >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                MB(c[(c[l >> 2] | 0) + 148 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0);
	                i = f;
	                return
	            }

	            function pC(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[(c[e >> 2] | 0) + 52 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 56 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 96 >> 2] = -1;
	                c[(c[e >> 2] | 0) + 176 >> 2] = -1;
	                c[(c[e >> 2] | 0) + 92 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 184 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 188 >> 2] = 0;
	                do if (!(c[(c[e >> 2] | 0) + 20 >> 2] | 0)) {
	                    c[(c[e >> 2] | 0) + 92 >> 2] = 1;
	                    if ((c[(c[e >> 2] | 0) + 88 >> 2] | 0) == 0 ? (zD(c[e >> 2] | 0) | 0) == -1 : 0) {
	                        c[d >> 2] = -1;
	                        g = c[d >> 2] | 0;
	                        i = b;
	                        return g | 0
	                    }
	                    c[f >> 2] = c[(c[e >> 2] | 0) + 88 >> 2];
	                    c[(c[f >> 2] | 0) + 104 >> 2] = 1;
	                    a = DB(c[f >> 2] | 0) | 0;
	                    c[(c[e >> 2] | 0) + 20 >> 2] = a;
	                    if (!(c[(c[e >> 2] | 0) + 20 >> 2] | 0)) {
	                        c[d >> 2] = -1;
	                        g = c[d >> 2] | 0;
	                        i = b;
	                        return g | 0
	                    }
	                    a = EB(c[(c[f >> 2] | 0) + 80 >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 28 >> 2] = a;
	                    if (c[(c[f >> 2] | 0) + 28 >> 2] | 0) {
	                        c[c[(c[f >> 2] | 0) + 28 >> 2] >> 2] = c[(c[e >> 2] | 0) + 20 >> 2];
	                        c[(c[f >> 2] | 0) + 32 >> 2] = 1;
	                        break
	                    }
	                    c[d >> 2] = -1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } while (0);
	                Wj(c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 48 >> 2] | 0, 357, c[e >> 2] | 0);
	                c[d >> 2] = 0;
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function qC(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[(c[d >> 2] | 0) + 92 >> 2] | 0) != 0 ? (c[(c[d >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) {
	                    WA(c[(c[d >> 2] | 0) + 20 >> 2] | 0);
	                    c[(c[d >> 2] | 0) + 20 >> 2] = 0
	                }
	                BD(c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function rC(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if ((c[g >> 2] | 0) != 0 ? !((c[h >> 2] | 0) == 0 & (c[j >> 2] | 0) == 0) : 0) {
	                    if (c[h >> 2] | 0)c[c[h >> 2] >> 2] = 0;
	                    if (c[j >> 2] | 0)c[c[j >> 2] >> 2] = 0;
	                    c[k >> 2] = c[g >> 2];
	                    if (!(c[(c[k >> 2] | 0) + 36 >> 2] | 0)) {
	                        c[f >> 2] = -1;
	                        l = c[f >> 2] | 0;
	                        i = e;
	                        return l | 0
	                    }
	                    if (c[h >> 2] | 0)c[c[h >> 2] >> 2] = c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2];
	                    if (c[j >> 2] | 0)c[c[j >> 2] >> 2] = c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2];
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[f >> 2] = -1;
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function sC(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (!(c[(c[d >> 2] | 0) + 4 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                c[f >> 2] = c[c[d >> 2] >> 2];
	                c[g >> 2] = 0;
	                while (1) {
	                    if ((c[g >> 2] | 0) >= (c[(c[d >> 2] | 0) + 4 >> 2] | 0))break;
	                    c[e >> 2] = c[(c[f >> 2] | 0) + (c[g >> 2] << 2) >> 2];
	                    a:do if (c[e >> 2] | 0)do switch (c[c[e >> 2] >> 2] | 0) {
	                        case 18:
	                        {
	                            KD(c[e >> 2] | 0);
	                            break a;
	                            break
	                        }
	                        case 26:
	                        {
	                            DD(c[e >> 2] | 0);
	                            break a;
	                            break
	                        }
	                        case 8:
	                        case 7:
	                        case 6:
	                        {
	                            GD(c[e >> 2] | 0);
	                            break a;
	                            break
	                        }
	                        case 14:
	                        {
	                            FD(c[e >> 2] | 0);
	                            break a;
	                            break
	                        }
	                        case 2e3:
	                        {
	                            LD(c[e >> 2] | 0);
	                            break a;
	                            break
	                        }
	                        case 25:
	                        {
	                            if (c[(c[e >> 2] | 0) + 4 >> 2] | 0)mB(c[(c[e >> 2] | 0) + 4 >> 2] | 0);
	                            zb[c[135736 >> 2] & 511](c[e >> 2] | 0);
	                            break a;
	                            break
	                        }
	                        case 5:
	                        case 4:
	                        {
	                            VA(c[e >> 2] | 0);
	                            break a;
	                            break
	                        }
	                        case 15:
	                        {
	                            CD(c[e >> 2] | 0);
	                            break a;
	                            break
	                        }
	                        case 17:
	                        {
	                            ID(c[e >> 2] | 0);
	                            break a;
	                            break
	                        }
	                        case 16:
	                        {
	                            HD(c[e >> 2] | 0);
	                            break a;
	                            break
	                        }
	                        case 2001:
	                        {
	                            ED(c[e >> 2] | 0);
	                            break a;
	                            break
	                        }
	                        case 24:
	                        case 22:
	                        case 23:
	                        {
	                            JD(c[e >> 2] | 0);
	                            break a;
	                            break
	                        }
	                        case 21:
	                        case 2:
	                        {
	                            TA(c[e >> 2] | 0);
	                            break a;
	                            break
	                        }
	                        default:
	                        {
	                            ND(0, 170280, MD(c[e >> 2] | 0) | 0);
	                            break a
	                        }
	                    } while (0); while (0);
	                    c[g >> 2] = (c[g >> 2] | 0) + 1
	                }
	                c[(c[d >> 2] | 0) + 4 >> 2] = 0;
	                i = b;
	                return
	            }

	            function tC(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if (c[f >> 2] | 0) {
	                    d = (c[f >> 2] | 0) + 20 | 0;
	                    c[d >> 2] = (c[d >> 2] | 0) + 1
	                }
	                ce(16, 2, c[h >> 2] | 0, 0, c[g >> 2] | 0);
	                i = e;
	                return
	            }

	            function uC(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 4 >> 2] | 0)oB(c[(c[d >> 2] | 0) + 4 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function vC(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                while (1) {
	                    if (!(c[d >> 2] | 0))break;
	                    c[e >> 2] = c[d >> 2];
	                    c[d >> 2] = c[c[d >> 2] >> 2];
	                    zb[c[135736 >> 2] & 511](c[e >> 2] | 0)
	                }
	                i = b;
	                return
	            }

	            function wC(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                while (1) {
	                    if (!(c[f >> 2] | 0))break;
	                    c[g >> 2] = c[(c[f >> 2] | 0) + 8 >> 2];
	                    a:do if (c[(c[f >> 2] | 0) + 24 >> 2] | 0) {
	                        c[h >> 2] = 0;
	                        while (1) {
	                            if ((c[h >> 2] | 0) >= (c[(c[f >> 2] | 0) + 28 >> 2] | 0))break a;
	                            if (c[(c[(c[f >> 2] | 0) + 24 >> 2] | 0) + (c[h >> 2] << 2) >> 2] | 0) {
	                                zb[c[135736 >> 2] & 511](c[(c[(c[f >> 2] | 0) + 24 >> 2] | 0) + (c[h >> 2] << 2) >> 2] | 0);
	                                c[(c[(c[f >> 2] | 0) + 24 >> 2] | 0) + (c[h >> 2] << 2) >> 2] = 0
	                            }
	                            c[h >> 2] = (c[h >> 2] | 0) + 1
	                        }
	                    } while (0);
	                    if (c[(c[f >> 2] | 0) + 32 >> 2] | 0) {
	                        b:do if ((c[(c[f >> 2] | 0) + 20 >> 2] | 0) == 24) {
	                            c[j >> 2] = 0;
	                            while (1) {
	                                if ((c[j >> 2] | 0) >= (c[(c[(c[f >> 2] | 0) + 32 >> 2] | 0) + 4 >> 2] | 0))break b;
	                                c[k >> 2] = c[(c[c[(c[f >> 2] | 0) + 32 >> 2] >> 2] | 0) + (c[j >> 2] << 2) >> 2];
	                                zb[c[135736 >> 2] & 511](c[(c[k >> 2] | 0) + 4 >> 2] | 0);
	                                zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                                c[j >> 2] = (c[j >> 2] | 0) + 1
	                            }
	                        } while (0);
	                        oB(c[(c[f >> 2] | 0) + 32 >> 2] | 0);
	                        c[(c[f >> 2] | 0) + 32 >> 2] = 0
	                    }
	                    c[(c[f >> 2] | 0) + 8 >> 2] = 0;
	                    if (c[(c[e >> 2] | 0) + 124 >> 2] | 0)c[(c[f >> 2] | 0) + 12 >> 2] = c[(c[e >> 2] | 0) + 124 >> 2];
	                    c[(c[e >> 2] | 0) + 124 >> 2] = c[f >> 2];
	                    c[f >> 2] = c[g >> 2]
	                }
	                i = d;
	                return
	            }

	            function xC(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                while (1) {
	                    if (!(c[d >> 2] | 0))break;
	                    c[e >> 2] = c[d >> 2];
	                    c[d >> 2] = c[c[d >> 2] >> 2];
	                    OD(c[e >> 2] | 0)
	                }
	                i = b;
	                return
	            }

	            function yC(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 20 | 0;
	                j = g + 16 | 0;
	                k = g + 12 | 0;
	                l = g + 8 | 0;
	                m = g + 4 | 0;
	                n = g;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                c[n >> 2] = 0;
	                if (!(c[h >> 2] | 0)) {
	                    i = g;
	                    return
	                }
	                c[n >> 2] = my(158256) | 0;
	                c[n >> 2] = By(c[n >> 2] | 0, c[j >> 2] | 0) | 0;
	                c[n >> 2] = By(c[n >> 2] | 0, 144448) | 0;
	                c[n >> 2] = By(c[n >> 2] | 0, c[k >> 2] | 0) | 0;
	                c[n >> 2] = By(c[n >> 2] | 0, 142704) | 0;
	                k = c[h >> 2] | 0;
	                if ((c[c[h >> 2] >> 2] | 0) != 2) {
	                    if ((c[k >> 2] | 0) == 1)PD(c[h >> 2] | 0, 3069, 0, c[n >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0)
	                } else PD(k, 1818, 0, c[n >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0);
	                if (!(c[n >> 2] | 0)) {
	                    i = g;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                c[n >> 2] = 0;
	                i = g;
	                return
	            }

	            function zC(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                b = QD(c[f >> 2] | 0) | 0;
	                if ((b | 0) == 3)c[e >> 2] = SH(c[g >> 2] | 0) | 0; else if ((b | 0) == 2)c[e >> 2] = RH(c[g >> 2] | 0) | 0; else c[e >> 2] = 0;
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function AC(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h + 44 | 0;
	                k = h + 40 | 0;
	                l = h + 36 | 0;
	                m = h + 32 | 0;
	                n = h + 28 | 0;
	                o = h + 24 | 0;
	                p = h + 20 | 0;
	                q = h + 16 | 0;
	                r = h + 12 | 0;
	                s = h + 8 | 0;
	                t = h + 4 | 0;
	                u = h;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                if ((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 20 >> 2] | 0) == 0 : 0) {
	                    xB(c[k >> 2] | 0, 157712, 157744);
	                    c[j >> 2] = -1;
	                    v = c[j >> 2] | 0;
	                    i = h;
	                    return v | 0
	                }
	                c[q >> 2] = Fh(c[n >> 2] | 0, 1) | 0;
	                if (c[q >> 2] | 0) {
	                    c[j >> 2] = c[q >> 2];
	                    v = c[j >> 2] | 0;
	                    i = h;
	                    return v | 0
	                }
	                c[r >> 2] = 0;
	                c[s >> 2] = 0;
	                c[r >> 2] = Ch(c[n >> 2] | 0, s) | 0;
	                if (!(c[s >> 2] | 0)) {
	                    if (!(SD(c[l >> 2] | 0, c[n >> 2] | 0, 0) | 0)) {
	                        c[j >> 2] = 1;
	                        v = c[j >> 2] | 0;
	                        i = h;
	                        return v | 0
	                    }
	                    if ((c[p >> 2] | 0) != 0 & (c[o >> 2] | 0) != 0 ? (g = NH(my(c[n >> 2] | 0) | 0, 0) | 0, c[c[o >> 2] >> 2] = g, (c[c[o >> 2] >> 2] | 0) == 0) : 0)c[q >> 2] = -1
	                } else {
	                    c[t >> 2] = 0;
	                    do if (!(c[k >> 2] | 0))if (c[m >> 2] | 0) {
	                        c[u >> 2] = cj(c[(c[m >> 2] | 0) + 32 >> 2] | 0, c[m >> 2] | 0, c[s >> 2] | 0) | 0;
	                        if (!(c[u >> 2] | 0))break;
	                        c[t >> 2] = c[(c[u >> 2] | 0) + 8 >> 2];
	                        break
	                    } else {
	                        zb[c[135736 >> 2] & 511](c[s >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                        c[j >> 2] = 1;
	                        v = c[j >> 2] | 0;
	                        i = h;
	                        return v | 0
	                    } else c[t >> 2] = RD(c[k >> 2] | 0, c[s >> 2] | 0) | 0; while (0);
	                    if (!(c[t >> 2] | 0)) {
	                        zb[c[135736 >> 2] & 511](c[s >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                        c[j >> 2] = 1;
	                        v = c[j >> 2] | 0;
	                        i = h;
	                        return v | 0
	                    }
	                    if (SD(c[l >> 2] | 0, c[r >> 2] | 0, c[t >> 2] | 0) | 0) {
	                        if ((c[p >> 2] | 0) != 0 & (c[o >> 2] | 0) != 0 ? (p = my(c[r >> 2] | 0) | 0, l = NH(p, my(c[t >> 2] | 0) | 0) | 0, c[c[o >> 2] >> 2] = l, (c[c[o >> 2] >> 2] | 0) == 0) : 0)c[q >> 2] = -1
	                    } else c[q >> 2] = 1;
	                    zb[c[135736 >> 2] & 511](c[s >> 2] | 0);
	                    zb[c[135736 >> 2] & 511](c[r >> 2] | 0)
	                }
	                c[j >> 2] = c[q >> 2];
	                v = c[j >> 2] | 0;
	                i = h;
	                return v | 0
	            }

	            function BC(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f + 32 | 0;
	                h = f + 28 | 0;
	                j = f + 24 | 0;
	                k = f + 20 | 0;
	                l = f + 16 | 0;
	                m = f + 12 | 0;
	                n = f + 8 | 0;
	                o = f + 4 | 0;
	                p = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[p >> 2] = 0;
	                c[m >> 2] = Fh(c[j >> 2] | 0, 1) | 0;
	                if (c[m >> 2] | 0)if ((c[m >> 2] | 0) == -1) {
	                    xB(c[h >> 2] | 0, 157656, 157680);
	                    c[g >> 2] = -1;
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                } else {
	                    c[g >> 2] = 1824;
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                c[o >> 2] = Ch(c[j >> 2] | 0, p) | 0;
	                if (!(c[o >> 2] | 0))c[o >> 2] = my(c[j >> 2] | 0) | 0;
	                c[n >> 2] = RD(c[h >> 2] | 0, c[p >> 2] | 0) | 0;
	                if ((c[p >> 2] | 0) != 0 ? (zb[c[135736 >> 2] & 511](c[p >> 2] | 0), (c[n >> 2] | 0) == 0) : 0) {
	                    c[m >> 2] = 1824;
	                    p = c[h >> 2] | 0;
	                    h = c[m >> 2] | 0;
	                    e = IH(21) | 0;
	                    AB(p, h, 0, e, 154112, c[j >> 2] | 0, 0);
	                    if (c[o >> 2] | 0)zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                    c[g >> 2] = c[m >> 2];
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                do if ((c[l >> 2] | 0) != 0 & (c[k >> 2] | 0) != 0)if (c[n >> 2] | 0) {
	                    m = my(c[n >> 2] | 0) | 0;
	                    j = OH(m, c[o >> 2] | 0) | 0;
	                    c[c[k >> 2] >> 2] = j;
	                    break
	                } else {
	                    j = OH(0, c[o >> 2] | 0) | 0;
	                    c[c[k >> 2] >> 2] = j;
	                    break
	                } else zb[c[135736 >> 2] & 511](c[o >> 2] | 0); while (0);
	                c[g >> 2] = 0;
	                q = c[g >> 2] | 0;
	                i = f;
	                return q | 0
	            }

	            function CC(a, b, d, e, f, g, h, j) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                var k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0;
	                k = i;
	                i = i + 80 | 0;
	                l = k + 68 | 0;
	                m = k + 64 | 0;
	                n = k + 60 | 0;
	                o = k + 56 | 0;
	                p = k + 52 | 0;
	                q = k + 48 | 0;
	                r = k + 44 | 0;
	                s = k + 40 | 0;
	                t = k + 36 | 0;
	                u = k + 32 | 0;
	                v = k + 28 | 0;
	                w = k + 24 | 0;
	                x = k + 20 | 0;
	                y = k + 16 | 0;
	                z = k + 12 | 0;
	                A = k + 8 | 0;
	                B = k + 4 | 0;
	                C = k;
	                c[m >> 2] = a;
	                c[n >> 2] = b;
	                c[o >> 2] = d;
	                c[p >> 2] = e;
	                c[q >> 2] = f;
	                c[r >> 2] = g;
	                c[s >> 2] = h;
	                c[t >> 2] = j;
	                c[v >> 2] = 0;
	                c[z >> 2] = 0;
	                if ((c[c[o >> 2] >> 2] | 0) == 1) {
	                    c[l >> 2] = 0;
	                    D = c[l >> 2] | 0;
	                    i = k;
	                    return D | 0
	                }
	                a:do if (c[(c[o >> 2] | 0) + 96 >> 2] | 0) {
	                    j = c[o >> 2] | 0;
	                    b:do if (c[(c[o >> 2] | 0) + 48 >> 2] & 256) {
	                        c[w >> 2] = TD(j) | 0;
	                        do if ((c[(c[w >> 2] | 0) + 88 >> 2] | 0) == 1)E = 9; else {
	                            if ((c[c[w >> 2] >> 2] | 0) == 1 ? (c[(c[w >> 2] | 0) + 88 >> 2] | 0) == 46 : 0) {
	                                E = 9;
	                                break
	                            }
	                            c[A >> 2] = 3
	                        } while (0);
	                        if ((E | 0) == 9)c[A >> 2] = QD(c[o >> 2] | 0) | 0;
	                        if (!(c[r >> 2] | 0))c[p >> 2] = c[p >> 2]; else c[p >> 2] = dI(c[r >> 2] | 0) | 0;
	                        c[u >> 2] = 0;
	                        c[x >> 2] = c[(c[o >> 2] | 0) + 96 >> 2];
	                        while (1) {
	                            if (!(c[x >> 2] | 0))break b;
	                            switch (c[c[(c[x >> 2] | 0) + 4 >> 2] >> 2] | 0) {
	                                case 1010:
	                                case 1011:
	                                case 1009:
	                                {
	                                    c[u >> 2] = aI(c[(c[x >> 2] | 0) + 4 >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0, c[r >> 2] | 0, z, c[A >> 2] | 0) | 0;
	                                    E = 19;
	                                    break
	                                }
	                                case 1007:
	                                case 1006:
	                                case 1008:
	                                    break;
	                                default:
	                                {
	                                    c[u >> 2] = bI(c[(c[x >> 2] | 0) + 4 >> 2] | 0, c[A >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0, c[r >> 2] | 0, c[A >> 2] | 0) | 0;
	                                    E = 19
	                                }
	                            }
	                            if ((E | 0) == 19) {
	                                E = 0;
	                                if ((c[u >> 2] | 0) < 0) {
	                                    E = 20;
	                                    break
	                                }
	                                if ((c[u >> 2] | 0) > 0) {
	                                    if (!(c[t >> 2] | 0)) {
	                                        E = 24;
	                                        break
	                                    }
	                                    UD(c[m >> 2] | 0, c[u >> 2] | 0, c[n >> 2] | 0, c[q >> 2] | 0, c[z >> 2] | 0, c[o >> 2] | 0, c[(c[x >> 2] | 0) + 4 >> 2] | 0, 0, 0, 0);
	                                    if (!(c[v >> 2] | 0))c[v >> 2] = c[u >> 2]
	                                }
	                                c[u >> 2] = 0
	                            }
	                            c[x >> 2] = c[c[x >> 2] >> 2]
	                        }
	                        if ((E | 0) == 20) {
	                            xB(c[m >> 2] | 0, 156584, 156608);
	                            c[l >> 2] = -1;
	                            D = c[l >> 2] | 0;
	                            i = k;
	                            return D | 0
	                        } else if ((E | 0) == 24) {
	                            c[l >> 2] = c[u >> 2];
	                            D = c[l >> 2] | 0;
	                            i = k;
	                            return D | 0
	                        }
	                    } else if (!(c[j + 48 >> 2] & 64))break a; while (0);
	                    if (c[(c[o >> 2] | 0) + 48 >> 2] & 64) {
	                        c[u >> 2] = 0;
	                        c[x >> 2] = c[(c[o >> 2] | 0) + 96 >> 2];
	                        while (1) {
	                            if (!(c[x >> 2] | 0))break a;
	                            if (((c[c[(c[x >> 2] | 0) + 4 >> 2] >> 2] | 0) + -1009 | 0) >>> 0 < 3) {
	                                c[u >> 2] = _H(c[(c[x >> 2] | 0) + 4 >> 2] | 0, c[q >> 2] | 0, c[s >> 2] | 0, 0) | 0;
	                                if ((c[u >> 2] | 0) < 0) {
	                                    E = 33;
	                                    break
	                                }
	                                if ((c[u >> 2] | 0) > 0) {
	                                    if (!(c[t >> 2] | 0)) {
	                                        E = 37;
	                                        break
	                                    }
	                                    UD(c[m >> 2] | 0, c[u >> 2] | 0, c[n >> 2] | 0, c[q >> 2] | 0, c[s >> 2] | 0, c[o >> 2] | 0, c[(c[x >> 2] | 0) + 4 >> 2] | 0, 0, 0, 0);
	                                    if (!(c[v >> 2] | 0))c[v >> 2] = c[u >> 2]
	                                }
	                                c[u >> 2] = 0
	                            }
	                            c[x >> 2] = c[c[x >> 2] >> 2]
	                        }
	                        if ((E | 0) == 33) {
	                            xB(c[m >> 2] | 0, 156584, 156648);
	                            c[l >> 2] = -1;
	                            D = c[l >> 2] | 0;
	                            i = k;
	                            return D | 0
	                        } else if ((E | 0) == 37) {
	                            c[l >> 2] = c[u >> 2];
	                            D = c[l >> 2] | 0;
	                            i = k;
	                            return D | 0
	                        }
	                    }
	                } while (0);
	                do if ((c[v >> 2] | 0) >= 0) {
	                    c[B >> 2] = 0;
	                    c[u >> 2] = 0;
	                    c[w >> 2] = c[o >> 2];
	                    c:do {
	                        c[y >> 2] = c[(c[w >> 2] | 0) + 68 >> 2];
	                        while (1) {
	                            if (!(c[y >> 2] | 0))break;
	                            if ((c[c[y >> 2] >> 2] | 0) == 1007) {
	                                c[B >> 2] = 1;
	                                c[u >> 2] = VD(c[(c[y >> 2] | 0) + 32 >> 2] | 0, c[r >> 2] | 0) | 0;
	                                if ((c[u >> 2] | 0) == 1)break;
	                                if ((c[u >> 2] | 0) < 0) {
	                                    E = 48;
	                                    break c
	                                }
	                            }
	                            c[y >> 2] = c[(c[y >> 2] | 0) + 4 >> 2]
	                        }
	                        if ((c[u >> 2] | 0) != 0 | (c[B >> 2] | 0) != 0)break;
	                        c[w >> 2] = c[(c[w >> 2] | 0) + 64 >> 2];
	                        if (!(c[w >> 2] | 0))break
	                    } while ((c[c[w >> 2] >> 2] | 0) != 1);
	                    if ((E | 0) == 48) {
	                        xB(c[m >> 2] | 0, 156584, 156688);
	                        c[l >> 2] = -1;
	                        D = c[l >> 2] | 0;
	                        i = k;
	                        return D | 0
	                    }
	                    if ((c[B >> 2] | 0) != 0 & (c[u >> 2] | 0) == 0) {
	                        c[u >> 2] = 1840;
	                        if (c[t >> 2] | 0) {
	                            UD(c[m >> 2] | 0, c[u >> 2] | 0, c[n >> 2] | 0, c[q >> 2] | 0, 0, c[o >> 2] | 0, 0, 0, 0, 0);
	                            if (c[v >> 2] | 0)break;
	                            c[v >> 2] = c[u >> 2];
	                            break
	                        } else {
	                            c[l >> 2] = c[u >> 2];
	                            D = c[l >> 2] | 0;
	                            i = k;
	                            return D | 0
	                        }
	                    }
	                } while (0);
	                d:do if ((c[v >> 2] | 0) >= 0) {
	                    c[w >> 2] = c[o >> 2];
	                    c[y >> 2] = 0;
	                    e:while (1) {
	                        c[C >> 2] = 0;
	                        c[x >> 2] = c[(c[w >> 2] | 0) + 96 >> 2];
	                        while (1) {
	                            if (!(c[x >> 2] | 0))break;
	                            if ((c[c[(c[x >> 2] | 0) + 4 >> 2] >> 2] | 0) == 1006) {
	                                c[C >> 2] = 1;
	                                c[u >> 2] = vz(c[(c[(c[x >> 2] | 0) + 4 >> 2] | 0) + 36 >> 2] | 0, c[q >> 2] | 0) | 0;
	                                if ((c[u >> 2] | 0) == 1)break;
	                                if ((c[u >> 2] | 0) < 0) {
	                                    E = 65;
	                                    break e
	                                }
	                                c[y >> 2] = c[(c[x >> 2] | 0) + 4 >> 2]
	                            }
	                            c[x >> 2] = c[c[x >> 2] >> 2]
	                        }
	                        if ((c[C >> 2] | 0) != 0 & (c[u >> 2] | 0) != 1)break;
	                        c[w >> 2] = c[(c[w >> 2] | 0) + 64 >> 2];
	                        if (!(c[w >> 2] | 0))break d;
	                        if ((c[c[w >> 2] >> 2] | 0) == 1)break d
	                    }
	                    if ((E | 0) == 65) {
	                        xB(c[m >> 2] | 0, 156584, 156728);
	                        c[l >> 2] = -1;
	                        D = c[l >> 2] | 0;
	                        i = k;
	                        return D | 0
	                    }
	                    c[u >> 2] = 1839;
	                    if (c[t >> 2] | 0) {
	                        UD(c[m >> 2] | 0, c[u >> 2] | 0, c[n >> 2] | 0, c[q >> 2] | 0, 0, c[o >> 2] | 0, c[y >> 2] | 0, 0, 0, 0);
	                        if (c[v >> 2] | 0)break;
	                        c[v >> 2] = c[u >> 2];
	                        break
	                    } else {
	                        c[l >> 2] = c[u >> 2];
	                        D = c[l >> 2] | 0;
	                        i = k;
	                        return D | 0
	                    }
	                } while (0);
	                c[l >> 2] = c[v >> 2];
	                D = c[l >> 2] | 0;
	                i = k;
	                return D | 0
	            }

	            function DC(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                h = i;
	                i = i + 32 | 0;
	                j = h + 28 | 0;
	                k = h + 24 | 0;
	                l = h + 20 | 0;
	                m = h + 16 | 0;
	                n = h + 12 | 0;
	                o = h + 8 | 0;
	                p = h + 4 | 0;
	                q = h;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                c[p >> 2] = 0;
	                HC(p, c[j >> 2] | 0, c[l >> 2] | 0) | 0;
	                if ((c[o >> 2] | 0) == 0 ? (WD(c[j >> 2] | 0, c[l >> 2] | 0) | 0) != 2 : 0)c[p >> 2] = By(c[p >> 2] | 0, 154288) | 0; else c[p >> 2] = By(c[p >> 2] | 0, 154256) | 0;
	                g = (XD(c[n >> 2] | 0) | 0) != 0;
	                f = c[p >> 2] | 0;
	                if (g)c[p >> 2] = By(f, 154352) | 0; else c[p >> 2] = By(f, 154336) | 0;
	                do if (!(c[(c[n >> 2] | 0) + 48 >> 2] & 256)) {
	                    if (c[(c[n >> 2] | 0) + 48 >> 2] & 64) {
	                        c[p >> 2] = By(c[p >> 2] | 0, 147936) | 0;
	                        break
	                    }
	                    if (c[(c[n >> 2] | 0) + 48 >> 2] & 128)c[p >> 2] = By(c[p >> 2] | 0, 147952) | 0
	                } else c[p >> 2] = By(c[p >> 2] | 0, 147920) | 0; while (0);
	                if (XD(c[n >> 2] | 0) | 0) {
	                    c[q >> 2] = 0;
	                    c[p >> 2] = By(c[p >> 2] | 0, 143656) | 0;
	                    f = c[p >> 2] | 0;
	                    if (c[(c[n >> 2] | 0) + 88 >> 2] | 0) {
	                        c[p >> 2] = By(f, 154360) | 0;
	                        c[p >> 2] = By(c[p >> 2] | 0, c[(c[n >> 2] | 0) + 8 >> 2] | 0) | 0
	                    } else c[p >> 2] = By(f, BB(q, c[(c[n >> 2] | 0) + 112 >> 2] | 0, c[(c[n >> 2] | 0) + 8 >> 2] | 0) | 0) | 0;
	                    c[p >> 2] = By(c[p >> 2] | 0, 142568) | 0;
	                    if (c[q >> 2] | 0) {
	                        zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                        c[q >> 2] = 0
	                    }
	                }
	                c[p >> 2] = By(c[p >> 2] | 0, 142704) | 0;
	                if ((c[o >> 2] | 0) == 0 ? (WD(c[j >> 2] | 0, c[l >> 2] | 0) | 0) != 2 : 0)PD(c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[p >> 2] | 0, 0, 0); else PD(c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[p >> 2] | 0, c[m >> 2] | 0, 0);
	                if (!(c[p >> 2] | 0)) {
	                    i = h;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                c[p >> 2] = 0;
	                i = h;
	                return
	            }

	            function EC(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                while (1) {
	                    if (!(c[e >> 2] | 0)) {
	                        f = 7;
	                        break
	                    }
	                    if ((c[c[e >> 2] >> 2] | 0) != 4) {
	                        f = 7;
	                        break
	                    }
	                    g = c[e >> 2] | 0;
	                    if (c[(c[e >> 2] | 0) + 92 >> 2] | 0) {
	                        f = 5;
	                        break
	                    }
	                    c[e >> 2] = c[g + 64 >> 2]
	                }
	                if ((f | 0) == 5) {
	                    c[d >> 2] = c[g + 92 >> 2];
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                } else if ((f | 0) == 7) {
	                    c[d >> 2] = 0;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                return 0
	            }

	            function FC(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                do switch (c[c[e >> 2] >> 2] | 0) {
	                    case 21:
	                    case 2:
	                    {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 12 >> 2];
	                        break
	                    }
	                    case 15:
	                    {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 52 >> 2];
	                        break
	                    }
	                    case 16:
	                    {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 32 >> 2];
	                        break
	                    }
	                    case 2e3:
	                    {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 20 >> 2];
	                        break
	                    }
	                    case 24:
	                    case 23:
	                    case 22:
	                    {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 12 >> 2];
	                        break
	                    }
	                    case 8:
	                    case 7:
	                    case 6:
	                    {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 16 >> 2];
	                        break
	                    }
	                    case 25:
	                    {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 24 >> 2];
	                        break
	                    }
	                    case 26:
	                    {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 20 >> 2];
	                        break
	                    }
	                    case 17:
	                    {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 24 >> 2];
	                        break
	                    }
	                    case 4:
	                    case 5:
	                    {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 36 >> 2];
	                        break
	                    }
	                    case 14:
	                    {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 36 >> 2];
	                        break
	                    }
	                    default:
	                        c[d >> 2] = 0
	                } while (0);
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function GC(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                f = i;
	                i = i + 64 | 0;
	                g = f + 48 | 0;
	                h = f + 44 | 0;
	                j = f + 40 | 0;
	                k = f + 36 | 0;
	                l = f + 32 | 0;
	                m = f + 28 | 0;
	                n = f + 24 | 0;
	                o = f + 20 | 0;
	                p = f + 16 | 0;
	                q = f + 12 | 0;
	                r = f + 8 | 0;
	                s = f + 4 | 0;
	                t = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[l >> 2] = 0;
	                c[m >> 2] = 1;
	                if (c[c[g >> 2] >> 2] | 0) {
	                    zb[c[135736 >> 2] & 511](c[c[g >> 2] >> 2] | 0);
	                    c[c[g >> 2] >> 2] = 0
	                }
	                a:do if (c[h >> 2] | 0) {
	                    e = my(c[h >> 2] | 0) | 0;
	                    c[c[g >> 2] >> 2] = e
	                } else {
	                    if (!(c[j >> 2] | 0)) {
	                        c[m >> 2] = 0;
	                        break
	                    }
	                    do switch (c[c[j >> 2] >> 2] | 0) {
	                        case 4:
	                        {
	                            c[o >> 2] = c[j >> 2];
	                            if (c[(c[o >> 2] | 0) + 48 >> 2] & 8) {
	                                e = my(142672) | 0;
	                                c[c[g >> 2] >> 2] = e
	                            } else {
	                                e = my(147912) | 0;
	                                c[c[g >> 2] >> 2] = e
	                            }
	                            do if (!(c[(c[o >> 2] | 0) + 48 >> 2] & 256)) {
	                                if (c[(c[o >> 2] | 0) + 48 >> 2] & 64) {
	                                    e = By(c[c[g >> 2] >> 2] | 0, 147936) | 0;
	                                    c[c[g >> 2] >> 2] = e;
	                                    break
	                                }
	                                e = c[c[g >> 2] >> 2] | 0;
	                                if (c[(c[o >> 2] | 0) + 48 >> 2] & 128) {
	                                    d = By(e, 147952) | 0;
	                                    c[c[g >> 2] >> 2] = d;
	                                    break
	                                } else {
	                                    d = By(e, 147968) | 0;
	                                    c[c[g >> 2] >> 2] = d;
	                                    break
	                                }
	                            } else {
	                                d = By(c[c[g >> 2] >> 2] | 0, 147920) | 0;
	                                c[c[g >> 2] >> 2] = d
	                            } while (0);
	                            if (!(c[(c[o >> 2] | 0) + 48 >> 2] & 8))break a;
	                            d = By(c[c[g >> 2] >> 2] | 0, 143656) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            d = By(c[c[g >> 2] >> 2] | 0, c[(c[o >> 2] | 0) + 8 >> 2] | 0) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            d = By(c[c[g >> 2] >> 2] | 0, 142568) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            break a;
	                            break
	                        }
	                        case 15:
	                        {
	                            c[r >> 2] = c[j >> 2];
	                            d = my(148032) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            d = By(c[c[g >> 2] >> 2] | 0, 143656) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            d = By(c[c[g >> 2] >> 2] | 0, BB(l, c[(c[r >> 2] | 0) + 56 >> 2] | 0, c[(c[r >> 2] | 0) + 8 >> 2] | 0) | 0) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            if (c[l >> 2] | 0) {
	                                zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                                c[l >> 2] = 0
	                            }
	                            d = By(c[c[g >> 2] >> 2] | 0, 142568) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            break a;
	                            break
	                        }
	                        case 16:
	                        {
	                            ZD(c[g >> 2] | 0, c[j >> 2] | 0) | 0;
	                            break a;
	                            break
	                        }
	                        case 5:
	                        {
	                            c[p >> 2] = c[j >> 2];
	                            if (c[(c[p >> 2] | 0) + 48 >> 2] & 8) {
	                                d = my(142672) | 0;
	                                c[c[g >> 2] >> 2] = d
	                            } else {
	                                d = my(147912) | 0;
	                                c[c[g >> 2] >> 2] = d
	                            }
	                            d = By(c[c[g >> 2] >> 2] | 0, 147984) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            if (!(c[(c[p >> 2] | 0) + 48 >> 2] & 8))break a;
	                            d = By(c[c[g >> 2] >> 2] | 0, 143656) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            d = By(c[c[g >> 2] >> 2] | 0, c[(c[p >> 2] | 0) + 8 >> 2] | 0) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            d = By(c[c[g >> 2] >> 2] | 0, 142568) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            break a;
	                            break
	                        }
	                        case 24:
	                        case 23:
	                        case 22:
	                        {
	                            do if ((c[c[j >> 2] >> 2] | 0) != 22)if ((c[c[j >> 2] >> 2] | 0) == 23) {
	                                d = my(148080) | 0;
	                                c[c[g >> 2] >> 2] = d;
	                                break
	                            } else {
	                                d = my(148088) | 0;
	                                c[c[g >> 2] >> 2] = d;
	                                break
	                            } else {
	                                d = my(148064) | 0;
	                                c[c[g >> 2] >> 2] = d
	                            } while (0);
	                            d = By(c[c[g >> 2] >> 2] | 0, c[(c[j >> 2] | 0) + 16 >> 2] | 0) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            d = By(c[c[g >> 2] >> 2] | 0, 142568) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            break a;
	                            break
	                        }
	                        case 14:
	                        {
	                            c[s >> 2] = c[j >> 2];
	                            d = my(148048) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            d = By(c[c[g >> 2] >> 2] | 0, 143656) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            d = By(c[c[g >> 2] >> 2] | 0, BB(l, c[(c[s >> 2] | 0) + 52 >> 2] | 0, c[(c[s >> 2] | 0) + 8 >> 2] | 0) | 0) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            d = By(c[c[g >> 2] >> 2] | 0, 142568) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            break a;
	                            break
	                        }
	                        case 1:
	                        {
	                            c[n >> 2] = c[j >> 2];
	                            do if (!(c[(c[n >> 2] | 0) + 48 >> 2] & 256)) {
	                                if (c[(c[n >> 2] | 0) + 48 >> 2] & 64) {
	                                    d = my(147856) | 0;
	                                    c[c[g >> 2] >> 2] = d;
	                                    break
	                                }
	                                if (c[(c[n >> 2] | 0) + 48 >> 2] & 128) {
	                                    d = my(147872) | 0;
	                                    c[c[g >> 2] >> 2] = d;
	                                    break
	                                } else {
	                                    d = my(147888) | 0;
	                                    c[c[g >> 2] >> 2] = d;
	                                    break
	                                }
	                            } else {
	                                d = my(147832) | 0;
	                                c[c[g >> 2] >> 2] = d
	                            } while (0);
	                            d = By(c[c[g >> 2] >> 2] | 0, c[(c[n >> 2] | 0) + 8 >> 2] | 0) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            d = By(c[c[g >> 2] >> 2] | 0, 142568) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            break a;
	                            break
	                        }
	                        case 17:
	                        {
	                            d = my(148128) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            d = By(c[c[g >> 2] >> 2] | 0, 143656) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            d = By(c[c[g >> 2] >> 2] | 0, YD(l, c[j >> 2] | 0) | 0) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            d = By(c[c[g >> 2] >> 2] | 0, 142568) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            if (!(c[l >> 2] | 0))break a;
	                            zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                            c[l >> 2] = 0;
	                            break a;
	                            break
	                        }
	                        case 25:
	                        case 8:
	                        case 7:
	                        case 6:
	                        {
	                            d = my(MD(c[j >> 2] | 0) | 0) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            break a;
	                            break
	                        }
	                        case 21:
	                        case 2:
	                        {
	                            d = my(_D(c[(c[j >> 2] | 0) + 24 >> 2] | 0) | 0) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            d = By(c[c[g >> 2] >> 2] | 0, 148104) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            break a;
	                            break
	                        }
	                        case 18:
	                        {
	                            d = my(MD(c[j >> 2] | 0) | 0) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            d = By(c[c[g >> 2] >> 2] | 0, 143656) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            d = By(c[c[g >> 2] >> 2] | 0, YD(l, c[j >> 2] | 0) | 0) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            d = By(c[c[g >> 2] >> 2] | 0, 142568) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            if (c[l >> 2] | 0) {
	                                zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                                c[l >> 2] = 0
	                            }
	                            break
	                        }
	                        case 1011:
	                        case 1010:
	                        case 1009:
	                        case 1008:
	                        case 1007:
	                        case 1006:
	                        case 1005:
	                        case 1004:
	                        case 1003:
	                        case 1002:
	                        case 1001:
	                        case 1e3:
	                        {
	                            d = my(148120) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            d = By(c[c[g >> 2] >> 2] | 0, zB(c[c[j >> 2] >> 2] | 0) | 0) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            d = By(c[c[g >> 2] >> 2] | 0, 142568) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            break a;
	                            break
	                        }
	                        case 26:
	                        {
	                            c[q >> 2] = c[j >> 2];
	                            d = my(148e3) | 0;
	                            c[c[g >> 2] >> 2] = d;
	                            d = c[c[g >> 2] >> 2] | 0;
	                            if (!(c[(c[q >> 2] | 0) + 12 >> 2] | 0)) {
	                                e = By(d, 148016) | 0;
	                                c[c[g >> 2] >> 2] = e;
	                                break a
	                            }
	                            e = By(d, 142568) | 0;
	                            c[c[g >> 2] >> 2] = e;
	                            e = By(c[c[g >> 2] >> 2] | 0, YD(l, c[(c[q >> 2] | 0) + 12 >> 2] | 0) | 0) | 0;
	                            c[c[g >> 2] >> 2] = e;
	                            if (c[l >> 2] | 0) {
	                                zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                                c[l >> 2] = 0
	                            }
	                            e = By(c[c[g >> 2] >> 2] | 0, 142568) | 0;
	                            c[c[g >> 2] >> 2] = e;
	                            break a;
	                            break
	                        }
	                        default:
	                        {
	                        }
	                    } while (0);
	                    c[m >> 2] = 0
	                } while (0);
	                if ((c[m >> 2] | 0) == 0 & (c[k >> 2] | 0) != 0) {
	                    m = c[k >> 2] | 0;
	                    if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 2)c[t >> 2] = c[m + 20 >> 2]; else c[t >> 2] = m;
	                    m = my(144464) | 0;
	                    c[c[g >> 2] >> 2] = m;
	                    m = c[c[g >> 2] >> 2] | 0;
	                    q = c[t >> 2] | 0;
	                    if (c[(c[t >> 2] | 0) + 36 >> 2] | 0) {
	                        j = By(m, BB(l, c[(c[q + 36 >> 2] | 0) + 8 >> 2] | 0, c[(c[t >> 2] | 0) + 8 >> 2] | 0) | 0) | 0;
	                        c[c[g >> 2] >> 2] = j;
	                        if (c[l >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                            c[l >> 2] = 0
	                        }
	                    } else {
	                        j = By(m, c[q + 8 >> 2] | 0) | 0;
	                        c[c[g >> 2] >> 2] = j
	                    }
	                    j = By(c[c[g >> 2] >> 2] | 0, 142568) | 0;
	                    c[c[g >> 2] >> 2] = j
	                }
	                if ((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 2 : 0) {
	                    j = By(c[c[g >> 2] >> 2] | 0, 148152) | 0;
	                    c[c[g >> 2] >> 2] = j;
	                    j = c[c[g >> 2] >> 2] | 0;
	                    q = c[k >> 2] | 0;
	                    if (c[(c[k >> 2] | 0) + 36 >> 2] | 0) {
	                        m = By(j, BB(l, c[(c[q + 36 >> 2] | 0) + 8 >> 2] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0) | 0) | 0;
	                        c[c[g >> 2] >> 2] = m;
	                        if (c[l >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                            c[l >> 2] = 0
	                        }
	                    } else {
	                        m = By(j, c[q + 8 >> 2] | 0) | 0;
	                        c[c[g >> 2] >> 2] = m
	                    }
	                    m = By(c[c[g >> 2] >> 2] | 0, 142568) | 0;
	                    c[c[g >> 2] >> 2] = m
	                }
	                if (!(c[l >> 2] | 0)) {
	                    u = c[g >> 2] | 0;
	                    v = c[u >> 2] | 0;
	                    i = f;
	                    return v | 0
	                }
	                zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                c[l >> 2] = 0;
	                u = c[g >> 2] | 0;
	                v = c[u >> 2] | 0;
	                i = f;
	                return v | 0
	            }

	            function HC(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e;
	                g = e + 36 | 0;
	                h = e + 32 | 0;
	                j = e + 28 | 0;
	                k = e + 24 | 0;
	                l = e + 20 | 0;
	                m = e + 16 | 0;
	                n = e + 12 | 0;
	                o = e + 8 | 0;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = 0;
	                c[c[h >> 2] >> 2] = 0;
	                if (((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 4 >> 2] | 0) != 1 : 0) ? (c[(c[k >> 2] | 0) + 4 >> 2] | 0) != 2 : 0) {
	                    d = my(142672) | 0;
	                    c[c[h >> 2] >> 2] = d;
	                    c[g >> 2] = c[c[h >> 2] >> 2];
	                    p = c[g >> 2] | 0;
	                    i = e;
	                    return p | 0
	                }
	                do if (c[k >> 2] | 0) {
	                    if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 2) {
	                        c[m >> 2] = c[(c[k >> 2] | 0) + 20 >> 2];
	                        d = my(144464) | 0;
	                        c[c[h >> 2] >> 2] = d;
	                        d = c[c[h >> 2] >> 2] | 0;
	                        b = c[m >> 2] | 0;
	                        if (c[(c[m >> 2] | 0) + 36 >> 2] | 0) {
	                            a = By(d, BB(l, c[(c[b + 36 >> 2] | 0) + 8 >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0) | 0) | 0;
	                            c[c[h >> 2] >> 2] = a
	                        } else {
	                            a = By(d, BB(l, 0, c[b + 8 >> 2] | 0) | 0) | 0;
	                            c[c[h >> 2] >> 2] = a
	                        }
	                        if (c[l >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                            c[l >> 2] = 0
	                        }
	                        a = By(c[c[h >> 2] >> 2] | 0, 142656) | 0;
	                        c[c[h >> 2] >> 2] = a;
	                        a = By(c[c[h >> 2] >> 2] | 0, 144480) | 0;
	                        c[c[h >> 2] >> 2] = a
	                    } else {
	                        a = my(144464) | 0;
	                        c[c[h >> 2] >> 2] = a
	                    }
	                    a = c[c[h >> 2] >> 2] | 0;
	                    b = c[k >> 2] | 0;
	                    if (c[(c[k >> 2] | 0) + 36 >> 2] | 0) {
	                        d = By(a, BB(l, c[(c[b + 36 >> 2] | 0) + 8 >> 2] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0) | 0) | 0;
	                        c[c[h >> 2] >> 2] = d
	                    } else {
	                        d = By(a, BB(l, 0, c[b + 8 >> 2] | 0) | 0) | 0;
	                        c[c[h >> 2] >> 2] = d
	                    }
	                    if (c[l >> 2] | 0) {
	                        zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                        c[l >> 2] = 0
	                    }
	                    d = By(c[c[h >> 2] >> 2] | 0, 144496) | 0;
	                    c[c[h >> 2] >> 2] = d
	                } else {
	                    d = c[j >> 2] | 0;
	                    if ((c[c[j >> 2] >> 2] | 0) != 2) {
	                        if ((c[d >> 2] | 0) == 1) {
	                            b = my(142672) | 0;
	                            c[c[h >> 2] >> 2] = b;
	                            break
	                        }
	                        b = c[33976] | 0;
	                        a = c[33980] | 0;
	                        c[f >> 2] = 140328;
	                        c[f + 4 >> 2] = 2246;
	                        Db[b & 511](a, 140296, f);
	                        c[g >> 2] = 0;
	                        p = c[g >> 2] | 0;
	                        i = e;
	                        return p | 0
	                    }
	                    c[n >> 2] = d;
	                    if ((c[c[(c[n >> 2] | 0) + 108 >> 2] >> 2] | 0) == 2) {
	                        c[o >> 2] = c[(c[(c[n >> 2] | 0) + 100 >> 2] | 0) + (c[(c[n >> 2] | 0) + 96 >> 2] << 2) >> 2];
	                        d = my(144464) | 0;
	                        c[c[h >> 2] >> 2] = d;
	                        d = c[c[h >> 2] >> 2] | 0;
	                        a = By(d, BB(l, c[(c[o >> 2] | 0) + 16 >> 2] | 0, c[(c[o >> 2] | 0) + 12 >> 2] | 0) | 0) | 0;
	                        c[c[h >> 2] >> 2] = a;
	                        if (c[l >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                            c[l >> 2] = 0
	                        }
	                        a = By(c[c[h >> 2] >> 2] | 0, 142656) | 0;
	                        c[c[h >> 2] >> 2] = a;
	                        a = By(c[c[h >> 2] >> 2] | 0, 144480) | 0;
	                        c[c[h >> 2] >> 2] = a
	                    } else {
	                        a = my(144464) | 0;
	                        c[c[h >> 2] >> 2] = a
	                    }
	                    a = c[c[h >> 2] >> 2] | 0;
	                    d = By(a, BB(l, c[(c[(c[n >> 2] | 0) + 108 >> 2] | 0) + 16 >> 2] | 0, c[(c[(c[n >> 2] | 0) + 108 >> 2] | 0) + 12 >> 2] | 0) | 0) | 0;
	                    c[c[h >> 2] >> 2] = d;
	                    if (c[l >> 2] | 0) {
	                        zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                        c[l >> 2] = 0
	                    }
	                    d = By(c[c[h >> 2] >> 2] | 0, 144496) | 0;
	                    c[c[h >> 2] >> 2] = d
	                } while (0);
	                c[g >> 2] = c[c[h >> 2] >> 2];
	                p = c[g >> 2] | 0;
	                i = e;
	                return p | 0
	            }

	            function IC(a, b, d, e, f, g, h, j) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                var k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                k = i;
	                i = i + 32 | 0;
	                l = k + 28 | 0;
	                m = k + 24 | 0;
	                n = k + 20 | 0;
	                o = k + 16 | 0;
	                p = k + 12 | 0;
	                q = k + 8 | 0;
	                r = k + 4 | 0;
	                s = k;
	                c[l >> 2] = a;
	                c[m >> 2] = b;
	                c[n >> 2] = d;
	                c[o >> 2] = e;
	                c[p >> 2] = f;
	                c[q >> 2] = g;
	                c[r >> 2] = h;
	                c[s >> 2] = j;
	                $D(c[l >> 2] | 0, 2, c[m >> 2] | 0, c[n >> 2] | 0, 0, c[o >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0, c[r >> 2] | 0, c[s >> 2] | 0);
	                i = k;
	                return
	            }

	            function JC(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[j >> 2] = c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 12 >> 2];
	                if (!(c[(c[j >> 2] | 0) + 4 >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                c[k >> 2] = 0;
	                while (1) {
	                    if ((c[k >> 2] | 0) >= (c[(c[j >> 2] | 0) + 4 >> 2] | 0)) {
	                        m = 8;
	                        break
	                    }
	                    c[h >> 2] = c[(c[c[j >> 2] >> 2] | 0) + (c[k >> 2] << 2) >> 2];
	                    if ((c[(c[h >> 2] | 0) + 8 >> 2] | 0) == (c[g >> 2] | 0)) {
	                        m = 6;
	                        break
	                    }
	                    c[k >> 2] = (c[k >> 2] | 0) + 1
	                }
	                if ((m | 0) == 6) {
	                    c[e >> 2] = c[h >> 2];
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                } else if ((m | 0) == 8) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                return 0
	            }

	            function KC() {
	                var a = 0, b = 0, d = 0, e = 0, f = 0;
	                a = i;
	                i = i + 16 | 0;
	                b = a + 4 | 0;
	                d = a;
	                c[d >> 2] = Cb[c[135744 >> 2] & 511](16) | 0;
	                if (!(c[d >> 2] | 0)) {
	                    tC(0, 170048, 0);
	                    c[b >> 2] = 0;
	                    e = c[b >> 2] | 0;
	                    i = a;
	                    return e | 0
	                } else {
	                    f = c[d >> 2] | 0;
	                    c[f + 0 >> 2] = 0;
	                    c[f + 4 >> 2] = 0;
	                    c[f + 8 >> 2] = 0;
	                    c[f + 12 >> 2] = 0;
	                    c[b >> 2] = c[d >> 2];
	                    e = c[b >> 2] | 0;
	                    i = a;
	                    return e | 0
	                }
	                return 0
	            }

	            function LC(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[g >> 2] = c[(c[e >> 2] | 0) + 24 >> 2];
	                if (!(c[g >> 2] | 0)) {
	                    c[(c[e >> 2] | 0) + 24 >> 2] = c[f >> 2];
	                    i = d;
	                    return
	                }
	                while (1) {
	                    if (!(c[c[g >> 2] >> 2] | 0))break;
	                    c[g >> 2] = c[c[g >> 2] >> 2]
	                }
	                c[c[g >> 2] >> 2] = c[f >> 2];
	                i = d;
	                return
	            }

	            function MC(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 20 | 0;
	                h = e + 16 | 0;
	                j = e + 12 | 0;
	                k = e + 8 | 0;
	                l = e + 4 | 0;
	                m = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[l >> 2] = c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 12 >> 2];
	                if (!(c[(c[l >> 2] | 0) + 4 >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                c[m >> 2] = 0;
	                while (1) {
	                    if ((c[m >> 2] | 0) >= (c[(c[l >> 2] | 0) + 4 >> 2] | 0)) {
	                        o = 14;
	                        break
	                    }
	                    c[k >> 2] = c[(c[c[l >> 2] >> 2] | 0) + (c[m >> 2] << 2) >> 2];
	                    if (!((c[(c[k >> 2] | 0) + 20 >> 2] | 0) == 0 ? (c[(c[k >> 2] | 0) + 8 >> 2] | 0) != 0 : 0))o = 7;
	                    if ((o | 0) == 7 ? (o = 0, (c[(c[k >> 2] | 0) + 12 >> 2] | 0) == (c[h >> 2] | 0)) : 0) {
	                        if ((c[j >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) {
	                            o = 12;
	                            break
	                        }
	                        if ((c[j >> 2] | 0) == 0 ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) == 0 : 0) {
	                            o = 12;
	                            break
	                        }
	                    }
	                    c[m >> 2] = (c[m >> 2] | 0) + 1
	                }
	                if ((o | 0) == 12) {
	                    c[f >> 2] = c[k >> 2];
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                } else if ((o | 0) == 14) {
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                return 0
	            }

	            function NC(a, b, d, e, f, g, h, j) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                var k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                k = i;
	                i = i + 48 | 0;
	                l = k + 32 | 0;
	                m = k + 28 | 0;
	                n = k + 24 | 0;
	                o = k + 16 | 0;
	                p = k + 12 | 0;
	                q = k + 8 | 0;
	                r = k + 4 | 0;
	                s = k;
	                c[l >> 2] = a;
	                c[m >> 2] = b;
	                c[n >> 2] = d;
	                c[k + 20 >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                c[q >> 2] = h;
	                c[r >> 2] = j;
	                c[s >> 2] = 0;
	                HC(s, c[l >> 2] | 0, c[n >> 2] | 0) | 0;
	                c[s >> 2] = By(c[s >> 2] | 0, c[o >> 2] | 0) | 0;
	                c[s >> 2] = By(c[s >> 2] | 0, 142704) | 0;
	                $D(c[l >> 2] | 0, 1, c[m >> 2] | 0, c[n >> 2] | 0, 0, c[s >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0, c[r >> 2] | 0, 0);
	                if (!(c[s >> 2] | 0)) {
	                    i = k;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[s >> 2] | 0);
	                c[s >> 2] = 0;
	                i = k;
	                return
	            }

	            function OC(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 20 | 0;
	                h = e + 16 | 0;
	                j = e + 12 | 0;
	                k = e + 8 | 0;
	                l = e + 4 | 0;
	                m = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[l >> 2] = c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 12 >> 2];
	                if (!(c[(c[l >> 2] | 0) + 4 >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                c[m >> 2] = 0;
	                while (1) {
	                    if ((c[m >> 2] | 0) >= (c[(c[l >> 2] | 0) + 4 >> 2] | 0)) {
	                        o = 10;
	                        break
	                    }
	                    c[k >> 2] = c[(c[c[l >> 2] >> 2] | 0) + (c[m >> 2] << 2) >> 2];
	                    if (((c[(c[k >> 2] | 0) + 12 >> 2] | 0) == 0 ? (c[(c[k >> 2] | 0) + 8 >> 2] | 0) == (c[h >> 2] | 0) : 0) ? (c[(c[k >> 2] | 0) + 16 >> 2] | 0) == (c[j >> 2] | 0) : 0) {
	                        o = 8;
	                        break
	                    }
	                    c[m >> 2] = (c[m >> 2] | 0) + 1
	                }
	                if ((o | 0) == 8) {
	                    c[f >> 2] = c[k >> 2];
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                } else if ((o | 0) == 10) {
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                return 0
	            }

	            function PC(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h;
	                k = h + 40 | 0;
	                l = h + 36 | 0;
	                m = h + 32 | 0;
	                n = h + 28 | 0;
	                o = h + 24 | 0;
	                p = h + 20 | 0;
	                q = h + 16 | 0;
	                r = h + 12 | 0;
	                s = h + 8 | 0;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                c[q >> 2] = 0;
	                c[r >> 2] = 0;
	                c[s >> 2] = 0;
	                if (c[k >> 2] | 0) {
	                    g = (c[k >> 2] | 0) + 20 | 0;
	                    c[g >> 2] = (c[g >> 2] | 0) + 1;
	                    c[(c[k >> 2] | 0) + 16 >> 2] = c[m >> 2];
	                    c[q >> 2] = c[(c[k >> 2] | 0) + 8 >> 2];
	                    c[s >> 2] = c[(c[k >> 2] | 0) + 4 >> 2];
	                    c[r >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                }
	                g = c[r >> 2] | 0;
	                r = c[q >> 2] | 0;
	                q = c[s >> 2] | 0;
	                s = c[k >> 2] | 0;
	                k = c[l >> 2] | 0;
	                l = c[m >> 2] | 0;
	                m = c[o >> 2] | 0;
	                f = c[p >> 2] | 0;
	                e = c[n >> 2] | 0;
	                n = c[p >> 2] | 0;
	                c[j >> 2] = c[o >> 2];
	                c[j + 4 >> 2] = n;
	                Xd(g, r, q, s, k, 16, l, 2, 0, 0, m, f, 0, 0, 0, e, j);
	                i = h;
	                return
	            }

	            function QC(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if ((c[e >> 2] | 0) == 0 | (c[f >> 2] | 0) == 0) {
	                    i = d;
	                    return
	                }
	                c[g >> 2] = 0;
	                c[h >> 2] = c[f >> 2];
	                a:while (1) {
	                    j = (c[g >> 2] | 0) != 0;
	                    if (!(c[h >> 2] | 0))break;
	                    if (j) {
	                        Qh(c[g >> 2] | 0);
	                        Rh(c[g >> 2] | 0);
	                        c[g >> 2] = 0
	                    }
	                    e = c[(c[h >> 2] | 0) + 4 >> 2] | 0;
	                    if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 3)if (((e | 0) == 3 ? (aE(c[(c[h >> 2] | 0) + 40 >> 2] | 0, -1) | 0) != 0 : 0) ? (Vi(c[h >> 2] | 0) | 0) != 1 : 0) {
	                        c[g >> 2] = c[h >> 2];
	                        k = 14
	                    } else k = 14; else if ((e | 0) != 1 ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 4 : 0)c[g >> 2] = c[h >> 2]; else k = 14;
	                    if (((((k | 0) == 14 ? (k = 0, (c[(c[h >> 2] | 0) + 12 >> 2] | 0) != 0) : 0) ? (c[(c[(c[h >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) != 17 : 0) ? (c[(c[(c[h >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) != 5 : 0) ? (c[(c[(c[h >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) != 6 : 0) {
	                        c[h >> 2] = c[(c[h >> 2] | 0) + 12 >> 2];
	                        continue
	                    }
	                    if (c[(c[h >> 2] | 0) + 24 >> 2] | 0) {
	                        c[h >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                        continue
	                    }
	                    while (1) {
	                        c[h >> 2] = c[(c[h >> 2] | 0) + 20 >> 2];
	                        if (!(c[h >> 2] | 0))continue a;
	                        if ((c[h >> 2] | 0) == (c[f >> 2] | 0)) {
	                            k = 23;
	                            break
	                        }
	                        l = c[h >> 2] | 0;
	                        if (c[(c[h >> 2] | 0) + 24 >> 2] | 0) {
	                            k = 25;
	                            break
	                        }
	                        if (!l)continue a
	                    }
	                    if ((k | 0) == 23) {
	                        k = 0;
	                        c[h >> 2] = 0;
	                        continue
	                    } else if ((k | 0) == 25) {
	                        k = 0;
	                        c[h >> 2] = c[l + 24 >> 2];
	                        continue
	                    }
	                }
	                if (!j) {
	                    i = d;
	                    return
	                }
	                Qh(c[g >> 2] | 0);
	                Rh(c[g >> 2] | 0);
	                c[g >> 2] = 0;
	                i = d;
	                return
	            }

	            function RC(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = ej(c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                } else {
	                    c[l >> 2] = AP(c[(c[g >> 2] | 0) + 80 >> 2] | 0, c[k >> 2] | 0, -1) | 0;
	                    zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    c[f >> 2] = c[l >> 2];
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                return 0
	            }

	            function SC(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 28 | 0;
	                g = e + 24 | 0;
	                h = e + 20 | 0;
	                j = e + 16 | 0;
	                k = e + 12 | 0;
	                l = e + 8 | 0;
	                m = e + 4 | 0;
	                n = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                d = c[g >> 2] | 0;
	                if (!(c[c[(c[g >> 2] | 0) + 28 >> 2] >> 2] | 0)) {
	                    xB(d, 169824, 169848);
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                c[m >> 2] = c[c[d + 28 >> 2] >> 2];
	                c[l >> 2] = 56;
	                c[k >> 2] = Cb[c[135744 >> 2] & 511](c[l >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    tC(0, 169880, 0);
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                cU(c[k >> 2] | 0, 0, c[l >> 2] | 0) | 0;
	                c[(c[k >> 2] | 0) + 16 >> 2] = c[j >> 2];
	                c[c[k >> 2] >> 2] = c[h >> 2];
	                l = JB() | 0;
	                c[(c[k >> 2] | 0) + 44 >> 2] = l;
	                if (!(c[(c[k >> 2] | 0) + 44 >> 2] | 0)) {
	                    zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                l = JB() | 0;
	                c[(c[k >> 2] | 0) + 48 >> 2] = l;
	                if (!(c[(c[k >> 2] | 0) + 48 >> 2] | 0)) {
	                    zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                do if ((c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[(c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) > 0 : 0) {
	                    if (!(c[h >> 2] | 0)) {
	                        xB(c[g >> 2] | 0, 169824, 169960);
	                        qB(c[k >> 2] | 0);
	                        c[f >> 2] = 0;
	                        o = c[f >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    }
	                    if ((c[h >> 2] | 0) == 1) {
	                        l = DB(c[g >> 2] | 0) | 0;
	                        c[(c[k >> 2] | 0) + 52 >> 2] = l;
	                        if (c[(c[k >> 2] | 0) + 52 >> 2] | 0) {
	                            c[(c[(c[k >> 2] | 0) + 52 >> 2] | 0) + 4 >> 2] = c[j >> 2];
	                            break
	                        }
	                        qB(c[k >> 2] | 0);
	                        c[f >> 2] = 0;
	                        o = c[f >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    }
	                } else p = 11; while (0);
	                do if ((p | 0) == 11) {
	                    if (!((c[h >> 2] | 0) == 2 | (c[h >> 2] | 0) == 3)) {
	                        c[c[k >> 2] >> 2] = 0;
	                        c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 4 >> 2] = c[k >> 2];
	                        c[(c[k >> 2] | 0) + 52 >> 2] = c[m >> 2];
	                        c[(c[m >> 2] | 0) + 4 >> 2] = c[j >> 2];
	                        break
	                    }
	                    xB(c[g >> 2] | 0, 169824, 169912);
	                    qB(c[k >> 2] | 0);
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                } while (0);
	                if ((c[h >> 2] | 0) == 0 | (c[h >> 2] | 0) == 1) {
	                    if ((c[(c[m >> 2] | 0) + 48 >> 2] | 0) == 0 ? (h = Jj(5, c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 8 >> 2] | 0) | 0, c[(c[m >> 2] | 0) + 48 >> 2] = h, (c[(c[m >> 2] | 0) + 48 >> 2] | 0) == 0) : 0) {
	                        qB(c[k >> 2] | 0);
	                        c[f >> 2] = 0;
	                        o = c[f >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    }
	                    h = c[(c[m >> 2] | 0) + 48 >> 2] | 0;
	                    if (!(c[j >> 2] | 0))c[n >> 2] = Lj(h, 145792, c[k >> 2] | 0) | 0; else c[n >> 2] = Lj(h, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                    if (c[n >> 2] | 0) {
	                        xB(c[g >> 2] | 0, 169824, 17e4);
	                        qB(c[k >> 2] | 0);
	                        c[f >> 2] = 0;
	                        o = c[f >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    }
	                } else {
	                    if ((c[c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] >> 2] | 0) != 0 ? (c[c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] >> 2] | 0) != 1 : 0)c[(c[k >> 2] | 0) + 52 >> 2] = c[(c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] | 0) + 52 >> 2]; else c[(c[k >> 2] | 0) + 52 >> 2] = c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2];
	                    if ((c[(c[m >> 2] | 0) + 64 >> 2] | 0) == 0 ? (n = JB() | 0, c[(c[m >> 2] | 0) + 64 >> 2] = n, (c[(c[m >> 2] | 0) + 64 >> 2] | 0) == 0) : 0) {
	                        qB(c[k >> 2] | 0);
	                        c[f >> 2] = 0;
	                        o = c[f >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    }
	                    bE(c[(c[m >> 2] | 0) + 64 >> 2] | 0, c[k >> 2] | 0) | 0
	                }
	                if ((bE(c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 12 >> 2] | 0, c[k >> 2] | 0) | 0) == -1) {
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                } else {
	                    c[f >> 2] = c[k >> 2];
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                return 0
	            }

	            function TC(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (c[(c[d >> 2] | 0) + 24 >> 2] & 1) {
	                    a = (c[d >> 2] | 0) + 24 | 0;
	                    c[a >> 2] = c[a >> 2] ^ 1
	                }
	                if (c[(c[d >> 2] | 0) + 24 >> 2] & 2) {
	                    a = (c[d >> 2] | 0) + 24 | 0;
	                    c[a >> 2] = c[a >> 2] ^ 2
	                }
	                if (c[(c[d >> 2] | 0) + 24 >> 2] & 4) {
	                    a = (c[d >> 2] | 0) + 24 | 0;
	                    c[a >> 2] = c[a >> 2] ^ 4
	                }
	                if (c[(c[d >> 2] | 0) + 24 >> 2] & 8) {
	                    a = (c[d >> 2] | 0) + 24 | 0;
	                    c[a >> 2] = c[a >> 2] ^ 8
	                }
	                if (c[(c[d >> 2] | 0) + 24 >> 2] & 16) {
	                    a = (c[d >> 2] | 0) + 24 | 0;
	                    c[a >> 2] = c[a >> 2] ^ 16
	                }
	                if (c[(c[d >> 2] | 0) + 24 >> 2] & 32) {
	                    a = (c[d >> 2] | 0) + 24 | 0;
	                    c[a >> 2] = c[a >> 2] ^ 32
	                }
	                if (c[(c[d >> 2] | 0) + 24 >> 2] & 64) {
	                    a = (c[d >> 2] | 0) + 24 | 0;
	                    c[a >> 2] = c[a >> 2] ^ 64
	                }
	                if (c[(c[d >> 2] | 0) + 24 >> 2] & 128) {
	                    a = (c[d >> 2] | 0) + 24 | 0;
	                    c[a >> 2] = c[a >> 2] ^ 128
	                }
	                if (!(c[(c[d >> 2] | 0) + 24 >> 2] & 256)) {
	                    i = b;
	                    return
	                }
	                a = (c[d >> 2] | 0) + 24 | 0;
	                c[a >> 2] = c[a >> 2] ^ 256;
	                i = b;
	                return
	            }

	            function UC(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 28 | 0;
	                g = e + 24 | 0;
	                h = e + 20 | 0;
	                j = e + 16 | 0;
	                k = e + 12 | 0;
	                l = e + 8 | 0;
	                m = e + 4 | 0;
	                n = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[m >> 2] = 0;
	                c[n >> 2] = c[(c[g >> 2] | 0) + 20 >> 2];
	                c[m >> 2] = cE(c[g >> 2] | 0, c[j >> 2] | 0, 161384) | 0;
	                do if ((c[m >> 2] | 0) != -1) {
	                    c[k >> 2] = dE(c[j >> 2] | 0, 168888) | 0;
	                    if (c[k >> 2] | 0) {
	                        d = c[g >> 2] | 0;
	                        b = c[k >> 2] | 0;
	                        c[m >> 2] = eE(d, 0, b, IH(29) | 0, 0) | 0;
	                        if ((c[m >> 2] | 0) == -1)break;
	                        if (c[m >> 2] | 0)c[(c[g >> 2] | 0) + 108 >> 2] = 3037; else o = 6
	                    } else o = 6;
	                    if ((o | 0) == 6) {
	                        c[k >> 2] = dE(c[j >> 2] | 0, 168904) | 0;
	                        if (c[k >> 2] | 0) {
	                            c[l >> 2] = fE(c[g >> 2] | 0, c[k >> 2] | 0) | 0;
	                            c[m >> 2] = gE(c[l >> 2] | 0, (c[h >> 2] | 0) + 24 | 0, 1) | 0;
	                            if ((c[m >> 2] | 0) == -1)break;
	                            if (c[m >> 2] | 0)hE(c[g >> 2] | 0, 1705, 0, c[k >> 2] | 0, 0, 163568, c[l >> 2] | 0, 0, 0, 0)
	                        }
	                        c[k >> 2] = dE(c[j >> 2] | 0, 168928) | 0;
	                        if (c[k >> 2] | 0) {
	                            c[l >> 2] = fE(c[g >> 2] | 0, c[k >> 2] | 0) | 0;
	                            c[m >> 2] = gE(c[l >> 2] | 0, (c[h >> 2] | 0) + 24 | 0, 2) | 0;
	                            if ((c[m >> 2] | 0) == -1)break;
	                            if (c[m >> 2] | 0)hE(c[g >> 2] | 0, 1701, 0, c[k >> 2] | 0, 0, 163568, c[l >> 2] | 0, 0, 0, 0)
	                        }
	                        c[k >> 2] = dE(c[j >> 2] | 0, 168952) | 0;
	                        if (c[k >> 2] | 0) {
	                            c[l >> 2] = fE(c[g >> 2] | 0, c[k >> 2] | 0) | 0;
	                            c[m >> 2] = iE(c[l >> 2] | 0, (c[h >> 2] | 0) + 24 | 0, -1, 4, 8, -1, 16, 32) | 0;
	                            if ((c[m >> 2] | 0) == -1)break;
	                            if (c[m >> 2] | 0)hE(c[g >> 2] | 0, 3037, 0, c[k >> 2] | 0, 0, 168968, c[l >> 2] | 0, 0, 0, 0)
	                        }
	                        c[k >> 2] = dE(c[j >> 2] | 0, 169032) | 0;
	                        if (c[k >> 2] | 0) {
	                            c[l >> 2] = fE(c[g >> 2] | 0, c[k >> 2] | 0) | 0;
	                            c[m >> 2] = iE(c[l >> 2] | 0, (c[h >> 2] | 0) + 24 | 0, -1, 64, 128, 256, -1, -1) | 0;
	                            if ((c[m >> 2] | 0) == -1)break;
	                            if (c[m >> 2] | 0)hE(c[g >> 2] | 0, 3037, 0, c[k >> 2] | 0, 0, 164576, c[l >> 2] | 0, 0, 0, 0)
	                        }
	                    }
	                    if ((c[n >> 2] | 0) != (c[(c[g >> 2] | 0) + 20 >> 2] | 0))c[m >> 2] = c[(c[g >> 2] | 0) + 16 >> 2];
	                    c[f >> 2] = c[m >> 2];
	                    p = c[f >> 2] | 0;
	                    i = e;
	                    return p | 0
	                } while (0);
	                c[f >> 2] = -1;
	                p = c[f >> 2] | 0;
	                i = e;
	                return p | 0
	            }

	            function VC(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 32 | 0;
	                g = e + 28 | 0;
	                h = e + 24 | 0;
	                j = e + 20 | 0;
	                k = e + 16 | 0;
	                l = e + 12 | 0;
	                m = e + 8 | 0;
	                n = e + 4 | 0;
	                o = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[m >> 2] = 0;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    c[f >> 2] = -1;
	                    p = c[f >> 2] | 0;
	                    i = e;
	                    return p | 0
	                }
	                c[n >> 2] = c[(c[g >> 2] | 0) + 20 >> 2];
	                c[k >> 2] = c[j >> 2];
	                a:while (1) {
	                    if (!((((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 160960) | 0) != 0 : 0) ? (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0))q = 8;
	                    do if ((q | 0) == 8) {
	                        q = 0;
	                        if ((((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 160968) | 0) != 0 : 0) ? (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0)break;
	                        if ((((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 160976) | 0) != 0 : 0) ? (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0)break;
	                        if (!(c[k >> 2] | 0)) {
	                            q = 49;
	                            break a
	                        }
	                        if (!(c[(c[k >> 2] | 0) + 36 >> 2] | 0)) {
	                            q = 49;
	                            break a
	                        }
	                        if (!(qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 160992) | 0)) {
	                            q = 49;
	                            break a
	                        }
	                        if (!(qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)) {
	                            q = 49;
	                            break a
	                        }
	                    } while (0);
	                    do if ((((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 160992) | 0) != 0 : 0) ? (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        c[l >> 2] = jE(c[g >> 2] | 0, c[k >> 2] | 0, 1) | 0;
	                        j = c[l >> 2] | 0;
	                        if (!(c[(c[h >> 2] | 0) + 20 >> 2] | 0)) {
	                            c[(c[h >> 2] | 0) + 20 >> 2] = j;
	                            break
	                        } else {
	                            mB(j);
	                            break
	                        }
	                    } else q = 27; while (0);
	                    do if ((q | 0) == 27) {
	                        q = 0;
	                        if ((((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 160968) | 0) != 0 : 0) ? (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                            c[o >> 2] = c[(c[g >> 2] | 0) + 20 >> 2];
	                            c[m >> 2] = kE(c[g >> 2] | 0, c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                            if ((c[m >> 2] | 0) == -1) {
	                                q = 97;
	                                break a
	                            }
	                            if (c[(c[g >> 2] | 0) + 108 >> 2] | 0)break a;
	                            if ((c[o >> 2] | 0) != (c[(c[g >> 2] | 0) + 20 >> 2] | 0))break a; else break
	                        }
	                        if ((((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 160960) | 0) != 0 : 0) ? (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                            c[o >> 2] = c[(c[g >> 2] | 0) + 20 >> 2];
	                            c[m >> 2] = lE(c[g >> 2] | 0, c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                            if ((c[m >> 2] | 0) == -1) {
	                                q = 97;
	                                break a
	                            }
	                            if (c[(c[g >> 2] | 0) + 108 >> 2] | 0)break a;
	                            if ((c[o >> 2] | 0) != (c[(c[g >> 2] | 0) + 20 >> 2] | 0))break a; else break
	                        }
	                        if ((((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 160976) | 0) != 0 : 0) ? (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                            c[o >> 2] = c[(c[g >> 2] | 0) + 20 >> 2];
	                            c[m >> 2] = mE(c[g >> 2] | 0, c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                            if ((c[m >> 2] | 0) == -1) {
	                                q = 97;
	                                break a
	                            }
	                            if (c[(c[g >> 2] | 0) + 108 >> 2] | 0)break a;
	                            if ((c[o >> 2] | 0) != (c[(c[g >> 2] | 0) + 20 >> 2] | 0))break a
	                        }
	                    } while (0);
	                    c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                }
	                if ((q | 0) == 97) {
	                    c[f >> 2] = -1;
	                    p = c[f >> 2] | 0;
	                    i = e;
	                    return p | 0
	                }
	                b:do if ((q | 0) == 49)c:while (1) {
	                    q = 0;
	                    if (!(c[k >> 2] | 0))break b;
	                    if ((((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 161008) | 0) != 0 : 0) ? (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        nE(c[g >> 2] | 0, c[h >> 2] | 0, c[k >> 2] | 0, 1) | 0;
	                        c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                    } else q = 55;
	                    do if ((q | 0) == 55) {
	                        q = 0;
	                        if ((((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 161024) | 0) != 0 : 0) ? (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                            oE(c[g >> 2] | 0, c[h >> 2] | 0, c[k >> 2] | 0, 1) | 0;
	                            c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2];
	                            break
	                        }
	                        if ((((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 161040) | 0) != 0 : 0) ? (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                            pE(c[g >> 2] | 0, c[h >> 2] | 0, c[k >> 2] | 0, 0, 1) | 0;
	                            c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2];
	                            break
	                        }
	                        if ((((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 161048) | 0) != 0 : 0) ? (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                            qE(c[g >> 2] | 0, c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                            c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2];
	                            break
	                        }
	                        if ((((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 161064) | 0) != 0 : 0) ? (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                            rE(c[g >> 2] | 0, c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                            c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2];
	                            break
	                        }
	                        if ((((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 161080) | 0) != 0 : 0) ? (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                            sE(c[g >> 2] | 0, c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                            c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2];
	                            break
	                        }
	                        if ((((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 161088) | 0) != 0 : 0) ? (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                            tE(c[g >> 2] | 0, c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                            c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2];
	                            break
	                        }
	                        uE(c[g >> 2] | 0, 3033, 0, c[(c[k >> 2] | 0) + 20 >> 2] | 0, c[k >> 2] | 0, 0, 161104);
	                        c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                    } while (0);
	                    while (1) {
	                        if (!(c[k >> 2] | 0)) {
	                            q = 49;
	                            continue c
	                        }
	                        if (!(c[(c[k >> 2] | 0) + 36 >> 2] | 0)) {
	                            q = 49;
	                            continue c
	                        }
	                        if (!(qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 160992) | 0)) {
	                            q = 49;
	                            continue c
	                        }
	                        if (!(qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)) {
	                            q = 49;
	                            continue c
	                        }
	                        c[l >> 2] = jE(c[g >> 2] | 0, c[k >> 2] | 0, 1) | 0;
	                        o = c[l >> 2] | 0;
	                        if (!(c[(c[h >> 2] | 0) + 20 >> 2] | 0))c[(c[h >> 2] | 0) + 20 >> 2] = o; else mB(o);
	                        c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                    }
	                } while (0);
	                c[(c[g >> 2] | 0) + 84 >> 2] = 0;
	                if ((c[n >> 2] | 0) != (c[(c[g >> 2] | 0) + 20 >> 2] | 0))c[m >> 2] = c[(c[g >> 2] | 0) + 16 >> 2];
	                c[f >> 2] = c[m >> 2];
	                p = c[f >> 2] | 0;
	                i = e;
	                return p | 0
	            }

	            function WC(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                b = i;
	                i = i + 48 | 0;
	                d = b + 40 | 0;
	                e = b + 36 | 0;
	                f = b + 32 | 0;
	                g = b + 28 | 0;
	                h = b + 24 | 0;
	                j = b + 20 | 0;
	                k = b + 16 | 0;
	                l = b + 12 | 0;
	                m = b + 8 | 0;
	                n = b + 4 | 0;
	                o = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                c[g >> 2] = c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + 28 >> 2];
	                if (!(c[g >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    p = c[d >> 2] | 0;
	                    i = b;
	                    return p | 0
	                }
	                a:while (1) {
	                    c[j >> 2] = c[(c[g >> 2] | 0) + 4 >> 2];
	                    c[h >> 2] = vE(c[(c[g >> 2] | 0) + 24 >> 2] | 0, c[c[j >> 2] >> 2] | 0, c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[(c[g >> 2] | 0) + 20 >> 2] | 0) | 0;
	                    do if (!(c[h >> 2] | 0)) {
	                        c[l >> 2] = 0;
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0)c[m >> 2] = FC(c[(c[g >> 2] | 0) + 8 >> 2] | 0) | 0; else c[m >> 2] = FC(c[j >> 2] | 0) | 0;
	                        a = c[e >> 2] | 0;
	                        q = c[m >> 2] | 0;
	                        r = MD(c[j >> 2] | 0) | 0;
	                        AB(a, 3081, q, 0, 160712, r, BB(l, c[(c[g >> 2] | 0) + 20 >> 2] | 0, c[(c[g >> 2] | 0) + 16 >> 2] | 0) | 0);
	                        if (c[l >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                            c[l >> 2] = 0
	                        }
	                        c[f >> 2] = c[(c[e >> 2] | 0) + 16 >> 2];
	                        c[g >> 2] = c[c[g >> 2] >> 2]
	                    } else {
	                        c[k >> 2] = 0;
	                        r = c[c[j >> 2] >> 2] | 0;
	                        do if ((r | 0) == 4 | (r | 0) == 5)if (c[(c[h >> 2] | 0) + 48 >> 2] & 1073741824) {
	                            c[k >> 2] = 1;
	                            break
	                        } else {
	                            q = (c[h >> 2] | 0) + 48 | 0;
	                            c[q >> 2] = c[q >> 2] | 1073741824;
	                            c[(c[j >> 2] | 0) + 64 >> 2] = c[h >> 2];
	                            break
	                        } else if ((r | 0) == 17) {
	                            if (c[(c[h >> 2] | 0) + 28 >> 2] & 2) {
	                                c[k >> 2] = 1;
	                                break
	                            }
	                            q = (c[h >> 2] | 0) + 28 | 0;
	                            c[q >> 2] = c[q >> 2] | 2;
	                            if (c[(c[g >> 2] | 0) + 8 >> 2] | 0)c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 12 >> 2] = c[h >> 2];
	                            c[(c[g >> 2] | 0) + 12 >> 2] = c[h >> 2]
	                        } else if ((r | 0) == 16) {
	                            if (c[(c[h >> 2] | 0) + 36 >> 2] & 8) {
	                                c[k >> 2] = 1;
	                                break
	                            }
	                            q = (c[h >> 2] | 0) + 36 | 0;
	                            c[q >> 2] = c[q >> 2] | 8;
	                            q = c[h >> 2] | 0;
	                            a = c[g >> 2] | 0;
	                            if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                                c[(c[a + 8 >> 2] | 0) + 4 >> 2] = q;
	                                c[(c[g >> 2] | 0) + 12 >> 2] = 0;
	                                break
	                            } else {
	                                c[a + 12 >> 2] = q;
	                                break
	                            }
	                        } else {
	                            s = 24;
	                            break a
	                        } while (0);
	                        if (!(c[k >> 2] | 0)) {
	                            c[g >> 2] = c[c[g >> 2] >> 2];
	                            break
	                        }
	                        c[n >> 2] = 0;
	                        r = c[g >> 2] | 0;
	                        if (c[(c[g >> 2] | 0) + 8 >> 2] | 0)c[o >> 2] = FC(c[r + 8 >> 2] | 0) | 0; else c[o >> 2] = FC(c[r + 4 >> 2] | 0) | 0;
	                        r = c[e >> 2] | 0;
	                        q = c[o >> 2] | 0;
	                        AB(r, 3081, q, 0, 160856, ZD(n, c[h >> 2] | 0) | 0, 0);
	                        if (c[n >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                            c[n >> 2] = 0
	                        }
	                        c[f >> 2] = c[(c[e >> 2] | 0) + 16 >> 2];
	                        c[g >> 2] = c[c[g >> 2] >> 2]
	                    } while (0);
	                    if (!(c[g >> 2] | 0)) {
	                        s = 34;
	                        break
	                    }
	                }
	                if ((s | 0) == 24) {
	                    xB(c[e >> 2] | 0, 160784, 160816);
	                    c[d >> 2] = -1;
	                    p = c[d >> 2] | 0;
	                    i = b;
	                    return p | 0
	                } else if ((s | 0) == 34) {
	                    c[d >> 2] = c[f >> 2];
	                    p = c[d >> 2] | 0;
	                    i = b;
	                    return p | 0
	                }
	                return 0
	            }

	            function XC(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                d = i;
	                i = i + 48 | 0;
	                e = d + 36 | 0;
	                f = d + 32 | 0;
	                g = d + 28 | 0;
	                h = d + 24 | 0;
	                j = d + 20 | 0;
	                k = d + 16 | 0;
	                l = d + 12 | 0;
	                m = d + 8 | 0;
	                n = d + 4 | 0;
	                o = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    p = c[e >> 2] | 0;
	                    i = d;
	                    return p | 0
	                }
	                if (c[(c[g >> 2] | 0) + 4 >> 2] & 2) {
	                    c[e >> 2] = 0;
	                    p = c[e >> 2] | 0;
	                    i = d;
	                    return p | 0
	                }
	                b = (c[g >> 2] | 0) + 4 | 0;
	                c[b >> 2] = c[b >> 2] | 2;
	                c[m >> 2] = 0;
	                while (1) {
	                    if ((c[m >> 2] | 0) >= (c[(c[(c[g >> 2] | 0) + 44 >> 2] | 0) + 4 >> 2] | 0))break;
	                    c[h >> 2] = c[(c[c[(c[g >> 2] | 0) + 44 >> 2] >> 2] | 0) + (c[m >> 2] << 2) >> 2];
	                    c[k >> 2] = 0;
	                    a:do switch (c[c[h >> 2] >> 2] | 0) {
	                        case 4:
	                        case 5:
	                        {
	                            if (!(c[(c[h >> 2] | 0) + 48 >> 2] & 1073741824)) {
	                                c[l >> 2] = c[(c[h >> 2] | 0) + 8 >> 2];
	                                if ((c[c[g >> 2] >> 2] | 0) != 0 ? (c[c[g >> 2] >> 2] | 0) != 1 : 0) {
	                                    c[k >> 2] = (c[(c[(c[g >> 2] | 0) + 52 >> 2] | 0) + 52 >> 2] | 0) + 28;
	                                    q = 40;
	                                    break a
	                                }
	                                c[k >> 2] = (c[(c[g >> 2] | 0) + 52 >> 2] | 0) + 28;
	                                q = 40
	                            }
	                            break
	                        }
	                        case 18:
	                        {
	                            c[l >> 2] = c[(c[h >> 2] | 0) + 4 >> 2];
	                            if ((c[c[g >> 2] >> 2] | 0) != 0 ? (c[c[g >> 2] >> 2] | 0) != 1 : 0) {
	                                c[k >> 2] = (c[(c[(c[g >> 2] | 0) + 52 >> 2] | 0) + 52 >> 2] | 0) + 44;
	                                q = 40;
	                                break a
	                            }
	                            c[k >> 2] = (c[(c[g >> 2] | 0) + 52 >> 2] | 0) + 44;
	                            q = 40;
	                            break
	                        }
	                        case 14:
	                        {
	                            c[l >> 2] = c[(c[h >> 2] | 0) + 8 >> 2];
	                            if ((c[c[g >> 2] >> 2] | 0) != 0 ? (c[c[g >> 2] >> 2] | 0) != 1 : 0) {
	                                c[k >> 2] = (c[(c[(c[g >> 2] | 0) + 52 >> 2] | 0) + 52 >> 2] | 0) + 40;
	                                q = 40;
	                                break a
	                            }
	                            c[k >> 2] = (c[(c[g >> 2] | 0) + 52 >> 2] | 0) + 40;
	                            q = 40;
	                            break
	                        }
	                        case 16:
	                        {
	                            if (!(c[(c[h >> 2] | 0) + 36 >> 2] & 8)) {
	                                c[l >> 2] = c[(c[h >> 2] | 0) + 8 >> 2];
	                                if ((c[c[g >> 2] >> 2] | 0) != 0 ? (c[c[g >> 2] >> 2] | 0) != 1 : 0) {
	                                    c[k >> 2] = (c[(c[(c[g >> 2] | 0) + 52 >> 2] | 0) + 52 >> 2] | 0) + 36;
	                                    q = 40;
	                                    break a
	                                }
	                                c[k >> 2] = (c[(c[g >> 2] | 0) + 52 >> 2] | 0) + 36;
	                                q = 40
	                            }
	                            break
	                        }
	                        case 24:
	                        case 22:
	                        case 23:
	                        {
	                            c[l >> 2] = c[(c[h >> 2] | 0) + 16 >> 2];
	                            if ((c[c[g >> 2] >> 2] | 0) != 0 ? (c[c[g >> 2] >> 2] | 0) != 1 : 0) {
	                                c[k >> 2] = (c[(c[(c[g >> 2] | 0) + 52 >> 2] | 0) + 52 >> 2] | 0) + 76;
	                                q = 40;
	                                break a
	                            }
	                            c[k >> 2] = (c[(c[g >> 2] | 0) + 52 >> 2] | 0) + 76;
	                            q = 40;
	                            break
	                        }
	                        case 17:
	                        {
	                            if (!(c[(c[h >> 2] | 0) + 28 >> 2] & 2)) {
	                                c[l >> 2] = c[(c[h >> 2] | 0) + 16 >> 2];
	                                if ((c[c[g >> 2] >> 2] | 0) != 0 ? (c[c[g >> 2] >> 2] | 0) != 1 : 0) {
	                                    c[k >> 2] = (c[(c[(c[g >> 2] | 0) + 52 >> 2] | 0) + 52 >> 2] | 0) + 56;
	                                    q = 40;
	                                    break a
	                                }
	                                c[k >> 2] = (c[(c[g >> 2] | 0) + 52 >> 2] | 0) + 56;
	                                q = 40
	                            }
	                            break
	                        }
	                        case 15:
	                        {
	                            c[l >> 2] = c[(c[h >> 2] | 0) + 8 >> 2];
	                            if ((c[c[g >> 2] >> 2] | 0) != 0 ? (c[c[g >> 2] >> 2] | 0) != 1 : 0) {
	                                c[k >> 2] = (c[(c[(c[g >> 2] | 0) + 52 >> 2] | 0) + 52 >> 2] | 0) + 32;
	                                q = 40;
	                                break a
	                            }
	                            c[k >> 2] = (c[(c[g >> 2] | 0) + 52 >> 2] | 0) + 32;
	                            q = 40;
	                            break
	                        }
	                        default:
	                            xB(c[f >> 2] | 0, 160568, 160592)
	                    } while (0);
	                    if ((q | 0) == 40) {
	                        q = 0;
	                        if ((c[c[k >> 2] >> 2] | 0) == 0 ? (b = Jj(10, c[(c[f >> 2] | 0) + 80 >> 2] | 0) | 0, c[c[k >> 2] >> 2] = b, (c[c[k >> 2] >> 2] | 0) == 0) : 0) {
	                            q = 42;
	                            break
	                        }
	                        c[j >> 2] = Lj(c[c[k >> 2] >> 2] | 0, c[l >> 2] | 0, c[h >> 2] | 0) | 0;
	                        if ((c[j >> 2] | 0) != 0 ? (c[n >> 2] = 0, b = c[f >> 2] | 0, a = FC(c[h >> 2] | 0) | 0, r = c[h >> 2] | 0, s = MD(c[h >> 2] | 0) | 0, AB(b, 1761, a, r, 160672, s, YD(n, c[h >> 2] | 0) | 0), (c[n >> 2] | 0) != 0) : 0) {
	                            zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                            c[n >> 2] = 0
	                        }
	                    }
	                    c[m >> 2] = (c[m >> 2] | 0) + 1
	                }
	                if ((q | 0) == 42) {
	                    xB(c[f >> 2] | 0, 160568, 160632);
	                    c[e >> 2] = -1;
	                    p = c[e >> 2] | 0;
	                    i = d;
	                    return p | 0
	                }
	                b:do if (c[(c[g >> 2] | 0) + 24 >> 2] | 0) {
	                    c[o >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                    while (1) {
	                        if (((c[(c[o >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[(c[(c[o >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] & 2 | 0) == 0 : 0) ? (XC(c[f >> 2] | 0, c[(c[o >> 2] | 0) + 12 >> 2] | 0) | 0) == -1 : 0)break;
	                        c[o >> 2] = c[c[o >> 2] >> 2];
	                        if (!(c[o >> 2] | 0))break b
	                    }
	                    c[e >> 2] = -1;
	                    p = c[e >> 2] | 0;
	                    i = d;
	                    return p | 0
	                } while (0);
	                c[e >> 2] = 0;
	                p = c[e >> 2] | 0;
	                i = d;
	                return p | 0
	            }

	            function YC(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if ((c[f >> 2] | 0) == 0 | (c[e >> 2] | 0) == 0) {
	                    i = d;
	                    return
	                }
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 48 >> 2] & 256 | 0) != 0 : 0) {
	                    i = d;
	                    return
	                }
	                b = (c[e >> 2] | 0) + 48 | 0;
	                c[b >> 2] = c[b >> 2] | 256;
	                do if ((c[(c[e >> 2] | 0) + 28 >> 2] | 0) == 0 ? (c[(c[e >> 2] | 0) + 56 >> 2] | 0) != 0 : 0) {
	                    c[g >> 2] = wE(c[(c[f >> 2] | 0) + 36 >> 2] | 0, c[(c[e >> 2] | 0) + 56 >> 2] | 0, c[(c[e >> 2] | 0) + 60 >> 2] | 0) | 0;
	                    if (!(c[g >> 2] | 0)) {
	                        xE(c[f >> 2] | 0, 3004, c[e >> 2] | 0, c[(c[e >> 2] | 0) + 36 >> 2] | 0, 155448, c[(c[e >> 2] | 0) + 56 >> 2] | 0, c[(c[e >> 2] | 0) + 60 >> 2] | 0, 1, 160528);
	                        break
	                    } else {
	                        c[(c[e >> 2] | 0) + 28 >> 2] = c[g >> 2];
	                        break
	                    }
	                } while (0);
	                do if (c[(c[e >> 2] | 0) + 64 >> 2] | 0) {
	                    c[h >> 2] = yE(c[(c[f >> 2] | 0) + 36 >> 2] | 0, c[(c[e >> 2] | 0) + 64 >> 2] | 0, c[(c[e >> 2] | 0) + 68 >> 2] | 0) | 0;
	                    if (!(c[h >> 2] | 0)) {
	                        xE(c[f >> 2] | 0, 3004, c[e >> 2] | 0, 0, 160544, c[(c[e >> 2] | 0) + 64 >> 2] | 0, c[(c[e >> 2] | 0) + 68 >> 2] | 0, 14, 0);
	                        break
	                    }
	                    YC(c[h >> 2] | 0, c[f >> 2] | 0);
	                    c[(c[e >> 2] | 0) + 80 >> 2] = c[h >> 2];
	                    if (!(c[(c[e >> 2] | 0) + 28 >> 2] | 0))c[(c[e >> 2] | 0) + 28 >> 2] = c[(c[h >> 2] | 0) + 28 >> 2]
	                } while (0);
	                if (c[(c[e >> 2] | 0) + 28 >> 2] | 0) {
	                    i = d;
	                    return
	                }
	                if (c[(c[e >> 2] | 0) + 56 >> 2] | 0) {
	                    i = d;
	                    return
	                }
	                if (c[(c[e >> 2] | 0) + 64 >> 2] | 0) {
	                    i = d;
	                    return
	                }
	                h = IH(45) | 0;
	                c[(c[e >> 2] | 0) + 28 >> 2] = h;
	                i = d;
	                return
	            }

	            function ZC(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if ((c[(c[e >> 2] | 0) + 64 >> 2] | 0) == 0 ? (b = wE(c[(c[f >> 2] | 0) + 36 >> 2] | 0, c[(c[e >> 2] | 0) + 56 >> 2] | 0, c[(c[e >> 2] | 0) + 60 >> 2] | 0) | 0, c[(c[e >> 2] | 0) + 64 >> 2] = b, (c[(c[e >> 2] | 0) + 64 >> 2] | 0) == 0) : 0) {
	                    xE(c[f >> 2] | 0, 3004, c[e >> 2] | 0, c[(c[e >> 2] | 0) + 36 >> 2] | 0, 151424, c[(c[e >> 2] | 0) + 56 >> 2] | 0, c[(c[e >> 2] | 0) + 60 >> 2] | 0, 4, 0);
	                    i = d;
	                    return
	                }
	                do if ((c[c[e >> 2] >> 2] | 0) != 4) {
	                    if ((c[c[e >> 2] >> 2] | 0) == 1 ? (c[(c[e >> 2] | 0) + 88 >> 2] | 0) != 45 : 0)break;
	                    if (!(c[(c[e >> 2] | 0) + 28 >> 2] | 0)) {
	                        i = d;
	                        return
	                    }
	                    if ((c[c[(c[e >> 2] | 0) + 28 >> 2] >> 2] | 0) != 25) {
	                        i = d;
	                        return
	                    }
	                    if (!(c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + 12 >> 2] | 0)) {
	                        i = d;
	                        return
	                    }
	                    if ((c[c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + 12 >> 2] >> 2] | 0) != 2e3) {
	                        i = d;
	                        return
	                    }
	                    c[g >> 2] = c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + 12 >> 2];
	                    c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + 12 >> 2] = 0;
	                    c[h >> 2] = AE(c[(c[f >> 2] | 0) + 36 >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[(c[g >> 2] | 0) + 16 >> 2] | 0) | 0;
	                    if (!(c[h >> 2] | 0)) {
	                        b = c[f >> 2] | 0;
	                        a = FC(c[(c[e >> 2] | 0) + 28 >> 2] | 0) | 0;
	                        xE(b, 3004, 0, a, 160064, c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0, 0);
	                        c[(c[e >> 2] | 0) + 28 >> 2] = 0;
	                        i = d;
	                        return
	                    }
	                    if (!(c[(c[h >> 2] | 0) + 12 >> 2] | 0)) {
	                        c[(c[e >> 2] | 0) + 28 >> 2] = 0;
	                        i = d;
	                        return
	                    }
	                    c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + 12 >> 2] = c[(c[h >> 2] | 0) + 12 >> 2];
	                    if ((c[c[(c[h >> 2] | 0) + 12 >> 2] >> 2] | 0) != 8) {
	                        i = d;
	                        return
	                    }
	                    if ((c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + 20 >> 2] | 0) == 1) {
	                        i = d;
	                        return
	                    }
	                    a = c[f >> 2] | 0;
	                    AB(a, 3091, FC(c[(c[e >> 2] | 0) + 28 >> 2] | 0) | 0, 0, 160416, 0, 0);
	                    i = d;
	                    return
	                } while (0);
	                if (c[(c[e >> 2] | 0) + 48 >> 2] & 128) {
	                    zE(c[f >> 2] | 0, c[e >> 2] | 0) | 0;
	                    i = d;
	                    return
	                }
	                if (!(c[(c[e >> 2] | 0) + 48 >> 2] & 64)) {
	                    i = d;
	                    return
	                }
	                if (c[(c[e >> 2] | 0) + 28 >> 2] | 0) {
	                    i = d;
	                    return
	                }
	                if (!(c[(c[e >> 2] | 0) + 56 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                h = wE(c[(c[f >> 2] | 0) + 36 >> 2] | 0, c[(c[e >> 2] | 0) + 56 >> 2] | 0, c[(c[e >> 2] | 0) + 60 >> 2] | 0) | 0;
	                c[(c[e >> 2] | 0) + 28 >> 2] = h;
	                if (c[(c[e >> 2] | 0) + 28 >> 2] | 0) {
	                    if ((c[c[(c[e >> 2] | 0) + 28 >> 2] >> 2] | 0) == 4) {
	                        i = d;
	                        return
	                    }
	                    if ((c[c[(c[e >> 2] | 0) + 28 >> 2] >> 2] | 0) == 1 ? (c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + 88 >> 2] | 0) != 45 : 0) {
	                        i = d;
	                        return
	                    }
	                }
	                c[(c[e >> 2] | 0) + 28 >> 2] = 0;
	                xE(c[f >> 2] | 0, 3004, c[e >> 2] | 0, c[(c[e >> 2] | 0) + 36 >> 2] | 0, 160400, c[(c[e >> 2] | 0) + 56 >> 2] | 0, c[(c[e >> 2] | 0) + 60 >> 2] | 0, 4, 0);
	                i = d;
	                return
	            }

	            function _C(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (c[(c[f >> 2] | 0) + 60 >> 2] & 256) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                b = (c[f >> 2] | 0) + 60 | 0;
	                c[b >> 2] = c[b >> 2] | 256;
	                if (c[(c[f >> 2] | 0) + 48 >> 2] | 0) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                a:do if (c[(c[f >> 2] | 0) + 24 >> 2] | 0) {
	                    c[h >> 2] = wE(c[(c[g >> 2] | 0) + 36 >> 2] | 0, c[(c[f >> 2] | 0) + 24 >> 2] | 0, c[(c[f >> 2] | 0) + 28 >> 2] | 0) | 0;
	                    do if (c[h >> 2] | 0) {
	                        if ((c[c[h >> 2] >> 2] | 0) != 4) {
	                            if ((c[c[h >> 2] >> 2] | 0) != 1)break;
	                            if ((c[(c[h >> 2] | 0) + 88 >> 2] | 0) == 45)break
	                        }
	                        c[(c[f >> 2] | 0) + 48 >> 2] = c[h >> 2];
	                        break a
	                    } while (0);
	                    xE(c[g >> 2] | 0, 3004, c[f >> 2] | 0, c[(c[f >> 2] | 0) + 52 >> 2] | 0, 155448, c[(c[f >> 2] | 0) + 24 >> 2] | 0, c[(c[f >> 2] | 0) + 28 >> 2] | 0, 4, 0);
	                    c[e >> 2] = c[(c[g >> 2] | 0) + 16 >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } else {
	                    b = IH(46) | 0;
	                    c[(c[f >> 2] | 0) + 48 >> 2] = b
	                } while (0);
	                c[e >> 2] = 0;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function $C(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[g >> 2] | 0) == 0 | (c[f >> 2] | 0) == 0) {
	                    c[e >> 2] = -1;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                if ((c[(c[f >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[c[(c[f >> 2] | 0) + 12 >> 2] >> 2] | 0) == 2e3 : 0) {
	                    c[h >> 2] = c[(c[f >> 2] | 0) + 12 >> 2];
	                    b = BE(c[(c[g >> 2] | 0) + 36 >> 2] | 0, c[(c[h >> 2] | 0) + 12 >> 2] | 0, c[(c[h >> 2] | 0) + 16 >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 12 >> 2] = b;
	                    if (!(c[(c[f >> 2] | 0) + 12 >> 2] | 0)) {
	                        xE(c[g >> 2] | 0, 3004, c[f >> 2] | 0, c[(c[f >> 2] | 0) + 20 >> 2] | 0, 160064, c[(c[h >> 2] | 0) + 12 >> 2] | 0, c[(c[h >> 2] | 0) + 16 >> 2] | 0, 15, 0);
	                        c[e >> 2] = c[(c[g >> 2] | 0) + 16 >> 2];
	                        j = c[e >> 2] | 0;
	                        i = d;
	                        return j | 0
	                    } else {
	                        c[e >> 2] = 0;
	                        j = c[e >> 2] | 0;
	                        i = d;
	                        return j | 0
	                    }
	                }
	                c[e >> 2] = 0;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function aD(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (c[(c[f >> 2] | 0) + 4 >> 2] | 0) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[h >> 2] = CE(c[(c[g >> 2] | 0) + 36 >> 2] | 0, c[(c[f >> 2] | 0) + 12 >> 2] | 0, c[(c[f >> 2] | 0) + 16 >> 2] | 0) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    xE(c[g >> 2] | 0, 3004, 0, c[(c[f >> 2] | 0) + 20 >> 2] | 0, 160064, c[(c[f >> 2] | 0) + 12 >> 2] | 0, c[(c[f >> 2] | 0) + 16 >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0, 0);
	                    c[e >> 2] = c[(c[g >> 2] | 0) + 16 >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } else {
	                    c[(c[f >> 2] | 0) + 4 >> 2] = c[h >> 2];
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                return 0
	            }

	            function bD(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[g >> 2] = c[(c[f >> 2] | 0) + 12 >> 2];
	                while (1) {
	                    if (!(c[g >> 2] | 0))break;
	                    do if ((c[(c[g >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2] | 0) == 2e3 : 0) {
	                        c[h >> 2] = c[(c[g >> 2] | 0) + 12 >> 2];
	                        c[(c[g >> 2] | 0) + 12 >> 2] = 0;
	                        c[j >> 2] = AE(c[(c[e >> 2] | 0) + 36 >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[(c[h >> 2] | 0) + 12 >> 2] | 0, c[(c[h >> 2] | 0) + 16 >> 2] | 0) | 0;
	                        if (!(c[j >> 2] | 0)) {
	                            f = c[e >> 2] | 0;
	                            b = FC(c[g >> 2] | 0) | 0;
	                            xE(f, 3004, 0, b, 160064, c[(c[h >> 2] | 0) + 12 >> 2] | 0, c[(c[h >> 2] | 0) + 16 >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0, 0);
	                            break
	                        }
	                        b = c[j >> 2] | 0;
	                        if ((c[c[j >> 2] >> 2] | 0) != 17) {
	                            c[(c[g >> 2] | 0) + 12 >> 2] = b;
	                            break
	                        }
	                        if (c[b + 12 >> 2] | 0)if ((c[c[(c[j >> 2] | 0) + 12 >> 2] >> 2] | 0) == 8) {
	                            b = c[e >> 2] | 0;
	                            AB(b, 3091, FC(c[g >> 2] | 0) | 0, 0, 160280, 0, 0);
	                            break
	                        } else {
	                            c[(c[g >> 2] | 0) + 12 >> 2] = c[j >> 2];
	                            break
	                        }
	                    } while (0);
	                    c[g >> 2] = c[(c[g >> 2] | 0) + 8 >> 2]
	                }
	                i = d;
	                return
	            }

	            function cD(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[c[f >> 2] >> 2] | 0) != 24) {
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                if (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) {
	                    b = DE(c[(c[g >> 2] | 0) + 36 >> 2] | 0, c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0;
	                    c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] = b;
	                    if (!(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0)) {
	                        xE(c[g >> 2] | 0, 3004, c[f >> 2] | 0, c[(c[f >> 2] | 0) + 12 >> 2] | 0, 160144, c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0, 23, 0);
	                        c[e >> 2] = c[(c[g >> 2] | 0) + 16 >> 2];
	                        k = c[e >> 2] | 0;
	                        i = d;
	                        return k | 0
	                    }
	                    if ((c[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] >> 2] | 0) == 24) {
	                        AB(c[g >> 2] | 0, 3080, 0, c[f >> 2] | 0, 160152, 0, 0);
	                        c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] = 0;
	                        c[e >> 2] = c[(c[g >> 2] | 0) + 16 >> 2];
	                        k = c[e >> 2] | 0;
	                        i = d;
	                        return k | 0
	                    }
	                    if ((c[(c[f >> 2] | 0) + 32 >> 2] | 0) != (c[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) + 32 >> 2] | 0)) {
	                        c[h >> 2] = 0;
	                        c[j >> 2] = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2];
	                        b = c[g >> 2] | 0;
	                        a = c[f >> 2] | 0;
	                        AB(b, 3080, 0, a, 160184, BB(h, c[(c[j >> 2] | 0) + 20 >> 2] | 0, c[(c[j >> 2] | 0) + 16 >> 2] | 0) | 0, 0);
	                        if (c[h >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                            c[h >> 2] = 0
	                        }
	                        c[e >> 2] = c[(c[g >> 2] | 0) + 16 >> 2];
	                        k = c[e >> 2] | 0;
	                        i = d;
	                        return k | 0
	                    }
	                }
	                c[e >> 2] = 0;
	                k = c[e >> 2] | 0;
	                i = d;
	                return k | 0
	            }

	            function dD(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(BE(c[(c[g >> 2] | 0) + 36 >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0, c[(c[f >> 2] | 0) + 12 >> 2] | 0) | 0)) {
	                    xE(c[g >> 2] | 0, 3004, 0, c[(c[f >> 2] | 0) + 4 >> 2] | 0, 160064, c[(c[f >> 2] | 0) + 8 >> 2] | 0, c[(c[f >> 2] | 0) + 12 >> 2] | 0, 15, 0);
	                    c[e >> 2] = 3004;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                } else {
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                return 0
	            }

	            function eD(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if ((c[c[e >> 2] >> 2] | 0) == 1) {
	                    i = d;
	                    return
	                }
	                if (!(c[(c[e >> 2] | 0) + 64 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                EE(c[f >> 2] | 0, c[e >> 2] | 0, c[(c[e >> 2] | 0) + 64 >> 2] | 0) | 0;
	                i = d;
	                return
	            }

	            function fD(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if ((c[c[e >> 2] >> 2] | 0) != 17) {
	                    i = d;
	                    return
	                }
	                if (!(c[(c[e >> 2] | 0) + 12 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                c[g >> 2] = FE(c[e >> 2] | 0, c[(c[(c[e >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2] | 0) | 0;
	                if (!(c[g >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                c[h >> 2] = 0;
	                b = c[f >> 2] | 0;
	                f = FC(c[g >> 2] | 0) | 0;
	                GE(b, 3075, 0, f, 159968, BB(h, c[(c[e >> 2] | 0) + 20 >> 2] | 0, c[(c[e >> 2] | 0) + 16 >> 2] | 0) | 0);
	                if (c[h >> 2] | 0) {
	                    zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                    c[h >> 2] = 0
	                }
	                c[(c[g >> 2] | 0) + 12 >> 2] = 0;
	                i = d;
	                return
	            }

	            function gD(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[(c[f >> 2] | 0) + 56 >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                if (!(c[(c[f >> 2] | 0) + 36 >> 2] & 16)) {
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                c[h >> 2] = HE(c[f >> 2] | 0, c[(c[f >> 2] | 0) + 56 >> 2] | 0) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                c[j >> 2] = 0;
	                b = c[g >> 2] | 0;
	                a = FC(c[h >> 2] | 0) | 0;
	                GE(b, 3073, 0, a, 159912, YD(j, c[f >> 2] | 0) | 0);
	                if (c[j >> 2] | 0) {
	                    zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                    c[j >> 2] = 0
	                }
	                c[(c[h >> 2] | 0) + 4 >> 2] = 0;
	                c[e >> 2] = c[(c[g >> 2] | 0) + 16 >> 2];
	                k = c[e >> 2] | 0;
	                i = d;
	                return k | 0
	            }

	            function hD(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[d + 8 >> 2] = a;
	                c[e >> 2] = b;
	                c[f >> 2] = c[(c[e >> 2] | 0) + 12 >> 2];
	                while (1) {
	                    if (!(c[f >> 2] | 0))break;
	                    if ((c[(c[f >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[c[(c[f >> 2] | 0) + 12 >> 2] >> 2] | 0) == 17 : 0) {
	                        e = (c[f >> 2] | 0) + 12 | 0;
	                        if (!(c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2] | 0)) {
	                            c[e >> 2] = 0;
	                            c[f >> 2] = c[(c[f >> 2] | 0) + 8 >> 2];
	                            continue
	                        } else {
	                            c[(c[f >> 2] | 0) + 12 >> 2] = c[(c[e >> 2] | 0) + 12 >> 2];
	                            c[f >> 2] = c[(c[f >> 2] | 0) + 8 >> 2];
	                            continue
	                        }
	                    }
	                    c[f >> 2] = c[(c[f >> 2] | 0) + 8 >> 2]
	                }
	                i = d;
	                return
	            }

	            function iD(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[(c[g >> 2] | 0) + 56 >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] & 1 | 0) == 0 : 0) {
	                    b = (c[g >> 2] | 0) + 36 | 0;
	                    c[b >> 2] = c[b >> 2] | 1;
	                    if ((IE(c[f >> 2] | 0, c[g >> 2] | 0, (c[g >> 2] | 0) + 40 | 0, c[(c[g >> 2] | 0) + 56 >> 2] | 0, 0) | 0) == -1) {
	                        c[e >> 2] = -1;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    } else {
	                        c[e >> 2] = 0;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                }
	                c[e >> 2] = 0;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function jD(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[c[g >> 2] >> 2] | 0) != 4) {
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                if ((c[c[g >> 2] >> 2] | 0) != 1 ? (c[(c[g >> 2] | 0) + 48 >> 2] & 536870912 | 0) == 0 : 0) {
	                    b = (c[g >> 2] | 0) + 48 | 0;
	                    c[b >> 2] = c[b >> 2] | 536870912;
	                    b = c[g >> 2] | 0;
	                    do if (c[(c[g >> 2] | 0) + 48 >> 2] & 64) {
	                        if (!(c[b + 28 >> 2] | 0)) {
	                            xB(c[f >> 2] | 0, 153152, 153192);
	                            c[e >> 2] = -1;
	                            h = c[e >> 2] | 0;
	                            i = d;
	                            return h | 0
	                        }
	                    } else {
	                        a = c[g >> 2] | 0;
	                        if (c[b + 48 >> 2] & 128) {
	                            if (c[a + 92 >> 2] | 0)break;
	                            xB(c[f >> 2] | 0, 153152, 153232);
	                            c[e >> 2] = -1;
	                            h = c[e >> 2] | 0;
	                            i = d;
	                            return h | 0
	                        }
	                        if (!(c[a + 64 >> 2] | 0)) {
	                            xB(c[f >> 2] | 0, 153152, 153272);
	                            c[e >> 2] = -1;
	                            h = c[e >> 2] | 0;
	                            i = d;
	                            return h | 0
	                        }
	                        if (((c[c[(c[g >> 2] | 0) + 64 >> 2] >> 2] | 0) != 1 ? (c[(c[(c[g >> 2] | 0) + 64 >> 2] | 0) + 48 >> 2] & 536870912 | 0) == 0 : 0) ? (jD(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 64 >> 2] | 0) | 0) == -1 : 0) {
	                            c[e >> 2] = -1;
	                            h = c[e >> 2] | 0;
	                            i = d;
	                            return h | 0
	                        }
	                        a = c[g >> 2] | 0;
	                        if (c[(c[(c[g >> 2] | 0) + 64 >> 2] | 0) + 48 >> 2] & 256) {
	                            j = a + 48 | 0;
	                            c[j >> 2] = c[j >> 2] | 256;
	                            break
	                        }
	                        j = c[g >> 2] | 0;
	                        if (c[(c[a + 64 >> 2] | 0) + 48 >> 2] & 64) {
	                            a = j + 48 | 0;
	                            c[a >> 2] = c[a >> 2] | 64;
	                            c[(c[g >> 2] | 0) + 28 >> 2] = c[(c[(c[g >> 2] | 0) + 64 >> 2] | 0) + 28 >> 2];
	                            break
	                        }
	                        if (c[(c[j + 64 >> 2] | 0) + 48 >> 2] & 128) {
	                            j = (c[g >> 2] | 0) + 48 | 0;
	                            c[j >> 2] = c[j >> 2] | 128
	                        }
	                    } while (0);
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                c[e >> 2] = 0;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function kD(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (c[(c[g >> 2] | 0) + 48 >> 2] & 128) {
	                    c[e >> 2] = JE(c[f >> 2] | 0, c[g >> 2] | 0, c[(c[g >> 2] | 0) + 92 >> 2] | 0) | 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                } else {
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                return 0
	            }

	            function lD(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[j >> 2] = c[(c[f >> 2] | 0) + 20 >> 2];
	                if ((c[c[g >> 2] >> 2] | 0) != 4) {
	                    c[e >> 2] = -1;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                if ((c[c[g >> 2] >> 2] | 0) != 1 ? (c[(c[g >> 2] | 0) + 48 >> 2] & 4194304 | 0) == 0 : 0) {
	                    b = (c[g >> 2] | 0) + 48 | 0;
	                    c[b >> 2] = c[b >> 2] | 4194304;
	                    c[(c[g >> 2] | 0) + 52 >> 2] = 4;
	                    a:do if (c[(c[g >> 2] | 0) + 64 >> 2] | 0) {
	                        if ((c[c[(c[g >> 2] | 0) + 64 >> 2] >> 2] | 0) != 1 ? (c[(c[(c[g >> 2] | 0) + 64 >> 2] | 0) + 48 >> 2] & 4194304 | 0) == 0 : 0)KE(c[(c[g >> 2] | 0) + 64 >> 2] | 0, c[f >> 2] | 0) | 0;
	                        if ((c[(c[g >> 2] | 0) + 92 >> 2] | 0) != 0 ? (LE(c[f >> 2] | 0, c[g >> 2] | 0) | 0) == -1 : 0) {
	                            c[e >> 2] = -1;
	                            k = c[e >> 2] | 0;
	                            i = d;
	                            return k | 0
	                        }
	                        c[h >> 2] = ME(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                        if ((c[h >> 2] | 0) != -1) {
	                            do if (!(c[h >> 2] | 0)) {
	                                c[h >> 2] = NE(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                                if ((c[h >> 2] | 0) == -1)break a;
	                                if (!(c[h >> 2] | 0)) {
	                                    c[h >> 2] = OE(c[g >> 2] | 0, c[f >> 2] | 0) | 0;
	                                    if ((c[h >> 2] | 0) == -1)break a;
	                                    if (!(c[h >> 2] | 0)) {
	                                        if (!((c[(c[g >> 2] | 0) + 96 >> 2] | 0) == 0 ? (c[(c[(c[g >> 2] | 0) + 64 >> 2] | 0) + 96 >> 2] | 0) == 0 : 0)) {
	                                            c[h >> 2] = PE(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                                            if ((c[h >> 2] | 0) == -1)break a;
	                                            if (c[h >> 2] | 0)break
	                                        }
	                                        c[h >> 2] = QE(c[g >> 2] | 0) | 0;
	                                        if ((c[h >> 2] | 0) == -1)break a;
	                                        if (!(c[h >> 2] | 0))RE(c[g >> 2] | 0)
	                                    }
	                                }
	                            } while (0);
	                            if ((c[j >> 2] | 0) != (c[(c[f >> 2] | 0) + 20 >> 2] | 0)) {
	                                c[e >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                                k = c[e >> 2] | 0;
	                                i = d;
	                                return k | 0
	                            } else {
	                                c[e >> 2] = 0;
	                                k = c[e >> 2] | 0;
	                                i = d;
	                                return k | 0
	                            }
	                        }
	                    } else xB(c[f >> 2] | 0, 147168, 147208); while (0);
	                    c[e >> 2] = -1;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                c[e >> 2] = 0;
	                k = c[e >> 2] | 0;
	                i = d;
	                return k | 0
	            }

	            function mD(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[(c[g >> 2] | 0) + 48 >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                if (c[(c[g >> 2] | 0) + 44 >> 2] | 0) {
	                    b = (SE(c[(c[g >> 2] | 0) + 48 >> 2] | 0, 23) | 0) != 0;
	                    a = c[f >> 2] | 0;
	                    k = c[g >> 2] | 0;
	                    if (b) {
	                        AB(a, 3090, 0, k, 159552, 0, 0);
	                        c[e >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                        j = c[e >> 2] | 0;
	                        i = d;
	                        return j | 0
	                    }
	                    c[h >> 2] = yB(a, c[k + 52 >> 2] | 0, c[(c[g >> 2] | 0) + 48 >> 2] | 0, c[(c[g >> 2] | 0) + 44 >> 2] | 0, (c[g >> 2] | 0) + 68 | 0, 1, 1, 0) | 0;
	                    if (c[h >> 2] | 0) {
	                        k = c[f >> 2] | 0;
	                        if ((c[h >> 2] | 0) < 0) {
	                            xB(k, 159840, 141832);
	                            c[e >> 2] = -1;
	                            j = c[e >> 2] | 0;
	                            i = d;
	                            return j | 0
	                        } else {
	                            AB(k, 3079, 0, c[g >> 2] | 0, 159680, 0, 0);
	                            c[e >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                            j = c[e >> 2] | 0;
	                            i = d;
	                            return j | 0
	                        }
	                    }
	                }
	                c[e >> 2] = 0;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function nD(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = -1;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                if (((c[(c[g >> 2] | 0) + 28 >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2] | 0) == 15 : 0) {
	                    if (((c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 44 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 60 >> 2] & 512 | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 16 >> 2] & 1 | 0) == 0 : 0) {
	                        GE(c[f >> 2] | 0, 3078, c[g >> 2] | 0, 0, 159424, 0);
	                        c[e >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                        j = c[e >> 2] | 0;
	                        i = d;
	                        return j | 0
	                    }
	                    if ((c[(c[g >> 2] | 0) + 32 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 48 >> 2] | 0) != 0 : 0) {
	                        b = (SE(c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 48 >> 2] | 0, 23) | 0) != 0;
	                        a = c[f >> 2] | 0;
	                        k = c[g >> 2] | 0;
	                        if (b) {
	                            AB(a, 3089, 0, k, 159552, 0, 0);
	                            c[e >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                            j = c[e >> 2] | 0;
	                            i = d;
	                            return j | 0
	                        }
	                        c[h >> 2] = yB(a, c[k + 20 >> 2] | 0, c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 48 >> 2] | 0, c[(c[g >> 2] | 0) + 28 >> 2] | 0, (c[g >> 2] | 0) + 32 | 0, 1, 1, 0) | 0;
	                        if (c[h >> 2] | 0) {
	                            k = c[f >> 2] | 0;
	                            if ((c[h >> 2] | 0) < 0) {
	                                xB(k, 159640, 141832);
	                                c[e >> 2] = -1;
	                                j = c[e >> 2] | 0;
	                                i = d;
	                                return j | 0
	                            } else {
	                                AB(k, 3089, 0, c[g >> 2] | 0, 159680, 0, 0);
	                                c[e >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                                j = c[e >> 2] | 0;
	                                i = d;
	                                return j | 0
	                            }
	                        }
	                    }
	                    if ((c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 60 >> 2] & 1 | 0) == 0 : 0) {
	                        if (!(VD(c[(c[g >> 2] | 0) + 32 >> 2] | 0, c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2] | 0) | 0))GE(c[f >> 2] | 0, 3078, c[g >> 2] | 0, 0, 159728, c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 44 >> 2] | 0);
	                        c[e >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                        j = c[e >> 2] | 0;
	                        i = d;
	                        return j | 0
	                    }
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[e >> 2] = 0;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function oD(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                d = i;
	                i = i + 48 | 0;
	                e = d + 40 | 0;
	                f = d + 36 | 0;
	                g = d + 32 | 0;
	                h = d + 28 | 0;
	                j = d + 24 | 0;
	                k = d + 20 | 0;
	                l = d + 16 | 0;
	                m = d + 12 | 0;
	                n = d + 8 | 0;
	                o = d + 4 | 0;
	                p = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                a:do if ((c[(c[g >> 2] | 0) + 56 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 56 >> 2] | 0) + 4 >> 2] | 0) > 1 : 0) {
	                    c[h >> 2] = c[(c[g >> 2] | 0) + 56 >> 2];
	                    c[n >> 2] = 0;
	                    c[l >> 2] = (c[(c[h >> 2] | 0) + 4 >> 2] | 0) - 1;
	                    b:while (1) {
	                        if ((c[l >> 2] | 0) < 0)break a;
	                        c[j >> 2] = c[(c[c[h >> 2] >> 2] | 0) + (c[l >> 2] << 2) >> 2];
	                        c:do if ((c[l >> 2] | 0) > 0) {
	                            c[m >> 2] = (c[l >> 2] | 0) - 1;
	                            while (1) {
	                                if ((c[m >> 2] | 0) < 0) {
	                                    q = 15;
	                                    break c
	                                }
	                                c[k >> 2] = c[(c[c[h >> 2] >> 2] | 0) + (c[m >> 2] << 2) >> 2];
	                                if ((c[(c[(c[j >> 2] | 0) + 12 >> 2] | 0) + 8 >> 2] | 0) == (c[(c[(c[k >> 2] | 0) + 12 >> 2] | 0) + 8 >> 2] | 0) ? (c[(c[(c[j >> 2] | 0) + 12 >> 2] | 0) + 56 >> 2] | 0) == (c[(c[(c[k >> 2] | 0) + 12 >> 2] | 0) + 56 >> 2] | 0) : 0)break;
	                                c[m >> 2] = (c[m >> 2] | 0) + -1
	                            }
	                            c[o >> 2] = 0;
	                            b = c[f >> 2] | 0;
	                            a = c[(c[g >> 2] | 0) + 32 >> 2] | 0;
	                            r = c[g >> 2] | 0;
	                            AB(b, 3087, a, r, 152424, ZD(o, c[j >> 2] | 0) | 0, 0);
	                            if (c[o >> 2] | 0) {
	                                zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                                c[o >> 2] = 0
	                            }
	                            if ((TE(c[h >> 2] | 0, c[l >> 2] | 0) | 0) == -1) {
	                                q = 13;
	                                break b
	                            }
	                        } else q = 15; while (0);
	                        if (((q | 0) == 15 ? (q = 0, (c[(c[(c[j >> 2] | 0) + 12 >> 2] | 0) + 48 >> 2] | 0) != 0) : 0) ? (SE(c[(c[(c[j >> 2] | 0) + 12 >> 2] | 0) + 48 >> 2] | 0, 23) | 0) != 0 : 0) {
	                            if (c[n >> 2] | 0) {
	                                c[p >> 2] = 0;
	                                r = c[f >> 2] | 0;
	                                a = c[(c[g >> 2] | 0) + 32 >> 2] | 0;
	                                b = c[g >> 2] | 0;
	                                AB(r, 3087, a, b, 152440, ZD(p, c[j >> 2] | 0) | 0, 0);
	                                if (c[p >> 2] | 0) {
	                                    zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                                    c[p >> 2] = 0
	                                }
	                                if ((TE(c[h >> 2] | 0, c[l >> 2] | 0) | 0) == -1) {
	                                    q = 21;
	                                    break
	                                }
	                            }
	                            c[n >> 2] = 1
	                        }
	                        c[l >> 2] = (c[l >> 2] | 0) + -1
	                    }
	                    if ((q | 0) == 13) {
	                        c[e >> 2] = -1;
	                        s = c[e >> 2] | 0;
	                        i = d;
	                        return s | 0
	                    } else if ((q | 0) == 21) {
	                        c[e >> 2] = -1;
	                        s = c[e >> 2] | 0;
	                        i = d;
	                        return s | 0
	                    }
	                } while (0);
	                c[e >> 2] = 0;
	                s = c[e >> 2] | 0;
	                i = d;
	                return s | 0
	            }

	            function pD(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 16 | 0;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                g = b + 4 | 0;
	                h = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                c[g >> 2] = c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + 28 >> 2];
	                if (!(c[g >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    j = c[d >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                while (1) {
	                    a = c[g >> 2] | 0;
	                    if (!(c[(c[g >> 2] | 0) + 12 >> 2] | 0))c[g >> 2] = c[a >> 2]; else {
	                        c[h >> 2] = c[a + 4 >> 2];
	                        a = c[c[h >> 2] >> 2] | 0;
	                        if ((a | 0) == 16) {
	                            c[f >> 2] = UE(c[e >> 2] | 0, 1, c[h >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[(c[h >> 2] | 0) + 56 >> 2] | 0, c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 56 >> 2] | 0, c[(c[h >> 2] | 0) + 40 >> 2] | 0, c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 40 >> 2] | 0) | 0;
	                            if ((c[f >> 2] | 0) == -1) {
	                                k = 8;
	                                break
	                            }
	                        } else if ((a | 0) == 5 | (a | 0) == 4)c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 8 >> 2] = 0;
	                        c[g >> 2] = c[c[g >> 2] >> 2]
	                    }
	                    if (!(c[g >> 2] | 0)) {
	                        k = 11;
	                        break
	                    }
	                }
	                if ((k | 0) == 8) {
	                    c[d >> 2] = -1;
	                    j = c[d >> 2] | 0;
	                    i = b;
	                    return j | 0
	                } else if ((k | 0) == 11) {
	                    c[d >> 2] = 0;
	                    j = c[d >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                return 0
	            }

	            function qD(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                d = i;
	                i = i + 48 | 0;
	                e = d + 40 | 0;
	                f = d + 36 | 0;
	                g = d + 32 | 0;
	                h = d + 28 | 0;
	                j = d + 24 | 0;
	                k = d + 20 | 0;
	                l = d + 16 | 0;
	                m = d + 12 | 0;
	                n = d + 8 | 0;
	                o = d + 4 | 0;
	                p = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                c[j >> 2] = c[(c[f >> 2] | 0) + 20 >> 2];
	                c[k >> 2] = c[(c[g >> 2] | 0) + 64 >> 2];
	                if ((c[c[g >> 2] >> 2] | 0) != 1 ? (c[(c[g >> 2] | 0) + 48 >> 2] & 4194304 | 0) == 0 : 0) {
	                    b = (c[g >> 2] | 0) + 48 | 0;
	                    c[b >> 2] = c[b >> 2] | 4194304;
	                    a:do if (c[k >> 2] | 0) {
	                        if ((c[c[k >> 2] >> 2] | 0) != 1 ? (c[(c[k >> 2] | 0) + 48 >> 2] & 4194304 | 0) == 0 : 0)KE(c[k >> 2] | 0, c[f >> 2] | 0) | 0;
	                        if (c[(c[k >> 2] | 0) + 48 >> 2] & 8388608) {
	                            c[e >> 2] = 0;
	                            q = c[e >> 2] | 0;
	                            i = d;
	                            return q | 0
	                        }
	                        c[h >> 2] = VE(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                        if ((c[h >> 2] | 0) != -1) {
	                            b:do if (!(c[h >> 2] | 0)) {
	                                c:do if ((c[(c[g >> 2] | 0) + 52 >> 2] | 0) == 4) {
	                                    if (!((c[c[k >> 2] >> 2] | 0) != 5 ? (c[(c[k >> 2] | 0) + 88 >> 2] | 0) != 45 : 0))r = 16;
	                                    if (((r | 0) == 16 ? (c[(c[k >> 2] | 0) + 104 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 48 >> 2] & 4 | 0) != 0 : 0) {
	                                        if (c[(c[g >> 2] | 0) + 104 >> 2] | 0) {
	                                            c[l >> 2] = c[(c[g >> 2] | 0) + 104 >> 2];
	                                            c[(c[g >> 2] | 0) + 104 >> 2] = 0
	                                        } else c[l >> 2] = c[(c[k >> 2] | 0) + 104 >> 2];
	                                        c[m >> 2] = WE(c[f >> 2] | 0, c[(c[f >> 2] | 0) + 36 >> 2] | 0, 4, 0, c[(c[g >> 2] | 0) + 112 >> 2] | 0, c[(c[g >> 2] | 0) + 36 >> 2] | 0, 0) | 0;
	                                        if (!(c[m >> 2] | 0))break a;
	                                        c[c[m >> 2] >> 2] = 4;
	                                        c[(c[m >> 2] | 0) + 64 >> 2] = c[l >> 2];
	                                        c[(c[m >> 2] | 0) + 68 >> 2] = c[(c[g >> 2] | 0) + 68 >> 2];
	                                        c[(c[g >> 2] | 0) + 68 >> 2] = 0;
	                                        c[(c[m >> 2] | 0) + 96 >> 2] = c[(c[g >> 2] | 0) + 96 >> 2];
	                                        c[(c[g >> 2] | 0) + 96 >> 2] = 0;
	                                        c[(c[g >> 2] | 0) + 104 >> 2] = c[m >> 2];
	                                        do if ((c[c[l >> 2] >> 2] | 0) != 1) {
	                                            if (c[(c[l >> 2] | 0) + 48 >> 2] & 4194304)break;
	                                            KE(c[l >> 2] | 0, c[f >> 2] | 0) | 0
	                                        } while (0);
	                                        c[h >> 2] = jD(c[f >> 2] | 0, c[m >> 2] | 0) | 0;
	                                        if ((c[h >> 2] | 0) == -1)break a;
	                                        if (c[h >> 2] | 0)break b;
	                                        c[h >> 2] = lD(c[f >> 2] | 0, c[m >> 2] | 0) | 0;
	                                        if ((c[h >> 2] | 0) == -1)break a;
	                                        if (c[h >> 2] | 0)break b; else break
	                                    }
	                                    if (!((c[c[k >> 2] >> 2] | 0) != 5 ? (c[(c[k >> 2] | 0) + 88 >> 2] | 0) != 45 : 0))r = 31;
	                                    if (((r | 0) == 31 ? (c[(c[k >> 2] | 0) + 52 >> 2] | 0) == 3 : 0) ? (c[(c[g >> 2] | 0) + 48 >> 2] & 4 | 0) != 0 : 0) {
	                                        if ((c[(c[g >> 2] | 0) + 104 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 104 >> 2] | 0) + 64 >> 2] | 0) != 0 : 0)break;
	                                        GE(c[f >> 2] | 0, 3069, c[g >> 2] | 0, 0, 149808, c[(c[g >> 2] | 0) + 8 >> 2] | 0);
	                                        break a
	                                    }
	                                    if (!((c[c[k >> 2] >> 2] | 0) != 5 ? (c[(c[k >> 2] | 0) + 88 >> 2] | 0) != 45 : 0))r = 38;
	                                    if ((r | 0) == 38 ? (c[(c[g >> 2] | 0) + 48 >> 2] & 2 | 0) != 0 : 0)if (!(c[(c[k >> 2] | 0) + 104 >> 2] | 0)) {
	                                        GE(c[f >> 2] | 0, 3069, c[g >> 2] | 0, 0, 149976, c[(c[g >> 2] | 0) + 8 >> 2] | 0);
	                                        break a
	                                    } else {
	                                        c[(c[g >> 2] | 0) + 104 >> 2] = c[(c[k >> 2] | 0) + 104 >> 2];
	                                        break
	                                    }
	                                    if ((c[c[k >> 2] >> 2] | 0) != 4) {
	                                        if ((c[c[k >> 2] >> 2] | 0) == 1 ? (c[(c[k >> 2] | 0) + 88 >> 2] | 0) != 45 : 0)r = 45
	                                    } else r = 45;
	                                    if ((r | 0) == 45 ? (c[(c[g >> 2] | 0) + 48 >> 2] & 2 | 0) != 0 : 0) {
	                                        c[(c[g >> 2] | 0) + 104 >> 2] = c[k >> 2];
	                                        break
	                                    }
	                                    GE(c[f >> 2] | 0, 3069, c[g >> 2] | 0, 0, 150112, c[(c[g >> 2] | 0) + 8 >> 2] | 0);
	                                    break a
	                                } else {
	                                    c[n >> 2] = 0;
	                                    c[o >> 2] = c[(c[g >> 2] | 0) + 28 >> 2];
	                                    d:do if (!(c[o >> 2] | 0))r = 55; else {
	                                        do if ((c[c[o >> 2] >> 2] | 0) == 25) {
	                                            if ((c[c[(c[o >> 2] | 0) + 12 >> 2] >> 2] | 0) != 8 ? (c[c[(c[o >> 2] | 0) + 12 >> 2] >> 2] | 0) != 6 : 0) {
	                                                if ((c[c[(c[o >> 2] | 0) + 12 >> 2] >> 2] | 0) != 7)break;
	                                                if (c[(c[o >> 2] | 0) + 16 >> 2] | 0)break
	                                            }
	                                            if (!(c[(c[(c[o >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2] | 0)) {
	                                                r = 55;
	                                                break d
	                                            }
	                                        } while (0);
	                                        c[(c[g >> 2] | 0) + 52 >> 2] = 2
	                                    } while (0);
	                                    do if ((r | 0) == 55) {
	                                        if (!(c[(c[g >> 2] | 0) + 48 >> 2] & 1)) {
	                                            c[(c[g >> 2] | 0) + 52 >> 2] = 1;
	                                            break
	                                        }
	                                        if (!((c[o >> 2] | 0) != 0 ? (c[c[(c[o >> 2] | 0) + 12 >> 2] >> 2] | 0) == 6 : 0)) {
	                                            c[o >> 2] = XE(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 36 >> 2] | 0, 1, 1) | 0;
	                                            if (!(c[o >> 2] | 0))break a;
	                                            b = YE(c[f >> 2] | 0, c[(c[f >> 2] | 0) + 36 >> 2] | 0, 6, c[(c[g >> 2] | 0) + 36 >> 2] | 0) | 0;
	                                            c[(c[o >> 2] | 0) + 12 >> 2] = b;
	                                            if (!(c[(c[o >> 2] | 0) + 12 >> 2] | 0))break a;
	                                            c[(c[g >> 2] | 0) + 28 >> 2] = c[o >> 2]
	                                        }
	                                        c[n >> 2] = 1;
	                                        c[(c[g >> 2] | 0) + 52 >> 2] = 2
	                                    } while (0);
	                                    b = c[(c[g >> 2] | 0) + 52 >> 2] | 0;
	                                    if (c[(c[g >> 2] | 0) + 48 >> 2] & 4) {
	                                        if ((b | 0) == 1)break;
	                                        if (!(c[(c[g >> 2] | 0) + 48 >> 2] & 1))break;
	                                        c[(c[g >> 2] | 0) + 52 >> 2] = 3;
	                                        break
	                                    }
	                                    a = c[(c[k >> 2] | 0) + 52 >> 2] | 0;
	                                    if ((b | 0) == 1) {
	                                        c[(c[g >> 2] | 0) + 52 >> 2] = a;
	                                        c[(c[g >> 2] | 0) + 28 >> 2] = c[(c[k >> 2] | 0) + 28 >> 2];
	                                        c[(c[g >> 2] | 0) + 104 >> 2] = c[(c[k >> 2] | 0) + 104 >> 2];
	                                        break
	                                    }
	                                    b = (c[(c[g >> 2] | 0) + 48 >> 2] & 1 | 0) != 0;
	                                    if ((a | 0) == 1) {
	                                        if (!b)break;
	                                        c[(c[g >> 2] | 0) + 52 >> 2] = 3;
	                                        break
	                                    }
	                                    if (b)c[(c[g >> 2] | 0) + 52 >> 2] = 3;
	                                    do if ((c[(c[g >> 2] | 0) + 28 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                                        if ((c[c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 12 >> 2] >> 2] | 0) != 8)break;
	                                        b = c[f >> 2] | 0;
	                                        AB(b, 3091, FC(c[g >> 2] | 0) | 0, 0, 150216, 0, 0);
	                                        break c
	                                    } while (0);
	                                    do if (c[(c[k >> 2] | 0) + 28 >> 2] | 0) {
	                                        if (!(c[(c[(c[k >> 2] | 0) + 28 >> 2] | 0) + 12 >> 2] | 0))break;
	                                        if ((c[c[(c[(c[k >> 2] | 0) + 28 >> 2] | 0) + 12 >> 2] >> 2] | 0) != 8)break;
	                                        b = c[f >> 2] | 0;
	                                        AB(b, 3091, FC(c[g >> 2] | 0) | 0, 0, 150480, 0, 0);
	                                        break c
	                                    } while (0);
	                                    if (c[n >> 2] | 0) {
	                                        c[(c[(c[o >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2] = c[(c[k >> 2] | 0) + 28 >> 2];
	                                        break
	                                    }
	                                    c[p >> 2] = c[(c[g >> 2] | 0) + 28 >> 2];
	                                    c[o >> 2] = XE(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 36 >> 2] | 0, 1, 1) | 0;
	                                    if (!(c[o >> 2] | 0))break a;
	                                    b = YE(c[f >> 2] | 0, c[(c[f >> 2] | 0) + 36 >> 2] | 0, 6, c[(c[g >> 2] | 0) + 36 >> 2] | 0) | 0;
	                                    c[(c[o >> 2] | 0) + 12 >> 2] = b;
	                                    if (!(c[(c[o >> 2] | 0) + 12 >> 2] | 0))break a;
	                                    c[(c[g >> 2] | 0) + 28 >> 2] = c[o >> 2];
	                                    b = XE(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 36 >> 2] | 0, c[(c[(c[k >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] | 0, c[(c[(c[k >> 2] | 0) + 28 >> 2] | 0) + 20 >> 2] | 0) | 0;
	                                    c[(c[(c[o >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2] = b;
	                                    if (!(c[(c[(c[o >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2] | 0))break a;
	                                    c[o >> 2] = c[(c[(c[o >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2];
	                                    c[(c[o >> 2] | 0) + 12 >> 2] = c[(c[(c[k >> 2] | 0) + 28 >> 2] | 0) + 12 >> 2];
	                                    c[(c[o >> 2] | 0) + 8 >> 2] = c[p >> 2]
	                                } while (0);
	                                c[h >> 2] = ZE(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                                if ((c[h >> 2] | 0) == -1)break a;
	                                if (!(c[h >> 2] | 0)) {
	                                    c[h >> 2] = _E(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                                    if ((c[h >> 2] | 0) == -1)break a;
	                                    if (!(c[h >> 2] | 0))if ((c[j >> 2] | 0) != (c[(c[f >> 2] | 0) + 20 >> 2] | 0)) {
	                                        c[e >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                                        q = c[e >> 2] | 0;
	                                        i = d;
	                                        return q | 0
	                                    } else {
	                                        c[e >> 2] = 0;
	                                        q = c[e >> 2] | 0;
	                                        i = d;
	                                        return q | 0
	                                    }
	                                }
	                            } while (0);
	                            b = (c[g >> 2] | 0) + 48 | 0;
	                            c[b >> 2] = c[b >> 2] | 8388608;
	                            c[e >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                            q = c[e >> 2] | 0;
	                            i = d;
	                            return q | 0
	                        }
	                    } else xB(c[f >> 2] | 0, 149776, 147208); while (0);
	                    f = (c[g >> 2] | 0) + 48 | 0;
	                    c[f >> 2] = c[f >> 2] | 8388608;
	                    c[e >> 2] = -1;
	                    q = c[e >> 2] | 0;
	                    i = d;
	                    return q | 0
	                }
	                c[e >> 2] = 0;
	                q = c[e >> 2] | 0;
	                i = d;
	                return q | 0
	            }

	            function rD(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if (c[(c[e >> 2] | 0) + 48 >> 2] & 262144) {
	                    i = d;
	                    return
	                }
	                b = (c[e >> 2] | 0) + 48 | 0;
	                c[b >> 2] = c[b >> 2] | 262144;
	                if ($E(c[f >> 2] | 0, c[e >> 2] | 0) | 0) {
	                    i = d;
	                    return
	                }
	                aF(c[f >> 2] | 0, c[e >> 2] | 0);
	                i = d;
	                return
	            }

	            function sD(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[c[f >> 2] >> 2] | 0) != 5) {
	                    i = d;
	                    return
	                }
	                if (c[(c[f >> 2] | 0) + 108 >> 2] | 0) {
	                    i = d;
	                    return
	                }
	                if ((c[(c[f >> 2] | 0) + 52 >> 2] | 0) != 2 ? (c[(c[f >> 2] | 0) + 52 >> 2] | 0) != 3 : 0) {
	                    i = d;
	                    return
	                }
	                c[(c[g >> 2] | 0) + 64 >> 2] = 0;
	                b = xz() | 0;
	                c[(c[g >> 2] | 0) + 64 >> 2] = b;
	                if (!(c[(c[g >> 2] | 0) + 64 >> 2] | 0)) {
	                    b = c[33976] | 0;
	                    a = c[33980] | 0;
	                    c[e >> 2] = c[(c[f >> 2] | 0) + 8 >> 2];
	                    Db[b & 511](a, 157984, e);
	                    i = d;
	                    return
	                }
	                e = Bz(c[(c[g >> 2] | 0) + 64 >> 2] | 0) | 0;
	                c[(c[g >> 2] | 0) + 76 >> 2] = e;
	                bF(c[g >> 2] | 0, c[(c[f >> 2] | 0) + 28 >> 2] | 0) | 0;
	                Cz(c[(c[g >> 2] | 0) + 64 >> 2] | 0, c[(c[g >> 2] | 0) + 76 >> 2] | 0) | 0;
	                e = Oz(c[(c[g >> 2] | 0) + 64 >> 2] | 0) | 0;
	                c[(c[f >> 2] | 0) + 108 >> 2] = e;
	                if (c[(c[f >> 2] | 0) + 108 >> 2] | 0) {
	                    if ((wz(c[(c[f >> 2] | 0) + 108 >> 2] | 0) | 0) != 1)GE(c[g >> 2] | 0, 3070, c[f >> 2] | 0, c[(c[f >> 2] | 0) + 36 >> 2] | 0, 158072, 0)
	                } else GE(c[g >> 2] | 0, 3069, c[f >> 2] | 0, c[(c[f >> 2] | 0) + 36 >> 2] | 0, 158032, 0);
	                c[(c[g >> 2] | 0) + 76 >> 2] = 0;
	                yz(c[(c[g >> 2] | 0) + 64 >> 2] | 0);
	                c[(c[g >> 2] | 0) + 64 >> 2] = 0;
	                i = d;
	                return
	            }

	            function tD(a) {
	                a = a | 0;
	                var b = 0, d = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 28 | 0;
	                f = b + 24 | 0;
	                g = b + 20 | 0;
	                h = b + 16 | 0;
	                j = b + 12 | 0;
	                k = b + 8 | 0;
	                l = b + 4 | 0;
	                m = b;
	                c[f >> 2] = a;
	                c[h >> 2] = 0;
	                c[j >> 2] = 0;
	                a = c[f >> 2] | 0;
	                if (c[(c[f >> 2] | 0) + 84 >> 2] | 0)c[l >> 2] = c[a + 84 >> 2]; else c[l >> 2] = Pi(c[a + 24 >> 2] | 0) | 0;
	                a = c[f >> 2] | 0;
	                if (!(c[l >> 2] | 0)) {
	                    AB(a, 1, 0, 0, 141128, 0, 0);
	                    c[d >> 2] = 1;
	                    n = c[d >> 2] | 0;
	                    i = b;
	                    return n | 0
	                }
	                c[a + 96 >> 2] = -1;
	                c[(c[f >> 2] | 0) + 84 >> 2] = c[l >> 2];
	                c[k >> 2] = c[l >> 2];
	                a:while (1) {
	                    if (!(c[k >> 2] | 0)) {
	                        o = 48;
	                        break
	                    }
	                    if ((c[(c[f >> 2] | 0) + 176 >> 2] | 0) != -1 ? (c[(c[f >> 2] | 0) + 96 >> 2] | 0) >= (c[(c[f >> 2] | 0) + 176 >> 2] | 0) : 0)o = 45; else o = 10;
	                    do if ((o | 0) == 10) {
	                        o = 0;
	                        if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                            a = (c[f >> 2] | 0) + 96 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1;
	                            if ((uD(c[f >> 2] | 0) | 0) == -1)break a;
	                            c[j >> 2] = c[(c[f >> 2] | 0) + 108 >> 2];
	                            c[(c[j >> 2] | 0) + 4 >> 2] = c[k >> 2];
	                            c[(c[j >> 2] | 0) + 8 >> 2] = e[(c[k >> 2] | 0) + 56 >> 1];
	                            c[(c[j >> 2] | 0) + 12 >> 2] = c[(c[k >> 2] | 0) + 8 >> 2];
	                            if (c[(c[k >> 2] | 0) + 36 >> 2] | 0)c[(c[j >> 2] | 0) + 16 >> 2] = c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2];
	                            a = (c[j >> 2] | 0) + 32 | 0;
	                            c[a >> 2] = c[a >> 2] | 32;
	                            c[(c[f >> 2] | 0) + 168 >> 2] = 0;
	                            if (c[(c[k >> 2] | 0) + 44 >> 2] | 0) {
	                                c[g >> 2] = c[(c[k >> 2] | 0) + 44 >> 2];
	                                do {
	                                    if (c[(c[g >> 2] | 0) + 36 >> 2] | 0)c[m >> 2] = c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2]; else c[m >> 2] = 0;
	                                    a = c[f >> 2] | 0;
	                                    p = c[g >> 2] | 0;
	                                    q = c[(c[j >> 2] | 0) + 8 >> 2] | 0;
	                                    r = c[(c[g >> 2] | 0) + 8 >> 2] | 0;
	                                    s = c[m >> 2] | 0;
	                                    c[h >> 2] = vD(a, p, q, r, s, 0, _h(c[(c[g >> 2] | 0) + 32 >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] | 0, 1) | 0, 1) | 0;
	                                    if ((c[h >> 2] | 0) == -1) {
	                                        o = 20;
	                                        break a
	                                    }
	                                    c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2]
	                                } while ((c[g >> 2] | 0) != 0)
	                            }
	                            c[h >> 2] = wD(c[f >> 2] | 0) | 0;
	                            if (c[h >> 2] | 0)if ((c[h >> 2] | 0) == -1) {
	                                o = 24;
	                                break a
	                            } else break;
	                            if ((c[(c[f >> 2] | 0) + 176 >> 2] | 0) != -1 ? (c[(c[f >> 2] | 0) + 96 >> 2] | 0) >= (c[(c[f >> 2] | 0) + 176 >> 2] | 0) : 0)break
	                        } else {
	                            if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) != 3 ? (c[(c[k >> 2] | 0) + 4 >> 2] | 0) != 4 : 0) {
	                                if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 6) {
	                                    o = 36;
	                                    break a
	                                }
	                                if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 5) {
	                                    o = 36;
	                                    break a
	                                } else break
	                            }
	                            if ((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 32 >> 2] & 32 | 0) != 0 : 0) {
	                                s = (c[j >> 2] | 0) + 32 | 0;
	                                c[s >> 2] = c[s >> 2] ^ 32
	                            }
	                            c[h >> 2] = yD(c[f >> 2] | 0, c[(c[k >> 2] | 0) + 4 >> 2] | 0, c[(c[k >> 2] | 0) + 40 >> 2] | 0, -1, 1, 0) | 0;
	                            if ((c[h >> 2] | 0) < 0) {
	                                o = 33;
	                                break a
	                            }
	                        }
	                        if (c[(c[k >> 2] | 0) + 12 >> 2] | 0) {
	                            c[k >> 2] = c[(c[k >> 2] | 0) + 12 >> 2];
	                            continue a
	                        }
	                    } while (0);
	                    while (1) {
	                        if ((o | 0) == 45) {
	                            o = 0;
	                            t = c[k >> 2] | 0;
	                            if (c[(c[k >> 2] | 0) + 24 >> 2] | 0)break;
	                            c[k >> 2] = c[t + 20 >> 2]
	                        }
	                        if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) != 1) {
	                            o = 45;
	                            continue
	                        }
	                        u = c[f >> 2] | 0;
	                        if ((c[k >> 2] | 0) != (c[(c[(c[f >> 2] | 0) + 108 >> 2] | 0) + 4 >> 2] | 0)) {
	                            o = 41;
	                            break a
	                        }
	                        c[h >> 2] = xD(u) | 0;
	                        if ((c[h >> 2] | 0) != 0 & (c[h >> 2] | 0) < 0) {
	                            o = 43;
	                            break a
	                        }
	                        if ((c[k >> 2] | 0) == (c[l >> 2] | 0)) {
	                            o = 48;
	                            break a
	                        } else o = 45
	                    }
	                    c[k >> 2] = c[t + 24 >> 2]
	                }
	                if ((o | 0) == 20)xB(c[f >> 2] | 0, 155912, 144696); else if ((o | 0) == 24)xB(c[f >> 2] | 0, 155912, 144744); else if ((o | 0) == 33)xB(c[f >> 2] | 0, 155936, 141336); else if ((o | 0) == 36)xB(c[f >> 2] | 0, 155936, 155960); else if ((o | 0) == 41)xB(u, 155936, 156168); else if ((o | 0) == 43)xB(c[f >> 2] | 0, 155936, 141688); else if ((o | 0) == 48) {
	                    c[d >> 2] = c[h >> 2];
	                    n = c[d >> 2] | 0;
	                    i = b;
	                    return n | 0
	                }
	                c[d >> 2] = -1;
	                n = c[d >> 2] | 0;
	                i = b;
	                return n | 0
	            }

	            function uD(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                a = cF(c[e >> 2] | 0) | 0;
	                c[(c[e >> 2] | 0) + 108 >> 2] = a;
	                a = c[e >> 2] | 0;
	                if (!(c[(c[e >> 2] | 0) + 108 >> 2] | 0)) {
	                    xB(a, 155592, 155624);
	                    c[d >> 2] = -1;
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                } else {
	                    c[a + 168 >> 2] = 0;
	                    c[d >> 2] = 0;
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                }
	                return 0
	            }

	            function vD(a, b, d, e, f, g, h, j) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                var k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                k = i;
	                i = i + 48 | 0;
	                l = k + 36 | 0;
	                m = k + 32 | 0;
	                n = k + 28 | 0;
	                o = k + 24 | 0;
	                p = k + 20 | 0;
	                q = k + 16 | 0;
	                r = k + 12 | 0;
	                s = k + 8 | 0;
	                t = k + 4 | 0;
	                u = k;
	                c[m >> 2] = a;
	                c[n >> 2] = b;
	                c[o >> 2] = d;
	                c[p >> 2] = e;
	                c[q >> 2] = f;
	                c[r >> 2] = g;
	                c[s >> 2] = h;
	                c[t >> 2] = j;
	                c[u >> 2] = dF(c[m >> 2] | 0) | 0;
	                if (!(c[u >> 2] | 0)) {
	                    xB(c[m >> 2] | 0, 155408, 145304);
	                    c[l >> 2] = -1;
	                    v = c[l >> 2] | 0;
	                    i = k;
	                    return v | 0
	                }
	                c[(c[u >> 2] | 0) + 4 >> 2] = c[n >> 2];
	                c[(c[u >> 2] | 0) + 8 >> 2] = c[o >> 2];
	                c[(c[u >> 2] | 0) + 44 >> 2] = 1;
	                c[(c[u >> 2] | 0) + 12 >> 2] = c[p >> 2];
	                c[(c[u >> 2] | 0) + 16 >> 2] = c[q >> 2];
	                if (c[r >> 2] | 0) {
	                    r = (c[u >> 2] | 0) + 32 | 0;
	                    c[r >> 2] = c[r >> 2] | 1
	                }
	                do if (c[q >> 2] | 0) {
	                    if (qy(c[p >> 2] | 0, 155432) | 0) {
	                        if (!(qy(c[(c[u >> 2] | 0) + 16 >> 2] | 0, c[38860] | 0) | 0))break;
	                        c[(c[u >> 2] | 0) + 48 >> 2] = 2;
	                        break
	                    }
	                    if (qy(c[p >> 2] | 0, 155448) | 0) {
	                        if (!(qy(c[(c[u >> 2] | 0) + 16 >> 2] | 0, c[38860] | 0) | 0))break;
	                        c[(c[u >> 2] | 0) + 48 >> 2] = 1;
	                        break
	                    }
	                    if (qy(c[p >> 2] | 0, 155456) | 0) {
	                        if (!(qy(c[(c[u >> 2] | 0) + 16 >> 2] | 0, c[38860] | 0) | 0))break;
	                        c[(c[u >> 2] | 0) + 48 >> 2] = 3;
	                        break
	                    }
	                    r = (qy(c[p >> 2] | 0, 155472) | 0) != 0;
	                    o = c[(c[u >> 2] | 0) + 16 >> 2] | 0;
	                    if (r) {
	                        if (!(qy(o, c[38860] | 0) | 0))break;
	                        c[(c[u >> 2] | 0) + 48 >> 2] = 4;
	                        break
	                    } else {
	                        if (!(qy(o, c[38876] | 0) | 0))break;
	                        c[(c[u >> 2] | 0) + 48 >> 2] = 5;
	                        break
	                    }
	                } while (0);
	                c[(c[u >> 2] | 0) + 20 >> 2] = c[s >> 2];
	                if (c[t >> 2] | 0) {
	                    t = (c[u >> 2] | 0) + 32 | 0;
	                    c[t >> 2] = c[t >> 2] | 2
	                }
	                if (c[(c[u >> 2] | 0) + 48 >> 2] | 0)c[(c[u >> 2] | 0) + 44 >> 2] = 17;
	                c[l >> 2] = 0;
	                v = c[l >> 2] | 0;
	                i = k;
	                return v | 0
	            }

	            function wD(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                if ((c[(c[e >> 2] | 0) + 176 >> 2] | 0) != -1 ? (c[(c[e >> 2] | 0) + 96 >> 2] | 0) >= (c[(c[e >> 2] | 0) + 176 >> 2] | 0) : 0)xB(c[e >> 2] | 0, 144776, 144800); else h = 4;
	                a:do if ((h | 0) == 4) {
	                    do if (c[(c[e >> 2] | 0) + 92 >> 2] | 0) {
	                        c[f >> 2] = eF(c[e >> 2] | 0) | 0;
	                        if (!(c[f >> 2] | 0)) {
	                            Wj(c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 48 >> 2] | 0, 357, c[e >> 2] | 0);
	                            break
	                        }
	                        if ((c[f >> 2] | 0) == -1)break a;
	                        c[(c[e >> 2] | 0) + 176 >> 2] = 0;
	                        c[d >> 2] = c[f >> 2];
	                        j = c[d >> 2] | 0;
	                        i = b;
	                        return j | 0
	                    } while (0);
	                    a = c[e >> 2] | 0;
	                    do if ((c[(c[e >> 2] | 0) + 96 >> 2] | 0) > 0) {
	                        c[f >> 2] = fF(a) | 0;
	                        if (c[f >> 2] | 0) {
	                            if ((c[f >> 2] | 0) >= 0)break;
	                            xB(c[e >> 2] | 0, 144776, 144816);
	                            break a
	                        }
	                        if ((c[(c[e >> 2] | 0) + 96 >> 2] | 0) != (c[(c[e >> 2] | 0) + 176 >> 2] | 0))if ((c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 44 >> 2] | 0) == 0 ? (c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 28 >> 2] | 0) == 0 : 0) {
	                            xB(c[e >> 2] | 0, 144776, 144864);
	                            break a
	                        } else h = 19
	                    } else {
	                        k = yE(c[a + 20 >> 2] | 0, c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 16 >> 2] | 0) | 0;
	                        c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 44 >> 2] = k;
	                        if (!(c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 44 >> 2] | 0)) {
	                            c[f >> 2] = 1845;
	                            AB(c[e >> 2] | 0, c[f >> 2] | 0, 0, 0, 144944, 0, 0)
	                        } else h = 19
	                    } while (0);
	                    b:do if ((h | 0) == 19) {
	                        do if (c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 44 >> 2] | 0) {
	                            if ((c[c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 44 >> 2] >> 2] | 0) == 2) {
	                                c[f >> 2] = gF(c[e >> 2] | 0, g) | 0;
	                                if (c[f >> 2] | 0) {
	                                    if ((c[f >> 2] | 0) >= 0)break b;
	                                    xB(c[e >> 2] | 0, 144776, 145016);
	                                    break a
	                                }
	                                a = c[e >> 2] | 0;
	                                if (c[g >> 2] | 0) {
	                                    c[(c[e >> 2] | 0) + 176 >> 2] = c[a + 96 >> 2];
	                                    break b
	                                }
	                                if ((c[c[(c[a + 108 >> 2] | 0) + 44 >> 2] >> 2] | 0) != 14) {
	                                    c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 44 >> 2] = 0;
	                                    break
	                                }
	                            }
	                            c[f >> 2] = hF(c[e >> 2] | 0) | 0;
	                            if (c[f >> 2] | 0) {
	                                if ((c[f >> 2] | 0) >= 0)break b;
	                                xB(c[e >> 2] | 0, 144776, 145056);
	                                break a
	                            }
	                        } while (0);
	                        a = c[(c[e >> 2] | 0) + 108 >> 2] | 0;
	                        if (!(c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 28 >> 2] | 0)) {
	                            k = a + 32 | 0;
	                            c[k >> 2] = c[k >> 2] | 1024;
	                            c[f >> 2] = 1875;
	                            AB(c[e >> 2] | 0, c[f >> 2] | 0, 0, 0, 145096, 0, 0);
	                            break
	                        }
	                        k = c[e >> 2] | 0;
	                        if (c[(c[a + 28 >> 2] | 0) + 48 >> 2] & 1048576) {
	                            a = (c[k + 108 >> 2] | 0) + 32 | 0;
	                            c[a >> 2] = c[a >> 2] | 1024;
	                            c[f >> 2] = 1876;
	                            AB(c[e >> 2] | 0, c[f >> 2] | 0, 0, 0, 145128, 0, 0);
	                            break
	                        }
	                        if ((c[k + 116 >> 2] | 0) != 0 ? (c[f >> 2] = iF(c[e >> 2] | 0, 1) | 0, c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 80 >> 2] = 1, (c[f >> 2] | 0) == -1) : 0) {
	                            xB(c[e >> 2] | 0, 144776, 145160);
	                            break a
	                        }
	                        if ((c[c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 28 >> 2] >> 2] | 0) != 5 ? (c[(c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 28 >> 2] | 0) + 88 >> 2] | 0) != 45 : 0) {
	                            if (c[(c[e >> 2] | 0) + 168 >> 2] | 0)c[f >> 2] = kF(c[e >> 2] | 0) | 0
	                        } else h = 40;
	                        do if ((h | 0) == 40) {
	                            if ((c[(c[e >> 2] | 0) + 168 >> 2] | 0) == 0 ? (c[(c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 28 >> 2] | 0) + 116 >> 2] | 0) == 0 : 0)break;
	                            c[f >> 2] = jF(c[e >> 2] | 0) | 0
	                        } while (0);
	                        if (c[(c[e >> 2] | 0) + 168 >> 2] | 0)vB(c[e >> 2] | 0);
	                        if ((c[f >> 2] | 0) == -1) {
	                            xB(c[e >> 2] | 0, 144776, 145200);
	                            break a
	                        } else {
	                            c[f >> 2] = 0;
	                            break
	                        }
	                    } while (0);
	                    if (c[f >> 2] | 0)c[(c[e >> 2] | 0) + 176 >> 2] = c[(c[e >> 2] | 0) + 96 >> 2];
	                    c[d >> 2] = c[f >> 2];
	                    j = c[d >> 2] | 0;
	                    i = b;
	                    return j | 0
	                } while (0);
	                c[d >> 2] = -1;
	                j = c[d >> 2] | 0;
	                i = b;
	                return j | 0
	            }

	            function xD(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                b = i;
	                i = i + 80 | 0;
	                d = b + 76 | 0;
	                e = b + 72 | 0;
	                f = b + 68 | 0;
	                g = b + 64 | 0;
	                h = b + 24 | 0;
	                j = b + 20 | 0;
	                k = b + 16 | 0;
	                l = b + 12 | 0;
	                m = b + 8 | 0;
	                n = b + 4 | 0;
	                o = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                c[g >> 2] = c[(c[e >> 2] | 0) + 108 >> 2];
	                if (c[(c[e >> 2] | 0) + 168 >> 2] | 0)vB(c[e >> 2] | 0);
	                a:do if (!(c[(c[g >> 2] | 0) + 32 >> 2] & 512))if ((c[(c[g >> 2] | 0) + 28 >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 32 >> 2] & 1024 | 0) == 0 : 0) {
	                    if ((c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 52 >> 2] | 0) != 3 ? (c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 52 >> 2] | 0) != 2 : 0)p = 21; else p = 9;
	                    b:do if ((p | 0) == 9 ? (c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 88 >> 2] | 0) != 45 : 0)if (!(c[(c[g >> 2] | 0) + 32 >> 2] & 256)) {
	                        c[k >> 2] = 10;
	                        if ((c[(c[g >> 2] | 0) + 60 >> 2] | 0) == 0 ? (a = oz(c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 108 >> 2] | 0, 358, c[e >> 2] | 0) | 0, c[(c[g >> 2] | 0) + 60 >> 2] = a, (c[(c[g >> 2] | 0) + 60 >> 2] | 0) == 0) : 0) {
	                            xB(c[e >> 2] | 0, 141728, 141760);
	                            break a
	                        }
	                        if (c[(c[g >> 2] | 0) + 32 >> 2] & 4) {
	                            c[f >> 2] = 0;
	                            p = 21;
	                            break
	                        }
	                        sz(c[(c[g >> 2] | 0) + 60 >> 2] | 0, k, l, h, j) | 0;
	                        c[f >> 2] = qz(c[(c[g >> 2] | 0) + 60 >> 2] | 0, 0, 0) | 0;
	                        do if ((c[f >> 2] | 0) >= 0) {
	                            if ((c[f >> 2] | 0) == 0 ? (c[(c[g >> 2] | 0) + 32 >> 2] & 4 | 0) == 0 : 0)break;
	                            c[f >> 2] = 0;
	                            p = 21;
	                            break b
	                        } while (0);
	                        c[f >> 2] = 1;
	                        a = (c[g >> 2] | 0) + 32 | 0;
	                        c[a >> 2] = c[a >> 2] | 256;
	                        mF(c[e >> 2] | 0, 1871, 0, 0, 141800, c[k >> 2] | 0, c[l >> 2] | 0, h);
	                        p = 21
	                    } else p = 21; while (0);
	                    if ((p | 0) == 21 ? (c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 52 >> 2] | 0) == 2 : 0) {
	                        p = 81;
	                        break
	                    }
	                    if (c[(c[e >> 2] | 0) + 72 >> 2] | 0) {
	                        PH(c[(c[e >> 2] | 0) + 72 >> 2] | 0);
	                        c[(c[e >> 2] | 0) + 72 >> 2] = 0
	                    }
	                    a = c[g >> 2] | 0;
	                    if (!(c[(c[g >> 2] | 0) + 44 >> 2] | 0)) {
	                        do if ((c[c[a + 28 >> 2] >> 2] | 0) == 4)p = 28; else {
	                            if ((c[c[(c[g >> 2] | 0) + 28 >> 2] >> 2] | 0) == 1 ? (c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 88 >> 2] | 0) != 45 : 0) {
	                                p = 28;
	                                break
	                            }
	                            if ((c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 52 >> 2] | 0) != 4 ? (c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 52 >> 2] | 0) != 6 : 0)break;
	                            c[f >> 2] = nF(c[e >> 2] | 0, c[g >> 2] | 0, c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 104 >> 2] | 0, c[(c[g >> 2] | 0) + 20 >> 2] | 0) | 0
	                        } while (0);
	                        if ((p | 0) == 28)c[f >> 2] = nF(c[e >> 2] | 0, c[g >> 2] | 0, c[(c[g >> 2] | 0) + 28 >> 2] | 0, c[(c[g >> 2] | 0) + 20 >> 2] | 0) | 0;
	                        if ((c[f >> 2] | 0) >= 0) {
	                            p = 81;
	                            break
	                        }
	                        xB(c[e >> 2] | 0, 141728, 141832);
	                        break
	                    }
	                    if (((c[(c[a + 44 >> 2] | 0) + 76 >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 32 >> 2] & 32 | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 32 >> 2] & 4 | 0) == 0 : 0) {
	                        if (c[(c[g >> 2] | 0) + 32 >> 2] & 8) {
	                            c[f >> 2] = oF(c[e >> 2] | 0, c[(c[(c[g >> 2] | 0) + 44 >> 2] | 0) + 76 >> 2] | 0, (c[g >> 2] | 0) + 24 | 0) | 0;
	                            if (c[f >> 2] | 0) {
	                                if ((c[f >> 2] | 0) >= 0) {
	                                    p = 81;
	                                    break
	                                }
	                                xB(c[e >> 2] | 0, 141728, 141872);
	                                break
	                            }
	                        } else {
	                            do if ((c[c[(c[g >> 2] | 0) + 28 >> 2] >> 2] | 0) == 4)p = 44; else {
	                                if ((c[c[(c[g >> 2] | 0) + 28 >> 2] >> 2] | 0) == 1 ? (c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 88 >> 2] | 0) != 45 : 0) {
	                                    p = 44;
	                                    break
	                                }
	                                if ((c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 52 >> 2] | 0) != 4 ? (c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 52 >> 2] | 0) != 6 : 0)break;
	                                c[f >> 2] = nF(c[e >> 2] | 0, c[g >> 2] | 0, c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 104 >> 2] | 0, c[(c[(c[g >> 2] | 0) + 44 >> 2] | 0) + 76 >> 2] | 0) | 0
	                            } while (0);
	                            if ((p | 0) == 44)c[f >> 2] = nF(c[e >> 2] | 0, c[g >> 2] | 0, c[(c[g >> 2] | 0) + 28 >> 2] | 0, c[(c[(c[g >> 2] | 0) + 44 >> 2] | 0) + 76 >> 2] | 0) | 0;
	                            if (c[f >> 2] | 0) {
	                                if ((c[f >> 2] | 0) >= 0) {
	                                    p = 81;
	                                    break
	                                }
	                                xB(c[e >> 2] | 0, 141728, 141832);
	                                break
	                            }
	                        }
	                        if (!(c[(c[e >> 2] | 0) + 80 >> 2] & 1)) {
	                            p = 81;
	                            break
	                        }
	                        if (!(c[(c[g >> 2] | 0) + 4 >> 2] | 0)) {
	                            p = 81;
	                            break
	                        }
	                        c[n >> 2] = zC(c[(c[g >> 2] | 0) + 28 >> 2] | 0, c[(c[(c[g >> 2] | 0) + 44 >> 2] | 0) + 76 >> 2] | 0) | 0;
	                        if (c[n >> 2] | 0) {
	                            c[m >> 2] = li(c[n >> 2] | 0) | 0;
	                            zb[c[135736 >> 2] & 511](c[n >> 2] | 0)
	                        } else c[m >> 2] = li(c[(c[(c[g >> 2] | 0) + 44 >> 2] | 0) + 76 >> 2] | 0) | 0;
	                        if (!(c[m >> 2] | 0)) {
	                            xB(c[e >> 2] | 0, 141728, 141912);
	                            break
	                        } else {
	                            zi(c[(c[g >> 2] | 0) + 4 >> 2] | 0, c[m >> 2] | 0) | 0;
	                            p = 81;
	                            break
	                        }
	                    }
	                    if (!(c[(c[g >> 2] | 0) + 32 >> 2] & 4)) {
	                        do if ((c[c[(c[g >> 2] | 0) + 28 >> 2] >> 2] | 0) == 4)p = 63; else {
	                            if ((c[c[(c[g >> 2] | 0) + 28 >> 2] >> 2] | 0) == 1 ? (c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 88 >> 2] | 0) != 45 : 0) {
	                                p = 63;
	                                break
	                            }
	                            if ((c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 52 >> 2] | 0) != 4 ? (c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 52 >> 2] | 0) != 6 : 0)break;
	                            c[f >> 2] = nF(c[e >> 2] | 0, c[g >> 2] | 0, c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 104 >> 2] | 0, c[(c[g >> 2] | 0) + 20 >> 2] | 0) | 0
	                        } while (0);
	                        if ((p | 0) == 63)c[f >> 2] = nF(c[e >> 2] | 0, c[g >> 2] | 0, c[(c[g >> 2] | 0) + 28 >> 2] | 0, c[(c[g >> 2] | 0) + 20 >> 2] | 0) | 0;
	                        if (c[f >> 2] | 0) {
	                            if ((c[f >> 2] | 0) >= 0) {
	                                p = 81;
	                                break
	                            }
	                            xB(c[e >> 2] | 0, 141728, 141832);
	                            break
	                        }
	                        if ((c[(c[(c[g >> 2] | 0) + 44 >> 2] | 0) + 76 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 44 >> 2] | 0) + 48 >> 2] & 8 | 0) != 0 : 0) {
	                            if (c[(c[g >> 2] | 0) + 32 >> 2] & 128) {
	                                c[f >> 2] = 1856;
	                                AB(c[e >> 2] | 0, c[f >> 2] | 0, 0, 0, 141936, 0, 0);
	                                p = 81;
	                                break
	                            }
	                            a = c[g >> 2] | 0;
	                            if ((c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 52 >> 2] | 0) == 3) {
	                                if (qy(c[a + 20 >> 2] | 0, c[(c[(c[g >> 2] | 0) + 44 >> 2] | 0) + 76 >> 2] | 0) | 0) {
	                                    p = 81;
	                                    break
	                                }
	                                c[f >> 2] = 1857;
	                                AB(c[e >> 2] | 0, c[f >> 2] | 0, 0, 0, 142024, c[(c[g >> 2] | 0) + 20 >> 2] | 0, c[(c[(c[g >> 2] | 0) + 44 >> 2] | 0) + 76 >> 2] | 0);
	                                p = 81;
	                                break
	                            }
	                            if ((c[(c[a + 28 >> 2] | 0) + 52 >> 2] | 0) != 4 ? (c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 52 >> 2] | 0) != 6 : 0) {
	                                p = 81;
	                                break
	                            }
	                            if (!(qy(c[(c[g >> 2] | 0) + 20 >> 2] | 0, c[(c[(c[g >> 2] | 0) + 44 >> 2] | 0) + 76 >> 2] | 0) | 0)) {
	                                c[f >> 2] = 1858;
	                                AB(c[e >> 2] | 0, c[f >> 2] | 0, 0, 0, 142096, c[(c[g >> 2] | 0) + 20 >> 2] | 0, c[(c[(c[g >> 2] | 0) + 44 >> 2] | 0) + 76 >> 2] | 0);
	                                p = 81
	                            } else p = 81
	                        } else p = 81
	                    } else p = 81
	                } else p = 81; else {
	                    c[(c[e >> 2] | 0) + 176 >> 2] = (c[(c[e >> 2] | 0) + 96 >> 2] | 0) - 1;
	                    p = 81
	                } while (0);
	                c:do if ((p | 0) == 81) {
	                    if ((c[(c[e >> 2] | 0) + 96 >> 2] | 0) < 0) {
	                        c[d >> 2] = 0;
	                        q = c[d >> 2] | 0;
	                        i = b;
	                        return q | 0
	                    }
	                    if ((c[(c[e >> 2] | 0) + 96 >> 2] | 0) == (c[(c[e >> 2] | 0) + 176 >> 2] | 0))c[(c[e >> 2] | 0) + 176 >> 2] = -1;
	                    if ((c[(c[g >> 2] | 0) + 80 >> 2] | 0) != 0 ? (pF(c[e >> 2] | 0, c[(c[e >> 2] | 0) + 96 >> 2] | 0) | 0) == -1 : 0)break;
	                    do if (c[(c[g >> 2] | 0) + 56 >> 2] | 0) {
	                        if ((c[(c[e >> 2] | 0) + 184 >> 2] | 0) == 0 ? (c[(c[e >> 2] | 0) + 188 >> 2] | 0) == 0 : 0)break;
	                        if ((qF(c[e >> 2] | 0, c[g >> 2] | 0) | 0) == -1)break c
	                    } while (0);
	                    if ((c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 76 >> 2] | 0) != 0 ? (rF(c[e >> 2] | 0) | 0) == -1 : 0)break;
	                    do if ((c[(c[g >> 2] | 0) + 52 >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 96 >> 2] | 0) > 0 : 0) {
	                        if ((c[(c[e >> 2] | 0) + 184 >> 2] | 0) == 0 ? (c[(c[e >> 2] | 0) + 188 >> 2] | 0) == 0 : 0)break;
	                        if ((sF(c[e >> 2] | 0) | 0) == -1)break c
	                    } while (0);
	                    wB(c[e >> 2] | 0, c[g >> 2] | 0);
	                    m = c[e >> 2] | 0;
	                    if (!(c[(c[e >> 2] | 0) + 96 >> 2] | 0)) {
	                        n = m + 96 | 0;
	                        c[n >> 2] = (c[n >> 2] | 0) + -1;
	                        c[(c[e >> 2] | 0) + 108 >> 2] = 0;
	                        c[d >> 2] = 0;
	                        q = c[d >> 2] | 0;
	                        i = b;
	                        return q | 0
	                    }
	                    if (c[m + 112 >> 2] | 0) {
	                        c[o >> 2] = c[(c[e >> 2] | 0) + 112 >> 2];
	                        do {
	                            if ((c[(c[o >> 2] | 0) + 8 >> 2] | 0) == (c[(c[e >> 2] | 0) + 96 >> 2] | 0))c[(c[o >> 2] | 0) + 8 >> 2] = -1;
	                            c[o >> 2] = c[c[o >> 2] >> 2]
	                        } while ((c[o >> 2] | 0) != 0)
	                    }
	                    m = (c[e >> 2] | 0) + 96 | 0;
	                    c[m >> 2] = (c[m >> 2] | 0) + -1;
	                    c[(c[e >> 2] | 0) + 108 >> 2] = c[(c[(c[e >> 2] | 0) + 100 >> 2] | 0) + (c[(c[e >> 2] | 0) + 96 >> 2] << 2) >> 2];
	                    c[d >> 2] = c[f >> 2];
	                    q = c[d >> 2] | 0;
	                    i = b;
	                    return q | 0
	                } while (0);
	                c[(c[e >> 2] | 0) + 52 >> 2] = -1;
	                c[d >> 2] = -1;
	                q = c[d >> 2] | 0;
	                i = b;
	                return q | 0
	            }

	            function yD(a, b, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                j = i;
	                i = i + 32 | 0;
	                k = j + 24 | 0;
	                l = j + 20 | 0;
	                m = j + 16 | 0;
	                n = j + 12 | 0;
	                o = j + 8 | 0;
	                p = j + 4 | 0;
	                q = j;
	                c[l >> 2] = a;
	                c[m >> 2] = b;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                c[q >> 2] = h;
	                if (c[q >> 2] | 0)c[c[q >> 2] >> 2] = 0;
	                h = c[l >> 2] | 0;
	                if (c[(c[(c[l >> 2] | 0) + 108 >> 2] | 0) + 32 >> 2] & 4) {
	                    AB(h, 1848, 0, 0, 141368, 0, 0);
	                    c[k >> 2] = c[(c[l >> 2] | 0) + 52 >> 2];
	                    r = c[k >> 2] | 0;
	                    i = j;
	                    return r | 0
	                }
	                g = c[l >> 2] | 0;
	                if ((c[(c[(c[h + 108 >> 2] | 0) + 28 >> 2] | 0) + 52 >> 2] | 0) == 1) {
	                    AB(g, 1841, 0, 0, 141456, 0, 0);
	                    c[k >> 2] = c[(c[l >> 2] | 0) + 52 >> 2];
	                    r = c[k >> 2] | 0;
	                    i = j;
	                    return r | 0
	                }
	                if ((c[(c[(c[g + 108 >> 2] | 0) + 28 >> 2] | 0) + 52 >> 2] | 0) == 2) {
	                    if ((c[m >> 2] | 0) == 3 ? (aE(c[n >> 2] | 0, c[o >> 2] | 0) | 0) != 0 : 0) {
	                        c[k >> 2] = 0;
	                        r = c[k >> 2] | 0;
	                        i = j;
	                        return r | 0
	                    }
	                    AB(c[l >> 2] | 0, 1843, 0, 0, 141528, 0, 0);
	                    c[k >> 2] = c[(c[l >> 2] | 0) + 52 >> 2];
	                    r = c[k >> 2] | 0;
	                    i = j;
	                    return r | 0
	                }
	                if ((c[n >> 2] | 0) != 0 ? (d[c[n >> 2] >> 0] | 0 | 0) != 0 : 0) {
	                    do if ((c[(c[(c[(c[l >> 2] | 0) + 108 >> 2] | 0) + 28 >> 2] | 0) + 52 >> 2] | 0) == 3) {
	                        if ((c[(c[(c[l >> 2] | 0) + 108 >> 2] | 0) + 44 >> 2] | 0) != 0 ? (c[(c[(c[(c[l >> 2] | 0) + 108 >> 2] | 0) + 44 >> 2] | 0) + 76 >> 2] | 0) != 0 : 0)break;
	                        c[k >> 2] = 0;
	                        r = c[k >> 2] | 0;
	                        i = j;
	                        return r | 0
	                    } while (0);
	                    do if (!(c[(c[(c[l >> 2] | 0) + 108 >> 2] | 0) + 20 >> 2] | 0)) {
	                        m = c[p >> 2] | 0;
	                        if ((m | 0) == 1) {
	                            c[(c[(c[l >> 2] | 0) + 108 >> 2] | 0) + 20 >> 2] = c[n >> 2];
	                            break
	                        } else if ((m | 0) == 2) {
	                            c[(c[(c[l >> 2] | 0) + 108 >> 2] | 0) + 20 >> 2] = c[n >> 2];
	                            if (c[q >> 2] | 0)c[c[q >> 2] >> 2] = 1;
	                            g = (c[(c[l >> 2] | 0) + 108 >> 2] | 0) + 32 | 0;
	                            c[g >> 2] = c[g >> 2] | 2;
	                            break
	                        } else if ((m | 0) == 3) {
	                            m = c[n >> 2] | 0;
	                            if ((c[o >> 2] | 0) != -1) {
	                                g = ly(m, c[o >> 2] | 0) | 0;
	                                c[(c[(c[l >> 2] | 0) + 108 >> 2] | 0) + 20 >> 2] = g
	                            } else {
	                                g = my(m) | 0;
	                                c[(c[(c[l >> 2] | 0) + 108 >> 2] | 0) + 20 >> 2] = g
	                            }
	                            g = (c[(c[l >> 2] | 0) + 108 >> 2] | 0) + 32 | 0;
	                            c[g >> 2] = c[g >> 2] | 2;
	                            break
	                        } else break
	                    } else {
	                        if ((c[o >> 2] | 0) < 0)c[o >> 2] = xy(c[n >> 2] | 0) | 0;
	                        g = c[(c[(c[l >> 2] | 0) + 108 >> 2] | 0) + 20 >> 2] | 0;
	                        m = c[n >> 2] | 0;
	                        h = c[o >> 2] | 0;
	                        if (c[(c[(c[l >> 2] | 0) + 108 >> 2] | 0) + 32 >> 2] & 2) {
	                            f = zy(g, m, h) | 0;
	                            c[(c[(c[l >> 2] | 0) + 108 >> 2] | 0) + 20 >> 2] = f;
	                            break
	                        } else {
	                            f = Ay(g, m, h) | 0;
	                            c[(c[(c[l >> 2] | 0) + 108 >> 2] | 0) + 20 >> 2] = f;
	                            f = (c[(c[l >> 2] | 0) + 108 >> 2] | 0) + 32 | 0;
	                            c[f >> 2] = c[f >> 2] | 2;
	                            break
	                        }
	                    } while (0);
	                    c[k >> 2] = 0;
	                    r = c[k >> 2] | 0;
	                    i = j;
	                    return r | 0
	                }
	                c[k >> 2] = 0;
	                r = c[k >> 2] | 0;
	                i = j;
	                return r | 0
	            }

	            function zD(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                do if (!(c[(c[e >> 2] | 0) + 88 >> 2] | 0)) {
	                    if (c[(c[e >> 2] | 0) + 20 >> 2] | 0) {
	                        a = tF(140432, c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 60 >> 2] | 0) | 0;
	                        c[(c[e >> 2] | 0) + 88 >> 2] = a
	                    } else {
	                        a = XA(140432) | 0;
	                        c[(c[e >> 2] | 0) + 88 >> 2] = a
	                    }
	                    a = c[e >> 2] | 0;
	                    if (c[(c[e >> 2] | 0) + 88 >> 2] | 0) {
	                        aB(c[a + 88 >> 2] | 0, c[(c[e >> 2] | 0) + 8 >> 2] | 0, c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[(c[e >> 2] | 0) + 4 >> 2] | 0);
	                        cB(c[(c[e >> 2] | 0) + 88 >> 2] | 0, c[(c[e >> 2] | 0) + 16 >> 2] | 0, c[(c[e >> 2] | 0) + 4 >> 2] | 0);
	                        break
	                    }
	                    xB(a, 141232, 141264);
	                    c[d >> 2] = -1;
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                } while (0);
	                c[d >> 2] = 0;
	                f = c[d >> 2] | 0;
	                i = b;
	                return f | 0
	            }

	            function AD(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[(c[(c[e >> 2] | 0) + 52 >> 2] | 0) + 76 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                Wj(c[(c[(c[e >> 2] | 0) + 52 >> 2] | 0) + 76 >> 2] | 0, 359, c[f >> 2] | 0);
	                i = d;
	                return
	            }

	            function BD(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                b = i;
	                i = i + 48 | 0;
	                d = b + 32 | 0;
	                e = b + 28 | 0;
	                f = b + 24 | 0;
	                g = b + 20 | 0;
	                h = b + 16 | 0;
	                j = b + 12 | 0;
	                k = b + 8 | 0;
	                l = b + 4 | 0;
	                m = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                c[(c[d >> 2] | 0) + 152 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 84 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 24 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 160 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 184 >> 2] = 0;
	                if (c[(c[d >> 2] | 0) + 72 >> 2] | 0) {
	                    PH(c[(c[d >> 2] | 0) + 72 >> 2] | 0);
	                    c[(c[d >> 2] | 0) + 72 >> 2] = 0
	                }
	                if (c[(c[d >> 2] | 0) + 112 >> 2] | 0) {
	                    c[e >> 2] = c[(c[d >> 2] | 0) + 112 >> 2];
	                    do {
	                        c[f >> 2] = c[c[e >> 2] >> 2];
	                        zb[c[135736 >> 2] & 511](c[e >> 2] | 0);
	                        c[e >> 2] = c[f >> 2]
	                    } while ((c[e >> 2] | 0) != 0);
	                    c[(c[d >> 2] | 0) + 112 >> 2] = 0
	                }
	                if (c[(c[d >> 2] | 0) + 124 >> 2] | 0) {
	                    c[g >> 2] = c[(c[d >> 2] | 0) + 124 >> 2];
	                    while (1) {
	                        if (!(c[g >> 2] | 0))break;
	                        c[h >> 2] = c[g >> 2];
	                        c[g >> 2] = c[(c[g >> 2] | 0) + 12 >> 2];
	                        vF(c[h >> 2] | 0)
	                    }
	                    c[(c[d >> 2] | 0) + 124 >> 2] = 0
	                }
	                if (c[(c[d >> 2] | 0) + 128 >> 2] | 0) {
	                    c[j >> 2] = 0;
	                    while (1) {
	                        if ((c[j >> 2] | 0) >= (c[(c[d >> 2] | 0) + 132 >> 2] | 0))break;
	                        c[k >> 2] = c[(c[(c[d >> 2] | 0) + 128 >> 2] | 0) + (c[j >> 2] << 2) >> 2];
	                        zb[c[135736 >> 2] & 511](c[(c[k >> 2] | 0) + 4 >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                        c[j >> 2] = (c[j >> 2] | 0) + 1
	                    }
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 128 >> 2] | 0);
	                    c[(c[d >> 2] | 0) + 128 >> 2] = 0;
	                    c[(c[d >> 2] | 0) + 132 >> 2] = 0;
	                    c[(c[d >> 2] | 0) + 136 >> 2] = 0
	                }
	                if (c[(c[d >> 2] | 0) + 116 >> 2] | 0) {
	                    uB(c[(c[d >> 2] | 0) + 116 >> 2] | 0);
	                    c[(c[d >> 2] | 0) + 116 >> 2] = 0
	                }
	                if (c[(c[d >> 2] | 0) + 168 >> 2] | 0)vB(c[d >> 2] | 0);
	                a:do if (c[(c[d >> 2] | 0) + 100 >> 2] | 0) {
	                    c[l >> 2] = 0;
	                    while (1) {
	                        if ((c[l >> 2] | 0) >= (c[(c[d >> 2] | 0) + 104 >> 2] | 0))break a;
	                        c[m >> 2] = c[(c[(c[d >> 2] | 0) + 100 >> 2] | 0) + (c[l >> 2] << 2) >> 2];
	                        if (!(c[m >> 2] | 0))break a;
	                        wB(c[d >> 2] | 0, c[m >> 2] | 0);
	                        c[l >> 2] = (c[l >> 2] | 0) + 1
	                    }
	                } while (0);
	                wF(c[(c[d >> 2] | 0) + 180 >> 2] | 0);
	                zP(c[(c[d >> 2] | 0) + 156 >> 2] | 0);
	                l = xP() | 0;
	                c[(c[d >> 2] | 0) + 156 >> 2] = l;
	                if (!(c[(c[d >> 2] | 0) + 48 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 48 >> 2] | 0);
	                c[(c[d >> 2] | 0) + 48 >> 2] = 0;
	                i = b;
	                return
	            }

	            function CD(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 32 >> 2] | 0)mB(c[(c[d >> 2] | 0) + 32 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 68 >> 2] | 0)PH(c[(c[d >> 2] | 0) + 68 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function DD(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 4 >> 2] | 0)mB(c[(c[d >> 2] | 0) + 4 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 32 >> 2] | 0)PH(c[(c[d >> 2] | 0) + 32 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function ED(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function FD(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 24 >> 2] | 0)mB(c[(c[d >> 2] | 0) + 24 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 84 >> 2] | 0)zz(c[(c[d >> 2] | 0) + 84 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 96 >> 2] | 0)PH(c[(c[d >> 2] | 0) + 96 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function GD(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (c[(c[d >> 2] | 0) + 4 >> 2] | 0)mB(c[(c[d >> 2] | 0) + 4 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function HD(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 24 >> 2] | 0)mB(c[(c[d >> 2] | 0) + 24 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 56 >> 2] | 0)oB(c[(c[d >> 2] | 0) + 56 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function ID(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (c[(c[d >> 2] | 0) + 4 >> 2] | 0)mB(c[(c[d >> 2] | 0) + 4 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function JD(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 4 >> 2] | 0)mB(c[(c[d >> 2] | 0) + 4 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 24 >> 2] | 0) {
	                    if (c[(c[(c[d >> 2] | 0) + 24 >> 2] | 0) + 16 >> 2] | 0)EQ(c[(c[(c[d >> 2] | 0) + 24 >> 2] | 0) + 16 >> 2] | 0);
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 24 >> 2] | 0)
	                }
	                if (c[(c[d >> 2] | 0) + 28 >> 2] | 0) {
	                    c[e >> 2] = c[(c[d >> 2] | 0) + 28 >> 2];
	                    do {
	                        c[f >> 2] = c[e >> 2];
	                        c[e >> 2] = c[c[e >> 2] >> 2];
	                        if (c[(c[f >> 2] | 0) + 16 >> 2] | 0)EQ(c[(c[f >> 2] | 0) + 16 >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[f >> 2] | 0)
	                    } while ((c[e >> 2] | 0) != 0)
	                }
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function KD(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function LD(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function MD(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                a = c[e >> 2] | 0;
	                do if ((c[c[e >> 2] >> 2] | 0) == 1) {
	                    if ((c[a >> 2] | 0) != 5 ? (c[(c[e >> 2] | 0) + 88 >> 2] | 0) != 45 : 0) {
	                        c[d >> 2] = 143688;
	                        break
	                    }
	                    c[d >> 2] = 143664
	                } else c[d >> 2] = xF(c[a >> 2] | 0) | 0; while (0);
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function ND(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                ce(16, 3069, c[f >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0);
	                i = e;
	                return
	            }

	            function OD(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (c[(c[d >> 2] | 0) + 8 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 20 >> 2] | 0)oB(c[(c[d >> 2] | 0) + 20 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function PD(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                h = i;
	                i = i + 32 | 0;
	                j = h + 20 | 0;
	                k = h + 16 | 0;
	                l = h + 12 | 0;
	                m = h + 8 | 0;
	                n = h + 4 | 0;
	                o = h;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                IC(c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, 0, 0);
	                i = h;
	                return
	            }

	            function QD(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                a = c[e >> 2] | 0;
	                do if ((c[c[e >> 2] >> 2] | 0) != 1) {
	                    if (c[a + 48 >> 2] & 64) {
	                        c[d >> 2] = 3;
	                        break
	                    }
	                    if (c[(c[e >> 2] | 0) + 48 >> 2] & 128) {
	                        c[d >> 2] = 0;
	                        break
	                    }
	                    if (!(c[(c[e >> 2] | 0) + 48 >> 2] & 256)) {
	                        c[d >> 2] = -1;
	                        break
	                    }
	                    if (c[(c[e >> 2] | 0) + 48 >> 2] & 16777216) {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    if (c[(c[e >> 2] | 0) + 48 >> 2] & 33554432) {
	                        c[d >> 2] = 2;
	                        break
	                    } else {
	                        c[d >> 2] = 3;
	                        break
	                    }
	                } else {
	                    if ((c[a + 88 >> 2] | 0) != 1 ? (c[(c[e >> 2] | 0) + 88 >> 2] | 0) != 46 : 0)if ((c[(c[e >> 2] | 0) + 88 >> 2] | 0) == 2) {
	                        c[d >> 2] = 2;
	                        break
	                    } else {
	                        c[d >> 2] = 3;
	                        break
	                    }
	                    c[d >> 2] = 1
	                } while (0);
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function RD(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                d = i;
	                i = i + 48 | 0;
	                e = d + 32 | 0;
	                f = d + 28 | 0;
	                g = d + 24 | 0;
	                h = d + 20 | 0;
	                j = d + 16 | 0;
	                k = d + 12 | 0;
	                l = d + 8 | 0;
	                m = d + 4 | 0;
	                n = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                b = c[f >> 2] | 0;
	                if (c[(c[f >> 2] | 0) + 36 >> 2] | 0) {
	                    c[h >> 2] = c[b + 96 >> 2];
	                    a:while (1) {
	                        if ((c[h >> 2] | 0) < 0) {
	                            o = 14;
	                            break
	                        }
	                        b:do if (c[(c[(c[(c[f >> 2] | 0) + 100 >> 2] | 0) + (c[h >> 2] << 2) >> 2] | 0) + 68 >> 2] | 0) {
	                            c[k >> 2] = c[(c[(c[f >> 2] | 0) + 100 >> 2] | 0) + (c[h >> 2] << 2) >> 2];
	                            c[j >> 2] = 0;
	                            while (1) {
	                                if ((c[j >> 2] | 0) >= (c[(c[k >> 2] | 0) + 68 >> 2] << 1 | 0))break b;
	                                if ((c[g >> 2] | 0) == 0 ? (c[(c[(c[k >> 2] | 0) + 64 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) == 0 : 0) {
	                                    o = 11;
	                                    break a
	                                }
	                                if ((c[g >> 2] | 0) != 0 ? (qy(c[g >> 2] | 0, c[(c[(c[k >> 2] | 0) + 64 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) | 0) != 0 : 0) {
	                                    o = 11;
	                                    break a
	                                }
	                                c[j >> 2] = (c[j >> 2] | 0) + 2
	                            }
	                        } while (0);
	                        c[h >> 2] = (c[h >> 2] | 0) + -1
	                    }
	                    if ((o | 0) == 11) {
	                        c[e >> 2] = c[(c[(c[k >> 2] | 0) + 64 >> 2] | 0) + ((c[j >> 2] | 0) + 1 << 2) >> 2];
	                        p = c[e >> 2] | 0;
	                        i = d;
	                        return p | 0
	                    } else if ((o | 0) == 14) {
	                        c[e >> 2] = 0;
	                        p = c[e >> 2] | 0;
	                        i = d;
	                        return p | 0
	                    }
	                } else {
	                    o = c[f >> 2] | 0;
	                    if (c[b + 160 >> 2] | 0) {
	                        c[l >> 2] = WL(c[o + 160 >> 2] | 0, c[g >> 2] | 0) | 0;
	                        if (c[l >> 2] | 0) {
	                            c[m >> 2] = AP(c[(c[f >> 2] | 0) + 156 >> 2] | 0, c[l >> 2] | 0, -1) | 0;
	                            zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                            c[e >> 2] = c[m >> 2];
	                            p = c[e >> 2] | 0;
	                            i = d;
	                            return p | 0
	                        } else {
	                            c[e >> 2] = 0;
	                            p = c[e >> 2] | 0;
	                            i = d;
	                            return p | 0
	                        }
	                    }
	                    if ((c[(c[o + 108 >> 2] | 0) + 4 >> 2] | 0) != 0 ? (c[(c[(c[(c[f >> 2] | 0) + 108 >> 2] | 0) + 4 >> 2] | 0) + 32 >> 2] | 0) != 0 : 0) {
	                        c[n >> 2] = cj(c[(c[(c[(c[f >> 2] | 0) + 108 >> 2] | 0) + 4 >> 2] | 0) + 32 >> 2] | 0, c[(c[(c[f >> 2] | 0) + 108 >> 2] | 0) + 4 >> 2] | 0, c[g >> 2] | 0) | 0;
	                        if (c[n >> 2] | 0) {
	                            c[e >> 2] = c[(c[n >> 2] | 0) + 8 >> 2];
	                            p = c[e >> 2] | 0;
	                            i = d;
	                            return p | 0
	                        } else {
	                            c[e >> 2] = 0;
	                            p = c[e >> 2] | 0;
	                            i = d;
	                            return p | 0
	                        }
	                    }
	                    xB(c[f >> 2] | 0, 154192, 154224);
	                    c[e >> 2] = 0;
	                    p = c[e >> 2] | 0;
	                    i = d;
	                    return p | 0
	                }
	                return 0
	            }

	            function SD(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 0;
	                if ((c[h >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                do if (c[g >> 2] | 0) {
	                    if ((qy(c[j >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] | 0) | 0) != 0 ? (c[k >> 2] = Rj(c[(c[g >> 2] | 0) + 44 >> 2] | 0, c[h >> 2] | 0) | 0, (c[k >> 2] | 0) != 0) : 0)break;
	                    if (($j(c[(c[g >> 2] | 0) + 48 >> 2] | 0) | 0) > 1) {
	                        d = c[(c[g >> 2] | 0) + 48 >> 2] | 0;
	                        if (!(c[j >> 2] | 0))c[l >> 2] = Rj(d, 145792) | 0; else c[l >> 2] = Rj(d, c[j >> 2] | 0) | 0;
	                        if (c[l >> 2] | 0)c[k >> 2] = Rj(c[(c[(c[l >> 2] | 0) + 52 >> 2] | 0) + 44 >> 2] | 0, c[h >> 2] | 0) | 0
	                    }
	                } while (0);
	                c[f >> 2] = c[k >> 2];
	                m = c[f >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function TD(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                while (1) {
	                    if (!(c[e >> 2] | 0)) {
	                        f = 7;
	                        break
	                    }
	                    if ((c[(c[e >> 2] | 0) + 88 >> 2] | 0) == 46) {
	                        f = 5;
	                        break
	                    }
	                    if (c[(c[e >> 2] | 0) + 48 >> 2] & 16384) {
	                        f = 5;
	                        break
	                    }
	                    c[e >> 2] = c[(c[e >> 2] | 0) + 64 >> 2]
	                }
	                if ((f | 0) == 5) {
	                    c[d >> 2] = c[e >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else if ((f | 0) == 7) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function UD(a, b, d, e, f, g, h, j, k, l) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                k = k | 0;
	                l = l | 0;
	                var m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0;
	                m = i;
	                i = i + 112 | 0;
	                n = m;
	                o = m + 56 | 0;
	                p = m + 52 | 0;
	                q = m + 48 | 0;
	                r = m + 44 | 0;
	                s = m + 40 | 0;
	                t = m + 36 | 0;
	                u = m + 32 | 0;
	                v = m + 28 | 0;
	                w = m + 24 | 0;
	                x = m + 20 | 0;
	                y = m + 16 | 0;
	                z = m + 12 | 0;
	                A = m + 8 | 0;
	                B = m + 4 | 0;
	                C = m + 85 | 0;
	                D = m + 60 | 0;
	                c[o >> 2] = a;
	                c[p >> 2] = b;
	                c[q >> 2] = d;
	                c[r >> 2] = e;
	                c[s >> 2] = f;
	                c[t >> 2] = g;
	                c[u >> 2] = h;
	                c[v >> 2] = j;
	                c[w >> 2] = k;
	                c[x >> 2] = l;
	                c[y >> 2] = 0;
	                c[z >> 2] = 0;
	                c[B >> 2] = WD(c[o >> 2] | 0, c[q >> 2] | 0) | 0;
	                HC(z, c[o >> 2] | 0, c[q >> 2] | 0) | 0;
	                if ((c[p >> 2] | 0) == 1840)c[A >> 2] = 1007; else c[A >> 2] = c[c[u >> 2] >> 2];
	                c[z >> 2] = By(c[z >> 2] | 0, 142560) | 0;
	                c[z >> 2] = By(c[z >> 2] | 0, 148120) | 0;
	                l = c[z >> 2] | 0;
	                c[z >> 2] = By(l, zB(c[A >> 2] | 0) | 0) | 0;
	                c[z >> 2] = By(c[z >> 2] | 0, 156768) | 0;
	                do if (!(c[v >> 2] | 0)) {
	                    if ((c[A >> 2] | 0) == 1009 | (c[A >> 2] | 0) == 1011 | (c[A >> 2] | 0) == 1010) {
	                        l = c[z >> 2] | 0;
	                        if ((c[B >> 2] | 0) == 2)c[z >> 2] = By(l, 156776) | 0; else c[z >> 2] = By(l, 156816) | 0;
	                        c[n >> 2] = ZH(c[u >> 2] | 0) | 0;
	                        JT(C, 24, 156856, n) | 0;
	                        c[n >> 2] = c[s >> 2];
	                        JT(D, 24, 156856, n) | 0;
	                        do if ((c[A >> 2] | 0) != 1009) {
	                            if ((c[A >> 2] | 0) == 1010) {
	                                c[z >> 2] = By(c[z >> 2] | 0, 156912) | 0;
	                                break
	                            }
	                            if ((c[A >> 2] | 0) == 1011)c[z >> 2] = By(c[z >> 2] | 0, 156968) | 0
	                        } else c[z >> 2] = By(c[z >> 2] | 0, 156864) | 0; while (0);
	                        l = c[o >> 2] | 0;
	                        k = c[p >> 2] | 0;
	                        j = c[q >> 2] | 0;
	                        h = c[z >> 2] | 0;
	                        if ((c[B >> 2] | 0) == 2) {
	                            yF(l, k, j, h, c[r >> 2] | 0, D, C);
	                            break
	                        } else {
	                            PD(l, k, j, h, D, C);
	                            break
	                        }
	                    }
	                    if ((c[A >> 2] | 0) == 1007) {
	                        c[z >> 2] = By(c[z >> 2] | 0, 157024) | 0;
	                        h = c[o >> 2] | 0;
	                        j = c[p >> 2] | 0;
	                        k = c[q >> 2] | 0;
	                        l = c[z >> 2] | 0;
	                        g = c[r >> 2] | 0;
	                        PD(h, j, k, l, g, zF(c[o >> 2] | 0, y, c[t >> 2] | 0) | 0);
	                        break
	                    }
	                    if ((c[A >> 2] | 0) == 1006) {
	                        c[z >> 2] = By(c[z >> 2] | 0, 157080) | 0;
	                        PD(c[o >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0, c[z >> 2] | 0, c[r >> 2] | 0, c[(c[u >> 2] | 0) + 8 >> 2] | 0);
	                        break
	                    }
	                    if ((c[A >> 2] | 0) == 1e3) {
	                        c[z >> 2] = By(c[z >> 2] | 0, 157136) | 0;
	                        PD(c[o >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0, c[z >> 2] | 0, c[r >> 2] | 0, c[(c[u >> 2] | 0) + 8 >> 2] | 0);
	                        break
	                    }
	                    if ((c[A >> 2] | 0) == 1002) {
	                        c[z >> 2] = By(c[z >> 2] | 0, 157200) | 0;
	                        PD(c[o >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0, c[z >> 2] | 0, c[r >> 2] | 0, c[(c[u >> 2] | 0) + 8 >> 2] | 0);
	                        break
	                    }
	                    if ((c[A >> 2] | 0) == 1001) {
	                        c[z >> 2] = By(c[z >> 2] | 0, 157272) | 0;
	                        PD(c[o >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0, c[z >> 2] | 0, c[r >> 2] | 0, c[(c[u >> 2] | 0) + 8 >> 2] | 0);
	                        break
	                    }
	                    if ((c[A >> 2] | 0) == 1003) {
	                        c[z >> 2] = By(c[z >> 2] | 0, 157320) | 0;
	                        PD(c[o >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0, c[z >> 2] | 0, c[r >> 2] | 0, c[(c[u >> 2] | 0) + 8 >> 2] | 0);
	                        break
	                    }
	                    if ((c[A >> 2] | 0) == 1004) {
	                        c[z >> 2] = By(c[z >> 2] | 0, 157360) | 0;
	                        PD(c[o >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0, c[z >> 2] | 0, c[r >> 2] | 0, c[(c[u >> 2] | 0) + 8 >> 2] | 0);
	                        break
	                    }
	                    if ((c[A >> 2] | 0) == 1005) {
	                        c[z >> 2] = By(c[z >> 2] | 0, 157424) | 0;
	                        PD(c[o >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0, c[z >> 2] | 0, c[r >> 2] | 0, c[(c[u >> 2] | 0) + 8 >> 2] | 0);
	                        break
	                    }
	                    g = c[z >> 2] | 0;
	                    if ((c[B >> 2] | 0) == 2) {
	                        c[z >> 2] = By(g, 157496) | 0;
	                        PD(c[o >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0, c[z >> 2] | 0, c[r >> 2] | 0, 0);
	                        break
	                    } else {
	                        c[z >> 2] = By(g, 157536) | 0;
	                        PD(c[o >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0, c[z >> 2] | 0, 0, 0);
	                        break
	                    }
	                } else {
	                    c[z >> 2] = By(c[z >> 2] | 0, c[v >> 2] | 0) | 0;
	                    c[z >> 2] = By(c[z >> 2] | 0, 142704) | 0;
	                    PD(c[o >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0, c[z >> 2] | 0, c[w >> 2] | 0, c[x >> 2] | 0)
	                } while (0);
	                if (!(c[y >> 2] | 0)) {
	                    E = c[33934] | 0;
	                    F = c[z >> 2] | 0;
	                    zb[E & 511](F);
	                    i = m;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[y >> 2] | 0);
	                c[y >> 2] = 0;
	                E = c[33934] | 0;
	                F = c[z >> 2] | 0;
	                zb[E & 511](F);
	                i = m;
	                return
	            }

	            function VD(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 28 | 0;
	                f = d + 24 | 0;
	                g = d + 20 | 0;
	                h = d + 16 | 0;
	                j = d + 12 | 0;
	                k = d + 8 | 0;
	                l = d + 4 | 0;
	                m = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                a:while (1) {
	                    if (!(c[f >> 2] | 0)) {
	                        n = 20;
	                        break
	                    }
	                    c[h >> 2] = IH(dI(c[f >> 2] | 0) | 0) | 0;
	                    c[j >> 2] = IH(dI(c[g >> 2] | 0) | 0) | 0;
	                    c[k >> 2] = TD(c[h >> 2] | 0) | 0;
	                    c[l >> 2] = TD(c[j >> 2] | 0) | 0;
	                    if ((c[k >> 2] | 0) != (c[l >> 2] | 0)) {
	                        n = 4;
	                        break
	                    }
	                    do if ((c[(c[k >> 2] | 0) + 88 >> 2] | 0) != 1) {
	                        if ((c[c[k >> 2] >> 2] | 0) == 1 ? (c[(c[k >> 2] | 0) + 88 >> 2] | 0) == 46 : 0) {
	                            n = 8;
	                            break
	                        }
	                        c[m >> 2] = YH(c[f >> 2] | 0, 1, c[g >> 2] | 0, 1) | 0;
	                        if ((c[m >> 2] | 0) == -2) {
	                            n = 11;
	                            break a
	                        }
	                        if (c[m >> 2] | 0) {
	                            n = 13;
	                            break a
	                        }
	                    } else n = 8; while (0);
	                    if ((n | 0) == 8 ? (n = 0, b = LH(c[f >> 2] | 0) | 0, (qy(b, LH(c[g >> 2] | 0) | 0) | 0) == 0) : 0) {
	                        n = 9;
	                        break
	                    }
	                    c[f >> 2] = KH(c[f >> 2] | 0) | 0;
	                    b = (c[f >> 2] | 0) != 0;
	                    o = KH(c[g >> 2] | 0) | 0;
	                    if (!b) {
	                        n = 17;
	                        break
	                    }
	                    c[g >> 2] = o;
	                    if (!(c[g >> 2] | 0)) {
	                        n = 16;
	                        break
	                    }
	                }
	                do if ((n | 0) == 4)c[e >> 2] = 0; else if ((n | 0) == 9)c[e >> 2] = 0; else if ((n | 0) == 11)c[e >> 2] = -1; else if ((n | 0) == 13)c[e >> 2] = 0; else if ((n | 0) == 16)c[e >> 2] = 0; else if ((n | 0) == 17)if (o) {
	                    c[e >> 2] = 0;
	                    break
	                } else {
	                    c[e >> 2] = 1;
	                    break
	                } else if ((n | 0) == 20)c[e >> 2] = 0; while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function WD(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (c[g >> 2] | 0) {
	                    c[e >> 2] = c[(c[g >> 2] | 0) + 4 >> 2];
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                if ((c[c[f >> 2] >> 2] | 0) == 2 ? (c[(c[f >> 2] | 0) + 108 >> 2] | 0) != 0 : 0) {
	                    c[e >> 2] = c[c[(c[f >> 2] | 0) + 108 >> 2] >> 2];
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                c[e >> 2] = -1;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function XD(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                switch (c[c[e >> 2] >> 2] | 0) {
	                    case 15:
	                    {
	                        if (c[(c[e >> 2] | 0) + 60 >> 2] & 1)c[d >> 2] = 1; else f = 10;
	                        break
	                    }
	                    case 17:
	                    {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    case 4:
	                    case 5:
	                    {
	                        if (c[(c[e >> 2] | 0) + 48 >> 2] & 8)c[d >> 2] = 1; else f = 10;
	                        break
	                    }
	                    case 14:
	                    {
	                        if (c[(c[e >> 2] | 0) + 48 >> 2] & 2)c[d >> 2] = 1; else f = 10;
	                        break
	                    }
	                    default:
	                        c[d >> 2] = 1
	                }
	                if ((f | 0) == 10)c[d >> 2] = 0;
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function YD(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                b = c[e >> 2] | 0;
	                e = AF(c[f >> 2] | 0) | 0;
	                a = BB(b, e, BF(c[f >> 2] | 0) | 0) | 0;
	                i = d;
	                return a | 0
	            }

	            function ZD(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[g >> 2] = 0;
	                b = c[c[e >> 2] >> 2] | 0;
	                a = By(b, MD(c[f >> 2] | 0) | 0) | 0;
	                c[c[e >> 2] >> 2] = a;
	                a = By(c[c[e >> 2] >> 2] | 0, 143656) | 0;
	                c[c[e >> 2] >> 2] = a;
	                a = c[c[e >> 2] >> 2] | 0;
	                b = By(a, YD(g, c[f >> 2] | 0) | 0) | 0;
	                c[c[e >> 2] >> 2] = b;
	                b = By(c[c[e >> 2] >> 2] | 0, 142568) | 0;
	                c[c[e >> 2] >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    h = c[e >> 2] | 0;
	                    j = c[h >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                c[g >> 2] = 0;
	                h = c[e >> 2] | 0;
	                j = c[h >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function _D(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                a = c[e >> 2] | 0;
	                if ((a | 0) == 1)c[d >> 2] = 148168; else if ((a | 0) == 2)c[d >> 2] = 148176; else if ((a | 0) == 3)c[d >> 2] = 148184; else c[d >> 2] = 148192;
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function $D(a, b, d, e, f, g, h, j, k, l) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                k = k | 0;
	                l = l | 0;
	                var m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0, J = 0, K = 0;
	                m = i;
	                i = i + 96 | 0;
	                n = m;
	                o = m + 88 | 0;
	                p = m + 84 | 0;
	                q = m + 80 | 0;
	                r = m + 76 | 0;
	                s = m + 72 | 0;
	                t = m + 68 | 0;
	                u = m + 64 | 0;
	                v = m + 60 | 0;
	                w = m + 56 | 0;
	                x = m + 52 | 0;
	                y = m + 48 | 0;
	                z = m + 44 | 0;
	                A = m + 40 | 0;
	                B = m + 36 | 0;
	                C = m + 32 | 0;
	                D = m + 28 | 0;
	                E = m + 24 | 0;
	                F = m + 20 | 0;
	                G = m + 16 | 0;
	                c[o >> 2] = a;
	                c[p >> 2] = b;
	                c[q >> 2] = d;
	                c[r >> 2] = e;
	                c[s >> 2] = f;
	                c[t >> 2] = g;
	                c[u >> 2] = h;
	                c[v >> 2] = j;
	                c[w >> 2] = k;
	                c[x >> 2] = l;
	                c[y >> 2] = 0;
	                c[z >> 2] = 0;
	                c[A >> 2] = 0;
	                if (!(c[o >> 2] | 0)) {
	                    i = m;
	                    return
	                }
	                l = c[o >> 2] | 0;
	                if ((c[c[o >> 2] >> 2] | 0) != 2) {
	                    if ((c[l >> 2] | 0) != 1) {
	                        k = c[33976] | 0;
	                        j = c[33980] | 0;
	                        c[n >> 2] = 140328;
	                        c[n + 4 >> 2] = 2125;
	                        Db[k & 511](j, 140296, n);
	                        i = m;
	                        return
	                    }
	                    c[G >> 2] = c[o >> 2];
	                    j = c[G >> 2] | 0;
	                    if ((c[p >> 2] | 0) != 1) {
	                        k = j + 20 | 0;
	                        c[k >> 2] = (c[k >> 2] | 0) + 1;
	                        c[(c[G >> 2] | 0) + 16 >> 2] = c[q >> 2];
	                        c[z >> 2] = c[(c[G >> 2] | 0) + 8 >> 2]
	                    } else c[z >> 2] = c[j + 12 >> 2];
	                    c[y >> 2] = c[(c[G >> 2] | 0) + 24 >> 2];
	                    c[A >> 2] = c[(c[G >> 2] | 0) + 4 >> 2];
	                    G = c[y >> 2] | 0;
	                    j = c[z >> 2] | 0;
	                    k = c[A >> 2] | 0;
	                    h = c[o >> 2] | 0;
	                    g = c[r >> 2] | 0;
	                    f = c[q >> 2] | 0;
	                    e = c[p >> 2] | 0;
	                    d = c[u >> 2] | 0;
	                    b = c[v >> 2] | 0;
	                    a = c[w >> 2] | 0;
	                    H = c[t >> 2] | 0;
	                    I = c[v >> 2] | 0;
	                    J = c[w >> 2] | 0;
	                    K = c[x >> 2] | 0;
	                    c[n >> 2] = c[u >> 2];
	                    c[n + 4 >> 2] = I;
	                    c[n + 8 >> 2] = J;
	                    c[n + 12 >> 2] = K;
	                    Xd(G, j, k, h, g, 16, f, e, 0, 0, d, b, a, 0, 0, H, n);
	                    i = m;
	                    return
	                }
	                c[B >> 2] = l;
	                c[C >> 2] = 0;
	                c[D >> 2] = 0;
	                l = c[B >> 2] | 0;
	                if ((c[p >> 2] | 0) != 1) {
	                    H = l + 56 | 0;
	                    c[H >> 2] = (c[H >> 2] | 0) + 1;
	                    c[(c[B >> 2] | 0) + 52 >> 2] = c[q >> 2];
	                    c[z >> 2] = c[(c[B >> 2] | 0) + 8 >> 2]
	                } else c[z >> 2] = c[l + 12 >> 2];
	                c[y >> 2] = c[(c[B >> 2] | 0) + 16 >> 2];
	                c[A >> 2] = c[(c[B >> 2] | 0) + 4 >> 2];
	                do if (!(c[s >> 2] | 0)) {
	                    if (((c[r >> 2] | 0) == 0 ? (c[(c[B >> 2] | 0) + 96 >> 2] | 0) >= 0 : 0) ? (c[(c[B >> 2] | 0) + 108 >> 2] | 0) != 0 : 0)c[r >> 2] = c[(c[(c[B >> 2] | 0) + 108 >> 2] | 0) + 4 >> 2];
	                    if (((c[r >> 2] | 0) == 0 ? (c[(c[B >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) ? (c[(c[(c[B >> 2] | 0) + 40 >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) {
	                        c[C >> 2] = c[(c[(c[(c[B >> 2] | 0) + 40 >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2];
	                        c[s >> 2] = c[(c[(c[(c[B >> 2] | 0) + 40 >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2];
	                        c[D >> 2] = c[(c[(c[(c[B >> 2] | 0) + 40 >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2]
	                    }
	                } else {
	                    c[r >> 2] = 0;
	                    l = c[B >> 2] | 0;
	                    if (c[(c[B >> 2] | 0) + 24 >> 2] | 0) {
	                        c[C >> 2] = c[(c[l + 24 >> 2] | 0) + 72 >> 2];
	                        break
	                    }
	                    if ((c[l + 40 >> 2] | 0) != 0 ? (c[(c[(c[B >> 2] | 0) + 40 >> 2] | 0) + 36 >> 2] | 0) != 0 : 0)c[C >> 2] = c[(c[(c[(c[B >> 2] | 0) + 40 >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2]
	                } while (0);
	                if ((c[(c[B >> 2] | 0) + 196 >> 2] | 0) != 0 ? (c[C >> 2] | 0) == 0 | (c[s >> 2] | 0) == 0 : 0) {
	                    vb[c[(c[B >> 2] | 0) + 196 >> 2] & 511](c[(c[B >> 2] | 0) + 200 >> 2] | 0, F, E) | 0;
	                    if (!(c[C >> 2] | 0))c[C >> 2] = c[F >> 2];
	                    if (!(c[s >> 2] | 0))c[s >> 2] = c[E >> 2]
	                }
	                if ((c[C >> 2] | 0) == 0 ? (c[(c[B >> 2] | 0) + 48 >> 2] | 0) != 0 : 0)c[C >> 2] = c[(c[B >> 2] | 0) + 48 >> 2];
	                B = c[y >> 2] | 0;
	                y = c[z >> 2] | 0;
	                z = c[A >> 2] | 0;
	                A = c[o >> 2] | 0;
	                o = c[r >> 2] | 0;
	                r = c[q >> 2] | 0;
	                q = c[p >> 2] | 0;
	                p = c[C >> 2] | 0;
	                C = c[s >> 2] | 0;
	                s = c[u >> 2] | 0;
	                E = c[v >> 2] | 0;
	                F = c[w >> 2] | 0;
	                l = c[D >> 2] | 0;
	                D = c[t >> 2] | 0;
	                t = c[v >> 2] | 0;
	                v = c[w >> 2] | 0;
	                w = c[x >> 2] | 0;
	                c[n >> 2] = c[u >> 2];
	                c[n + 4 >> 2] = t;
	                c[n + 8 >> 2] = v;
	                c[n + 12 >> 2] = w;
	                Xd(B, y, z, A, o, 17, r, q, p, C, s, E, F, 0, l, D, n);
	                i = m;
	                return
	            }

	            function aE(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 1;
	                    j = c[f >> 2] | 0;
	                    i = e;
	                    return j | 0
	                }
	                a:do if ((c[h >> 2] | 0) < 0) {
	                    b:while (1) {
	                        if (!(d[c[g >> 2] >> 0] | 0))break a;
	                        do if ((d[c[g >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[g >> 2] >> 0] | 0 | 0) ? (d[c[g >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[g >> 2] >> 0] | 0 | 0) != 13)break b
	                        } while (0);
	                        c[g >> 2] = (c[g >> 2] | 0) + 1
	                    }
	                    c[f >> 2] = 0;
	                    j = c[f >> 2] | 0;
	                    i = e;
	                    return j | 0
	                } else {
	                    c:while (1) {
	                        if (!((c[h >> 2] | 0) != 0 ? (d[c[g >> 2] >> 0] | 0 | 0) != 0 : 0))break a;
	                        do if ((d[c[g >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[g >> 2] >> 0] | 0 | 0) ? (d[c[g >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[g >> 2] >> 0] | 0 | 0) != 13)break c
	                        } while (0);
	                        c[g >> 2] = (c[g >> 2] | 0) + 1;
	                        c[h >> 2] = (c[h >> 2] | 0) + -1
	                    }
	                    c[f >> 2] = 0;
	                    j = c[f >> 2] | 0;
	                    i = e;
	                    return j | 0
	                } while (0);
	                c[f >> 2] = 1;
	                j = c[f >> 2] | 0;
	                i = e;
	                return j | 0
	            }

	            function bE(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                do if (c[c[f >> 2] >> 2] | 0) {
	                    if ((c[(c[f >> 2] | 0) + 8 >> 2] | 0) <= (c[(c[f >> 2] | 0) + 4 >> 2] | 0) ? (b = (c[f >> 2] | 0) + 8 | 0, c[b >> 2] = c[b >> 2] << 1, b = Hb[c[135760 >> 2] & 511](c[c[f >> 2] >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] << 2) | 0, c[c[f >> 2] >> 2] = b, (c[c[f >> 2] >> 2] | 0) == 0) : 0) {
	                        tC(0, 142376, 0);
	                        c[(c[f >> 2] | 0) + 8 >> 2] = 0;
	                        c[e >> 2] = -1;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                } else {
	                    b = Cb[c[135744 >> 2] & 511](80) | 0;
	                    c[c[f >> 2] >> 2] = b;
	                    if (c[c[f >> 2] >> 2] | 0) {
	                        c[(c[f >> 2] | 0) + 8 >> 2] = 20;
	                        break
	                    }
	                    tC(0, 142344, 0);
	                    c[e >> 2] = -1;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                } while (0);
	                b = c[g >> 2] | 0;
	                g = (c[f >> 2] | 0) + 4 | 0;
	                a = c[g >> 2] | 0;
	                c[g >> 2] = a + 1;
	                c[(c[c[f >> 2] >> 2] | 0) + (a << 2) >> 2] = b;
	                c[e >> 2] = 0;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function cE(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = dE(c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } else {
	                    c[f >> 2] = CF(c[g >> 2] | 0, c[k >> 2] | 0) | 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                return 0
	            }

	            function dE(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[h >> 2] = c[(c[f >> 2] | 0) + 44 >> 2];
	                while (1) {
	                    if (!(c[h >> 2] | 0)) {
	                        k = 9;
	                        break
	                    }
	                    if ((c[(c[h >> 2] | 0) + 36 >> 2] | 0) == 0 ? (qy(c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[g >> 2] | 0) | 0) != 0 : 0) {
	                        k = 7;
	                        break
	                    }
	                    c[h >> 2] = c[(c[h >> 2] | 0) + 24 >> 2]
	                }
	                if ((k | 0) == 7) {
	                    c[e >> 2] = c[h >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } else if ((k | 0) == 9) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                return 0
	            }

	            function eE(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 24 | 0;
	                j = g + 20 | 0;
	                k = g + 16 | 0;
	                l = g + 12 | 0;
	                m = g + 8 | 0;
	                n = g + 4 | 0;
	                o = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                if ((c[j >> 2] | 0) == 0 | (c[m >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0) {
	                    c[h >> 2] = -1;
	                    p = c[h >> 2] | 0;
	                    i = g;
	                    return p | 0
	                }
	                c[o >> 2] = fE(c[j >> 2] | 0, c[l >> 2] | 0) | 0;
	                if (c[n >> 2] | 0)c[c[n >> 2] >> 2] = c[o >> 2];
	                c[h >> 2] = DF(c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[o >> 2] | 0, c[m >> 2] | 0) | 0;
	                p = c[h >> 2] | 0;
	                i = g;
	                return p | 0
	            }

	            function fE(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[g >> 2] = _i(c[f >> 2] | 0) | 0;
	                if (!(c[g >> 2] | 0))c[g >> 2] = my(142672) | 0;
	                c[h >> 2] = AP(c[(c[e >> 2] | 0) + 80 >> 2] | 0, c[g >> 2] | 0, -1) | 0;
	                zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                i = d;
	                return c[h >> 2] | 0
	            }

	            function gE(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (qy(c[g >> 2] | 0, 163536) | 0) {
	                    if (!(c[c[h >> 2] >> 2] & c[j >> 2])) {
	                        d = c[h >> 2] | 0;
	                        c[d >> 2] = c[d >> 2] | c[j >> 2]
	                    }
	                } else if (!(qy(c[g >> 2] | 0, 163552) | 0)) {
	                    c[f >> 2] = 1;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                c[f >> 2] = 0;
	                k = c[f >> 2] | 0;
	                i = e;
	                return k | 0
	            }

	            function hE(a, b, d, e, f, g, h, j, k, l) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                k = k | 0;
	                l = l | 0;
	                var m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0;
	                m = i;
	                i = i + 48 | 0;
	                n = m + 44 | 0;
	                o = m + 40 | 0;
	                p = m + 32 | 0;
	                q = m + 28 | 0;
	                r = m + 24 | 0;
	                s = m + 20 | 0;
	                t = m + 16 | 0;
	                u = m + 12 | 0;
	                v = m + 8 | 0;
	                w = m + 4 | 0;
	                x = m;
	                c[n >> 2] = a;
	                c[o >> 2] = b;
	                c[m + 36 >> 2] = d;
	                c[p >> 2] = e;
	                c[q >> 2] = f;
	                c[r >> 2] = g;
	                c[s >> 2] = h;
	                c[t >> 2] = j;
	                c[u >> 2] = k;
	                c[v >> 2] = l;
	                c[w >> 2] = 0;
	                HC(w, c[n >> 2] | 0, c[p >> 2] | 0) | 0;
	                do if (!(c[t >> 2] | 0)) {
	                    l = (c[(c[p >> 2] | 0) + 4 >> 2] | 0) == 2;
	                    k = c[w >> 2] | 0;
	                    do if (c[q >> 2] | 0) {
	                        if (l)c[w >> 2] = By(k, 154256) | 0; else c[w >> 2] = By(k, 154288) | 0;
	                        j = (XD(c[q >> 2] | 0) | 0) != 0;
	                        h = c[w >> 2] | 0;
	                        if (j)c[w >> 2] = By(h, 154352) | 0; else c[w >> 2] = By(h, 154336) | 0;
	                        do if (!(c[(c[q >> 2] | 0) + 48 >> 2] & 256)) {
	                            if (c[(c[q >> 2] | 0) + 48 >> 2] & 64) {
	                                c[w >> 2] = By(c[w >> 2] | 0, 147936) | 0;
	                                break
	                            }
	                            if (c[(c[q >> 2] | 0) + 48 >> 2] & 128)c[w >> 2] = By(c[w >> 2] | 0, 147952) | 0
	                        } else c[w >> 2] = By(c[w >> 2] | 0, 147920) | 0; while (0);
	                        if (XD(c[q >> 2] | 0) | 0) {
	                            c[x >> 2] = 0;
	                            c[w >> 2] = By(c[w >> 2] | 0, 143656) | 0;
	                            h = c[w >> 2] | 0;
	                            if (c[(c[q >> 2] | 0) + 88 >> 2] | 0) {
	                                c[w >> 2] = By(h, 154360) | 0;
	                                c[w >> 2] = By(c[w >> 2] | 0, c[(c[q >> 2] | 0) + 8 >> 2] | 0) | 0
	                            } else c[w >> 2] = By(h, BB(x, c[(c[q >> 2] | 0) + 112 >> 2] | 0, c[(c[q >> 2] | 0) + 8 >> 2] | 0) | 0) | 0;
	                            c[w >> 2] = By(c[w >> 2] | 0, 161528) | 0;
	                            if (c[x >> 2] | 0) {
	                                zb[c[135736 >> 2] & 511](c[x >> 2] | 0);
	                                c[x >> 2] = 0
	                            }
	                        }
	                    } else if (l) {
	                        c[w >> 2] = By(k, 161536) | 0;
	                        break
	                    } else {
	                        c[w >> 2] = By(k, 161568) | 0;
	                        break
	                    } while (0);
	                    k = c[w >> 2] | 0;
	                    if (c[r >> 2] | 0) {
	                        c[w >> 2] = By(k, 161608) | 0;
	                        c[w >> 2] = By(c[w >> 2] | 0, c[r >> 2] | 0) | 0;
	                        c[w >> 2] = By(c[w >> 2] | 0, 161624) | 0
	                    } else c[w >> 2] = By(k, 140352) | 0;
	                    k = c[n >> 2] | 0;
	                    l = c[p >> 2] | 0;
	                    h = c[o >> 2] | 0;
	                    j = c[w >> 2] | 0;
	                    if ((c[(c[p >> 2] | 0) + 4 >> 2] | 0) == 2) {
	                        PC(k, l, h, j, c[s >> 2] | 0, 0);
	                        break
	                    } else {
	                        PC(k, l, h, j, 0, 0);
	                        break
	                    }
	                } else {
	                    c[w >> 2] = By(c[w >> 2] | 0, c[t >> 2] | 0) | 0;
	                    c[w >> 2] = By(c[w >> 2] | 0, 142704) | 0;
	                    EF(c[n >> 2] | 0, c[p >> 2] | 0, c[o >> 2] | 0, 0, 0, 0, c[w >> 2] | 0, c[u >> 2] | 0, c[v >> 2] | 0, 0, 0, 0)
	                } while (0);
	                if (!(c[w >> 2] | 0)) {
	                    i = m;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[w >> 2] | 0);
	                c[w >> 2] = 0;
	                i = m;
	                return
	            }

	            function iE(a, b, e, f, g, h, j, k) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                k = k | 0;
	                var l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0;
	                l = i;
	                i = i + 64 | 0;
	                m = l + 48 | 0;
	                n = l + 44 | 0;
	                o = l + 40 | 0;
	                p = l + 36 | 0;
	                q = l + 32 | 0;
	                r = l + 28 | 0;
	                s = l + 24 | 0;
	                t = l + 20 | 0;
	                u = l + 16 | 0;
	                v = l + 12 | 0;
	                w = l + 8 | 0;
	                x = l + 4 | 0;
	                y = l;
	                c[n >> 2] = a;
	                c[o >> 2] = b;
	                c[p >> 2] = e;
	                c[q >> 2] = f;
	                c[r >> 2] = g;
	                c[s >> 2] = h;
	                c[t >> 2] = j;
	                c[u >> 2] = k;
	                c[v >> 2] = 0;
	                if ((c[o >> 2] | 0) == 0 | (c[n >> 2] | 0) == 0) {
	                    c[m >> 2] = -1;
	                    z = c[m >> 2] | 0;
	                    i = l;
	                    return z | 0
	                }
	                if (!(d[c[n >> 2] >> 0] | 0)) {
	                    c[m >> 2] = 0;
	                    z = c[m >> 2] | 0;
	                    i = l;
	                    return z | 0
	                }
	                a:do if (qy(c[n >> 2] | 0, 165432) | 0) {
	                    if ((c[p >> 2] | 0) != -1) {
	                        k = c[o >> 2] | 0;
	                        c[k >> 2] = c[k >> 2] | c[p >> 2];
	                        break
	                    }
	                    if ((c[q >> 2] | 0) != -1) {
	                        k = c[o >> 2] | 0;
	                        c[k >> 2] = c[k >> 2] | c[q >> 2]
	                    }
	                    if ((c[r >> 2] | 0) != -1) {
	                        k = c[o >> 2] | 0;
	                        c[k >> 2] = c[k >> 2] | c[r >> 2]
	                    }
	                    if ((c[s >> 2] | 0) != -1) {
	                        k = c[o >> 2] | 0;
	                        c[k >> 2] = c[k >> 2] | c[s >> 2]
	                    }
	                    if ((c[t >> 2] | 0) != -1) {
	                        k = c[o >> 2] | 0;
	                        c[k >> 2] = c[k >> 2] | c[t >> 2]
	                    }
	                    if ((c[u >> 2] | 0) != -1) {
	                        k = c[o >> 2] | 0;
	                        c[k >> 2] = c[k >> 2] | c[u >> 2]
	                    }
	                } else {
	                    c[x >> 2] = c[n >> 2];
	                    while (1) {
	                        do if ((d[c[x >> 2] >> 0] | 0 | 0) == 32)A = 1; else {
	                            if (9 <= (d[c[x >> 2] >> 0] | 0 | 0) ? (d[c[x >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                A = 1;
	                                break
	                            }
	                            A = (d[c[x >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        k = c[x >> 2] | 0;
	                        if (A) {
	                            c[x >> 2] = k + 1;
	                            continue
	                        }
	                        c[w >> 2] = k;
	                        while (1) {
	                            if (d[c[w >> 2] >> 0] | 0) {
	                                do if ((d[c[w >> 2] >> 0] | 0 | 0) == 32)B = 1; else {
	                                    if (9 <= (d[c[w >> 2] >> 0] | 0 | 0) ? (d[c[w >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                        B = 1;
	                                        break
	                                    }
	                                    B = (d[c[w >> 2] >> 0] | 0 | 0) == 13
	                                } while (0);
	                                C = B ^ 1
	                            } else C = 0;
	                            D = c[w >> 2] | 0;
	                            if (!C)break;
	                            c[w >> 2] = D + 1
	                        }
	                        if ((D | 0) == (c[x >> 2] | 0))break a;
	                        c[y >> 2] = ly(c[x >> 2] | 0, (c[w >> 2] | 0) - (c[x >> 2] | 0) | 0) | 0;
	                        do if (qy(c[y >> 2] | 0, 165440) | 0) {
	                            if ((c[q >> 2] | 0) == -1) {
	                                c[v >> 2] = 1;
	                                break
	                            }
	                            if (!(c[c[o >> 2] >> 2] & c[q >> 2])) {
	                                k = c[o >> 2] | 0;
	                                c[k >> 2] = c[k >> 2] | c[q >> 2]
	                            }
	                        } else {
	                            if (qy(c[y >> 2] | 0, 165456) | 0) {
	                                if ((c[r >> 2] | 0) == -1) {
	                                    c[v >> 2] = 1;
	                                    break
	                                }
	                                if (c[c[o >> 2] >> 2] & c[r >> 2])break;
	                                k = c[o >> 2] | 0;
	                                c[k >> 2] = c[k >> 2] | c[r >> 2];
	                                break
	                            }
	                            if (qy(c[y >> 2] | 0, 165472) | 0) {
	                                if ((c[s >> 2] | 0) == -1) {
	                                    c[v >> 2] = 1;
	                                    break
	                                }
	                                if (c[c[o >> 2] >> 2] & c[s >> 2])break;
	                                k = c[o >> 2] | 0;
	                                c[k >> 2] = c[k >> 2] | c[s >> 2];
	                                break
	                            }
	                            if (qy(c[y >> 2] | 0, 165488) | 0) {
	                                if ((c[t >> 2] | 0) == -1) {
	                                    c[v >> 2] = 1;
	                                    break
	                                }
	                                if (c[c[o >> 2] >> 2] & c[t >> 2])break;
	                                k = c[o >> 2] | 0;
	                                c[k >> 2] = c[k >> 2] | c[t >> 2];
	                                break
	                            }
	                            if (!(qy(c[y >> 2] | 0, 165496) | 0)) {
	                                c[v >> 2] = 1;
	                                break
	                            }
	                            if ((c[u >> 2] | 0) == -1) {
	                                c[v >> 2] = 1;
	                                break
	                            }
	                            if (!(c[c[o >> 2] >> 2] & c[u >> 2])) {
	                                k = c[o >> 2] | 0;
	                                c[k >> 2] = c[k >> 2] | c[u >> 2]
	                            }
	                        } while (0);
	                        if (c[y >> 2] | 0)zb[c[135736 >> 2] & 511](c[y >> 2] | 0);
	                        c[x >> 2] = c[w >> 2];
	                        if (c[v >> 2] | 0)break a;
	                        if (!(d[c[x >> 2] >> 0] | 0))break
	                    }
	                } while (0);
	                c[m >> 2] = c[v >> 2];
	                z = c[m >> 2] | 0;
	                i = l;
	                return z | 0
	            }

	            function jE(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 28 | 0;
	                g = e + 24 | 0;
	                h = e + 20 | 0;
	                j = e + 16 | 0;
	                k = e + 12 | 0;
	                l = e + 8 | 0;
	                m = e + 4 | 0;
	                n = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[l >> 2] = 0;
	                c[n >> 2] = 0;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                if (c[j >> 2] | 0)c[k >> 2] = FF(c[g >> 2] | 0, c[h >> 2] | 0) | 0; else c[k >> 2] = 0;
	                c[m >> 2] = c[(c[h >> 2] | 0) + 44 >> 2];
	                while (1) {
	                    if (!(c[m >> 2] | 0))break;
	                    if ((c[(c[m >> 2] | 0) + 36 >> 2] | 0) == 0 ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 161384) | 0) == 0 : 0)p = 12; else p = 10;
	                    if (((p | 0) == 10 ? (p = 0, (c[(c[m >> 2] | 0) + 36 >> 2] | 0) != 0) : 0) ? (qy(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0)p = 12;
	                    if ((p | 0) == 12) {
	                        p = 0;
	                        GF(c[g >> 2] | 0, 3035, 0, c[m >> 2] | 0)
	                    }
	                    c[m >> 2] = c[(c[m >> 2] | 0) + 24 >> 2]
	                }
	                cE(c[g >> 2] | 0, c[h >> 2] | 0, 161384) | 0;
	                c[l >> 2] = c[(c[h >> 2] | 0) + 12 >> 2];
	                while (1) {
	                    if (!(c[l >> 2] | 0))break;
	                    if ((((c[l >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[l >> 2] | 0) + 8 >> 2] | 0, 168752) | 0) != 0 : 0) ? (qy(c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        c[m >> 2] = c[(c[l >> 2] | 0) + 44 >> 2];
	                        while (1) {
	                            if (!(c[m >> 2] | 0))break;
	                            if ((c[(c[m >> 2] | 0) + 36 >> 2] | 0) == 0 ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 168760) | 0) == 0 : 0)p = 26; else p = 24;
	                            if (((p | 0) == 24 ? (p = 0, (c[(c[m >> 2] | 0) + 36 >> 2] | 0) != 0) : 0) ? (qy(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0)p = 26;
	                            if ((p | 0) == 26) {
	                                p = 0;
	                                GF(c[g >> 2] | 0, 3035, 0, c[m >> 2] | 0)
	                            }
	                            c[m >> 2] = c[(c[m >> 2] | 0) + 24 >> 2]
	                        }
	                        j = c[g >> 2] | 0;
	                        d = c[l >> 2] | 0;
	                        HF(j, 0, d, 168760, IH(29) | 0, 0) | 0;
	                        c[l >> 2] = c[(c[l >> 2] | 0) + 24 >> 2];
	                        continue
	                    }
	                    if ((((c[l >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[l >> 2] | 0) + 8 >> 2] | 0, 168768) | 0) != 0 : 0) ? (qy(c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        c[m >> 2] = c[(c[l >> 2] | 0) + 44 >> 2];
	                        while (1) {
	                            if (!(c[m >> 2] | 0))break;
	                            d = c[m >> 2] | 0;
	                            do if (!(c[(c[m >> 2] | 0) + 36 >> 2] | 0)) {
	                                if (!(qy(c[d + 8 >> 2] | 0, 168760) | 0))GF(c[g >> 2] | 0, 3035, 0, c[m >> 2] | 0)
	                            } else {
	                                if (!(qy(c[(c[d + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)) {
	                                    if (!(qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 168784) | 0))break;
	                                    if (qy(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, 168792) | 0)break
	                                }
	                                GF(c[g >> 2] | 0, 3035, 0, c[m >> 2] | 0)
	                            } while (0);
	                            c[m >> 2] = c[(c[m >> 2] | 0) + 24 >> 2]
	                        }
	                        c[m >> 2] = IF(c[l >> 2] | 0, 168792, 168784) | 0;
	                        if (c[m >> 2] | 0) {
	                            d = c[g >> 2] | 0;
	                            j = c[m >> 2] | 0;
	                            eE(d, 0, j, IH(17) | 0, 0) | 0
	                        }
	                        c[l >> 2] = c[(c[l >> 2] | 0) + 24 >> 2];
	                        continue
	                    }
	                    if (!(c[n >> 2] | 0))uE(c[g >> 2] | 0, 3033, 0, c[h >> 2] | 0, c[l >> 2] | 0, 0, 168832);
	                    c[n >> 2] = 1;
	                    c[l >> 2] = c[(c[l >> 2] | 0) + 24 >> 2]
	                }
	                c[f >> 2] = c[k >> 2];
	                o = c[f >> 2] | 0;
	                i = e;
	                return o | 0
	            }

	            function kE(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 40 | 0;
	                g = e + 36 | 0;
	                h = e + 32 | 0;
	                j = e + 28 | 0;
	                k = e + 24 | 0;
	                l = e + 20 | 0;
	                m = e + 16 | 0;
	                n = e + 12 | 0;
	                o = e + 8 | 0;
	                p = e + 4 | 0;
	                q = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[l >> 2] = 0;
	                c[m >> 2] = 0;
	                c[p >> 2] = 0;
	                c[q >> 2] = 0;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    c[f >> 2] = -1;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                }
	                c[o >> 2] = c[(c[j >> 2] | 0) + 44 >> 2];
	                while (1) {
	                    if (!(c[o >> 2] | 0))break;
	                    d = c[o >> 2] | 0;
	                    if (!(c[(c[o >> 2] | 0) + 36 >> 2] | 0)) {
	                        if (((qy(c[d + 8 >> 2] | 0, 161384) | 0) == 0 ? (qy(c[(c[o >> 2] | 0) + 8 >> 2] | 0, 162304) | 0) == 0 : 0) ? (qy(c[(c[o >> 2] | 0) + 8 >> 2] | 0, 155456) | 0) == 0 : 0)GF(c[g >> 2] | 0, 3035, 0, c[o >> 2] | 0)
	                    } else if (qy(c[(c[d + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)GF(c[g >> 2] | 0, 3035, 0, c[o >> 2] | 0);
	                    c[o >> 2] = c[(c[o >> 2] | 0) + 24 >> 2]
	                }
	                o = c[g >> 2] | 0;
	                d = c[j >> 2] | 0;
	                b = (HF(o, 0, d, 162304, IH(29) | 0, l) | 0) != 0;
	                d = c[g >> 2] | 0;
	                o = c[j >> 2] | 0;
	                a = IH(29) | 0;
	                if (b) {
	                    hE(d, 3037, 0, o, a, 0, c[l >> 2] | 0, 0, 0, 0);
	                    c[f >> 2] = c[(c[g >> 2] | 0) + 16 >> 2];
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                }
	                if (HF(d, 0, o, 155456, a, m) | 0) {
	                    a = c[g >> 2] | 0;
	                    o = c[j >> 2] | 0;
	                    d = IH(29) | 0;
	                    hE(a, 3037, 0, o, d, 0, c[m >> 2] | 0, 0, 0, 0);
	                    c[f >> 2] = c[(c[g >> 2] | 0) + 16 >> 2];
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                }
	                c[k >> 2] = c[(c[j >> 2] | 0) + 12 >> 2];
	                if ((((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 160992) | 0) != 0 : 0) ? (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0)c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2];
	                if (c[k >> 2] | 0)uE(c[g >> 2] | 0, 3033, 0, c[j >> 2] | 0, c[k >> 2] | 0, 0, 161392);
	                c[n >> 2] = c[(c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] | 0) + 12 >> 2];
	                k = c[n >> 2] | 0;
	                if (c[l >> 2] | 0) {
	                    if (qy(k, c[l >> 2] | 0) | 0) {
	                        GE(c[g >> 2] | 0, 3064, 0, c[j >> 2] | 0, 168408, c[n >> 2] | 0);
	                        c[f >> 2] = c[(c[g >> 2] | 0) + 16 >> 2];
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    }
	                } else if (!k) {
	                    GE(c[g >> 2] | 0, 3065, 0, c[j >> 2] | 0, 168512, 0);
	                    c[f >> 2] = c[(c[g >> 2] | 0) + 16 >> 2];
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                }
	                if (c[m >> 2] | 0)c[m >> 2] = JF(c[(c[g >> 2] | 0) + 80 >> 2] | 0, c[m >> 2] | 0, c[j >> 2] | 0) | 0;
	                c[p >> 2] = FB(c[g >> 2] | 0, 1, c[m >> 2] | 0, 0, 0, 0, c[j >> 2] | 0, c[n >> 2] | 0, c[l >> 2] | 0, q) | 0;
	                if (c[p >> 2] | 0) {
	                    c[f >> 2] = c[p >> 2];
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                }
	                if ((c[q >> 2] | 0) == 0 & (c[m >> 2] | 0) != 0)NC(c[g >> 2] | 0, 3084, c[j >> 2] | 0, 0, 168608, c[m >> 2] | 0, 0, 0);
	                if (((c[q >> 2] | 0) != 0 ? (c[(c[q >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) ? (c[(c[q >> 2] | 0) + 32 >> 2] | 0) == 0 : 0)c[p >> 2] = KF(c[g >> 2] | 0, c[h >> 2] | 0, c[q >> 2] | 0) | 0;
	                c[f >> 2] = c[p >> 2];
	                r = c[f >> 2] | 0;
	                i = e;
	                return r | 0
	            }

	            function lE(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = LF(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, 2) | 0;
	                if (c[k >> 2] | 0) {
	                    c[f >> 2] = c[k >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } else {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                return 0
	            }

	            function mE(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = LF(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, 3) | 0;
	                if (c[k >> 2] | 0) {
	                    c[f >> 2] = c[k >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } else {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                return 0
	            }

	            function nE(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0;
	                f = i;
	                i = i + 64 | 0;
	                g = f + 52 | 0;
	                h = f + 48 | 0;
	                j = f + 44 | 0;
	                k = f + 40 | 0;
	                l = f + 36 | 0;
	                m = f + 32 | 0;
	                n = f + 28 | 0;
	                o = f + 24 | 0;
	                p = f + 20 | 0;
	                q = f + 16 | 0;
	                r = f + 12 | 0;
	                s = f + 8 | 0;
	                t = f + 4 | 0;
	                u = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[o >> 2] = 0;
	                c[p >> 2] = 0;
	                c[s >> 2] = 0;
	                c[t >> 2] = 0;
	                c[u >> 2] = 0;
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0) {
	                    c[g >> 2] = 0;
	                    v = c[g >> 2] | 0;
	                    i = f;
	                    return v | 0
	                }
	                c[n >> 2] = c[(c[h >> 2] | 0) + 84 >> 2];
	                if (c[l >> 2] | 0) {
	                    c[q >> 2] = dE(c[k >> 2] | 0, 161352) | 0;
	                    e = c[h >> 2] | 0;
	                    if (!(c[q >> 2] | 0)) {
	                        MF(e, 3036, 0, c[k >> 2] | 0, 161352, 0);
	                        c[g >> 2] = 0;
	                        v = c[g >> 2] | 0;
	                        i = f;
	                        return v | 0
	                    }
	                    d = c[q >> 2] | 0;
	                    if (eE(e, 0, d, IH(22) | 0, p) | 0) {
	                        c[g >> 2] = 0;
	                        v = c[g >> 2] | 0;
	                        i = f;
	                        return v | 0
	                    }
	                }
	                d = c[h >> 2] | 0;
	                e = c[j >> 2] | 0;
	                do if (!(c[l >> 2] | 0)) {
	                    c[m >> 2] = WE(d, e, 5, 0, c[(c[h >> 2] | 0) + 112 >> 2] | 0, c[k >> 2] | 0, 0) | 0;
	                    if (c[m >> 2] | 0) {
	                        c[p >> 2] = c[(c[m >> 2] | 0) + 8 >> 2];
	                        c[(c[m >> 2] | 0) + 36 >> 2] = c[k >> 2];
	                        c[c[m >> 2] >> 2] = 5;
	                        break
	                    }
	                    c[g >> 2] = 0;
	                    v = c[g >> 2] | 0;
	                    i = f;
	                    return v | 0
	                } else {
	                    c[m >> 2] = WE(d, e, 5, c[p >> 2] | 0, c[(c[h >> 2] | 0) + 112 >> 2] | 0, c[k >> 2] | 0, 1) | 0;
	                    if (c[m >> 2] | 0) {
	                        c[(c[m >> 2] | 0) + 36 >> 2] = c[k >> 2];
	                        c[c[m >> 2] >> 2] = 5;
	                        b = (c[m >> 2] | 0) + 48 | 0;
	                        c[b >> 2] = c[b >> 2] | 8;
	                        break
	                    }
	                    c[g >> 2] = 0;
	                    v = c[g >> 2] | 0;
	                    i = f;
	                    return v | 0
	                } while (0);
	                c[(c[m >> 2] | 0) + 112 >> 2] = c[(c[h >> 2] | 0) + 112 >> 2];
	                c[q >> 2] = c[(c[k >> 2] | 0) + 44 >> 2];
	                while (1) {
	                    if (!(c[q >> 2] | 0))break;
	                    p = c[q >> 2] | 0;
	                    do if (!(c[(c[q >> 2] | 0) + 36 >> 2] | 0)) {
	                        if (qy(c[p + 8 >> 2] | 0, 161384) | 0) {
	                            cE(c[h >> 2] | 0, c[k >> 2] | 0, 161384) | 0;
	                            break
	                        }
	                        if (qy(c[(c[q >> 2] | 0) + 8 >> 2] | 0, 167064) | 0) {
	                            if (!(NF(c[h >> 2] | 0, 0, c[q >> 2] | 0) | 0))break;
	                            e = (c[m >> 2] | 0) + 48 | 0;
	                            c[e >> 2] = c[e >> 2] | 1;
	                            break
	                        }
	                        if (!(c[l >> 2] | 0)) {
	                            GF(c[h >> 2] | 0, 3035, 0, c[q >> 2] | 0);
	                            break
	                        }
	                        if (!(qy(c[(c[q >> 2] | 0) + 8 >> 2] | 0, 161352) | 0)) {
	                            if (qy(c[(c[q >> 2] | 0) + 8 >> 2] | 0, 164512) | 0) {
	                                if (!(NF(c[h >> 2] | 0, 0, c[q >> 2] | 0) | 0))break;
	                                e = (c[m >> 2] | 0) + 48 | 0;
	                                c[e >> 2] = c[e >> 2] | 1048576;
	                                break
	                            }
	                            if (qy(c[(c[q >> 2] | 0) + 8 >> 2] | 0, 164504) | 0) {
	                                c[r >> 2] = fE(c[h >> 2] | 0, c[q >> 2] | 0) | 0;
	                                if (iE(c[r >> 2] | 0, (c[m >> 2] | 0) + 48 | 0, -1, 512, 1024, -1, -1, -1) | 0) {
	                                    hE(c[h >> 2] | 0, 3037, 0, c[q >> 2] | 0, 0, 164528, c[r >> 2] | 0, 0, 0, 0);
	                                    break
	                                } else {
	                                    c[s >> 2] = 1;
	                                    break
	                                }
	                            }
	                            e = (qy(c[(c[q >> 2] | 0) + 8 >> 2] | 0, 164480) | 0) != 0;
	                            d = c[h >> 2] | 0;
	                            b = c[q >> 2] | 0;
	                            if (!e) {
	                                GF(d, 3035, 0, b);
	                                break
	                            }
	                            c[r >> 2] = fE(d, b) | 0;
	                            if (iE(c[r >> 2] | 0, (c[m >> 2] | 0) + 48 | 0, -1, 262144, 524288, -1, -1, -1) | 0) {
	                                hE(c[h >> 2] | 0, 3037, 0, c[q >> 2] | 0, 0, 167072, c[r >> 2] | 0, 0, 0, 0);
	                                break
	                            } else {
	                                c[t >> 2] = 1;
	                                break
	                            }
	                        }
	                    } else if (qy(c[(c[p + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)GF(c[h >> 2] | 0, 3035, 0, c[q >> 2] | 0); while (0);
	                    c[q >> 2] = c[(c[q >> 2] | 0) + 24 >> 2]
	                }
	                if (!(c[t >> 2] | 0)) {
	                    if (c[(c[j >> 2] | 0) + 24 >> 2] & 128) {
	                        t = (c[m >> 2] | 0) + 48 | 0;
	                        c[t >> 2] = c[t >> 2] | 524288
	                    }
	                    if (c[(c[j >> 2] | 0) + 24 >> 2] & 64) {
	                        t = (c[m >> 2] | 0) + 48 | 0;
	                        c[t >> 2] = c[t >> 2] | 262144
	                    }
	                }
	                if (!(c[s >> 2] | 0)) {
	                    if (c[(c[j >> 2] | 0) + 24 >> 2] & 8) {
	                        s = (c[m >> 2] | 0) + 48 | 0;
	                        c[s >> 2] = c[s >> 2] | 1024
	                    }
	                    if (c[(c[j >> 2] | 0) + 24 >> 2] & 4) {
	                        s = (c[m >> 2] | 0) + 48 | 0;
	                        c[s >> 2] = c[s >> 2] | 512
	                    }
	                }
	                c[o >> 2] = c[(c[k >> 2] | 0) + 12 >> 2];
	                if ((((c[o >> 2] | 0) != 0 ? (c[(c[o >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[o >> 2] | 0) + 8 >> 2] | 0, 160992) | 0) != 0 : 0) ? (qy(c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    s = jE(c[h >> 2] | 0, c[o >> 2] | 0, 1) | 0;
	                    c[(c[m >> 2] | 0) + 24 >> 2] = s;
	                    c[o >> 2] = c[(c[o >> 2] | 0) + 24 >> 2]
	                }
	                c[(c[h >> 2] | 0) + 84 >> 2] = c[m >> 2];
	                if ((((c[o >> 2] | 0) != 0 ? (c[(c[o >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[o >> 2] | 0) + 8 >> 2] | 0, 167120) | 0) != 0 : 0) ? (qy(c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    if (c[(c[m >> 2] | 0) + 48 >> 2] & 1) {
	                        s = (c[m >> 2] | 0) + 48 | 0;
	                        c[s >> 2] = c[s >> 2] ^ 1
	                    }
	                    OF(c[h >> 2] | 0, c[j >> 2] | 0, c[o >> 2] | 0, u) | 0;
	                    c[o >> 2] = c[(c[o >> 2] | 0) + 24 >> 2]
	                } else w = 63;
	                do if ((w | 0) == 63) {
	                    if ((((c[o >> 2] | 0) != 0 ? (c[(c[o >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[o >> 2] | 0) + 8 >> 2] | 0, 167136) | 0) != 0 : 0) ? (qy(c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        c[(c[m >> 2] | 0) + 52 >> 2] = 1;
	                        PF(c[h >> 2] | 0, c[j >> 2] | 0, c[o >> 2] | 0, u) | 0;
	                        c[o >> 2] = c[(c[o >> 2] | 0) + 24 >> 2];
	                        break
	                    }
	                    s = IH(45) | 0;
	                    c[(c[m >> 2] | 0) + 64 >> 2] = s;
	                    s = (c[m >> 2] | 0) + 48 | 0;
	                    c[s >> 2] = c[s >> 2] | 4;
	                    if ((((c[o >> 2] | 0) != 0 ? (c[(c[o >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[o >> 2] | 0) + 8 >> 2] | 0, 161648) | 0) != 0 : 0) ? (qy(c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        s = QF(c[h >> 2] | 0, c[j >> 2] | 0, c[o >> 2] | 0, 8, 1) | 0;
	                        c[(c[m >> 2] | 0) + 28 >> 2] = s;
	                        c[o >> 2] = c[(c[o >> 2] | 0) + 24 >> 2]
	                    } else w = 73;
	                    do if ((w | 0) == 73) {
	                        if ((((c[o >> 2] | 0) != 0 ? (c[(c[o >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[o >> 2] | 0) + 8 >> 2] | 0, 161656) | 0) != 0 : 0) ? (qy(c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                            s = QF(c[h >> 2] | 0, c[j >> 2] | 0, c[o >> 2] | 0, 7, 1) | 0;
	                            c[(c[m >> 2] | 0) + 28 >> 2] = s;
	                            c[o >> 2] = c[(c[o >> 2] | 0) + 24 >> 2];
	                            break
	                        }
	                        if ((((c[o >> 2] | 0) != 0 ? (c[(c[o >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[o >> 2] | 0) + 8 >> 2] | 0, 161664) | 0) != 0 : 0) ? (qy(c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                            s = QF(c[h >> 2] | 0, c[j >> 2] | 0, c[o >> 2] | 0, 6, 1) | 0;
	                            c[(c[m >> 2] | 0) + 28 >> 2] = s;
	                            c[o >> 2] = c[(c[o >> 2] | 0) + 24 >> 2];
	                            break
	                        }
	                        if ((((c[o >> 2] | 0) != 0 ? (c[(c[o >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[o >> 2] | 0) + 8 >> 2] | 0, 161080) | 0) != 0 : 0) ? (qy(c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                            s = RF(c[h >> 2] | 0, c[j >> 2] | 0, c[o >> 2] | 0) | 0;
	                            c[(c[m >> 2] | 0) + 28 >> 2] = s;
	                            c[o >> 2] = c[(c[o >> 2] | 0) + 24 >> 2]
	                        }
	                    } while (0);
	                    if ((SF(c[h >> 2] | 0, c[j >> 2] | 0, o, (c[m >> 2] | 0) + 116 | 0, 12, 0) | 0) == -1) {
	                        c[g >> 2] = 0;
	                        v = c[g >> 2] | 0;
	                        i = f;
	                        return v | 0
	                    }
	                    if ((((c[o >> 2] | 0) != 0 ? (c[(c[o >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[o >> 2] | 0) + 8 >> 2] | 0, 163328) | 0) != 0 : 0) ? (qy(c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        s = TF(c[h >> 2] | 0, c[j >> 2] | 0, c[o >> 2] | 0) | 0;
	                        c[(c[m >> 2] | 0) + 84 >> 2] = s;
	                        c[o >> 2] = c[(c[o >> 2] | 0) + 24 >> 2]
	                    }
	                } while (0);
	                if (c[o >> 2] | 0)uE(c[h >> 2] | 0, 3033, 0, c[k >> 2] | 0, c[o >> 2] | 0, 0, 167152);
	                if ((c[l >> 2] | 0) != 0 ? !((c[u >> 2] | 0) != 0 ? 1 : (c[(c[h >> 2] | 0) + 100 >> 2] | 0) == 0) : 0)GE(c[h >> 2] | 0, 3081, 0, c[k >> 2] | 0, 167288, 0);
	                c[(c[h >> 2] | 0) + 84 >> 2] = c[n >> 2];
	                c[g >> 2] = c[m >> 2];
	                v = c[g >> 2] | 0;
	                i = f;
	                return v | 0
	            }

	            function oE(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f + 44 | 0;
	                h = f + 40 | 0;
	                j = f + 36 | 0;
	                k = f + 32 | 0;
	                l = f + 28 | 0;
	                m = f + 24 | 0;
	                n = f + 20 | 0;
	                o = f + 16 | 0;
	                p = f + 12 | 0;
	                q = f + 8 | 0;
	                r = f + 4 | 0;
	                s = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[o >> 2] = 0;
	                c[p >> 2] = 0;
	                c[r >> 2] = 0;
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0) {
	                    c[g >> 2] = 0;
	                    t = c[g >> 2] | 0;
	                    i = f;
	                    return t | 0
	                }
	                if (c[l >> 2] | 0) {
	                    c[q >> 2] = dE(c[k >> 2] | 0, 161352) | 0;
	                    e = c[h >> 2] | 0;
	                    if (!(c[q >> 2] | 0)) {
	                        MF(e, 3036, 0, c[k >> 2] | 0, 161352, 0);
	                        c[g >> 2] = 0;
	                        t = c[g >> 2] | 0;
	                        i = f;
	                        return t | 0
	                    }
	                    d = c[q >> 2] | 0;
	                    if (eE(e, 0, d, IH(22) | 0, p) | 0) {
	                        c[g >> 2] = 0;
	                        t = c[g >> 2] | 0;
	                        i = f;
	                        return t | 0
	                    }
	                    if (c[(c[h >> 2] | 0) + 96 >> 2] | 0) {
	                        if (c[(c[h >> 2] | 0) + 100 >> 2] | 0) {
	                            GE(c[h >> 2] | 0, 3081, 0, c[k >> 2] | 0, 165552, 0);
	                            c[g >> 2] = 0;
	                            t = c[g >> 2] | 0;
	                            i = f;
	                            return t | 0
	                        }
	                        c[s >> 2] = QH(c[p >> 2] | 0, c[38526] | 0) | 0;
	                        if (c[s >> 2] | 0) {
	                            c[g >> 2] = c[s >> 2];
	                            t = c[g >> 2] | 0;
	                            i = f;
	                            return t | 0
	                        }
	                    }
	                }
	                s = c[h >> 2] | 0;
	                d = c[j >> 2] | 0;
	                a:do if (c[l >> 2] | 0) {
	                    c[m >> 2] = WE(s, d, 4, c[p >> 2] | 0, c[(c[h >> 2] | 0) + 112 >> 2] | 0, c[k >> 2] | 0, 1) | 0;
	                    if (!(c[m >> 2] | 0)) {
	                        c[g >> 2] = 0;
	                        t = c[g >> 2] | 0;
	                        i = f;
	                        return t | 0
	                    }
	                    c[c[m >> 2] >> 2] = 4;
	                    c[(c[m >> 2] | 0) + 52 >> 2] = 4;
	                    e = (c[m >> 2] | 0) + 48 | 0;
	                    c[e >> 2] = c[e >> 2] | 8;
	                    c[q >> 2] = c[(c[k >> 2] | 0) + 44 >> 2];
	                    while (1) {
	                        if (!(c[q >> 2] | 0))break;
	                        e = c[q >> 2] | 0;
	                        if (!(c[(c[q >> 2] | 0) + 36 >> 2] | 0)) {
	                            if (((qy(c[e + 8 >> 2] | 0, 161384) | 0) == 0 ? (qy(c[(c[q >> 2] | 0) + 8 >> 2] | 0, 161352) | 0) == 0 : 0) ? (qy(c[(c[q >> 2] | 0) + 8 >> 2] | 0, 164504) | 0) == 0 : 0)GF(c[h >> 2] | 0, 3035, 0, c[q >> 2] | 0)
	                        } else if (qy(c[(c[e + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)GF(c[h >> 2] | 0, 3035, 0, c[q >> 2] | 0);
	                        c[q >> 2] = c[(c[q >> 2] | 0) + 24 >> 2]
	                    }
	                    c[q >> 2] = dE(c[k >> 2] | 0, 164504) | 0;
	                    if (c[q >> 2] | 0) {
	                        c[p >> 2] = RC(c[h >> 2] | 0, c[k >> 2] | 0, 164504) | 0;
	                        if (!(iE(c[p >> 2] | 0, (c[m >> 2] | 0) + 48 | 0, -1, -1, 1024, -1, 2048, 4096) | 0))break;
	                        hE(c[h >> 2] | 0, 3037, c[m >> 2] | 0, c[q >> 2] | 0, 0, 165608, c[p >> 2] | 0, 0, 0, 0);
	                        break
	                    }
	                    if (c[(c[j >> 2] | 0) + 24 >> 2] & 8) {
	                        e = (c[m >> 2] | 0) + 48 | 0;
	                        c[e >> 2] = c[e >> 2] | 1024
	                    }
	                    if (c[(c[j >> 2] | 0) + 24 >> 2] & 16) {
	                        e = (c[m >> 2] | 0) + 48 | 0;
	                        c[e >> 2] = c[e >> 2] | 2048
	                    }
	                    if (c[(c[j >> 2] | 0) + 24 >> 2] & 32) {
	                        e = (c[m >> 2] | 0) + 48 | 0;
	                        c[e >> 2] = c[e >> 2] | 4096
	                    }
	                } else {
	                    c[m >> 2] = WE(s, d, 4, 0, c[(c[h >> 2] | 0) + 112 >> 2] | 0, c[k >> 2] | 0, 0) | 0;
	                    if (!(c[m >> 2] | 0)) {
	                        c[g >> 2] = 0;
	                        t = c[g >> 2] | 0;
	                        i = f;
	                        return t | 0
	                    }
	                    c[c[m >> 2] >> 2] = 4;
	                    c[(c[m >> 2] | 0) + 52 >> 2] = 4;
	                    c[q >> 2] = c[(c[k >> 2] | 0) + 44 >> 2];
	                    while (1) {
	                        if (!(c[q >> 2] | 0))break a;
	                        e = c[q >> 2] | 0;
	                        if (!(c[(c[q >> 2] | 0) + 36 >> 2] | 0)) {
	                            if (!(qy(c[e + 8 >> 2] | 0, 161384) | 0))GF(c[h >> 2] | 0, 3035, 0, c[q >> 2] | 0)
	                        } else if (qy(c[(c[e + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)GF(c[h >> 2] | 0, 3035, 0, c[q >> 2] | 0);
	                        c[q >> 2] = c[(c[q >> 2] | 0) + 24 >> 2]
	                    }
	                } while (0);
	                c[(c[m >> 2] | 0) + 112 >> 2] = c[(c[h >> 2] | 0) + 112 >> 2];
	                cE(c[h >> 2] | 0, c[k >> 2] | 0, 161384) | 0;
	                c[n >> 2] = c[(c[h >> 2] | 0) + 84 >> 2];
	                c[(c[h >> 2] | 0) + 84 >> 2] = c[m >> 2];
	                c[o >> 2] = c[(c[k >> 2] | 0) + 12 >> 2];
	                if ((((c[o >> 2] | 0) != 0 ? (c[(c[o >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[o >> 2] | 0) + 8 >> 2] | 0, 160992) | 0) != 0 : 0) ? (qy(c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    q = jE(c[h >> 2] | 0, c[o >> 2] | 0, 1) | 0;
	                    c[(c[m >> 2] | 0) + 24 >> 2] = q;
	                    c[o >> 2] = c[(c[o >> 2] | 0) + 24 >> 2]
	                }
	                do if (c[o >> 2] | 0) {
	                    if ((((c[o >> 2] | 0) != 0 ? (c[(c[o >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[o >> 2] | 0) + 8 >> 2] | 0, 165456) | 0) != 0 : 0) ? (qy(c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        UF(c[h >> 2] | 0, c[j >> 2] | 0, c[o >> 2] | 0, 4) | 0;
	                        c[r >> 2] = 1;
	                        c[o >> 2] = c[(c[o >> 2] | 0) + 24 >> 2];
	                        break
	                    }
	                    if ((((c[o >> 2] | 0) != 0 ? (c[(c[o >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[o >> 2] | 0) + 8 >> 2] | 0, 165488) | 0) != 0 : 0) ? (qy(c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        VF(c[h >> 2] | 0, c[j >> 2] | 0, c[o >> 2] | 0) | 0;
	                        c[o >> 2] = c[(c[o >> 2] | 0) + 24 >> 2];
	                        break
	                    }
	                    if ((((c[o >> 2] | 0) != 0 ? (c[(c[o >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[o >> 2] | 0) + 8 >> 2] | 0, 165496) | 0) != 0 : 0) ? (qy(c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        WF(c[h >> 2] | 0, c[j >> 2] | 0, c[o >> 2] | 0) | 0;
	                        c[o >> 2] = c[(c[o >> 2] | 0) + 24 >> 2]
	                    }
	                } else uE(c[h >> 2] | 0, 3034, 0, c[k >> 2] | 0, c[o >> 2] | 0, 0, 165656); while (0);
	                if (c[o >> 2] | 0)uE(c[h >> 2] | 0, 3033, 0, c[k >> 2] | 0, c[o >> 2] | 0, 0, 165656);
	                if ((c[l >> 2] | 0) != 0 ? !((c[r >> 2] | 0) != 0 ? 1 : (c[(c[h >> 2] | 0) + 100 >> 2] | 0) == 0) : 0)GE(c[h >> 2] | 0, 3081, 0, c[k >> 2] | 0, 165704, 0);
	                c[(c[h >> 2] | 0) + 84 >> 2] = c[n >> 2];
	                c[g >> 2] = c[m >> 2];
	                t = c[g >> 2] | 0;
	                i = f;
	                return t | 0
	            }

	            function pE(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0, J = 0, K = 0;
	                g = i;
	                i = i + 112 | 0;
	                h = g + 96 | 0;
	                j = g + 92 | 0;
	                k = g + 88 | 0;
	                l = g + 84 | 0;
	                m = g + 80 | 0;
	                n = g + 76 | 0;
	                o = g + 72 | 0;
	                p = g + 68 | 0;
	                q = g + 64 | 0;
	                r = g + 60 | 0;
	                s = g + 56 | 0;
	                t = g + 52 | 0;
	                u = g + 48 | 0;
	                v = g + 44 | 0;
	                w = g + 40 | 0;
	                x = g + 36 | 0;
	                y = g + 32 | 0;
	                z = g + 28 | 0;
	                A = g + 24 | 0;
	                B = g + 20 | 0;
	                C = g + 16 | 0;
	                D = g + 12 | 0;
	                E = g + 8 | 0;
	                F = g + 4 | 0;
	                G = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = 0;
	                c[p >> 2] = 0;
	                c[q >> 2] = 0;
	                c[r >> 2] = 0;
	                c[w >> 2] = 0;
	                c[x >> 2] = 0;
	                if ((c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0) {
	                    c[h >> 2] = 0;
	                    H = c[h >> 2] | 0;
	                    i = g;
	                    return H | 0
	                }
	                if (c[m >> 2] | 0)c[c[m >> 2] >> 2] = 0;
	                c[t >> 2] = dE(c[l >> 2] | 0, 161352) | 0;
	                c[s >> 2] = dE(c[l >> 2] | 0, 160064) | 0;
	                if ((c[n >> 2] | 0) != 0 | (c[s >> 2] | 0) == 0) {
	                    if (!(c[t >> 2] | 0)) {
	                        MF(c[j >> 2] | 0, 3036, 0, c[l >> 2] | 0, 161352, 0);
	                        c[h >> 2] = 0;
	                        H = c[h >> 2] | 0;
	                        i = g;
	                        return H | 0
	                    }
	                } else c[w >> 2] = 1;
	                cE(c[j >> 2] | 0, c[l >> 2] | 0, 161384) | 0;
	                c[r >> 2] = c[(c[l >> 2] | 0) + 12 >> 2];
	                if ((((c[r >> 2] | 0) != 0 ? (c[(c[r >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[r >> 2] | 0) + 8 >> 2] | 0, 160992) | 0) != 0 : 0) ? (qy(c[(c[(c[r >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    c[q >> 2] = jE(c[j >> 2] | 0, c[r >> 2] | 0, 1) | 0;
	                    c[r >> 2] = c[(c[r >> 2] | 0) + 24 >> 2]
	                }
	                if (!(c[n >> 2] | 0)) {
	                    c[u >> 2] = XF(c[j >> 2] | 0, c[l >> 2] | 0, 0, -1, 1, 161744) | 0;
	                    c[v >> 2] = YF(c[j >> 2] | 0, c[l >> 2] | 0, 0, 1073741824, 1, 161768) | 0;
	                    ZF(c[j >> 2] | 0, 0, c[l >> 2] | 0, c[u >> 2] | 0, c[v >> 2] | 0) | 0;
	                    c[p >> 2] = XE(c[j >> 2] | 0, c[l >> 2] | 0, c[u >> 2] | 0, c[v >> 2] | 0) | 0;
	                    if (c[p >> 2] | 0)if (c[w >> 2] | 0) {
	                        c[y >> 2] = 0;
	                        c[z >> 2] = 0;
	                        c[A >> 2] = 0;
	                        if (c[m >> 2] | 0)c[c[m >> 2] >> 2] = 1;
	                        _F(c[j >> 2] | 0, c[k >> 2] | 0, 0, c[s >> 2] | 0, y, z) | 0;
	                        $F(c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[s >> 2] | 0, c[y >> 2] | 0) | 0;
	                        if (c[t >> 2] | 0)aG(c[j >> 2] | 0, 3039, 0, c[t >> 2] | 0, 160064, 161352);
	                        c[s >> 2] = c[(c[l >> 2] | 0) + 44 >> 2];
	                        while (1) {
	                            if (!(c[s >> 2] | 0))break;
	                            m = c[s >> 2] | 0;
	                            if (c[(c[s >> 2] | 0) + 36 >> 2] | 0) {
	                                if (qy(c[(c[m + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)GF(c[j >> 2] | 0, 3035, 0, c[s >> 2] | 0);
	                                c[s >> 2] = c[(c[s >> 2] | 0) + 24 >> 2];
	                                continue
	                            }
	                            if (((((qy(c[m + 8 >> 2] | 0, 160064) | 0) == 0 ? (qy(c[(c[s >> 2] | 0) + 8 >> 2] | 0, 161352) | 0) == 0 : 0) ? (qy(c[(c[s >> 2] | 0) + 8 >> 2] | 0, 161384) | 0) == 0 : 0) ? (qy(c[(c[s >> 2] | 0) + 8 >> 2] | 0, 161808) | 0) == 0 : 0) ? (qy(c[(c[s >> 2] | 0) + 8 >> 2] | 0, 161824) | 0) == 0 : 0) {
	                                I = 30;
	                                break
	                            }
	                            c[s >> 2] = c[(c[s >> 2] | 0) + 24 >> 2]
	                        }
	                        if ((I | 0) == 30)bG(c[j >> 2] | 0, 3040, 0, 0, c[s >> 2] | 0, 164392);
	                        if (c[r >> 2] | 0)uE(c[j >> 2] | 0, 3033, 0, c[l >> 2] | 0, c[r >> 2] | 0, 0, 161392);
	                        if (!((c[u >> 2] | 0) == 0 & (c[v >> 2] | 0) == 0) ? (c[A >> 2] = cG(c[j >> 2] | 0, 14, c[z >> 2] | 0, c[y >> 2] | 0) | 0, (c[A >> 2] | 0) != 0) : 0) {
	                            c[(c[p >> 2] | 0) + 12 >> 2] = c[A >> 2];
	                            c[(c[p >> 2] | 0) + 4 >> 2] = c[q >> 2];
	                            dG((c[(c[j >> 2] | 0) + 28 >> 2] | 0) + 20 | 0, 10, c[p >> 2] | 0) | 0;
	                            c[h >> 2] = c[p >> 2];
	                            H = c[h >> 2] | 0;
	                            i = g;
	                            return H | 0
	                        }
	                    } else I = 39
	                } else I = 39;
	                if ((I | 0) == 39 ? (c[B >> 2] = 0, c[F >> 2] = 0, c[G >> 2] = 0, A = c[j >> 2] | 0, y = c[t >> 2] | 0, (eE(A, 0, y, IH(22) | 0, D) | 0) == 0) : 0) {
	                    do if (!(c[n >> 2] | 0)) {
	                        c[s >> 2] = dE(c[l >> 2] | 0, 163528) | 0;
	                        if (!(c[s >> 2] | 0)) {
	                            if (!(c[(c[k >> 2] | 0) + 24 >> 2] & 1))break;
	                            c[B >> 2] = c[(c[j >> 2] | 0) + 112 >> 2];
	                            break
	                        }
	                        c[E >> 2] = fE(c[j >> 2] | 0, c[s >> 2] | 0) | 0;
	                        if (qy(c[E >> 2] | 0, 163536) | 0) {
	                            c[B >> 2] = c[(c[j >> 2] | 0) + 112 >> 2];
	                            break
	                        }
	                        if (!(qy(c[E >> 2] | 0, 163552) | 0))hE(c[j >> 2] | 0, 3037, 0, c[s >> 2] | 0, 0, 163568, c[E >> 2] | 0, 0, 0, 0)
	                    } else c[B >> 2] = c[(c[j >> 2] | 0) + 112 >> 2]; while (0);
	                    c[o >> 2] = eG(c[j >> 2] | 0, c[D >> 2] | 0, c[B >> 2] | 0, c[l >> 2] | 0, c[n >> 2] | 0) | 0;
	                    if (c[o >> 2] | 0) {
	                        c[s >> 2] = c[(c[l >> 2] | 0) + 44 >> 2];
	                        while (1) {
	                            if (!(c[s >> 2] | 0))break;
	                            B = c[s >> 2] | 0;
	                            do if (!(c[(c[s >> 2] | 0) + 36 >> 2] | 0)) {
	                                if (((((((qy(c[B + 8 >> 2] | 0, 161352) | 0) == 0 ? (qy(c[(c[s >> 2] | 0) + 8 >> 2] | 0, 155448) | 0) == 0 : 0) ? (qy(c[(c[s >> 2] | 0) + 8 >> 2] | 0, 161384) | 0) == 0 : 0) ? (qy(c[(c[s >> 2] | 0) + 8 >> 2] | 0, 159128) | 0) == 0 : 0) ? (qy(c[(c[s >> 2] | 0) + 8 >> 2] | 0, 159120) | 0) == 0 : 0) ? (qy(c[(c[s >> 2] | 0) + 8 >> 2] | 0, 164480) | 0) == 0 : 0) ? (qy(c[(c[s >> 2] | 0) + 8 >> 2] | 0, 164488) | 0) == 0 : 0) {
	                                    D = c[(c[s >> 2] | 0) + 8 >> 2] | 0;
	                                    if (!(c[n >> 2] | 0)) {
	                                        if (qy(D, 161808) | 0)break;
	                                        if (qy(c[(c[s >> 2] | 0) + 8 >> 2] | 0, 161824) | 0)break;
	                                        if (qy(c[(c[s >> 2] | 0) + 8 >> 2] | 0, 163528) | 0)break;
	                                        GF(c[j >> 2] | 0, 3035, 0, c[s >> 2] | 0);
	                                        break
	                                    } else {
	                                        if (qy(D, 164504) | 0)break;
	                                        if (qy(c[(c[s >> 2] | 0) + 8 >> 2] | 0, 164512) | 0)break;
	                                        if (qy(c[(c[s >> 2] | 0) + 8 >> 2] | 0, 160544) | 0)break;
	                                        GF(c[j >> 2] | 0, 3035, 0, c[s >> 2] | 0);
	                                        break
	                                    }
	                                }
	                            } else if (qy(c[(c[B + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)GF(c[j >> 2] | 0, 3035, 0, c[s >> 2] | 0); while (0);
	                            c[s >> 2] = c[(c[s >> 2] | 0) + 24 >> 2]
	                        }
	                        do if (c[n >> 2] | 0) {
	                            B = (c[o >> 2] | 0) + 48 | 0;
	                            c[B >> 2] = c[B >> 2] | 2;
	                            B = (c[o >> 2] | 0) + 48 | 0;
	                            c[B >> 2] = c[B >> 2] | 32;
	                            fG(c[j >> 2] | 0, c[k >> 2] | 0, 0, c[l >> 2] | 0, 160544, (c[o >> 2] | 0) + 68 | 0, (c[o >> 2] | 0) + 64 | 0) | 0;
	                            if (gG(c[j >> 2] | 0, c[l >> 2] | 0, 164512, 0) | 0) {
	                                B = (c[o >> 2] | 0) + 48 | 0;
	                                c[B >> 2] = c[B >> 2] | 16
	                            }
	                            c[s >> 2] = dE(c[l >> 2] | 0, 164504) | 0;
	                            if (c[s >> 2] | 0) {
	                                c[E >> 2] = fE(c[j >> 2] | 0, c[s >> 2] | 0) | 0;
	                                if (!(iE(c[E >> 2] | 0, (c[o >> 2] | 0) + 48 | 0, -1, 32768, 65536, -1, -1, -1) | 0))break;
	                                hE(c[j >> 2] | 0, 3037, 0, c[s >> 2] | 0, 0, 164528, c[E >> 2] | 0, 0, 0, 0);
	                                break
	                            }
	                            if (c[(c[k >> 2] | 0) + 24 >> 2] & 4) {
	                                B = (c[o >> 2] | 0) + 48 | 0;
	                                c[B >> 2] = c[B >> 2] | 32768
	                            }
	                            if (c[(c[k >> 2] | 0) + 24 >> 2] & 8) {
	                                B = (c[o >> 2] | 0) + 48 | 0;
	                                c[B >> 2] = c[B >> 2] | 65536
	                            }
	                        } while (0);
	                        c[s >> 2] = dE(c[l >> 2] | 0, 164480) | 0;
	                        if (!(c[s >> 2] | 0)) {
	                            if (c[(c[k >> 2] | 0) + 24 >> 2] & 128) {
	                                B = (c[o >> 2] | 0) + 48 | 0;
	                                c[B >> 2] = c[B >> 2] | 4096
	                            }
	                            if (c[(c[k >> 2] | 0) + 24 >> 2] & 64) {
	                                B = (c[o >> 2] | 0) + 48 | 0;
	                                c[B >> 2] = c[B >> 2] | 2048
	                            }
	                            if (c[(c[k >> 2] | 0) + 24 >> 2] & 256) {
	                                B = (c[o >> 2] | 0) + 48 | 0;
	                                c[B >> 2] = c[B >> 2] | 8192
	                            }
	                        } else {
	                            c[E >> 2] = fE(c[j >> 2] | 0, c[s >> 2] | 0) | 0;
	                            if (iE(c[E >> 2] | 0, (c[o >> 2] | 0) + 48 | 0, -1, 2048, 4096, 8192, -1, -1) | 0)hE(c[j >> 2] | 0, 3037, 0, c[s >> 2] | 0, 0, 164576, c[E >> 2] | 0, 0, 0, 0)
	                        }
	                        if (gG(c[j >> 2] | 0, c[l >> 2] | 0, 164488, 0) | 0) {
	                            E = (c[o >> 2] | 0) + 48 | 0;
	                            c[E >> 2] = c[E >> 2] | 1
	                        }
	                        c[s >> 2] = dE(c[l >> 2] | 0, 155448) | 0;
	                        if (c[s >> 2] | 0) {
	                            _F(c[j >> 2] | 0, c[k >> 2] | 0, 0, c[s >> 2] | 0, (c[o >> 2] | 0) + 60 | 0, (c[o >> 2] | 0) + 56 | 0) | 0;
	                            $F(c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[s >> 2] | 0, c[(c[o >> 2] | 0) + 60 >> 2] | 0) | 0
	                        }
	                        E = RC(c[j >> 2] | 0, c[l >> 2] | 0, 159128) | 0;
	                        c[(c[o >> 2] | 0) + 76 >> 2] = E;
	                        c[s >> 2] = dE(c[l >> 2] | 0, 159120) | 0;
	                        do if (c[s >> 2] | 0) {
	                            c[C >> 2] = fE(c[j >> 2] | 0, c[s >> 2] | 0) | 0;
	                            if (c[(c[o >> 2] | 0) + 76 >> 2] | 0) {
	                                aG(c[j >> 2] | 0, 3038, 0, c[s >> 2] | 0, 159128, 159120);
	                                break
	                            } else {
	                                E = (c[o >> 2] | 0) + 48 | 0;
	                                c[E >> 2] = c[E >> 2] | 8;
	                                c[(c[o >> 2] | 0) + 76 >> 2] = c[C >> 2];
	                                break
	                            }
	                        } while (0);
	                        if ((((c[r >> 2] | 0) != 0 ? (c[(c[r >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[r >> 2] | 0) + 8 >> 2] | 0, 161008) | 0) != 0 : 0) ? (qy(c[(c[(c[r >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                            C = c[j >> 2] | 0;
	                            if (c[(c[o >> 2] | 0) + 56 >> 2] | 0)uE(C, 3041, 0, c[l >> 2] | 0, c[r >> 2] | 0, 164640, 0); else {
	                                s = nE(C, c[k >> 2] | 0, c[r >> 2] | 0, 0) | 0;
	                                c[(c[o >> 2] | 0) + 28 >> 2] = s
	                            }
	                            c[r >> 2] = c[(c[r >> 2] | 0) + 24 >> 2]
	                        } else I = 107;
	                        if (((((I | 0) == 107 ? (c[r >> 2] | 0) != 0 : 0) ? (c[(c[r >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[r >> 2] | 0) + 8 >> 2] | 0, 161024) | 0) != 0 : 0) ? (qy(c[(c[(c[r >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                            s = c[j >> 2] | 0;
	                            if (c[(c[o >> 2] | 0) + 56 >> 2] | 0)uE(s, 3041, 0, c[l >> 2] | 0, c[r >> 2] | 0, 164128, 0); else {
	                                C = oE(s, c[k >> 2] | 0, c[r >> 2] | 0, 0) | 0;
	                                c[(c[o >> 2] | 0) + 28 >> 2] = C
	                            }
	                            c[r >> 2] = c[(c[r >> 2] | 0) + 24 >> 2]
	                        }
	                        while (1) {
	                            if ((((c[r >> 2] | 0) != 0 ? (c[(c[r >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[r >> 2] | 0) + 8 >> 2] | 0, 164712) | 0) != 0 : 0) ? (qy(c[(c[(c[r >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0)J = 1; else I = 119;
	                            a:do if ((I | 0) == 119) {
	                                I = 0;
	                                do if (c[r >> 2] | 0) {
	                                    if (!(c[(c[r >> 2] | 0) + 36 >> 2] | 0))break;
	                                    if (!(qy(c[(c[r >> 2] | 0) + 8 >> 2] | 0, 164720) | 0))break;
	                                    if (qy(c[(c[(c[r >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) {
	                                        J = 1;
	                                        break a
	                                    }
	                                } while (0);
	                                if (c[r >> 2] | 0) {
	                                    if (!(c[(c[r >> 2] | 0) + 36 >> 2] | 0)) {
	                                        J = 0;
	                                        break
	                                    }
	                                    if (!(qy(c[(c[r >> 2] | 0) + 8 >> 2] | 0, 164728) | 0)) {
	                                        J = 0;
	                                        break
	                                    }
	                                    J = (qy(c[(c[(c[r >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0
	                                } else J = 0
	                            } while (0);
	                            K = (c[r >> 2] | 0) != 0;
	                            if (!J)break;
	                            do if (K) {
	                                if (!(c[(c[r >> 2] | 0) + 36 >> 2] | 0)) {
	                                    I = 133;
	                                    break
	                                }
	                                if (!(qy(c[(c[r >> 2] | 0) + 8 >> 2] | 0, 164712) | 0)) {
	                                    I = 133;
	                                    break
	                                }
	                                if (!(qy(c[(c[(c[r >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)) {
	                                    I = 133;
	                                    break
	                                }
	                                c[F >> 2] = hG(c[j >> 2] | 0, c[k >> 2] | 0, c[r >> 2] | 0, 22, c[(c[o >> 2] | 0) + 52 >> 2] | 0) | 0
	                            } else I = 133; while (0);
	                            b:do if ((I | 0) == 133) {
	                                I = 0;
	                                do if (c[r >> 2] | 0) {
	                                    if (!(c[(c[r >> 2] | 0) + 36 >> 2] | 0))break;
	                                    if (!(qy(c[(c[r >> 2] | 0) + 8 >> 2] | 0, 164720) | 0))break;
	                                    if (!(qy(c[(c[(c[r >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0))break;
	                                    c[F >> 2] = hG(c[j >> 2] | 0, c[k >> 2] | 0, c[r >> 2] | 0, 23, c[(c[o >> 2] | 0) + 52 >> 2] | 0) | 0;
	                                    break b
	                                } while (0);
	                                if (!(c[r >> 2] | 0))break;
	                                if (!(c[(c[r >> 2] | 0) + 36 >> 2] | 0))break;
	                                if (!(qy(c[(c[r >> 2] | 0) + 8 >> 2] | 0, 164728) | 0))break;
	                                if (!(qy(c[(c[(c[r >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0))break;
	                                c[F >> 2] = hG(c[j >> 2] | 0, c[k >> 2] | 0, c[r >> 2] | 0, 24, c[(c[o >> 2] | 0) + 52 >> 2] | 0) | 0
	                            } while (0);
	                            C = c[F >> 2] | 0;
	                            if (c[G >> 2] | 0)c[(c[G >> 2] | 0) + 8 >> 2] = C; else c[(c[o >> 2] | 0) + 100 >> 2] = C;
	                            c[G >> 2] = c[F >> 2];
	                            c[r >> 2] = c[(c[r >> 2] | 0) + 24 >> 2]
	                        }
	                        if (K)uE(c[j >> 2] | 0, 3033, 0, c[l >> 2] | 0, c[r >> 2] | 0, 0, 164736);
	                        c[(c[o >> 2] | 0) + 24 >> 2] = c[q >> 2];
	                        if (c[x >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[x >> 2] | 0);
	                            c[x >> 2] = 0
	                        }
	                        r = c[o >> 2] | 0;
	                        if (c[n >> 2] | 0) {
	                            c[h >> 2] = r;
	                            H = c[h >> 2] | 0;
	                            i = g;
	                            return H | 0
	                        } else {
	                            c[(c[p >> 2] | 0) + 12 >> 2] = r;
	                            c[h >> 2] = c[p >> 2];
	                            H = c[h >> 2] | 0;
	                            i = g;
	                            return H | 0
	                        }
	                    }
	                }
	                if (c[x >> 2] | 0) {
	                    zb[c[135736 >> 2] & 511](c[x >> 2] | 0);
	                    c[x >> 2] = 0
	                }
	                if (c[q >> 2] | 0) {
	                    if (c[p >> 2] | 0)c[(c[p >> 2] | 0) + 4 >> 2] = 0;
	                    if (c[o >> 2] | 0)c[(c[o >> 2] | 0) + 24 >> 2] = 0;
	                    mB(c[q >> 2] | 0)
	                }
	                c[h >> 2] = 0;
	                H = c[h >> 2] | 0;
	                i = g;
	                return H | 0
	            }

	            function qE(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 28 | 0;
	                g = e + 24 | 0;
	                h = e + 20 | 0;
	                j = e + 16 | 0;
	                k = e + 12 | 0;
	                l = e + 8 | 0;
	                m = e + 4 | 0;
	                n = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[m >> 2] = 0;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                c[n >> 2] = dE(c[j >> 2] | 0, 161352) | 0;
	                d = c[g >> 2] | 0;
	                if (!(c[n >> 2] | 0)) {
	                    MF(d, 3036, 0, c[j >> 2] | 0, 161352, 0);
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                b = c[n >> 2] | 0;
	                if (eE(d, 0, b, IH(22) | 0, k) | 0) {
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                b = (qy(c[k >> 2] | 0, 163840) | 0) != 0;
	                d = c[g >> 2] | 0;
	                if (b) {
	                    b = c[n >> 2] | 0;
	                    hE(d, 3056, 0, b, IH(22) | 0, 0, 0, 163848, 0, 0);
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                if (qy(c[d + 112 >> 2] | 0, c[38860] | 0) | 0)AB(c[g >> 2] | 0, 3057, c[j >> 2] | 0, 0, 163792, c[38860] | 0, 0);
	                c[l >> 2] = iG(c[g >> 2] | 0, c[h >> 2] | 0, c[k >> 2] | 0, c[(c[g >> 2] | 0) + 112 >> 2] | 0, c[j >> 2] | 0, 1) | 0;
	                if (!(c[l >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                k = (c[l >> 2] | 0) + 60 | 0;
	                c[k >> 2] = c[k >> 2] | 1;
	                c[n >> 2] = c[(c[j >> 2] | 0) + 44 >> 2];
	                while (1) {
	                    if (!(c[n >> 2] | 0))break;
	                    k = c[n >> 2] | 0;
	                    if (!(c[(c[n >> 2] | 0) + 36 >> 2] | 0)) {
	                        if (((((qy(c[k + 8 >> 2] | 0, 161384) | 0) == 0 ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 159128) | 0) == 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 159120) | 0) == 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 161352) | 0) == 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 155448) | 0) == 0 : 0)GF(c[g >> 2] | 0, 3035, 0, c[n >> 2] | 0)
	                    } else if (qy(c[(c[k + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)GF(c[g >> 2] | 0, 3035, 0, c[n >> 2] | 0);
	                    c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2]
	                }
	                fG(c[g >> 2] | 0, c[h >> 2] | 0, 0, c[j >> 2] | 0, 155448, (c[l >> 2] | 0) + 28 | 0, (c[l >> 2] | 0) + 24 | 0) | 0;
	                cE(c[g >> 2] | 0, c[j >> 2] | 0, 161384) | 0;
	                k = RC(c[g >> 2] | 0, c[j >> 2] | 0, 159120) | 0;
	                c[(c[l >> 2] | 0) + 44 >> 2] = k;
	                if (c[(c[l >> 2] | 0) + 44 >> 2] | 0) {
	                    k = (c[l >> 2] | 0) + 60 | 0;
	                    c[k >> 2] = c[k >> 2] | 512
	                }
	                c[n >> 2] = dE(c[j >> 2] | 0, 159128) | 0;
	                do if (c[n >> 2] | 0) {
	                    k = c[g >> 2] | 0;
	                    if (c[(c[l >> 2] | 0) + 60 >> 2] & 512) {
	                        aG(k, 3051, c[l >> 2] | 0, c[n >> 2] | 0, 159128, 159120);
	                        break
	                    } else {
	                        d = fE(k, c[n >> 2] | 0) | 0;
	                        c[(c[l >> 2] | 0) + 44 >> 2] = d;
	                        break
	                    }
	                } while (0);
	                c[m >> 2] = c[(c[j >> 2] | 0) + 12 >> 2];
	                if ((((c[m >> 2] | 0) != 0 ? (c[(c[m >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 160992) | 0) != 0 : 0) ? (qy(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    n = jE(c[g >> 2] | 0, c[m >> 2] | 0, 1) | 0;
	                    c[(c[l >> 2] | 0) + 32 >> 2] = n;
	                    c[m >> 2] = c[(c[m >> 2] | 0) + 24 >> 2]
	                }
	                if ((((c[m >> 2] | 0) != 0 ? (c[(c[m >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 161024) | 0) != 0 : 0) ? (qy(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    n = c[g >> 2] | 0;
	                    if (c[(c[l >> 2] | 0) + 24 >> 2] | 0)uE(n, 3055, 0, c[j >> 2] | 0, c[m >> 2] | 0, 164128, 0); else {
	                        d = oE(n, c[h >> 2] | 0, c[m >> 2] | 0, 0) | 0;
	                        c[(c[l >> 2] | 0) + 48 >> 2] = d
	                    }
	                    c[m >> 2] = c[(c[m >> 2] | 0) + 24 >> 2]
	                }
	                if (c[m >> 2] | 0)uE(c[g >> 2] | 0, 3033, 0, c[j >> 2] | 0, c[m >> 2] | 0, 0, 164200);
	                c[f >> 2] = c[l >> 2];
	                o = c[f >> 2] | 0;
	                i = e;
	                return o | 0
	            }

	            function rE(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 32 | 0;
	                g = e + 28 | 0;
	                h = e + 24 | 0;
	                j = e + 20 | 0;
	                k = e + 16 | 0;
	                l = e + 12 | 0;
	                m = e + 8 | 0;
	                n = e + 4 | 0;
	                o = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[m >> 2] = 0;
	                c[o >> 2] = 0;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    p = c[f >> 2] | 0;
	                    i = e;
	                    return p | 0
	                }
	                c[n >> 2] = dE(c[j >> 2] | 0, 161352) | 0;
	                d = c[g >> 2] | 0;
	                if (!(c[n >> 2] | 0)) {
	                    MF(d, 3036, 0, c[j >> 2] | 0, 161352, 0);
	                    c[f >> 2] = 0;
	                    p = c[f >> 2] | 0;
	                    i = e;
	                    return p | 0
	                }
	                b = c[n >> 2] | 0;
	                if (eE(d, 0, b, IH(22) | 0, k) | 0) {
	                    c[f >> 2] = 0;
	                    p = c[f >> 2] | 0;
	                    i = e;
	                    return p | 0
	                }
	                c[l >> 2] = jG(c[g >> 2] | 0, c[h >> 2] | 0, c[k >> 2] | 0, c[(c[g >> 2] | 0) + 112 >> 2] | 0, c[j >> 2] | 0) | 0;
	                if (!(c[l >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    p = c[f >> 2] | 0;
	                    i = e;
	                    return p | 0
	                }
	                c[n >> 2] = c[(c[j >> 2] | 0) + 44 >> 2];
	                while (1) {
	                    if (!(c[n >> 2] | 0))break;
	                    k = c[n >> 2] | 0;
	                    if (!(c[(c[n >> 2] | 0) + 36 >> 2] | 0)) {
	                        if ((qy(c[k + 8 >> 2] | 0, 161352) | 0) == 0 ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 161384) | 0) == 0 : 0)GF(c[g >> 2] | 0, 3035, 0, c[n >> 2] | 0)
	                    } else if (qy(c[(c[k + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)GF(c[g >> 2] | 0, 3035, 0, c[n >> 2] | 0);
	                    c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2]
	                }
	                cE(c[g >> 2] | 0, c[j >> 2] | 0, 161384) | 0;
	                c[m >> 2] = c[(c[j >> 2] | 0) + 12 >> 2];
	                if ((((c[m >> 2] | 0) != 0 ? (c[(c[m >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 160992) | 0) != 0 : 0) ? (qy(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    n = jE(c[g >> 2] | 0, c[m >> 2] | 0, 1) | 0;
	                    c[(c[l >> 2] | 0) + 24 >> 2] = n;
	                    c[m >> 2] = c[(c[m >> 2] | 0) + 24 >> 2]
	                }
	                if ((SF(c[g >> 2] | 0, c[h >> 2] | 0, m, (c[l >> 2] | 0) + 56 | 0, 16, o) | 0) == -1) {
	                    c[f >> 2] = 0;
	                    p = c[f >> 2] | 0;
	                    i = e;
	                    return p | 0
	                }
	                if (c[o >> 2] | 0) {
	                    o = (c[l >> 2] | 0) + 36 | 0;
	                    c[o >> 2] = c[o >> 2] | 16
	                }
	                if ((((c[m >> 2] | 0) != 0 ? (c[(c[m >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 163328) | 0) != 0 : 0) ? (qy(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    o = TF(c[g >> 2] | 0, c[h >> 2] | 0, c[m >> 2] | 0) | 0;
	                    c[(c[l >> 2] | 0) + 40 >> 2] = o;
	                    c[m >> 2] = c[(c[m >> 2] | 0) + 24 >> 2]
	                }
	                if (c[m >> 2] | 0)uE(c[g >> 2] | 0, 3033, 0, c[j >> 2] | 0, c[m >> 2] | 0, 0, 163344);
	                c[f >> 2] = c[l >> 2];
	                p = c[f >> 2] | 0;
	                i = e;
	                return p | 0
	            }

	            function sE(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 28 | 0;
	                g = e + 24 | 0;
	                h = e + 20 | 0;
	                j = e + 16 | 0;
	                k = e + 12 | 0;
	                l = e + 8 | 0;
	                m = e + 4 | 0;
	                n = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[l >> 2] = 0;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                c[m >> 2] = dE(c[j >> 2] | 0, 161352) | 0;
	                d = c[g >> 2] | 0;
	                if (!(c[m >> 2] | 0)) {
	                    MF(d, 3036, 0, c[j >> 2] | 0, 161352, 0);
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                b = c[m >> 2] | 0;
	                if (eE(d, 0, b, IH(22) | 0, n) | 0) {
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                c[k >> 2] = kG(c[g >> 2] | 0, c[h >> 2] | 0, c[n >> 2] | 0, c[(c[g >> 2] | 0) + 112 >> 2] | 0, c[j >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                c[m >> 2] = c[(c[j >> 2] | 0) + 44 >> 2];
	                while (1) {
	                    if (!(c[m >> 2] | 0))break;
	                    n = c[m >> 2] | 0;
	                    if (!(c[(c[m >> 2] | 0) + 36 >> 2] | 0)) {
	                        if ((qy(c[n + 8 >> 2] | 0, 161352) | 0) == 0 ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 161384) | 0) == 0 : 0)GF(c[g >> 2] | 0, 3035, 0, c[m >> 2] | 0)
	                    } else if (qy(c[(c[n + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)GF(c[g >> 2] | 0, 3035, 0, c[m >> 2] | 0);
	                    c[m >> 2] = c[(c[m >> 2] | 0) + 24 >> 2]
	                }
	                cE(c[g >> 2] | 0, c[j >> 2] | 0, 161384) | 0;
	                c[l >> 2] = c[(c[j >> 2] | 0) + 12 >> 2];
	                if ((((c[l >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[l >> 2] | 0) + 8 >> 2] | 0, 160992) | 0) != 0 : 0) ? (qy(c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    m = jE(c[g >> 2] | 0, c[l >> 2] | 0, 1) | 0;
	                    c[(c[k >> 2] | 0) + 4 >> 2] = m;
	                    c[l >> 2] = c[(c[l >> 2] | 0) + 24 >> 2]
	                }
	                if ((((c[l >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[l >> 2] | 0) + 8 >> 2] | 0, 161648) | 0) != 0 : 0) ? (qy(c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    m = QF(c[g >> 2] | 0, c[h >> 2] | 0, c[l >> 2] | 0, 8, 0) | 0;
	                    c[(c[k >> 2] | 0) + 12 >> 2] = m;
	                    c[l >> 2] = c[(c[l >> 2] | 0) + 24 >> 2]
	                } else p = 28;
	                do if ((p | 0) == 28) {
	                    if ((((c[l >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[l >> 2] | 0) + 8 >> 2] | 0, 161656) | 0) != 0 : 0) ? (qy(c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        m = QF(c[g >> 2] | 0, c[h >> 2] | 0, c[l >> 2] | 0, 7, 0) | 0;
	                        c[(c[k >> 2] | 0) + 12 >> 2] = m;
	                        c[l >> 2] = c[(c[l >> 2] | 0) + 24 >> 2];
	                        break
	                    }
	                    if ((((c[l >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[l >> 2] | 0) + 8 >> 2] | 0, 161664) | 0) != 0 : 0) ? (qy(c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        m = QF(c[g >> 2] | 0, c[h >> 2] | 0, c[l >> 2] | 0, 6, 0) | 0;
	                        c[(c[k >> 2] | 0) + 12 >> 2] = m;
	                        c[l >> 2] = c[(c[l >> 2] | 0) + 24 >> 2]
	                    }
	                } while (0);
	                if (c[l >> 2] | 0)uE(c[g >> 2] | 0, 3033, 0, c[j >> 2] | 0, c[l >> 2] | 0, 0, 161680);
	                c[f >> 2] = c[k >> 2];
	                o = c[f >> 2] | 0;
	                i = e;
	                return o | 0
	            }

	            function tE(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 20 | 0;
	                h = e + 16 | 0;
	                j = e + 12 | 0;
	                k = e + 8 | 0;
	                l = e + 4 | 0;
	                m = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[m >> 2] = 0;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                c[k >> 2] = RC(c[g >> 2] | 0, c[j >> 2] | 0, 161352) | 0;
	                d = c[g >> 2] | 0;
	                if (!(c[k >> 2] | 0)) {
	                    lG(d, c[j >> 2] | 0, c[m >> 2] | 0, 1723, 161360, 0, 0);
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                c[l >> 2] = mG(d, c[h >> 2] | 0, c[k >> 2] | 0, c[(c[g >> 2] | 0) + 112 >> 2] | 0, c[j >> 2] | 0) | 0;
	                if (!(c[l >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                cE(c[g >> 2] | 0, c[j >> 2] | 0, 161384) | 0;
	                c[m >> 2] = c[(c[j >> 2] | 0) + 12 >> 2];
	                if ((((c[m >> 2] | 0) != 0 ? (c[(c[m >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 160992) | 0) != 0 : 0) ? (qy(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    k = jE(c[g >> 2] | 0, c[m >> 2] | 0, 1) | 0;
	                    c[(c[l >> 2] | 0) + 8 >> 2] = k;
	                    c[m >> 2] = c[(c[m >> 2] | 0) + 24 >> 2]
	                }
	                if (c[m >> 2] | 0)uE(c[g >> 2] | 0, 3033, 0, c[j >> 2] | 0, c[m >> 2] | 0, 0, 161392);
	                c[f >> 2] = c[l >> 2];
	                n = c[f >> 2] | 0;
	                i = e;
	                return n | 0
	            }

	            function uE(a, b, d, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                j = i;
	                i = i + 32 | 0;
	                k = j + 28 | 0;
	                l = j + 24 | 0;
	                m = j + 20 | 0;
	                n = j + 16 | 0;
	                o = j + 12 | 0;
	                p = j + 8 | 0;
	                q = j + 4 | 0;
	                r = j;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                c[q >> 2] = h;
	                c[r >> 2] = 0;
	                GC(r, 0, c[m >> 2] | 0, c[n >> 2] | 0) | 0;
	                do if (!(c[p >> 2] | 0)) {
	                    m = c[k >> 2] | 0;
	                    h = c[n >> 2] | 0;
	                    g = c[o >> 2] | 0;
	                    f = c[l >> 2] | 0;
	                    e = c[r >> 2] | 0;
	                    if (c[q >> 2] | 0) {
	                        lG(m, h, g, f, 161272, e, c[q >> 2] | 0);
	                        break
	                    } else {
	                        lG(m, h, g, f, 161320, e, 0);
	                        break
	                    }
	                } else lG(c[k >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, c[l >> 2] | 0, 161256, c[r >> 2] | 0, c[p >> 2] | 0); while (0);
	                if (!(c[r >> 2] | 0)) {
	                    i = j;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                c[r >> 2] = 0;
	                i = j;
	                return
	            }

	            function vE(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 28 | 0;
	                h = f + 24 | 0;
	                j = f + 20 | 0;
	                k = f + 16 | 0;
	                l = f + 12 | 0;
	                m = f + 8 | 0;
	                n = f + 4 | 0;
	                o = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if ((c[h >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0) {
	                    c[g >> 2] = 0;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                a:do if ((c[(c[h >> 2] | 0) + 44 >> 2] | 0) != 0 ? (c[(c[(c[h >> 2] | 0) + 44 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                    c[n >> 2] = 0;
	                    b:while (1) {
	                        if ((c[n >> 2] | 0) >= (c[(c[(c[h >> 2] | 0) + 44 >> 2] | 0) + 4 >> 2] | 0))break a;
	                        c[m >> 2] = c[(c[c[(c[h >> 2] | 0) + 44 >> 2] >> 2] | 0) + (c[n >> 2] << 2) >> 2];
	                        do if ((c[c[m >> 2] >> 2] | 0) == (c[j >> 2] | 0)) {
	                            e = c[j >> 2] | 0;
	                            if ((e | 0) == 4 | (e | 0) == 5) {
	                                if ((c[(c[m >> 2] | 0) + 8 >> 2] | 0) != (c[k >> 2] | 0))break;
	                                if ((c[(c[m >> 2] | 0) + 112 >> 2] | 0) == (c[l >> 2] | 0)) {
	                                    q = 11;
	                                    break b
	                                } else break
	                            } else if ((e | 0) == 16) {
	                                if ((c[(c[m >> 2] | 0) + 8 >> 2] | 0) != (c[k >> 2] | 0))break;
	                                if ((c[(c[m >> 2] | 0) + 52 >> 2] | 0) == (c[l >> 2] | 0)) {
	                                    q = 17;
	                                    break b
	                                } else break
	                            } else if ((e | 0) == 17) {
	                                if ((c[(c[m >> 2] | 0) + 16 >> 2] | 0) != (c[k >> 2] | 0))break;
	                                if ((c[(c[m >> 2] | 0) + 20 >> 2] | 0) == (c[l >> 2] | 0)) {
	                                    q = 14;
	                                    break b
	                                } else break
	                            } else {
	                                q = 18;
	                                break b
	                            }
	                        } while (0);
	                        c[n >> 2] = (c[n >> 2] | 0) + 1
	                    }
	                    if ((q | 0) == 11) {
	                        c[g >> 2] = c[m >> 2];
	                        p = c[g >> 2] | 0;
	                        i = f;
	                        return p | 0
	                    } else if ((q | 0) == 14) {
	                        c[g >> 2] = c[m >> 2];
	                        p = c[g >> 2] | 0;
	                        i = f;
	                        return p | 0
	                    } else if ((q | 0) == 17) {
	                        c[g >> 2] = c[m >> 2];
	                        p = c[g >> 2] | 0;
	                        i = f;
	                        return p | 0
	                    } else if ((q | 0) == 18) {
	                        c[g >> 2] = 0;
	                        p = c[g >> 2] | 0;
	                        i = f;
	                        return p | 0
	                    }
	                } while (0);
	                do if (c[(c[h >> 2] | 0) + 24 >> 2] | 0) {
	                    c[o >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                    n = (c[h >> 2] | 0) + 4 | 0;
	                    c[n >> 2] = c[n >> 2] | 1;
	                    while (1) {
	                        if (((c[(c[o >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[(c[(c[o >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] & 1 | 0) == 0 : 0) ? (c[m >> 2] = vE(c[(c[o >> 2] | 0) + 12 >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0, (c[m >> 2] | 0) != 0) : 0)break;
	                        c[o >> 2] = c[c[o >> 2] >> 2];
	                        if (!(c[o >> 2] | 0)) {
	                            q = 27;
	                            break
	                        }
	                    }
	                    if ((q | 0) == 27) {
	                        n = (c[h >> 2] | 0) + 4 | 0;
	                        c[n >> 2] = c[n >> 2] ^ 1;
	                        break
	                    }
	                    c[g >> 2] = c[m >> 2];
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                } while (0);
	                c[g >> 2] = 0;
	                p = c[g >> 2] | 0;
	                i = f;
	                return p | 0
	            }

	            function wE(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                if ((c[j >> 2] | 0) != 0 ? (qy(c[j >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    c[k >> 2] = QH(c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                    if ((c[k >> 2] | 0) == 0 & (c[g >> 2] | 0) != 0)n = 7
	                } else n = 6;
	                if ((n | 0) == 6 ? (c[g >> 2] | 0) != 0 : 0)n = 7;
	                do if ((n | 0) == 7) {
	                    if ((qy(c[j >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] | 0) | 0) != 0 ? (c[k >> 2] = Rj(c[(c[g >> 2] | 0) + 28 >> 2] | 0, c[h >> 2] | 0) | 0, (c[k >> 2] | 0) != 0) : 0)break;
	                    if (($j(c[(c[g >> 2] | 0) + 48 >> 2] | 0) | 0) > 1) {
	                        d = c[(c[g >> 2] | 0) + 48 >> 2] | 0;
	                        if (!(c[j >> 2] | 0))c[l >> 2] = Rj(d, 145792) | 0; else c[l >> 2] = Rj(d, c[j >> 2] | 0) | 0;
	                        if (c[l >> 2] | 0)c[k >> 2] = Rj(c[(c[(c[l >> 2] | 0) + 52 >> 2] | 0) + 28 >> 2] | 0, c[h >> 2] | 0) | 0
	                    }
	                } while (0);
	                c[f >> 2] = c[k >> 2];
	                m = c[f >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function xE(a, b, d, e, f, g, h, j, k) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                k = k | 0;
	                var l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0;
	                l = i;
	                i = i + 48 | 0;
	                m = l + 40 | 0;
	                n = l + 36 | 0;
	                o = l + 32 | 0;
	                p = l + 28 | 0;
	                q = l + 24 | 0;
	                r = l + 20 | 0;
	                s = l + 16 | 0;
	                t = l + 12 | 0;
	                u = l + 8 | 0;
	                v = l + 4 | 0;
	                w = l;
	                c[m >> 2] = a;
	                c[n >> 2] = b;
	                c[o >> 2] = d;
	                c[p >> 2] = e;
	                c[q >> 2] = f;
	                c[r >> 2] = g;
	                c[s >> 2] = h;
	                c[t >> 2] = j;
	                c[u >> 2] = k;
	                c[v >> 2] = 0;
	                c[w >> 2] = 0;
	                GC(v, 0, c[o >> 2] | 0, c[p >> 2] | 0) | 0;
	                if (!(c[u >> 2] | 0))c[u >> 2] = xF(c[t >> 2] | 0) | 0;
	                t = c[m >> 2] | 0;
	                m = c[p >> 2] | 0;
	                p = c[n >> 2] | 0;
	                n = c[v >> 2] | 0;
	                o = c[q >> 2] | 0;
	                q = BB(w, c[s >> 2] | 0, c[r >> 2] | 0) | 0;
	                EF(t, m, p, 0, 0, 0, 160072, n, o, q, c[u >> 2] | 0, 0);
	                if (c[v >> 2] | 0) {
	                    zb[c[135736 >> 2] & 511](c[v >> 2] | 0);
	                    c[v >> 2] = 0
	                }
	                if (!(c[w >> 2] | 0)) {
	                    i = l;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[w >> 2] | 0);
	                c[w >> 2] = 0;
	                i = l;
	                return
	            }

	            function yE(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 0;
	                if ((c[h >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                do if (c[g >> 2] | 0) {
	                    if ((qy(c[j >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] | 0) | 0) != 0 ? (c[k >> 2] = Rj(c[(c[g >> 2] | 0) + 40 >> 2] | 0, c[h >> 2] | 0) | 0, (c[k >> 2] | 0) != 0) : 0)break;
	                    if (($j(c[(c[g >> 2] | 0) + 48 >> 2] | 0) | 0) > 1) {
	                        d = c[(c[g >> 2] | 0) + 48 >> 2] | 0;
	                        if (!(c[j >> 2] | 0))c[l >> 2] = Rj(d, 145792) | 0; else c[l >> 2] = Rj(d, c[j >> 2] | 0) | 0;
	                        if (c[l >> 2] | 0)c[k >> 2] = Rj(c[(c[(c[l >> 2] | 0) + 52 >> 2] | 0) + 40 >> 2] | 0, c[h >> 2] | 0) | 0
	                    }
	                } while (0);
	                c[f >> 2] = c[k >> 2];
	                m = c[f >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function zE(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                d = i;
	                i = i + 48 | 0;
	                e = d + 32 | 0;
	                f = d + 28 | 0;
	                g = d + 24 | 0;
	                h = d + 20 | 0;
	                j = d + 16 | 0;
	                k = d + 12 | 0;
	                l = d + 8 | 0;
	                m = d + 4 | 0;
	                n = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = c[(c[g >> 2] | 0) + 92 >> 2];
	                c[j >> 2] = 0;
	                a:while (1) {
	                    if (!(c[h >> 2] | 0))break;
	                    c[m >> 2] = c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 12 >> 2];
	                    c[n >> 2] = c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 16 >> 2];
	                    c[l >> 2] = wE(c[(c[f >> 2] | 0) + 36 >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0) | 0;
	                    do if (c[l >> 2] | 0) {
	                        if ((c[c[l >> 2] >> 2] | 0) != 4) {
	                            if ((c[c[l >> 2] >> 2] | 0) != 1)break;
	                            if ((c[(c[l >> 2] | 0) + 88 >> 2] | 0) == 45)break
	                        }
	                        c[(c[h >> 2] | 0) + 4 >> 2] = c[l >> 2];
	                        c[j >> 2] = c[h >> 2];
	                        c[h >> 2] = c[c[h >> 2] >> 2];
	                        continue a
	                    } while (0);
	                    xE(c[f >> 2] | 0, 3004, c[g >> 2] | 0, c[(c[g >> 2] | 0) + 36 >> 2] | 0, 160512, c[m >> 2] | 0, c[n >> 2] | 0, 4, 0);
	                    b = c[c[h >> 2] >> 2] | 0;
	                    if (!(c[j >> 2] | 0))c[(c[g >> 2] | 0) + 92 >> 2] = b; else c[c[j >> 2] >> 2] = b;
	                    c[k >> 2] = c[h >> 2];
	                    c[h >> 2] = c[c[h >> 2] >> 2];
	                    zb[c[135736 >> 2] & 511](c[k >> 2] | 0)
	                }
	                c[l >> 2] = c[(c[g >> 2] | 0) + 28 >> 2];
	                while (1) {
	                    if (!(c[l >> 2] | 0)) {
	                        o = 20;
	                        break
	                    }
	                    c[h >> 2] = Cb[c[135744 >> 2] & 511](8) | 0;
	                    if (!(c[h >> 2] | 0)) {
	                        o = 15;
	                        break
	                    }
	                    c[(c[h >> 2] | 0) + 4 >> 2] = c[l >> 2];
	                    c[c[h >> 2] >> 2] = 0;
	                    k = c[h >> 2] | 0;
	                    if (!(c[j >> 2] | 0))c[(c[g >> 2] | 0) + 92 >> 2] = k; else c[c[j >> 2] >> 2] = k;
	                    c[j >> 2] = c[h >> 2];
	                    c[l >> 2] = c[(c[l >> 2] | 0) + 4 >> 2]
	                }
	                if ((o | 0) == 15) {
	                    tC(c[f >> 2] | 0, 149752, 0);
	                    c[e >> 2] = -1;
	                    p = c[e >> 2] | 0;
	                    i = d;
	                    return p | 0
	                } else if ((o | 0) == 20) {
	                    c[e >> 2] = 0;
	                    p = c[e >> 2] | 0;
	                    i = d;
	                    return p | 0
	                }
	                return 0
	            }

	            function AE(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f;
	                h = f + 24 | 0;
	                j = f + 20 | 0;
	                k = f + 16 | 0;
	                l = f + 12 | 0;
	                m = f + 8 | 0;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                e = c[k >> 2] | 0;
	                if ((e | 0) == 17) {
	                    c[h >> 2] = nG(c[j >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0) | 0;
	                    n = c[h >> 2] | 0;
	                    i = f;
	                    return n | 0
	                } else if ((e | 0) == 14) {
	                    c[h >> 2] = yE(c[j >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0) | 0;
	                    n = c[h >> 2] | 0;
	                    i = f;
	                    return n | 0
	                } else {
	                    m = c[33976] | 0;
	                    l = c[33980] | 0;
	                    c[g >> 2] = 140328;
	                    c[g + 4 >> 2] = 4984;
	                    Db[m & 511](l, 140296, g);
	                    c[h >> 2] = 0;
	                    n = c[h >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                return 0
	            }

	            function BE(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 0;
	                if ((c[h >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                do if (c[g >> 2] | 0) {
	                    if ((qy(c[j >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] | 0) | 0) != 0 ? (c[k >> 2] = Rj(c[(c[g >> 2] | 0) + 32 >> 2] | 0, c[h >> 2] | 0) | 0, (c[k >> 2] | 0) != 0) : 0)break;
	                    if (($j(c[(c[g >> 2] | 0) + 48 >> 2] | 0) | 0) > 1) {
	                        d = c[(c[g >> 2] | 0) + 48 >> 2] | 0;
	                        if (!(c[j >> 2] | 0))c[l >> 2] = Rj(d, 145792) | 0; else c[l >> 2] = Rj(d, c[j >> 2] | 0) | 0;
	                        if (c[l >> 2] | 0)c[k >> 2] = Rj(c[(c[(c[l >> 2] | 0) + 52 >> 2] | 0) + 32 >> 2] | 0, c[h >> 2] | 0) | 0
	                    }
	                } while (0);
	                c[f >> 2] = c[k >> 2];
	                m = c[f >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function CE(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 0;
	                if ((c[h >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                do if (c[g >> 2] | 0) {
	                    if ((qy(c[j >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] | 0) | 0) != 0 ? (c[k >> 2] = Rj(c[(c[g >> 2] | 0) + 36 >> 2] | 0, c[h >> 2] | 0) | 0, (c[k >> 2] | 0) != 0) : 0)break;
	                    if (($j(c[(c[g >> 2] | 0) + 48 >> 2] | 0) | 0) > 1) {
	                        d = c[(c[g >> 2] | 0) + 48 >> 2] | 0;
	                        if (!(c[j >> 2] | 0))c[l >> 2] = Rj(d, 145792) | 0; else c[l >> 2] = Rj(d, c[j >> 2] | 0) | 0;
	                        if (c[l >> 2] | 0)c[k >> 2] = Rj(c[(c[(c[l >> 2] | 0) + 52 >> 2] | 0) + 36 >> 2] | 0, c[h >> 2] | 0) | 0
	                    }
	                } while (0);
	                c[f >> 2] = c[k >> 2];
	                m = c[f >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function DE(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 0;
	                if ((c[h >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                do if (c[g >> 2] | 0) {
	                    if ((qy(c[j >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] | 0) | 0) != 0 ? (c[k >> 2] = Rj(c[(c[g >> 2] | 0) + 76 >> 2] | 0, c[h >> 2] | 0) | 0, (c[k >> 2] | 0) != 0) : 0)break;
	                    if (($j(c[(c[g >> 2] | 0) + 48 >> 2] | 0) | 0) > 1) {
	                        d = c[(c[g >> 2] | 0) + 48 >> 2] | 0;
	                        if (!(c[j >> 2] | 0))c[l >> 2] = Rj(d, 145792) | 0; else c[l >> 2] = Rj(d, c[j >> 2] | 0) | 0;
	                        if (c[l >> 2] | 0)c[k >> 2] = Rj(c[(c[(c[l >> 2] | 0) + 52 >> 2] | 0) + 76 >> 2] | 0, c[h >> 2] | 0) | 0
	                    }
	                } while (0);
	                c[f >> 2] = c[k >> 2];
	                m = c[f >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function EE(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if ((c[j >> 2] | 0) != 0 ? (c[c[j >> 2] >> 2] | 0) != 1 : 0) {
	                    if ((c[h >> 2] | 0) == (c[j >> 2] | 0)) {
	                        d = c[g >> 2] | 0;
	                        b = c[h >> 2] | 0;
	                        GE(d, 3009, b, FC(c[h >> 2] | 0) | 0, 160032, 0);
	                        c[f >> 2] = 3009;
	                        l = c[f >> 2] | 0;
	                        i = e;
	                        return l | 0
	                    }
	                    if (c[(c[j >> 2] | 0) + 48 >> 2] & 65536) {
	                        c[f >> 2] = 0;
	                        l = c[f >> 2] | 0;
	                        i = e;
	                        return l | 0
	                    } else {
	                        b = (c[j >> 2] | 0) + 48 | 0;
	                        c[b >> 2] = c[b >> 2] | 65536;
	                        c[k >> 2] = EE(c[g >> 2] | 0, c[h >> 2] | 0, c[(c[j >> 2] | 0) + 64 >> 2] | 0) | 0;
	                        h = (c[j >> 2] | 0) + 48 | 0;
	                        c[h >> 2] = c[h >> 2] ^ 65536;
	                        c[f >> 2] = c[k >> 2];
	                        l = c[f >> 2] | 0;
	                        i = e;
	                        return l | 0
	                    }
	                }
	                c[f >> 2] = 0;
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function FE(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                a:while (1) {
	                    if (!(c[g >> 2] | 0)) {
	                        l = 14;
	                        break
	                    }
	                    c[j >> 2] = c[(c[g >> 2] | 0) + 12 >> 2];
	                    do if (c[j >> 2] | 0) {
	                        b = c[c[j >> 2] >> 2] | 0;
	                        if ((b | 0) == 8 | (b | 0) == 7 | (b | 0) == 6) {
	                            c[h >> 2] = FE(c[f >> 2] | 0, c[(c[j >> 2] | 0) + 12 >> 2] | 0) | 0;
	                            if (c[h >> 2] | 0) {
	                                l = 12;
	                                break a
	                            } else break
	                        } else if ((b | 0) != 17)break;
	                        c[k >> 2] = c[j >> 2];
	                        if ((c[k >> 2] | 0) == (c[f >> 2] | 0)) {
	                            l = 6;
	                            break a
	                        }
	                        if (((c[(c[k >> 2] | 0) + 28 >> 2] & 1 | 0) == 0 ? (c[(c[k >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (b = (c[k >> 2] | 0) + 28 | 0, c[b >> 2] = c[b >> 2] | 1, c[h >> 2] = FE(c[f >> 2] | 0, c[(c[(c[k >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2] | 0) | 0, b = (c[k >> 2] | 0) + 28 | 0, c[b >> 2] = c[b >> 2] ^ 1, (c[h >> 2] | 0) != 0) : 0) {
	                            l = 10;
	                            break a
	                        }
	                    } while (0);
	                    c[g >> 2] = c[(c[g >> 2] | 0) + 8 >> 2]
	                }
	                if ((l | 0) == 6) {
	                    c[e >> 2] = c[g >> 2];
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                } else if ((l | 0) == 10) {
	                    c[e >> 2] = c[h >> 2];
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                } else if ((l | 0) == 12) {
	                    c[e >> 2] = c[h >> 2];
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                } else if ((l | 0) == 14) {
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                return 0
	            }

	            function GE(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                h = i;
	                i = i + 32 | 0;
	                j = h + 20 | 0;
	                k = h + 16 | 0;
	                l = h + 12 | 0;
	                m = h + 8 | 0;
	                n = h + 4 | 0;
	                o = h;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                oG(c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, 0, 0);
	                i = h;
	                return
	            }

	            function HE(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 24 | 0;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                l = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[l >> 2] = 0;
	                while (1) {
	                    if ((c[l >> 2] | 0) >= (c[(c[g >> 2] | 0) + 4 >> 2] | 0)) {
	                        m = 14;
	                        break
	                    }
	                    c[j >> 2] = c[(c[c[g >> 2] >> 2] | 0) + (c[l >> 2] << 2) >> 2];
	                    if (((c[c[j >> 2] >> 2] | 0) == 2e3 ? (c[(c[j >> 2] | 0) + 8 >> 2] | 0) == 16 : 0) ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                        c[h >> 2] = c[(c[j >> 2] | 0) + 4 >> 2];
	                        if ((c[h >> 2] | 0) == (c[f >> 2] | 0)) {
	                            m = 7;
	                            break
	                        }
	                        if ((((c[(c[h >> 2] | 0) + 36 >> 2] & 4 | 0) == 0 ? (c[(c[h >> 2] | 0) + 56 >> 2] | 0) != 0 : 0) ? (c[(c[h >> 2] | 0) + 36 >> 2] & 16 | 0) != 0 : 0) ? (b = (c[h >> 2] | 0) + 36 | 0, c[b >> 2] = c[b >> 2] | 4, c[k >> 2] = HE(c[f >> 2] | 0, c[(c[h >> 2] | 0) + 56 >> 2] | 0) | 0, b = (c[h >> 2] | 0) + 36 | 0, c[b >> 2] = c[b >> 2] ^ 4, (c[k >> 2] | 0) != 0) : 0) {
	                            m = 12;
	                            break
	                        }
	                    }
	                    c[l >> 2] = (c[l >> 2] | 0) + 1
	                }
	                if ((m | 0) == 7) {
	                    c[e >> 2] = c[j >> 2];
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                } else if ((m | 0) == 12) {
	                    c[e >> 2] = c[k >> 2];
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                } else if ((m | 0) == 14) {
	                    c[e >> 2] = 0;
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                return 0
	            }

	            function IE(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0;
	                g = i;
	                i = i + 64 | 0;
	                h = g + 56 | 0;
	                j = g + 52 | 0;
	                k = g + 48 | 0;
	                l = g + 44 | 0;
	                m = g + 40 | 0;
	                n = g + 36 | 0;
	                o = g + 32 | 0;
	                p = g + 28 | 0;
	                q = g + 24 | 0;
	                r = g + 20 | 0;
	                s = g + 16 | 0;
	                t = g + 12 | 0;
	                u = g + 8 | 0;
	                v = g + 4 | 0;
	                w = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[t >> 2] = (c[c[l >> 2] >> 2] | 0) == 0 ? 0 : 1;
	                if (c[n >> 2] | 0)c[(c[n >> 2] | 0) + 4 >> 2] = 0;
	                c[r >> 2] = 0;
	                a:while (1) {
	                    if ((c[r >> 2] | 0) >= (c[(c[m >> 2] | 0) + 4 >> 2] | 0)) {
	                        x = 41;
	                        break
	                    }
	                    c[p >> 2] = c[(c[c[m >> 2] >> 2] | 0) + (c[r >> 2] << 2) >> 2];
	                    b:do if ((c[c[p >> 2] >> 2] | 0) != 2001) {
	                        if ((c[c[p >> 2] >> 2] | 0) == 2e3 ? (c[(c[p >> 2] | 0) + 8 >> 2] | 0) == 16 : 0) {
	                            if (!(c[(c[p >> 2] | 0) + 4 >> 2] | 0)) {
	                                x = 14;
	                                break a
	                            }
	                            c[o >> 2] = c[(c[p >> 2] | 0) + 4 >> 2];
	                            if ((c[(c[o >> 2] | 0) + 36 >> 2] & 1 | 0) == 0 ? (iD(c[j >> 2] | 0, c[o >> 2] | 0) | 0) == -1 : 0) {
	                                x = 17;
	                                break a
	                            }
	                            do if (c[(c[o >> 2] | 0) + 40 >> 2] | 0) {
	                                if (!(c[c[l >> 2] >> 2] | 0)) {
	                                    c[c[l >> 2] >> 2] = c[(c[o >> 2] | 0) + 40 >> 2];
	                                    break
	                                }
	                                if (!(c[t >> 2] | 0)) {
	                                    f = c[j >> 2] | 0;
	                                    e = c[(c[j >> 2] | 0) + 36 >> 2] | 0;
	                                    c[u >> 2] = qG(f, e, 21, FC(c[k >> 2] | 0) | 0) | 0;
	                                    if (!(c[u >> 2] | 0)) {
	                                        x = 23;
	                                        break a
	                                    }
	                                    if ((rG(c[j >> 2] | 0, c[u >> 2] | 0, c[c[l >> 2] >> 2] | 0) | 0) == -1) {
	                                        x = 25;
	                                        break a
	                                    }
	                                    c[(c[u >> 2] | 0) + 24 >> 2] = c[(c[c[l >> 2] >> 2] | 0) + 24 >> 2];
	                                    c[c[l >> 2] >> 2] = c[u >> 2];
	                                    c[t >> 2] = 1
	                                }
	                                if ((sG(c[j >> 2] | 0, c[c[l >> 2] >> 2] | 0, c[(c[o >> 2] | 0) + 40 >> 2] | 0) | 0) == -1) {
	                                    x = 28;
	                                    break a
	                                }
	                            } while (0);
	                            c[q >> 2] = c[(c[o >> 2] | 0) + 56 >> 2];
	                            if ((c[q >> 2] | 0) != 0 ? (c[(c[q >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                                c[(c[c[m >> 2] >> 2] | 0) + (c[r >> 2] << 2) >> 2] = c[c[c[q >> 2] >> 2] >> 2];
	                                if ((c[(c[q >> 2] | 0) + 4 >> 2] | 0) == 1)break;
	                                c[s >> 2] = 1;
	                                while (1) {
	                                    if ((c[s >> 2] | 0) >= (c[(c[q >> 2] | 0) + 4 >> 2] | 0))break b;
	                                    c[r >> 2] = (c[r >> 2] | 0) + 1;
	                                    if ((tG(c[m >> 2] | 0, c[(c[c[q >> 2] >> 2] | 0) + (c[s >> 2] << 2) >> 2] | 0, c[r >> 2] | 0) | 0) == -1) {
	                                        x = 38;
	                                        break a
	                                    }
	                                    c[s >> 2] = (c[s >> 2] | 0) + 1
	                                }
	                            }
	                            if ((TE(c[m >> 2] | 0, c[r >> 2] | 0) | 0) == -1) {
	                                x = 32;
	                                break a
	                            }
	                            c[r >> 2] = (c[r >> 2] | 0) + -1
	                        }
	                    } else {
	                        if (!(c[n >> 2] | 0)) {
	                            x = 7;
	                            break a
	                        }
	                        if ((TE(c[m >> 2] | 0, c[r >> 2] | 0) | 0) == -1) {
	                            x = 9;
	                            break a
	                        }
	                        c[r >> 2] = (c[r >> 2] | 0) + -1;
	                        pG(c[n >> 2] | 0, 2, c[p >> 2] | 0) | 0
	                    } while (0);
	                    c[r >> 2] = (c[r >> 2] | 0) + 1
	                }
	                switch (x | 0) {
	                    case 7:
	                    {
	                        xB(c[j >> 2] | 0, 152800, 152840);
	                        c[h >> 2] = -1;
	                        y = c[h >> 2] | 0;
	                        i = g;
	                        return y | 0
	                    }
	                    case 9:
	                    {
	                        c[h >> 2] = -1;
	                        y = c[h >> 2] | 0;
	                        i = g;
	                        return y | 0
	                    }
	                    case 14:
	                    {
	                        c[h >> 2] = -1;
	                        y = c[h >> 2] | 0;
	                        i = g;
	                        return y | 0
	                    }
	                    case 17:
	                    {
	                        c[h >> 2] = -1;
	                        y = c[h >> 2] | 0;
	                        i = g;
	                        return y | 0
	                    }
	                    case 23:
	                    {
	                        c[h >> 2] = -1;
	                        y = c[h >> 2] | 0;
	                        i = g;
	                        return y | 0
	                    }
	                    case 25:
	                    {
	                        c[h >> 2] = -1;
	                        y = c[h >> 2] | 0;
	                        i = g;
	                        return y | 0
	                    }
	                    case 28:
	                    {
	                        c[h >> 2] = -1;
	                        y = c[h >> 2] | 0;
	                        i = g;
	                        return y | 0
	                    }
	                    case 32:
	                    {
	                        c[h >> 2] = -1;
	                        y = c[h >> 2] | 0;
	                        i = g;
	                        return y | 0
	                    }
	                    case 38:
	                    {
	                        c[h >> 2] = -1;
	                        y = c[h >> 2] | 0;
	                        i = g;
	                        return y | 0
	                    }
	                    case 41:
	                    {
	                        c:do if (((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) ? (c[(c[m >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                            c[r >> 2] = (c[(c[n >> 2] | 0) + 4 >> 2] | 0) - 1;
	                            while (1) {
	                                if ((c[r >> 2] | 0) < 0)break c;
	                                c[v >> 2] = c[(c[c[n >> 2] >> 2] | 0) + (c[r >> 2] << 2) >> 2];
	                                c[s >> 2] = 0;
	                                while (1) {
	                                    if ((c[s >> 2] | 0) >= (c[(c[m >> 2] | 0) + 4 >> 2] | 0))break;
	                                    c[p >> 2] = c[(c[c[m >> 2] >> 2] | 0) + (c[s >> 2] << 2) >> 2];
	                                    if ((c[(c[v >> 2] | 0) + 8 >> 2] | 0) == (c[(c[(c[p >> 2] | 0) + 12 >> 2] | 0) + 8 >> 2] | 0) ? (c[(c[v >> 2] | 0) + 12 >> 2] | 0) == (c[(c[(c[p >> 2] | 0) + 12 >> 2] | 0) + 56 >> 2] | 0) : 0) {
	                                        x = 50;
	                                        break
	                                    }
	                                    c[s >> 2] = (c[s >> 2] | 0) + 1
	                                }
	                                if ((x | 0) == 50) {
	                                    x = 0;
	                                    c[w >> 2] = 0;
	                                    q = c[j >> 2] | 0;
	                                    o = c[(c[v >> 2] | 0) + 4 >> 2] | 0;
	                                    NC(q, 3086, o, 0, 152880, BB(w, c[(c[v >> 2] | 0) + 12 >> 2] | 0, c[(c[v >> 2] | 0) + 8 >> 2] | 0) | 0, 0, 0);
	                                    if (c[w >> 2] | 0) {
	                                        zb[c[135736 >> 2] & 511](c[w >> 2] | 0);
	                                        c[w >> 2] = 0
	                                    }
	                                    if ((TE(c[n >> 2] | 0, c[r >> 2] | 0) | 0) == -1)break
	                                }
	                                c[r >> 2] = (c[r >> 2] | 0) + -1
	                            }
	                            c[h >> 2] = -1;
	                            y = c[h >> 2] | 0;
	                            i = g;
	                            return y | 0
	                        } while (0);
	                        c[h >> 2] = 0;
	                        y = c[h >> 2] | 0;
	                        i = g;
	                        return y | 0
	                    }
	                }
	                return 0
	            }

	            function JE(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 20 | 0;
	                h = e + 16 | 0;
	                j = e + 12 | 0;
	                k = e + 8 | 0;
	                l = e + 4 | 0;
	                m = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = c[j >> 2];
	                a:while (1) {
	                    if (!(c[k >> 2] | 0)) {
	                        n = 14;
	                        break
	                    }
	                    c[l >> 2] = c[(c[k >> 2] | 0) + 4 >> 2];
	                    while (1) {
	                        if (!(c[l >> 2] | 0))break;
	                        if ((c[c[l >> 2] >> 2] | 0) == 1)break;
	                        if ((c[l >> 2] | 0) == (c[h >> 2] | 0)) {
	                            n = 7;
	                            break a
	                        }
	                        if (((c[(c[l >> 2] | 0) + 48 >> 2] & 128 | 0) != 0 ? (c[(c[l >> 2] | 0) + 48 >> 2] & 65536 | 0) == 0 : 0) ? (j = (c[l >> 2] | 0) + 48 | 0, c[j >> 2] = c[j >> 2] | 65536, j = c[g >> 2] | 0, d = c[h >> 2] | 0, c[m >> 2] = JE(j, d, EC(c[l >> 2] | 0) | 0) | 0, d = (c[l >> 2] | 0) + 48 | 0, c[d >> 2] = c[d >> 2] ^ 65536, (c[m >> 2] | 0) != 0) : 0) {
	                            n = 11;
	                            break a
	                        }
	                        c[l >> 2] = c[(c[l >> 2] | 0) + 64 >> 2]
	                    }
	                    c[k >> 2] = c[c[k >> 2] >> 2]
	                }
	                if ((n | 0) == 7) {
	                    GE(c[g >> 2] | 0, 3003, c[h >> 2] | 0, 0, 159872, 0);
	                    c[f >> 2] = 3003;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                } else if ((n | 0) == 11) {
	                    c[f >> 2] = c[m >> 2];
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                } else if ((n | 0) == 14) {
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                return 0
	            }

	            function KE(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                do if (!(c[f >> 2] | 0))c[e >> 2] = 0; else {
	                    if ((c[c[g >> 2] >> 2] | 0) != 1) {
	                        xB(c[g >> 2] | 0, 147104, 147128);
	                        c[e >> 2] = -1;
	                        break
	                    }
	                    if ((c[c[f >> 2] >> 2] | 0) != 1 ? (c[(c[f >> 2] | 0) + 48 >> 2] & 4194304 | 0) == 0 : 0) {
	                        if ((c[c[f >> 2] >> 2] | 0) == 5) {
	                            c[e >> 2] = qD(c[g >> 2] | 0, c[f >> 2] | 0) | 0;
	                            break
	                        }
	                        if ((c[c[f >> 2] >> 2] | 0) == 4) {
	                            c[e >> 2] = lD(c[g >> 2] | 0, c[f >> 2] | 0) | 0;
	                            break
	                        } else {
	                            c[e >> 2] = 0;
	                            break
	                        }
	                    }
	                    c[e >> 2] = 0
	                } while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function LE(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 28 | 0;
	                f = d + 24 | 0;
	                g = d + 20 | 0;
	                h = d + 16 | 0;
	                j = d + 12 | 0;
	                k = d + 8 | 0;
	                l = d + 4 | 0;
	                m = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = c[(c[g >> 2] | 0) + 92 >> 2];
	                a:while (1) {
	                    if (!(c[h >> 2] | 0)) {
	                        n = 15;
	                        break
	                    }
	                    if ((c[c[(c[h >> 2] | 0) + 4 >> 2] >> 2] | 0) != 1 ? (c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 48 >> 2] & 4194304 | 0) == 0 : 0)KE(c[(c[h >> 2] | 0) + 4 >> 2] | 0, c[f >> 2] | 0) | 0;
	                    b:do if (((c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 48 >> 2] & 128 | 0) != 0 ? (c[l >> 2] = EC(c[(c[h >> 2] | 0) + 4 >> 2] | 0) | 0, (c[l >> 2] | 0) != 0) : 0) ? (c[(c[h >> 2] | 0) + 4 >> 2] = c[(c[l >> 2] | 0) + 4 >> 2], (c[c[l >> 2] >> 2] | 0) != 0) : 0) {
	                        c[j >> 2] = c[c[h >> 2] >> 2];
	                        c[l >> 2] = c[c[l >> 2] >> 2];
	                        c[k >> 2] = c[h >> 2];
	                        while (1) {
	                            if (!(c[l >> 2] | 0))break b;
	                            c[m >> 2] = Cb[c[135744 >> 2] & 511](8) | 0;
	                            if (!(c[m >> 2] | 0)) {
	                                n = 12;
	                                break a
	                            }
	                            c[(c[m >> 2] | 0) + 4 >> 2] = c[(c[l >> 2] | 0) + 4 >> 2];
	                            c[c[k >> 2] >> 2] = c[m >> 2];
	                            c[k >> 2] = c[m >> 2];
	                            c[c[m >> 2] >> 2] = c[j >> 2];
	                            c[l >> 2] = c[c[l >> 2] >> 2]
	                        }
	                    } while (0);
	                    c[h >> 2] = c[c[h >> 2] >> 2]
	                }
	                if ((n | 0) == 12) {
	                    tC(c[f >> 2] | 0, 149752, 0);
	                    c[e >> 2] = -1;
	                    o = c[e >> 2] | 0;
	                    i = d;
	                    return o | 0
	                } else if ((n | 0) == 15) {
	                    c[e >> 2] = 0;
	                    o = c[e >> 2] | 0;
	                    i = d;
	                    return o | 0
	                }
	                return 0
	            }

	            function ME(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = c[(c[g >> 2] | 0) + 64 >> 2];
	                c[j >> 2] = 0;
	                if (!(c[h >> 2] | 0)) {
	                    GE(c[f >> 2] | 0, 3008, c[g >> 2] | 0, 0, 149560, 0);
	                    c[e >> 2] = 3008;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                do if ((c[c[h >> 2] >> 2] | 0) != 4) {
	                    if ((c[c[h >> 2] >> 2] | 0) == 1 ? (c[(c[h >> 2] | 0) + 88 >> 2] | 0) != 45 : 0)break;
	                    b = c[f >> 2] | 0;
	                    a = c[g >> 2] | 0;
	                    GE(b, 3008, a, 0, 149584, YD(j, c[h >> 2] | 0) | 0);
	                    if (c[j >> 2] | 0) {
	                        zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                        c[j >> 2] = 0
	                    }
	                    c[e >> 2] = 3008;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                } while (0);
	                if (!((c[(c[g >> 2] | 0) + 48 >> 2] & 64 | 0) == 0 ? (c[(c[g >> 2] | 0) + 48 >> 2] & 128 | 0) == 0 : 0))l = 11;
	                do if ((l | 0) == 11 ? (c[(c[g >> 2] | 0) + 48 >> 2] & 4 | 0) == 0 : 0) {
	                    if ((c[c[h >> 2] >> 2] | 0) == 1 ? (c[(c[h >> 2] | 0) + 88 >> 2] | 0) == 46 : 0)break;
	                    if ((c[c[h >> 2] >> 2] | 0) != 4) {
	                        a = c[f >> 2] | 0;
	                        b = c[g >> 2] | 0;
	                        GE(a, 3008, b, 0, 149624, YD(j, c[h >> 2] | 0) | 0);
	                        if (c[j >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                            c[j >> 2] = 0
	                        }
	                        c[e >> 2] = 3008;
	                        k = c[e >> 2] | 0;
	                        i = d;
	                        return k | 0
	                    }
	                } while (0);
	                if (((c[(c[g >> 2] | 0) + 48 >> 2] & 256 | 0) == 0 ? (c[(c[g >> 2] | 0) + 48 >> 2] & 128 | 0) == 0 : 0) ? (c[(c[g >> 2] | 0) + 48 >> 2] & 64 | 0) == 0 : 0) {
	                    GE(c[f >> 2] | 0, 3008, c[g >> 2] | 0, 0, 149728, 0);
	                    c[e >> 2] = 3008;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                if (!(uG(c[h >> 2] | 0, 1024) | 0)) {
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                l = c[f >> 2] | 0;
	                f = c[g >> 2] | 0;
	                GE(l, 3010, f, 0, 149224, YD(j, c[h >> 2] | 0) | 0);
	                if (c[j >> 2] | 0) {
	                    zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                    c[j >> 2] = 0
	                }
	                c[e >> 2] = 3010;
	                k = c[e >> 2] | 0;
	                i = d;
	                return k | 0
	            }

	            function NE(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0;
	                d = i;
	                i = i + 96 | 0;
	                e = d + 80 | 0;
	                f = d + 76 | 0;
	                g = d + 72 | 0;
	                h = d + 68 | 0;
	                j = d + 64 | 0;
	                k = d + 60 | 0;
	                l = d + 56 | 0;
	                m = d + 52 | 0;
	                n = d + 48 | 0;
	                o = d + 44 | 0;
	                p = d + 40 | 0;
	                q = d + 36 | 0;
	                r = d + 32 | 0;
	                s = d + 28 | 0;
	                t = d + 24 | 0;
	                u = d + 20 | 0;
	                v = d + 16 | 0;
	                w = d + 12 | 0;
	                x = d + 8 | 0;
	                y = d + 4 | 0;
	                z = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                if ((c[c[g >> 2] >> 2] | 0) != 4) {
	                    xB(c[f >> 2] | 0, 148320, 148352);
	                    c[e >> 2] = -1;
	                    A = c[e >> 2] | 0;
	                    i = d;
	                    return A | 0
	                }
	                b = c[g >> 2] | 0;
	                a:do if (c[(c[g >> 2] | 0) + 48 >> 2] & 256) {
	                    if (!(c[(c[b + 64 >> 2] | 0) + 48 >> 2] & 256)) {
	                        a = c[f >> 2] | 0;
	                        B = c[g >> 2] | 0;
	                        GE(a, 3011, B, 0, 148400, YD(h, c[(c[g >> 2] | 0) + 64 >> 2] | 0) | 0);
	                        if (c[h >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                            c[h >> 2] = 0
	                        }
	                        c[e >> 2] = 3011;
	                        A = c[e >> 2] | 0;
	                        i = d;
	                        return A | 0
	                    }
	                    if (uG(c[(c[g >> 2] | 0) + 64 >> 2] | 0, 1024) | 0) {
	                        B = c[f >> 2] | 0;
	                        a = c[g >> 2] | 0;
	                        GE(B, 3012, a, 0, 148448, YD(h, c[(c[g >> 2] | 0) + 64 >> 2] | 0) | 0);
	                        if (c[h >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                            c[h >> 2] = 0
	                        }
	                        c[e >> 2] = 3012;
	                        A = c[e >> 2] | 0;
	                        i = d;
	                        return A | 0
	                    }
	                    if (c[(c[g >> 2] | 0) + 68 >> 2] | 0) {
	                        c[l >> 2] = 1;
	                        c[j >> 2] = TD(c[g >> 2] | 0) | 0;
	                        if (!(c[j >> 2] | 0)) {
	                            xB(c[f >> 2] | 0, 148320, 148512);
	                            c[e >> 2] = -1;
	                            A = c[e >> 2] | 0;
	                            i = d;
	                            return A | 0
	                        }
	                        c[k >> 2] = c[(c[g >> 2] | 0) + 68 >> 2];
	                        do {
	                            if (!(HH(c[j >> 2] | 0, c[c[k >> 2] >> 2] | 0) | 0)) {
	                                c[l >> 2] = 0;
	                                vG(c[f >> 2] | 0, 3013, c[g >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0)
	                            }
	                            c[k >> 2] = c[(c[k >> 2] | 0) + 4 >> 2]
	                        } while ((c[k >> 2] | 0) != 0);
	                        if (!(c[l >> 2] | 0)) {
	                            c[e >> 2] = 3013;
	                            A = c[e >> 2] | 0;
	                            i = d;
	                            return A | 0
	                        }
	                    }
	                } else {
	                    if (!(c[b + 48 >> 2] & 64)) {
	                        if (!(c[(c[g >> 2] | 0) + 48 >> 2] & 128))break;
	                        c[u >> 2] = c[(c[g >> 2] | 0) + 92 >> 2];
	                        while (1) {
	                            if (!(c[u >> 2] | 0))break;
	                            if ((c[c[(c[u >> 2] | 0) + 4 >> 2] >> 2] | 0) != 1 ? (c[(c[(c[u >> 2] | 0) + 4 >> 2] | 0) + 48 >> 2] & 4194304 | 0) == 0 : 0)KE(c[(c[u >> 2] | 0) + 4 >> 2] | 0, c[f >> 2] | 0) | 0;
	                            if ((c[(c[(c[u >> 2] | 0) + 4 >> 2] | 0) + 48 >> 2] & 256 | 0) == 0 ? (c[(c[(c[u >> 2] | 0) + 4 >> 2] | 0) + 48 >> 2] & 64 | 0) == 0 : 0) {
	                                C = 91;
	                                break
	                            }
	                            c[u >> 2] = c[c[u >> 2] >> 2]
	                        }
	                        if ((C | 0) == 91) {
	                            a = c[f >> 2] | 0;
	                            B = c[g >> 2] | 0;
	                            GE(a, 3023, B, 0, 149040, YD(h, c[(c[u >> 2] | 0) + 4 >> 2] | 0) | 0);
	                            if (c[h >> 2] | 0) {
	                                zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                                c[h >> 2] = 0
	                            }
	                            c[e >> 2] = 3023;
	                            A = c[e >> 2] | 0;
	                            i = d;
	                            return A | 0
	                        }
	                        B = c[g >> 2] | 0;
	                        if ((c[(c[(c[g >> 2] | 0) + 64 >> 2] | 0) + 88 >> 2] | 0) == 46) {
	                            c[u >> 2] = c[B + 92 >> 2];
	                            while (1) {
	                                if (!(c[u >> 2] | 0)) {
	                                    C = 103;
	                                    break
	                                }
	                                if (uG(c[(c[u >> 2] | 0) + 4 >> 2] | 0, 4096) | 0)break;
	                                c[u >> 2] = c[c[u >> 2] >> 2]
	                            }
	                            if ((C | 0) == 103) {
	                                if (!(c[(c[g >> 2] | 0) + 96 >> 2] | 0))break;
	                                GE(c[f >> 2] | 0, 3025, c[g >> 2] | 0, 0, 149160, 0);
	                                c[e >> 2] = 3025;
	                                A = c[e >> 2] | 0;
	                                i = d;
	                                return A | 0
	                            }
	                            a = c[f >> 2] | 0;
	                            D = c[g >> 2] | 0;
	                            GE(a, 3024, D, 0, 149104, YD(h, c[(c[u >> 2] | 0) + 4 >> 2] | 0) | 0);
	                            if (c[h >> 2] | 0) {
	                                zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                                c[h >> 2] = 0
	                            }
	                            c[e >> 2] = 3024;
	                            A = c[e >> 2] | 0;
	                            i = d;
	                            return A | 0
	                        }
	                        if (!(c[(c[B + 64 >> 2] | 0) + 48 >> 2] & 128)) {
	                            D = c[f >> 2] | 0;
	                            a = c[g >> 2] | 0;
	                            GE(D, 3027, a, 0, 149184, YD(h, c[(c[g >> 2] | 0) + 64 >> 2] | 0) | 0);
	                            if (c[h >> 2] | 0) {
	                                zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                                c[h >> 2] = 0
	                            }
	                            c[e >> 2] = 3027;
	                            A = c[e >> 2] | 0;
	                            i = d;
	                            return A | 0
	                        }
	                        if (uG(c[(c[g >> 2] | 0) + 64 >> 2] | 0, 1024) | 0) {
	                            a = c[f >> 2] | 0;
	                            D = c[g >> 2] | 0;
	                            GE(a, 3026, D, 0, 149224, YD(h, c[(c[g >> 2] | 0) + 64 >> 2] | 0) | 0);
	                            if (c[h >> 2] | 0) {
	                                zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                                c[h >> 2] = 0
	                            }
	                            c[e >> 2] = 3026;
	                            A = c[e >> 2] | 0;
	                            i = d;
	                            return A | 0
	                        }
	                        b:do if (c[(c[g >> 2] | 0) + 92 >> 2] | 0) {
	                            c[u >> 2] = c[(c[g >> 2] | 0) + 92 >> 2];
	                            c[v >> 2] = EC(c[(c[g >> 2] | 0) + 64 >> 2] | 0) | 0;
	                            if ((c[u >> 2] | 0) == 0 & (c[v >> 2] | 0) != 0)xB(c[f >> 2] | 0, 148320, 149296);
	                            while (1) {
	                                if (!(c[u >> 2] | 0))break b;
	                                if (c[v >> 2] | 0) {
	                                    if ((c[(c[u >> 2] | 0) + 4 >> 2] | 0) != (c[(c[v >> 2] | 0) + 4 >> 2] | 0) ? (xG(c[f >> 2] | 0, c[(c[u >> 2] | 0) + 4 >> 2] | 0, c[(c[v >> 2] | 0) + 4 >> 2] | 0, 0) | 0) != 0 : 0)break
	                                } else xB(c[f >> 2] | 0, 148320, 149296);
	                                c[u >> 2] = c[c[u >> 2] >> 2];
	                                if (!(c[v >> 2] | 0))continue;
	                                c[v >> 2] = c[c[v >> 2] >> 2]
	                            }
	                            c[w >> 2] = 0;
	                            c[x >> 2] = 0;
	                            D = c[f >> 2] | 0;
	                            a = c[g >> 2] | 0;
	                            E = YD(h, c[(c[u >> 2] | 0) + 4 >> 2] | 0) | 0;
	                            F = YD(w, c[(c[v >> 2] | 0) + 4 >> 2] | 0) | 0;
	                            oG(D, 3028, a, 0, 149344, E, F, YD(x, c[(c[g >> 2] | 0) + 64 >> 2] | 0) | 0);
	                            if (c[h >> 2] | 0) {
	                                zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                                c[h >> 2] = 0
	                            }
	                            if (c[w >> 2] | 0) {
	                                zb[c[135736 >> 2] & 511](c[w >> 2] | 0);
	                                c[w >> 2] = 0
	                            }
	                            if (c[x >> 2] | 0) {
	                                zb[c[135736 >> 2] & 511](c[x >> 2] | 0);
	                                c[x >> 2] = 0
	                            }
	                            c[e >> 2] = 3028;
	                            A = c[e >> 2] | 0;
	                            i = d;
	                            return A | 0
	                        } while (0);
	                        if (!(c[(c[g >> 2] | 0) + 68 >> 2] | 0))break;
	                        c[z >> 2] = 1;
	                        c[y >> 2] = c[(c[g >> 2] | 0) + 68 >> 2];
	                        do {
	                            if ((c[c[y >> 2] >> 2] | 0) != 1006 ? (c[c[y >> 2] >> 2] | 0) != 1007 : 0) {
	                                wG(c[f >> 2] | 0, 3029, c[g >> 2] | 0, c[y >> 2] | 0);
	                                c[z >> 2] = 0
	                            }
	                            c[y >> 2] = c[(c[y >> 2] | 0) + 4 >> 2]
	                        } while ((c[y >> 2] | 0) != 0);
	                        if (c[z >> 2] | 0)break;
	                        c[e >> 2] = 3029;
	                        A = c[e >> 2] | 0;
	                        i = d;
	                        return A | 0
	                    }
	                    c[m >> 2] = 0;
	                    c[m >> 2] = c[(c[g >> 2] | 0) + 28 >> 2];
	                    do if (c[m >> 2] | 0) {
	                        if ((c[c[m >> 2] >> 2] | 0) != 4) {
	                            if ((c[c[m >> 2] >> 2] | 0) != 1)break;
	                            if ((c[(c[m >> 2] | 0) + 88 >> 2] | 0) == 45)break
	                        }
	                        if ((c[c[m >> 2] >> 2] | 0) != 1 ? (c[(c[m >> 2] | 0) + 48 >> 2] & 4194304 | 0) == 0 : 0)KE(c[m >> 2] | 0, c[f >> 2] | 0) | 0;
	                        if ((c[(c[m >> 2] | 0) + 48 >> 2] & 256 | 0) == 0 ? (c[(c[m >> 2] | 0) + 48 >> 2] & 128 | 0) == 0 : 0) {
	                            B = c[f >> 2] | 0;
	                            F = c[g >> 2] | 0;
	                            GE(B, 3015, F, 0, 148584, YD(h, c[m >> 2] | 0) | 0);
	                            if (c[h >> 2] | 0) {
	                                zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                                c[h >> 2] = 0
	                            }
	                            c[e >> 2] = 3015;
	                            A = c[e >> 2] | 0;
	                            i = d;
	                            return A | 0
	                        }
	                        c:do if (c[(c[m >> 2] | 0) + 48 >> 2] & 128) {
	                            c[n >> 2] = c[(c[m >> 2] | 0) + 92 >> 2];
	                            while (1) {
	                                if (!(c[n >> 2] | 0))break c;
	                                if (!(c[(c[(c[n >> 2] | 0) + 4 >> 2] | 0) + 48 >> 2] & 256))break;
	                                c[n >> 2] = c[c[n >> 2] >> 2]
	                            }
	                            F = c[f >> 2] | 0;
	                            B = c[g >> 2] | 0;
	                            GE(F, 3015, B, 0, 148648, YD(h, c[(c[n >> 2] | 0) + 4 >> 2] | 0) | 0);
	                            if (c[h >> 2] | 0) {
	                                zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                                c[h >> 2] = 0
	                            }
	                            c[e >> 2] = 3015;
	                            A = c[e >> 2] | 0;
	                            i = d;
	                            return A | 0
	                        } while (0);
	                        if ((c[c[(c[g >> 2] | 0) + 64 >> 2] >> 2] | 0) == 1 ? (c[(c[(c[g >> 2] | 0) + 64 >> 2] | 0) + 88 >> 2] | 0) == 46 : 0) {
	                            if (uG(c[m >> 2] | 0, 2048) | 0) {
	                                B = c[f >> 2] | 0;
	                                F = c[g >> 2] | 0;
	                                GE(B, 3016, F, 0, 148736, YD(h, c[m >> 2] | 0) | 0);
	                                if (c[h >> 2] | 0) {
	                                    zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                                    c[h >> 2] = 0
	                                }
	                                c[e >> 2] = 3016;
	                                A = c[e >> 2] | 0;
	                                i = d;
	                                return A | 0
	                            }
	                            if (!(c[(c[g >> 2] | 0) + 68 >> 2] | 0))break a;
	                            c[o >> 2] = c[(c[g >> 2] | 0) + 68 >> 2];
	                            while (1) {
	                                if ((c[c[o >> 2] >> 2] | 0) != 1008)break;
	                                c[o >> 2] = c[(c[o >> 2] | 0) + 4 >> 2];
	                                if (!(c[o >> 2] | 0))break a
	                            }
	                            wG(c[f >> 2] | 0, 3017, c[g >> 2] | 0, c[o >> 2] | 0);
	                            c[e >> 2] = 3017;
	                            A = c[e >> 2] | 0;
	                            i = d;
	                            return A | 0
	                        }
	                        if (!(c[(c[(c[g >> 2] | 0) + 64 >> 2] | 0) + 48 >> 2] & 64)) {
	                            F = c[f >> 2] | 0;
	                            B = c[g >> 2] | 0;
	                            GE(F, 3018, B, 0, 148792, YD(h, c[(c[g >> 2] | 0) + 64 >> 2] | 0) | 0);
	                            if (c[h >> 2] | 0) {
	                                zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                                c[h >> 2] = 0
	                            }
	                            c[e >> 2] = 3018;
	                            A = c[e >> 2] | 0;
	                            i = d;
	                            return A | 0
	                        }
	                        if (uG(c[(c[g >> 2] | 0) + 64 >> 2] | 0, 1024) | 0) {
	                            B = c[f >> 2] | 0;
	                            F = c[g >> 2] | 0;
	                            GE(B, 3019, F, 0, 148832, YD(h, c[(c[g >> 2] | 0) + 64 >> 2] | 0) | 0);
	                            if (c[h >> 2] | 0) {
	                                zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                                c[h >> 2] = 0
	                            }
	                            c[e >> 2] = 3019;
	                            A = c[e >> 2] | 0;
	                            i = d;
	                            return A | 0
	                        }
	                        c[p >> 2] = c[(c[(c[g >> 2] | 0) + 64 >> 2] | 0) + 28 >> 2];
	                        do if (c[p >> 2] | 0) {
	                            if ((c[c[p >> 2] >> 2] | 0) != 4) {
	                                if ((c[c[p >> 2] >> 2] | 0) != 1)break;
	                                if ((c[(c[p >> 2] | 0) + 88 >> 2] | 0) == 45)break
	                            }
	                            if ((c[m >> 2] | 0) != (c[p >> 2] | 0) ? (xG(c[f >> 2] | 0, c[m >> 2] | 0, c[p >> 2] | 0, 0) | 0) != 0 : 0) {
	                                c[q >> 2] = 0;
	                                c[r >> 2] = 0;
	                                F = c[f >> 2] | 0;
	                                B = c[g >> 2] | 0;
	                                E = YD(h, c[m >> 2] | 0) | 0;
	                                a = YD(q, c[p >> 2] | 0) | 0;
	                                oG(F, 3020, B, 0, 148952, E, a, YD(r, c[(c[g >> 2] | 0) + 64 >> 2] | 0) | 0);
	                                if (c[h >> 2] | 0) {
	                                    zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                                    c[h >> 2] = 0
	                                }
	                                if (c[q >> 2] | 0) {
	                                    zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                                    c[q >> 2] = 0
	                                }
	                                if (c[r >> 2] | 0) {
	                                    zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                                    c[r >> 2] = 0
	                                }
	                                c[e >> 2] = 3020;
	                                A = c[e >> 2] | 0;
	                                i = d;
	                                return A | 0
	                            }
	                            if (!(c[(c[g >> 2] | 0) + 68 >> 2] | 0))break a;
	                            c[t >> 2] = 1;
	                            c[s >> 2] = c[(c[g >> 2] | 0) + 68 >> 2];
	                            do {
	                                if (((c[c[s >> 2] >> 2] | 0) + -1006 | 0) >>> 0 >= 6) {
	                                    wG(c[f >> 2] | 0, 3021, c[g >> 2] | 0, c[s >> 2] | 0);
	                                    c[t >> 2] = 0
	                                }
	                                c[s >> 2] = c[(c[s >> 2] | 0) + 4 >> 2]
	                            } while ((c[s >> 2] | 0) != 0);
	                            if (c[t >> 2] | 0)break a;
	                            c[e >> 2] = 3021;
	                            A = c[e >> 2] | 0;
	                            i = d;
	                            return A | 0
	                        } while (0);
	                        xB(c[f >> 2] | 0, 148320, 148904);
	                        c[e >> 2] = -1;
	                        A = c[e >> 2] | 0;
	                        i = d;
	                        return A | 0
	                    } while (0);
	                    xB(c[f >> 2] | 0, 148320, 148544);
	                    c[e >> 2] = -1;
	                    A = c[e >> 2] | 0;
	                    i = d;
	                    return A | 0
	                } while (0);
	                c[e >> 2] = 0;
	                A = c[e >> 2] | 0;
	                i = d;
	                return A | 0
	            }

	            function OE(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 24 | 0;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                l = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[j >> 2] = c[(c[g >> 2] | 0) + 20 >> 2];
	                c[k >> 2] = c[(c[f >> 2] | 0) + 8 >> 2];
	                do if (c[(c[f >> 2] | 0) + 68 >> 2] | 0) {
	                    c[l >> 2] = c[(c[f >> 2] | 0) + 68 >> 2];
	                    if ((c[(c[g >> 2] | 0) + 92 >> 2] | 0) == 0 ? (yG(c[g >> 2] | 0) | 0) == -1 : 0) {
	                        c[e >> 2] = -1;
	                        m = c[e >> 2] | 0;
	                        i = d;
	                        return m | 0
	                    }
	                    c[(c[(c[g >> 2] | 0) + 92 >> 2] | 0) + 20 >> 2] = c[(c[g >> 2] | 0) + 36 >> 2];
	                    while (1) {
	                        if (!(c[l >> 2] | 0)) {
	                            n = 9;
	                            break
	                        }
	                        c[h >> 2] = _A(c[l >> 2] | 0, c[f >> 2] | 0, c[g >> 2] | 0, c[k >> 2] | 0) | 0;
	                        if ((c[h >> 2] | 0) == -1)break;
	                        c[l >> 2] = c[(c[l >> 2] | 0) + 4 >> 2]
	                    }
	                    if ((n | 0) == 9) {
	                        c[(c[(c[g >> 2] | 0) + 92 >> 2] | 0) + 20 >> 2] = 0;
	                        break
	                    }
	                    c[e >> 2] = -1;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                } while (0);
	                if ((c[j >> 2] | 0) != (c[(c[g >> 2] | 0) + 20 >> 2] | 0)) {
	                    c[e >> 2] = c[(c[g >> 2] | 0) + 16 >> 2];
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                } else {
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                return 0
	            }

	            function PE(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0, J = 0, K = 0;
	                d = i;
	                i = i + 112 | 0;
	                e = d + 108 | 0;
	                f = d + 104 | 0;
	                g = d + 100 | 0;
	                h = d + 96 | 0;
	                j = d + 92 | 0;
	                k = d + 88 | 0;
	                l = d + 84 | 0;
	                m = d + 80 | 0;
	                n = d + 76 | 0;
	                o = d + 72 | 0;
	                p = d + 68 | 0;
	                q = d + 64 | 0;
	                r = d + 60 | 0;
	                s = d + 56 | 0;
	                t = d + 52 | 0;
	                u = d + 48 | 0;
	                v = d + 44 | 0;
	                w = d + 40 | 0;
	                x = d + 36 | 0;
	                y = d + 32 | 0;
	                z = d + 28 | 0;
	                A = d + 24 | 0;
	                B = d + 20 | 0;
	                C = d + 16 | 0;
	                D = d + 12 | 0;
	                E = d + 8 | 0;
	                F = d + 4 | 0;
	                G = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = c[(c[g >> 2] | 0) + 64 >> 2];
	                c[l >> 2] = 0;
	                c[o >> 2] = 0;
	                c[p >> 2] = 0;
	                c[q >> 2] = 0;
	                c[r >> 2] = 0;
	                c[s >> 2] = 0;
	                c[t >> 2] = 0;
	                c[u >> 2] = 0;
	                c[v >> 2] = 0;
	                c[w >> 2] = 0;
	                c[x >> 2] = 0;
	                c[y >> 2] = 0;
	                c[z >> 2] = 0;
	                c[A >> 2] = 0;
	                c[B >> 2] = 0;
	                c[C >> 2] = 0;
	                c[D >> 2] = 0;
	                c[E >> 2] = 0;
	                c[F >> 2] = 0;
	                if ((c[(c[g >> 2] | 0) + 96 >> 2] | 0) == 0 ? (c[(c[h >> 2] | 0) + 96 >> 2] | 0) == 0 : 0) {
	                    c[e >> 2] = 0;
	                    H = c[e >> 2] | 0;
	                    i = d;
	                    return H | 0
	                }
	                c[l >> 2] = c[(c[g >> 2] | 0) + 96 >> 2];
	                a:do if (c[l >> 2] | 0)while (1) {
	                    if (!(c[c[l >> 2] >> 2] | 0))break a;
	                    c[l >> 2] = c[c[l >> 2] >> 2]
	                } while (0);
	                c[k >> 2] = c[(c[g >> 2] | 0) + 96 >> 2];
	                while (1) {
	                    if (!(c[k >> 2] | 0))break;
	                    c[m >> 2] = c[(c[k >> 2] | 0) + 4 >> 2];
	                    switch (c[c[m >> 2] >> 2] | 0) {
	                        case 1011:
	                        {
	                            c[s >> 2] = c[m >> 2];
	                            break
	                        }
	                        case 1005:
	                        {
	                            c[q >> 2] = c[m >> 2];
	                            break
	                        }
	                        case 1009:
	                        {
	                            c[o >> 2] = c[m >> 2];
	                            break
	                        }
	                        case 1003:
	                        {
	                            c[w >> 2] = c[m >> 2];
	                            break
	                        }
	                        case 1004:
	                        {
	                            c[p >> 2] = c[m >> 2];
	                            break
	                        }
	                        case 1001:
	                        {
	                            c[v >> 2] = c[m >> 2];
	                            break
	                        }
	                        case 1002:
	                        {
	                            c[u >> 2] = c[m >> 2];
	                            break
	                        }
	                        case 1e3:
	                        {
	                            c[t >> 2] = c[m >> 2];
	                            break
	                        }
	                        case 1010:
	                        {
	                            c[r >> 2] = c[m >> 2];
	                            break
	                        }
	                        default:
	                        {
	                        }
	                    }
	                    c[k >> 2] = c[c[k >> 2] >> 2]
	                }
	                c[k >> 2] = c[(c[h >> 2] | 0) + 96 >> 2];
	                while (1) {
	                    if (!(c[k >> 2] | 0))break;
	                    c[m >> 2] = c[(c[k >> 2] | 0) + 4 >> 2];
	                    switch (c[c[m >> 2] >> 2] | 0) {
	                        case 1002:
	                        {
	                            c[D >> 2] = c[m >> 2];
	                            break
	                        }
	                        case 1001:
	                        {
	                            c[E >> 2] = c[m >> 2];
	                            break
	                        }
	                        case 1005:
	                        {
	                            c[z >> 2] = c[m >> 2];
	                            break
	                        }
	                        case 1004:
	                        {
	                            c[y >> 2] = c[m >> 2];
	                            break
	                        }
	                        case 1e3:
	                        {
	                            c[C >> 2] = c[m >> 2];
	                            break
	                        }
	                        case 1003:
	                        {
	                            c[F >> 2] = c[m >> 2];
	                            break
	                        }
	                        case 1011:
	                        {
	                            c[B >> 2] = c[m >> 2];
	                            break
	                        }
	                        case 1010:
	                        {
	                            c[A >> 2] = c[m >> 2];
	                            break
	                        }
	                        case 1009:
	                        {
	                            c[x >> 2] = c[m >> 2];
	                            break
	                        }
	                        default:
	                        {
	                        }
	                    }
	                    c[k >> 2] = c[c[k >> 2] >> 2]
	                }
	                if ((c[o >> 2] | 0) != 0 ? (c[s >> 2] | 0) != 0 | (c[r >> 2] | 0) != 0 : 0)GE(c[f >> 2] | 0, 1717, c[o >> 2] | 0, c[(c[o >> 2] | 0) + 20 >> 2] | 0, 147232, 0);
	                if ((c[u >> 2] | 0) != 0 & (c[w >> 2] | 0) != 0) {
	                    b = c[f >> 2] | 0;
	                    a = c[u >> 2] | 0;
	                    I = c[(c[u >> 2] | 0) + 20 >> 2] | 0;
	                    J = zB(c[c[u >> 2] >> 2] | 0) | 0;
	                    oG(b, 1717, a, I, 147352, J, zB(c[c[w >> 2] >> 2] | 0) | 0, 0)
	                }
	                if ((c[t >> 2] | 0) != 0 & (c[v >> 2] | 0) != 0) {
	                    J = c[f >> 2] | 0;
	                    I = c[t >> 2] | 0;
	                    a = c[(c[t >> 2] | 0) + 20 >> 2] | 0;
	                    b = zB(c[c[t >> 2] >> 2] | 0) | 0;
	                    oG(J, 1717, I, a, 147352, b, zB(c[c[v >> 2] >> 2] | 0) | 0, 0)
	                }
	                if ((c[o >> 2] | 0) != 0 & (c[x >> 2] | 0) != 0) {
	                    c[G >> 2] = XH(c[(c[o >> 2] | 0) + 32 >> 2] | 0, c[(c[x >> 2] | 0) + 32 >> 2] | 0) | 0;
	                    if ((c[G >> 2] | 0) != -2) {
	                        if (c[G >> 2] | 0)zG(c[f >> 2] | 0, c[o >> 2] | 0, c[x >> 2] | 0, 0, 0, 1);
	                        if ((c[G >> 2] | 0) != 0 ? (c[(c[x >> 2] | 0) + 24 >> 2] | 0) != 0 : 0) {
	                            GE(c[f >> 2] | 0, 1717, c[o >> 2] | 0, c[(c[o >> 2] | 0) + 20 >> 2] | 0, 147440, 0);
	                            K = 47
	                        } else K = 47
	                    }
	                } else K = 47;
	                b:do if ((K | 0) == 47) {
	                    if ((c[s >> 2] | 0) != 0 & (c[B >> 2] | 0) != 0) {
	                        c[G >> 2] = XH(c[(c[s >> 2] | 0) + 32 >> 2] | 0, c[(c[B >> 2] | 0) + 32 >> 2] | 0) | 0;
	                        if ((c[G >> 2] | 0) == -2)break;
	                        if ((c[G >> 2] | 0) == -1)zG(c[f >> 2] | 0, c[s >> 2] | 0, c[B >> 2] | 0, 1, 1, 1);
	                        if ((c[G >> 2] | 0) != 0 ? (c[(c[B >> 2] | 0) + 24 >> 2] | 0) != 0 : 0)GE(c[f >> 2] | 0, 1717, c[s >> 2] | 0, c[(c[s >> 2] | 0) + 20 >> 2] | 0, 147440, 0)
	                    }
	                    if ((c[r >> 2] | 0) != 0 & (c[A >> 2] | 0) != 0) {
	                        c[G >> 2] = XH(c[(c[r >> 2] | 0) + 32 >> 2] | 0, c[(c[A >> 2] | 0) + 32 >> 2] | 0) | 0;
	                        if ((c[G >> 2] | 0) == -2)break;
	                        if ((c[G >> 2] | 0) == 1)zG(c[f >> 2] | 0, c[r >> 2] | 0, c[A >> 2] | 0, -1, 1, 1);
	                        if ((c[G >> 2] | 0) != 0 ? (c[(c[A >> 2] | 0) + 24 >> 2] | 0) != 0 : 0)GE(c[f >> 2] | 0, 1717, c[r >> 2] | 0, c[(c[r >> 2] | 0) + 20 >> 2] | 0, 147440, 0)
	                    }
	                    if (!(c[o >> 2] | 0))c[o >> 2] = c[x >> 2];
	                    if (c[o >> 2] | 0) {
	                        if (!(c[s >> 2] | 0))c[s >> 2] = c[B >> 2];
	                        if (c[s >> 2] | 0) {
	                            c[G >> 2] = XH(c[(c[o >> 2] | 0) + 32 >> 2] | 0, c[(c[s >> 2] | 0) + 32 >> 2] | 0) | 0;
	                            if ((c[G >> 2] | 0) == -2)break;
	                            if ((c[G >> 2] | 0) == -1)zG(c[f >> 2] | 0, c[o >> 2] | 0, c[s >> 2] | 0, 1, 1, 0)
	                        }
	                        if (!(c[r >> 2] | 0))c[r >> 2] = c[A >> 2];
	                        if (c[r >> 2] | 0) {
	                            c[G >> 2] = XH(c[(c[o >> 2] | 0) + 32 >> 2] | 0, c[(c[r >> 2] | 0) + 32 >> 2] | 0) | 0;
	                            if ((c[G >> 2] | 0) == -2)break;
	                            if ((c[G >> 2] | 0) == 1)zG(c[f >> 2] | 0, c[o >> 2] | 0, c[r >> 2] | 0, -1, 1, 0)
	                        }
	                    }
	                    if (c[u >> 2] | 0) {
	                        if (c[t >> 2] | 0) {
	                            c[G >> 2] = XH(c[(c[u >> 2] | 0) + 32 >> 2] | 0, c[(c[t >> 2] | 0) + 32 >> 2] | 0) | 0;
	                            if ((c[G >> 2] | 0) == -2)break;
	                            if ((c[G >> 2] | 0) == -1)zG(c[f >> 2] | 0, c[u >> 2] | 0, c[t >> 2] | 0, 1, 1, 0)
	                        }
	                        if (c[D >> 2] | 0) {
	                            c[G >> 2] = XH(c[(c[u >> 2] | 0) + 32 >> 2] | 0, c[(c[D >> 2] | 0) + 32 >> 2] | 0) | 0;
	                            if ((c[G >> 2] | 0) == -2)break;
	                            if ((c[G >> 2] | 0) == 1)zG(c[f >> 2] | 0, c[u >> 2] | 0, c[D >> 2] | 0, -1, 1, 1);
	                            if ((c[G >> 2] | 0) != 0 ? (c[(c[D >> 2] | 0) + 24 >> 2] | 0) != 0 : 0)GE(c[f >> 2] | 0, 1717, c[u >> 2] | 0, c[(c[u >> 2] | 0) + 20 >> 2] | 0, 147440, 0)
	                        }
	                        if (c[F >> 2] | 0) {
	                            c[G >> 2] = XH(c[(c[u >> 2] | 0) + 32 >> 2] | 0, c[(c[F >> 2] | 0) + 32 >> 2] | 0) | 0;
	                            if ((c[G >> 2] | 0) == -2)break;
	                            if ((c[G >> 2] | 0) != -1)zG(c[f >> 2] | 0, c[u >> 2] | 0, c[F >> 2] | 0, -1, 0, 1)
	                        }
	                        if (c[C >> 2] | 0) {
	                            c[G >> 2] = XH(c[(c[u >> 2] | 0) + 32 >> 2] | 0, c[(c[C >> 2] | 0) + 32 >> 2] | 0) | 0;
	                            if ((c[G >> 2] | 0) == -2)break;
	                            if ((c[G >> 2] | 0) == -1)zG(c[f >> 2] | 0, c[u >> 2] | 0, c[C >> 2] | 0, 1, 1, 1)
	                        }
	                        if (c[E >> 2] | 0) {
	                            c[G >> 2] = XH(c[(c[u >> 2] | 0) + 32 >> 2] | 0, c[(c[E >> 2] | 0) + 32 >> 2] | 0) | 0;
	                            if ((c[G >> 2] | 0) == -2)break;
	                            if ((c[G >> 2] | 0) != 1)zG(c[f >> 2] | 0, c[u >> 2] | 0, c[E >> 2] | 0, 1, 0, 1)
	                        }
	                    }
	                    do if (c[w >> 2] | 0) {
	                        if (c[v >> 2] | 0) {
	                            c[G >> 2] = XH(c[(c[w >> 2] | 0) + 32 >> 2] | 0, c[(c[v >> 2] | 0) + 32 >> 2] | 0) | 0;
	                            if ((c[G >> 2] | 0) == -2)break b;
	                            if ((c[G >> 2] | 0) == -1)zG(c[f >> 2] | 0, c[w >> 2] | 0, c[v >> 2] | 0, 1, 1, 0)
	                        }
	                        do if (c[F >> 2] | 0) {
	                            c[G >> 2] = XH(c[(c[w >> 2] | 0) + 32 >> 2] | 0, c[(c[F >> 2] | 0) + 32 >> 2] | 0) | 0;
	                            if ((c[G >> 2] | 0) == -2)break b;
	                            if ((c[G >> 2] | 0) == 1)zG(c[f >> 2] | 0, c[w >> 2] | 0, c[F >> 2] | 0, -1, 1, 1);
	                            if (c[G >> 2] | 0) {
	                                if (!(c[(c[F >> 2] | 0) + 24 >> 2] | 0))break;
	                                GE(c[f >> 2] | 0, 1717, c[w >> 2] | 0, c[(c[w >> 2] | 0) + 20 >> 2] | 0, 147440, 0)
	                            }
	                        } while (0);
	                        if (c[D >> 2] | 0) {
	                            c[G >> 2] = XH(c[(c[w >> 2] | 0) + 32 >> 2] | 0, c[(c[D >> 2] | 0) + 32 >> 2] | 0) | 0;
	                            if ((c[G >> 2] | 0) == -2)break b;
	                            if ((c[G >> 2] | 0) == 1)zG(c[f >> 2] | 0, c[w >> 2] | 0, c[D >> 2] | 0, -1, 1, 1)
	                        }
	                        do if (c[C >> 2] | 0) {
	                            c[G >> 2] = XH(c[(c[w >> 2] | 0) + 32 >> 2] | 0, c[(c[C >> 2] | 0) + 32 >> 2] | 0) | 0;
	                            if ((c[G >> 2] | 0) == -2)break b;
	                            if ((c[G >> 2] | 0) == 1)break;
	                            zG(c[f >> 2] | 0, c[w >> 2] | 0, c[C >> 2] | 0, 1, 0, 1)
	                        } while (0);
	                        if (c[E >> 2] | 0) {
	                            c[G >> 2] = XH(c[(c[w >> 2] | 0) + 32 >> 2] | 0, c[(c[E >> 2] | 0) + 32 >> 2] | 0) | 0;
	                            if ((c[G >> 2] | 0) == -2)break b;
	                            if ((c[G >> 2] | 0) == 1)break;
	                            zG(c[f >> 2] | 0, c[w >> 2] | 0, c[E >> 2] | 0, 1, 0, 1)
	                        }
	                    } while (0);
	                    do if (c[v >> 2] | 0) {
	                        if (c[u >> 2] | 0) {
	                            c[G >> 2] = XH(c[(c[v >> 2] | 0) + 32 >> 2] | 0, c[(c[u >> 2] | 0) + 32 >> 2] | 0) | 0;
	                            if ((c[G >> 2] | 0) == -2)break b;
	                            if ((c[G >> 2] | 0) != -1)zG(c[f >> 2] | 0, c[v >> 2] | 0, c[u >> 2] | 0, -1, 0, 0)
	                        }
	                        do if (c[E >> 2] | 0) {
	                            c[G >> 2] = XH(c[(c[v >> 2] | 0) + 32 >> 2] | 0, c[(c[E >> 2] | 0) + 32 >> 2] | 0) | 0;
	                            if ((c[G >> 2] | 0) == -2)break b;
	                            if ((c[G >> 2] | 0) == -1)zG(c[f >> 2] | 0, c[v >> 2] | 0, c[E >> 2] | 0, 1, 1, 1);
	                            if (!(c[G >> 2] | 0))break;
	                            if (!(c[(c[E >> 2] | 0) + 24 >> 2] | 0))break;
	                            GE(c[f >> 2] | 0, 1717, c[v >> 2] | 0, c[(c[v >> 2] | 0) + 20 >> 2] | 0, 147440, 0)
	                        } while (0);
	                        do if (c[D >> 2] | 0) {
	                            c[G >> 2] = XH(c[(c[v >> 2] | 0) + 32 >> 2] | 0, c[(c[D >> 2] | 0) + 32 >> 2] | 0) | 0;
	                            if ((c[G >> 2] | 0) == -2)break b;
	                            if ((c[G >> 2] | 0) != 1)break;
	                            zG(c[f >> 2] | 0, c[v >> 2] | 0, c[D >> 2] | 0, -1, 1, 1)
	                        } while (0);
	                        do if (c[C >> 2] | 0) {
	                            c[G >> 2] = XH(c[(c[v >> 2] | 0) + 32 >> 2] | 0, c[(c[C >> 2] | 0) + 32 >> 2] | 0) | 0;
	                            if ((c[G >> 2] | 0) == -2)break b;
	                            if ((c[G >> 2] | 0) != -1)break;
	                            zG(c[f >> 2] | 0, c[v >> 2] | 0, c[C >> 2] | 0, 1, 1, 1)
	                        } while (0);
	                        if (c[F >> 2] | 0) {
	                            c[G >> 2] = XH(c[(c[v >> 2] | 0) + 32 >> 2] | 0, c[(c[F >> 2] | 0) + 32 >> 2] | 0) | 0;
	                            if ((c[G >> 2] | 0) == -2)break b;
	                            if ((c[G >> 2] | 0) == -1)break;
	                            zG(c[f >> 2] | 0, c[v >> 2] | 0, c[F >> 2] | 0, -1, 0, 1)
	                        }
	                    } while (0);
	                    do if (c[t >> 2] | 0) {
	                        if (c[w >> 2] | 0) {
	                            c[G >> 2] = XH(c[(c[t >> 2] | 0) + 32 >> 2] | 0, c[(c[w >> 2] | 0) + 32 >> 2] | 0) | 0;
	                            if ((c[G >> 2] | 0) == -2)break b;
	                            if ((c[G >> 2] | 0) != -1)zG(c[f >> 2] | 0, c[t >> 2] | 0, c[w >> 2] | 0, -1, 0, 0)
	                        }
	                        do if (c[C >> 2] | 0) {
	                            c[G >> 2] = XH(c[(c[t >> 2] | 0) + 32 >> 2] | 0, c[(c[C >> 2] | 0) + 32 >> 2] | 0) | 0;
	                            if ((c[G >> 2] | 0) == -2)break b;
	                            if ((c[G >> 2] | 0) == -1)zG(c[f >> 2] | 0, c[t >> 2] | 0, c[C >> 2] | 0, 1, 1, 1);
	                            if (!(c[G >> 2] | 0))break;
	                            if (!(c[(c[C >> 2] | 0) + 24 >> 2] | 0))break;
	                            GE(c[f >> 2] | 0, 1717, c[t >> 2] | 0, c[(c[t >> 2] | 0) + 20 >> 2] | 0, 147440, 0)
	                        } while (0);
	                        do if (c[D >> 2] | 0) {
	                            c[G >> 2] = XH(c[(c[t >> 2] | 0) + 32 >> 2] | 0, c[(c[D >> 2] | 0) + 32 >> 2] | 0) | 0;
	                            if ((c[G >> 2] | 0) == -2)break b;
	                            if ((c[G >> 2] | 0) != 1)break;
	                            zG(c[f >> 2] | 0, c[t >> 2] | 0, c[D >> 2] | 0, -1, 1, 1)
	                        } while (0);
	                        do if (c[E >> 2] | 0) {
	                            c[G >> 2] = XH(c[(c[t >> 2] | 0) + 32 >> 2] | 0, c[(c[E >> 2] | 0) + 32 >> 2] | 0) | 0;
	                            if ((c[G >> 2] | 0) == -2)break b;
	                            if ((c[G >> 2] | 0) == 1)break;
	                            zG(c[f >> 2] | 0, c[t >> 2] | 0, c[E >> 2] | 0, 1, 0, 1)
	                        } while (0);
	                        if (!(c[F >> 2] | 0))break;
	                        c[G >> 2] = XH(c[(c[t >> 2] | 0) + 32 >> 2] | 0, c[(c[F >> 2] | 0) + 32 >> 2] | 0) | 0;
	                        if ((c[G >> 2] | 0) == -2)break b;
	                        if ((c[G >> 2] | 0) == -1)break;
	                        zG(c[f >> 2] | 0, c[t >> 2] | 0, c[F >> 2] | 0, -1, 0, 1)
	                    } while (0);
	                    do if ((c[p >> 2] | 0) != 0 & (c[y >> 2] | 0) != 0) {
	                        c[G >> 2] = XH(c[(c[p >> 2] | 0) + 32 >> 2] | 0, c[(c[y >> 2] | 0) + 32 >> 2] | 0) | 0;
	                        if ((c[G >> 2] | 0) == -2)break b;
	                        if ((c[G >> 2] | 0) == 1)zG(c[f >> 2] | 0, c[p >> 2] | 0, c[y >> 2] | 0, -1, 1, 1);
	                        if (c[G >> 2] | 0) {
	                            if (!(c[(c[y >> 2] | 0) + 24 >> 2] | 0))break;
	                            GE(c[f >> 2] | 0, 1717, c[p >> 2] | 0, c[(c[p >> 2] | 0) + 20 >> 2] | 0, 147440, 0)
	                        }
	                    } while (0);
	                    do if ((c[q >> 2] | 0) != 0 & (c[z >> 2] | 0) != 0) {
	                        c[G >> 2] = XH(c[(c[q >> 2] | 0) + 32 >> 2] | 0, c[(c[z >> 2] | 0) + 32 >> 2] | 0) | 0;
	                        if ((c[G >> 2] | 0) == -2)break b;
	                        if ((c[G >> 2] | 0) == 1)zG(c[f >> 2] | 0, c[q >> 2] | 0, c[z >> 2] | 0, -1, 1, 1);
	                        if (!(c[G >> 2] | 0))break;
	                        if (!(c[(c[z >> 2] | 0) + 24 >> 2] | 0))break;
	                        GE(c[f >> 2] | 0, 1717, c[q >> 2] | 0, c[(c[q >> 2] | 0) + 20 >> 2] | 0, 147440, 0)
	                    } while (0);
	                    if (!(c[p >> 2] | 0))c[p >> 2] = c[y >> 2];
	                    if (!(c[q >> 2] | 0))c[q >> 2] = c[z >> 2];
	                    do if ((c[p >> 2] | 0) != 0 & (c[q >> 2] | 0) != 0) {
	                        c[G >> 2] = XH(c[(c[q >> 2] | 0) + 32 >> 2] | 0, c[(c[p >> 2] | 0) + 32 >> 2] | 0) | 0;
	                        if ((c[G >> 2] | 0) == -2)break b;
	                        if ((c[G >> 2] | 0) != 1)break;
	                        zG(c[f >> 2] | 0, c[q >> 2] | 0, c[p >> 2] | 0, -1, 1, 0)
	                    } while (0);
	                    c[k >> 2] = c[(c[h >> 2] | 0) + 96 >> 2];
	                    c:while (1) {
	                        if (!(c[k >> 2] | 0)) {
	                            K = 216;
	                            break
	                        }
	                        c[n >> 2] = c[(c[k >> 2] | 0) + 4 >> 2];
	                        do if ((c[c[n >> 2] >> 2] | 0) != 1006) {
	                            if ((c[c[n >> 2] >> 2] | 0) == 1007)break;
	                            c[j >> 2] = c[(c[g >> 2] | 0) + 96 >> 2];
	                            while (1) {
	                                if (!(c[j >> 2] | 0))break;
	                                c[m >> 2] = c[(c[j >> 2] | 0) + 4 >> 2];
	                                if ((c[c[m >> 2] >> 2] | 0) == (c[c[n >> 2] >> 2] | 0)) {
	                                    K = 201;
	                                    break
	                                }
	                                c[j >> 2] = c[c[j >> 2] >> 2]
	                            }
	                            do if ((K | 0) == 201) {
	                                K = 0;
	                                if ((c[c[m >> 2] >> 2] | 0) != 1008)break;
	                                if ((c[(c[m >> 2] | 0) + 28 >> 2] | 0) < (c[(c[n >> 2] | 0) + 28 >> 2] | 0))GE(c[f >> 2] | 0, 1717, c[m >> 2] | 0, c[(c[m >> 2] | 0) + 20 >> 2] | 0, 147512, 0);
	                                if (!(c[(c[n >> 2] | 0) + 24 >> 2] | 0))break;
	                                if ((c[(c[m >> 2] | 0) + 28 >> 2] | 0) == (c[(c[n >> 2] | 0) + 28 >> 2] | 0))break;
	                                GE(c[f >> 2] | 0, 1717, c[m >> 2] | 0, c[(c[m >> 2] | 0) + 20 >> 2] | 0, 147440, 0)
	                            } while (0);
	                            if (c[j >> 2] | 0)break;
	                            c[j >> 2] = Cb[c[135744 >> 2] & 511](8) | 0;
	                            if (!(c[j >> 2] | 0)) {
	                                K = 210;
	                                break c
	                            }
	                            c[(c[j >> 2] | 0) + 4 >> 2] = c[(c[k >> 2] | 0) + 4 >> 2];
	                            c[c[j >> 2] >> 2] = 0;
	                            b = c[j >> 2] | 0;
	                            if (!(c[l >> 2] | 0))c[(c[g >> 2] | 0) + 96 >> 2] = b; else c[c[l >> 2] >> 2] = b;
	                            c[l >> 2] = c[j >> 2]
	                        } while (0);
	                        c[k >> 2] = c[c[k >> 2] >> 2]
	                    }
	                    if ((K | 0) == 210) {
	                        tC(c[f >> 2] | 0, 147616, 0);
	                        c[e >> 2] = -1;
	                        H = c[e >> 2] | 0;
	                        i = d;
	                        return H | 0
	                    } else if ((K | 0) == 216) {
	                        c[e >> 2] = 0;
	                        H = c[e >> 2] | 0;
	                        i = d;
	                        return H | 0
	                    }
	                } while (0);
	                xB(c[f >> 2] | 0, 147656, 147696);
	                c[e >> 2] = -1;
	                H = c[e >> 2] | 0;
	                i = d;
	                return H | 0
	            }

	            function QE(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                a = (c[e >> 2] | 0) + 48 | 0;
	                h = c[a >> 2] | 0;
	                if (c[(c[e >> 2] | 0) + 48 >> 2] & 64) {
	                    c[a >> 2] = h | 67108864;
	                    c[d >> 2] = 0;
	                    j = c[d >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                if (h & 128) {
	                    c[d >> 2] = 0;
	                    j = c[d >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                a:do if (c[(c[e >> 2] | 0) + 96 >> 2] | 0) {
	                    c[f >> 2] = c[(c[e >> 2] | 0) + 96 >> 2];
	                    while (1) {
	                        if (!(c[f >> 2] | 0))break a;
	                        k = c[f >> 2] | 0;
	                        if ((c[c[(c[f >> 2] | 0) + 4 >> 2] >> 2] | 0) == 1008)break;
	                        c[f >> 2] = c[k >> 2]
	                    }
	                    h = c[(c[k + 4 >> 2] | 0) + 28 >> 2] | 0;
	                    if ((h | 0) == 2) {
	                        a = (c[e >> 2] | 0) + 48 | 0;
	                        c[a >> 2] = c[a >> 2] | 33554432
	                    } else if ((h | 0) == 1) {
	                        a = (c[e >> 2] | 0) + 48 | 0;
	                        c[a >> 2] = c[a >> 2] | 16777216
	                    } else if ((h | 0) == 3) {
	                        h = (c[e >> 2] | 0) + 48 | 0;
	                        c[h >> 2] = c[h >> 2] | 67108864
	                    } else {
	                        c[d >> 2] = -1;
	                        j = c[d >> 2] | 0;
	                        i = b;
	                        return j | 0
	                    }
	                    c[d >> 2] = 0;
	                    j = c[d >> 2] | 0;
	                    i = b;
	                    return j | 0
	                } while (0);
	                c[g >> 2] = c[(c[e >> 2] | 0) + 64 >> 2];
	                while (1) {
	                    if (!(c[g >> 2] | 0))break;
	                    if ((c[(c[g >> 2] | 0) + 88 >> 2] | 0) == 45)break;
	                    l = c[g >> 2] | 0;
	                    if ((c[c[g >> 2] >> 2] | 0) == 1) {
	                        m = 20;
	                        break
	                    }
	                    c[g >> 2] = c[l + 64 >> 2]
	                }
	                do if ((m | 0) == 20) {
	                    if ((c[l + 88 >> 2] | 0) == 2) {
	                        k = (c[e >> 2] | 0) + 48 | 0;
	                        c[k >> 2] = c[k >> 2] | 33554432;
	                        break
	                    }
	                    if ((c[(c[g >> 2] | 0) + 88 >> 2] | 0) != 1 ? (c[(c[g >> 2] | 0) + 88 >> 2] | 0) != 46 : 0) {
	                        k = (c[e >> 2] | 0) + 48 | 0;
	                        c[k >> 2] = c[k >> 2] | 67108864;
	                        break
	                    }
	                    k = (c[e >> 2] | 0) + 48 | 0;
	                    c[k >> 2] = c[k >> 2] | 16777216
	                } while (0);
	                c[d >> 2] = 0;
	                j = c[d >> 2] | 0;
	                i = b;
	                return j | 0
	            }

	            function RE(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 20 | 0;
	                e = b + 16 | 0;
	                f = b + 12 | 0;
	                g = b + 8 | 0;
	                h = b + 4 | 0;
	                j = b;
	                c[d >> 2] = a;
	                c[e >> 2] = 0;
	                c[f >> 2] = 0;
	                c[g >> 2] = 0;
	                c[e >> 2] = (c[(c[(c[d >> 2] | 0) + 64 >> 2] | 0) + 48 >> 2] & 134217728 | 0) != 0 ? 1 : 0;
	                if (c[e >> 2] | 0) {
	                    c[f >> 2] = (c[(c[(c[d >> 2] | 0) + 64 >> 2] | 0) + 48 >> 2] & 2097152 | 0) != 0 ? 1 : 0;
	                    c[g >> 2] = (c[(c[(c[d >> 2] | 0) + 64 >> 2] | 0) + 48 >> 2] & 268435456 | 0) != 0 ? 1 : 0
	                }
	                a:do if (c[(c[d >> 2] | 0) + 68 >> 2] | 0) {
	                    c[h >> 2] = c[(c[d >> 2] | 0) + 68 >> 2];
	                    while (1) {
	                        if (!(c[h >> 2] | 0))break a;
	                        a = c[c[h >> 2] >> 2] | 0;
	                        if ((a | 0) == 1007) {
	                            c[f >> 2] = 1;
	                            c[g >> 2] = 1;
	                            c[e >> 2] = 1
	                        } else if ((a | 0) == 1006) {
	                            c[g >> 2] = 1;
	                            c[e >> 2] = 1
	                        } else if ((a | 0) != 1008)c[e >> 2] = 1;
	                        c[h >> 2] = c[(c[h >> 2] | 0) + 4 >> 2]
	                    }
	                } while (0);
	                if (c[g >> 2] | 0) {
	                    g = (c[d >> 2] | 0) + 48 | 0;
	                    c[g >> 2] = c[g >> 2] | 268435456
	                }
	                if (c[f >> 2] | 0) {
	                    g = (c[d >> 2] | 0) + 48 | 0;
	                    c[g >> 2] = c[g >> 2] | 2097152
	                }
	                if (c[e >> 2] | 0) {
	                    g = (c[d >> 2] | 0) + 48 | 0;
	                    c[g >> 2] = c[g >> 2] | 134217728
	                }
	                if ((c[e >> 2] | 0) == 0 | (c[f >> 2] | 0) != 0) {
	                    i = b;
	                    return
	                }
	                if (!(c[(c[d >> 2] | 0) + 48 >> 2] & 256)) {
	                    i = b;
	                    return
	                }
	                c[j >> 2] = TD(c[d >> 2] | 0) | 0;
	                if ((c[(c[j >> 2] | 0) + 88 >> 2] | 0) == 46) {
	                    i = b;
	                    return
	                }
	                if ((c[(c[j >> 2] | 0) + 88 >> 2] | 0) == 1) {
	                    i = b;
	                    return
	                }
	                j = (c[d >> 2] | 0) + 48 | 0;
	                c[j >> 2] = c[j >> 2] | 2097152;
	                i = b;
	                return
	            }

	            function SE(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                do if (!(c[f >> 2] | 0))c[e >> 2] = 0; else {
	                    if ((c[c[f >> 2] >> 2] | 0) != 5 ? (c[(c[f >> 2] | 0) + 88 >> 2] | 0) != 45 : 0) {
	                        b = c[f >> 2] | 0;
	                        if ((c[c[f >> 2] >> 2] | 0) != 1) {
	                            c[e >> 2] = SE(c[b + 28 >> 2] | 0, c[g >> 2] | 0) | 0;
	                            break
	                        }
	                        if ((c[b + 88 >> 2] | 0) == (c[g >> 2] | 0)) {
	                            c[e >> 2] = 1;
	                            break
	                        }
	                        if ((c[(c[f >> 2] | 0) + 88 >> 2] | 0) != 46 ? (c[(c[f >> 2] | 0) + 88 >> 2] | 0) != 45 : 0) {
	                            c[e >> 2] = SE(c[(c[f >> 2] | 0) + 28 >> 2] | 0, c[g >> 2] | 0) | 0;
	                            break
	                        }
	                        c[e >> 2] = 0;
	                        break
	                    }
	                    c[e >> 2] = 0
	                } while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function TE(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[c[f >> 2] >> 2] | 0) != 0 ? (c[g >> 2] | 0) < (c[(c[f >> 2] | 0) + 4 >> 2] | 0) : 0) {
	                    do if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                        zb[c[135736 >> 2] & 511](c[c[f >> 2] >> 2] | 0);
	                        c[c[f >> 2] >> 2] = 0;
	                        c[(c[f >> 2] | 0) + 4 >> 2] = 0;
	                        c[(c[f >> 2] | 0) + 8 >> 2] = 0
	                    } else {
	                        if (((c[(c[f >> 2] | 0) + 4 >> 2] | 0) - 1 | 0) == (c[g >> 2] | 0)) {
	                            b = (c[f >> 2] | 0) + 4 | 0;
	                            c[b >> 2] = (c[b >> 2] | 0) + -1;
	                            break
	                        }
	                        c[h >> 2] = c[g >> 2];
	                        while (1) {
	                            if ((c[h >> 2] | 0) >= ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) - 1 | 0))break;
	                            c[(c[c[f >> 2] >> 2] | 0) + (c[h >> 2] << 2) >> 2] = c[(c[c[f >> 2] >> 2] | 0) + ((c[h >> 2] | 0) + 1 << 2) >> 2];
	                            c[h >> 2] = (c[h >> 2] | 0) + 1
	                        }
	                        b = (c[f >> 2] | 0) + 4 | 0;
	                        c[b >> 2] = (c[b >> 2] | 0) + -1
	                    } while (0);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                AG(152576);
	                c[e >> 2] = -1;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function UE(a, b, d, e, f, g, h, j) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                var k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0, J = 0, K = 0, L = 0, M = 0, N = 0;
	                k = i;
	                i = i + 112 | 0;
	                l = k + 108 | 0;
	                m = k + 104 | 0;
	                n = k + 100 | 0;
	                o = k + 96 | 0;
	                p = k + 92 | 0;
	                q = k + 88 | 0;
	                r = k + 84 | 0;
	                s = k + 80 | 0;
	                t = k + 76 | 0;
	                u = k + 72 | 0;
	                v = k + 68 | 0;
	                w = k + 64 | 0;
	                x = k + 60 | 0;
	                y = k + 56 | 0;
	                z = k + 52 | 0;
	                A = k + 48 | 0;
	                B = k + 44 | 0;
	                C = k + 40 | 0;
	                D = k + 36 | 0;
	                E = k + 32 | 0;
	                F = k + 28 | 0;
	                G = k + 24 | 0;
	                H = k + 20 | 0;
	                I = k + 16 | 0;
	                J = k + 12 | 0;
	                K = k + 8 | 0;
	                L = k + 4 | 0;
	                M = k;
	                c[m >> 2] = a;
	                c[n >> 2] = b;
	                c[o >> 2] = d;
	                c[p >> 2] = e;
	                c[q >> 2] = f;
	                c[r >> 2] = g;
	                c[s >> 2] = h;
	                c[t >> 2] = j;
	                c[u >> 2] = 0;
	                a:do if (c[q >> 2] | 0) {
	                    c[w >> 2] = 0;
	                    while (1) {
	                        if ((c[w >> 2] | 0) >= (c[(c[q >> 2] | 0) + 4 >> 2] | 0))break a;
	                        c[u >> 2] = c[(c[c[q >> 2] >> 2] | 0) + (c[w >> 2] << 2) >> 2];
	                        c[y >> 2] = 0;
	                        b:do if (c[r >> 2] | 0) {
	                            c[x >> 2] = 0;
	                            while (1) {
	                                if ((c[x >> 2] | 0) >= (c[(c[r >> 2] | 0) + 4 >> 2] | 0))break b;
	                                c[v >> 2] = c[(c[c[r >> 2] >> 2] | 0) + (c[x >> 2] << 2) >> 2];
	                                if ((c[(c[(c[u >> 2] | 0) + 12 >> 2] | 0) + 8 >> 2] | 0) == (c[(c[(c[v >> 2] | 0) + 12 >> 2] | 0) + 8 >> 2] | 0) ? (c[(c[(c[u >> 2] | 0) + 12 >> 2] | 0) + 56 >> 2] | 0) == (c[(c[(c[v >> 2] | 0) + 12 >> 2] | 0) + 56 >> 2] | 0) : 0)break;
	                                c[x >> 2] = (c[x >> 2] | 0) + 1
	                            }
	                            c[y >> 2] = 1;
	                            if ((c[(c[u >> 2] | 0) + 24 >> 2] | 0) == 2 ? (c[(c[v >> 2] | 0) + 24 >> 2] | 0) == 1 : 0) {
	                                c[B >> 2] = 0;
	                                j = c[m >> 2] | 0;
	                                h = FC(c[o >> 2] | 0) | 0;
	                                g = c[o >> 2] | 0;
	                                f = c[u >> 2] | 0;
	                                e = (c[n >> 2] | 0) == 0 ? 151424 : 151432;
	                                BG(j, 1788, h, g, f, 151312, e, ZD(B, c[p >> 2] | 0) | 0, 0, 0);
	                                if (!(c[B >> 2] | 0))break;
	                                zb[c[135736 >> 2] & 511](c[B >> 2] | 0);
	                                c[B >> 2] = 0;
	                                break
	                            }
	                            if (!(xG(c[m >> 2] | 0, c[(c[(c[u >> 2] | 0) + 12 >> 2] | 0) + 48 >> 2] | 0, c[(c[(c[v >> 2] | 0) + 12 >> 2] | 0) + 48 >> 2] | 0, 0) | 0)) {
	                                CG(c[v >> 2] | 0, A, z, 0) | 0;
	                                if (!((c[z >> 2] | 0) != 0 & (c[A >> 2] | 0) == 1))break;
	                                c[F >> 2] = 0;
	                                CG(c[v >> 2] | 0, A, F, 0) | 0;
	                                if ((c[A >> 2] | 0) != 0 ? (c[F >> 2] | 0) == (c[z >> 2] | 0) : 0)break;
	                                c[G >> 2] = 0;
	                                e = c[m >> 2] | 0;
	                                f = FC(c[o >> 2] | 0) | 0;
	                                g = c[o >> 2] | 0;
	                                h = c[u >> 2] | 0;
	                                j = (c[n >> 2] | 0) == 0 ? 151424 : 151432;
	                                BG(e, 3077, f, g, h, 151576, j, ZD(G, c[p >> 2] | 0) | 0, 0, 0);
	                                if (!(c[G >> 2] | 0))break;
	                                zb[c[135736 >> 2] & 511](c[G >> 2] | 0);
	                                c[G >> 2] = 0;
	                                break
	                            }
	                            c[C >> 2] = 0;
	                            c[D >> 2] = 0;
	                            c[E >> 2] = 0;
	                            j = c[m >> 2] | 0;
	                            h = FC(c[o >> 2] | 0) | 0;
	                            g = c[o >> 2] | 0;
	                            f = c[u >> 2] | 0;
	                            e = ZD(C, c[(c[(c[u >> 2] | 0) + 12 >> 2] | 0) + 48 >> 2] | 0) | 0;
	                            d = ZD(D, c[(c[(c[v >> 2] | 0) + 12 >> 2] | 0) + 48 >> 2] | 0) | 0;
	                            b = (c[n >> 2] | 0) == 0 ? 151424 : 151432;
	                            BG(j, 1789, h, g, f, 151448, e, d, b, ZD(E, c[p >> 2] | 0) | 0);
	                            if (c[C >> 2] | 0) {
	                                zb[c[135736 >> 2] & 511](c[C >> 2] | 0);
	                                c[C >> 2] = 0
	                            }
	                            if (c[D >> 2] | 0) {
	                                zb[c[135736 >> 2] & 511](c[D >> 2] | 0);
	                                c[D >> 2] = 0
	                            }
	                            if (c[E >> 2] | 0) {
	                                zb[c[135736 >> 2] & 511](c[E >> 2] | 0);
	                                c[E >> 2] = 0
	                            }
	                        } while (0);
	                        do if (!(c[y >> 2] | 0)) {
	                            if ((c[t >> 2] | 0) != 0 ? (DG(c[t >> 2] | 0, c[(c[(c[u >> 2] | 0) + 12 >> 2] | 0) + 56 >> 2] | 0) | 0) == 0 : 0)break;
	                            c[H >> 2] = 0;
	                            b = c[m >> 2] | 0;
	                            d = FC(c[o >> 2] | 0) | 0;
	                            e = c[o >> 2] | 0;
	                            f = c[u >> 2] | 0;
	                            g = (c[n >> 2] | 0) == 0 ? 151424 : 151432;
	                            BG(b, 1790, d, e, f, 151680, g, ZD(H, c[p >> 2] | 0) | 0, 0, 0);
	                            if (c[H >> 2] | 0) {
	                                zb[c[135736 >> 2] & 511](c[H >> 2] | 0);
	                                c[H >> 2] = 0
	                            }
	                        } while (0);
	                        c[w >> 2] = (c[w >> 2] | 0) + 1
	                    }
	                } while (0);
	                c:do if (c[r >> 2] | 0) {
	                    c[x >> 2] = 0;
	                    while (1) {
	                        if ((c[x >> 2] | 0) >= (c[(c[r >> 2] | 0) + 4 >> 2] | 0))break c;
	                        c[v >> 2] = c[(c[c[r >> 2] >> 2] | 0) + (c[x >> 2] << 2) >> 2];
	                        if ((c[(c[v >> 2] | 0) + 24 >> 2] | 0) == 1) {
	                            c[y >> 2] = 0;
	                            d:do if (c[q >> 2] | 0) {
	                                c[w >> 2] = 0;
	                                while (1) {
	                                    if ((c[w >> 2] | 0) >= (c[(c[q >> 2] | 0) + 4 >> 2] | 0))break d;
	                                    c[u >> 2] = c[(c[c[q >> 2] >> 2] | 0) + (c[w >> 2] << 2) >> 2];
	                                    if ((c[(c[(c[u >> 2] | 0) + 12 >> 2] | 0) + 8 >> 2] | 0) == (c[(c[(c[v >> 2] | 0) + 12 >> 2] | 0) + 8 >> 2] | 0) ? (c[(c[(c[u >> 2] | 0) + 12 >> 2] | 0) + 56 >> 2] | 0) == (c[(c[(c[v >> 2] | 0) + 12 >> 2] | 0) + 56 >> 2] | 0) : 0)break;
	                                    c[w >> 2] = (c[w >> 2] | 0) + 1
	                                }
	                                c[y >> 2] = 1
	                            } while (0);
	                            if (!(c[y >> 2] | 0)) {
	                                c[I >> 2] = 0;
	                                c[J >> 2] = 0;
	                                H = c[m >> 2] | 0;
	                                E = c[o >> 2] | 0;
	                                D = ZD(I, c[v >> 2] | 0) | 0;
	                                C = (c[n >> 2] | 0) == 0 ? 151424 : 151432;
	                                CB(H, 1791, 0, E, 151760, D, C, ZD(J, c[p >> 2] | 0) | 0, 0);
	                                if (c[I >> 2] | 0) {
	                                    zb[c[135736 >> 2] & 511](c[I >> 2] | 0);
	                                    c[I >> 2] = 0
	                                }
	                                if (c[J >> 2] | 0) {
	                                    zb[c[135736 >> 2] & 511](c[J >> 2] | 0);
	                                    c[J >> 2] = 0
	                                }
	                            }
	                        }
	                        c[x >> 2] = (c[x >> 2] | 0) + 1
	                    }
	                } while (0);
	                do if (c[s >> 2] | 0) {
	                    if (!(c[t >> 2] | 0)) {
	                        c[K >> 2] = 0;
	                        x = c[m >> 2] | 0;
	                        J = c[o >> 2] | 0;
	                        I = MD(c[o >> 2] | 0) | 0;
	                        v = (c[n >> 2] | 0) == 0 ? 151424 : 151432;
	                        y = MD(c[p >> 2] | 0) | 0;
	                        CB(x, 1797, 0, J, 151832, I, v, y, YD(K, c[p >> 2] | 0) | 0);
	                        if (c[K >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[K >> 2] | 0);
	                            c[K >> 2] = 0
	                        }
	                        c[l >> 2] = c[(c[m >> 2] | 0) + 16 >> 2];
	                        N = c[l >> 2] | 0;
	                        i = k;
	                        return N | 0
	                    }
	                    if ((c[(c[t >> 2] | 0) + 28 >> 2] | 0) == 0 ? (EG(c[s >> 2] | 0, c[t >> 2] | 0) | 0) != 0 : 0) {
	                        c[L >> 2] = 0;
	                        y = c[m >> 2] | 0;
	                        v = c[o >> 2] | 0;
	                        I = (c[n >> 2] | 0) == 0 ? 151424 : 151432;
	                        J = MD(c[p >> 2] | 0) | 0;
	                        CB(y, 1798, 0, v, 151904, I, J, YD(L, c[p >> 2] | 0) | 0, 0);
	                        if (c[L >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[L >> 2] | 0);
	                            c[L >> 2] = 0
	                        }
	                        c[l >> 2] = c[(c[m >> 2] | 0) + 16 >> 2];
	                        N = c[l >> 2] | 0;
	                        i = k;
	                        return N | 0
	                    }
	                    if ((c[c[p >> 2] >> 2] | 0) == 1 ? (c[(c[p >> 2] | 0) + 88 >> 2] | 0) == 45 : 0)break;
	                    if ((c[(c[s >> 2] | 0) + 24 >> 2] | 0) < (c[(c[t >> 2] | 0) + 24 >> 2] | 0)) {
	                        c[M >> 2] = 0;
	                        J = c[m >> 2] | 0;
	                        I = c[p >> 2] | 0;
	                        v = (c[n >> 2] | 0) == 0 ? 151424 : 151432;
	                        y = MD(c[p >> 2] | 0) | 0;
	                        CB(J, 1799, 0, I, 151984, v, y, YD(M, c[p >> 2] | 0) | 0, 0);
	                        if (c[M >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[M >> 2] | 0);
	                            c[M >> 2] = 0
	                        }
	                        c[l >> 2] = c[(c[m >> 2] | 0) + 16 >> 2];
	                        N = c[l >> 2] | 0;
	                        i = k;
	                        return N | 0
	                    }
	                } while (0);
	                c[l >> 2] = 0;
	                N = c[l >> 2] | 0;
	                i = k;
	                return N | 0
	            }

	            function VE(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                d = i;
	                i = i + 48 | 0;
	                e = d + 32 | 0;
	                f = d + 28 | 0;
	                g = d + 24 | 0;
	                h = d + 20 | 0;
	                j = d + 16 | 0;
	                k = d + 12 | 0;
	                l = d + 8 | 0;
	                m = d + 4 | 0;
	                n = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[j >> 2] = 0;
	                c[h >> 2] = c[(c[g >> 2] | 0) + 64 >> 2];
	                if ((c[(c[g >> 2] | 0) + 52 >> 2] | 0) != 4 ? (c[(c[g >> 2] | 0) + 52 >> 2] | 0) != 6 : 0) {
	                    if ((c[c[h >> 2] >> 2] | 0) != 5 ? (c[(c[h >> 2] | 0) + 88 >> 2] | 0) != 45 : 0) {
	                        c[k >> 2] = 0;
	                        b = c[f >> 2] | 0;
	                        a = c[g >> 2] | 0;
	                        o = c[(c[g >> 2] | 0) + 36 >> 2] | 0;
	                        GE(b, 3076, a, o, 153352, BB(k, c[(c[h >> 2] | 0) + 112 >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0) | 0);
	                        if (c[k >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                            c[k >> 2] = 0
	                        }
	                        c[e >> 2] = 3076;
	                        p = c[e >> 2] | 0;
	                        i = d;
	                        return p | 0
	                    }
	                } else {
	                    do if ((c[c[h >> 2] >> 2] | 0) != 4) {
	                        if ((c[c[h >> 2] >> 2] | 0) == 1 ? (c[(c[h >> 2] | 0) + 88 >> 2] | 0) != 45 : 0) {
	                            q = 11;
	                            break
	                        }
	                        if ((c[(c[h >> 2] | 0) + 52 >> 2] | 0) != 4 ? (c[(c[h >> 2] | 0) + 52 >> 2] | 0) != 6 : 0) {
	                            if ((c[(c[h >> 2] | 0) + 52 >> 2] | 0) == 3 ? (c[(c[g >> 2] | 0) + 48 >> 2] & 4 | 0) != 0 : 0) {
	                                if (!(FG(c[(c[h >> 2] | 0) + 28 >> 2] | 0) | 0)) {
	                                    c[j >> 2] = 3076;
	                                    break
	                                }
	                                if (c[(c[g >> 2] | 0) + 104 >> 2] | 0)break;
	                                c[m >> 2] = 0;
	                                k = c[f >> 2] | 0;
	                                o = c[g >> 2] | 0;
	                                GE(k, 3076, o, 0, 153664, BB(m, c[(c[h >> 2] | 0) + 112 >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0) | 0);
	                                if (c[m >> 2] | 0) {
	                                    zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                                    c[m >> 2] = 0
	                                }
	                                c[e >> 2] = 3076;
	                                p = c[e >> 2] | 0;
	                                i = d;
	                                return p | 0
	                            }
	                            c[j >> 2] = 3076;
	                            break
	                        }
	                        if (!(c[(c[h >> 2] | 0) + 104 >> 2] | 0)) {
	                            GE(c[f >> 2] | 0, 3069, c[g >> 2] | 0, 0, 153584, c[(c[g >> 2] | 0) + 8 >> 2] | 0);
	                            c[e >> 2] = -1;
	                            p = c[e >> 2] | 0;
	                            i = d;
	                            return p | 0
	                        }
	                    } else q = 11; while (0);
	                    if ((q | 0) == 11 ? (c[(c[g >> 2] | 0) + 48 >> 2] & 2 | 0) == 0 : 0) {
	                        c[l >> 2] = 0;
	                        q = c[f >> 2] | 0;
	                        m = c[g >> 2] | 0;
	                        GE(q, 3076, m, 0, 153464, BB(l, c[(c[h >> 2] | 0) + 112 >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0) | 0);
	                        if (c[l >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                            c[l >> 2] = 0
	                        }
	                        c[e >> 2] = 3076;
	                        p = c[e >> 2] | 0;
	                        i = d;
	                        return p | 0
	                    }
	                    if ((c[j >> 2] | 0) > 0) {
	                        c[n >> 2] = 0;
	                        l = (c[(c[g >> 2] | 0) + 48 >> 2] & 4 | 0) != 0;
	                        m = c[f >> 2] | 0;
	                        f = c[g >> 2] | 0;
	                        g = BB(n, c[(c[h >> 2] | 0) + 112 >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        if (l)GE(m, 3076, f, 0, 153800, g); else GE(m, 3076, f, 0, 153984, g);
	                        if (c[n >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                            c[n >> 2] = 0
	                        }
	                    }
	                }
	                c[e >> 2] = c[j >> 2];
	                p = c[e >> 2] | 0;
	                i = d;
	                return p | 0
	            }

	            function WE(a, b, d, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                j = i;
	                i = i + 48 | 0;
	                k = j + 32 | 0;
	                l = j + 28 | 0;
	                m = j + 24 | 0;
	                n = j + 20 | 0;
	                o = j + 16 | 0;
	                p = j + 12 | 0;
	                q = j + 8 | 0;
	                r = j + 4 | 0;
	                s = j;
	                c[l >> 2] = a;
	                c[m >> 2] = b;
	                c[n >> 2] = d;
	                c[o >> 2] = e;
	                c[p >> 2] = f;
	                c[q >> 2] = g;
	                c[r >> 2] = h;
	                c[s >> 2] = 0;
	                if ((c[l >> 2] | 0) == 0 | (c[m >> 2] | 0) == 0) {
	                    c[k >> 2] = 0;
	                    t = c[k >> 2] | 0;
	                    i = j;
	                    return t | 0
	                }
	                c[s >> 2] = Cb[c[135744 >> 2] & 511](120) | 0;
	                if (!(c[s >> 2] | 0)) {
	                    tC(c[l >> 2] | 0, 153304, 0);
	                    c[k >> 2] = 0;
	                    t = c[k >> 2] | 0;
	                    i = j;
	                    return t | 0
	                }
	                m = (c[s >> 2] | 0) + 0 | 0;
	                h = m + 120 | 0;
	                do {
	                    c[m >> 2] = 0;
	                    m = m + 4 | 0
	                } while ((m | 0) < (h | 0));
	                c[c[s >> 2] >> 2] = c[n >> 2];
	                c[(c[s >> 2] | 0) + 8 >> 2] = c[o >> 2];
	                c[(c[s >> 2] | 0) + 112 >> 2] = c[p >> 2];
	                c[(c[s >> 2] | 0) + 36 >> 2] = c[q >> 2];
	                q = c[l >> 2] | 0;
	                if (c[r >> 2] | 0) {
	                    do if (c[q + 100 >> 2] | 0) {
	                        r = GG(c[l >> 2] | 0, c[(c[l >> 2] | 0) + 116 >> 2] | 0, c[s >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0) | 0;
	                        c[(c[l >> 2] | 0) + 120 >> 2] = r;
	                        if (c[(c[l >> 2] | 0) + 120 >> 2] | 0) {
	                            c[(c[l >> 2] | 0) + 124 >> 2] = 0;
	                            break
	                        }
	                        zb[c[135736 >> 2] & 511](c[s >> 2] | 0);
	                        c[k >> 2] = 0;
	                        t = c[k >> 2] | 0;
	                        i = j;
	                        return t | 0
	                    } while (0);
	                    dG((c[(c[(c[l >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] | 0) + 44 | 0, 5, c[s >> 2] | 0) | 0
	                } else dG((c[(c[q + 28 >> 2] | 0) + 16 >> 2] | 0) + 48 | 0, 10, c[s >> 2] | 0) | 0;
	                dG((c[(c[l >> 2] | 0) + 28 >> 2] | 0) + 20 | 0, 10, c[s >> 2] | 0) | 0;
	                c[k >> 2] = c[s >> 2];
	                t = c[k >> 2] | 0;
	                i = j;
	                return t | 0
	            }

	            function XE(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                c[m >> 2] = Cb[c[135744 >> 2] & 511](28) | 0;
	                if (!(c[m >> 2] | 0)) {
	                    tC(c[h >> 2] | 0, 153120, 0);
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                } else {
	                    c[c[m >> 2] >> 2] = 25;
	                    c[(c[m >> 2] | 0) + 4 >> 2] = 0;
	                    c[(c[m >> 2] | 0) + 24 >> 2] = c[j >> 2];
	                    c[(c[m >> 2] | 0) + 16 >> 2] = c[k >> 2];
	                    c[(c[m >> 2] | 0) + 20 >> 2] = c[l >> 2];
	                    c[(c[m >> 2] | 0) + 8 >> 2] = 0;
	                    c[(c[m >> 2] | 0) + 12 >> 2] = 0;
	                    dG((c[(c[(c[h >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] | 0) + 48 | 0, 10, c[m >> 2] | 0) | 0;
	                    c[g >> 2] = c[m >> 2];
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                return 0
	            }

	            function YE(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = 0;
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                c[m >> 2] = Cb[c[135744 >> 2] & 511](20) | 0;
	                if (!(c[m >> 2] | 0)) {
	                    tC(c[h >> 2] | 0, 153080, 0);
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                j = c[m >> 2] | 0;
	                c[j + 0 >> 2] = 0;
	                c[j + 4 >> 2] = 0;
	                c[j + 8 >> 2] = 0;
	                c[j + 12 >> 2] = 0;
	                c[j + 16 >> 2] = 0;
	                c[c[m >> 2] >> 2] = c[k >> 2];
	                c[(c[m >> 2] | 0) + 16 >> 2] = c[l >> 2];
	                dG((c[(c[(c[h >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] | 0) + 48 | 0, 10, c[m >> 2] | 0) | 0;
	                if ((c[k >> 2] | 0) == 6 | (c[k >> 2] | 0) == 7)dG((c[(c[h >> 2] | 0) + 28 >> 2] | 0) + 20 | 0, 10, c[m >> 2] | 0) | 0;
	                c[g >> 2] = c[m >> 2];
	                n = c[g >> 2] | 0;
	                i = f;
	                return n | 0
	            }

	            function ZE(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                d = i;
	                i = i + 64 | 0;
	                e = d + 48 | 0;
	                f = d + 44 | 0;
	                g = d + 40 | 0;
	                h = d + 36 | 0;
	                j = d + 32 | 0;
	                k = d + 28 | 0;
	                l = d + 24 | 0;
	                m = d + 20 | 0;
	                n = d + 16 | 0;
	                o = d + 12 | 0;
	                p = d + 8 | 0;
	                q = d + 4 | 0;
	                r = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                c[m >> 2] = 0;
	                if (!(c[(c[g >> 2] | 0) + 64 >> 2] | 0)) {
	                    xB(c[f >> 2] | 0, 152632, 152664);
	                    c[e >> 2] = -1;
	                    s = c[e >> 2] | 0;
	                    i = d;
	                    return s | 0
	                }
	                c[h >> 2] = c[(c[g >> 2] | 0) + 64 >> 2];
	                if (((c[c[h >> 2] >> 2] | 0) != 1 ? (c[(c[h >> 2] | 0) + 48 >> 2] & 4194304 | 0) == 0 : 0) ? (KE(c[h >> 2] | 0, c[f >> 2] | 0) | 0) == -1 : 0) {
	                    c[e >> 2] = -1;
	                    s = c[e >> 2] | 0;
	                    i = d;
	                    return s | 0
	                }
	                c[k >> 2] = c[(c[g >> 2] | 0) + 116 >> 2];
	                c[l >> 2] = c[(c[h >> 2] | 0) + 116 >> 2];
	                do if (c[k >> 2] | 0) {
	                    b = c[f >> 2] | 0;
	                    a = c[g >> 2] | 0;
	                    t = (c[g >> 2] | 0) + 84 | 0;
	                    u = c[k >> 2] | 0;
	                    if (!(c[(c[g >> 2] | 0) + 48 >> 2] & 4)) {
	                        if ((IE(b, a, t, u, 0) | 0) != -1)break;
	                        xB(c[f >> 2] | 0, 152632, 152680);
	                        break
	                    }
	                    if ((IE(b, a, t, u, c[(c[f >> 2] | 0) + 128 >> 2] | 0) | 0) == -1)xB(c[f >> 2] | 0, 152632, 152680);
	                    if (c[(c[(c[f >> 2] | 0) + 128 >> 2] | 0) + 4 >> 2] | 0)c[m >> 2] = c[(c[f >> 2] | 0) + 128 >> 2]
	                } while (0);
	                a:do if (c[l >> 2] | 0) {
	                    if (!(c[(c[g >> 2] | 0) + 48 >> 2] & 4)) {
	                        c[n >> 2] = 0;
	                        while (1) {
	                            if ((c[n >> 2] | 0) >= (c[(c[l >> 2] | 0) + 4 >> 2] | 0)) {
	                                v = 45;
	                                break a
	                            }
	                            c[j >> 2] = c[(c[c[l >> 2] >> 2] | 0) + (c[n >> 2] << 2) >> 2];
	                            if (!(c[k >> 2] | 0)) {
	                                u = JB() | 0;
	                                c[(c[g >> 2] | 0) + 116 >> 2] = u;
	                                if (!(c[(c[g >> 2] | 0) + 116 >> 2] | 0))break a;
	                                c[k >> 2] = c[(c[g >> 2] | 0) + 116 >> 2]
	                            }
	                            pG(c[k >> 2] | 0, c[(c[l >> 2] | 0) + 4 >> 2] | 0, c[j >> 2] | 0) | 0;
	                            c[n >> 2] = (c[n >> 2] | 0) + 1
	                        }
	                    }
	                    if (c[k >> 2] | 0)c[q >> 2] = c[(c[k >> 2] | 0) + 4 >> 2]; else c[q >> 2] = 0;
	                    c[n >> 2] = 0;
	                    while (1) {
	                        if ((c[n >> 2] | 0) >= (c[(c[l >> 2] | 0) + 4 >> 2] | 0)) {
	                            v = 45;
	                            break a
	                        }
	                        c[j >> 2] = c[(c[c[l >> 2] >> 2] | 0) + (c[n >> 2] << 2) >> 2];
	                        b:do if (c[m >> 2] | 0) {
	                            c[o >> 2] = 0;
	                            while (1) {
	                                if ((c[o >> 2] | 0) >= (c[(c[m >> 2] | 0) + 4 >> 2] | 0)) {
	                                    v = 28;
	                                    break b
	                                }
	                                c[p >> 2] = c[(c[c[m >> 2] >> 2] | 0) + (c[o >> 2] << 2) >> 2];
	                                if ((c[(c[(c[j >> 2] | 0) + 12 >> 2] | 0) + 8 >> 2] | 0) == (c[(c[p >> 2] | 0) + 8 >> 2] | 0) ? (c[(c[(c[j >> 2] | 0) + 12 >> 2] | 0) + 56 >> 2] | 0) == (c[(c[p >> 2] | 0) + 12 >> 2] | 0) : 0)break b;
	                                c[o >> 2] = (c[o >> 2] | 0) + 1
	                            }
	                        } else v = 28; while (0);
	                        c:do if ((v | 0) == 28) {
	                            v = 0;
	                            d:do if (c[q >> 2] | 0) {
	                                c[o >> 2] = 0;
	                                while (1) {
	                                    if ((c[o >> 2] | 0) >= (c[q >> 2] | 0))break d;
	                                    c[r >> 2] = c[(c[c[k >> 2] >> 2] | 0) + (c[o >> 2] << 2) >> 2];
	                                    if ((c[(c[(c[j >> 2] | 0) + 12 >> 2] | 0) + 8 >> 2] | 0) == (c[(c[(c[r >> 2] | 0) + 12 >> 2] | 0) + 8 >> 2] | 0) ? (c[(c[(c[j >> 2] | 0) + 12 >> 2] | 0) + 56 >> 2] | 0) == (c[(c[(c[r >> 2] | 0) + 12 >> 2] | 0) + 56 >> 2] | 0) : 0)break c;
	                                    c[o >> 2] = (c[o >> 2] | 0) + 1
	                                }
	                            } while (0);
	                            if (!(c[k >> 2] | 0)) {
	                                u = JB() | 0;
	                                c[(c[g >> 2] | 0) + 116 >> 2] = u;
	                                if (!(c[(c[g >> 2] | 0) + 116 >> 2] | 0))break a;
	                                c[k >> 2] = c[(c[g >> 2] | 0) + 116 >> 2]
	                            }
	                            pG(c[k >> 2] | 0, 2, c[j >> 2] | 0) | 0
	                        } while (0);
	                        c[n >> 2] = (c[n >> 2] | 0) + 1
	                    }
	                } else v = 45; while (0);
	                e:do if ((v | 0) == 45) {
	                    if ((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 0 : 0) {
	                        oB(c[k >> 2] | 0);
	                        c[(c[g >> 2] | 0) + 116 >> 2] = 0
	                    }
	                    do if ((c[(c[g >> 2] | 0) + 48 >> 2] & 2 | 0) != 0 ? (c[(c[h >> 2] | 0) + 84 >> 2] | 0) != 0 : 0)if (c[(c[g >> 2] | 0) + 84 >> 2] | 0)if ((HG(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 84 >> 2] | 0, c[(c[h >> 2] | 0) + 84 >> 2] | 0) | 0) == -1)break e; else break; else {
	                        c[(c[g >> 2] | 0) + 84 >> 2] = c[(c[h >> 2] | 0) + 84 >> 2];
	                        break
	                    } while (0);
	                    c[e >> 2] = 0;
	                    s = c[e >> 2] | 0;
	                    i = d;
	                    return s | 0
	                } while (0);
	                c[e >> 2] = -1;
	                s = c[e >> 2] | 0;
	                i = d;
	                return s | 0
	            }

	            function _E(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = IG(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                if (c[h >> 2] | 0) {
	                    c[e >> 2] = c[h >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                b = c[f >> 2] | 0;
	                f = c[g >> 2] | 0;
	                if (c[(c[g >> 2] | 0) + 48 >> 2] & 2)c[h >> 2] = JG(b, f) | 0; else c[h >> 2] = KG(b, f) | 0;
	                c[e >> 2] = c[h >> 2];
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function $E(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0;
	                d = i;
	                i = i + 64 | 0;
	                e = d + 56 | 0;
	                f = d + 52 | 0;
	                g = d + 48 | 0;
	                h = d + 44 | 0;
	                j = d + 40 | 0;
	                k = d + 36 | 0;
	                l = d + 32 | 0;
	                m = d + 28 | 0;
	                n = d + 24 | 0;
	                o = d + 20 | 0;
	                p = d + 16 | 0;
	                q = d + 12 | 0;
	                r = d + 8 | 0;
	                s = d + 4 | 0;
	                t = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                c[j >> 2] = c[(c[g >> 2] | 0) + 28 >> 2];
	                if (c[(c[g >> 2] | 0) + 80 >> 2] | 0) {
	                    c[k >> 2] = c[(c[g >> 2] | 0) + 80 >> 2];
	                    rD(c[k >> 2] | 0, c[f >> 2] | 0);
	                    if (!(c[(c[g >> 2] | 0) + 48 >> 2] & 2)) {
	                        GE(c[f >> 2] | 0, 3046, c[g >> 2] | 0, 0, 158528, 0);
	                        c[h >> 2] = 3046
	                    }
	                    b = c[k >> 2] | 0;
	                    do if ((c[k >> 2] | 0) != (c[g >> 2] | 0))if (c[b + 80 >> 2] | 0) {
	                        c[l >> 2] = LG(c[k >> 2] | 0, c[k >> 2] | 0) | 0;
	                        break
	                    } else {
	                        c[l >> 2] = 0;
	                        break
	                    } else c[l >> 2] = b; while (0);
	                    if (c[l >> 2] | 0) {
	                        c[m >> 2] = 0;
	                        c[n >> 2] = 0;
	                        b = c[f >> 2] | 0;
	                        a = c[l >> 2] | 0;
	                        u = YD(m, c[l >> 2] | 0) | 0;
	                        oG(b, 3049, a, 0, 158608, u, YD(n, c[k >> 2] | 0) | 0, 0);
	                        if (c[m >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                            c[m >> 2] = 0
	                        }
	                        if (c[n >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                            c[n >> 2] = 0
	                        }
	                        c[h >> 2] = 3049
	                    }
	                    if ((c[j >> 2] | 0) != (c[(c[(c[g >> 2] | 0) + 80 >> 2] | 0) + 28 >> 2] | 0)) {
	                        c[o >> 2] = 0;
	                        if (c[(c[k >> 2] | 0) + 48 >> 2] & 32768)c[o >> 2] = c[o >> 2] | 2;
	                        if (c[(c[k >> 2] | 0) + 48 >> 2] & 65536)c[o >> 2] = c[o >> 2] | 1;
	                        if (MG(c[f >> 2] | 0, c[j >> 2] | 0, c[(c[k >> 2] | 0) + 28 >> 2] | 0, c[o >> 2] | 0) | 0) {
	                            c[p >> 2] = 0;
	                            c[q >> 2] = 0;
	                            c[r >> 2] = 0;
	                            c[h >> 2] = 3047;
	                            o = c[f >> 2] | 0;
	                            n = c[g >> 2] | 0;
	                            m = YD(p, c[j >> 2] | 0) | 0;
	                            u = YD(q, c[k >> 2] | 0) | 0;
	                            oG(o, 3047, n, 0, 158704, m, u, YD(r, c[(c[k >> 2] | 0) + 28 >> 2] | 0) | 0);
	                            if (c[p >> 2] | 0) {
	                                zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                                c[p >> 2] = 0
	                            }
	                            if (c[q >> 2] | 0) {
	                                zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                                c[q >> 2] = 0
	                            }
	                            if (c[r >> 2] | 0) {
	                                zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                                c[r >> 2] = 0
	                            }
	                        }
	                    }
	                }
	                do if (c[(c[g >> 2] | 0) + 76 >> 2] | 0) {
	                    if ((c[c[j >> 2] >> 2] | 0) != 4)if ((c[c[j >> 2] >> 2] | 0) == 1 ? (c[(c[j >> 2] | 0) + 88 >> 2] | 0) != 45 : 0)v = 31; else v = 32; else v = 31;
	                    if ((v | 0) == 31 ? (SE(c[j >> 2] | 0, 23) | 0) == 0 : 0)v = 32;
	                    if ((v | 0) == 32) {
	                        if ((c[c[j >> 2] >> 2] | 0) != 5 ? (c[(c[j >> 2] | 0) + 88 >> 2] | 0) != 45 : 0) {
	                            v = 38;
	                            break
	                        }
	                        if ((c[(c[j >> 2] | 0) + 52 >> 2] | 0) != 4 ? (c[(c[j >> 2] | 0) + 52 >> 2] | 0) != 6 : 0) {
	                            v = 38;
	                            break
	                        }
	                        if (!(SE(c[(c[j >> 2] | 0) + 104 >> 2] | 0, 23) | 0)) {
	                            v = 38;
	                            break
	                        }
	                    }
	                    c[h >> 2] = 3048;
	                    GE(c[f >> 2] | 0, 3048, c[g >> 2] | 0, 0, 158848, 0)
	                } else v = 38; while (0);
	                if ((v | 0) == 38 ? (c[(c[g >> 2] | 0) + 76 >> 2] | 0) != 0 : 0) {
	                    c[t >> 2] = 0;
	                    if (!(c[j >> 2] | 0)) {
	                        PC(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 36 >> 2] | 0, 3069, 159008, 0, 0);
	                        c[e >> 2] = -1;
	                        w = c[e >> 2] | 0;
	                        i = d;
	                        return w | 0
	                    }
	                    do if (c[(c[g >> 2] | 0) + 36 >> 2] | 0) {
	                        v = c[(c[g >> 2] | 0) + 36 >> 2] | 0;
	                        if (c[(c[g >> 2] | 0) + 48 >> 2] & 8) {
	                            c[t >> 2] = dj(v, 159120) | 0;
	                            break
	                        } else {
	                            c[t >> 2] = dj(v, 159128) | 0;
	                            break
	                        }
	                    } while (0);
	                    c[s >> 2] = NG(c[f >> 2] | 0, c[t >> 2] | 0, c[j >> 2] | 0, c[(c[g >> 2] | 0) + 76 >> 2] | 0, (c[g >> 2] | 0) + 96 | 0) | 0;
	                    if (c[s >> 2] | 0)if ((c[s >> 2] | 0) < 0) {
	                        xB(c[f >> 2] | 0, 159136, 159168);
	                        c[e >> 2] = -1;
	                        w = c[e >> 2] | 0;
	                        i = d;
	                        return w | 0
	                    } else {
	                        c[e >> 2] = c[s >> 2];
	                        w = c[e >> 2] | 0;
	                        i = d;
	                        return w | 0
	                    }
	                }
	                c[e >> 2] = c[h >> 2];
	                w = c[e >> 2] | 0;
	                i = d;
	                return w | 0
	            }

	            function aF(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 24 | 0;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                l = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[(c[f >> 2] | 0) + 80 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if (c[(c[f >> 2] | 0) + 48 >> 2] & 16) {
	                    i = d;
	                    return
	                }
	                c[g >> 2] = c[(c[f >> 2] | 0) + 80 >> 2];
	                while (1) {
	                    if (!(c[g >> 2] | 0))break;
	                    c[k >> 2] = 0;
	                    c[l >> 2] = 0;
	                    do if (!(c[(c[g >> 2] | 0) + 48 >> 2] & 8192)) {
	                        c[h >> 2] = c[(c[g >> 2] | 0) + 28 >> 2];
	                        c[j >> 2] = c[(c[f >> 2] | 0) + 28 >> 2];
	                        if ((c[h >> 2] | 0) != (c[j >> 2] | 0)) {
	                            if (c[(c[g >> 2] | 0) + 48 >> 2] & 4096)c[k >> 2] = c[k >> 2] | 524288;
	                            if (c[(c[g >> 2] | 0) + 48 >> 2] & 2048)c[k >> 2] = c[k >> 2] | 262144;
	                            while (1) {
	                                if (!(c[j >> 2] | 0))break;
	                                if ((c[j >> 2] | 0) == (c[h >> 2] | 0))break;
	                                if ((c[(c[j >> 2] | 0) + 48 >> 2] & 2 | 0) != 0 ? (c[l >> 2] & 524288 | 0) == 0 : 0)c[l >> 2] = c[l >> 2] | 262144;
	                                if ((c[(c[j >> 2] | 0) + 48 >> 2] & 4 | 0) != 0 ? (c[l >> 2] & 524288 | 0) == 0 : 0)c[l >> 2] = c[l >> 2] | 524288;
	                                c[j >> 2] = c[(c[j >> 2] | 0) + 64 >> 2]
	                            }
	                            c[j >> 2] = c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 64 >> 2];
	                            while (1) {
	                                if (!(c[j >> 2] | 0))break;
	                                if ((c[c[j >> 2] >> 2] | 0) != 5 ? (c[(c[j >> 2] | 0) + 88 >> 2] | 0) != 45 : 0)break;
	                                if ((c[(c[j >> 2] | 0) + 48 >> 2] & 262144 | 0) != 0 ? (c[k >> 2] & 262144 | 0) == 0 : 0)c[k >> 2] = c[k >> 2] | 262144;
	                                if ((c[(c[j >> 2] | 0) + 48 >> 2] & 524288 | 0) != 0 ? (c[k >> 2] & 524288 | 0) == 0 : 0)c[k >> 2] = c[k >> 2] | 524288;
	                                if ((c[j >> 2] | 0) == (c[h >> 2] | 0))break;
	                                c[j >> 2] = c[(c[j >> 2] | 0) + 64 >> 2]
	                            }
	                            if (c[k >> 2] | 0) {
	                                if ((c[k >> 2] & 262144 | 0) != 0 ? (c[l >> 2] & 262144 | 0) != 0 : 0)break;
	                                if ((c[k >> 2] & 524288 | 0) != 0 ? (c[l >> 2] & 524288 | 0) != 0 : 0)break
	                            }
	                        }
	                        OG(c[e >> 2] | 0, c[g >> 2] | 0, c[f >> 2] | 0) | 0;
	                        if (!(c[(c[g >> 2] | 0) + 48 >> 2] & 131072)) {
	                            b = (c[g >> 2] | 0) + 48 | 0;
	                            c[b >> 2] = c[b >> 2] | 131072
	                        }
	                    } while (0);
	                    c[g >> 2] = c[(c[g >> 2] | 0) + 80 >> 2]
	                }
	                i = d;
	                return
	            }

	            function bF(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0, J = 0, K = 0, L = 0, M = 0, N = 0, O = 0, P = 0, Q = 0, R = 0, S = 0, T = 0, U = 0, V = 0, W = 0;
	                d = i;
	                i = i + 128 | 0;
	                e = d + 124 | 0;
	                f = d + 120 | 0;
	                g = d + 116 | 0;
	                h = d + 112 | 0;
	                j = d + 108 | 0;
	                k = d + 104 | 0;
	                l = d + 100 | 0;
	                m = d + 96 | 0;
	                n = d + 92 | 0;
	                o = d + 88 | 0;
	                p = d + 84 | 0;
	                q = d + 80 | 0;
	                r = d + 76 | 0;
	                s = d + 72 | 0;
	                t = d + 68 | 0;
	                u = d + 64 | 0;
	                v = d + 60 | 0;
	                w = d + 56 | 0;
	                x = d + 52 | 0;
	                y = d + 48 | 0;
	                z = d + 44 | 0;
	                A = d + 40 | 0;
	                B = d + 36 | 0;
	                C = d + 32 | 0;
	                D = d + 28 | 0;
	                E = d + 24 | 0;
	                F = d + 20 | 0;
	                G = d + 16 | 0;
	                H = d + 12 | 0;
	                I = d + 8 | 0;
	                J = d + 4 | 0;
	                K = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                if (!(c[g >> 2] | 0)) {
	                    xB(c[f >> 2] | 0, 158112, 158144);
	                    c[e >> 2] = 1;
	                    L = c[e >> 2] | 0;
	                    i = d;
	                    return L | 0
	                }
	                if (!(c[(c[g >> 2] | 0) + 12 >> 2] | 0)) {
	                    c[e >> 2] = 1;
	                    L = c[e >> 2] | 0;
	                    i = d;
	                    return L | 0
	                }
	                a:do switch (c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2] | 0) {
	                    case 8:
	                    {
	                        c[h >> 2] = 1;
	                        c[I >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2];
	                        if (c[I >> 2] | 0) {
	                            c[h >> 2] = 0;
	                            c[G >> 2] = c[(c[f >> 2] | 0) + 76 >> 2];
	                            c[H >> 2] = Iz(c[(c[f >> 2] | 0) + 64 >> 2] | 0) | 0;
	                            Jz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0, c[H >> 2] | 0) | 0;
	                            c[(c[f >> 2] | 0) + 76 >> 2] = c[H >> 2];
	                            while (1) {
	                                if (!(c[I >> 2] | 0)) {
	                                    M = 103;
	                                    break
	                                }
	                                c[(c[f >> 2] | 0) + 76 >> 2] = c[H >> 2];
	                                c[J >> 2] = c[(c[I >> 2] | 0) + 12 >> 2];
	                                if (!(c[J >> 2] | 0)) {
	                                    M = 93;
	                                    break
	                                }
	                                do if (!(c[(c[J >> 2] | 0) + 48 >> 2] & 131072)) {
	                                    if ((c[(c[I >> 2] | 0) + 16 >> 2] | 0) == 1 ? (c[(c[I >> 2] | 0) + 20 >> 2] | 0) == 1 : 0) {
	                                        Hz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0, c[(c[J >> 2] | 0) + 8 >> 2] | 0, c[(c[J >> 2] | 0) + 52 >> 2] | 0, 1, 1, c[J >> 2] | 0) | 0;
	                                        break
	                                    }
	                                    if ((c[(c[I >> 2] | 0) + 16 >> 2] | 0) == 0 ? (c[(c[I >> 2] | 0) + 20 >> 2] | 0) == 1 : 0)Gz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0, c[(c[J >> 2] | 0) + 8 >> 2] | 0, c[(c[J >> 2] | 0) + 52 >> 2] | 0, 0, 1, c[J >> 2] | 0) | 0
	                                } else {
	                                    c[K >> 2] = Lz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[(c[I >> 2] | 0) + 16 >> 2] | 0, c[(c[I >> 2] | 0) + 20 >> 2] | 0) | 0;
	                                    QG(c[f >> 2] | 0, c[I >> 2] | 0, c[K >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0) | 0
	                                } while (0);
	                                c[I >> 2] = c[(c[I >> 2] | 0) + 8 >> 2]
	                            }
	                            if ((M | 0) == 93) {
	                                xB(c[f >> 2] | 0, 158112, 158168);
	                                c[e >> 2] = c[h >> 2];
	                                L = c[e >> 2] | 0;
	                                i = d;
	                                return L | 0
	                            } else if ((M | 0) == 103) {
	                                b = Kz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0, 0, 0) | 0;
	                                c[(c[f >> 2] | 0) + 76 >> 2] = b;
	                                if (c[(c[g >> 2] | 0) + 16 >> 2] | 0)break a;
	                                Jz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[G >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0) | 0;
	                                c[h >> 2] = 1;
	                                break a
	                            }
	                        }
	                        break
	                    }
	                    case 2:
	                    {
	                        c[m >> 2] = c[(c[g >> 2] | 0) + 12 >> 2];
	                        c[k >> 2] = c[(c[f >> 2] | 0) + 76 >> 2];
	                        c[l >> 2] = Iz(c[(c[f >> 2] | 0) + 64 >> 2] | 0) | 0;
	                        do if ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) == 1) {
	                            if ((c[(c[m >> 2] | 0) + 28 >> 2] | 0) == 1) {
	                                b = Ez(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[k >> 2] | 0, 0, 140432, 140432, c[m >> 2] | 0) | 0;
	                                c[(c[f >> 2] | 0) + 76 >> 2] = b;
	                                Jz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0, c[l >> 2] | 0) | 0;
	                                b = Ez(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[k >> 2] | 0, 0, 140432, 0, c[m >> 2] | 0) | 0;
	                                c[(c[f >> 2] | 0) + 76 >> 2] = b;
	                                Jz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0, c[l >> 2] | 0) | 0;
	                                break
	                            }
	                            b = c[m >> 2] | 0;
	                            if (c[(c[m >> 2] | 0) + 32 >> 2] | 0) {
	                                c[n >> 2] = c[b + 32 >> 2];
	                                do {
	                                    c[(c[f >> 2] | 0) + 76 >> 2] = c[k >> 2];
	                                    a = Ez(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0, 0, 140432, c[(c[n >> 2] | 0) + 4 >> 2] | 0, c[m >> 2] | 0) | 0;
	                                    c[(c[f >> 2] | 0) + 76 >> 2] = a;
	                                    Jz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0, c[l >> 2] | 0) | 0;
	                                    c[n >> 2] = c[c[n >> 2] >> 2]
	                                } while ((c[n >> 2] | 0) != 0)
	                            } else {
	                                if (!(c[b + 36 >> 2] | 0))break;
	                                a = Fz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, 140432, c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0, c[m >> 2] | 0) | 0;
	                                c[(c[f >> 2] | 0) + 76 >> 2] = a;
	                                break
	                            }
	                        } else {
	                            if ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) == 1073741824)N = 1073741824; else N = (c[(c[g >> 2] | 0) + 20 >> 2] | 0) - 1 | 0;
	                            c[q >> 2] = N;
	                            if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) < 1)O = 0; else O = (c[(c[g >> 2] | 0) + 16 >> 2] | 0) - 1 | 0;
	                            c[r >> 2] = O;
	                            c[o >> 2] = Lz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[r >> 2] | 0, c[q >> 2] | 0) | 0;
	                            c[p >> 2] = Iz(c[(c[f >> 2] | 0) + 64 >> 2] | 0) | 0;
	                            do if ((c[(c[m >> 2] | 0) + 28 >> 2] | 0) != 1) {
	                                a = c[m >> 2] | 0;
	                                if (c[(c[m >> 2] | 0) + 32 >> 2] | 0) {
	                                    c[n >> 2] = c[a + 32 >> 2];
	                                    do {
	                                        P = Ez(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[k >> 2] | 0, 0, 140432, c[(c[n >> 2] | 0) + 4 >> 2] | 0, c[m >> 2] | 0) | 0;
	                                        c[(c[f >> 2] | 0) + 76 >> 2] = P;
	                                        Jz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0, c[p >> 2] | 0) | 0;
	                                        c[n >> 2] = c[c[n >> 2] >> 2]
	                                    } while ((c[n >> 2] | 0) != 0)
	                                } else {
	                                    if (!(c[a + 36 >> 2] | 0))break;
	                                    P = Fz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[k >> 2] | 0, c[p >> 2] | 0, 140432, c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0, c[m >> 2] | 0) | 0;
	                                    c[(c[f >> 2] | 0) + 76 >> 2] = P;
	                                    break
	                                }
	                            } else {
	                                P = Ez(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[k >> 2] | 0, 0, 140432, 140432, c[m >> 2] | 0) | 0;
	                                c[(c[f >> 2] | 0) + 76 >> 2] = P;
	                                Jz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0, c[p >> 2] | 0) | 0;
	                                P = Ez(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[k >> 2] | 0, 0, 140432, 0, c[m >> 2] | 0) | 0;
	                                c[(c[f >> 2] | 0) + 76 >> 2] = P;
	                                Jz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0, c[p >> 2] | 0) | 0
	                            } while (0);
	                            Mz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[p >> 2] | 0, c[k >> 2] | 0, c[o >> 2] | 0) | 0;
	                            Nz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[p >> 2] | 0, c[l >> 2] | 0, c[o >> 2] | 0) | 0
	                        } while (0);
	                        if (!(c[(c[g >> 2] | 0) + 16 >> 2] | 0)) {
	                            Jz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0;
	                            c[h >> 2] = 1
	                        }
	                        c[(c[f >> 2] | 0) + 76 >> 2] = c[l >> 2];
	                        break
	                    }
	                    case 14:
	                    {
	                        c[h >> 2] = PG(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                        break
	                    }
	                    case 17:
	                    {
	                        c[h >> 2] = 1;
	                        break
	                    }
	                    case 7:
	                    {
	                        c[h >> 2] = 0;
	                        c[z >> 2] = c[(c[f >> 2] | 0) + 76 >> 2];
	                        c[A >> 2] = Iz(c[(c[f >> 2] | 0) + 64 >> 2] | 0) | 0;
	                        b = c[g >> 2] | 0;
	                        b:do if ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) != 1) {
	                            if ((c[b + 20 >> 2] | 0) == 1073741824)Q = 1073741824; else Q = (c[(c[g >> 2] | 0) + 20 >> 2] | 0) - 1 | 0;
	                            c[E >> 2] = Q;
	                            if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) < 1)R = 0; else R = (c[(c[g >> 2] | 0) + 16 >> 2] | 0) - 1 | 0;
	                            c[F >> 2] = R;
	                            c[B >> 2] = Lz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[F >> 2] | 0, c[E >> 2] | 0) | 0;
	                            c[C >> 2] = Iz(c[(c[f >> 2] | 0) + 64 >> 2] | 0) | 0;
	                            c[D >> 2] = Iz(c[(c[f >> 2] | 0) + 64 >> 2] | 0) | 0;
	                            c[y >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2];
	                            while (1) {
	                                if (!(c[y >> 2] | 0))break;
	                                c[(c[f >> 2] | 0) + 76 >> 2] = c[D >> 2];
	                                c[j >> 2] = bF(c[f >> 2] | 0, c[y >> 2] | 0) | 0;
	                                if ((c[j >> 2] | 0) == 1)c[h >> 2] = 1;
	                                Jz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0, c[C >> 2] | 0) | 0;
	                                c[y >> 2] = c[(c[y >> 2] | 0) + 8 >> 2]
	                            }
	                            Jz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[z >> 2] | 0, c[D >> 2] | 0) | 0;
	                            Mz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[C >> 2] | 0, c[D >> 2] | 0, c[B >> 2] | 0) | 0;
	                            Nz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[C >> 2] | 0, c[A >> 2] | 0, c[B >> 2] | 0) | 0;
	                            if ((c[h >> 2] | 0) == 1)Jz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[D >> 2] | 0, c[A >> 2] | 0) | 0
	                        } else {
	                            c[y >> 2] = c[(c[b + 12 >> 2] | 0) + 12 >> 2];
	                            while (1) {
	                                if (!(c[y >> 2] | 0))break b;
	                                c[(c[f >> 2] | 0) + 76 >> 2] = c[z >> 2];
	                                c[j >> 2] = bF(c[f >> 2] | 0, c[y >> 2] | 0) | 0;
	                                if ((c[j >> 2] | 0) == 1)c[h >> 2] = 1;
	                                Jz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0, c[A >> 2] | 0) | 0;
	                                c[y >> 2] = c[(c[y >> 2] | 0) + 8 >> 2]
	                            }
	                        } while (0);
	                        if (!(c[(c[g >> 2] | 0) + 16 >> 2] | 0)) {
	                            Jz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[z >> 2] | 0, c[A >> 2] | 0) | 0;
	                            c[h >> 2] = 1
	                        }
	                        c[(c[f >> 2] | 0) + 76 >> 2] = c[A >> 2];
	                        break
	                    }
	                    case 6:
	                    {
	                        c[h >> 2] = 1;
	                        if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) == 1 ? (c[(c[g >> 2] | 0) + 20 >> 2] | 0) == 1 : 0) {
	                            c[s >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2];
	                            while (1) {
	                                if (!(c[s >> 2] | 0))break a;
	                                c[j >> 2] = bF(c[f >> 2] | 0, c[s >> 2] | 0) | 0;
	                                if ((c[j >> 2] | 0) != 1)c[h >> 2] = 0;
	                                c[s >> 2] = c[(c[s >> 2] | 0) + 8 >> 2]
	                            }
	                        }
	                        c[t >> 2] = c[(c[f >> 2] | 0) + 76 >> 2];
	                        b = c[g >> 2] | 0;
	                        if ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) >= 1073741824) {
	                            P = (c[b + 16 >> 2] | 0) > 1;
	                            S = Jz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[t >> 2] | 0, 0) | 0;
	                            c[(c[f >> 2] | 0) + 76 >> 2] = S;
	                            c[t >> 2] = c[(c[f >> 2] | 0) + 76 >> 2];
	                            if (P) {
	                                c[v >> 2] = Lz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, (c[(c[g >> 2] | 0) + 16 >> 2] | 0) - 1 | 0, 1073741824) | 0;
	                                c[s >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2];
	                                while (1) {
	                                    T = c[f >> 2] | 0;
	                                    if (!(c[s >> 2] | 0))break;
	                                    c[j >> 2] = bF(T, c[s >> 2] | 0) | 0;
	                                    if ((c[j >> 2] | 0) != 1)c[h >> 2] = 0;
	                                    c[s >> 2] = c[(c[s >> 2] | 0) + 8 >> 2]
	                                }
	                                c[u >> 2] = c[T + 76 >> 2];
	                                Mz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[u >> 2] | 0, c[t >> 2] | 0, c[v >> 2] | 0) | 0;
	                                P = Nz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[u >> 2] | 0, 0, c[v >> 2] | 0) | 0;
	                                c[(c[f >> 2] | 0) + 76 >> 2] = P;
	                                if ((c[h >> 2] | 0) != 1)break a;
	                                Jz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[t >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0) | 0;
	                                break a
	                            } else {
	                                c[s >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2];
	                                while (1) {
	                                    U = c[f >> 2] | 0;
	                                    if (!(c[s >> 2] | 0))break;
	                                    c[j >> 2] = bF(U, c[s >> 2] | 0) | 0;
	                                    if ((c[j >> 2] | 0) != 1)c[h >> 2] = 0;
	                                    c[s >> 2] = c[(c[s >> 2] | 0) + 8 >> 2]
	                                }
	                                Jz(c[U + 64 >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0, c[t >> 2] | 0) | 0;
	                                P = Jz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0, 0) | 0;
	                                c[(c[f >> 2] | 0) + 76 >> 2] = P;
	                                if (c[(c[g >> 2] | 0) + 16 >> 2] | 0)break a;
	                                Jz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[t >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0) | 0;
	                                c[h >> 2] = 1;
	                                break a
	                            }
	                        }
	                        if ((c[b + 20 >> 2] | 0) <= 1 ? (c[(c[g >> 2] | 0) + 16 >> 2] | 0) <= 1 : 0) {
	                            c[s >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2];
	                            while (1) {
	                                V = c[f >> 2] | 0;
	                                if (!(c[s >> 2] | 0))break;
	                                c[j >> 2] = bF(V, c[s >> 2] | 0) | 0;
	                                if ((c[j >> 2] | 0) != 1)c[h >> 2] = 0;
	                                c[s >> 2] = c[(c[s >> 2] | 0) + 8 >> 2]
	                            }
	                            b = Jz(c[V + 64 >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0, 0) | 0;
	                            c[(c[f >> 2] | 0) + 76 >> 2] = b;
	                            if (c[(c[g >> 2] | 0) + 16 >> 2] | 0)break a;
	                            Jz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[t >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0) | 0;
	                            c[h >> 2] = 1;
	                            break a
	                        }
	                        b = Jz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[t >> 2] | 0, 0) | 0;
	                        c[(c[f >> 2] | 0) + 76 >> 2] = b;
	                        c[t >> 2] = c[(c[f >> 2] | 0) + 76 >> 2];
	                        c[x >> 2] = Lz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, (c[(c[g >> 2] | 0) + 16 >> 2] | 0) - 1 | 0, (c[(c[g >> 2] | 0) + 20 >> 2] | 0) - 1 | 0) | 0;
	                        c[s >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2];
	                        while (1) {
	                            W = c[f >> 2] | 0;
	                            if (!(c[s >> 2] | 0))break;
	                            c[j >> 2] = bF(W, c[s >> 2] | 0) | 0;
	                            if ((c[j >> 2] | 0) != 1)c[h >> 2] = 0;
	                            c[s >> 2] = c[(c[s >> 2] | 0) + 8 >> 2]
	                        }
	                        c[w >> 2] = c[W + 76 >> 2];
	                        Mz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[w >> 2] | 0, c[t >> 2] | 0, c[x >> 2] | 0) | 0;
	                        b = Nz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[w >> 2] | 0, 0, c[x >> 2] | 0) | 0;
	                        c[(c[f >> 2] | 0) + 76 >> 2] = b;
	                        if ((c[h >> 2] | 0) == 1 ? 1 : (c[(c[g >> 2] | 0) + 16 >> 2] | 0) == 0) {
	                            Jz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[t >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0) | 0;
	                            c[h >> 2] = 1
	                        }
	                        break
	                    }
	                    default:
	                    {
	                        b = c[f >> 2] | 0;
	                        yC(b, 158112, 158200, MD(c[(c[g >> 2] | 0) + 12 >> 2] | 0) | 0, 0);
	                        c[e >> 2] = c[h >> 2];
	                        L = c[e >> 2] | 0;
	                        i = d;
	                        return L | 0
	                    }
	                } while (0);
	                c[e >> 2] = c[h >> 2];
	                L = c[e >> 2] | 0;
	                i = d;
	                return L | 0
	            }

	            function cF(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                a = c[e >> 2] | 0;
	                if ((c[(c[e >> 2] | 0) + 96 >> 2] | 0) > (c[(c[e >> 2] | 0) + 104 >> 2] | 0)) {
	                    xB(a, 155664, 155696);
	                    c[d >> 2] = 0;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                a:do if (c[a + 100 >> 2] | 0) {
	                    j = c[e >> 2] | 0;
	                    if ((c[(c[e >> 2] | 0) + 104 >> 2] | 0) > (c[(c[e >> 2] | 0) + 96 >> 2] | 0)) {
	                        c[f >> 2] = c[(c[(c[e >> 2] | 0) + 100 >> 2] | 0) + (c[j + 96 >> 2] << 2) >> 2];
	                        break
	                    }
	                    c[g >> 2] = c[j + 104 >> 2];
	                    j = (c[e >> 2] | 0) + 104 | 0;
	                    c[j >> 2] = c[j >> 2] << 1;
	                    j = Hb[c[135760 >> 2] & 511](c[(c[e >> 2] | 0) + 100 >> 2] | 0, c[(c[e >> 2] | 0) + 104 >> 2] << 2) | 0;
	                    c[(c[e >> 2] | 0) + 100 >> 2] = j;
	                    if (!(c[(c[e >> 2] | 0) + 100 >> 2] | 0)) {
	                        IB(c[e >> 2] | 0, 155768, 0);
	                        c[d >> 2] = 0;
	                        h = c[d >> 2] | 0;
	                        i = b;
	                        return h | 0
	                    } else while (1) {
	                        if ((c[g >> 2] | 0) >= (c[(c[e >> 2] | 0) + 104 >> 2] | 0))break a;
	                        c[(c[(c[e >> 2] | 0) + 100 >> 2] | 0) + (c[g >> 2] << 2) >> 2] = 0;
	                        c[g >> 2] = (c[g >> 2] | 0) + 1
	                    }
	                } else {
	                    j = Cb[c[135744 >> 2] & 511](40) | 0;
	                    c[(c[e >> 2] | 0) + 100 >> 2] = j;
	                    j = c[e >> 2] | 0;
	                    if (c[(c[e >> 2] | 0) + 100 >> 2] | 0) {
	                        k = (c[j + 100 >> 2] | 0) + 0 | 0;
	                        l = k + 40 | 0;
	                        do {
	                            c[k >> 2] = 0;
	                            k = k + 4 | 0
	                        } while ((k | 0) < (l | 0));
	                        c[(c[e >> 2] | 0) + 104 >> 2] = 10;
	                        break
	                    }
	                    IB(j, 155728, 0);
	                    c[d >> 2] = 0;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                } while (0);
	                do if (c[f >> 2] | 0) {
	                    if (c[(c[f >> 2] | 0) + 12 >> 2] | 0) {
	                        xB(c[e >> 2] | 0, 155664, 155840);
	                        c[d >> 2] = 0;
	                        h = c[d >> 2] | 0;
	                        i = b;
	                        return h | 0
	                    }
	                } else {
	                    c[f >> 2] = Cb[c[135744 >> 2] & 511](84) | 0;
	                    if (c[f >> 2] | 0) {
	                        c[(c[(c[e >> 2] | 0) + 100 >> 2] | 0) + (c[(c[e >> 2] | 0) + 96 >> 2] << 2) >> 2] = c[f >> 2];
	                        break
	                    }
	                    IB(c[e >> 2] | 0, 155808, 0);
	                    c[d >> 2] = 0;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                } while (0);
	                k = (c[f >> 2] | 0) + 0 | 0;
	                l = k + 84 | 0;
	                do {
	                    c[k >> 2] = 0;
	                    k = k + 4 | 0
	                } while ((k | 0) < (l | 0));
	                c[c[f >> 2] >> 2] = 1;
	                c[(c[f >> 2] | 0) + 48 >> 2] = c[(c[e >> 2] | 0) + 96 >> 2];
	                c[d >> 2] = c[f >> 2];
	                h = c[d >> 2] | 0;
	                i = b;
	                return h | 0
	            }

	            function dF(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                do if (!(c[(c[e >> 2] | 0) + 164 >> 2] | 0)) {
	                    a = Cb[c[135744 >> 2] & 511](4) | 0;
	                    c[(c[e >> 2] | 0) + 164 >> 2] = a;
	                    c[(c[e >> 2] | 0) + 172 >> 2] = 1;
	                    if (!(c[(c[e >> 2] | 0) + 164 >> 2] | 0)) {
	                        IB(c[e >> 2] | 0, 145800, 0);
	                        c[d >> 2] = 0;
	                        g = c[d >> 2] | 0;
	                        i = b;
	                        return g | 0
	                    }
	                } else {
	                    a = c[e >> 2] | 0;
	                    if ((c[(c[e >> 2] | 0) + 172 >> 2] | 0) <= (c[(c[e >> 2] | 0) + 168 >> 2] | 0)) {
	                        h = a + 172 | 0;
	                        c[h >> 2] = (c[h >> 2] | 0) + 1;
	                        h = Hb[c[135760 >> 2] & 511](c[(c[e >> 2] | 0) + 164 >> 2] | 0, c[(c[e >> 2] | 0) + 172 >> 2] << 2) | 0;
	                        c[(c[e >> 2] | 0) + 164 >> 2] = h;
	                        if (c[(c[e >> 2] | 0) + 164 >> 2] | 0)break;
	                        IB(c[e >> 2] | 0, 145832, 0);
	                        c[d >> 2] = 0;
	                        g = c[d >> 2] | 0;
	                        i = b;
	                        return g | 0
	                    }
	                    h = a + 168 | 0;
	                    a = c[h >> 2] | 0;
	                    c[h >> 2] = a + 1;
	                    c[f >> 2] = c[(c[(c[e >> 2] | 0) + 164 >> 2] | 0) + (a << 2) >> 2];
	                    if (c[(c[f >> 2] | 0) + 12 >> 2] | 0) {
	                        xB(c[e >> 2] | 0, 145872, 145904);
	                        c[d >> 2] = 0;
	                        g = c[d >> 2] | 0;
	                        i = b;
	                        return g | 0
	                    } else {
	                        c[c[f >> 2] >> 2] = 2;
	                        c[d >> 2] = c[f >> 2];
	                        g = c[d >> 2] | 0;
	                        i = b;
	                        return g | 0
	                    }
	                } while (0);
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](60) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    IB(c[e >> 2] | 0, 145928, 0);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    a = (c[f >> 2] | 0) + 0 | 0;
	                    h = a + 60 | 0;
	                    do {
	                        c[a >> 2] = 0;
	                        a = a + 4 | 0
	                    } while ((a | 0) < (h | 0));
	                    c[c[f >> 2] >> 2] = 2;
	                    a = c[f >> 2] | 0;
	                    h = (c[e >> 2] | 0) + 168 | 0;
	                    j = c[h >> 2] | 0;
	                    c[h >> 2] = j + 1;
	                    c[(c[(c[e >> 2] | 0) + 164 >> 2] | 0) + (j << 2) >> 2] = a;
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function eF(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0;
	                b = i;
	                i = i + 48 | 0;
	                e = b + 32 | 0;
	                f = b + 28 | 0;
	                g = b + 24 | 0;
	                h = b + 20 | 0;
	                j = b + 16 | 0;
	                k = b + 12 | 0;
	                l = b + 8 | 0;
	                m = b + 4 | 0;
	                n = b;
	                c[f >> 2] = a;
	                c[j >> 2] = 0;
	                c[l >> 2] = 0;
	                c[m >> 2] = 0;
	                c[n >> 2] = RG(c[f >> 2] | 0, 3) | 0;
	                if (!(c[n >> 2] | 0))c[n >> 2] = RG(c[f >> 2] | 0, 4) | 0;
	                if (!(c[n >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    o = c[e >> 2] | 0;
	                    i = b;
	                    return o | 0
	                }
	                c[g >> 2] = c[(c[n >> 2] | 0) + 20 >> 2];
	                do {
	                    if ((c[(c[n >> 2] | 0) + 48 >> 2] | 0) == 3) {
	                        while (1) {
	                            do if ((d[c[g >> 2] >> 0] | 0 | 0) == 32)p = 1; else {
	                                if (9 <= (d[c[g >> 2] >> 0] | 0 | 0) ? (d[c[g >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                    p = 1;
	                                    break
	                                }
	                                p = (d[c[g >> 2] >> 0] | 0 | 0) == 13
	                            } while (0);
	                            q = c[g >> 2] | 0;
	                            if (!p)break;
	                            c[g >> 2] = q + 1
	                        }
	                        c[h >> 2] = q;
	                        while (1) {
	                            if (d[c[h >> 2] >> 0] | 0) {
	                                do if ((d[c[h >> 2] >> 0] | 0 | 0) == 32)r = 1; else {
	                                    if (9 <= (d[c[h >> 2] >> 0] | 0 | 0) ? (d[c[h >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                        r = 1;
	                                        break
	                                    }
	                                    r = (d[c[h >> 2] >> 0] | 0 | 0) == 13
	                                } while (0);
	                                s = r ^ 1
	                            } else s = 0;
	                            t = c[h >> 2] | 0;
	                            if (!s)break;
	                            c[h >> 2] = t + 1
	                        }
	                        if ((t | 0) == (c[g >> 2] | 0))break;
	                        c[l >> 2] = (c[l >> 2] | 0) + 1;
	                        c[j >> 2] = AP(c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 60 >> 2] | 0, c[g >> 2] | 0, (c[h >> 2] | 0) - (c[g >> 2] | 0) | 0) | 0;
	                        c[g >> 2] = c[h >> 2]
	                    }
	                    while (1) {
	                        do if ((d[c[g >> 2] >> 0] | 0 | 0) == 32)u = 1; else {
	                            if (9 <= (d[c[g >> 2] >> 0] | 0 | 0) ? (d[c[g >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                u = 1;
	                                break
	                            }
	                            u = (d[c[g >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        v = c[g >> 2] | 0;
	                        if (!u)break;
	                        c[g >> 2] = v + 1
	                    }
	                    c[h >> 2] = v;
	                    while (1) {
	                        if (d[c[h >> 2] >> 0] | 0) {
	                            do if ((d[c[h >> 2] >> 0] | 0 | 0) == 32)w = 1; else {
	                                if (9 <= (d[c[h >> 2] >> 0] | 0 | 0) ? (d[c[h >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                    w = 1;
	                                    break
	                                }
	                                w = (d[c[h >> 2] >> 0] | 0 | 0) == 13
	                            } while (0);
	                            x = w ^ 1
	                        } else x = 0;
	                        y = c[h >> 2] | 0;
	                        if (!x)break;
	                        c[h >> 2] = y + 1
	                    }
	                    if ((y | 0) == (c[g >> 2] | 0)) {
	                        z = 40;
	                        break
	                    }
	                    c[l >> 2] = (c[l >> 2] | 0) + 1;
	                    c[k >> 2] = AP(c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 60 >> 2] | 0, c[g >> 2] | 0, (c[h >> 2] | 0) - (c[g >> 2] | 0) | 0) | 0;
	                    c[g >> 2] = c[h >> 2];
	                    c[m >> 2] = SG(c[f >> 2] | 0, c[(c[f >> 2] | 0) + 20 >> 2] | 0, c[(c[n >> 2] | 0) + 4 >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                    if ((c[m >> 2] | 0) == -1) {
	                        z = 43;
	                        break
	                    }
	                } while ((d[c[g >> 2] >> 0] | 0 | 0) != 0);
	                if ((z | 0) == 40) {
	                    if ((c[(c[n >> 2] | 0) + 48 >> 2] | 0) == 3)NC(c[f >> 2] | 0, 1879, c[(c[n >> 2] | 0) + 4 >> 2] | 0, 0, 155136, 0, 0, 0)
	                } else if ((z | 0) == 43) {
	                    xB(c[f >> 2] | 0, 155224, 155248);
	                    c[e >> 2] = -1;
	                    o = c[e >> 2] | 0;
	                    i = b;
	                    return o | 0
	                }
	                c[e >> 2] = c[m >> 2];
	                o = c[e >> 2] | 0;
	                i = b;
	                return o | 0
	            }

	            function fF(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                b = i;
	                i = i + 96 | 0;
	                d = b + 80 | 0;
	                e = b + 76 | 0;
	                f = b + 72 | 0;
	                g = b + 68 | 0;
	                h = b + 64 | 0;
	                j = b + 60 | 0;
	                k = b + 56 | 0;
	                l = b + 16 | 0;
	                m = b + 8 | 0;
	                n = b + 4 | 0;
	                o = b;
	                c[e >> 2] = a;
	                c[h >> 2] = 0;
	                a = c[e >> 2] | 0;
	                if ((c[(c[e >> 2] | 0) + 96 >> 2] | 0) <= 0) {
	                    xB(a, 154576, 154608);
	                    c[d >> 2] = -1;
	                    p = c[d >> 2] | 0;
	                    i = b;
	                    return p | 0
	                }
	                c[f >> 2] = c[(c[(c[e >> 2] | 0) + 100 >> 2] | 0) + ((c[a + 96 >> 2] | 0) - 1 << 2) >> 2];
	                if (c[(c[f >> 2] | 0) + 32 >> 2] & 32) {
	                    a = (c[f >> 2] | 0) + 32 | 0;
	                    c[a >> 2] = c[a >> 2] ^ 32
	                }
	                a:do if (c[(c[f >> 2] | 0) + 32 >> 2] & 4) {
	                    c[(c[e >> 2] | 0) + 108 >> 2] = c[(c[(c[e >> 2] | 0) + 100 >> 2] | 0) + ((c[(c[e >> 2] | 0) + 96 >> 2] | 0) - 1 << 2) >> 2];
	                    c[h >> 2] = 1848;
	                    AB(c[e >> 2] | 0, c[h >> 2] | 0, 0, 0, 154648, 0, 0);
	                    c[(c[e >> 2] | 0) + 108 >> 2] = c[(c[(c[e >> 2] | 0) + 100 >> 2] | 0) + (c[(c[e >> 2] | 0) + 96 >> 2] << 2) >> 2]
	                } else {
	                    c[g >> 2] = c[(c[f >> 2] | 0) + 28 >> 2];
	                    if ((c[(c[g >> 2] | 0) + 88 >> 2] | 0) == 45) {
	                        a = yE(c[(c[e >> 2] | 0) + 20 >> 2] | 0, c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 16 >> 2] | 0) | 0;
	                        c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 44 >> 2] = a;
	                        do if (!(c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 44 >> 2] | 0)) {
	                            c[j >> 2] = RG(c[e >> 2] | 0, 1) | 0;
	                            if (!(c[j >> 2] | 0)) {
	                                a = IH(45) | 0;
	                                c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 28 >> 2] = a;
	                                break
	                            }
	                            c[h >> 2] = TG(c[e >> 2] | 0, c[j >> 2] | 0, (c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 28 | 0, 0) | 0;
	                            if (c[h >> 2] | 0)if ((c[h >> 2] | 0) == -1) {
	                                xB(c[e >> 2] | 0, 154576, 154504);
	                                c[d >> 2] = -1;
	                                p = c[d >> 2] | 0;
	                                i = b;
	                                return p | 0
	                            } else {
	                                c[d >> 2] = c[h >> 2];
	                                p = c[d >> 2] | 0;
	                                i = b;
	                                return p | 0
	                            }
	                        } while (0);
	                        c[d >> 2] = 0;
	                        p = c[d >> 2] | 0;
	                        i = b;
	                        return p | 0
	                    }
	                    b:do switch (c[(c[g >> 2] | 0) + 52 >> 2] | 0) {
	                        case 2:
	                        case 3:
	                        {
	                            c[n >> 2] = 10;
	                            if (!(c[(c[g >> 2] | 0) + 108 >> 2] | 0)) {
	                                xB(c[e >> 2] | 0, 154576, 154808);
	                                c[d >> 2] = -1;
	                                p = c[d >> 2] | 0;
	                                i = b;
	                                return p | 0
	                            }
	                            if (c[(c[f >> 2] | 0) + 32 >> 2] & 256) {
	                                xB(c[e >> 2] | 0, 154576, 154856);
	                                c[d >> 2] = -1;
	                                p = c[d >> 2] | 0;
	                                i = b;
	                                return p | 0
	                            }
	                            c[k >> 2] = c[(c[f >> 2] | 0) + 60 >> 2];
	                            do if (!(c[k >> 2] | 0)) {
	                                c[k >> 2] = oz(c[(c[g >> 2] | 0) + 108 >> 2] | 0, 358, c[e >> 2] | 0) | 0;
	                                if (c[k >> 2] | 0) {
	                                    c[(c[f >> 2] | 0) + 60 >> 2] = c[k >> 2];
	                                    break
	                                }
	                                xB(c[e >> 2] | 0, 154576, 141760);
	                                c[d >> 2] = -1;
	                                p = c[d >> 2] | 0;
	                                i = b;
	                                return p | 0
	                            } while (0);
	                            c[h >> 2] = rz(c[k >> 2] | 0, c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 16 >> 2] | 0, c[(c[e >> 2] | 0) + 108 >> 2] | 0) | 0;
	                            if ((c[(c[e >> 2] | 0) + 52 >> 2] | 0) == 1818) {
	                                xB(c[e >> 2] | 0, 154576, 154912);
	                                c[d >> 2] = -1;
	                                p = c[d >> 2] | 0;
	                                i = b;
	                                return p | 0
	                            }
	                            if ((c[h >> 2] | 0) < 0) {
	                                tz(c[k >> 2] | 0, 0, n, o, l, m) | 0;
	                                mF(c[e >> 2] | 0, 1871, 0, 0, 154944, c[n >> 2] | 0, c[o >> 2] | 0, l);
	                                c[h >> 2] = c[(c[e >> 2] | 0) + 52 >> 2];
	                                break a
	                            } else {
	                                c[h >> 2] = 0;
	                                break b
	                            }
	                            break
	                        }
	                        case 1:
	                        {
	                            c[(c[e >> 2] | 0) + 108 >> 2] = c[(c[(c[e >> 2] | 0) + 100 >> 2] | 0) + ((c[(c[e >> 2] | 0) + 96 >> 2] | 0) - 1 << 2) >> 2];
	                            c[h >> 2] = 1841;
	                            AB(c[e >> 2] | 0, c[h >> 2] | 0, 0, 0, 154736, 0, 0);
	                            c[(c[e >> 2] | 0) + 108 >> 2] = c[(c[(c[e >> 2] | 0) + 100 >> 2] | 0) + (c[(c[e >> 2] | 0) + 96 >> 2] << 2) >> 2];
	                            break a;
	                            break
	                        }
	                        case 6:
	                        case 4:
	                        {
	                            c[(c[e >> 2] | 0) + 108 >> 2] = c[(c[(c[e >> 2] | 0) + 100 >> 2] | 0) + ((c[(c[e >> 2] | 0) + 96 >> 2] | 0) - 1 << 2) >> 2];
	                            if ((c[c[g >> 2] >> 2] | 0) != 5 ? (c[(c[g >> 2] | 0) + 88 >> 2] | 0) != 45 : 0) {
	                                c[h >> 2] = 1828;
	                                AB(c[e >> 2] | 0, c[h >> 2] | 0, 0, 0, 155064, 0, 0)
	                            } else {
	                                c[h >> 2] = 1842;
	                                AB(c[e >> 2] | 0, c[h >> 2] | 0, 0, 0, 154976, 0, 0)
	                            }
	                            c[(c[e >> 2] | 0) + 108 >> 2] = c[(c[(c[e >> 2] | 0) + 100 >> 2] | 0) + (c[(c[e >> 2] | 0) + 96 >> 2] << 2) >> 2];
	                            c[h >> 2] = c[(c[e >> 2] | 0) + 52 >> 2];
	                            break a;
	                            break
	                        }
	                        default:
	                        {
	                        }
	                    } while (0);
	                    c[d >> 2] = c[h >> 2];
	                    p = c[d >> 2] | 0;
	                    i = b;
	                    return p | 0
	                } while (0);
	                c[(c[e >> 2] | 0) + 176 >> 2] = c[(c[e >> 2] | 0) + 96 >> 2];
	                g = (c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 32 | 0;
	                c[g >> 2] = c[g >> 2] | 512;
	                g = (c[f >> 2] | 0) + 32 | 0;
	                c[g >> 2] = c[g >> 2] | 256;
	                c[d >> 2] = c[h >> 2];
	                p = c[d >> 2] | 0;
	                i = b;
	                return p | 0
	            }

	            function gF(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = c[(c[(c[f >> 2] | 0) + 108 >> 2] | 0) + 44 >> 2];
	                if (!((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) ? (c[c[h >> 2] >> 2] | 0) == 2 : 0) {
	                    c[c[g >> 2] >> 2] = 0;
	                    if ((c[(c[h >> 2] | 0) + 24 >> 2] | 0) == 1) {
	                        c[c[g >> 2] >> 2] = 1;
	                        c[e >> 2] = 0;
	                        l = c[e >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    }
	                    c[j >> 2] = 0;
	                    c[j >> 2] = yE(c[(c[f >> 2] | 0) + 20 >> 2] | 0, c[(c[(c[f >> 2] | 0) + 108 >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[f >> 2] | 0) + 108 >> 2] | 0) + 16 >> 2] | 0) | 0;
	                    if (c[j >> 2] | 0) {
	                        c[(c[(c[f >> 2] | 0) + 108 >> 2] | 0) + 44 >> 2] = c[j >> 2];
	                        c[e >> 2] = 0;
	                        l = c[e >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    }
	                    j = c[f >> 2] | 0;
	                    if ((c[(c[h >> 2] | 0) + 24 >> 2] | 0) == 3) {
	                        AB(j, 1845, 0, 0, 154416, 0, 0);
	                        c[e >> 2] = c[(c[f >> 2] | 0) + 52 >> 2];
	                        l = c[e >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    }
	                    if ((c[j + 168 >> 2] | 0) != 0 ? (c[k >> 2] = RG(c[f >> 2] | 0, 1) | 0, (c[k >> 2] | 0) != 0) : 0)if ((TG(c[f >> 2] | 0, c[k >> 2] | 0, (c[(c[f >> 2] | 0) + 108 >> 2] | 0) + 28 | 0, 0) | 0) == -1) {
	                        xB(c[f >> 2] | 0, 154368, 154504);
	                        c[e >> 2] = -1;
	                        l = c[e >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    } else {
	                        c[e >> 2] = 0;
	                        l = c[e >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    }
	                    k = IH(45) | 0;
	                    c[(c[(c[f >> 2] | 0) + 108 >> 2] | 0) + 28 >> 2] = k;
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                xB(c[f >> 2] | 0, 154368, 154400);
	                c[e >> 2] = -1;
	                l = c[e >> 2] | 0;
	                i = d;
	                return l | 0
	            }

	            function hF(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 24 | 0;
	                e = b + 20 | 0;
	                f = b + 16 | 0;
	                g = b + 12 | 0;
	                h = b + 8 | 0;
	                j = b + 4 | 0;
	                k = b;
	                c[e >> 2] = a;
	                c[f >> 2] = c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 44 >> 2];
	                if (!(c[f >> 2] | 0)) {
	                    AB(c[e >> 2] | 0, 1845, 0, 0, 146200, 0, 0);
	                    c[d >> 2] = c[(c[e >> 2] | 0) + 52 >> 2];
	                    l = c[d >> 2] | 0;
	                    i = b;
	                    return l | 0
	                }
	                c[g >> 2] = c[(c[f >> 2] | 0) + 28 >> 2];
	                if (c[(c[f >> 2] | 0) + 48 >> 2] & 16) {
	                    AB(c[e >> 2] | 0, 1846, 0, 0, 146240, 0, 0);
	                    c[d >> 2] = c[(c[e >> 2] | 0) + 52 >> 2];
	                    l = c[d >> 2] | 0;
	                    i = b;
	                    return l | 0
	                }
	                a = c[e >> 2] | 0;
	                if (!(c[g >> 2] | 0)) {
	                    AB(a, 1875, 0, 0, 145096, 0, 0);
	                    c[d >> 2] = 1875;
	                    l = c[d >> 2] | 0;
	                    i = b;
	                    return l | 0
	                }
	                do if (c[a + 168 >> 2] | 0) {
	                    c[j >> 2] = RG(c[e >> 2] | 0, 2) | 0;
	                    do if (c[j >> 2] | 0) {
	                        c[(c[e >> 2] | 0) + 108 >> 2] = c[j >> 2];
	                        m = c[e >> 2] | 0;
	                        n = IH(15) | 0;
	                        c[h >> 2] = yB(m, 0, n, c[(c[j >> 2] | 0) + 20 >> 2] | 0, (c[j >> 2] | 0) + 24 | 0, 1, 0, 0) | 0;
	                        c[(c[e >> 2] | 0) + 108 >> 2] = c[(c[(c[e >> 2] | 0) + 100 >> 2] | 0) + (c[(c[e >> 2] | 0) + 96 >> 2] << 2) >> 2];
	                        if ((c[h >> 2] | 0) < 0) {
	                            xB(c[e >> 2] | 0, 146280, 146312);
	                            c[d >> 2] = -1;
	                            l = c[d >> 2] | 0;
	                            i = b;
	                            return l | 0
	                        }
	                        if (!(c[h >> 2] | 0)) {
	                            if (!(c[(c[f >> 2] | 0) + 48 >> 2] & 1)) {
	                                AB(c[e >> 2] | 0, 1847, 0, 0, 146392, 0, 0);
	                                break
	                            }
	                            if (MH(c[(c[j >> 2] | 0) + 24 >> 2] | 0) | 0) {
	                                if ((c[(c[f >> 2] | 0) + 48 >> 2] & 8 | 0) != 0 ? (c[(c[f >> 2] | 0) + 76 >> 2] | 0) != 0 : 0) {
	                                    AB(c[e >> 2] | 0, 1849, 0, 0, 146424, 0, 0);
	                                    break
	                                }
	                                n = (c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 32 | 0;
	                                c[n >> 2] = c[n >> 2] | 4
	                            }
	                        }
	                    } while (0);
	                    c[j >> 2] = RG(c[e >> 2] | 0, 1) | 0;
	                    if (c[j >> 2] | 0) {
	                        c[k >> 2] = 0;
	                        c[h >> 2] = TG(c[e >> 2] | 0, c[j >> 2] | 0, k, c[f >> 2] | 0) | 0;
	                        if ((c[h >> 2] | 0) != 0 & (c[h >> 2] | 0) == -1) {
	                            xB(c[e >> 2] | 0, 146280, 146512);
	                            c[d >> 2] = -1;
	                            l = c[d >> 2] | 0;
	                            i = b;
	                            return l | 0
	                        } else {
	                            if (!(c[k >> 2] | 0))break;
	                            n = (c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 32 | 0;
	                            c[n >> 2] = c[n >> 2] | 8;
	                            c[g >> 2] = c[k >> 2];
	                            break
	                        }
	                    }
	                } while (0);
	                if ((c[(c[f >> 2] | 0) + 100 >> 2] | 0) != 0 ? (UG(c[e >> 2] | 0, c[f >> 2] | 0) | 0) == -1 : 0) {
	                    c[d >> 2] = -1;
	                    l = c[d >> 2] | 0;
	                    i = b;
	                    return l | 0
	                }
	                if (!(c[g >> 2] | 0)) {
	                    AB(c[e >> 2] | 0, 1875, 0, 0, 145096, 0, 0);
	                    c[d >> 2] = 1875;
	                    l = c[d >> 2] | 0;
	                    i = b;
	                    return l | 0
	                } else {
	                    c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 28 >> 2] = c[g >> 2];
	                    c[d >> 2] = 0;
	                    l = c[d >> 2] | 0;
	                    i = b;
	                    return l | 0
	                }
	                return 0
	            }

	            function iF(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                d = i;
	                i = i + 48 | 0;
	                e = d + 36 | 0;
	                f = d + 32 | 0;
	                g = d + 28 | 0;
	                h = d + 24 | 0;
	                j = d + 20 | 0;
	                k = d + 16 | 0;
	                l = d + 12 | 0;
	                m = d + 8 | 0;
	                n = d + 4 | 0;
	                o = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[j >> 2] = 0;
	                c[m >> 2] = 0;
	                c[n >> 2] = c[(c[f >> 2] | 0) + 96 >> 2];
	                if (!(c[(c[f >> 2] | 0) + 116 >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    p = c[e >> 2] | 0;
	                    i = d;
	                    return p | 0
	                }
	                if ((c[g >> 2] | 0) == 2)c[n >> 2] = (c[n >> 2] | 0) + 1;
	                c[k >> 2] = c[(c[f >> 2] | 0) + 116 >> 2];
	                c[h >> 2] = c[k >> 2];
	                a:while (1) {
	                    if ((c[h >> 2] | 0) == (c[j >> 2] | 0)) {
	                        q = 34;
	                        break
	                    }
	                    b = c[(c[h >> 2] | 0) + 32 >> 2] | 0;
	                    a = c[(c[(c[f >> 2] | 0) + 108 >> 2] | 0) + 12 >> 2] | 0;
	                    r = c[(c[(c[f >> 2] | 0) + 108 >> 2] | 0) + 16 >> 2] | 0;
	                    if ((c[g >> 2] | 0) == 1)c[l >> 2] = HQ(b, a, r) | 0; else c[l >> 2] = JQ(b, a, r) | 0;
	                    if ((c[l >> 2] | 0) == -1) {
	                        q = 11;
	                        break
	                    }
	                    b:do if (c[l >> 2] | 0) {
	                        if (c[(c[h >> 2] | 0) + 12 >> 2] | 0) {
	                            if ((c[(c[h >> 2] | 0) + 20 >> 2] | 0) <= (c[(c[h >> 2] | 0) + 16 >> 2] | 0) ? (r = (c[h >> 2] | 0) + 20 | 0, c[r >> 2] = c[r >> 2] << 1, r = Hb[c[135760 >> 2] & 511](c[(c[h >> 2] | 0) + 12 >> 2] | 0, c[(c[h >> 2] | 0) + 20 >> 2] << 2) | 0, c[(c[h >> 2] | 0) + 12 >> 2] = r, (c[(c[h >> 2] | 0) + 12 >> 2] | 0) == 0) : 0) {
	                                q = 19;
	                                break a
	                            }
	                        } else {
	                            r = Cb[c[135744 >> 2] & 511](20) | 0;
	                            c[(c[h >> 2] | 0) + 12 >> 2] = r;
	                            if (!(c[(c[h >> 2] | 0) + 12 >> 2] | 0)) {
	                                q = 15;
	                                break a
	                            }
	                            c[(c[h >> 2] | 0) + 20 >> 2] = 5
	                        }
	                        r = c[n >> 2] | 0;
	                        a = (c[h >> 2] | 0) + 16 | 0;
	                        b = c[a >> 2] | 0;
	                        c[a >> 2] = b + 1;
	                        c[(c[(c[h >> 2] | 0) + 12 >> 2] | 0) + (b << 2) >> 2] = r;
	                        r = c[h >> 2] | 0;
	                        if ((c[c[h >> 2] >> 2] | 0) == 1) {
	                            c[o >> 2] = c[(c[(c[(c[r + 24 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) + 28 >> 2];
	                            while (1) {
	                                if (!(c[o >> 2] | 0))break b;
	                                if ((VG(c[f >> 2] | 0, c[(c[h >> 2] | 0) + 24 >> 2] | 0, c[o >> 2] | 0, 2) | 0) == -1) {
	                                    q = 24;
	                                    break a
	                                }
	                                c[o >> 2] = c[c[o >> 2] >> 2]
	                            }
	                        }
	                        if ((c[r >> 2] | 0) == 2) {
	                            if ((c[m >> 2] | 0) == 0 ? (c[(c[(c[f >> 2] | 0) + 108 >> 2] | 0) + 32 >> 2] & 16 | 0) == 0 : 0) {
	                                b = (c[(c[f >> 2] | 0) + 108 >> 2] | 0) + 32 | 0;
	                                c[b >> 2] = c[b >> 2] | 16
	                            }
	                            c[m >> 2] = (c[m >> 2] | 0) + 1
	                        }
	                    } while (0);
	                    if (!(c[(c[h >> 2] | 0) + 4 >> 2] | 0)) {
	                        c[j >> 2] = c[k >> 2];
	                        c[h >> 2] = c[(c[f >> 2] | 0) + 116 >> 2];
	                        continue
	                    } else {
	                        c[h >> 2] = c[(c[h >> 2] | 0) + 4 >> 2];
	                        continue
	                    }
	                }
	                if ((q | 0) == 11) {
	                    xB(c[f >> 2] | 0, 145960, 145984);
	                    c[e >> 2] = -1;
	                    p = c[e >> 2] | 0;
	                    i = d;
	                    return p | 0
	                } else if ((q | 0) == 15) {
	                    IB(0, 146008, 0);
	                    c[e >> 2] = -1;
	                    p = c[e >> 2] | 0;
	                    i = d;
	                    return p | 0
	                } else if ((q | 0) == 19) {
	                    IB(0, 146048, 0);
	                    c[e >> 2] = -1;
	                    p = c[e >> 2] | 0;
	                    i = d;
	                    return p | 0
	                } else if ((q | 0) == 24) {
	                    c[e >> 2] = -1;
	                    p = c[e >> 2] | 0;
	                    i = d;
	                    return p | 0
	                } else if ((q | 0) == 34) {
	                    c[e >> 2] = c[m >> 2];
	                    p = c[e >> 2] | 0;
	                    i = d;
	                    return p | 0
	                }
	                return 0
	            }

	            function jF(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0;
	                b = i;
	                i = i + 128 | 0;
	                e = b;
	                f = b + 100 | 0;
	                g = b + 96 | 0;
	                h = b + 92 | 0;
	                j = b + 88 | 0;
	                k = b + 84 | 0;
	                l = b + 80 | 0;
	                m = b + 76 | 0;
	                n = b + 72 | 0;
	                o = b + 68 | 0;
	                p = b + 64 | 0;
	                q = b + 60 | 0;
	                r = b + 56 | 0;
	                s = b + 52 | 0;
	                t = b + 48 | 0;
	                u = b + 44 | 0;
	                v = b + 40 | 0;
	                w = b + 36 | 0;
	                x = b + 32 | 0;
	                y = b + 28 | 0;
	                z = b + 24 | 0;
	                A = b + 20 | 0;
	                B = b + 16 | 0;
	                C = b + 104 | 0;
	                D = b + 12 | 0;
	                E = b + 8 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = c[(c[(c[g >> 2] | 0) + 108 >> 2] | 0) + 28 >> 2];
	                c[k >> 2] = 0;
	                c[l >> 2] = 0;
	                c[t >> 2] = 0;
	                c[v >> 2] = 0;
	                c[x >> 2] = 0;
	                c[j >> 2] = c[(c[h >> 2] | 0) + 116 >> 2];
	                c[r >> 2] = c[(c[g >> 2] | 0) + 168 >> 2];
	                if (c[j >> 2] | 0)c[s >> 2] = c[(c[j >> 2] | 0) + 4 >> 2]; else c[s >> 2] = 0;
	                c[o >> 2] = 0;
	                a:while (1) {
	                    if ((c[o >> 2] | 0) >= (c[s >> 2] | 0)) {
	                        F = 26;
	                        break
	                    }
	                    c[q >> 2] = 0;
	                    c[k >> 2] = c[(c[c[j >> 2] >> 2] | 0) + (c[o >> 2] << 2) >> 2];
	                    c[l >> 2] = c[(c[k >> 2] | 0) + 12 >> 2];
	                    c[p >> 2] = 0;
	                    while (1) {
	                        if ((c[p >> 2] | 0) >= (c[r >> 2] | 0))break;
	                        c[m >> 2] = c[(c[(c[g >> 2] | 0) + 164 >> 2] | 0) + (c[p >> 2] << 2) >> 2];
	                        if ((((c[(c[m >> 2] | 0) + 48 >> 2] | 0) == 0 ? (d[c[(c[m >> 2] | 0) + 12 >> 2] >> 0] | 0 | 0) == (d[c[(c[l >> 2] | 0) + 8 >> 2] >> 0] | 0 | 0) : 0) ? (qy(c[(c[m >> 2] | 0) + 12 >> 2] | 0, c[(c[l >> 2] | 0) + 8 >> 2] | 0) | 0) != 0 : 0) ? (qy(c[(c[m >> 2] | 0) + 16 >> 2] | 0, c[(c[l >> 2] | 0) + 56 >> 2] | 0) | 0) != 0 : 0) {
	                            F = 12;
	                            break
	                        }
	                        c[p >> 2] = (c[p >> 2] | 0) + 1
	                    }
	                    if ((F | 0) == 12) {
	                        F = 0;
	                        c[q >> 2] = 1;
	                        c[(c[m >> 2] | 0) + 44 >> 2] = 2;
	                        c[(c[m >> 2] | 0) + 40 >> 2] = c[k >> 2];
	                        c[(c[m >> 2] | 0) + 36 >> 2] = c[l >> 2];
	                        c[(c[m >> 2] | 0) + 28 >> 2] = c[(c[l >> 2] | 0) + 48 >> 2]
	                    }
	                    do if (!(c[q >> 2] | 0)) {
	                        if ((c[(c[k >> 2] | 0) + 24 >> 2] | 0) == 1) {
	                            c[n >> 2] = dF(c[g >> 2] | 0) | 0;
	                            if (!(c[n >> 2] | 0)) {
	                                F = 17;
	                                break a
	                            }
	                            c[(c[n >> 2] | 0) + 44 >> 2] = 4;
	                            c[(c[n >> 2] | 0) + 40 >> 2] = c[k >> 2];
	                            c[(c[n >> 2] | 0) + 36 >> 2] = c[l >> 2];
	                            break
	                        }
	                        if ((c[(c[k >> 2] | 0) + 24 >> 2] | 0) == 2) {
	                            if ((c[(c[k >> 2] | 0) + 28 >> 2] | 0) == 0 ? (c[(c[l >> 2] | 0) + 44 >> 2] | 0) == 0 : 0)break;
	                            c[n >> 2] = dF(c[g >> 2] | 0) | 0;
	                            if (!(c[n >> 2] | 0)) {
	                                F = 23;
	                                break a
	                            }
	                            c[(c[n >> 2] | 0) + 44 >> 2] = 8;
	                            c[(c[n >> 2] | 0) + 40 >> 2] = c[k >> 2];
	                            c[(c[n >> 2] | 0) + 36 >> 2] = c[l >> 2];
	                            c[(c[n >> 2] | 0) + 28 >> 2] = c[(c[l >> 2] | 0) + 48 >> 2];
	                            c[(c[n >> 2] | 0) + 12 >> 2] = c[(c[l >> 2] | 0) + 8 >> 2];
	                            c[(c[n >> 2] | 0) + 16 >> 2] = c[(c[l >> 2] | 0) + 56 >> 2]
	                        }
	                    } while (0);
	                    c[o >> 2] = (c[o >> 2] | 0) + 1
	                }
	                if ((F | 0) == 17) {
	                    xB(c[g >> 2] | 0, 145272, 145304);
	                    c[f >> 2] = -1;
	                    G = c[f >> 2] | 0;
	                    i = b;
	                    return G | 0
	                } else if ((F | 0) == 23) {
	                    xB(c[g >> 2] | 0, 145272, 145304);
	                    c[f >> 2] = -1;
	                    G = c[f >> 2] | 0;
	                    i = b;
	                    return G | 0
	                } else if ((F | 0) == 26) {
	                    if (!(c[(c[g >> 2] | 0) + 168 >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        G = c[f >> 2] | 0;
	                        i = b;
	                        return G | 0
	                    }
	                    b:do if (c[(c[h >> 2] | 0) + 84 >> 2] | 0) {
	                        c[o >> 2] = 0;
	                        while (1) {
	                            if ((c[o >> 2] | 0) >= (c[r >> 2] | 0))break b;
	                            c[m >> 2] = c[(c[(c[g >> 2] | 0) + 164 >> 2] | 0) + (c[o >> 2] << 2) >> 2];
	                            c:do if ((c[(c[m >> 2] | 0) + 44 >> 2] | 0) == 1 ? (DG(c[(c[h >> 2] | 0) + 84 >> 2] | 0, c[(c[m >> 2] | 0) + 16 >> 2] | 0) | 0) == 0 : 0) {
	                                if ((c[(c[(c[h >> 2] | 0) + 84 >> 2] | 0) + 24 >> 2] | 0) == 1) {
	                                    c[(c[m >> 2] | 0) + 44 >> 2] = 13;
	                                    break
	                                }
	                                l = BE(c[(c[g >> 2] | 0) + 20 >> 2] | 0, c[(c[m >> 2] | 0) + 12 >> 2] | 0, c[(c[m >> 2] | 0) + 16 >> 2] | 0) | 0;
	                                c[(c[m >> 2] | 0) + 36 >> 2] = l;
	                                if (!(c[(c[m >> 2] | 0) + 36 >> 2] | 0)) {
	                                    l = (c[m >> 2] | 0) + 44 | 0;
	                                    if ((c[(c[(c[h >> 2] | 0) + 84 >> 2] | 0) + 24 >> 2] | 0) == 2) {
	                                        c[l >> 2] = 14;
	                                        break
	                                    } else {
	                                        c[l >> 2] = 10;
	                                        break
	                                    }
	                                }
	                                c[(c[m >> 2] | 0) + 44 >> 2] = 2;
	                                c[(c[m >> 2] | 0) + 28 >> 2] = c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 48 >> 2];
	                                if (SE(c[(c[m >> 2] | 0) + 28 >> 2] | 0, 23) | 0) {
	                                    if (c[v >> 2] | 0) {
	                                        c[(c[m >> 2] | 0) + 44 >> 2] = 15;
	                                        l = c[33976] | 0;
	                                        n = c[33980] | 0;
	                                        c[e >> 2] = 140328;
	                                        c[e + 4 >> 2] = 25406;
	                                        Db[l & 511](n, 140296, e);
	                                        break
	                                    }
	                                    c[v >> 2] = (c[v >> 2] | 0) + 1;
	                                    if (c[j >> 2] | 0) {
	                                        c[p >> 2] = 0;
	                                        while (1) {
	                                            if ((c[p >> 2] | 0) >= (c[(c[j >> 2] | 0) + 4 >> 2] | 0))break c;
	                                            if (SE(c[(c[(c[(c[c[j >> 2] >> 2] | 0) + (c[p >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0) + 48 >> 2] | 0, 23) | 0)break;
	                                            c[p >> 2] = (c[p >> 2] | 0) + 1
	                                        }
	                                        c[(c[m >> 2] | 0) + 44 >> 2] = 16;
	                                        n = c[33976] | 0;
	                                        l = c[33980] | 0;
	                                        c[e >> 2] = 140328;
	                                        c[e + 4 >> 2] = 25424;
	                                        Db[n & 511](l, 140296, e)
	                                    }
	                                }
	                            } while (0);
	                            c[o >> 2] = (c[o >> 2] | 0) + 1
	                        }
	                    } while (0);
	                    if (!(c[(c[g >> 2] | 0) + 168 >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        G = c[f >> 2] | 0;
	                        i = b;
	                        return G | 0
	                    }
	                    if ((((c[(c[g >> 2] | 0) + 80 >> 2] & 1 | 0) != 0 ? (c[y >> 2] = c[(c[(c[g >> 2] | 0) + 100 >> 2] | 0) + (c[(c[g >> 2] | 0) + 96 >> 2] << 2) >> 2], (c[y >> 2] | 0) != 0) : 0) ? (c[(c[y >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) ? (c[(c[(c[y >> 2] | 0) + 4 >> 2] | 0) + 32 >> 2] | 0) != 0 : 0)c[x >> 2] = c[(c[y >> 2] | 0) + 4 >> 2];
	                    c[o >> 2] = 0;
	                    d:while (1) {
	                        if ((c[o >> 2] | 0) >= (c[(c[g >> 2] | 0) + 168 >> 2] | 0)) {
	                            F = 124;
	                            break
	                        }
	                        c[m >> 2] = c[(c[(c[g >> 2] | 0) + 164 >> 2] | 0) + (c[o >> 2] << 2) >> 2];
	                        if (!((c[(c[m >> 2] | 0) + 44 >> 2] | 0) != 2 ? (c[(c[m >> 2] | 0) + 44 >> 2] | 0) != 8 : 0))F = 60;
	                        do if ((F | 0) == 60) {
	                            F = 0;
	                            y = c[m >> 2] | 0;
	                            if (!(c[(c[m >> 2] | 0) + 28 >> 2] | 0)) {
	                                c[y + 44 >> 2] = 6;
	                                break
	                            }
	                            c[(c[g >> 2] | 0) + 108 >> 2] = y;
	                            c[w >> 2] = 0;
	                            c[t >> 2] = 0;
	                            if ((c[(c[g >> 2] | 0) + 116 >> 2] | 0) != 0 ? (c[t >> 2] = iF(c[g >> 2] | 0, 2) | 0, (c[t >> 2] | 0) == -1) : 0) {
	                                F = 64;
	                                break d
	                            }
	                            e:do if ((c[(c[m >> 2] | 0) + 44 >> 2] | 0) == 8) {
	                                if ((c[t >> 2] | 0) != 0 | (c[x >> 2] | 0) != 0) {
	                                    y = c[m >> 2] | 0;
	                                    if (c[(c[(c[m >> 2] | 0) + 40 >> 2] | 0) + 28 >> 2] | 0) {
	                                        c[(c[m >> 2] | 0) + 20 >> 2] = c[(c[y + 40 >> 2] | 0) + 28 >> 2];
	                                        c[(c[m >> 2] | 0) + 24 >> 2] = c[(c[(c[m >> 2] | 0) + 40 >> 2] | 0) + 32 >> 2]
	                                    } else {
	                                        c[(c[m >> 2] | 0) + 20 >> 2] = c[(c[y + 36 >> 2] | 0) + 44 >> 2];
	                                        c[(c[m >> 2] | 0) + 24 >> 2] = c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 68 >> 2]
	                                    }
	                                    if (!(c[(c[m >> 2] | 0) + 24 >> 2] | 0)) {
	                                        F = 71;
	                                        break d
	                                    }
	                                    y = WH(c[(c[m >> 2] | 0) + 24 >> 2] | 0) | 0;
	                                    c[(c[m >> 2] | 0) + 24 >> 2] = y;
	                                    if (!(c[(c[m >> 2] | 0) + 24 >> 2] | 0)) {
	                                        F = 73;
	                                        break d
	                                    }
	                                }
	                                if (c[x >> 2] | 0) {
	                                    c[A >> 2] = c[(c[m >> 2] | 0) + 20 >> 2];
	                                    c[z >> 2] = zC(c[(c[m >> 2] | 0) + 28 >> 2] | 0, c[(c[m >> 2] | 0) + 20 >> 2] | 0) | 0;
	                                    if (c[z >> 2] | 0)c[A >> 2] = c[z >> 2];
	                                    y = c[x >> 2] | 0;
	                                    if (!(c[(c[m >> 2] | 0) + 16 >> 2] | 0)) {
	                                        if (!($h(y, c[(c[m >> 2] | 0) + 12 >> 2] | 0, c[A >> 2] | 0) | 0)) {
	                                            F = 79;
	                                            break d
	                                        }
	                                    } else {
	                                        c[B >> 2] = Ri(c[y + 32 >> 2] | 0, c[x >> 2] | 0, c[(c[m >> 2] | 0) + 16 >> 2] | 0) | 0;
	                                        if (!(c[B >> 2] | 0)) {
	                                            c[D >> 2] = 0;
	                                            do {
	                                                y = c[D >> 2] | 0;
	                                                c[D >> 2] = y + 1;
	                                                c[e >> 2] = y;
	                                                JT(C, 12, 145464, e) | 0;
	                                                c[B >> 2] = cj(c[(c[x >> 2] | 0) + 32 >> 2] | 0, c[x >> 2] | 0, C) | 0;
	                                                if ((c[D >> 2] | 0) > 1e3) {
	                                                    F = 84;
	                                                    break d
	                                                }
	                                            } while ((c[B >> 2] | 0) != 0);
	                                            c[B >> 2] = Ih(c[(c[g >> 2] | 0) + 84 >> 2] | 0, c[(c[m >> 2] | 0) + 16 >> 2] | 0, C) | 0
	                                        }
	                                        ai(c[x >> 2] | 0, c[B >> 2] | 0, c[(c[m >> 2] | 0) + 12 >> 2] | 0, c[A >> 2] | 0) | 0
	                                    }
	                                    if (c[z >> 2] | 0)zb[c[135736 >> 2] & 511](c[z >> 2] | 0)
	                                }
	                            } else {
	                                if (c[(c[g >> 2] | 0) + 72 >> 2] | 0) {
	                                    PH(c[(c[g >> 2] | 0) + 72 >> 2] | 0);
	                                    c[(c[g >> 2] | 0) + 72 >> 2] = 0
	                                }
	                                do if (c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 60 >> 2] & 512)F = 96; else {
	                                    if ((c[(c[m >> 2] | 0) + 40 >> 2] | 0) != 0 ? (c[(c[(c[m >> 2] | 0) + 40 >> 2] | 0) + 16 >> 2] & 512 | 0) != 0 : 0) {
	                                        F = 96;
	                                        break
	                                    }
	                                    c[w >> 2] = 0
	                                } while (0);
	                                if ((F | 0) == 96) {
	                                    F = 0;
	                                    c[w >> 2] = 1
	                                }
	                                if ((c[t >> 2] | 0) != 0 | (c[w >> 2] | 0) != 0) {
	                                    y = (c[m >> 2] | 0) + 32 | 0;
	                                    c[y >> 2] = c[y >> 2] | 16;
	                                    c[u >> 2] = yB(c[g >> 2] | 0, c[(c[m >> 2] | 0) + 4 >> 2] | 0, c[(c[m >> 2] | 0) + 28 >> 2] | 0, c[(c[m >> 2] | 0) + 20 >> 2] | 0, (c[m >> 2] | 0) + 24 | 0, 1, 1, 0) | 0
	                                } else c[u >> 2] = yB(c[g >> 2] | 0, c[(c[m >> 2] | 0) + 4 >> 2] | 0, c[(c[m >> 2] | 0) + 28 >> 2] | 0, c[(c[m >> 2] | 0) + 20 >> 2] | 0, 0, 1, 0, 0) | 0;
	                                if (c[u >> 2] | 0) {
	                                    if ((c[u >> 2] | 0) == -1) {
	                                        F = 103;
	                                        break d
	                                    }
	                                    c[(c[m >> 2] | 0) + 44 >> 2] = 5;
	                                    break
	                                }
	                                if (c[w >> 2] | 0) {
	                                    if (!(c[(c[m >> 2] | 0) + 24 >> 2] | 0)) {
	                                        y = c[33976] | 0;
	                                        p = c[33980] | 0;
	                                        c[e >> 2] = 140328;
	                                        c[e + 4 >> 2] = 25678;
	                                        Db[y & 511](p, 140296, e);
	                                        break
	                                    }
	                                    do if (c[(c[m >> 2] | 0) + 40 >> 2] | 0) {
	                                        if (!(c[(c[(c[m >> 2] | 0) + 40 >> 2] | 0) + 28 >> 2] | 0))break;
	                                        if (!(c[(c[(c[m >> 2] | 0) + 40 >> 2] | 0) + 32 >> 2] | 0)) {
	                                            p = c[33976] | 0;
	                                            y = c[33980] | 0;
	                                            c[e >> 2] = 140328;
	                                            c[e + 4 >> 2] = 25685;
	                                            Db[p & 511](y, 140296, e);
	                                            break e
	                                        }
	                                        c[(c[m >> 2] | 0) + 52 >> 2] = c[(c[(c[m >> 2] | 0) + 40 >> 2] | 0) + 28 >> 2];
	                                        if (VD(c[(c[m >> 2] | 0) + 24 >> 2] | 0, c[(c[(c[m >> 2] | 0) + 40 >> 2] | 0) + 32 >> 2] | 0) | 0)break e;
	                                        c[(c[m >> 2] | 0) + 44 >> 2] = 7;
	                                        break e
	                                    } while (0);
	                                    if (!(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 68 >> 2] | 0)) {
	                                        y = c[33976] | 0;
	                                        p = c[33980] | 0;
	                                        c[e >> 2] = 140328;
	                                        c[e + 4 >> 2] = 25700;
	                                        Db[y & 511](p, 140296, e);
	                                        break
	                                    }
	                                    c[(c[m >> 2] | 0) + 52 >> 2] = c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 44 >> 2];
	                                    if (VD(c[(c[m >> 2] | 0) + 24 >> 2] | 0, c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 68 >> 2] | 0) | 0)break;
	                                    c[(c[m >> 2] | 0) + 44 >> 2] = 7
	                                }
	                            } while (0);
	                            p = c[g >> 2] | 0;
	                            if (c[t >> 2] | 0)if ((pF(p, (c[(c[g >> 2] | 0) + 96 >> 2] | 0) + 1 | 0) | 0) == -1) {
	                                F = 120;
	                                break d
	                            } else break;
	                            if (c[p + 116 >> 2] | 0)WG(c[g >> 2] | 0) | 0
	                        } while (0);
	                        c[o >> 2] = (c[o >> 2] | 0) + 1
	                    }
	                    if ((F | 0) == 64)xB(c[g >> 2] | 0, 145272, 145160); else if ((F | 0) == 71)xB(c[g >> 2] | 0, 145272, 145344); else if ((F | 0) == 73)xB(c[g >> 2] | 0, 145272, 145408); else if ((F | 0) == 79) {
	                        xB(c[g >> 2] | 0, 145272, 145440);
	                        if (c[z >> 2] | 0)zb[c[135736 >> 2] & 511](c[z >> 2] | 0)
	                    } else if ((F | 0) == 84) {
	                        xB(c[g >> 2] | 0, 145272, 145472);
	                        if (c[z >> 2] | 0)zb[c[135736 >> 2] & 511](c[z >> 2] | 0)
	                    } else if ((F | 0) == 103)xB(c[g >> 2] | 0, 145272, 145536); else if ((F | 0) == 120)xB(c[g >> 2] | 0, 145272, 145160); else if ((F | 0) == 124) {
	                        c[o >> 2] = 0;
	                        while (1) {
	                            if ((c[o >> 2] | 0) >= (c[(c[g >> 2] | 0) + 168 >> 2] | 0))break;
	                            c[m >> 2] = c[(c[(c[g >> 2] | 0) + 164 >> 2] | 0) + (c[o >> 2] << 2) >> 2];
	                            f:do if ((((c[(c[m >> 2] | 0) + 44 >> 2] | 0) != 17 ? (c[(c[m >> 2] | 0) + 44 >> 2] | 0) != 2 : 0) ? (c[(c[m >> 2] | 0) + 44 >> 2] | 0) != 13 : 0) ? (c[(c[m >> 2] | 0) + 44 >> 2] | 0) != 14 : 0) {
	                                c[(c[g >> 2] | 0) + 108 >> 2] = c[m >> 2];
	                                switch (c[(c[m >> 2] | 0) + 44 >> 2] | 0) {
	                                    case 6:
	                                    {
	                                        AB(c[g >> 2] | 0, 1862, 0, 0, 145096, 0, 0);
	                                        break f;
	                                        break
	                                    }
	                                    case 4:
	                                    {
	                                        c[E >> 2] = 0;
	                                        c[(c[g >> 2] | 0) + 108 >> 2] = c[(c[(c[g >> 2] | 0) + 100 >> 2] | 0) + (c[(c[g >> 2] | 0) + 96 >> 2] << 2) >> 2];
	                                        AB(c[g >> 2] | 0, 1868, 0, 0, 145592, BB(E, c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 56 >> 2] | 0, c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) | 0, 0);
	                                        if (!(c[E >> 2] | 0))break f;
	                                        zb[c[135736 >> 2] & 511](c[E >> 2] | 0);
	                                        c[E >> 2] = 0;
	                                        break f;
	                                        break
	                                    }
	                                    case 7:
	                                    {
	                                        AB(c[g >> 2] | 0, 1874, 0, 0, 145640, c[(c[m >> 2] | 0) + 20 >> 2] | 0, c[(c[m >> 2] | 0) + 52 >> 2] | 0);
	                                        break f;
	                                        break
	                                    }
	                                    case 10:
	                                    {
	                                        AB(c[g >> 2] | 0, 1878, 0, 0, 145704, 0, 0);
	                                        break f;
	                                        break
	                                    }
	                                    case 1:
	                                    {
	                                        if (c[(c[m >> 2] | 0) + 48 >> 2] | 0)break f;
	                                        F = c[g >> 2] | 0;
	                                        z = c[m >> 2] | 0;
	                                        if (!(c[(c[h >> 2] | 0) + 84 >> 2] | 0)) {
	                                            XG(F, 1866, z, 0);
	                                            break f
	                                        } else {
	                                            XG(F, 1867, z, 0);
	                                            break f
	                                        }
	                                        break
	                                    }
	                                    default:
	                                        break f
	                                }
	                            } while (0);
	                            c[o >> 2] = (c[o >> 2] | 0) + 1
	                        }
	                        c[(c[g >> 2] | 0) + 108 >> 2] = c[(c[(c[g >> 2] | 0) + 100 >> 2] | 0) + (c[(c[g >> 2] | 0) + 96 >> 2] << 2) >> 2];
	                        c[f >> 2] = 0;
	                        G = c[f >> 2] | 0;
	                        i = b;
	                        return G | 0
	                    }
	                    c[(c[g >> 2] | 0) + 108 >> 2] = c[(c[(c[g >> 2] | 0) + 100 >> 2] | 0) + (c[(c[g >> 2] | 0) + 96 >> 2] << 2) >> 2];
	                    c[f >> 2] = -1;
	                    G = c[f >> 2] | 0;
	                    i = b;
	                    return G | 0
	                }
	                return 0
	            }

	            function kF(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 16 | 0;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                g = b + 4 | 0;
	                h = b;
	                c[e >> 2] = a;
	                c[g >> 2] = 0;
	                if (!(c[(c[e >> 2] | 0) + 168 >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    j = c[d >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                c[h >> 2] = 0;
	                while (1) {
	                    if ((c[h >> 2] | 0) >= (c[(c[e >> 2] | 0) + 168 >> 2] | 0))break;
	                    c[f >> 2] = c[(c[(c[e >> 2] | 0) + 164 >> 2] | 0) + (c[h >> 2] << 2) >> 2];
	                    if (!(c[(c[f >> 2] | 0) + 48 >> 2] | 0)) {
	                        c[(c[e >> 2] | 0) + 108 >> 2] = c[f >> 2];
	                        XG(c[e >> 2] | 0, 1827, c[f >> 2] | 0, 0);
	                        c[g >> 2] = 1827
	                    }
	                    c[h >> 2] = (c[h >> 2] | 0) + 1
	                }
	                c[(c[e >> 2] | 0) + 108 >> 2] = c[(c[(c[e >> 2] | 0) + 100 >> 2] | 0) + (c[(c[e >> 2] | 0) + 96 >> 2] << 2) >> 2];
	                c[d >> 2] = c[g >> 2];
	                j = c[d >> 2] | 0;
	                i = b;
	                return j | 0
	            }

	            function lF(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 4 | 0;
	                h = f;
	                c[f + 12 >> 2] = a;
	                c[f + 8 >> 2] = b;
	                c[g >> 2] = d;
	                c[h >> 2] = e;
	                c[(c[h >> 2] | 0) + 44 >> 2] = c[g >> 2];
	                i = f;
	                return
	            }

	            function mF(a, b, e, f, g, h, j, k) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                k = k | 0;
	                var l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0;
	                l = i;
	                i = i + 64 | 0;
	                m = l + 56 | 0;
	                n = l + 52 | 0;
	                o = l + 48 | 0;
	                p = l + 40 | 0;
	                q = l + 36 | 0;
	                r = l + 32 | 0;
	                s = l + 28 | 0;
	                t = l + 24 | 0;
	                u = l + 20 | 0;
	                v = l + 16 | 0;
	                w = l + 12 | 0;
	                x = l + 8 | 0;
	                y = l + 4 | 0;
	                z = l;
	                c[m >> 2] = a;
	                c[n >> 2] = b;
	                c[o >> 2] = e;
	                c[l + 44 >> 2] = f;
	                c[p >> 2] = g;
	                c[q >> 2] = h;
	                c[r >> 2] = j;
	                c[s >> 2] = k;
	                c[t >> 2] = 0;
	                c[u >> 2] = 0;
	                HC(u, c[m >> 2] | 0, c[o >> 2] | 0) | 0;
	                c[u >> 2] = By(c[u >> 2] | 0, c[p >> 2] | 0) | 0;
	                c[u >> 2] = By(c[u >> 2] | 0, 144352) | 0;
	                if (((c[q >> 2] | 0) + (c[r >> 2] | 0) | 0) <= 0) {
	                    c[u >> 2] = By(c[u >> 2] | 0, 140352) | 0;
	                    A = c[m >> 2] | 0;
	                    B = c[n >> 2] | 0;
	                    C = c[o >> 2] | 0;
	                    D = c[u >> 2] | 0;
	                    PD(A, B, C, D, 0, 0);
	                    E = c[33934] | 0;
	                    F = c[u >> 2] | 0;
	                    zb[E & 511](F);
	                    i = l;
	                    return
	                }
	                if (((c[q >> 2] | 0) + (c[r >> 2] | 0) | 0) > 1)c[t >> 2] = my(144360) | 0; else c[t >> 2] = my(144384) | 0;
	                c[w >> 2] = 0;
	                c[z >> 2] = 0;
	                while (1) {
	                    if ((c[z >> 2] | 0) >= ((c[q >> 2] | 0) + (c[r >> 2] | 0) | 0))break;
	                    c[x >> 2] = c[(c[s >> 2] | 0) + (c[z >> 2] << 2) >> 2];
	                    do if (c[x >> 2] | 0) {
	                        if ((((d[c[x >> 2] >> 0] | 0 | 0) == 110 ? (d[(c[x >> 2] | 0) + 1 >> 0] | 0 | 0) == 111 : 0) ? (d[(c[x >> 2] | 0) + 2 >> 0] | 0 | 0) == 116 : 0) ? (d[(c[x >> 2] | 0) + 3 >> 0] | 0 | 0) == 32 : 0) {
	                            c[x >> 2] = (c[x >> 2] | 0) + 4;
	                            c[t >> 2] = By(c[t >> 2] | 0, 144400) | 0
	                        }
	                        c[v >> 2] = 0;
	                        c[y >> 2] = c[x >> 2];
	                        if ((d[c[y >> 2] >> 0] | 0 | 0) == 42) {
	                            c[v >> 2] = my(140432) | 0;
	                            c[y >> 2] = (c[y >> 2] | 0) + 1
	                        } else {
	                            while (1) {
	                                if (!(d[c[y >> 2] >> 0] | 0))break;
	                                if ((d[c[y >> 2] >> 0] | 0 | 0) == 124)break;
	                                c[y >> 2] = (c[y >> 2] | 0) + 1
	                            }
	                            c[v >> 2] = zy(c[v >> 2] | 0, c[x >> 2] | 0, (c[y >> 2] | 0) - (c[x >> 2] | 0) | 0) | 0
	                        }
	                        if (d[c[y >> 2] >> 0] | 0) {
	                            c[y >> 2] = (c[y >> 2] | 0) + 1;
	                            if (((c[r >> 2] | 0) != 0 ? (d[c[y >> 2] >> 0] | 0 | 0) == 42 : 0) ? (d[c[v >> 2] >> 0] | 0 | 0) == 42 : 0) {
	                                if (!(c[v >> 2] | 0))break;
	                                zb[c[135736 >> 2] & 511](c[v >> 2] | 0);
	                                c[v >> 2] = 0;
	                                break
	                            }
	                            c[x >> 2] = c[y >> 2];
	                            if ((d[c[y >> 2] >> 0] | 0 | 0) == 42)c[w >> 2] = my(144408) | 0; else {
	                                while (1) {
	                                    if (!(d[c[y >> 2] >> 0] | 0))break;
	                                    c[y >> 2] = (c[y >> 2] | 0) + 1
	                                }
	                                if ((c[z >> 2] | 0) >= (c[q >> 2] | 0))c[w >> 2] = my(144416) | 0; else c[w >> 2] = my(144432) | 0;
	                                c[w >> 2] = zy(c[w >> 2] | 0, c[x >> 2] | 0, (c[y >> 2] | 0) - (c[x >> 2] | 0) | 0) | 0;
	                                c[w >> 2] = By(c[w >> 2] | 0, 144440) | 0
	                            }
	                            c[t >> 2] = By(c[t >> 2] | 0, c[w >> 2] | 0) | 0;
	                            if (c[w >> 2] | 0) {
	                                zb[c[135736 >> 2] & 511](c[w >> 2] | 0);
	                                c[w >> 2] = 0
	                            }
	                        }
	                        c[t >> 2] = By(c[t >> 2] | 0, c[v >> 2] | 0) | 0;
	                        if (c[v >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[v >> 2] | 0);
	                            c[v >> 2] = 0
	                        }
	                        if ((c[z >> 2] | 0) < ((c[q >> 2] | 0) + (c[r >> 2] | 0) - 1 | 0))c[t >> 2] = By(c[t >> 2] | 0, 144448) | 0
	                    } while (0);
	                    c[z >> 2] = (c[z >> 2] | 0) + 1
	                }
	                c[t >> 2] = By(c[t >> 2] | 0, 144456) | 0;
	                c[u >> 2] = By(c[u >> 2] | 0, c[t >> 2] | 0) | 0;
	                if (!(c[t >> 2] | 0)) {
	                    A = c[m >> 2] | 0;
	                    B = c[n >> 2] | 0;
	                    C = c[o >> 2] | 0;
	                    D = c[u >> 2] | 0;
	                    PD(A, B, C, D, 0, 0);
	                    E = c[33934] | 0;
	                    F = c[u >> 2] | 0;
	                    zb[E & 511](F);
	                    i = l;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[t >> 2] | 0);
	                c[t >> 2] = 0;
	                A = c[m >> 2] | 0;
	                B = c[n >> 2] | 0;
	                C = c[o >> 2] | 0;
	                D = c[u >> 2] | 0;
	                PD(A, B, C, D, 0, 0);
	                E = c[33934] | 0;
	                F = c[u >> 2] | 0;
	                zb[E & 511](F);
	                i = l;
	                return
	            }

	            function nF(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                e = c[h >> 2] | 0;
	                h = c[k >> 2] | 0;
	                k = c[l >> 2] | 0;
	                if (c[(c[j >> 2] | 0) + 32 >> 2] & 16) {
	                    c[g >> 2] = yB(e, 0, h, k, (c[j >> 2] | 0) + 24 | 0, 1, 1, 0) | 0;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                } else {
	                    c[g >> 2] = yB(e, 0, h, k, 0, 1, 0, 0) | 0;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                return 0
	            }

	            function oF(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 0;
	                c[l >> 2] = c[(c[g >> 2] | 0) + 108 >> 2];
	                if (!((c[c[(c[l >> 2] | 0) + 28 >> 2] >> 2] | 0) != 5 ? (c[(c[(c[l >> 2] | 0) + 28 >> 2] | 0) + 88 >> 2] | 0) != 45 : 0))m = 3;
	                do if (((m | 0) == 3 ? (c[(c[(c[l >> 2] | 0) + 28 >> 2] | 0) + 52 >> 2] | 0) != 4 : 0) ? (c[(c[(c[l >> 2] | 0) + 28 >> 2] | 0) + 52 >> 2] | 0) != 6 : 0) {
	                    if ((c[(c[(c[l >> 2] | 0) + 28 >> 2] | 0) + 52 >> 2] | 0) == 3 ? (FG(c[(c[(c[l >> 2] | 0) + 28 >> 2] | 0) + 28 >> 2] | 0) | 0) != 0 : 0)break;
	                    c[k >> 2] = 3059;
	                    AB(c[g >> 2] | 0, c[k >> 2] | 0, 0, 0, 144160, 0, 0);
	                    c[f >> 2] = c[k >> 2];
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                } while (0);
	                do if ((c[c[(c[l >> 2] | 0) + 28 >> 2] >> 2] | 0) == 4)m = 11; else {
	                    if ((c[c[(c[l >> 2] | 0) + 28 >> 2] >> 2] | 0) == 1 ? (c[(c[(c[l >> 2] | 0) + 28 >> 2] | 0) + 88 >> 2] | 0) != 45 : 0) {
	                        m = 11;
	                        break
	                    }
	                    if ((c[(c[(c[l >> 2] | 0) + 28 >> 2] | 0) + 52 >> 2] | 0) != 4 ? (c[(c[(c[l >> 2] | 0) + 28 >> 2] | 0) + 52 >> 2] | 0) != 6 : 0)break;
	                    c[k >> 2] = yB(c[g >> 2] | 0, 0, c[(c[(c[l >> 2] | 0) + 28 >> 2] | 0) + 104 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, 1, 1, 0) | 0
	                } while (0);
	                if ((m | 0) == 11)c[k >> 2] = yB(c[g >> 2] | 0, 0, c[(c[l >> 2] | 0) + 28 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, 1, 1, 0) | 0;
	                if ((c[k >> 2] | 0) < 0)xB(c[g >> 2] | 0, 144320, 141832);
	                c[f >> 2] = c[k >> 2];
	                n = c[f >> 2] | 0;
	                i = e;
	                return n | 0
	            }

	            function pF(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0, J = 0, K = 0, L = 0, M = 0, N = 0;
	                d = i;
	                i = i + 128 | 0;
	                e = d + 124 | 0;
	                f = d + 120 | 0;
	                g = d + 116 | 0;
	                h = d + 112 | 0;
	                j = d + 108 | 0;
	                k = d + 104 | 0;
	                l = d + 100 | 0;
	                m = d + 96 | 0;
	                n = d + 92 | 0;
	                o = d + 88 | 0;
	                p = d + 84 | 0;
	                q = d + 80 | 0;
	                r = d + 76 | 0;
	                s = d + 72 | 0;
	                t = d + 68 | 0;
	                u = d + 64 | 0;
	                v = d + 60 | 0;
	                w = d + 56 | 0;
	                x = d + 52 | 0;
	                y = d + 48 | 0;
	                z = d + 44 | 0;
	                A = d + 40 | 0;
	                B = d + 36 | 0;
	                C = d + 32 | 0;
	                D = d + 28 | 0;
	                E = d + 24 | 0;
	                F = d + 20 | 0;
	                G = d + 16 | 0;
	                H = d + 12 | 0;
	                I = d + 8 | 0;
	                J = d + 4 | 0;
	                K = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[m >> 2] = 0;
	                c[n >> 2] = c[(c[(c[f >> 2] | 0) + 108 >> 2] | 0) + 28 >> 2];
	                c[o >> 2] = 0;
	                if (!(c[(c[f >> 2] | 0) + 116 >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    L = c[e >> 2] | 0;
	                    i = d;
	                    return L | 0
	                }
	                c[h >> 2] = c[(c[f >> 2] | 0) + 116 >> 2];
	                a:while (1) {
	                    if (!(c[h >> 2] | 0)) {
	                        M = 103;
	                        break
	                    }
	                    c[k >> 2] = KQ(c[(c[h >> 2] | 0) + 32 >> 2] | 0) | 0;
	                    if ((c[k >> 2] | 0) == -1) {
	                        M = 6;
	                        break
	                    }
	                    do if (c[(c[h >> 2] | 0) + 16 >> 2] | 0) {
	                        c[l >> 2] = c[(c[(c[h >> 2] | 0) + 12 >> 2] | 0) + ((c[(c[h >> 2] | 0) + 16 >> 2] | 0) - 1 << 2) >> 2];
	                        b = c[h >> 2] | 0;
	                        if ((c[l >> 2] | 0) != (c[g >> 2] | 0)) {
	                            c[h >> 2] = c[b + 4 >> 2];
	                            continue a
	                        }
	                        if ((c[b >> 2] | 0) != 2) {
	                            if ((c[c[h >> 2] >> 2] | 0) == 1) {
	                                c[w >> 2] = 0;
	                                c[y >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                                c[z >> 2] = c[(c[(c[y >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2];
	                                c[E >> 2] = c[(c[z >> 2] | 0) + 32 >> 2];
	                                c[B >> 2] = (c[g >> 2] | 0) - (c[(c[y >> 2] | 0) + 4 >> 2] | 0);
	                                do if ((c[(c[y >> 2] | 0) + 24 >> 2] | 0) != 0 ? (c[(c[y >> 2] | 0) + 28 >> 2] | 0) > (c[B >> 2] | 0) : 0) {
	                                    c[w >> 2] = (c[(c[y >> 2] | 0) + 24 >> 2] | 0) + (c[B >> 2] << 2);
	                                    if (!(c[c[w >> 2] >> 2] | 0))if ((c[c[z >> 2] >> 2] | 0) == 23) {
	                                        M = 91;
	                                        break
	                                    } else break;
	                                    c[C >> 2] = 0;
	                                    while (1) {
	                                        if ((c[C >> 2] | 0) >= (c[E >> 2] | 0))break;
	                                        if (!(c[(c[c[w >> 2] >> 2] | 0) + (c[C >> 2] << 2) >> 2] | 0)) {
	                                            M = 61;
	                                            break
	                                        }
	                                        c[C >> 2] = (c[C >> 2] | 0) + 1
	                                    }
	                                    if ((M | 0) == 61) {
	                                        M = 0;
	                                        if ((c[c[z >> 2] >> 2] | 0) == 23) {
	                                            M = 91;
	                                            break
	                                        } else break
	                                    }
	                                    c[A >> 2] = _G(c[f >> 2] | 0, c[y >> 2] | 0) | 0;
	                                    if ((c[c[z >> 2] >> 2] | 0) != 24 ? (c[(c[A >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                                        c[C >> 2] = 0;
	                                        c[k >> 2] = 0;
	                                        do {
	                                            c[H >> 2] = c[(c[(c[c[A >> 2] >> 2] | 0) + (c[C >> 2] << 2) >> 2] | 0) + 4 >> 2];
	                                            c[D >> 2] = 0;
	                                            while (1) {
	                                                if ((c[D >> 2] | 0) >= (c[E >> 2] | 0))break;
	                                                c[F >> 2] = c[(c[c[w >> 2] >> 2] | 0) + (c[D >> 2] << 2) >> 2];
	                                                c[G >> 2] = c[(c[H >> 2] | 0) + (c[D >> 2] << 2) >> 2];
	                                                c[k >> 2] = VD(c[(c[F >> 2] | 0) + 4 >> 2] | 0, c[(c[G >> 2] | 0) + 4 >> 2] | 0) | 0;
	                                                if ((c[k >> 2] | 0) == -1) {
	                                                    M = 69;
	                                                    break a
	                                                }
	                                                if (!(c[k >> 2] | 0))break;
	                                                c[D >> 2] = (c[D >> 2] | 0) + 1
	                                            }
	                                            if ((c[k >> 2] | 0) == 1)break;
	                                            c[C >> 2] = (c[C >> 2] | 0) + 1
	                                        } while ((c[C >> 2] | 0) < (c[(c[A >> 2] | 0) + 4 >> 2] | 0));
	                                        if ((c[C >> 2] | 0) != (c[(c[A >> 2] | 0) + 4 >> 2] | 0)) {
	                                            c[I >> 2] = 0;
	                                            c[J >> 2] = 0;
	                                            b = c[f >> 2] | 0;
	                                            a = c[z >> 2] | 0;
	                                            N = $G(c[f >> 2] | 0, I, c[c[w >> 2] >> 2] | 0, c[E >> 2] | 0) | 0;
	                                            AB(b, 1877, 0, a, 143312, N, YG(J, c[z >> 2] | 0) | 0);
	                                            if (c[I >> 2] | 0) {
	                                                zb[c[135736 >> 2] & 511](c[I >> 2] | 0);
	                                                c[I >> 2] = 0
	                                            }
	                                            if (!(c[J >> 2] | 0))break;
	                                            zb[c[135736 >> 2] & 511](c[J >> 2] | 0);
	                                            c[J >> 2] = 0;
	                                            break
	                                        }
	                                    }
	                                    c[x >> 2] = Cb[c[135744 >> 2] & 511](16) | 0;
	                                    if (!(c[x >> 2] | 0)) {
	                                        M = 80;
	                                        break a
	                                    }
	                                    N = c[x >> 2] | 0;
	                                    c[N + 0 >> 2] = 0;
	                                    c[N + 4 >> 2] = 0;
	                                    c[N + 8 >> 2] = 0;
	                                    c[N + 12 >> 2] = 0;
	                                    N = c[f >> 2] | 0;
	                                    if ((c[c[z >> 2] >> 2] | 0) == 24) {
	                                        a = bH(N, c[(c[(c[f >> 2] | 0) + 108 >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[f >> 2] | 0) + 108 >> 2] | 0) + 16 >> 2] | 0) | 0;
	                                        c[(c[x >> 2] | 0) + 12 >> 2] = a;
	                                        if ((c[(c[x >> 2] | 0) + 12 >> 2] | 0) == -1) {
	                                            M = 86;
	                                            break a
	                                        }
	                                    } else {
	                                        if ((aH(N, c[x >> 2] | 0) | 0) == -1) {
	                                            M = 83;
	                                            break a
	                                        }
	                                        c[(c[x >> 2] | 0) + 12 >> 2] = -1
	                                    }
	                                    c[c[x >> 2] >> 2] = c[(c[f >> 2] | 0) + 60 >> 2];
	                                    c[(c[x >> 2] | 0) + 8 >> 2] = c[(c[(c[f >> 2] | 0) + 108 >> 2] | 0) + 8 >> 2];
	                                    c[(c[x >> 2] | 0) + 4 >> 2] = c[c[w >> 2] >> 2];
	                                    c[c[w >> 2] >> 2] = 0;
	                                    if ((bE(c[A >> 2] | 0, c[x >> 2] | 0) | 0) == -1) {
	                                        M = 88;
	                                        break a
	                                    }
	                                } else M = 55; while (0);
	                                if ((M | 0) == 55 ? (M = 0, (c[c[z >> 2] >> 2] | 0) == 23) : 0)M = 91;
	                                if ((M | 0) == 91 ? (M = 0, c[K >> 2] = 0, N = c[f >> 2] | 0, a = c[z >> 2] | 0, AB(N, 1877, 0, a, 143384, YG(K, c[z >> 2] | 0) | 0, 0), (c[K >> 2] | 0) != 0) : 0) {
	                                    zb[c[135736 >> 2] & 511](c[K >> 2] | 0);
	                                    c[K >> 2] = 0
	                                }
	                                if ((c[w >> 2] | 0) != 0 ? (c[c[w >> 2] >> 2] | 0) != 0 : 0) {
	                                    zb[c[135736 >> 2] & 511](c[c[w >> 2] >> 2] | 0);
	                                    c[c[w >> 2] >> 2] = 0
	                                }
	                            }
	                        } else {
	                            if ((c[c[n >> 2] >> 2] | 0) != 5 ? (c[(c[n >> 2] | 0) + 88 >> 2] | 0) != 45 : 0)c[o >> 2] = c[n >> 2]; else M = 13;
	                            do if ((M | 0) == 13) {
	                                M = 0;
	                                if ((c[(c[n >> 2] | 0) + 52 >> 2] | 0) != 4 ? (c[(c[n >> 2] | 0) + 52 >> 2] | 0) != 6 : 0) {
	                                    c[o >> 2] = 0;
	                                    break
	                                }
	                                c[o >> 2] = c[(c[n >> 2] | 0) + 104 >> 2];
	                                if (!(c[o >> 2] | 0)) {
	                                    M = 16;
	                                    break a
	                                }
	                            } while (0);
	                            if (!(c[o >> 2] | 0)) {
	                                c[p >> 2] = 0;
	                                a = c[f >> 2] | 0;
	                                N = c[(c[(c[(c[h >> 2] | 0) + 24 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0;
	                                b = c[(c[(c[h >> 2] | 0) + 28 >> 2] | 0) + 12 >> 2] | 0;
	                                AB(a, 1877, 0, N, 142904, b, YG(p, c[(c[(c[(c[h >> 2] | 0) + 24 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) | 0);
	                                if (c[p >> 2] | 0) {
	                                    zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                                    c[p >> 2] = 0
	                                }
	                                b = (c[h >> 2] | 0) + 16 | 0;
	                                c[b >> 2] = (c[b >> 2] | 0) + -1;
	                                break
	                            }
	                            if ((c[m >> 2] | 0) == 0 ? (c[(c[(c[f >> 2] | 0) + 108 >> 2] | 0) + 24 >> 2] | 0) == 0 : 0) {
	                                AB(c[f >> 2] | 0, 1877, 0, c[(c[(c[(c[h >> 2] | 0) + 24 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0, 142984, 0, 0);
	                                b = (c[h >> 2] | 0) + 16 | 0;
	                                c[b >> 2] = (c[b >> 2] | 0) + -1;
	                                break
	                            }
	                            c[q >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                            c[s >> 2] = (c[(c[h >> 2] | 0) + 8 >> 2] | 0) - (c[(c[q >> 2] | 0) + 4 >> 2] | 0);
	                            c[t >> 2] = c[(c[(c[h >> 2] | 0) + 28 >> 2] | 0) + 8 >> 2];
	                            b = c[s >> 2] | 0;
	                            b:do if (c[(c[q >> 2] | 0) + 24 >> 2] | 0) {
	                                if ((b | 0) >= (c[(c[q >> 2] | 0) + 28 >> 2] | 0)) {
	                                    c[u >> 2] = c[(c[q >> 2] | 0) + 28 >> 2];
	                                    N = (c[q >> 2] | 0) + 28 | 0;
	                                    c[N >> 2] = c[N >> 2] << 1;
	                                    N = Hb[c[135760 >> 2] & 511](c[(c[q >> 2] | 0) + 24 >> 2] | 0, c[(c[q >> 2] | 0) + 28 >> 2] << 2) | 0;
	                                    c[(c[q >> 2] | 0) + 24 >> 2] = N;
	                                    if (!(c[(c[q >> 2] | 0) + 24 >> 2] | 0)) {
	                                        M = 35;
	                                        break a
	                                    }
	                                    while (1) {
	                                        if ((c[u >> 2] | 0) >= (c[(c[q >> 2] | 0) + 28 >> 2] | 0))break b;
	                                        c[(c[(c[q >> 2] | 0) + 24 >> 2] | 0) + (c[u >> 2] << 2) >> 2] = 0;
	                                        c[u >> 2] = (c[u >> 2] | 0) + 1
	                                    }
	                                }
	                            } else {
	                                if ((b | 0) > 9)c[(c[q >> 2] | 0) + 28 >> 2] = c[s >> 2] << 1; else c[(c[q >> 2] | 0) + 28 >> 2] = 10;
	                                N = Cb[c[135744 >> 2] & 511](c[(c[q >> 2] | 0) + 28 >> 2] << 2) | 0;
	                                c[(c[q >> 2] | 0) + 24 >> 2] = N;
	                                if (!(c[(c[q >> 2] | 0) + 24 >> 2] | 0)) {
	                                    M = 31;
	                                    break a
	                                }
	                                cU(c[(c[q >> 2] | 0) + 24 >> 2] | 0, 0, c[(c[q >> 2] | 0) + 28 >> 2] << 2 | 0) | 0
	                            } while (0);
	                            c[r >> 2] = c[(c[(c[q >> 2] | 0) + 24 >> 2] | 0) + (c[s >> 2] << 2) >> 2];
	                            if (c[r >> 2] | 0) {
	                                if (c[(c[r >> 2] | 0) + (c[t >> 2] << 2) >> 2] | 0) {
	                                    c[v >> 2] = 0;
	                                    b = c[f >> 2] | 0;
	                                    N = c[(c[(c[q >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0;
	                                    a = c[(c[(c[h >> 2] | 0) + 28 >> 2] | 0) + 12 >> 2] | 0;
	                                    AB(b, 1877, 0, N, 143168, a, YG(v, c[(c[(c[q >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) | 0);
	                                    if (c[v >> 2] | 0) {
	                                        zb[c[135736 >> 2] & 511](c[v >> 2] | 0);
	                                        c[v >> 2] = 0
	                                    }
	                                    a = (c[h >> 2] | 0) + 16 | 0;
	                                    c[a >> 2] = (c[a >> 2] | 0) + -1;
	                                    break
	                                }
	                            } else {
	                                c[r >> 2] = Cb[c[135744 >> 2] & 511](c[(c[(c[(c[q >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) + 32 >> 2] << 2) | 0;
	                                if (!(c[r >> 2] | 0)) {
	                                    M = 44;
	                                    break a
	                                }
	                                cU(c[r >> 2] | 0, 0, c[(c[(c[(c[q >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) + 32 >> 2] << 2 | 0) | 0;
	                                c[(c[(c[q >> 2] | 0) + 24 >> 2] | 0) + (c[s >> 2] << 2) >> 2] = c[r >> 2]
	                            }
	                            if (!(c[m >> 2] | 0)) {
	                                c[m >> 2] = Cb[c[135744 >> 2] & 511](8) | 0;
	                                if (!(c[m >> 2] | 0)) {
	                                    M = 48;
	                                    break a
	                                }
	                                c[c[m >> 2] >> 2] = c[o >> 2];
	                                c[(c[m >> 2] | 0) + 4 >> 2] = c[(c[(c[f >> 2] | 0) + 108 >> 2] | 0) + 24 >> 2];
	                                c[(c[(c[f >> 2] | 0) + 108 >> 2] | 0) + 24 >> 2] = 0;
	                                if ((ZG(c[f >> 2] | 0, c[m >> 2] | 0) | 0) == -1) {
	                                    M = 50;
	                                    break a
	                                }
	                            }
	                            c[(c[r >> 2] | 0) + (c[t >> 2] << 2) >> 2] = c[m >> 2]
	                        }
	                        a = (c[h >> 2] | 0) + 16 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + -1
	                    } while (0);
	                    if ((c[(c[h >> 2] | 0) + 16 >> 2] | 0) == 0 ? (c[(c[h >> 2] | 0) + 8 >> 2] | 0) == (c[g >> 2] | 0) : 0) {
	                        if ((c[(c[f >> 2] | 0) + 116 >> 2] | 0) != (c[h >> 2] | 0))xB(c[f >> 2] | 0, 142760, 143424);
	                        c[j >> 2] = c[(c[h >> 2] | 0) + 4 >> 2];
	                        c[(c[f >> 2] | 0) + 116 >> 2] = c[(c[h >> 2] | 0) + 4 >> 2];
	                        c[(c[h >> 2] | 0) + 4 >> 2] = c[(c[f >> 2] | 0) + 120 >> 2];
	                        c[(c[f >> 2] | 0) + 120 >> 2] = c[h >> 2];
	                        c[h >> 2] = c[j >> 2];
	                        continue
	                    }
	                    c[h >> 2] = c[(c[h >> 2] | 0) + 4 >> 2]
	                }
	                switch (M | 0) {
	                    case 6:
	                    {
	                        xB(c[f >> 2] | 0, 142760, 142792);
	                        c[e >> 2] = -1;
	                        L = c[e >> 2] | 0;
	                        i = d;
	                        return L | 0
	                    }
	                    case 16:
	                    {
	                        xB(c[f >> 2] | 0, 142760, 142816);
	                        c[e >> 2] = -1;
	                        L = c[e >> 2] | 0;
	                        i = d;
	                        return L | 0
	                    }
	                    case 31:
	                    {
	                        IB(0, 143088, 0);
	                        c[e >> 2] = -1;
	                        L = c[e >> 2] | 0;
	                        i = d;
	                        return L | 0
	                    }
	                    case 35:
	                    {
	                        IB(0, 143128, 0);
	                        c[e >> 2] = -1;
	                        L = c[e >> 2] | 0;
	                        i = d;
	                        return L | 0
	                    }
	                    case 44:
	                    {
	                        IB(0, 143256, 0);
	                        c[e >> 2] = -1;
	                        L = c[e >> 2] | 0;
	                        i = d;
	                        return L | 0
	                    }
	                    case 48:
	                    {
	                        IB(0, 143288, 0);
	                        zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                        c[(c[(c[q >> 2] | 0) + 24 >> 2] | 0) + (c[s >> 2] << 2) >> 2] = 0;
	                        c[e >> 2] = -1;
	                        L = c[e >> 2] | 0;
	                        i = d;
	                        return L | 0
	                    }
	                    case 50:
	                    {
	                        tB(c[m >> 2] | 0);
	                        c[e >> 2] = -1;
	                        L = c[e >> 2] | 0;
	                        i = d;
	                        return L | 0
	                    }
	                    case 69:
	                    {
	                        c[e >> 2] = -1;
	                        L = c[e >> 2] | 0;
	                        i = d;
	                        return L | 0
	                    }
	                    case 80:
	                    {
	                        IB(0, 143344, 0);
	                        zb[c[135736 >> 2] & 511](c[c[w >> 2] >> 2] | 0);
	                        c[c[w >> 2] >> 2] = 0;
	                        c[e >> 2] = -1;
	                        L = c[e >> 2] | 0;
	                        i = d;
	                        return L | 0
	                    }
	                    case 83:
	                    {
	                        zb[c[135736 >> 2] & 511](c[x >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[c[w >> 2] >> 2] | 0);
	                        c[c[w >> 2] >> 2] = 0;
	                        c[e >> 2] = -1;
	                        L = c[e >> 2] | 0;
	                        i = d;
	                        return L | 0
	                    }
	                    case 86:
	                    {
	                        zb[c[135736 >> 2] & 511](c[x >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[c[w >> 2] >> 2] | 0);
	                        c[c[w >> 2] >> 2] = 0;
	                        c[e >> 2] = -1;
	                        L = c[e >> 2] | 0;
	                        i = d;
	                        return L | 0
	                    }
	                    case 88:
	                    {
	                        if ((c[c[z >> 2] >> 2] | 0) == 24) {
	                            zb[c[135736 >> 2] & 511](c[(c[x >> 2] | 0) + 4 >> 2] | 0);
	                            zb[c[135736 >> 2] & 511](c[x >> 2] | 0)
	                        }
	                        c[e >> 2] = -1;
	                        L = c[e >> 2] | 0;
	                        i = d;
	                        return L | 0
	                    }
	                    case 103:
	                    {
	                        c[e >> 2] = 0;
	                        L = c[e >> 2] | 0;
	                        i = d;
	                        return L | 0
	                    }
	                }
	                return 0
	            }

	            function qF(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0;
	                d = i;
	                i = i + 80 | 0;
	                e = d + 64 | 0;
	                f = d + 60 | 0;
	                g = d + 56 | 0;
	                h = d + 52 | 0;
	                j = d + 48 | 0;
	                k = d + 44 | 0;
	                l = d + 40 | 0;
	                m = d + 36 | 0;
	                n = d + 32 | 0;
	                o = d + 28 | 0;
	                p = d + 24 | 0;
	                q = d + 20 | 0;
	                r = d + 16 | 0;
	                s = d + 12 | 0;
	                t = d + 8 | 0;
	                u = d + 4 | 0;
	                v = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[v >> 2] = c[(c[g >> 2] | 0) + 56 >> 2];
	                a:while (1) {
	                    if (!(c[v >> 2] | 0)) {
	                        w = 51;
	                        break
	                    }
	                    if (((c[c[(c[(c[v >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] >> 2] | 0) != 24 ? (c[(c[v >> 2] | 0) + 32 >> 2] | 0) != 0 : 0) ? (c[(c[(c[v >> 2] | 0) + 32 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                        do if (!(c[(c[f >> 2] | 0) + 188 >> 2] | 0)) {
	                            if ((c[(c[(c[v >> 2] | 0) + 16 >> 2] | 0) + 8 >> 2] | 0) != -1 ? (c[(c[(c[v >> 2] | 0) + 16 >> 2] | 0) + 8 >> 2] | 0) <= (c[(c[f >> 2] | 0) + 96 >> 2] | 0) : 0)break;
	                            c[v >> 2] = c[(c[v >> 2] | 0) + 8 >> 2];
	                            continue a
	                        } while (0);
	                        c[h >> 2] = cH(c[f >> 2] | 0, c[v >> 2] | 0) | 0;
	                        if ((c[(c[h >> 2] | 0) + 20 >> 2] | 0) != 0 ? (c[(c[(c[h >> 2] | 0) + 20 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                            c[u >> 2] = c[c[(c[h >> 2] | 0) + 20 >> 2] >> 2];
	                            c[p >> 2] = c[(c[(c[h >> 2] | 0) + 20 >> 2] | 0) + 4 >> 2]
	                        } else {
	                            c[u >> 2] = 0;
	                            c[p >> 2] = 0
	                        }
	                        if (c[(c[h >> 2] | 0) + 8 >> 2] | 0)c[q >> 2] = c[(c[h >> 2] | 0) + 12 >> 2]; else c[q >> 2] = 0;
	                        g = c[(c[v >> 2] | 0) + 32 >> 2] | 0;
	                        if ((c[q >> 2] | 0) == 0 & (c[p >> 2] | 0) == 0) {
	                            c[(c[h >> 2] | 0) + 8 >> 2] = c[g >> 2];
	                            c[(c[h >> 2] | 0) + 16 >> 2] = c[(c[(c[v >> 2] | 0) + 32 >> 2] | 0) + 8 >> 2];
	                            c[(c[h >> 2] | 0) + 12 >> 2] = c[(c[(c[v >> 2] | 0) + 32 >> 2] | 0) + 4 >> 2];
	                            c[c[(c[v >> 2] | 0) + 32 >> 2] >> 2] = 0;
	                            c[(c[(c[v >> 2] | 0) + 32 >> 2] | 0) + 8 >> 2] = 0;
	                            c[(c[(c[v >> 2] | 0) + 32 >> 2] | 0) + 4 >> 2] = 0
	                        } else {
	                            c[n >> 2] = c[g + 4 >> 2];
	                            c[t >> 2] = c[c[(c[v >> 2] | 0) + 32 >> 2] >> 2];
	                            c[o >> 2] = c[(c[(c[(c[v >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) + 32 >> 2];
	                            c[k >> 2] = 0;
	                            do {
	                                c[r >> 2] = c[(c[(c[t >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 4 >> 2];
	                                b:do if (c[p >> 2] | 0) {
	                                    c[l >> 2] = 0;
	                                    while (1) {
	                                        if ((c[o >> 2] | 0) == 1) {
	                                            c[j >> 2] = VD(c[(c[c[r >> 2] >> 2] | 0) + 4 >> 2] | 0, c[(c[c[(c[(c[u >> 2] | 0) + (c[l >> 2] << 2) >> 2] | 0) + 4 >> 2] >> 2] | 0) + 4 >> 2] | 0) | 0;
	                                            if ((c[j >> 2] | 0) == -1) {
	                                                w = 52;
	                                                break a
	                                            }
	                                            if ((c[j >> 2] | 0) == 1)break b
	                                        } else {
	                                            c[j >> 2] = 0;
	                                            c[s >> 2] = c[(c[(c[u >> 2] | 0) + (c[l >> 2] << 2) >> 2] | 0) + 4 >> 2];
	                                            c[m >> 2] = 0;
	                                            while (1) {
	                                                if ((c[m >> 2] | 0) >= (c[o >> 2] | 0))break;
	                                                c[j >> 2] = VD(c[(c[(c[r >> 2] | 0) + (c[m >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0, c[(c[(c[s >> 2] | 0) + (c[m >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0) | 0;
	                                                if ((c[j >> 2] | 0) == -1) {
	                                                    w = 52;
	                                                    break a
	                                                }
	                                                if (!(c[j >> 2] | 0))break;
	                                                c[m >> 2] = (c[m >> 2] | 0) + 1
	                                            }
	                                            if ((c[j >> 2] | 0) == 1)break b
	                                        }
	                                        c[l >> 2] = (c[l >> 2] | 0) + 1;
	                                        if ((c[l >> 2] | 0) >= (c[p >> 2] | 0)) {
	                                            w = 33;
	                                            break
	                                        }
	                                    }
	                                } else w = 33; while (0);
	                                c:do if ((w | 0) == 33) {
	                                    w = 0;
	                                    d:do if (c[q >> 2] | 0) {
	                                        c[l >> 2] = 0;
	                                        e:while (1) {
	                                            f:do if ((c[o >> 2] | 0) == 1) {
	                                                c[j >> 2] = VD(c[(c[c[r >> 2] >> 2] | 0) + 4 >> 2] | 0, c[(c[c[(c[(c[(c[h >> 2] | 0) + 8 >> 2] | 0) + (c[l >> 2] << 2) >> 2] | 0) + 4 >> 2] >> 2] | 0) + 4 >> 2] | 0) | 0;
	                                                if ((c[j >> 2] | 0) == -1) {
	                                                    w = 52;
	                                                    break a
	                                                }
	                                                if (c[j >> 2] | 0)break e
	                                            } else {
	                                                c[j >> 2] = 0;
	                                                c[s >> 2] = c[(c[(c[(c[h >> 2] | 0) + 8 >> 2] | 0) + (c[l >> 2] << 2) >> 2] | 0) + 4 >> 2];
	                                                c[m >> 2] = 0;
	                                                while (1) {
	                                                    if ((c[m >> 2] | 0) >= (c[o >> 2] | 0))break e;
	                                                    c[j >> 2] = VD(c[(c[(c[r >> 2] | 0) + (c[m >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0, c[(c[(c[s >> 2] | 0) + (c[m >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0) | 0;
	                                                    if ((c[j >> 2] | 0) == -1) {
	                                                        w = 52;
	                                                        break a
	                                                    }
	                                                    if (!(c[j >> 2] | 0))break f;
	                                                    c[m >> 2] = (c[m >> 2] | 0) + 1
	                                                }
	                                            } while (0);
	                                            c[l >> 2] = (c[l >> 2] | 0) + 1;
	                                            if ((c[l >> 2] | 0) >= (c[q >> 2] | 0))break d
	                                        }
	                                        if ((c[(c[h >> 2] | 0) + 20 >> 2] | 0) == 0 ? (g = JB() | 0, c[(c[h >> 2] | 0) + 20 >> 2] = g, (c[(c[h >> 2] | 0) + 20 >> 2] | 0) == 0) : 0) {
	                                            w = 52;
	                                            break a
	                                        }
	                                        if ((bE(c[(c[h >> 2] | 0) + 20 >> 2] | 0, c[(c[(c[h >> 2] | 0) + 8 >> 2] | 0) + (c[l >> 2] << 2) >> 2] | 0) | 0) == -1) {
	                                            w = 52;
	                                            break a
	                                        }
	                                        c[(c[(c[h >> 2] | 0) + 8 >> 2] | 0) + (c[l >> 2] << 2) >> 2] = c[(c[(c[h >> 2] | 0) + 8 >> 2] | 0) + ((c[(c[h >> 2] | 0) + 12 >> 2] | 0) - 1 << 2) >> 2];
	                                        g = (c[h >> 2] | 0) + 12 | 0;
	                                        c[g >> 2] = (c[g >> 2] | 0) + -1;
	                                        break c
	                                    } while (0);
	                                    if ((dH(c[h >> 2] | 0, c[(c[t >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) | 0) == -1) {
	                                        w = 52;
	                                        break a
	                                    }
	                                } while (0);
	                                c[k >> 2] = (c[k >> 2] | 0) + 1
	                            } while ((c[k >> 2] | 0) < (c[n >> 2] | 0))
	                        }
	                        c[v >> 2] = c[(c[v >> 2] | 0) + 8 >> 2];
	                        continue
	                    }
	                    c[v >> 2] = c[(c[v >> 2] | 0) + 8 >> 2]
	                }
	                if ((w | 0) == 51) {
	                    c[e >> 2] = 0;
	                    x = c[e >> 2] | 0;
	                    i = d;
	                    return x | 0
	                } else if ((w | 0) == 52) {
	                    c[e >> 2] = -1;
	                    x = c[e >> 2] | 0;
	                    i = d;
	                    return x | 0
	                }
	                return 0
	            }

	            function Kb(a) {
	                a = a | 0;
	                var b = 0;
	                b = i;
	                i = i + a | 0;
	                i = i + 15 & -16;
	                return b | 0
	            }

	            function Lb() {
	                return i | 0
	            }

	            function Mb(a) {
	                a = a | 0;
	                i = a
	            }

	            function Nb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                if (!r) {
	                    r = a;
	                    s = b
	                }
	            }

	            function Ob(b) {
	                b = b | 0;
	                a[k >> 0] = a[b >> 0];
	                a[k + 1 >> 0] = a[b + 1 >> 0];
	                a[k + 2 >> 0] = a[b + 2 >> 0];
	                a[k + 3 >> 0] = a[b + 3 >> 0]
	            }

	            function Pb(b) {
	                b = b | 0;
	                a[k >> 0] = a[b >> 0];
	                a[k + 1 >> 0] = a[b + 1 >> 0];
	                a[k + 2 >> 0] = a[b + 2 >> 0];
	                a[k + 3 >> 0] = a[b + 3 >> 0];
	                a[k + 4 >> 0] = a[b + 4 >> 0];
	                a[k + 5 >> 0] = a[b + 5 >> 0];
	                a[k + 6 >> 0] = a[b + 6 >> 0];
	                a[k + 7 >> 0] = a[b + 7 >> 0]
	            }

	            function Qb(a) {
	                a = a | 0;
	                G = a
	            }

	            function Rb() {
	                return G | 0
	            }

	            function Sb(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0;
	                e = i;
	                i = i + 64 | 0;
	                f = e;
	                g = e + 52 | 0;
	                h = e + 48 | 0;
	                j = e + 44 | 0;
	                k = e + 40 | 0;
	                l = e + 36 | 0;
	                m = e + 32 | 0;
	                n = e + 28 | 0;
	                p = e + 24 | 0;
	                q = e + 20 | 0;
	                r = e + 16 | 0;
	                s = e + 12 | 0;
	                t = e + 8 | 0;
	                u = e + 4 | 0;
	                c[g >> 2] = 0;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[m >> 2] = 0;
	                c[n >> 2] = 0;
	                if ((c[h >> 2] | 0) <= 1) {
	                    Tb(c[c[j >> 2] >> 2] | 0);
	                    c[g >> 2] = 1;
	                    v = c[g >> 2] | 0;
	                    i = e;
	                    return v | 0
	                }
	                he(20902);
	                c[k >> 2] = 1;
	                a:while (1) {
	                    if ((c[k >> 2] | 0) >= (c[h >> 2] | 0))break;
	                    if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 144) | 0))break;
	                    b:do if ((a[c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] >> 0] | 0) == 45) {
	                        if ((PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 152) | 0) != 0 ? (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 160) | 0) != 0 : 0) {
	                            if ((PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 176) | 0) != 0 ? (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 184) | 0) != 0 : 0) {
	                                if ((PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 208) | 0) != 0 ? (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 216) | 0) != 0 : 0) {
	                                    if ((PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 232) | 0) != 0 ? (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 248) | 0) != 0 : 0) {
	                                        do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 280) | 0) {
	                                            if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 288) | 0))break;
	                                            do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 296) | 0) {
	                                                if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 304) | 0))break;
	                                                do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 320) | 0) {
	                                                    if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 328) | 0))break;
	                                                    do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 344) | 0) {
	                                                        if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 360) | 0))break;
	                                                        do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 376) | 0) {
	                                                            if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 392) | 0))break;
	                                                            do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 408) | 0) {
	                                                                if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 416) | 0))break;
	                                                                do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 432) | 0) {
	                                                                    if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 448) | 0))break;
	                                                                    do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 464) | 0) {
	                                                                        if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 472) | 0))break;
	                                                                        do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 480) | 0) {
	                                                                            if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 488) | 0))break;
	                                                                            if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 496) | 0))break;
	                                                                            do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 520) | 0) {
	                                                                                if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 536) | 0))break;
	                                                                                do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 560) | 0) {
	                                                                                    if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 568) | 0))break;
	                                                                                    do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 592) | 0) {
	                                                                                        if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 600) | 0))break;
	                                                                                        do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 616) | 0) {
	                                                                                            if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 624) | 0))break;
	                                                                                            do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 648) | 0) {
	                                                                                                if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 664) | 0))break;
	                                                                                                do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 688) | 0) {
	                                                                                                    if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 704) | 0))break;
	                                                                                                    do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 728) | 0) {
	                                                                                                        if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 744) | 0))break;
	                                                                                                        do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 768) | 0) {
	                                                                                                            if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 776) | 0))break;
	                                                                                                            do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 792) | 0) {
	                                                                                                                if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 808) | 0))break;
	                                                                                                                do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 832) | 0) {
	                                                                                                                    if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 848) | 0))break;
	                                                                                                                    do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 872) | 0) {
	                                                                                                                        if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 888) | 0))break;
	                                                                                                                        do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 912) | 0) {
	                                                                                                                            if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 928) | 0))break;
	                                                                                                                            do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 952) | 0) {
	                                                                                                                                if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 960) | 0))break;
	                                                                                                                                do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 984) | 0) {
	                                                                                                                                    if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 992) | 0))break;
	                                                                                                                                    do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1016) | 0) {
	                                                                                                                                        if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1024) | 0))break;
	                                                                                                                                        do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1040) | 0) {
	                                                                                                                                            if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1048) | 0))break;
	                                                                                                                                            do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1072) | 0) {
	                                                                                                                                                if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1080) | 0))break;
	                                                                                                                                                do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1096) | 0) {
	                                                                                                                                                    if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1112) | 0))break;
	                                                                                                                                                    do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1136) | 0) {
	                                                                                                                                                        if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1144) | 0))break;
	                                                                                                                                                        do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1168) | 0) {
	                                                                                                                                                            if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1176) | 0))break;
	                                                                                                                                                            do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1200) | 0) {
	                                                                                                                                                                if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1216) | 0))break;
	                                                                                                                                                                do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1240) | 0) {
	                                                                                                                                                                    if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1256) | 0))break;
	                                                                                                                                                                    do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1280) | 0) {
	                                                                                                                                                                        if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1304) | 0))break;
	                                                                                                                                                                        do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1328) | 0) {
	                                                                                                                                                                            if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1344) | 0))break;
	                                                                                                                                                                            do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1360) | 0) {
	                                                                                                                                                                                if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1376) | 0))break;
	                                                                                                                                                                                do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1392) | 0) {
	                                                                                                                                                                                    if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1408) | 0))break;
	                                                                                                                                                                                    do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1432) | 0) {
	                                                                                                                                                                                        if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1440) | 0))break;
	                                                                                                                                                                                        do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1456) | 0) {
	                                                                                                                                                                                            if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1464) | 0))break;
	                                                                                                                                                                                            do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1488) | 0) {
	                                                                                                                                                                                                if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1504) | 0))break;
	                                                                                                                                                                                                do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1528) | 0) {
	                                                                                                                                                                                                    if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1544) | 0))break;
	                                                                                                                                                                                                    do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1568) | 0) {
	                                                                                                                                                                                                        if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1584) | 0))break;
	                                                                                                                                                                                                        do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1608) | 0) {
	                                                                                                                                                                                                            if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1616) | 0))break;
	                                                                                                                                                                                                            do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1656) | 0) {
	                                                                                                                                                                                                                if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1672) | 0))break;
	                                                                                                                                                                                                                do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1696) | 0) {
	                                                                                                                                                                                                                    if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1704) | 0))break;
	                                                                                                                                                                                                                    do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1736) | 0) {
	                                                                                                                                                                                                                        if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1744) | 0))break;
	                                                                                                                                                                                                                        do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1768) | 0) {
	                                                                                                                                                                                                                            if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1776) | 0))break;
	                                                                                                                                                                                                                            do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1792) | 0) {
	                                                                                                                                                                                                                                if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1800) | 0))break;
	                                                                                                                                                                                                                                do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1824) | 0) {
	                                                                                                                                                                                                                                    if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1832) | 0))break;
	                                                                                                                                                                                                                                    do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1856) | 0) {
	                                                                                                                                                                                                                                        if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1864) | 0))break;
	                                                                                                                                                                                                                                        do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1880) | 0) {
	                                                                                                                                                                                                                                            if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1888) | 0))break;
	                                                                                                                                                                                                                                            do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1904) | 0) {
	                                                                                                                                                                                                                                                if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1920) | 0))break;
	                                                                                                                                                                                                                                                do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1944) | 0) {
	                                                                                                                                                                                                                                                    if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1960) | 0))break;
	                                                                                                                                                                                                                                                    do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1984) | 0) {
	                                                                                                                                                                                                                                                        if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1992) | 0))break;
	                                                                                                                                                                                                                                                        do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 2016) | 0) {
	                                                                                                                                                                                                                                                            if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 2032) | 0))break;
	                                                                                                                                                                                                                                                            do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 2056) | 0) {
	                                                                                                                                                                                                                                                                if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 2064) | 0))break;
	                                                                                                                                                                                                                                                                do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 2072) | 0) {
	                                                                                                                                                                                                                                                                    if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 2088) | 0))break;
	                                                                                                                                                                                                                                                                    do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 2104) | 0) {
	                                                                                                                                                                                                                                                                        if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 2120) | 0))break;
	                                                                                                                                                                                                                                                                        do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 2144) | 0) {
	                                                                                                                                                                                                                                                                            if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 2152) | 0))break;
	                                                                                                                                                                                                                                                                            do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 2160) | 0) {
	                                                                                                                                                                                                                                                                                if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 2176) | 0))break;
	                                                                                                                                                                                                                                                                                do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 2200) | 0) {
	                                                                                                                                                                                                                                                                                    if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 2208) | 0))break;
	                                                                                                                                                                                                                                                                                    if ((PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 2224) | 0) != 0 ? (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 2240) | 0) != 0 : 0) {
	                                                                                                                                                                                                                                                                                        w = 206;
	                                                                                                                                                                                                                                                                                        break a
	                                                                                                                                                                                                                                                                                    }
	                                                                                                                                                                                                                                                                                    c[564] = (c[564] | 0) + 1;
	                                                                                                                                                                                                                                                                                    c[68] = c[68] | 131072;
	                                                                                                                                                                                                                                                                                    break b
	                                                                                                                                                                                                                                                                                } while (0);
	                                                                                                                                                                                                                                                                                c[k >> 2] = (c[k >> 2] | 0) + 1;
	                                                                                                                                                                                                                                                                                c[50] = (c[50] | 0) + 1;
	                                                                                                                                                                                                                                                                                c[554] = c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2];
	                                                                                                                                                                                                                                                                                break b
	                                                                                                                                                                                                                                                                            } while (0);
	                                                                                                                                                                                                                                                                            c[k >> 2] = (c[k >> 2] | 0) + 1;
	                                                                                                                                                                                                                                                                            c[548] = c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2];
	                                                                                                                                                                                                                                                                            break b
	                                                                                                                                                                                                                                                                        } while (0);
	                                                                                                                                                                                                                                                                        c[k >> 2] = (c[k >> 2] | 0) + 1;
	                                                                                                                                                                                                                                                                        Zb(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0);
	                                                                                                                                                                                                                                                                        break b
	                                                                                                                                                                                                                                                                    } while (0);
	                                                                                                                                                                                                                                                                    c[534] = (c[534] | 0) + 1;
	                                                                                                                                                                                                                                                                    break b
	                                                                                                                                                                                                                                                                } while (0);
	                                                                                                                                                                                                                                                                c[68] = c[68] & -65537;
	                                                                                                                                                                                                                                                                break b
	                                                                                                                                                                                                                                                            } while (0);
	                                                                                                                                                                                                                                                            c[68] = c[68] | 2048;
	                                                                                                                                                                                                                                                            Tk(199);
	                                                                                                                                                                                                                                                            break b
	                                                                                                                                                                                                                                                        } while (0);
	                                                                                                                                                                                                                                                        c[k >> 2] = (c[k >> 2] | 0) + 1;
	                                                                                                                                                                                                                                                        c[512] = c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2];
	                                                                                                                                                                                                                                                        c[78] = (c[78] | 0) + 1;
	                                                                                                                                                                                                                                                        break b
	                                                                                                                                                                                                                                                    } while (0);
	                                                                                                                                                                                                                                                    c[k >> 2] = (c[k >> 2] | 0) + 1;
	                                                                                                                                                                                                                                                    c[502] = c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2];
	                                                                                                                                                                                                                                                    c[78] = (c[78] | 0) + 1;
	                                                                                                                                                                                                                                                    break b
	                                                                                                                                                                                                                                                } while (0);
	                                                                                                                                                                                                                                                c[k >> 2] = (c[k >> 2] | 0) + 1;
	                                                                                                                                                                                                                                                c[494] = c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2];
	                                                                                                                                                                                                                                                c[78] = (c[78] | 0) + 1;
	                                                                                                                                                                                                                                                c[68] = c[68] | 2;
	                                                                                                                                                                                                                                                break b
	                                                                                                                                                                                                                                            } while (0);
	                                                                                                                                                                                                                                            c[484] = (c[484] | 0) + 1;
	                                                                                                                                                                                                                                            break b
	                                                                                                                                                                                                                                        } while (0);
	                                                                                                                                                                                                                                        c[474] = (c[474] | 0) + 1;
	                                                                                                                                                                                                                                        break b
	                                                                                                                                                                                                                                    } while (0);
	                                                                                                                                                                                                                                    c[468] = (c[468] | 0) + 1;
	                                                                                                                                                                                                                                    c[68] = c[68] | 512;
	                                                                                                                                                                                                                                    break b
	                                                                                                                                                                                                                                } while (0);
	                                                                                                                                                                                                                                c[462] = (c[462] | 0) + 1;
	                                                                                                                                                                                                                                c[50] = (c[50] | 0) + 1;
	                                                                                                                                                                                                                                break b
	                                                                                                                                                                                                                            } while (0);
	                                                                                                                                                                                                                            c[454] = (c[454] | 0) + 1;
	                                                                                                                                                                                                                            break b
	                                                                                                                                                                                                                        } while (0);
	                                                                                                                                                                                                                        c[k >> 2] = (c[k >> 2] | 0) + 1;
	                                                                                                                                                                                                                        if (!(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0))break b;
	                                                                                                                                                                                                                        c[440] = MT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) | 0;
	                                                                                                                                                                                                                        if ((c[440] | 0) != 1)break b;
	                                                                                                                                                                                                                        c[422] = (c[422] | 0) + 1;
	                                                                                                                                                                                                                        He(0) | 0;
	                                                                                                                                                                                                                        break b
	                                                                                                                                                                                                                    } while (0);
	                                                                                                                                                                                                                    c[422] = (c[422] | 0) + 1;
	                                                                                                                                                                                                                    c[440] = 1;
	                                                                                                                                                                                                                    He(0) | 0;
	                                                                                                                                                                                                                    break b
	                                                                                                                                                                                                                } while (0);
	                                                                                                                                                                                                                c[k >> 2] = (c[k >> 2] | 0) + 1;
	                                                                                                                                                                                                                d = c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0;
	                                                                                                                                                                                                                c[f >> 2] = 1728;
	                                                                                                                                                                                                                if ((bT(d, 1720, f) | 0) == 1) {
	                                                                                                                                                                                                                    wl(195, 196, 197, 198) | 0;
	                                                                                                                                                                                                                    break b
	                                                                                                                                                                                                                } else {
	                                                                                                                                                                                                                    c[432] = 0;
	                                                                                                                                                                                                                    break b
	                                                                                                                                                                                                                }
	                                                                                                                                                                                                            } while (0);
	                                                                                                                                                                                                            c[422] = (c[422] | 0) + 1;
	                                                                                                                                                                                                            He(0) | 0;
	                                                                                                                                                                                                            c[68] = c[68] | 256;
	                                                                                                                                                                                                            break b
	                                                                                                                                                                                                        } while (0);
	                                                                                                                                                                                                        c[k >> 2] = (c[k >> 2] | 0) + 1;
	                                                                                                                                                                                                        c[408] = c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2];
	                                                                                                                                                                                                        vd(1640, 1648) | 0;
	                                                                                                                                                                                                        break b
	                                                                                                                                                                                                    } while (0);
	                                                                                                                                                                                                    c[400] = (c[400] | 0) + 1;
	                                                                                                                                                                                                    break b
	                                                                                                                                                                                                } while (0);
	                                                                                                                                                                                                c[390] = (c[390] | 0) + 1;
	                                                                                                                                                                                                break b
	                                                                                                                                                                                            } while (0);
	                                                                                                                                                                                            c[380] = (c[380] | 0) + 1;
	                                                                                                                                                                                            c[68] = c[68] | 14;
	                                                                                                                                                                                            break b
	                                                                                                                                                                                        } while (0);
	                                                                                                                                                                                        c[370] = (c[370] | 0) + 1;
	                                                                                                                                                                                        c[68] = c[68] | 14;
	                                                                                                                                                                                        break b
	                                                                                                                                                                                    } while (0);
	                                                                                                                                                                                    c[362] = (c[362] | 0) + 1;
	                                                                                                                                                                                    c[68] = c[68] | 14;
	                                                                                                                                                                                    break b
	                                                                                                                                                                                } while (0);
	                                                                                                                                                                                c[356] = (c[356] | 0) + 1;
	                                                                                                                                                                                c[33952] = 1;
	                                                                                                                                                                                break b
	                                                                                                                                                                            } while (0);
	                                                                                                                                                                            c[33956] = 1;
	                                                                                                                                                                            Ee(1) | 0;
	                                                                                                                                                                            c[68] = c[68] | 128;
	                                                                                                                                                                            break b
	                                                                                                                                                                        } while (0);
	                                                                                                                                                                        c[33956] = 0;
	                                                                                                                                                                        Ee(0) | 0;
	                                                                                                                                                                        c[68] = c[68] | 64;
	                                                                                                                                                                        break b
	                                                                                                                                                                    } while (0);
	                                                                                                                                                                    c[308] = (c[308] | 0) + 1;
	                                                                                                                                                                    c[68] = c[68] | 1024;
	                                                                                                                                                                    c[68] = c[68] | 262144;
	                                                                                                                                                                    break b
	                                                                                                                                                                } while (0);
	                                                                                                                                                                c[308] = (c[308] | 0) + 1;
	                                                                                                                                                                c[68] = c[68] | 1024;
	                                                                                                                                                                c[68] = c[68] | 32768;
	                                                                                                                                                                break b
	                                                                                                                                                            } while (0);
	                                                                                                                                                            c[308] = (c[308] | 0) + 1;
	                                                                                                                                                            c[68] = c[68] | 1024;
	                                                                                                                                                            break b
	                                                                                                                                                        } while (0);
	                                                                                                                                                        c[298] = (c[298] | 0) + 1;
	                                                                                                                                                        break b
	                                                                                                                                                    } while (0);
	                                                                                                                                                    c[290] = (c[290] | 0) + 1;
	                                                                                                                                                    break b
	                                                                                                                                                } while (0);
	                                                                                                                                                c[272] = (c[272] | 0) + 1;
	                                                                                                                                                c[282] = 10;
	                                                                                                                                                break b
	                                                                                                                                            } while (0);
	                                                                                                                                            c[272] = (c[272] | 0) + 1;
	                                                                                                                                            break b
	                                                                                                                                        } while (0);
	                                                                                                                                        if (c[266] | 0) {
	                                                                                                                                            c[266] = (c[266] | 0) * 10;
	                                                                                                                                            break b
	                                                                                                                                        } else {
	                                                                                                                                            c[266] = 100;
	                                                                                                                                            break b
	                                                                                                                                        }
	                                                                                                                                    } while (0);
	                                                                                                                                    c[258] = (c[258] | 0) + 1;
	                                                                                                                                    break b
	                                                                                                                                } while (0);
	                                                                                                                                c[252] = (c[252] | 0) + 1;
	                                                                                                                                break b
	                                                                                                                            } while (0);
	                                                                                                                            c[244] = (c[244] | 0) + 1;
	                                                                                                                            break b
	                                                                                                                        } while (0);
	                                                                                                                        c[236] = (c[236] | 0) + 1;
	                                                                                                                        break b
	                                                                                                                    } while (0);
	                                                                                                                    c[k >> 2] = (c[k >> 2] | 0) + 1;
	                                                                                                                    c[226] = c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2];
	                                                                                                                    c[180] = (c[180] | 0) + 1;
	                                                                                                                    c[68] = c[68] | 4;
	                                                                                                                    break b
	                                                                                                                } while (0);
	                                                                                                                c[k >> 2] = (c[k >> 2] | 0) + 1;
	                                                                                                                c[216] = c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2];
	                                                                                                                c[180] = (c[180] | 0) + 1;
	                                                                                                                c[68] = c[68] | 4;
	                                                                                                                break b
	                                                                                                            } while (0);
	                                                                                                            c[206] = (c[206] | 0) + 1;
	                                                                                                            c[180] = (c[180] | 0) + 1;
	                                                                                                            c[68] = c[68] | 4;
	                                                                                                            break b
	                                                                                                        } while (0);
	                                                                                                        c[196] = (c[196] | 0) + 1;
	                                                                                                        c[68] = c[68] | 16;
	                                                                                                        break b
	                                                                                                    } while (0);
	                                                                                                    c[180] = (c[180] | 0) + 1;
	                                                                                                    c[190] = (c[190] | 0) + 1;
	                                                                                                    c[68] = c[68] | 8;
	                                                                                                    break b
	                                                                                                } while (0);
	                                                                                                c[180] = (c[180] | 0) + 1;
	                                                                                                c[68] = c[68] | 4;
	                                                                                                break b
	                                                                                            } while (0);
	                                                                                            c[170] = (c[170] | 0) + 1;
	                                                                                            c[68] = c[68] | 4;
	                                                                                            break b
	                                                                                        } while (0);
	                                                                                        c[160] = (c[160] | 0) + 1;
	                                                                                        break b
	                                                                                    } while (0);
	                                                                                    c[152] = (c[152] | 0) + 1;
	                                                                                    break b
	                                                                                } while (0);
	                                                                                c[146] = (c[146] | 0) + 1;
	                                                                                break b
	                                                                            } while (0);
	                                                                            c[138] = (c[138] | 0) + 1;
	                                                                            break b
	                                                                        } while (0);
	                                                                        c[k >> 2] = (c[k >> 2] | 0) + 1;
	                                                                        c[128] = c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2];
	                                                                        break b
	                                                                    } while (0);
	                                                                    c[50] = (c[50] | 0) + 1;
	                                                                    break b
	                                                                } while (0);
	                                                                Ub(c[c[j >> 2] >> 2] | 0);
	                                                                c[n >> 2] = 1;
	                                                                break b
	                                                            } while (0);
	                                                            c[68] = c[68] | 4096;
	                                                            break b
	                                                        } while (0);
	                                                        c[68] = c[68] | 16384;
	                                                        break b
	                                                    } while (0);
	                                                    c[68] = c[68] | 8192;
	                                                    break b
	                                                } while (0);
	                                                c[84] = (c[84] | 0) + 1;
	                                                c[68] = c[68] | 2097152;
	                                                break b
	                                            } while (0);
	                                            c[78] = (c[78] | 0) + 1;
	                                            c[68] = c[68] | 2;
	                                            break b
	                                        } while (0);
	                                        c[68] = c[68] | 524288;
	                                        break
	                                    }
	                                    c[66] = (c[66] | 0) + 1;
	                                    c[68] = c[68] | 1;
	                                    break
	                                }
	                                c[56] = (c[56] | 0) + 1;
	                                break
	                            }
	                            c[48] = (c[48] | 0) + 1;
	                            c[50] = 1;
	                            break
	                        }
	                        c[42] = (c[42] | 0) + 1
	                    } while (0);
	                    c[k >> 2] = (c[k >> 2] | 0) + 1
	                }
	                if ((w | 0) == 206) {
	                    d = c[o >> 2] | 0;
	                    c[f >> 2] = c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2];
	                    Ka(d | 0, 2264, f | 0) | 0;
	                    Tb(c[c[j >> 2] >> 2] | 0);
	                    c[g >> 2] = 1;
	                    v = c[g >> 2] | 0;
	                    i = e;
	                    return v | 0
	                }
	                do if ((c[400] | 0) == 0 & (c[390] | 0) != 0) {
	                    c[q >> 2] = cb(2288) | 0;
	                    if (c[q >> 2] | 0) {
	                        Cw(c[q >> 2] | 0);
	                        break
	                    } else {
	                        Ka(c[o >> 2] | 0, 2312, f | 0) | 0;
	                        break
	                    }
	                } while (0);
	                if (c[468] | 0)nQ(1) | 0; else nQ(2) | 0;
	                if (c[484] | 0) {
	                    nx(200) | 0;
	                    ox(201) | 0
	                }
	                c[p >> 2] = cb(2352) | 0;
	                if (c[p >> 2] | 0)c[33988] = c[p >> 2];
	                c[592] = Uk() | 0;
	                Tk(202);
	                Fe(1) | 0;
	                if (c[180] | 0)c[33958] = c[33958] | 2;
	                if (c[190] | 0)c[33958] = c[33958] | 4;
	                if (c[78] | 0)Ge(1) | 0;
	                if (c[196] | 0)c[33954] = 1;
	                if (!((c[138] | 0) == 0 | (c[146] | 0) != 0)) {
	                    Db[c[135904 >> 2] & 511](c[33980] | 0, 2376, f);
	                    Db[c[135904 >> 2] & 511](c[33980] | 0, 2440, f);
	                    p = c[33976] | 0;
	                    q = c[33980] | 0;
	                    c[f >> 2] = c[c[j >> 2] >> 2];
	                    Db[p & 511](q, 2488, f);
	                    q = c[33976] | 0;
	                    p = c[33980] | 0;
	                    c[f >> 2] = c[c[j >> 2] >> 2];
	                    Db[q & 511](p, 2536, f)
	                }
	                if ((c[512] | 0) != 0 & (c[474] | 0) == 0 & (c[454] | 0) == 0) {
	                    c[33958] = c[33958] | 1;
	                    c[68] = c[68] | 4;
	                    if (c[252] | 0)bc();
	                    c[r >> 2] = iS(c[512] | 0) | 0;
	                    c[650] = kS(c[r >> 2] | 0) | 0;
	                    if (!(c[650] | 0)) {
	                        p = c[33976] | 0;
	                        q = c[33980] | 0;
	                        c[f >> 2] = c[512];
	                        Db[p & 511](q, 2608, f);
	                        c[662] = 5;
	                        c[512] = 0
	                    }
	                    jS(c[r >> 2] | 0);
	                    if (c[252] | 0)cc(2656, f)
	                }
	                if ((c[494] | 0) != 0 & (c[474] | 0) == 0 & (c[454] | 0) == 0) {
	                    c[33958] = c[33958] | 1;
	                    c[68] = c[68] | 4;
	                    if (c[252] | 0)bc();
	                    c[s >> 2] = YM(c[494] | 0) | 0;
	                    $M(c[s >> 2] | 0, 203, 203, c[o >> 2] | 0);
	                    c[670] = _M(c[s >> 2] | 0) | 0;
	                    if (!(c[670] | 0)) {
	                        r = c[33976] | 0;
	                        q = c[33980] | 0;
	                        c[f >> 2] = c[494];
	                        Db[r & 511](q, 2688, f);
	                        c[662] = 5;
	                        c[494] = 0
	                    }
	                    ZM(c[s >> 2] | 0);
	                    if (c[252] | 0)cc(2656, f)
	                } else if ((c[502] | 0) != 0 & (c[454] | 0) == 0) {
	                    if (c[252] | 0)bc();
	                    c[t >> 2] = XA(c[502] | 0) | 0;
	                    aB(c[t >> 2] | 0, 203, 203, c[o >> 2] | 0);
	                    c[682] = $A(c[t >> 2] | 0) | 0;
	                    if (!(c[682] | 0)) {
	                        s = c[33976] | 0;
	                        q = c[33980] | 0;
	                        c[f >> 2] = c[502];
	                        Db[s & 511](q, 2736, f);
	                        c[662] = 5;
	                        c[502] = 0
	                    }
	                    YA(c[t >> 2] | 0);
	                    if (c[252] | 0)cc(2656, f)
	                }
	                if ((c[548] | 0) != 0 & (c[462] | 0) == 0 ? (c[694] = MQ(c[548] | 0, 0, 0, 0) | 0, (c[694] | 0) == 0) : 0) {
	                    t = c[33976] | 0;
	                    q = c[33980] | 0;
	                    c[f >> 2] = c[548];
	                    Db[t & 511](q, 2784, f);
	                    c[662] = 7;
	                    c[548] = 0
	                }
	                c[k >> 2] = 1;
	                while (1) {
	                    if ((c[k >> 2] | 0) >= (c[h >> 2] | 0))break;
	                    c:do if ((PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1608) | 0) != 0 ? (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1616) | 0) != 0 : 0) {
	                        do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 480) | 0) {
	                            if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 488) | 0))break;
	                            if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 496) | 0))break;
	                            do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 832) | 0) {
	                                if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 848) | 0))break;
	                                do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 2144) | 0) {
	                                    if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 2152) | 0))break;
	                                    do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 872) | 0) {
	                                        if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 888) | 0))break;
	                                        do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1944) | 0) {
	                                            if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1960) | 0))break;
	                                            do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1696) | 0) {
	                                                if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1704) | 0))break;
	                                                do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1768) | 0) {
	                                                    if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1776) | 0))break;
	                                                    do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1984) | 0) {
	                                                        if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 1992) | 0))break;
	                                                        do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 2016) | 0) {
	                                                            if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 2032) | 0))break;
	                                                            do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 2160) | 0) {
	                                                                if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 2176) | 0))break;
	                                                                do if (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 2200) | 0) {
	                                                                    if (!(PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 2208) | 0))break;
	                                                                    if ((c[252] | 0) != 0 & (c[266] | 0) != 0)bc();
	                                                                    if ((a[c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] >> 0] | 0) == 45 ? (PT(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, 144) | 0) != 0 : 0)break c;
	                                                                    do if (c[266] | 0) {
	                                                                        c[u >> 2] = 0;
	                                                                        c[l >> 2] = 0;
	                                                                        while (1) {
	                                                                            if ((c[l >> 2] | 0) >= (c[266] | 0))break;
	                                                                            do if (c[454] | 0)dc(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0); else {
	                                                                                if (c[474] | 0) {
	                                                                                    ec(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0);
	                                                                                    break
	                                                                                }
	                                                                                if (!(c[u >> 2] | 0))c[u >> 2] = Be() | 0;
	                                                                                fc(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0, c[u >> 2] | 0)
	                                                                            } while (0);
	                                                                            c[l >> 2] = (c[l >> 2] | 0) + 1
	                                                                        }
	                                                                        if (!(c[u >> 2] | 0))break;
	                                                                        Ae(c[u >> 2] | 0)
	                                                                    } else {
	                                                                        c[704] = 0;
	                                                                        do if (!(c[454] | 0)) {
	                                                                            q = c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0;
	                                                                            if (c[474] | 0) {
	                                                                                ec(q);
	                                                                                break
	                                                                            } else {
	                                                                                fc(q, 0);
	                                                                                break
	                                                                            }
	                                                                        } else dc(c[(c[j >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0); while (0);
	                                                                        if (!((c[484] | 0) != 0 & (c[704] | 0) != 0))break;
	                                                                        q = c[o >> 2] | 0;
	                                                                        c[f >> 2] = c[704];
	                                                                        Ka(q | 0, 2824, f | 0) | 0;
	                                                                        c[662] = 8
	                                                                    } while (0);
	                                                                    c[m >> 2] = (c[m >> 2] | 0) + 1;
	                                                                    if (!((c[252] | 0) != 0 & (c[266] | 0) != 0))break c;
	                                                                    c[f >> 2] = c[266];
	                                                                    cc(2856, f);
	                                                                    break c
	                                                                } while (0);
	                                                                c[k >> 2] = (c[k >> 2] | 0) + 1;
	                                                                break c
	                                                            } while (0);
	                                                            c[k >> 2] = (c[k >> 2] | 0) + 1;
	                                                            break c
	                                                        } while (0);
	                                                        c[k >> 2] = (c[k >> 2] | 0) + 1;
	                                                        break c
	                                                    } while (0);
	                                                    c[k >> 2] = (c[k >> 2] | 0) + 1;
	                                                    break c
	                                                } while (0);
	                                                c[k >> 2] = (c[k >> 2] | 0) + 1;
	                                                break c
	                                            } while (0);
	                                            c[k >> 2] = (c[k >> 2] | 0) + 1;
	                                            break c
	                                        } while (0);
	                                        c[k >> 2] = (c[k >> 2] | 0) + 1;
	                                        break c
	                                    } while (0);
	                                    c[k >> 2] = (c[k >> 2] | 0) + 1;
	                                    break c
	                                } while (0);
	                                c[k >> 2] = (c[k >> 2] | 0) + 1;
	                                break c
	                            } while (0);
	                            c[k >> 2] = (c[k >> 2] | 0) + 1;
	                            break c
	                        } while (0);
	                        c[k >> 2] = (c[k >> 2] | 0) + 1
	                    } else w = 257; while (0);
	                    if ((w | 0) == 257) {
	                        w = 0;
	                        c[k >> 2] = (c[k >> 2] | 0) + 1
	                    }
	                    c[k >> 2] = (c[k >> 2] | 0) + 1
	                }
	                if (c[258] | 0)fc(0, 0);
	                if (!((c[138] | 0) == 0 | (c[146] | 0) != 0))Db[c[135904 >> 2] & 511](c[33980] | 0, 2872, f);
	                if ((((c[m >> 2] | 0) != 0 | (c[258] | 0) != 0) ^ 1) & (c[n >> 2] | 0) == 0)Tb(c[c[j >> 2] >> 2] | 0);
	                if (c[650] | 0)hS(c[650] | 0);
	                if (c[670] | 0)VM(c[670] | 0);
	                if (c[682] | 0)WA(c[682] | 0);
	                XM();
	                if (c[694] | 0)EQ(c[694] | 0);
	                dg();
	                ml();
	                c[g >> 2] = c[662];
	                v = c[g >> 2] | 0;
	                i = e;
	                return v | 0
	            }

	            function Tb(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                e = b + 4 | 0;
	                c[e >> 2] = a;
	                c[d >> 2] = c[e >> 2];
	                Wa(56872, d | 0) | 0;
	                Wa(56912, d | 0) | 0;
	                Wa(56976, d | 0) | 0;
	                Wa(57040, d | 0) | 0;
	                Wa(57096, d | 0) | 0;
	                Wa(57136, d | 0) | 0;
	                Wa(57200, d | 0) | 0;
	                Wa(57264, d | 0) | 0;
	                Wa(57328, d | 0) | 0;
	                Wa(57384, d | 0) | 0;
	                Wa(57440, d | 0) | 0;
	                Wa(57504, d | 0) | 0;
	                Wa(57552, d | 0) | 0;
	                Wa(57608, d | 0) | 0;
	                Wa(57672, d | 0) | 0;
	                Wa(57736, d | 0) | 0;
	                Wa(57792, d | 0) | 0;
	                Wa(57832, d | 0) | 0;
	                Wa(57880, d | 0) | 0;
	                Wa(57952, d | 0) | 0;
	                Wa(58016, d | 0) | 0;
	                Wa(58088, d | 0) | 0;
	                Wa(58160, d | 0) | 0;
	                Wa(58192, d | 0) | 0;
	                Wa(58248, d | 0) | 0;
	                Wa(58304, d | 0) | 0;
	                Wa(58352, d | 0) | 0;
	                Wa(58384, d | 0) | 0;
	                Wa(58448, d | 0) | 0;
	                Wa(58496, d | 0) | 0;
	                Wa(58544, d | 0) | 0;
	                Wa(58616, d | 0) | 0;
	                Wa(58648, d | 0) | 0;
	                Wa(58712, d | 0) | 0;
	                Wa(58776, d | 0) | 0;
	                Wa(58824, d | 0) | 0;
	                Wa(58880, d | 0) | 0;
	                Wa(58928, d | 0) | 0;
	                Wa(58984, d | 0) | 0;
	                Wa(59040, d | 0) | 0;
	                Wa(59096, d | 0) | 0;
	                Wa(59144, d | 0) | 0;
	                Wa(59208, d | 0) | 0;
	                Wa(59280, d | 0) | 0;
	                Wa(59344, d | 0) | 0;
	                Wa(59408, d | 0) | 0;
	                Wa(59480, d | 0) | 0;
	                Wa(59536, d | 0) | 0;
	                Wa(59576, d | 0) | 0;
	                Wa(59640, d | 0) | 0;
	                c[d >> 2] = 59736;
	                Wa(59696, d | 0) | 0;
	                Wa(59760, d | 0) | 0;
	                Wa(59800, d | 0) | 0;
	                Wa(59848, d | 0) | 0;
	                Wa(59888, d | 0) | 0;
	                Wa(59952, d | 0) | 0;
	                Wa(60008, d | 0) | 0;
	                Wa(60048, d | 0) | 0;
	                Wa(60120, d | 0) | 0;
	                Wa(60192, d | 0) | 0;
	                Wa(60256, d | 0) | 0;
	                Wa(60312, d | 0) | 0;
	                Wa(60368, d | 0) | 0;
	                Wa(60432, d | 0) | 0;
	                Wa(60496, d | 0) | 0;
	                Wa(60560, d | 0) | 0;
	                Wa(60616, d | 0) | 0;
	                Wa(60680, d | 0) | 0;
	                Wa(60744, d | 0) | 0;
	                Wa(60808, d | 0) | 0;
	                Wa(60856, d | 0) | 0;
	                i = b;
	                return
	            }

	            function Ub(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                e = b + 8 | 0;
	                c[e >> 2] = a;
	                a = c[o >> 2] | 0;
	                f = c[33946] | 0;
	                c[d >> 2] = c[e >> 2];
	                c[d + 4 >> 2] = f;
	                Ka(a | 0, 56440, d | 0) | 0;
	                Ka(c[o >> 2] | 0, 56472, d | 0) | 0;
	                if (Me(1) | 0)Ka(c[o >> 2] | 0, 56496, d | 0) | 0;
	                if (Me(2) | 0)Ka(c[o >> 2] | 0, 56512, d | 0) | 0;
	                if (Me(3) | 0)Ka(c[o >> 2] | 0, 56520, d | 0) | 0;
	                if (Me(4) | 0)Ka(c[o >> 2] | 0, 56528, d | 0) | 0;
	                if (Me(5) | 0)Ka(c[o >> 2] | 0, 56536, d | 0) | 0;
	                if (Me(6) | 0)Ka(c[o >> 2] | 0, 56544, d | 0) | 0;
	                if (Me(7) | 0)Ka(c[o >> 2] | 0, 56560, d | 0) | 0;
	                if (Me(8) | 0)Ka(c[o >> 2] | 0, 56568, d | 0) | 0;
	                if (Me(9) | 0)Ka(c[o >> 2] | 0, 56576, d | 0) | 0;
	                if (Me(10) | 0)Ka(c[o >> 2] | 0, 56584, d | 0) | 0;
	                if (Me(11) | 0)Ka(c[o >> 2] | 0, 56592, d | 0) | 0;
	                if (Me(12) | 0)Ka(c[o >> 2] | 0, 56608, d | 0) | 0;
	                if (Me(13) | 0)Ka(c[o >> 2] | 0, 56616, d | 0) | 0;
	                if (Me(14) | 0)Ka(c[o >> 2] | 0, 56624, d | 0) | 0;
	                if (Me(15) | 0)Ka(c[o >> 2] | 0, 56632, d | 0) | 0;
	                if (Me(16) | 0)Ka(c[o >> 2] | 0, 56648, d | 0) | 0;
	                if (Me(17) | 0)Ka(c[o >> 2] | 0, 56656, d | 0) | 0;
	                if (Me(18) | 0)Ka(c[o >> 2] | 0, 56672, d | 0) | 0;
	                if (Me(19) | 0)Ka(c[o >> 2] | 0, 56688, d | 0) | 0;
	                if (Me(20) | 0)Ka(c[o >> 2] | 0, 56696, d | 0) | 0;
	                if (Me(21) | 0)Ka(c[o >> 2] | 0, 56712, d | 0) | 0;
	                if (Me(22) | 0)Ka(c[o >> 2] | 0, 56728, d | 0) | 0;
	                if (Me(23) | 0)Ka(c[o >> 2] | 0, 56744, d | 0) | 0;
	                if (Me(24) | 0)Ka(c[o >> 2] | 0, 56760, d | 0) | 0;
	                if (Me(25) | 0)Ka(c[o >> 2] | 0, 56768, d | 0) | 0;
	                if (Me(26) | 0)Ka(c[o >> 2] | 0, 56784, d | 0) | 0;
	                if (Me(27) | 0)Ka(c[o >> 2] | 0, 56800, d | 0) | 0;
	                if (Me(28) | 0)Ka(c[o >> 2] | 0, 56816, d | 0) | 0;
	                if (Me(29) | 0)Ka(c[o >> 2] | 0, 56824, d | 0) | 0;
	                if (Me(30) | 0)Ka(c[o >> 2] | 0, 56840, d | 0) | 0;
	                if (Me(31) | 0)Ka(c[o >> 2] | 0, 56856, d | 0) | 0;
	                if (!(Me(33) | 0)) {
	                    g = c[o >> 2] | 0;
	                    Ka(g | 0, 3760, d | 0) | 0;
	                    i = b;
	                    return
	                }
	                Ka(c[o >> 2] | 0, 56864, d | 0) | 0;
	                g = c[o >> 2] | 0;
	                Ka(g | 0, 3760, d | 0) | 0;
	                i = b;
	                return
	            }

	            function Vb(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                ql(c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function Wb(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = nl(c[e >> 2] | 0) | 0;
	                if ((c[f >> 2] | 0) != 0 ? (e = tl() | 0, (e | 0) > (c[432] | 0)) : 0) {
	                    Vc();
	                    ql(c[f >> 2] | 0);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function Xb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = pl(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                if ((c[h >> 2] | 0) != 0 ? (g = tl() | 0, (g | 0) > (c[432] | 0)) : 0) {
	                    Vc();
	                    ql(c[h >> 2] | 0);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[e >> 2] = c[h >> 2];
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function Yb(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = sl(c[e >> 2] | 0) | 0;
	                if ((c[f >> 2] | 0) != 0 ? (e = tl() | 0, (e | 0) > (c[432] | 0)) : 0) {
	                    Vc();
	                    zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function Zb(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b;
	                f = b + 8 | 0;
	                g = b + 4 | 0;
	                c[f >> 2] = a;
	                if (!(c[f >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                while (1) {
	                    if (!(d[c[f >> 2] >> 0] | 0)) {
	                        h = 20;
	                        break
	                    }
	                    if ((c[13962] | 0) >= 64)break;
	                    c[g >> 2] = c[f >> 2];
	                    while (1) {
	                        if ((d[c[g >> 2] >> 0] | 0 | 0) == 32)j = 1; else j = (d[c[g >> 2] >> 0] | 0 | 0) == 58;
	                        k = c[g >> 2] | 0;
	                        if (!j)break;
	                        c[g >> 2] = k + 1
	                    }
	                    c[f >> 2] = k;
	                    while (1) {
	                        if ((d[c[g >> 2] >> 0] | 0 | 0) != 0 ? (d[c[g >> 2] >> 0] | 0 | 0) != 32 : 0)l = (d[c[g >> 2] >> 0] | 0 | 0) != 58; else l = 0;
	                        m = c[g >> 2] | 0;
	                        if (!l)break;
	                        c[g >> 2] = m + 1
	                    }
	                    if ((m | 0) == (c[f >> 2] | 0))continue;
	                    a = ly(c[f >> 2] | 0, (c[g >> 2] | 0) - (c[f >> 2] | 0) | 0) | 0;
	                    c[55888 + (c[13962] << 2) >> 2] = a;
	                    if (c[55888 + (c[13962] << 2) >> 2] | 0)c[13962] = (c[13962] | 0) + 1;
	                    c[f >> 2] = c[g >> 2]
	                }
	                if ((h | 0) == 20) {
	                    i = b;
	                    return
	                }
	                Ka(c[o >> 2] | 0, 56360, e | 0) | 0;
	                i = b;
	                return
	            }

	            function _b(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                c[d >> 2] = a;
	                a = iT(4) | 0;
	                c[c[d >> 2] >> 2] = a;
	                if (!(c[c[d >> 2] >> 2] | 0)) {
	                    Ka(c[o >> 2] | 0, 56312, b | 0) | 0;
	                    qb(9)
	                } else {
	                    c[c[c[d >> 2] >> 2] >> 2] = -2123209900;
	                    c[704] = (c[704] | 0) + 1;
	                    i = b;
	                    return
	                }
	            }

	            function $b(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[c[d >> 2] >> 2] | 0))Ea(56200, 56224, 3119, 56248);
	                if ((c[c[c[d >> 2] >> 2] >> 2] | 0) == -2123209900) {
	                    jT(c[c[d >> 2] >> 2] | 0);
	                    c[704] = (c[704] | 0) + -1;
	                    i = b;
	                    return
	                } else Ea(56264, 56224, 3120, 56248)
	            }

	            function ac(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                f = i;
	                i = i + 64 | 0;
	                g = f;
	                h = f + 48 | 0;
	                j = f + 44 | 0;
	                k = f + 40 | 0;
	                l = f + 36 | 0;
	                m = f + 32 | 0;
	                n = f + 28 | 0;
	                p = f + 24 | 0;
	                q = f + 20 | 0;
	                r = f + 16 | 0;
	                s = f + 12 | 0;
	                t = f + 8 | 0;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[n >> 2] = 0;
	                c[p >> 2] = 0;
	                c[r >> 2] = c[j >> 2];
	                c[s >> 2] = c[j >> 2];
	                a:do if ((c[13962] | 0) > 0 & (c[s >> 2] | 0) != 0)while (1) {
	                    if (!(a[c[s >> 2] >> 0] | 0))break a;
	                    if ((a[c[s >> 2] >> 0] | 0) == 47)c[r >> 2] = (c[s >> 2] | 0) + 1;
	                    c[s >> 2] = (c[s >> 2] | 0) + 1
	                } while (0);
	                if ((c[l >> 2] | 0) != 0 ? (c[c[l >> 2] >> 2] | 0) != 0 : 0) {
	                    c[n >> 2] = c[(c[c[l >> 2] >> 2] | 0) + 84 >> 2];
	                    c[p >> 2] = c[(c[c[l >> 2] >> 2] | 0) + 88 >> 2];
	                    c[(c[c[l >> 2] >> 2] | 0) + 84 >> 2] = 0;
	                    c[(c[c[l >> 2] >> 2] | 0) + 88 >> 2] = 0
	                }
	                if ((c[592] | 0) != 0 ? (c[m >> 2] = vb[c[2368 >> 2] & 511](c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0, (c[m >> 2] | 0) != 0) : 0) {
	                    if (c[n >> 2] | 0)c[(c[c[l >> 2] >> 2] | 0) + 84 >> 2] = c[n >> 2];
	                    if (c[p >> 2] | 0)c[(c[c[l >> 2] >> 2] | 0) + 88 >> 2] = c[p >> 2];
	                    if (c[534] | 0) {
	                        s = c[o >> 2] | 0;
	                        e = (c[k >> 2] | 0) != 0 ? c[k >> 2] | 0 : 55152;
	                        c[g >> 2] = (c[j >> 2] | 0) != 0 ? c[j >> 2] | 0 : 55152;
	                        c[g + 4 >> 2] = e;
	                        Ka(s | 0, 55856, g | 0) | 0
	                    }
	                    c[h >> 2] = c[m >> 2];
	                    u = c[h >> 2] | 0;
	                    i = f;
	                    return u | 0
	                }
	                c[q >> 2] = 0;
	                while (1) {
	                    if ((c[q >> 2] | 0) >= (c[13962] | 0))break;
	                    c[t >> 2] = my(c[55888 + (c[q >> 2] << 2) >> 2] | 0) | 0;
	                    c[t >> 2] = By(c[t >> 2] | 0, 56152) | 0;
	                    c[t >> 2] = By(c[t >> 2] | 0, c[r >> 2] | 0) | 0;
	                    if (c[t >> 2] | 0) {
	                        c[m >> 2] = vb[c[2368 >> 2] & 511](c[t >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0;
	                        if (c[m >> 2] | 0) {
	                            v = 22;
	                            break
	                        }
	                        zb[c[135736 >> 2] & 511](c[t >> 2] | 0)
	                    }
	                    c[q >> 2] = (c[q >> 2] | 0) + 1
	                }
	                if ((v | 0) == 22) {
	                    if (c[n >> 2] | 0)c[(c[c[l >> 2] >> 2] | 0) + 84 >> 2] = c[n >> 2];
	                    if (c[p >> 2] | 0)c[(c[c[l >> 2] >> 2] | 0) + 88 >> 2] = c[p >> 2];
	                    if (c[534] | 0) {
	                        v = c[o >> 2] | 0;
	                        q = (c[k >> 2] | 0) != 0 ? c[k >> 2] | 0 : 55152;
	                        c[g >> 2] = c[t >> 2];
	                        c[g + 4 >> 2] = q;
	                        Ka(v | 0, 55856, g | 0) | 0
	                    }
	                    zb[c[135736 >> 2] & 511](c[t >> 2] | 0);
	                    c[h >> 2] = c[m >> 2];
	                    u = c[h >> 2] | 0;
	                    i = f;
	                    return u | 0
	                }
	                if (c[p >> 2] | 0)c[(c[c[l >> 2] >> 2] | 0) + 88 >> 2] = c[p >> 2];
	                do if (c[n >> 2] | 0) {
	                    c[(c[c[l >> 2] >> 2] | 0) + 84 >> 2] = c[n >> 2];
	                    if (c[j >> 2] | 0) {
	                        p = c[n >> 2] | 0;
	                        m = c[l >> 2] | 0;
	                        c[g >> 2] = c[j >> 2];
	                        Db[p & 511](m, 56160, g);
	                        break
	                    }
	                    if (c[k >> 2] | 0) {
	                        m = c[n >> 2] | 0;
	                        p = c[l >> 2] | 0;
	                        c[g >> 2] = c[k >> 2];
	                        Db[m & 511](p, 56160, g)
	                    }
	                } while (0);
	                c[h >> 2] = 0;
	                u = c[h >> 2] | 0;
	                i = f;
	                return u | 0
	            }

	            function bc() {
	                var a = 0;
	                a = i;
	                mb(55824, 0) | 0;
	                i = a;
	                return
	            }

	            function cc(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 28 | 0;
	                g = d + 24 | 0;
	                h = d + 8 | 0;
	                c[f >> 2] = a;
	                mb(55816, 0) | 0;
	                c[g >> 2] = (c[13954] | 0) - (c[13956] | 0);
	                c[g >> 2] = (c[g >> 2] | 0) * 1e3;
	                c[g >> 2] = (c[g >> 2] | 0) + (((c[13955] | 0) - (c[13957] | 0) | 0) / 1e3 | 0);
	                c[h >> 2] = b;
	                Ca(c[o >> 2] | 0, c[f >> 2] | 0, h | 0) | 0;
	                h = c[o >> 2] | 0;
	                c[e >> 2] = c[g >> 2];
	                Ka(h | 0, 55832, e | 0) | 0;
	                i = d;
	                return
	            }

	            function dc(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                b = i;
	                i = i + 112 | 0;
	                d = b;
	                e = b + 100 | 0;
	                f = b + 96 | 0;
	                g = b + 92 | 0;
	                h = b + 88 | 0;
	                j = b + 12 | 0;
	                k = b + 8 | 0;
	                l = b + 4 | 0;
	                c[e >> 2] = a;
	                c[h >> 2] = -1;
	                c[k >> 2] = 0;
	                c[l >> 2] = 0;
	                a = c[e >> 2] | 0;
	                do if (c[290] | 0) {
	                    if (($a(a | 0, j | 0) | 0) < 0) {
	                        i = b;
	                        return
	                    }
	                    m = La(c[e >> 2] | 0, 0, d | 0) | 0;
	                    c[h >> 2] = m;
	                    if ((m | 0) < 0) {
	                        i = b;
	                        return
	                    }
	                    c[k >> 2] = ob(0, c[j + 36 >> 2] | 0, 1, 1, c[h >> 2] | 0, 0) | 0;
	                    if ((c[k >> 2] | 0) != (-1 | 0)) {
	                        c[f >> 2] = kM(c[k >> 2] | 0, c[j + 36 >> 2] | 0, c[e >> 2] | 0, 0, c[68] | 0) | 0;
	                        break
	                    }
	                    Ra(c[h >> 2] | 0) | 0;
	                    m = c[o >> 2] | 0;
	                    c[d >> 2] = c[e >> 2];
	                    Ka(m | 0, 2920, d | 0) | 0;
	                    c[662] = 4;
	                    i = b;
	                    return
	                } else c[f >> 2] = lM(a, 0, c[68] | 0) | 0; while (0);
	                if ((c[548] | 0) != 0 ? (c[694] = MQ(c[548] | 0, 0, 0, 0) | 0, (c[694] | 0) == 0) : 0) {
	                    a = c[33976] | 0;
	                    m = c[33980] | 0;
	                    c[d >> 2] = c[548];
	                    Db[a & 511](m, 2784, d);
	                    c[662] = 7;
	                    c[548] = 0
	                }
	                if (((c[694] | 0) != 0 ? (c[898] = OQ(c[694] | 0) | 0, (c[898] | 0) != 0) : 0) ? (c[g >> 2] = HQ(c[898] | 0, 0, 0) | 0, (c[g >> 2] | 0) < 0) : 0) {
	                    Ka(c[o >> 2] | 0, 3600, d | 0) | 0;
	                    GQ(c[898] | 0);
	                    c[898] = 0
	                }
	                if (c[f >> 2] | 0) {
	                    if (!(c[196] | 0)) {
	                        if (c[180] | 0)dM(c[f >> 2] | 0, 1, 1) | 0
	                    } else dM(c[f >> 2] | 0, 3, 1) | 0;
	                    if (c[494] | 0) {
	                        if (!((c[252] | 0) == 0 | (c[266] | 0) != 0))bc();
	                        c[g >> 2] = gM(c[f >> 2] | 0, c[494] | 0) | 0;
	                        if ((c[g >> 2] | 0) < 0) {
	                            m = c[33976] | 0;
	                            a = c[33980] | 0;
	                            c[d >> 2] = c[494];
	                            Db[m & 511](a, 2688, d);
	                            c[662] = 5;
	                            c[494] = 0
	                        }
	                        if (!((c[252] | 0) == 0 | (c[266] | 0) != 0))cc(2656, d)
	                    }
	                    if (c[502] | 0) {
	                        if (!((c[252] | 0) == 0 | (c[266] | 0) != 0))bc();
	                        c[g >> 2] = fM(c[f >> 2] | 0, c[502] | 0) | 0;
	                        if ((c[g >> 2] | 0) < 0) {
	                            a = c[33976] | 0;
	                            m = c[33980] | 0;
	                            c[d >> 2] = c[502];
	                            Db[a & 511](m, 55704, d);
	                            c[662] = 5;
	                            c[502] = 0
	                        }
	                        if (!((c[252] | 0) == 0 | (c[266] | 0) != 0))cc(2656, d)
	                    }
	                    if (!((c[252] | 0) == 0 | (c[266] | 0) != 0))bc();
	                    c[g >> 2] = QL(c[f >> 2] | 0) | 0;
	                    while (1) {
	                        if ((c[g >> 2] | 0) != 1)break;
	                        if ((c[42] | 0) != 0 | (c[694] | 0) != 0)pc(c[f >> 2] | 0);
	                        c[g >> 2] = QL(c[f >> 2] | 0) | 0
	                    }
	                    do if (!((c[252] | 0) == 0 | (c[266] | 0) != 0)) {
	                        if (c[494] | 0) {
	                            cc(55744, d);
	                            break
	                        }
	                        if (c[196] | 0) {
	                            cc(55744, d);
	                            break
	                        } else {
	                            cc(2952, d);
	                            break
	                        }
	                    } while (0);
	                    if ((c[196] | 0) != 0 ? (hM(c[f >> 2] | 0) | 0) != 1 : 0) {
	                        m = c[33976] | 0;
	                        a = c[33980] | 0;
	                        c[d >> 2] = c[e >> 2];
	                        Db[m & 511](a, 3448, d);
	                        c[662] = 3
	                    }
	                    do if ((c[494] | 0) != 0 | (c[502] | 0) != 0) {
	                        a = (hM(c[f >> 2] | 0) | 0) != 1;
	                        m = c[o >> 2] | 0;
	                        n = c[e >> 2] | 0;
	                        if (a) {
	                            c[d >> 2] = n;
	                            Ka(m | 0, 3512, d | 0) | 0;
	                            c[662] = 3;
	                            break
	                        } else {
	                            c[d >> 2] = n;
	                            Ka(m | 0, 3496, d | 0) | 0;
	                            break
	                        }
	                    } while (0);
	                    VL(c[f >> 2] | 0);
	                    if (c[g >> 2] | 0) {
	                        g = c[o >> 2] | 0;
	                        c[d >> 2] = c[e >> 2];
	                        Ka(g | 0, 55768, d | 0) | 0;
	                        c[662] = 1
	                    }
	                } else {
	                    g = c[o >> 2] | 0;
	                    c[d >> 2] = c[e >> 2];
	                    Ka(g | 0, 55792, d | 0) | 0;
	                    c[662] = 1
	                }
	                if (c[898] | 0) {
	                    GQ(c[898] | 0);
	                    c[898] = 0
	                }
	                if (!(c[290] | 0)) {
	                    i = b;
	                    return
	                }
	                yk(c[l >> 2] | 0);
	                Ta(c[k >> 2] | 0, c[j + 36 >> 2] | 0) | 0;
	                Ra(c[h >> 2] | 0) | 0;
	                i = b;
	                return
	            }

	            function ec(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, p = 0;
	                b = i;
	                i = i + 48 | 0;
	                d = b;
	                e = b + 36 | 0;
	                f = b + 32 | 0;
	                g = b + 28 | 0;
	                h = b + 24 | 0;
	                j = b + 20 | 0;
	                k = b + 16 | 0;
	                l = b + 12 | 0;
	                m = b + 8 | 0;
	                n = b + 4 | 0;
	                c[e >> 2] = a;
	                c[g >> 2] = 54320;
	                c[h >> 2] = 0;
	                c[k >> 2] = 0;
	                c[l >> 2] = 0;
	                c[13584] = 0;
	                do if (!(c[50] | 0))if (c[468] | 0) {
	                    c[f >> 2] = c[34];
	                    break
	                } else {
	                    c[f >> 2] = c[13588];
	                    break
	                } else c[f >> 2] = c[13586]; while (0);
	                c[h >> 2] = Ck(c[e >> 2] | 0, 0) | 0;
	                do if (c[h >> 2] | 0) {
	                    if (!(c[682] | 0)) {
	                        c[k >> 2] = Be() | 0;
	                        if (!(c[k >> 2] | 0)) {
	                            yk(c[h >> 2] | 0);
	                            break
	                        }
	                        c[l >> 2] = c[c[k >> 2] >> 2];
	                        c[c[k >> 2] >> 2] = c[f >> 2];
	                        c[(c[k >> 2] | 0) + 4 >> 2] = c[g >> 2];
	                        c[j >> 2] = ve(c[k >> 2] | 0, c[h >> 2] | 0, 0) | 0;
	                        if (!(c[j >> 2] | 0)) {
	                            yk(c[h >> 2] | 0);
	                            break
	                        }
	                        Oe(c[k >> 2] | 0, c[j >> 2] | 0) | 0;
	                        Qf(c[k >> 2] | 0) | 0;
	                        if (!(c[(c[k >> 2] | 0) + 8 >> 2] | 0))break;
	                        Ka(c[o >> 2] | 0, 54360, d | 0) | 0;
	                        Th(c[(c[k >> 2] | 0) + 8 >> 2] | 0);
	                        c[(c[k >> 2] | 0) + 8 >> 2] = 0;
	                        break
	                    }
	                    c[n >> 2] = eB(c[682] | 0) | 0;
	                    bB(c[n >> 2] | 0, 203, 203, c[o >> 2] | 0);
	                    fB(c[n >> 2] | 0, c[e >> 2] | 0);
	                    c[m >> 2] = lB(c[n >> 2] | 0, c[h >> 2] | 0, 0, c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                    do if (!(c[266] | 0)) {
	                        if (!(c[m >> 2] | 0)) {
	                            a = c[o >> 2] | 0;
	                            c[d >> 2] = c[e >> 2];
	                            Ka(a | 0, 3496, d | 0) | 0;
	                            break
	                        }
	                        a = c[o >> 2] | 0;
	                        p = c[e >> 2] | 0;
	                        if ((c[m >> 2] | 0) > 0) {
	                            c[d >> 2] = p;
	                            Ka(a | 0, 3512, d | 0) | 0;
	                            c[662] = 3;
	                            break
	                        } else {
	                            c[d >> 2] = p;
	                            Ka(a | 0, 3536, d | 0) | 0;
	                            c[662] = 3;
	                            break
	                        }
	                    } while (0);
	                    ZA(c[n >> 2] | 0)
	                } while (0);
	                if (!(c[k >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                c[c[k >> 2] >> 2] = c[l >> 2];
	                Ae(c[k >> 2] | 0);
	                i = b;
	                return
	            }

	            function fc(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0, J = 0, K = 0, L = 0, M = 0, N = 0, O = 0, P = 0, Q = 0, R = 0, S = 0, T = 0, U = 0, V = 0, W = 0, X = 0, Y = 0, Z = 0, _ = 0, $ = 0, aa = 0, ba = 0, ca = 0, da = 0, ea = 0, fa = 0, ga = 0, ha = 0, ia = 0, ja = 0, ka = 0, la = 0, ma = 0;
	                e = i;
	                i = i + 6512 | 0;
	                f = e;
	                g = e + 1376 | 0;
	                h = e + 1372 | 0;
	                j = e + 1368 | 0;
	                k = e + 1364 | 0;
	                l = e + 1360 | 0;
	                m = e + 1356 | 0;
	                n = e + 1352 | 0;
	                r = e + 2408 | 0;
	                s = e + 1348 | 0;
	                t = e + 1344 | 0;
	                u = e + 1268 | 0;
	                v = e + 1264 | 0;
	                w = e + 1260 | 0;
	                x = e + 1256 | 0;
	                y = e + 1252 | 0;
	                z = e + 1248 | 0;
	                A = e + 1384 | 0;
	                B = e + 1244 | 0;
	                C = e + 1240 | 0;
	                D = e + 1236 | 0;
	                E = e + 1232 | 0;
	                F = e + 1156 | 0;
	                G = e + 1152 | 0;
	                H = e + 1148 | 0;
	                I = e + 1144 | 0;
	                J = e + 120 | 0;
	                K = e + 112 | 0;
	                L = e + 108 | 0;
	                M = e + 104 | 0;
	                N = e + 100 | 0;
	                O = e + 96 | 0;
	                P = e + 92 | 0;
	                Q = e + 88 | 0;
	                R = e + 84 | 0;
	                S = e + 80 | 0;
	                T = e + 76 | 0;
	                U = e + 72 | 0;
	                V = e + 68 | 0;
	                W = e + 64 | 0;
	                X = e + 60 | 0;
	                Y = e + 56 | 0;
	                Z = e + 52 | 0;
	                _ = e + 48 | 0;
	                $ = e + 44 | 0;
	                aa = e + 40 | 0;
	                ba = e + 36 | 0;
	                ca = e + 32 | 0;
	                da = e + 28 | 0;
	                ea = e + 24 | 0;
	                fa = e + 20 | 0;
	                ga = e + 16 | 0;
	                ha = e + 12 | 0;
	                ia = e + 8 | 0;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = 0;
	                if (!((c[252] | 0) == 0 | (c[266] | 0) != 0))bc();
	                do if (!(c[g >> 2] | 0)) {
	                    if (c[258] | 0) {
	                        c[j >> 2] = Sh(2888) | 0;
	                        c[l >> 2] = ji(c[j >> 2] | 0, 0, 2896, 0) | 0;
	                        vi(c[l >> 2] | 0, 2904);
	                        Qi(c[j >> 2] | 0, c[l >> 2] | 0) | 0
	                    }
	                } else {
	                    if ((c[152] | 0) != 0 & (c[272] | 0) != 0) {
	                        c[m >> 2] = pb(c[g >> 2] | 0, 2912) | 0;
	                        if (!(c[m >> 2] | 0))break;
	                        c[n >> 2] = Aa(r | 0, 1, 4, c[m >> 2] | 0) | 0;
	                        if ((c[n >> 2] | 0) > 0) {
	                            c[s >> 2] = po(0, 0, r, c[n >> 2] | 0, c[g >> 2] | 0, 0) | 0;
	                            fg(c[s >> 2] | 0, c[68] | 0) | 0;
	                            while (1) {
	                                d = Aa(r | 0, 1, c[282] | 0, c[m >> 2] | 0) | 0;
	                                c[n >> 2] = d;
	                                ja = c[s >> 2] | 0;
	                                if ((d | 0) <= 0)break;
	                                oo(ja, r, c[n >> 2] | 0, 0) | 0
	                            }
	                            oo(ja, r, 0, 1) | 0;
	                            c[j >> 2] = c[(c[s >> 2] | 0) + 8 >> 2];
	                            lo(c[s >> 2] | 0)
	                        }
	                        Xa(c[m >> 2] | 0) | 0;
	                        break
	                    }
	                    if ((c[152] | 0) != 0 & (c[290] | 0) != 0) {
	                        if (($a(c[g >> 2] | 0, u | 0) | 0) < 0) {
	                            i = e;
	                            return
	                        }
	                        d = La(c[g >> 2] | 0, 0, f | 0) | 0;
	                        c[t >> 2] = d;
	                        if ((d | 0) < 0) {
	                            i = e;
	                            return
	                        }
	                        c[v >> 2] = ob(0, c[u + 36 >> 2] | 0, 1, 1, c[t >> 2] | 0, 0) | 0;
	                        if ((c[v >> 2] | 0) != (-1 | 0)) {
	                            c[j >> 2] = vo(c[v >> 2] | 0, c[u + 36 >> 2] | 0, c[g >> 2] | 0, 0, c[68] | 0) | 0;
	                            Ta(c[v >> 2] | 0, c[u + 36 >> 2] | 0) | 0;
	                            Ra(c[t >> 2] | 0) | 0;
	                            break
	                        }
	                        Ra(c[t >> 2] | 0) | 0;
	                        d = c[o >> 2] | 0;
	                        c[f >> 2] = c[g >> 2];
	                        Ka(d | 0, 2920, f | 0) | 0;
	                        c[662] = 4;
	                        i = e;
	                        return
	                    }
	                    if (c[152] | 0) {
	                        c[j >> 2] = uo(c[g >> 2] | 0, 0, c[68] | 0) | 0;
	                        break
	                    }
	                    if (c[272] | 0) {
	                        if ((a[c[g >> 2] >> 0] | 0) == 45 ? (a[(c[g >> 2] | 0) + 1 >> 0] | 0) == 0 : 0)c[w >> 2] = c[p >> 2]; else c[w >> 2] = pb(c[g >> 2] | 0, 2912) | 0;
	                        if (!(c[w >> 2] | 0))break;
	                        c[z >> 2] = 1024;
	                        c[y >> 2] = Aa(A | 0, 1, 4, c[w >> 2] | 0) | 0;
	                        if ((c[y >> 2] | 0) > 0) {
	                            c[B >> 2] = Tf(0, 0, A, c[y >> 2] | 0, c[g >> 2] | 0) | 0;
	                            fg(c[B >> 2] | 0, c[68] | 0) | 0;
	                            while (1) {
	                                d = Aa(A | 0, 1, c[z >> 2] | 0, c[w >> 2] | 0) | 0;
	                                c[y >> 2] = d;
	                                ka = c[B >> 2] | 0;
	                                if ((d | 0) <= 0)break;
	                                Sf(ka, A, c[y >> 2] | 0, 0) | 0
	                            }
	                            Sf(ka, A, 0, 1) | 0;
	                            c[j >> 2] = c[(c[B >> 2] | 0) + 8 >> 2];
	                            c[x >> 2] = c[(c[B >> 2] | 0) + 12 >> 2];
	                            Ae(c[B >> 2] | 0);
	                            if (!(c[x >> 2] | 0)) {
	                                Th(c[j >> 2] | 0);
	                                c[j >> 2] = 0
	                            }
	                        }
	                        if ((c[w >> 2] | 0) == (c[p >> 2] | 0))break;
	                        Xa(c[w >> 2] | 0) | 0;
	                        break
	                    }
	                    if (c[298] | 0) {
	                        if ((a[c[g >> 2] >> 0] | 0) == 45 ? (a[(c[g >> 2] | 0) + 1 >> 0] | 0) == 0 : 0) {
	                            c[j >> 2] = ig(0, 0, 0, c[68] | 0) | 0;
	                            break
	                        }
	                        c[C >> 2] = pb(c[g >> 2] | 0, 2912) | 0;
	                        if (!(c[C >> 2] | 0)) {
	                            c[j >> 2] = 0;
	                            break
	                        }
	                        if (!(c[h >> 2] | 0)) {
	                            c[j >> 2] = jg(204, 205, c[C >> 2] | 0, c[g >> 2] | 0, 0, c[68] | 0) | 0;
	                            break
	                        } else {
	                            c[j >> 2] = mg(c[h >> 2] | 0, 204, 205, c[C >> 2] | 0, c[g >> 2] | 0, 0, c[68] | 0) | 0;
	                            break
	                        }
	                    }
	                    if (c[138] | 0) {
	                        if (!(c[h >> 2] | 0))c[D >> 2] = Be() | 0; else c[D >> 2] = c[h >> 2];
	                        if (!(c[D >> 2] | 0)) {
	                            c[j >> 2] = 0;
	                            break
	                        }
	                        c[(c[c[D >> 2] >> 2] | 0) + 88 >> 2] = 206;
	                        c[(c[c[D >> 2] >> 2] | 0) + 84 >> 2] = 207;
	                        c[(c[D >> 2] | 0) + 112 >> 2] = 208;
	                        c[(c[D >> 2] | 0) + 116 >> 2] = 209;
	                        c[j >> 2] = kg(c[D >> 2] | 0, c[g >> 2] | 0, 0, c[68] | 0) | 0;
	                        if (c[h >> 2] | 0)break;
	                        Ae(c[D >> 2] | 0);
	                        break
	                    }
	                    if (c[290] | 0) {
	                        if (($a(c[g >> 2] | 0, F | 0) | 0) < 0) {
	                            i = e;
	                            return
	                        }
	                        d = La(c[g >> 2] | 0, 0, f | 0) | 0;
	                        c[E >> 2] = d;
	                        if ((d | 0) < 0) {
	                            i = e;
	                            return
	                        }
	                        c[G >> 2] = ob(0, c[F + 36 >> 2] | 0, 1, 1, c[E >> 2] | 0, 0) | 0;
	                        if ((c[G >> 2] | 0) == (-1 | 0)) {
	                            Ra(c[E >> 2] | 0) | 0;
	                            d = c[o >> 2] | 0;
	                            c[f >> 2] = c[g >> 2];
	                            Ka(d | 0, 2920, f | 0) | 0;
	                            c[662] = 4;
	                            i = e;
	                            return
	                        }
	                        if (!(c[h >> 2] | 0))c[j >> 2] = hg(c[G >> 2] | 0, c[F + 36 >> 2] | 0, c[g >> 2] | 0, 0, c[68] | 0) | 0; else c[j >> 2] = lg(c[h >> 2] | 0, c[G >> 2] | 0, c[F + 36 >> 2] | 0, c[g >> 2] | 0, 0, c[68] | 0) | 0;
	                        Ta(c[G >> 2] | 0, c[F + 36 >> 2] | 0) | 0;
	                        Ra(c[E >> 2] | 0) | 0;
	                        break
	                    }
	                    if (!(c[196] | 0)) {
	                        if (c[h >> 2] | 0) {
	                            c[j >> 2] = kg(c[h >> 2] | 0, c[g >> 2] | 0, 0, c[68] | 0) | 0;
	                            break
	                        }
	                        d = c[g >> 2] | 0;
	                        if (c[468] | 0) {
	                            c[j >> 2] = cg(d) | 0;
	                            break
	                        } else {
	                            c[j >> 2] = gg(d, 0, c[68] | 0) | 0;
	                            break
	                        }
	                    }
	                    c[H >> 2] = 0;
	                    if (!(c[h >> 2] | 0))c[H >> 2] = Be() | 0; else c[H >> 2] = c[h >> 2];
	                    if (!(c[H >> 2] | 0)) {
	                        c[j >> 2] = 0;
	                        break
	                    }
	                    c[j >> 2] = kg(c[H >> 2] | 0, c[g >> 2] | 0, 0, c[68] | 0) | 0;
	                    if (!(c[(c[H >> 2] | 0) + 100 >> 2] | 0))c[662] = 4;
	                    if (!(c[h >> 2] | 0))Ae(c[H >> 2] | 0)
	                } while (0);
	                if (!(c[j >> 2] | 0)) {
	                    c[662] = 1;
	                    i = e;
	                    return
	                }
	                if (!((c[252] | 0) == 0 | (c[266] | 0) != 0))cc(2952, f);
	                if ((c[236] | 0) != 0 ? (c[I >> 2] = Nh(c[j >> 2] | 0) | 0, (c[I >> 2] | 0) != 0) : 0) {
	                    Qh(c[I >> 2] | 0);
	                    Ph(c[I >> 2] | 0)
	                }
	                if (c[308] | 0) {
	                    if (!((c[252] | 0) == 0 | (c[266] | 0) != 0))bc();
	                    if ((Vv(c[j >> 2] | 0, c[68] | 0) | 0) < 0)c[662] = 1;
	                    if (!((c[252] | 0) == 0 | (c[266] | 0) != 0))cc(2960, f)
	                }
	                if (c[554] | 0)mc(c[j >> 2] | 0, c[554] | 0);
	                if (c[48] | 0) {
	                    Xq(c[j >> 2] | 0) | 0;
	                    Zp(c[j >> 2] | 0, c[g >> 2] | 0, 210, c[q >> 2] | 0)
	                }
	                if (c[56] | 0) {
	                    c[k >> 2] = c[j >> 2];
	                    if (c[252] | 0)bc();
	                    c[j >> 2] = Mi(c[j >> 2] | 0, 1) | 0;
	                    if (c[252] | 0)cc(2984, f);
	                    if (c[252] | 0)bc();
	                    Th(c[k >> 2] | 0);
	                    if (c[252] | 0)cc(2992, f)
	                }
	                a:do if ((c[244] | 0) == 0 | (c[152] | 0) != 0) {
	                    if (c[462] | 0)oc(c[j >> 2] | 0)
	                } else if (c[(c[j >> 2] | 0) + 12 >> 2] | 0) {
	                    c[M >> 2] = c[(c[j >> 2] | 0) + 12 >> 2];
	                    while (1) {
	                        if (c[M >> 2] | 0)la = (c[(c[M >> 2] | 0) + 16 >> 2] | 0) == 0; else la = 0;
	                        ma = c[M >> 2] | 0;
	                        if (!la)break;
	                        c[M >> 2] = c[ma + 24 >> 2]
	                    }
	                    if (ma) {
	                        c[K >> 2] = hn(c[(c[M >> 2] | 0) + 16 >> 2] | 0, 0, J, 256) | 0;
	                        if ((c[K >> 2] | 0) < 0) {
	                            Ka(c[o >> 2] | 0, 3016, f | 0) | 0;
	                            break
	                        }
	                        k = c[o >> 2] | 0;
	                        if (!(c[K >> 2] | 0)) {
	                            Ka(k | 0, 3056, f | 0) | 0;
	                            break
	                        }
	                        c[f >> 2] = c[K >> 2];
	                        Ka(k | 0, 3096, f | 0) | 0;
	                        c[L >> 2] = 0;
	                        while (1) {
	                            if ((c[L >> 2] | 0) >= (c[K >> 2] | 0))break a;
	                            k = c[o >> 2] | 0;
	                            c[f >> 2] = c[J + (c[L >> 2] << 2) >> 2];
	                            Ka(k | 0, 3144, f | 0) | 0;
	                            c[L >> 2] = (c[L >> 2] | 0) + 1
	                        }
	                    }
	                } while (0);
	                do if (!(c[50] | 0)) {
	                    if (c[42] | 0) {
	                        if (!(c[128] | 0))c[_ >> 2] = c[q >> 2]; else c[_ >> 2] = pb(c[128] | 0, 3160) | 0;
	                        if (!(c[_ >> 2] | 0)) {
	                            L = c[o >> 2] | 0;
	                            c[f >> 2] = c[128];
	                            Ka(L | 0, 3168, f | 0) | 0;
	                            c[662] = 6;
	                            break
	                        }
	                        Mp(c[_ >> 2] | 0, c[j >> 2] | 0);
	                        if (!(c[128] | 0))break;
	                        Xa(c[_ >> 2] | 0) | 0;
	                        break
	                    }
	                    if (!((c[252] | 0) == 0 | (c[266] | 0) != 0))bc();
	                    do if (!((c[152] | 0) == 0 | (c[160] | 0) != 0)) {
	                        do if (c[788] | 0)Ap((c[128] | 0) != 0 ? c[128] | 0 : 144, c[j >> 2] | 0) | 0; else {
	                            L = (c[440] | 0) == 1;
	                            J = c[128] | 0;
	                            if (c[408] | 0) {
	                                K = (J | 0) != 0 ? c[128] | 0 : 144;
	                                M = c[j >> 2] | 0;
	                                ma = c[408] | 0;
	                                if (L) {
	                                    Bp(K, M, ma, 1) | 0;
	                                    break
	                                } else {
	                                    Bp(K, M, ma, 0) | 0;
	                                    break
	                                }
	                            }
	                            if (L) {
	                                Bp((J | 0) != 0 ? c[128] | 0 : 144, c[j >> 2] | 0, 0, 1) | 0;
	                                break
	                            }
	                            if (!J)c[O >> 2] = c[q >> 2]; else c[O >> 2] = pb(c[128] | 0, 3160) | 0;
	                            if (!(c[O >> 2] | 0)) {
	                                J = c[o >> 2] | 0;
	                                c[f >> 2] = c[128];
	                                Ka(J | 0, 3168, f | 0) | 0;
	                                c[662] = 6;
	                                break
	                            }
	                            if ((zp(c[O >> 2] | 0, c[j >> 2] | 0) | 0) < 0)c[662] = 6;
	                            if (!(c[128] | 0))break;
	                            Xa(c[O >> 2] | 0) | 0
	                        } while (0);
	                        if (!((c[252] | 0) == 0 | (c[266] | 0) != 0))cc(3192, f)
	                    } else {
	                        if (c[362] | 0) {
	                            c[P >> 2] = 0;
	                            c[Q >> 2] = Dx(c[j >> 2] | 0, 0, 0, 0, 1, P) | 0;
	                            if ((c[Q >> 2] | 0) < 0) {
	                                Ka(c[o >> 2] | 0, 3224, f | 0) | 0;
	                                c[662] = 6;
	                                break
	                            }
	                            if ((Ya(1, c[P >> 2] | 0, c[Q >> 2] | 0) | 0) == -1)Ka(c[o >> 2] | 0, 3200, f | 0) | 0;
	                            zb[c[135736 >> 2] & 511](c[P >> 2] | 0);
	                            break
	                        }
	                        if (c[370] | 0) {
	                            c[R >> 2] = 0;
	                            c[S >> 2] = Dx(c[j >> 2] | 0, 0, 2, 0, 1, R) | 0;
	                            if ((c[S >> 2] | 0) < 0) {
	                                Ka(c[o >> 2] | 0, 3224, f | 0) | 0;
	                                c[662] = 6;
	                                break
	                            }
	                            if ((Ya(1, c[R >> 2] | 0, c[S >> 2] | 0) | 0) == -1)Ka(c[o >> 2] | 0, 3200, f | 0) | 0;
	                            zb[c[135736 >> 2] & 511](c[R >> 2] | 0);
	                            break
	                        }
	                        if (c[380] | 0) {
	                            c[T >> 2] = 0;
	                            c[U >> 2] = Dx(c[j >> 2] | 0, 0, 1, 0, 1, T) | 0;
	                            if ((c[U >> 2] | 0) < 0) {
	                                Ka(c[o >> 2] | 0, 3224, f | 0) | 0;
	                                c[662] = 6;
	                                break
	                            }
	                            if ((Ya(1, c[T >> 2] | 0, c[U >> 2] | 0) | 0) == -1)Ka(c[o >> 2] | 0, 3200, f | 0) | 0;
	                            zb[c[135736 >> 2] & 511](c[T >> 2] | 0);
	                            break
	                        }
	                        if (c[290] | 0) {
	                            J = (c[440] | 0) == 1;
	                            L = c[j >> 2] | 0;
	                            do if (c[408] | 0) {
	                                ma = c[408] | 0;
	                                if (J) {
	                                    AR(L, V, W, ma, 1);
	                                    break
	                                } else {
	                                    DR(L, V, W, ma);
	                                    break
	                                }
	                            } else if (J) {
	                                CR(L, V, W, 1);
	                                break
	                            } else {
	                                BR(L, V, W);
	                                break
	                            } while (0);
	                            if (!(c[V >> 2] | 0)) {
	                                Ka(c[o >> 2] | 0, 3248, f | 0) | 0;
	                                c[662] = 6;
	                                break
	                            }
	                            if ((Ya(1, c[V >> 2] | 0, c[W >> 2] | 0) | 0) == -1)Ka(c[o >> 2] | 0, 3200, f | 0) | 0;
	                            zb[c[135736 >> 2] & 511](c[V >> 2] | 0);
	                            break
	                        }
	                        if (c[788] | 0) {
	                            JR((c[128] | 0) != 0 ? c[128] | 0 : 144, c[j >> 2] | 0) | 0;
	                            break
	                        }
	                        if (!(c[816] | 0)) {
	                            c[Z >> 2] = 0;
	                            do if ((c[440] | 0) == 1)c[Z >> 2] = c[Z >> 2] | 1; else {
	                                if ((c[440] | 0) != 2)break;
	                                c[Z >> 2] = c[Z >> 2] | 128
	                            } while (0);
	                            if (c[160] | 0)c[Z >> 2] = c[Z >> 2] | 32;
	                            if (!(c[128] | 0))c[Y >> 2] = rR(1, c[408] | 0, c[Z >> 2] | 0) | 0; else c[Y >> 2] = sR(c[128] | 0, c[408] | 0, c[Z >> 2] | 0) | 0;
	                            if (!(c[Y >> 2] | 0)) {
	                                c[662] = 6;
	                                break
	                            }
	                            if ((tR(c[Y >> 2] | 0, c[j >> 2] | 0) | 0) < 0) {
	                                L = c[o >> 2] | 0;
	                                c[f >> 2] = (c[128] | 0) != 0 ? c[128] | 0 : 144;
	                                Ka(L | 0, 3272, f | 0) | 0;
	                                c[662] = 6
	                            }
	                            wR(c[Y >> 2] | 0) | 0;
	                            break
	                        }
	                        L = (c[440] | 0) == 1;
	                        J = c[128] | 0;
	                        if (c[408] | 0) {
	                            ma = (J | 0) != 0 ? c[128] | 0 : 144;
	                            M = c[j >> 2] | 0;
	                            K = c[408] | 0;
	                            if (L)c[N >> 2] = GR(ma, M, K, 1) | 0; else c[N >> 2] = HR(ma, M, K) | 0;
	                            if ((c[N >> 2] | 0) >= 0)break;
	                            K = c[o >> 2] | 0;
	                            c[f >> 2] = (c[128] | 0) != 0 ? c[128] | 0 : 144;
	                            Ka(K | 0, 3272, f | 0) | 0;
	                            c[662] = 6;
	                            break
	                        }
	                        if (L) {
	                            c[N >> 2] = IR((J | 0) != 0 ? c[128] | 0 : 144, c[j >> 2] | 0, 1) | 0;
	                            if ((c[N >> 2] | 0) >= 0)break;
	                            L = c[o >> 2] | 0;
	                            c[f >> 2] = (c[128] | 0) != 0 ? c[128] | 0 : 144;
	                            Ka(L | 0, 3272, f | 0) | 0;
	                            c[662] = 6;
	                            break
	                        }
	                        if (!J)c[X >> 2] = c[q >> 2]; else c[X >> 2] = pb(c[128] | 0, 3160) | 0;
	                        if (!(c[X >> 2] | 0)) {
	                            J = c[o >> 2] | 0;
	                            c[f >> 2] = c[128];
	                            Ka(J | 0, 3168, f | 0) | 0;
	                            c[662] = 6;
	                            break
	                        }
	                        if ((FR(c[X >> 2] | 0, c[j >> 2] | 0) | 0) < 0)c[662] = 6;
	                        if (!(c[128] | 0))break;
	                        Xa(c[X >> 2] | 0) | 0
	                    } while (0);
	                    if (!((c[252] | 0) == 0 | (c[266] | 0) != 0))cc(3192, f)
	                } while (0);
	                do if (!((c[216] | 0) != 0 | (c[226] | 0) != 0)) {
	                    if (c[206] | 0) {
	                        X = gm() | 0;
	                        c[ba >> 2] = X;
	                        if (!X) {
	                            Db[c[135904 >> 2] & 511](c[33980] | 0, 3336, f);
	                            qb(-1)
	                        }
	                        if (!((c[252] | 0) == 0 | (c[266] | 0) != 0))bc();
	                        c[c[ba >> 2] >> 2] = c[o >> 2];
	                        c[(c[ba >> 2] | 0) + 4 >> 2] = 203;
	                        c[(c[ba >> 2] | 0) + 8 >> 2] = 203;
	                        if (!(fn(c[ba >> 2] | 0, c[j >> 2] | 0) | 0)) {
	                            X = c[33976] | 0;
	                            N = c[33980] | 0;
	                            c[f >> 2] = c[g >> 2];
	                            Db[X & 511](N, 3448, f);
	                            c[662] = 3
	                        }
	                        if (!((c[252] | 0) == 0 | (c[266] | 0) != 0))cc(3480, f);
	                        hm(c[ba >> 2] | 0)
	                    }
	                } else {
	                    if (!((c[252] | 0) == 0 | (c[266] | 0) != 0))bc();
	                    if (c[216] | 0)c[$ >> 2] = Wf(0, c[216] | 0) | 0; else c[$ >> 2] = Wf(c[226] | 0, 0) | 0;
	                    if (!((c[252] | 0) == 0 | (c[266] | 0) != 0))cc(3296, f);
	                    if (!(c[$ >> 2] | 0)) {
	                        N = c[33976] | 0;
	                        X = c[33980] | 0;
	                        if (c[216] | 0) {
	                            c[f >> 2] = c[216];
	                            Db[N & 511](X, 3312, f)
	                        } else {
	                            c[f >> 2] = c[226];
	                            Db[N & 511](X, 3312, f)
	                        }
	                        c[662] = 2;
	                        break
	                    }
	                    X = gm() | 0;
	                    c[aa >> 2] = X;
	                    if (!X) {
	                        Db[c[135904 >> 2] & 511](c[33980] | 0, 3336, f);
	                        qb(-1)
	                    }
	                    c[c[aa >> 2] >> 2] = c[o >> 2];
	                    c[(c[aa >> 2] | 0) + 4 >> 2] = 203;
	                    c[(c[aa >> 2] | 0) + 8 >> 2] = 203;
	                    if (!((c[252] | 0) == 0 | (c[266] | 0) != 0))bc();
	                    if (!(dn(c[aa >> 2] | 0, c[j >> 2] | 0, c[$ >> 2] | 0) | 0)) {
	                        X = c[33976] | 0;
	                        N = c[33980] | 0;
	                        Y = c[g >> 2] | 0;
	                        if (c[216] | 0) {
	                            Z = c[216] | 0;
	                            c[f >> 2] = Y;
	                            c[f + 4 >> 2] = Z;
	                            Db[X & 511](N, 3376, f)
	                        } else {
	                            Z = c[226] | 0;
	                            c[f >> 2] = Y;
	                            c[f + 4 >> 2] = Z;
	                            Db[X & 511](N, 3376, f)
	                        }
	                        c[662] = 3
	                    }
	                    if (!((c[252] | 0) == 0 | (c[266] | 0) != 0))cc(3424, f);
	                    hm(c[aa >> 2] | 0);
	                    Ph(c[$ >> 2] | 0)
	                } while (0);
	                if (c[650] | 0) {
	                    if (!((c[252] | 0) == 0 | (c[266] | 0) != 0))bc();
	                    if (c[42] | 0)c[ea >> 2] = 4; else c[ea >> 2] = 2;
	                    if (c[50] | 0)c[ea >> 2] = c[ea >> 2] | 1;
	                    c[ca >> 2] = lS(c[650] | 0, c[ea >> 2] | 0) | 0;
	                    c[da >> 2] = nS(c[ca >> 2] | 0, c[j >> 2] | 0) | 0;
	                    do if (c[da >> 2] | 0) {
	                        ea = c[o >> 2] | 0;
	                        $ = c[g >> 2] | 0;
	                        if ((c[da >> 2] | 0) > 0) {
	                            c[f >> 2] = $;
	                            Ka(ea | 0, 3512, f | 0) | 0;
	                            c[662] = 3;
	                            break
	                        } else {
	                            c[f >> 2] = $;
	                            Ka(ea | 0, 3536, f | 0) | 0;
	                            c[662] = 3;
	                            break
	                        }
	                    } else {
	                        ea = c[o >> 2] | 0;
	                        c[f >> 2] = c[g >> 2];
	                        Ka(ea | 0, 3496, f | 0) | 0
	                    } while (0);
	                    mS(c[ca >> 2] | 0);
	                    if (!((c[252] | 0) == 0 | (c[266] | 0) != 0))cc(3480, f)
	                }
	                if (c[670] | 0) {
	                    if (!((c[252] | 0) == 0 | (c[266] | 0) != 0))bc();
	                    c[fa >> 2] = eN(c[670] | 0) | 0;
	                    gN(c[fa >> 2] | 0, 203, 203, c[o >> 2] | 0);
	                    c[ga >> 2] = iN(c[fa >> 2] | 0, c[j >> 2] | 0) | 0;
	                    do if (c[ga >> 2] | 0) {
	                        ca = c[o >> 2] | 0;
	                        da = c[g >> 2] | 0;
	                        if ((c[ga >> 2] | 0) > 0) {
	                            c[f >> 2] = da;
	                            Ka(ca | 0, 3512, f | 0) | 0;
	                            c[662] = 3;
	                            break
	                        } else {
	                            c[f >> 2] = da;
	                            Ka(ca | 0, 3536, f | 0) | 0;
	                            c[662] = 3;
	                            break
	                        }
	                    } else {
	                        ca = c[o >> 2] | 0;
	                        c[f >> 2] = c[g >> 2];
	                        Ka(ca | 0, 3496, f | 0) | 0
	                    } while (0);
	                    fN(c[fa >> 2] | 0);
	                    if (!((c[252] | 0) == 0 | (c[266] | 0) != 0))cc(3480, f)
	                } else if (c[682] | 0) {
	                    if (!((c[252] | 0) == 0 | (c[266] | 0) != 0))bc();
	                    c[ha >> 2] = eB(c[682] | 0) | 0;
	                    bB(c[ha >> 2] | 0, 203, 203, c[o >> 2] | 0);
	                    c[ia >> 2] = hB(c[ha >> 2] | 0, c[j >> 2] | 0) | 0;
	                    do if (c[ia >> 2] | 0) {
	                        fa = c[o >> 2] | 0;
	                        ga = c[g >> 2] | 0;
	                        if ((c[ia >> 2] | 0) > 0) {
	                            c[f >> 2] = ga;
	                            Ka(fa | 0, 3512, f | 0) | 0;
	                            c[662] = 3;
	                            break
	                        } else {
	                            c[f >> 2] = ga;
	                            Ka(fa | 0, 3536, f | 0) | 0;
	                            c[662] = 3;
	                            break
	                        }
	                    } else {
	                        fa = c[o >> 2] | 0;
	                        c[f >> 2] = c[g >> 2];
	                        Ka(fa | 0, 3496, f | 0) | 0
	                    } while (0);
	                    ZA(c[ha >> 2] | 0);
	                    if (!((c[252] | 0) == 0 | (c[266] | 0) != 0))cc(3480, f)
	                }
	                if (!((c[356] | 0) == 0 | (c[152] | 0) != 0))Jp(c[o >> 2] | 0, c[j >> 2] | 0);
	                if (!((c[252] | 0) == 0 | (c[266] | 0) != 0))bc();
	                Th(c[j >> 2] | 0);
	                if ((c[252] | 0) == 0 | (c[266] | 0) != 0) {
	                    i = e;
	                    return
	                }
	                cc(3584, f);
	                i = e;
	                return
	            }

	            function gc(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                d = Aa(c[g >> 2] | 0, 1, c[h >> 2] | 0, c[f >> 2] | 0) | 0;
	                i = e;
	                return d | 0
	            }

	            function hc(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) == (c[p >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                Xa(c[d >> 2] | 0) | 0;
	                i = b;
	                return
	            }

	            function ic(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f;
	                h = f + 36 | 0;
	                j = f + 32 | 0;
	                k = f + 28 | 0;
	                l = f + 24 | 0;
	                m = f + 8 | 0;
	                n = f + 4 | 0;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = c[h >> 2];
	                a[4136] = 0;
	                c[l >> 2] = c[(c[k >> 2] | 0) + 36 >> 2];
	                if (((c[l >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 4 >> 2] | 0) == 0 : 0) ? (c[(c[k >> 2] | 0) + 40 >> 2] | 0) > 1 : 0)c[l >> 2] = c[(c[(c[k >> 2] | 0) + 48 >> 2] | 0) + ((c[(c[k >> 2] | 0) + 40 >> 2] | 0) - 2 << 2) >> 2];
	                rc(c[l >> 2] | 0);
	                Db[c[135904 >> 2] & 511](c[33980] | 0, 54304, g);
	                c[m >> 2] = e;
	                c[n >> 2] = ZT(4136) | 0;
	                LT(4136 + (c[n >> 2] | 0) | 0, 5e4 - (c[n >> 2] | 0) | 0, c[j >> 2] | 0, m) | 0;
	                sc();
	                Db[c[135904 >> 2] & 511](c[33980] | 0, 54168, g);
	                tc(c[l >> 2] | 0);
	                sc();
	                i = f;
	                return
	            }

	            function jc(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f;
	                h = f + 36 | 0;
	                j = f + 32 | 0;
	                k = f + 28 | 0;
	                l = f + 24 | 0;
	                m = f + 8 | 0;
	                n = f + 4 | 0;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = c[h >> 2];
	                a[4136] = 0;
	                c[l >> 2] = c[(c[k >> 2] | 0) + 36 >> 2];
	                if (((c[l >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 4 >> 2] | 0) == 0 : 0) ? (c[(c[k >> 2] | 0) + 40 >> 2] | 0) > 1 : 0)c[l >> 2] = c[(c[(c[k >> 2] | 0) + 48 >> 2] | 0) + ((c[(c[k >> 2] | 0) + 40 >> 2] | 0) - 2 << 2) >> 2];
	                rc(c[l >> 2] | 0);
	                Db[c[135904 >> 2] & 511](c[33980] | 0, 54280, g);
	                c[m >> 2] = e;
	                c[n >> 2] = ZT(4136) | 0;
	                LT(4136 + (c[n >> 2] | 0) | 0, 5e4 - (c[n >> 2] | 0) | 0, c[j >> 2] | 0, m) | 0;
	                sc();
	                Db[c[135904 >> 2] & 511](c[33980] | 0, 54168, g);
	                tc(c[l >> 2] | 0);
	                sc();
	                i = f;
	                return
	            }

	            function kc(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f;
	                h = f + 36 | 0;
	                j = f + 32 | 0;
	                k = f + 28 | 0;
	                l = f + 24 | 0;
	                m = f + 8 | 0;
	                n = f + 4 | 0;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = c[h >> 2];
	                a[4136] = 0;
	                c[l >> 2] = c[(c[k >> 2] | 0) + 36 >> 2];
	                if ((c[(c[l >> 2] | 0) + 4 >> 2] | 0) == 0 ? (c[(c[k >> 2] | 0) + 40 >> 2] | 0) > 1 : 0)c[l >> 2] = c[(c[(c[k >> 2] | 0) + 48 >> 2] | 0) + ((c[(c[k >> 2] | 0) + 40 >> 2] | 0) - 2 << 2) >> 2];
	                rc(c[l >> 2] | 0);
	                Db[c[135904 >> 2] & 511](c[33980] | 0, 54256, g);
	                c[n >> 2] = ZT(4136) | 0;
	                c[m >> 2] = e;
	                LT(4136 + (c[n >> 2] | 0) | 0, 5e4 - (c[n >> 2] | 0) | 0, c[j >> 2] | 0, m) | 0;
	                sc();
	                Db[c[135904 >> 2] & 511](c[33980] | 0, 54168, g);
	                tc(c[l >> 2] | 0);
	                sc();
	                c[662] = 3;
	                i = f;
	                return
	            }

	            function lc(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f;
	                h = f + 36 | 0;
	                j = f + 32 | 0;
	                k = f + 28 | 0;
	                l = f + 24 | 0;
	                m = f + 8 | 0;
	                n = f + 4 | 0;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = c[h >> 2];
	                a[4136] = 0;
	                c[l >> 2] = c[(c[k >> 2] | 0) + 36 >> 2];
	                if ((c[(c[l >> 2] | 0) + 4 >> 2] | 0) == 0 ? (c[(c[k >> 2] | 0) + 40 >> 2] | 0) > 1 : 0)c[l >> 2] = c[(c[(c[k >> 2] | 0) + 48 >> 2] | 0) + ((c[(c[k >> 2] | 0) + 40 >> 2] | 0) - 2 << 2) >> 2];
	                rc(c[l >> 2] | 0);
	                Db[c[135904 >> 2] & 511](c[33980] | 0, 54136, g);
	                c[m >> 2] = e;
	                c[n >> 2] = ZT(4136) | 0;
	                LT(4136 + (c[n >> 2] | 0) | 0, 5e4 - (c[n >> 2] | 0) | 0, c[j >> 2] | 0, m) | 0;
	                sc();
	                Db[c[135904 >> 2] & 511](c[33980] | 0, 54168, g);
	                tc(c[l >> 2] | 0);
	                sc();
	                i = f;
	                return
	            }

	            function mc(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = Lr(c[f >> 2] | 0) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    Ka(c[o >> 2] | 0, 3912, e | 0) | 0;
	                    c[662] = 9;
	                    i = d;
	                    return
	                }
	                c[(c[h >> 2] | 0) + 4 >> 2] = c[f >> 2];
	                c[j >> 2] = Rs(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                Nr(c[h >> 2] | 0);
	                if (!(c[j >> 2] | 0)) {
	                    Ka(c[o >> 2] | 0, 3944, e | 0) | 0;
	                    c[662] = 10;
	                    i = d;
	                    return
	                } else {
	                    qc(c[j >> 2] | 0);
	                    Qq(c[j >> 2] | 0);
	                    i = d;
	                    return
	                }
	            }

	            function nc(b) {
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 528 | 0;
	                e = d;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 20 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                c[g >> 2] = b;
	                if (c[g >> 2] | 0) {
	                    b = c[q >> 2] | 0;
	                    c[e >> 2] = c[g >> 2];
	                    Ka(b | 0, 3904, e | 0) | 0
	                }
	                if (!(nb(h | 0, 500, c[p >> 2] | 0) | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                a[h + 500 >> 0] = 0;
	                c[k >> 2] = ZT(h | 0) | 0;
	                c[j >> 2] = iT((c[k >> 2] | 0) + 1 | 0) | 0;
	                if (c[j >> 2] | 0)eU(c[j >> 2] | 0, h | 0, (c[k >> 2] | 0) + 1 | 0) | 0;
	                c[f >> 2] = c[j >> 2];
	                l = c[f >> 2] | 0;
	                i = d;
	                return l | 0
	            }

	            function oc(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                b = i;
	                i = i + 128 | 0;
	                d = b;
	                e = b + 116 | 0;
	                f = b + 112 | 0;
	                g = b + 108 | 0;
	                h = b + 104 | 0;
	                j = b + 16 | 0;
	                k = b + 8 | 0;
	                l = b + 4 | 0;
	                c[e >> 2] = a;
	                c[h >> 2] = Pi(c[e >> 2] | 0) | 0;
	                c[l >> 2] = c[(c[h >> 2] | 0) + 48 >> 2];
	                c[k >> 2] = 0;
	                while (1) {
	                    if (!((c[l >> 2] | 0) != 0 & (c[k >> 2] | 0) < 20))break;
	                    h = c[(c[l >> 2] | 0) + 8 >> 2] | 0;
	                    a = c[k >> 2] | 0;
	                    c[k >> 2] = a + 1;
	                    c[j + (a << 2) >> 2] = h;
	                    h = c[(c[l >> 2] | 0) + 12 >> 2] | 0;
	                    a = c[k >> 2] | 0;
	                    c[k >> 2] = a + 1;
	                    c[j + (a << 2) >> 2] = h;
	                    c[l >> 2] = c[c[l >> 2] >> 2]
	                }
	                l = c[k >> 2] | 0;
	                c[k >> 2] = l + 1;
	                c[j + (l << 2) >> 2] = 0;
	                c[j + (c[k >> 2] << 2) >> 2] = 0;
	                if ((c[548] | 0) != 0 ? (c[694] = MQ(c[548] | 0, c[(c[e >> 2] | 0) + 80 >> 2] | 0, 0, j) | 0, (c[694] | 0) == 0) : 0) {
	                    j = c[33976] | 0;
	                    k = c[33980] | 0;
	                    c[d >> 2] = c[548];
	                    Db[j & 511](k, 2784, d);
	                    c[662] = 7;
	                    c[548] = 0
	                }
	                if (((c[694] | 0) != 0 ? (c[898] = OQ(c[694] | 0) | 0, (c[898] | 0) != 0) : 0) ? (c[g >> 2] = HQ(c[898] | 0, 0, 0) | 0, (c[g >> 2] | 0) < 0) : 0) {
	                    Ka(c[o >> 2] | 0, 3600, d | 0) | 0;
	                    GQ(c[898] | 0);
	                    c[898] = 0
	                }
	                c[f >> 2] = jM(c[e >> 2] | 0) | 0;
	                if (c[f >> 2] | 0) {
	                    if (!((c[252] | 0) == 0 | (c[266] | 0) != 0))bc();
	                    c[g >> 2] = QL(c[f >> 2] | 0) | 0;
	                    while (1) {
	                        if ((c[g >> 2] | 0) != 1)break;
	                        if ((c[42] | 0) != 0 | (c[694] | 0) != 0)pc(c[f >> 2] | 0);
	                        c[g >> 2] = QL(c[f >> 2] | 0) | 0
	                    }
	                    if (!((c[252] | 0) == 0 | (c[266] | 0) != 0))cc(3632, d);
	                    VL(c[f >> 2] | 0);
	                    if (c[g >> 2] | 0) {
	                        Ka(c[o >> 2] | 0, 3656, d | 0) | 0;
	                        c[662] = 1
	                    }
	                } else {
	                    Ka(c[o >> 2] | 0, 3688, d | 0) | 0;
	                    c[662] = 1
	                }
	                if (!(c[898] | 0)) {
	                    i = b;
	                    return
	                }
	                GQ(c[898] | 0);
	                c[898] = 0;
	                i = b;
	                return
	            }

	            function pc(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, p = 0, q = 0, r = 0;
	                b = i;
	                i = i + 64 | 0;
	                d = b;
	                e = b + 48 | 0;
	                f = b + 44 | 0;
	                g = b + 40 | 0;
	                h = b + 36 | 0;
	                j = b + 32 | 0;
	                k = b + 28 | 0;
	                l = b + 24 | 0;
	                m = b + 20 | 0;
	                c[e >> 2] = a;
	                c[h >> 2] = XL(c[e >> 2] | 0) | 0;
	                c[j >> 2] = YL(c[e >> 2] | 0) | 0;
	                do if (c[42] | 0) {
	                    a = _L(c[e >> 2] | 0) | 0;
	                    c[f >> 2] = a;
	                    c[f >> 2] = (c[f >> 2] | 0) == 0 ? 3736 : a;
	                    c[g >> 2] = cM(c[e >> 2] | 0) | 0;
	                    a = aM(c[e >> 2] | 0) | 0;
	                    n = c[h >> 2] | 0;
	                    p = c[f >> 2] | 0;
	                    q = c[j >> 2] | 0;
	                    r = bM(c[e >> 2] | 0) | 0;
	                    c[d >> 2] = a;
	                    c[d + 4 >> 2] = n;
	                    c[d + 8 >> 2] = p;
	                    c[d + 12 >> 2] = q;
	                    c[d + 16 >> 2] = r;
	                    Wa(3744, d | 0) | 0;
	                    if (!(c[g >> 2] | 0)) {
	                        Wa(3760, d | 0) | 0;
	                        break
	                    } else {
	                        c[d >> 2] = c[g >> 2];
	                        Wa(3768, d | 0) | 0;
	                        break
	                    }
	                } while (0);
	                if (!(c[694] | 0)) {
	                    i = b;
	                    return
	                }
	                c[k >> 2] = 0;
	                c[l >> 2] = -1;
	                if ((c[h >> 2] | 0) == 1 ? (g = c[694] | 0, c[l >> 2] = NQ(g, eM(c[e >> 2] | 0) | 0) | 0, (c[l >> 2] | 0) != 0) : 0) {
	                    c[k >> 2] = Oi(eM(c[e >> 2] | 0) | 0) | 0;
	                    g = c[548] | 0;
	                    c[d >> 2] = c[k >> 2];
	                    c[d + 4 >> 2] = g;
	                    Wa(3776, d | 0) | 0
	                }
	                do if (c[898] | 0) {
	                    do if ((c[h >> 2] | 0) == 1) {
	                        g = c[898] | 0;
	                        f = ZL(c[e >> 2] | 0) | 0;
	                        c[m >> 2] = HQ(g, f, $L(c[e >> 2] | 0) | 0) | 0;
	                        if ((c[m >> 2] | 0) < 0) {
	                            Ka(c[o >> 2] | 0, 3600, d | 0) | 0;
	                            GQ(c[898] | 0);
	                            c[898] = 0;
	                            break
	                        }
	                        if ((c[m >> 2] | 0) != (c[l >> 2] | 0)) {
	                            if (!(c[k >> 2] | 0))c[k >> 2] = Oi(eM(c[e >> 2] | 0) | 0) | 0;
	                            Ka(c[o >> 2] | 0, 3808, d | 0) | 0;
	                            f = c[o >> 2] | 0;
	                            g = c[548] | 0;
	                            if (c[k >> 2] | 0) {
	                                r = c[k >> 2] | 0;
	                                c[d >> 2] = g;
	                                c[d + 4 >> 2] = r;
	                                Ka(f | 0, 3856, d | 0) | 0;
	                                break
	                            } else {
	                                r = _L(c[e >> 2] | 0) | 0;
	                                c[d >> 2] = g;
	                                c[d + 4 >> 2] = r;
	                                Ka(f | 0, 3856, d | 0) | 0;
	                                break
	                            }
	                        }
	                    } while (0);
	                    if ((c[h >> 2] | 0) != 15 ? !((c[h >> 2] | 0) == 1 & (c[j >> 2] | 0) != 0) : 0)break;
	                    c[m >> 2] = KQ(c[898] | 0) | 0;
	                    if ((c[m >> 2] | 0) < 0) {
	                        Ka(c[o >> 2] | 0, 3880, d | 0) | 0;
	                        GQ(c[898] | 0);
	                        c[898] = 0
	                    }
	                } while (0);
	                if (!(c[k >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                i = b;
	                return
	            }

	            function qc(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, j = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b;
	                e = b + 20 | 0;
	                f = b + 16 | 0;
	                g = b + 12 | 0;
	                j = b + 8 | 0;
	                c[e >> 2] = a;
	                switch (c[c[e >> 2] >> 2] | 0) {
	                    case 4:
	                    {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 24 >> 2];
	                        Wa(3904, d | 0) | 0;
	                        i = b;
	                        return
	                    }
	                    case 3:
	                    {
	                        a = Mq(+h[(c[e >> 2] | 0) + 16 >> 3]) | 0;
	                        if ((a | 0) == -1) {
	                            Wa(4032, d | 0) | 0;
	                            i = b;
	                            return
	                        } else if ((a | 0) != 1)if (Lq(+h[(c[e >> 2] | 0) + 16 >> 3]) | 0) {
	                            Wa(4048, d | 0) | 0;
	                            i = b;
	                            return
	                        } else {
	                            h[k >> 3] = +h[(c[e >> 2] | 0) + 16 >> 3];
	                            c[d >> 2] = c[k >> 2];
	                            c[d + 4 >> 2] = c[k + 4 >> 2];
	                            Wa(4056, d | 0) | 0;
	                            i = b;
	                            return
	                        } else {
	                            Wa(4016, d | 0) | 0;
	                            i = b;
	                            return
	                        }
	                        break
	                    }
	                    case 1:
	                    {
	                        if ((c[(c[e >> 2] | 0) + 4 >> 2] | 0) != 0 ? (c[c[(c[e >> 2] | 0) + 4 >> 2] >> 2] | 0) > 0 : 0) {
	                            c[j >> 2] = rR(1, 0, 0) | 0;
	                            if (!(c[j >> 2] | 0)) {
	                                Ka(c[o >> 2] | 0, 3912, d | 0) | 0;
	                                c[662] = 9;
	                                i = b;
	                                return
	                            }
	                            c[f >> 2] = 0;
	                            while (1) {
	                                if ((c[f >> 2] | 0) >= (c[c[(c[e >> 2] | 0) + 4 >> 2] >> 2] | 0))break;
	                                c[g >> 2] = c[(c[(c[(c[e >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0) + (c[f >> 2] << 2) >> 2];
	                                uR(c[j >> 2] | 0, c[g >> 2] | 0) | 0;
	                                c[f >> 2] = (c[f >> 2] | 0) + 1
	                            }
	                            wR(c[j >> 2] | 0) | 0;
	                            i = b;
	                            return
	                        }
	                        Ka(c[o >> 2] | 0, 3976, d | 0) | 0;
	                        c[662] = 10;
	                        i = b;
	                        return
	                    }
	                    case 2:
	                    {
	                        if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                            Wa(4e3, d | 0) | 0;
	                            i = b;
	                            return
	                        } else {
	                            Wa(4008, d | 0) | 0;
	                            i = b;
	                            return
	                        }
	                        break
	                    }
	                    case 0:
	                    {
	                        Ka(c[o >> 2] | 0, 4064, d | 0) | 0;
	                        c[662] = 10;
	                        i = b;
	                        return
	                    }
	                    default:
	                    {
	                        Ka(c[o >> 2] | 0, 4096, d | 0) | 0;
	                        c[662] = 10;
	                        i = b;
	                        return
	                    }
	                }
	            }

	            function rc(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                c[e >> 2] = a;
	                Db[c[135904 >> 2] & 511](c[33980] | 0, 54216, d);
	                c[f >> 2] = ZT(4136) | 0;
	                if (!(c[e >> 2] | 0)) {
	                    sc();
	                    i = b;
	                    return
	                }
	                a = 4136 + (c[f >> 2] | 0) | 0;
	                g = 5e4 - (c[f >> 2] | 0) | 0;
	                f = c[e >> 2] | 0;
	                if (c[(c[e >> 2] | 0) + 4 >> 2] | 0) {
	                    h = c[(c[e >> 2] | 0) + 28 >> 2] | 0;
	                    c[d >> 2] = c[f + 4 >> 2];
	                    c[d + 4 >> 2] = h;
	                    JT(a, g, 54224, d) | 0;
	                    sc();
	                    i = b;
	                    return
	                } else {
	                    c[d >> 2] = c[f + 28 >> 2];
	                    JT(a, g, 54232, d) | 0;
	                    sc();
	                    i = b;
	                    return
	                }
	            }

	            function sc() {
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                e = b + 4 | 0;
	                c[e >> 2] = cd(0, 4136) | 0;
	                if (!(c[e >> 2] | 0)) {
	                    a[4136] = 0;
	                    i = b;
	                    return
	                }
	                f = c[33976] | 0;
	                g = c[33980] | 0;
	                c[d >> 2] = c[e >> 2];
	                Db[f & 511](g, 3904, d);
	                zb[c[135736 >> 2] & 511](c[e >> 2] | 0);
	                a[4136] = 0;
	                i = b;
	                return
	            }

	            function tc(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                b = i;
	                i = i + 32 | 0;
	                e = b;
	                f = b + 20 | 0;
	                g = b + 16 | 0;
	                h = b + 12 | 0;
	                j = b + 8 | 0;
	                k = b + 4 | 0;
	                c[f >> 2] = a;
	                if (!(c[f >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                Db[c[135904 >> 2] & 511](c[33980] | 0, 54176, e);
	                c[g >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                c[h >> 2] = c[(c[f >> 2] | 0) + 12 >> 2];
	                while (1) {
	                    if ((c[g >> 2] | 0) >>> 0 <= (c[h >> 2] | 0) >>> 0)break;
	                    if ((d[c[g >> 2] >> 0] | 0 | 0) != 10 ? (d[c[g >> 2] >> 0] | 0 | 0) != 13 : 0)break;
	                    c[g >> 2] = (c[g >> 2] | 0) + -1
	                }
	                c[k >> 2] = 0;
	                while (1) {
	                    a = c[k >> 2] | 0;
	                    c[k >> 2] = a + 1;
	                    if (((a | 0) < 80 ? (c[g >> 2] | 0) >>> 0 > (c[h >> 2] | 0) >>> 0 : 0) ? (d[c[g >> 2] >> 0] | 0 | 0) != 10 : 0)l = (d[c[g >> 2] >> 0] | 0 | 0) != 13; else l = 0;
	                    m = c[g >> 2] | 0;
	                    if (!l)break;
	                    c[g >> 2] = m + -1
	                }
	                if (!((d[m >> 0] | 0 | 0) != 10 ? (d[c[g >> 2] >> 0] | 0 | 0) != 13 : 0))c[g >> 2] = (c[g >> 2] | 0) + 1;
	                c[h >> 2] = c[g >> 2];
	                c[k >> 2] = 0;
	                while (1) {
	                    if (((d[c[g >> 2] >> 0] | 0 | 0) != 0 ? (d[c[g >> 2] >> 0] | 0 | 0) != 10 : 0) ? (d[c[g >> 2] >> 0] | 0 | 0) != 13 : 0)n = (c[k >> 2] | 0) < 79; else n = 0;
	                    c[j >> 2] = ZT(4136) | 0;
	                    o = 4136 + (c[j >> 2] | 0) | 0;
	                    p = 5e4 - (c[j >> 2] | 0) | 0;
	                    if (!n)break;
	                    m = c[g >> 2] | 0;
	                    c[g >> 2] = m + 1;
	                    c[e >> 2] = d[m >> 0];
	                    JT(o, p, 54184, e) | 0;
	                    c[k >> 2] = (c[k >> 2] | 0) + 1
	                }
	                JT(o, p, 3760, e) | 0;
	                c[g >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                while (1) {
	                    if ((d[c[g >> 2] >> 0] | 0 | 0) != 10 ? (d[c[g >> 2] >> 0] | 0 | 0) != 13 : 0)break;
	                    c[g >> 2] = (c[g >> 2] | 0) + -1
	                }
	                c[k >> 2] = 0;
	                while (1) {
	                    if ((c[g >> 2] | 0) != (c[h >> 2] | 0)) {
	                        f = c[k >> 2] | 0;
	                        c[k >> 2] = f + 1;
	                        q = (f | 0) < 80
	                    } else q = 0;
	                    c[j >> 2] = ZT(4136) | 0;
	                    r = 4136 + (c[j >> 2] | 0) | 0;
	                    s = 5e4 - (c[j >> 2] | 0) | 0;
	                    if (!q)break;
	                    JT(r, s, 54192, e) | 0;
	                    c[h >> 2] = (c[h >> 2] | 0) + 1
	                }
	                JT(r, s, 54200, e) | 0;
	                sc();
	                Db[c[135904 >> 2] & 511](c[33980] | 0, 54208, e);
	                i = b;
	                return
	            }

	            function uc(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                c[f + 16 >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[13584] = (c[13584] | 0) + 1;
	                if (c[50] | 0) {
	                    i = f;
	                    return
	                }
	                e = c[q >> 2] | 0;
	                c[g >> 2] = c[h >> 2];
	                Ka(e | 0, 55552, g | 0) | 0;
	                e = c[q >> 2] | 0;
	                if (!(c[j >> 2] | 0))Ka(e | 0, 54736, g | 0) | 0; else {
	                    c[g >> 2] = c[j >> 2];
	                    Ka(e | 0, 54744, g | 0) | 0
	                }
	                e = c[q >> 2] | 0;
	                if (!(c[k >> 2] | 0)) {
	                    Ka(e | 0, 54752, g | 0) | 0;
	                    i = f;
	                    return
	                } else {
	                    c[g >> 2] = c[k >> 2];
	                    Ka(e | 0, 54760, g | 0) | 0;
	                    i = f;
	                    return
	                }
	            }

	            function vc(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                c[b + 4 >> 2] = a;
	                c[13584] = (c[13584] | 0) + 1;
	                if (c[50] | 0) {
	                    c[d >> 2] = 0;
	                    e = c[d >> 2] | 0;
	                    i = b;
	                    return e | 0
	                } else {
	                    Ka(c[q >> 2] | 0, 55528, b | 0) | 0;
	                    c[d >> 2] = 0;
	                    e = c[d >> 2] | 0;
	                    i = b;
	                    return e | 0
	                }
	                return 0
	            }

	            function wc(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                c[b + 4 >> 2] = a;
	                c[13584] = (c[13584] | 0) + 1;
	                if (c[50] | 0) {
	                    c[d >> 2] = 0;
	                    e = c[d >> 2] | 0;
	                    i = b;
	                    return e | 0
	                } else {
	                    Ka(c[q >> 2] | 0, 55496, b | 0) | 0;
	                    c[d >> 2] = 0;
	                    e = c[d >> 2] | 0;
	                    i = b;
	                    return e | 0
	                }
	                return 0
	            }

	            function xc(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                c[b + 4 >> 2] = a;
	                c[13584] = (c[13584] | 0) + 1;
	                if (c[50] | 0) {
	                    c[d >> 2] = 0;
	                    e = c[d >> 2] | 0;
	                    i = b;
	                    return e | 0
	                } else {
	                    Ka(c[q >> 2] | 0, 55464, b | 0) | 0;
	                    c[d >> 2] = 0;
	                    e = c[d >> 2] | 0;
	                    i = b;
	                    return e | 0
	                }
	                return 0
	            }

	            function yc(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e;
	                g = e + 16 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                c[e + 12 >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[13584] = (c[13584] | 0) + 1;
	                if (c[50] | 0) {
	                    c[g >> 2] = 0;
	                    k = c[g >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                Ka(c[q >> 2] | 0, 55424, f | 0) | 0;
	                d = c[q >> 2] | 0;
	                if (c[h >> 2] | 0) {
	                    c[f >> 2] = c[h >> 2];
	                    Ka(d | 0, 3904, f | 0) | 0
	                } else Ka(d | 0, 54192, f | 0) | 0;
	                d = c[q >> 2] | 0;
	                if (c[j >> 2] | 0) {
	                    c[f >> 2] = c[j >> 2];
	                    Ka(d | 0, 55448, f | 0) | 0
	                } else Ka(d | 0, 55456, f | 0) | 0;
	                c[g >> 2] = 0;
	                k = c[g >> 2] | 0;
	                i = e;
	                return k | 0
	            }

	            function zc(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                f = d + 12 | 0;
	                g = d + 4 | 0;
	                c[d + 8 >> 2] = a;
	                c[g >> 2] = b;
	                c[13584] = (c[13584] | 0) + 1;
	                if (c[50] | 0) {
	                    c[f >> 2] = 0;
	                    h = c[f >> 2] | 0;
	                    i = d;
	                    return h | 0
	                } else {
	                    b = c[q >> 2] | 0;
	                    c[e >> 2] = c[g >> 2];
	                    Ka(b | 0, 55400, e | 0) | 0;
	                    c[f >> 2] = 0;
	                    h = c[f >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                return 0
	            }

	            function Ac(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h;
	                k = h + 40 | 0;
	                l = h + 36 | 0;
	                m = h + 32 | 0;
	                n = h + 28 | 0;
	                o = h + 24 | 0;
	                p = h + 20 | 0;
	                c[h + 44 >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                c[p >> 2] = 55152;
	                if (!(c[m >> 2] | 0))c[m >> 2] = c[p >> 2];
	                if (!(c[n >> 2] | 0))c[n >> 2] = c[p >> 2];
	                if (!(c[o >> 2] | 0))c[o >> 2] = c[p >> 2];
	                c[13584] = (c[13584] | 0) + 1;
	                if (c[50] | 0) {
	                    i = h;
	                    return
	                }
	                p = c[q >> 2] | 0;
	                g = c[l >> 2] | 0;
	                l = c[m >> 2] | 0;
	                m = c[n >> 2] | 0;
	                n = c[o >> 2] | 0;
	                c[j >> 2] = c[k >> 2];
	                c[j + 4 >> 2] = g;
	                c[j + 8 >> 2] = l;
	                c[j + 12 >> 2] = m;
	                c[j + 16 >> 2] = n;
	                Ka(p | 0, 55360, j | 0) | 0;
	                i = h;
	                return
	            }

	            function Bc(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f;
	                h = f + 20 | 0;
	                j = f + 16 | 0;
	                k = f + 12 | 0;
	                c[f + 24 >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[13584] = (c[13584] | 0) + 1;
	                if (c[50] | 0) {
	                    i = f;
	                    return
	                }
	                e = c[q >> 2] | 0;
	                d = c[j >> 2] | 0;
	                j = c[k >> 2] | 0;
	                c[g >> 2] = c[h >> 2];
	                c[g + 4 >> 2] = d;
	                c[g + 8 >> 2] = j;
	                Ka(e | 0, 55328, g | 0) | 0;
	                i = f;
	                return
	            }

	            function Cc(a, b, d, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, r = 0;
	                j = i;
	                i = i + 48 | 0;
	                k = j;
	                l = j + 40 | 0;
	                m = j + 36 | 0;
	                n = j + 32 | 0;
	                o = j + 28 | 0;
	                p = j + 24 | 0;
	                r = j + 20 | 0;
	                c[j + 44 >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                c[r >> 2] = h;
	                c[13584] = (c[13584] | 0) + 1;
	                if (c[50] | 0) {
	                    i = j;
	                    return
	                }
	                h = c[q >> 2] | 0;
	                g = c[l >> 2] | 0;
	                l = c[m >> 2] | 0;
	                m = c[n >> 2] | 0;
	                n = c[o >> 2] | 0;
	                if (!(c[p >> 2] | 0)) {
	                    c[k >> 2] = g;
	                    c[k + 4 >> 2] = l;
	                    c[k + 8 >> 2] = m;
	                    c[k + 12 >> 2] = n;
	                    Ka(h | 0, 55232, k | 0) | 0
	                } else {
	                    o = c[p >> 2] | 0;
	                    c[k >> 2] = g;
	                    c[k + 4 >> 2] = l;
	                    c[k + 8 >> 2] = m;
	                    c[k + 12 >> 2] = n;
	                    c[k + 16 >> 2] = o;
	                    Ka(h | 0, 55280, k | 0) | 0
	                }
	                rm(c[r >> 2] | 0);
	                i = j;
	                return
	            }

	            function Dc(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                c[f + 20 >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[f + 8 >> 2] = e;
	                c[13584] = (c[13584] | 0) + 1;
	                if (c[50] | 0) {
	                    i = f;
	                    return
	                }
	                e = c[q >> 2] | 0;
	                d = c[j >> 2] | 0;
	                c[g >> 2] = c[h >> 2];
	                c[g + 4 >> 2] = d;
	                Ka(e | 0, 55200, g | 0) | 0;
	                i = f;
	                return
	            }

	            function Ec(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                g = i;
	                i = i + 48 | 0;
	                h = g;
	                j = g + 32 | 0;
	                k = g + 28 | 0;
	                l = g + 24 | 0;
	                m = g + 20 | 0;
	                n = g + 16 | 0;
	                c[g + 36 >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                c[n >> 2] = 55152;
	                if (!(c[k >> 2] | 0))c[k >> 2] = c[n >> 2];
	                if (!(c[l >> 2] | 0))c[l >> 2] = c[n >> 2];
	                if (!(c[m >> 2] | 0))c[m >> 2] = c[n >> 2];
	                c[13584] = (c[13584] | 0) + 1;
	                if (c[50] | 0) {
	                    i = g;
	                    return
	                }
	                n = c[q >> 2] | 0;
	                f = c[k >> 2] | 0;
	                k = c[l >> 2] | 0;
	                l = c[m >> 2] | 0;
	                c[h >> 2] = c[j >> 2];
	                c[h + 4 >> 2] = f;
	                c[h + 8 >> 2] = k;
	                c[h + 12 >> 2] = l;
	                Ka(n | 0, 55160, h | 0) | 0;
	                i = g;
	                return
	            }

	            function Fc(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0;
	                d = i;
	                i = i + 16 | 0;
	                c[d + 8 >> 2] = a;
	                c[d + 4 >> 2] = b;
	                c[13584] = (c[13584] | 0) + 1;
	                if (c[50] | 0) {
	                    i = d;
	                    return
	                }
	                Ka(c[q >> 2] | 0, 55120, d | 0) | 0;
	                i = d;
	                return
	            }

	            function Gc(a) {
	                a = a | 0;
	                var b = 0;
	                b = i;
	                i = i + 16 | 0;
	                c[b + 4 >> 2] = a;
	                c[13584] = (c[13584] | 0) + 1;
	                if (c[50] | 0) {
	                    i = b;
	                    return
	                }
	                Ka(c[q >> 2] | 0, 55096, b | 0) | 0;
	                i = b;
	                return
	            }

	            function Hc(a) {
	                a = a | 0;
	                var b = 0;
	                b = i;
	                i = i + 16 | 0;
	                c[b + 4 >> 2] = a;
	                c[13584] = (c[13584] | 0) + 1;
	                if (c[50] | 0) {
	                    i = b;
	                    return
	                }
	                Ka(c[q >> 2] | 0, 55072, b | 0) | 0;
	                i = b;
	                return
	            }

	            function Ic(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                f = d + 4 | 0;
	                c[d + 8 >> 2] = a;
	                c[f >> 2] = b;
	                c[13584] = (c[13584] | 0) + 1;
	                if (c[50] | 0) {
	                    i = d;
	                    return
	                }
	                b = c[q >> 2] | 0;
	                c[e >> 2] = c[f >> 2];
	                Ka(b | 0, 55048, e | 0) | 0;
	                i = d;
	                return
	            }

	            function Jc(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 64 | 0;
	                g = f;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 24 | 0;
	                l = f + 8 | 0;
	                c[f + 20 >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = e;
	                c[13584] = (c[13584] | 0) + 1;
	                if (c[50] | 0) {
	                    i = f;
	                    return
	                }
	                c[l >> 2] = 0;
	                while (1) {
	                    m = c[l >> 2] | 0;
	                    if (!((c[l >> 2] | 0) < 30 ? (c[l >> 2] | 0) < (c[j >> 2] | 0) : 0))break;
	                    a[k + (c[l >> 2] | 0) >> 0] = a[(c[h >> 2] | 0) + m >> 0] | 0;
	                    c[l >> 2] = (c[l >> 2] | 0) + 1
	                }
	                a[k + m >> 0] = 0;
	                m = c[q >> 2] | 0;
	                l = c[j >> 2] | 0;
	                c[g >> 2] = k;
	                c[g + 4 >> 2] = l;
	                Ka(m | 0, 55024, g | 0) | 0;
	                i = f;
	                return
	            }

	            function Kc(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 64 | 0;
	                g = f;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 24 | 0;
	                l = f + 8 | 0;
	                c[f + 20 >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = e;
	                c[13584] = (c[13584] | 0) + 1;
	                if (c[50] | 0) {
	                    i = f;
	                    return
	                }
	                c[l >> 2] = 0;
	                while (1) {
	                    m = c[l >> 2] | 0;
	                    if (!((c[l >> 2] | 0) < 30 ? (c[l >> 2] | 0) < (c[j >> 2] | 0) : 0))break;
	                    a[k + (c[l >> 2] | 0) >> 0] = a[(c[h >> 2] | 0) + m >> 0] | 0;
	                    c[l >> 2] = (c[l >> 2] | 0) + 1
	                }
	                a[k + m >> 0] = 0;
	                m = c[q >> 2] | 0;
	                l = c[j >> 2] | 0;
	                c[g >> 2] = k;
	                c[g + 4 >> 2] = l;
	                Ka(m | 0, 54984, g | 0) | 0;
	                i = f;
	                return
	            }

	            function Lc(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                c[e + 16 >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[13584] = (c[13584] | 0) + 1;
	                if (c[50] | 0) {
	                    i = e;
	                    return
	                }
	                d = c[q >> 2] | 0;
	                b = c[g >> 2] | 0;
	                if (c[h >> 2] | 0) {
	                    g = c[h >> 2] | 0;
	                    c[f >> 2] = b;
	                    c[f + 4 >> 2] = g;
	                    Ka(d | 0, 54904, f | 0) | 0;
	                    i = e;
	                    return
	                } else {
	                    c[f >> 2] = b;
	                    Ka(d | 0, 54944, f | 0) | 0;
	                    i = e;
	                    return
	                }
	            }

	            function Mc(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                f = d + 4 | 0;
	                c[d + 8 >> 2] = a;
	                c[f >> 2] = b;
	                c[13584] = (c[13584] | 0) + 1;
	                if (c[50] | 0) {
	                    i = d;
	                    return
	                }
	                b = c[q >> 2] | 0;
	                c[e >> 2] = c[f >> 2];
	                Ka(b | 0, 54880, e | 0) | 0;
	                i = d;
	                return
	            }

	            function Nc(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 8 | 0;
	                c[e + 28 >> 2] = a;
	                c[f >> 2] = b;
	                c[13584] = (c[13584] | 0) + 1;
	                if (c[50] | 0) {
	                    i = e;
	                    return
	                }
	                c[g >> 2] = d;
	                Ka(c[q >> 2] | 0, 54864, e | 0) | 0;
	                Ca(c[q >> 2] | 0, c[f >> 2] | 0, g | 0) | 0;
	                i = e;
	                return
	            }

	            function Oc(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 8 | 0;
	                c[e + 28 >> 2] = a;
	                c[f >> 2] = b;
	                c[13584] = (c[13584] | 0) + 1;
	                if (c[50] | 0) {
	                    i = e;
	                    return
	                }
	                c[g >> 2] = d;
	                Ka(c[q >> 2] | 0, 54848, e | 0) | 0;
	                Ca(c[q >> 2] | 0, c[f >> 2] | 0, g | 0) | 0;
	                i = e;
	                return
	            }

	            function Pc(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 8 | 0;
	                c[e + 28 >> 2] = a;
	                c[f >> 2] = b;
	                c[13584] = (c[13584] | 0) + 1;
	                if (c[50] | 0) {
	                    i = e;
	                    return
	                }
	                c[g >> 2] = d;
	                Ka(c[q >> 2] | 0, 54824, e | 0) | 0;
	                Ca(c[q >> 2] | 0, c[f >> 2] | 0, g | 0) | 0;
	                i = e;
	                return
	            }

	            function Qc(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                f = d + 12 | 0;
	                g = d + 4 | 0;
	                c[d + 8 >> 2] = a;
	                c[g >> 2] = b;
	                c[13584] = (c[13584] | 0) + 1;
	                if (c[50] | 0) {
	                    c[f >> 2] = 0;
	                    h = c[f >> 2] | 0;
	                    i = d;
	                    return h | 0
	                } else {
	                    b = c[q >> 2] | 0;
	                    c[e >> 2] = c[g >> 2];
	                    Ka(b | 0, 54792, e | 0) | 0;
	                    c[f >> 2] = 0;
	                    h = c[f >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                return 0
	            }

	            function Rc(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                c[e + 16 >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[13584] = (c[13584] | 0) + 1;
	                if (c[50] | 0) {
	                    i = e;
	                    return
	                }
	                d = c[q >> 2] | 0;
	                b = c[h >> 2] | 0;
	                c[f >> 2] = c[g >> 2];
	                c[f + 4 >> 2] = b;
	                Ka(d | 0, 54768, f | 0) | 0;
	                i = e;
	                return
	            }

	            function Sc(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                c[f + 16 >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[13584] = (c[13584] | 0) + 1;
	                if (c[50] | 0) {
	                    i = f;
	                    return
	                }
	                e = c[q >> 2] | 0;
	                c[g >> 2] = c[h >> 2];
	                Ka(e | 0, 54712, g | 0) | 0;
	                e = c[q >> 2] | 0;
	                if (!(c[j >> 2] | 0))Ka(e | 0, 54736, g | 0) | 0; else {
	                    c[g >> 2] = c[j >> 2];
	                    Ka(e | 0, 54744, g | 0) | 0
	                }
	                e = c[q >> 2] | 0;
	                if (!(c[k >> 2] | 0)) {
	                    Ka(e | 0, 54752, g | 0) | 0;
	                    i = f;
	                    return
	                } else {
	                    c[g >> 2] = c[k >> 2];
	                    Ka(e | 0, 54760, g | 0) | 0;
	                    i = f;
	                    return
	                }
	            }

	            function Tc(a, b, d, e, f, g, h, j, k) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                k = k | 0;
	                var l = 0, m = 0, n = 0, o = 0, p = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0;
	                l = i;
	                i = i + 48 | 0;
	                m = l;
	                n = l + 40 | 0;
	                o = l + 36 | 0;
	                p = l + 32 | 0;
	                r = l + 28 | 0;
	                s = l + 24 | 0;
	                t = l + 20 | 0;
	                u = l + 16 | 0;
	                v = l + 12 | 0;
	                w = l + 8 | 0;
	                c[l + 44 >> 2] = a;
	                c[n >> 2] = b;
	                c[o >> 2] = d;
	                c[p >> 2] = e;
	                c[r >> 2] = f;
	                c[s >> 2] = g;
	                c[t >> 2] = h;
	                c[u >> 2] = j;
	                c[v >> 2] = k;
	                c[13584] = (c[13584] | 0) + 1;
	                if (c[50] | 0) {
	                    i = l;
	                    return
	                }
	                k = c[q >> 2] | 0;
	                c[m >> 2] = c[n >> 2];
	                Ka(k | 0, 54584, m | 0) | 0;
	                k = c[q >> 2] | 0;
	                if (!(c[o >> 2] | 0))Ka(k | 0, 54536, m | 0) | 0; else {
	                    c[m >> 2] = c[o >> 2];
	                    Ka(k | 0, 54544, m | 0) | 0
	                }
	                k = c[q >> 2] | 0;
	                if (!(c[p >> 2] | 0))Ka(k | 0, 54536, m | 0) | 0; else {
	                    c[m >> 2] = c[p >> 2];
	                    Ka(k | 0, 54608, m | 0) | 0
	                }
	                k = c[q >> 2] | 0;
	                c[m >> 2] = c[r >> 2];
	                Ka(k | 0, 54616, m | 0) | 0;
	                a:do if (c[s >> 2] | 0) {
	                    c[w >> 2] = 0;
	                    while (1) {
	                        if ((c[w >> 2] | 0) >= (c[r >> 2] << 1 | 0))break a;
	                        Ka(c[q >> 2] | 0, 54624, m | 0) | 0;
	                        if (c[(c[s >> 2] | 0) + (c[w >> 2] << 2) >> 2] | 0) {
	                            k = c[q >> 2] | 0;
	                            c[m >> 2] = c[(c[s >> 2] | 0) + (c[w >> 2] << 2) >> 2];
	                            Ka(k | 0, 54632, m | 0) | 0
	                        }
	                        c[w >> 2] = (c[w >> 2] | 0) + 1;
	                        k = c[q >> 2] | 0;
	                        c[m >> 2] = c[(c[s >> 2] | 0) + (c[w >> 2] << 2) >> 2];
	                        Ka(k | 0, 54640, m | 0) | 0;
	                        c[w >> 2] = (c[w >> 2] | 0) + 1
	                    }
	                } while (0);
	                s = c[q >> 2] | 0;
	                r = c[u >> 2] | 0;
	                c[m >> 2] = c[t >> 2];
	                c[m + 4 >> 2] = r;
	                Ka(s | 0, 54648, m | 0) | 0;
	                b:do if (c[v >> 2] | 0) {
	                    c[w >> 2] = 0;
	                    while (1) {
	                        if ((c[w >> 2] | 0) >= ((c[t >> 2] | 0) * 5 | 0))break b;
	                        s = c[q >> 2] | 0;
	                        r = c[w >> 2] | 0;
	                        if (c[(c[v >> 2] | 0) + ((c[w >> 2] | 0) + 1 << 2) >> 2] | 0) {
	                            u = c[(c[v >> 2] | 0) + (c[w >> 2] << 2) >> 2] | 0;
	                            c[m >> 2] = c[(c[v >> 2] | 0) + (r + 1 << 2) >> 2];
	                            c[m + 4 >> 2] = u;
	                            Ka(s | 0, 54664, m | 0) | 0
	                        } else {
	                            c[m >> 2] = c[(c[v >> 2] | 0) + (r << 2) >> 2];
	                            Ka(s | 0, 54680, m | 0) | 0
	                        }
	                        s = c[q >> 2] | 0;
	                        r = (c[(c[v >> 2] | 0) + ((c[w >> 2] | 0) + 4 << 2) >> 2] | 0) - (c[(c[v >> 2] | 0) + ((c[w >> 2] | 0) + 3 << 2) >> 2] | 0) | 0;
	                        c[m >> 2] = c[(c[v >> 2] | 0) + ((c[w >> 2] | 0) + 3 << 2) >> 2];
	                        c[m + 4 >> 2] = r;
	                        Ka(s | 0, 54688, m | 0) | 0;
	                        c[w >> 2] = (c[w >> 2] | 0) + 5
	                    }
	                } while (0);
	                Ka(c[q >> 2] | 0, 54704, m | 0) | 0;
	                i = l;
	                return
	            }

	            function Uc(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                c[f + 16 >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[13584] = (c[13584] | 0) + 1;
	                if (c[50] | 0) {
	                    i = f;
	                    return
	                }
	                e = c[q >> 2] | 0;
	                c[g >> 2] = c[h >> 2];
	                Ka(e | 0, 54512, g | 0) | 0;
	                e = c[q >> 2] | 0;
	                if (!(c[j >> 2] | 0))Ka(e | 0, 54536, g | 0) | 0; else {
	                    c[g >> 2] = c[j >> 2];
	                    Ka(e | 0, 54544, g | 0) | 0
	                }
	                e = c[q >> 2] | 0;
	                if (!(c[k >> 2] | 0)) {
	                    Ka(e | 0, 54552, g | 0) | 0;
	                    i = f;
	                    return
	                } else {
	                    c[g >> 2] = c[k >> 2];
	                    Ka(e | 0, 54568, g | 0) | 0;
	                    i = f;
	                    return
	                }
	            }

	            function Vc() {
	                var a = 0, b = 0, d = 0;
	                a = i;
	                i = i + 16 | 0;
	                b = a;
	                d = c[o >> 2] | 0;
	                c[b >> 2] = c[432];
	                Ka(d | 0, 56400, b | 0) | 0;
	                c[662] = 9;
	                i = a;
	                return
	            }

	            function Wc(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                c[e + 16 >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[13584] = (c[13584] | 0) + 1;
	                if (c[50] | 0) {
	                    i = e;
	                    return
	                }
	                d = c[q >> 2] | 0;
	                c[f >> 2] = c[g >> 2];
	                Ka(d | 0, 60952, f | 0) | 0;
	                a:do if (c[h >> 2] | 0) {
	                    c[j >> 2] = 0;
	                    while (1) {
	                        if (!(c[(c[h >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0))break a;
	                        d = c[q >> 2] | 0;
	                        g = c[j >> 2] | 0;
	                        c[j >> 2] = g + 1;
	                        c[f >> 2] = c[(c[h >> 2] | 0) + (g << 2) >> 2];
	                        Ka(d | 0, 54680, f | 0) | 0;
	                        if (c[(c[h >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) {
	                            d = c[q >> 2] | 0;
	                            c[f >> 2] = c[(c[h >> 2] | 0) + (c[j >> 2] << 2) >> 2];
	                            Ka(d | 0, 60976, f | 0) | 0
	                        }
	                        c[j >> 2] = (c[j >> 2] | 0) + 1
	                    }
	                } while (0);
	                Ka(c[q >> 2] | 0, 54704, f | 0) | 0;
	                i = e;
	                return
	            }

	            function Xc(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                f = d + 4 | 0;
	                c[d + 8 >> 2] = a;
	                c[f >> 2] = b;
	                c[13584] = (c[13584] | 0) + 1;
	                if (c[50] | 0) {
	                    i = d;
	                    return
	                }
	                b = c[q >> 2] | 0;
	                c[e >> 2] = c[f >> 2];
	                Ka(b | 0, 60928, e | 0) | 0;
	                i = d;
	                return
	            }

	            function Yc(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[f >> 2] = a;
	                do if (!(c[f >> 2] | 0))c[e >> 2] = 0; else {
	                    a = d[c[f >> 2] >> 0] | 0;
	                    if ((a | 0) == 103) {
	                        if (qy(c[f >> 2] | 0, 61072) | 0) {
	                            c[e >> 2] = 61080;
	                            break
	                        }
	                    } else if ((a | 0) == 97) {
	                        if (qy(c[f >> 2] | 0, 61160) | 0) {
	                            c[e >> 2] = 61168;
	                            break
	                        }
	                        if (qy(c[f >> 2] | 0, 61248) | 0) {
	                            c[e >> 2] = 61256;
	                            break
	                        }
	                    } else if ((a | 0) == 108) {
	                        if (qy(c[f >> 2] | 0, 60984) | 0) {
	                            c[e >> 2] = 60992;
	                            break
	                        }
	                    } else if ((a | 0) == 113 ? (qy(c[f >> 2] | 0, 61336) | 0) != 0 : 0) {
	                        c[e >> 2] = 61344;
	                        break
	                    }
	                    c[e >> 2] = 0
	                } while (0);
	                i = b;
	                return c[e >> 2] | 0
	            }

	            function Zc(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h + 32 | 0;
	                k = h + 28 | 0;
	                l = h + 24 | 0;
	                m = h + 20 | 0;
	                n = h + 16 | 0;
	                o = h + 12 | 0;
	                p = h + 8 | 0;
	                q = h + 4 | 0;
	                r = h;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                if (!(c[k >> 2] | 0)) {
	                    gd(521, 61424);
	                    c[j >> 2] = 0;
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                }
	                if (!(c[(c[k >> 2] | 0) + 48 >> 2] | 0)) {
	                    gd(522, 61464);
	                    c[j >> 2] = 0;
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                }
	                c[r >> 2] = c[(c[k >> 2] | 0) + 48 >> 2];
	                c[q >> 2] = hd(c[r >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0) | 0;
	                if (!(c[q >> 2] | 0)) {
	                    c[j >> 2] = 0;
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                }
	                c[(c[q >> 2] | 0) + 20 >> 2] = c[r >> 2];
	                c[(c[q >> 2] | 0) + 32 >> 2] = c[(c[r >> 2] | 0) + 32 >> 2];
	                p = c[q >> 2] | 0;
	                o = (c[r >> 2] | 0) + 16 | 0;
	                if (!(c[(c[r >> 2] | 0) + 16 >> 2] | 0)) {
	                    c[o >> 2] = p;
	                    c[(c[r >> 2] | 0) + 12 >> 2] = p
	                } else {
	                    c[(c[o >> 2] | 0) + 24 >> 2] = p;
	                    c[(c[q >> 2] | 0) + 28 >> 2] = c[(c[r >> 2] | 0) + 16 >> 2];
	                    c[(c[r >> 2] | 0) + 16 >> 2] = c[q >> 2]
	                }
	                c[j >> 2] = c[q >> 2];
	                s = c[j >> 2] | 0;
	                i = h;
	                return s | 0
	            }

	            function _c(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h + 32 | 0;
	                k = h + 28 | 0;
	                l = h + 24 | 0;
	                m = h + 20 | 0;
	                n = h + 16 | 0;
	                o = h + 12 | 0;
	                p = h + 8 | 0;
	                q = h + 4 | 0;
	                r = h;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                if (!(c[k >> 2] | 0)) {
	                    gd(521, 61520);
	                    c[j >> 2] = 0;
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                }
	                if (!(c[(c[k >> 2] | 0) + 44 >> 2] | 0)) {
	                    gd(522, 61560);
	                    c[j >> 2] = 0;
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                }
	                c[r >> 2] = c[(c[k >> 2] | 0) + 44 >> 2];
	                c[q >> 2] = hd(c[r >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0) | 0;
	                if (!(c[q >> 2] | 0)) {
	                    c[j >> 2] = 0;
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                }
	                c[(c[q >> 2] | 0) + 20 >> 2] = c[r >> 2];
	                c[(c[q >> 2] | 0) + 32 >> 2] = c[(c[r >> 2] | 0) + 32 >> 2];
	                p = c[q >> 2] | 0;
	                o = (c[r >> 2] | 0) + 16 | 0;
	                if (!(c[(c[r >> 2] | 0) + 16 >> 2] | 0)) {
	                    c[o >> 2] = p;
	                    c[(c[r >> 2] | 0) + 12 >> 2] = p
	                } else {
	                    c[(c[o >> 2] | 0) + 24 >> 2] = p;
	                    c[(c[q >> 2] | 0) + 28 >> 2] = c[(c[r >> 2] | 0) + 16 >> 2];
	                    c[(c[r >> 2] | 0) + 16 >> 2] = c[q >> 2]
	                }
	                c[j >> 2] = c[q >> 2];
	                s = c[j >> 2] | 0;
	                i = h;
	                return s | 0
	            }

	            function $c(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                if (((c[(c[f >> 2] | 0) + 44 >> 2] | 0) != 0 ? (c[(c[(c[f >> 2] | 0) + 44 >> 2] | 0) + 60 >> 2] | 0) != 0 : 0) ? (c[h >> 2] = c[(c[(c[f >> 2] | 0) + 44 >> 2] | 0) + 60 >> 2], c[j >> 2] = jd(c[h >> 2] | 0, c[g >> 2] | 0) | 0, (c[j >> 2] | 0) != 0) : 0) {
	                    c[e >> 2] = c[j >> 2];
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                if ((c[(c[f >> 2] | 0) + 48 >> 2] | 0) != 0 ? (c[(c[(c[f >> 2] | 0) + 48 >> 2] | 0) + 60 >> 2] | 0) != 0 : 0) {
	                    c[h >> 2] = c[(c[(c[f >> 2] | 0) + 48 >> 2] | 0) + 60 >> 2];
	                    c[e >> 2] = jd(c[h >> 2] | 0, c[g >> 2] | 0) | 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                c[e >> 2] = 0;
	                k = c[e >> 2] | 0;
	                i = d;
	                return k | 0
	            }

	            function ad(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (c[f >> 2] | 0) {
	                    if (((c[(c[f >> 2] | 0) + 44 >> 2] | 0) != 0 ? (c[(c[(c[f >> 2] | 0) + 44 >> 2] | 0) + 48 >> 2] | 0) != 0 : 0) ? (c[j >> 2] = c[(c[(c[f >> 2] | 0) + 44 >> 2] | 0) + 48 >> 2], c[h >> 2] = jd(c[j >> 2] | 0, c[g >> 2] | 0) | 0, (c[h >> 2] | 0) != 0) : 0) {
	                        c[e >> 2] = c[h >> 2];
	                        k = c[e >> 2] | 0;
	                        i = d;
	                        return k | 0
	                    }
	                    if ((((c[(c[f >> 2] | 0) + 40 >> 2] | 0) != 1 ? (c[(c[f >> 2] | 0) + 48 >> 2] | 0) != 0 : 0) ? (c[(c[(c[f >> 2] | 0) + 48 >> 2] | 0) + 48 >> 2] | 0) != 0 : 0) ? (c[j >> 2] = c[(c[(c[f >> 2] | 0) + 48 >> 2] | 0) + 48 >> 2], c[h >> 2] = jd(c[j >> 2] | 0, c[g >> 2] | 0) | 0, (c[h >> 2] | 0) != 0) : 0) {
	                        c[e >> 2] = c[h >> 2];
	                        k = c[e >> 2] | 0;
	                        i = d;
	                        return k | 0
	                    }
	                }
	                c[e >> 2] = Yc(c[g >> 2] | 0) | 0;
	                k = c[e >> 2] | 0;
	                i = d;
	                return k | 0
	            }

	            function bd(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                b = kd(c[e >> 2] | 0, c[f >> 2] | 0, 1) | 0;
	                i = d;
	                return b | 0
	            }

	            function cd(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                b = kd(c[e >> 2] | 0, c[f >> 2] | 0, 0) | 0;
	                i = d;
	                return b | 0
	            }

	            function dd(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                Kj(c[d >> 2] | 0, 211);
	                i = b;
	                return
	            }

	            function ed(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = _j(c[d >> 2] | 0, 212) | 0;
	                i = b;
	                return a | 0
	            }

	            function fd(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if ((c[e >> 2] | 0) == 0 | (c[f >> 2] | 0) == 0) {
	                    i = d;
	                    return
	                }
	                switch (c[(c[f >> 2] | 0) + 48 >> 2] | 0) {
	                    case 2:
	                    {
	                        rj(c[e >> 2] | 0, 61616);
	                        qj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0);
	                        b = c[e >> 2] | 0;
	                        if (c[(c[f >> 2] | 0) + 52 >> 2] | 0) {
	                            rj(b, 61648);
	                            sj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 52 >> 2] | 0);
	                            rj(c[e >> 2] | 0, 61632);
	                            sj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 56 >> 2] | 0)
	                        } else {
	                            rj(b, 61664);
	                            sj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 56 >> 2] | 0)
	                        }
	                        rj(c[e >> 2] | 0, 61640);
	                        i = d;
	                        return
	                    }
	                    case 1:
	                    {
	                        rj(c[e >> 2] | 0, 61616);
	                        qj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0);
	                        rj(c[e >> 2] | 0, 61632);
	                        b = c[e >> 2] | 0;
	                        a = c[f >> 2] | 0;
	                        if (c[(c[f >> 2] | 0) + 36 >> 2] | 0)sj(b, c[a + 36 >> 2] | 0); else od(b, c[a + 40 >> 2] | 0);
	                        rj(c[e >> 2] | 0, 61640);
	                        i = d;
	                        return
	                    }
	                    case 5:
	                    {
	                        rj(c[e >> 2] | 0, 61688);
	                        qj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0);
	                        a = c[e >> 2] | 0;
	                        if (c[(c[f >> 2] | 0) + 52 >> 2] | 0) {
	                            rj(a, 61648);
	                            sj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 52 >> 2] | 0);
	                            rj(c[e >> 2] | 0, 61632);
	                            sj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 56 >> 2] | 0)
	                        } else {
	                            rj(a, 61664);
	                            sj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 56 >> 2] | 0)
	                        }
	                        rj(c[e >> 2] | 0, 61640);
	                        i = d;
	                        return
	                    }
	                    case 3:
	                    {
	                        rj(c[e >> 2] | 0, 61616);
	                        qj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0);
	                        a = c[e >> 2] | 0;
	                        if (c[(c[f >> 2] | 0) + 52 >> 2] | 0) {
	                            rj(a, 61648);
	                            sj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 52 >> 2] | 0);
	                            rj(c[e >> 2] | 0, 61632);
	                            sj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 56 >> 2] | 0)
	                        } else {
	                            rj(a, 61664);
	                            sj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 56 >> 2] | 0)
	                        }
	                        do if (c[(c[f >> 2] | 0) + 40 >> 2] | 0) {
	                            rj(c[e >> 2] | 0, 61680);
	                            a = c[e >> 2] | 0;
	                            b = c[f >> 2] | 0;
	                            if (c[(c[f >> 2] | 0) + 36 >> 2] | 0) {
	                                qj(a, c[b + 36 >> 2] | 0);
	                                break
	                            } else {
	                                qj(a, c[b + 40 >> 2] | 0);
	                                break
	                            }
	                        } while (0);
	                        rj(c[e >> 2] | 0, 61640);
	                        i = d;
	                        return
	                    }
	                    case 4:
	                    {
	                        rj(c[e >> 2] | 0, 61688);
	                        qj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0);
	                        rj(c[e >> 2] | 0, 61632);
	                        b = c[e >> 2] | 0;
	                        a = c[f >> 2] | 0;
	                        if (!(c[(c[f >> 2] | 0) + 36 >> 2] | 0))od(b, c[a + 40 >> 2] | 0); else sj(b, c[a + 36 >> 2] | 0);
	                        rj(c[e >> 2] | 0, 61640);
	                        i = d;
	                        return
	                    }
	                    default:
	                    {
	                        gd(535, 61704);
	                        i = d;
	                        return
	                    }
	                }
	            }

	            function gd(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                ce(2, c[e >> 2] | 0, 0, c[f >> 2] | 0, 0);
	                i = d;
	                return
	            }

	            function hd(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h + 36 | 0;
	                k = h + 32 | 0;
	                l = h + 28 | 0;
	                m = h + 24 | 0;
	                n = h + 20 | 0;
	                o = h + 16 | 0;
	                p = h + 12 | 0;
	                q = h + 8 | 0;
	                r = h + 4 | 0;
	                s = h;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                c[q >> 2] = 0;
	                c[r >> 2] = 0;
	                if (!(c[l >> 2] | 0)) {
	                    c[j >> 2] = 0;
	                    t = c[j >> 2] | 0;
	                    i = h;
	                    return t | 0
	                }
	                if (!(c[k >> 2] | 0)) {
	                    c[j >> 2] = 0;
	                    t = c[j >> 2] | 0;
	                    i = h;
	                    return t | 0
	                }
	                if (c[(c[k >> 2] | 0) + 32 >> 2] | 0)c[q >> 2] = c[(c[(c[k >> 2] | 0) + 32 >> 2] | 0) + 80 >> 2];
	                switch (c[m >> 2] | 0) {
	                    case 6:
	                    {
	                        c[j >> 2] = 0;
	                        t = c[j >> 2] | 0;
	                        i = h;
	                        return t | 0
	                    }
	                    case 3:
	                    case 2:
	                    case 1:
	                    {
	                        if (!(c[(c[k >> 2] | 0) + 48 >> 2] | 0)) {
	                            g = Jj(0, c[q >> 2] | 0) | 0;
	                            c[(c[k >> 2] | 0) + 48 >> 2] = g
	                        }
	                        c[r >> 2] = c[(c[k >> 2] | 0) + 48 >> 2];
	                        break
	                    }
	                    case 5:
	                    case 4:
	                    {
	                        if (!(c[(c[k >> 2] | 0) + 60 >> 2] | 0)) {
	                            g = Jj(0, c[q >> 2] | 0) | 0;
	                            c[(c[k >> 2] | 0) + 60 >> 2] = g
	                        }
	                        c[r >> 2] = c[(c[k >> 2] | 0) + 60 >> 2];
	                        break
	                    }
	                    default:
	                    {
	                    }
	                }
	                if (!(c[r >> 2] | 0)) {
	                    c[j >> 2] = 0;
	                    t = c[j >> 2] | 0;
	                    i = h;
	                    return t | 0
	                }
	                c[s >> 2] = id(c[q >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0) | 0;
	                if (!(c[s >> 2] | 0)) {
	                    c[j >> 2] = 0;
	                    t = c[j >> 2] | 0;
	                    i = h;
	                    return t | 0
	                }
	                c[(c[s >> 2] | 0) + 32 >> 2] = c[(c[k >> 2] | 0) + 32 >> 2];
	                k = (Lj(c[r >> 2] | 0, c[l >> 2] | 0, c[s >> 2] | 0) | 0) != 0;
	                l = c[s >> 2] | 0;
	                if (k) {
	                    pd(l);
	                    c[j >> 2] = 0;
	                    t = c[j >> 2] | 0;
	                    i = h;
	                    return t | 0
	                } else {
	                    c[j >> 2] = l;
	                    t = c[j >> 2] | 0;
	                    i = h;
	                    return t | 0
	                }
	                return 0
	            }

	            function id(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                h = i;
	                i = i + 32 | 0;
	                j = h + 28 | 0;
	                k = h + 24 | 0;
	                l = h + 20 | 0;
	                m = h + 16 | 0;
	                n = h + 12 | 0;
	                o = h + 8 | 0;
	                p = h + 4 | 0;
	                q = h;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                c[q >> 2] = Cb[c[135744 >> 2] & 511](76) | 0;
	                if (!(c[q >> 2] | 0)) {
	                    ld(62016);
	                    c[j >> 2] = 0;
	                    r = c[j >> 2] | 0;
	                    i = h;
	                    return r | 0
	                }
	                g = (c[q >> 2] | 0) + 0 | 0;
	                f = g + 76 | 0;
	                do {
	                    c[g >> 2] = 0;
	                    g = g + 4 | 0
	                } while ((g | 0) < (f | 0));
	                c[(c[q >> 2] | 0) + 4 >> 2] = 17;
	                c[(c[q >> 2] | 0) + 72 >> 2] = 0;
	                c[(c[q >> 2] | 0) + 48 >> 2] = c[m >> 2];
	                if (!(c[k >> 2] | 0)) {
	                    m = my(c[l >> 2] | 0) | 0;
	                    c[(c[q >> 2] | 0) + 8 >> 2] = m;
	                    if (c[n >> 2] | 0) {
	                        m = my(c[n >> 2] | 0) | 0;
	                        c[(c[q >> 2] | 0) + 52 >> 2] = m
	                    }
	                    if (c[o >> 2] | 0) {
	                        m = my(c[o >> 2] | 0) | 0;
	                        c[(c[q >> 2] | 0) + 56 >> 2] = m
	                    }
	                } else {
	                    m = AP(c[k >> 2] | 0, c[l >> 2] | 0, -1) | 0;
	                    c[(c[q >> 2] | 0) + 8 >> 2] = m;
	                    if (c[n >> 2] | 0) {
	                        m = AP(c[k >> 2] | 0, c[n >> 2] | 0, -1) | 0;
	                        c[(c[q >> 2] | 0) + 52 >> 2] = m
	                    }
	                    if (c[o >> 2] | 0) {
	                        m = AP(c[k >> 2] | 0, c[o >> 2] | 0, -1) | 0;
	                        c[(c[q >> 2] | 0) + 56 >> 2] = m
	                    }
	                }
	                do if (c[p >> 2] | 0) {
	                    m = xy(c[p >> 2] | 0) | 0;
	                    c[(c[q >> 2] | 0) + 44 >> 2] = m;
	                    if ((c[k >> 2] | 0) != 0 ? (c[(c[q >> 2] | 0) + 44 >> 2] | 0) < 5 : 0) {
	                        m = AP(c[k >> 2] | 0, c[p >> 2] | 0, c[(c[q >> 2] | 0) + 44 >> 2] | 0) | 0;
	                        c[(c[q >> 2] | 0) + 40 >> 2] = m;
	                        break
	                    }
	                    m = ly(c[p >> 2] | 0, c[(c[q >> 2] | 0) + 44 >> 2] | 0) | 0;
	                    c[(c[q >> 2] | 0) + 40 >> 2] = m
	                } else {
	                    c[(c[q >> 2] | 0) + 44 >> 2] = 0;
	                    c[(c[q >> 2] | 0) + 40 >> 2] = 0
	                } while (0);
	                c[(c[q >> 2] | 0) + 64 >> 2] = 0;
	                c[(c[q >> 2] | 0) + 36 >> 2] = 0;
	                c[(c[q >> 2] | 0) + 68 >> 2] = 0;
	                c[j >> 2] = c[q >> 2];
	                r = c[j >> 2] | 0;
	                i = h;
	                return r | 0
	            }

	            function jd(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                b = Rj(c[e >> 2] | 0, c[f >> 2] | 0) | 0;
	                i = d;
	                return b | 0
	            }

	            function kd(b, e, f) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0;
	                g = i;
	                i = i + 112 | 0;
	                h = g;
	                j = g + 84 | 0;
	                k = g + 80 | 0;
	                l = g + 76 | 0;
	                m = g + 72 | 0;
	                n = g + 68 | 0;
	                o = g + 64 | 0;
	                p = g + 60 | 0;
	                q = g + 56 | 0;
	                r = g + 52 | 0;
	                s = g + 48 | 0;
	                t = g + 44 | 0;
	                u = g + 40 | 0;
	                v = g + 36 | 0;
	                w = g + 32 | 0;
	                x = g + 28 | 0;
	                y = g + 24 | 0;
	                z = g + 20 | 0;
	                A = g + 99 | 0;
	                B = g + 16 | 0;
	                C = g + 12 | 0;
	                D = g + 8 | 0;
	                E = g + 88 | 0;
	                F = g + 4 | 0;
	                c[k >> 2] = b;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                c[n >> 2] = c[l >> 2];
	                c[o >> 2] = 0;
	                c[p >> 2] = 0;
	                c[q >> 2] = 0;
	                c[r >> 2] = 0;
	                if (!(c[l >> 2] | 0)) {
	                    c[j >> 2] = 0;
	                    G = c[j >> 2] | 0;
	                    i = g;
	                    return G | 0
	                }
	                if (c[k >> 2] | 0)c[r >> 2] = (c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 13 & 1;
	                c[q >> 2] = 1e3;
	                c[o >> 2] = Cb[c[135744 >> 2] & 511](c[q >> 2] | 0) | 0;
	                if (!(c[o >> 2] | 0)) {
	                    ld(61816);
	                    c[j >> 2] = 0;
	                    G = c[j >> 2] | 0;
	                    i = g;
	                    return G | 0
	                }
	                c[p >> 2] = c[o >> 2];
	                a:while (1) {
	                    H = c[p >> 2] | 0;
	                    if (!(d[c[n >> 2] >> 0] | 0)) {
	                        I = 87;
	                        break
	                    }
	                    c[s >> 2] = H - (c[o >> 2] | 0);
	                    if (((c[s >> 2] | 0) + 100 | 0) >>> 0 > (c[q >> 2] | 0) >>> 0) {
	                        c[u >> 2] = c[q >> 2] << 1;
	                        if ((c[u >> 2] | 0) >>> 0 < (c[q >> 2] | 0) >>> 0) {
	                            I = 88;
	                            break
	                        }
	                        c[t >> 2] = Hb[c[135760 >> 2] & 511](c[o >> 2] | 0, c[u >> 2] | 0) | 0;
	                        if (!(c[t >> 2] | 0)) {
	                            I = 88;
	                            break
	                        }
	                        c[o >> 2] = c[t >> 2];
	                        c[q >> 2] = c[u >> 2];
	                        c[p >> 2] = (c[o >> 2] | 0) + (c[s >> 2] | 0)
	                    }
	                    b:do if ((d[c[n >> 2] >> 0] | 0) == 60) {
	                        if (((((c[r >> 2] | 0) != 0 & (c[m >> 2] | 0) != 0 ? (d[(c[n >> 2] | 0) + 1 >> 0] | 0) == 33 : 0) ? (d[(c[n >> 2] | 0) + 2 >> 0] | 0) == 45 : 0) ? (d[(c[n >> 2] | 0) + 3 >> 0] | 0) == 45 : 0) ? (l = wy(c[n >> 2] | 0, 61856) | 0, c[v >> 2] = l, (l | 0) != 0) : 0) {
	                            while (1) {
	                                l = (c[n >> 2] | 0) != (c[v >> 2] | 0);
	                                f = c[n >> 2] | 0;
	                                c[n >> 2] = f + 1;
	                                e = a[f >> 0] | 0;
	                                f = c[p >> 2] | 0;
	                                c[p >> 2] = f + 1;
	                                a[f >> 0] = e;
	                                if (!l)break;
	                                c[s >> 2] = (c[p >> 2] | 0) - (c[o >> 2] | 0);
	                                if (((c[s >> 2] | 0) + 100 | 0) >>> 0 <= (c[q >> 2] | 0) >>> 0)continue;
	                                c[x >> 2] = c[q >> 2] << 1;
	                                if ((c[x >> 2] | 0) >>> 0 < (c[q >> 2] | 0) >>> 0) {
	                                    I = 88;
	                                    break a
	                                }
	                                c[w >> 2] = Hb[c[135760 >> 2] & 511](c[o >> 2] | 0, c[x >> 2] | 0) | 0;
	                                if (!(c[w >> 2] | 0)) {
	                                    I = 88;
	                                    break a
	                                }
	                                c[o >> 2] = c[w >> 2];
	                                c[q >> 2] = c[x >> 2];
	                                c[p >> 2] = (c[o >> 2] | 0) + (c[s >> 2] | 0)
	                            }
	                            l = c[n >> 2] | 0;
	                            c[n >> 2] = l + 1;
	                            e = a[l >> 0] | 0;
	                            l = c[p >> 2] | 0;
	                            c[p >> 2] = l + 1;
	                            a[l >> 0] = e;
	                            e = c[n >> 2] | 0;
	                            c[n >> 2] = e + 1;
	                            l = a[e >> 0] | 0;
	                            e = c[p >> 2] | 0;
	                            c[p >> 2] = e + 1;
	                            a[e >> 0] = l;
	                            continue a
	                        }
	                        l = c[p >> 2] | 0;
	                        c[p >> 2] = l + 1;
	                        a[l >> 0] = 38;
	                        l = c[p >> 2] | 0;
	                        c[p >> 2] = l + 1;
	                        a[l >> 0] = 108;
	                        l = c[p >> 2] | 0;
	                        c[p >> 2] = l + 1;
	                        a[l >> 0] = 116;
	                        l = c[p >> 2] | 0;
	                        c[p >> 2] = l + 1;
	                        a[l >> 0] = 59
	                    } else {
	                        if ((d[c[n >> 2] >> 0] | 0) == 62) {
	                            l = c[p >> 2] | 0;
	                            c[p >> 2] = l + 1;
	                            a[l >> 0] = 38;
	                            l = c[p >> 2] | 0;
	                            c[p >> 2] = l + 1;
	                            a[l >> 0] = 103;
	                            l = c[p >> 2] | 0;
	                            c[p >> 2] = l + 1;
	                            a[l >> 0] = 116;
	                            l = c[p >> 2] | 0;
	                            c[p >> 2] = l + 1;
	                            a[l >> 0] = 59;
	                            break
	                        }
	                        if ((d[c[n >> 2] >> 0] | 0) == 38) {
	                            if (((c[r >> 2] | 0) != 0 & (c[m >> 2] | 0) != 0 ? (d[(c[n >> 2] | 0) + 1 >> 0] | 0) == 123 : 0) ? (eT(c[n >> 2] | 0, 125) | 0) != 0 : 0)while (1) {
	                                l = (d[c[n >> 2] >> 0] | 0) != 125;
	                                e = c[n >> 2] | 0;
	                                c[n >> 2] = e + 1;
	                                f = a[e >> 0] | 0;
	                                e = c[p >> 2] | 0;
	                                c[p >> 2] = e + 1;
	                                a[e >> 0] = f;
	                                if (!l)continue a;
	                                c[s >> 2] = (c[p >> 2] | 0) - (c[o >> 2] | 0);
	                                if (((c[s >> 2] | 0) + 100 | 0) >>> 0 <= (c[q >> 2] | 0) >>> 0)continue;
	                                c[z >> 2] = c[q >> 2] << 1;
	                                if ((c[z >> 2] | 0) >>> 0 < (c[q >> 2] | 0) >>> 0) {
	                                    I = 88;
	                                    break a
	                                }
	                                c[y >> 2] = Hb[c[135760 >> 2] & 511](c[o >> 2] | 0, c[z >> 2] | 0) | 0;
	                                if (!(c[y >> 2] | 0)) {
	                                    I = 88;
	                                    break a
	                                }
	                                c[o >> 2] = c[y >> 2];
	                                c[q >> 2] = c[z >> 2];
	                                c[p >> 2] = (c[o >> 2] | 0) + (c[s >> 2] | 0)
	                            }
	                            l = c[p >> 2] | 0;
	                            c[p >> 2] = l + 1;
	                            a[l >> 0] = 38;
	                            l = c[p >> 2] | 0;
	                            c[p >> 2] = l + 1;
	                            a[l >> 0] = 97;
	                            l = c[p >> 2] | 0;
	                            c[p >> 2] = l + 1;
	                            a[l >> 0] = 109;
	                            l = c[p >> 2] | 0;
	                            c[p >> 2] = l + 1;
	                            a[l >> 0] = 112;
	                            l = c[p >> 2] | 0;
	                            c[p >> 2] = l + 1;
	                            a[l >> 0] = 59;
	                            break
	                        }
	                        if (!((d[c[n >> 2] >> 0] | 0) >= 32 ? (d[c[n >> 2] >> 0] | 0) < 128 : 0))I = 40;
	                        do if (((I | 0) == 40 ? (I = 0, (d[c[n >> 2] >> 0] | 0) != 10) : 0) ? (d[c[n >> 2] >> 0] | 0) != 9 : 0) {
	                            if ((c[r >> 2] | 0) != 0 ? (d[c[n >> 2] >> 0] | 0) == 13 : 0)break;
	                            if ((d[c[n >> 2] >> 0] | 0) < 128) {
	                                if (!(9 <= (d[c[n >> 2] >> 0] | 0) ? (d[c[n >> 2] >> 0] | 0) <= 10 : 0))I = 81;
	                                if (((I | 0) == 81 ? (I = 0, (d[c[n >> 2] >> 0] | 0) != 13) : 0) ? 32 > (d[c[n >> 2] >> 0] | 0) : 0)break b;
	                                c[h >> 2] = d[c[n >> 2] >> 0];
	                                JT(E, 11, 61920, h) | 0;
	                                a[E + 10 >> 0] = 0;
	                                c[F >> 2] = E;
	                                while (1) {
	                                    if (!(a[c[F >> 2] >> 0] | 0))break b;
	                                    l = c[F >> 2] | 0;
	                                    c[F >> 2] = l + 1;
	                                    f = a[l >> 0] | 0;
	                                    l = c[p >> 2] | 0;
	                                    c[p >> 2] = l + 1;
	                                    a[l >> 0] = f
	                                }
	                            }
	                            if (c[k >> 2] | 0) {
	                                if ((c[r >> 2] | 0) != 0 ? 1 : (c[(c[k >> 2] | 0) + 60 >> 2] | 0) != 0)I = 49
	                            } else if (c[r >> 2] | 0)I = 49;
	                            if ((I | 0) == 49) {
	                                I = 0;
	                                f = a[c[n >> 2] >> 0] | 0;
	                                l = c[p >> 2] | 0;
	                                c[p >> 2] = l + 1;
	                                a[l >> 0] = f;
	                                break b
	                            }
	                            c[C >> 2] = 0;
	                            c[D >> 2] = 1;
	                            if ((d[c[n >> 2] >> 0] | 0) < 192) {
	                                gd(5032, 61864);
	                                if (c[k >> 2] | 0) {
	                                    f = my(61904) | 0;
	                                    c[(c[k >> 2] | 0) + 60 >> 2] = f
	                                }
	                                c[h >> 2] = d[c[n >> 2] >> 0];
	                                JT(A, 11, 61920, h) | 0;
	                                a[A + 10 >> 0] = 0;
	                                c[B >> 2] = A;
	                                while (1) {
	                                    if (!(a[c[B >> 2] >> 0] | 0))break;
	                                    f = c[B >> 2] | 0;
	                                    c[B >> 2] = f + 1;
	                                    l = a[f >> 0] | 0;
	                                    f = c[p >> 2] | 0;
	                                    c[p >> 2] = f + 1;
	                                    a[f >> 0] = l
	                                }
	                                c[n >> 2] = (c[n >> 2] | 0) + 1;
	                                continue a
	                            }
	                            l = c[n >> 2] | 0;
	                            do if ((d[c[n >> 2] >> 0] | 0) < 224) {
	                                c[C >> 2] = d[l >> 0] & 31;
	                                c[C >> 2] = c[C >> 2] << 6;
	                                c[C >> 2] = c[C >> 2] | d[(c[n >> 2] | 0) + 1 >> 0] & 63;
	                                c[D >> 2] = 2
	                            } else {
	                                f = c[n >> 2] | 0;
	                                if ((d[l >> 0] | 0) < 240) {
	                                    c[C >> 2] = d[f >> 0] & 15;
	                                    c[C >> 2] = c[C >> 2] << 6;
	                                    c[C >> 2] = c[C >> 2] | d[(c[n >> 2] | 0) + 1 >> 0] & 63;
	                                    c[C >> 2] = c[C >> 2] << 6;
	                                    c[C >> 2] = c[C >> 2] | d[(c[n >> 2] | 0) + 2 >> 0] & 63;
	                                    c[D >> 2] = 3;
	                                    break
	                                }
	                                if ((d[f >> 0] | 0) >= 248)break;
	                                c[C >> 2] = d[c[n >> 2] >> 0] & 7;
	                                c[C >> 2] = c[C >> 2] << 6;
	                                c[C >> 2] = c[C >> 2] | d[(c[n >> 2] | 0) + 1 >> 0] & 63;
	                                c[C >> 2] = c[C >> 2] << 6;
	                                c[C >> 2] = c[C >> 2] | d[(c[n >> 2] | 0) + 2 >> 0] & 63;
	                                c[C >> 2] = c[C >> 2] << 6;
	                                c[C >> 2] = c[C >> 2] | d[(c[n >> 2] | 0) + 3 >> 0] & 63;
	                                c[D >> 2] = 4
	                            } while (0);
	                            c:do if ((c[D >> 2] | 0) != 1) {
	                                l = c[C >> 2] | 0;
	                                do if ((c[C >> 2] | 0) < 256) {
	                                    if (!(9 <= (l | 0) & (c[C >> 2] | 0) <= 10 | (c[C >> 2] | 0) == 13 | 32 <= (c[C >> 2] | 0)))break c
	                                } else {
	                                    if (256 <= (l | 0) & (c[C >> 2] | 0) <= 55295)break;
	                                    if (57344 <= (c[C >> 2] | 0) & (c[C >> 2] | 0) <= 65533)break;
	                                    if (!(65536 <= (c[C >> 2] | 0) & (c[C >> 2] | 0) <= 1114111))break c
	                                } while (0);
	                                c[h >> 2] = c[C >> 2];
	                                JT(A, 11, 61968, h) | 0;
	                                a[A + 10 >> 0] = 0;
	                                c[B >> 2] = A;
	                                while (1) {
	                                    if (!(a[c[B >> 2] >> 0] | 0))break;
	                                    l = c[B >> 2] | 0;
	                                    c[B >> 2] = l + 1;
	                                    f = a[l >> 0] | 0;
	                                    l = c[p >> 2] | 0;
	                                    c[p >> 2] = l + 1;
	                                    a[l >> 0] = f
	                                }
	                                c[n >> 2] = (c[n >> 2] | 0) + (c[D >> 2] | 0);
	                                continue a
	                            } while (0);
	                            gd(9, 61928);
	                            if (c[k >> 2] | 0) {
	                                f = my(61904) | 0;
	                                c[(c[k >> 2] | 0) + 60 >> 2] = f
	                            }
	                            c[h >> 2] = d[c[n >> 2] >> 0];
	                            JT(A, 11, 61920, h) | 0;
	                            a[A + 10 >> 0] = 0;
	                            c[B >> 2] = A;
	                            while (1) {
	                                if (!(a[c[B >> 2] >> 0] | 0))break;
	                                f = c[B >> 2] | 0;
	                                c[B >> 2] = f + 1;
	                                l = a[f >> 0] | 0;
	                                f = c[p >> 2] | 0;
	                                c[p >> 2] = f + 1;
	                                a[f >> 0] = l
	                            }
	                            c[n >> 2] = (c[n >> 2] | 0) + 1;
	                            continue a
	                        } while (0);
	                        l = a[c[n >> 2] >> 0] | 0;
	                        f = c[p >> 2] | 0;
	                        c[p >> 2] = f + 1;
	                        a[f >> 0] = l
	                    } while (0);
	                    c[n >> 2] = (c[n >> 2] | 0) + 1
	                }
	                if ((I | 0) == 87) {
	                    a[H >> 0] = 0;
	                    c[j >> 2] = c[o >> 2];
	                    G = c[j >> 2] | 0;
	                    i = g;
	                    return G | 0
	                } else if ((I | 0) == 88) {
	                    ld(61976);
	                    zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                    c[j >> 2] = 0;
	                    G = c[j >> 2] | 0;
	                    i = g;
	                    return G | 0
	                }
	                return 0
	            }

	            function ld(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                ce(2, 2, 0, 0, c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function md(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                c[e >> 2] = a;
	                c[d >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                pd(c[e >> 2] | 0);
	                i = d;
	                return
	            }

	            function nd(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](76) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    ld(61784);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = (c[f >> 2] | 0) + 0 | 0;
	                h = a + 76 | 0;
	                do {
	                    c[a >> 2] = 0;
	                    a = a + 4 | 0
	                } while ((a | 0) < (h | 0));
	                c[(c[f >> 2] | 0) + 4 >> 2] = 17;
	                c[(c[f >> 2] | 0) + 48 >> 2] = c[(c[e >> 2] | 0) + 48 >> 2];
	                if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                    a = my(c[(c[e >> 2] | 0) + 8 >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 8 >> 2] = a
	                }
	                if (c[(c[e >> 2] | 0) + 52 >> 2] | 0) {
	                    a = my(c[(c[e >> 2] | 0) + 52 >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 52 >> 2] = a
	                }
	                if (c[(c[e >> 2] | 0) + 56 >> 2] | 0) {
	                    a = my(c[(c[e >> 2] | 0) + 56 >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 56 >> 2] = a
	                }
	                if (c[(c[e >> 2] | 0) + 40 >> 2] | 0) {
	                    a = my(c[(c[e >> 2] | 0) + 40 >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 40 >> 2] = a
	                }
	                if (c[(c[e >> 2] | 0) + 36 >> 2] | 0) {
	                    a = my(c[(c[e >> 2] | 0) + 36 >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 36 >> 2] = a
	                }
	                if (c[(c[e >> 2] | 0) + 64 >> 2] | 0) {
	                    a = my(c[(c[e >> 2] | 0) + 64 >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 64 >> 2] = a
	                }
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function od(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[(c[f >> 2] | 0) + 12 >> 2] | 0) == 2) {
	                    i = e;
	                    return
	                }
	                b = (vy(c[g >> 2] | 0, 37) | 0) != 0;
	                a = c[f >> 2] | 0;
	                if (!b) {
	                    sj(a, c[g >> 2] | 0);
	                    i = e;
	                    return
	                }
	                pj(a, 61760) | 0;
	                a = c[g >> 2] | 0;
	                c[j >> 2] = a;
	                c[h >> 2] = a;
	                while (1) {
	                    if (!(d[c[j >> 2] >> 0] | 0))break;
	                    if ((d[c[j >> 2] >> 0] | 0 | 0) == 34) {
	                        if ((c[h >> 2] | 0) != (c[j >> 2] | 0))nj(c[f >> 2] | 0, c[h >> 2] | 0, (c[j >> 2] | 0) - (c[h >> 2] | 0) | 0) | 0;
	                        nj(c[f >> 2] | 0, 61768, 6) | 0;
	                        c[j >> 2] = (c[j >> 2] | 0) + 1;
	                        c[h >> 2] = c[j >> 2];
	                        continue
	                    }
	                    if ((d[c[j >> 2] >> 0] | 0 | 0) != 37) {
	                        c[j >> 2] = (c[j >> 2] | 0) + 1;
	                        continue
	                    }
	                    if ((c[h >> 2] | 0) != (c[j >> 2] | 0))nj(c[f >> 2] | 0, c[h >> 2] | 0, (c[j >> 2] | 0) - (c[h >> 2] | 0) | 0) | 0;
	                    nj(c[f >> 2] | 0, 61776, 6) | 0;
	                    c[j >> 2] = (c[j >> 2] | 0) + 1;
	                    c[h >> 2] = c[j >> 2]
	                }
	                if ((c[h >> 2] | 0) != (c[j >> 2] | 0))nj(c[f >> 2] | 0, c[h >> 2] | 0, (c[j >> 2] | 0) - (c[h >> 2] | 0) | 0) | 0;
	                pj(c[f >> 2] | 0, 61760) | 0;
	                i = e;
	                return
	            }

	            function pd(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                c[e >> 2] = 0;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 32 >> 2] | 0)c[e >> 2] = c[(c[(c[d >> 2] | 0) + 32 >> 2] | 0) + 80 >> 2];
	                if (((c[(c[d >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[(c[d >> 2] | 0) + 68 >> 2] | 0) == 1 : 0) ? (c[d >> 2] | 0) == (c[(c[(c[d >> 2] | 0) + 12 >> 2] | 0) + 20 >> 2] | 0) : 0)Uh(c[(c[d >> 2] | 0) + 12 >> 2] | 0);
	                a = (c[(c[d >> 2] | 0) + 8 >> 2] | 0) != 0;
	                if (c[e >> 2] | 0) {
	                    if (a ? (CP(c[e >> 2] | 0, c[(c[d >> 2] | 0) + 8 >> 2] | 0) | 0) == 0 : 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                    if ((c[(c[d >> 2] | 0) + 52 >> 2] | 0) != 0 ? (CP(c[e >> 2] | 0, c[(c[d >> 2] | 0) + 52 >> 2] | 0) | 0) == 0 : 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 52 >> 2] | 0);
	                    if ((c[(c[d >> 2] | 0) + 56 >> 2] | 0) != 0 ? (CP(c[e >> 2] | 0, c[(c[d >> 2] | 0) + 56 >> 2] | 0) | 0) == 0 : 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 56 >> 2] | 0);
	                    if ((c[(c[d >> 2] | 0) + 64 >> 2] | 0) != 0 ? (CP(c[e >> 2] | 0, c[(c[d >> 2] | 0) + 64 >> 2] | 0) | 0) == 0 : 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 64 >> 2] | 0);
	                    if ((c[(c[d >> 2] | 0) + 40 >> 2] | 0) != 0 ? (CP(c[e >> 2] | 0, c[(c[d >> 2] | 0) + 40 >> 2] | 0) | 0) == 0 : 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 40 >> 2] | 0);
	                    if ((c[(c[d >> 2] | 0) + 36 >> 2] | 0) != 0 ? (CP(c[e >> 2] | 0, c[(c[d >> 2] | 0) + 36 >> 2] | 0) | 0) == 0 : 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 36 >> 2] | 0)
	                } else {
	                    if (a)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                    if (c[(c[d >> 2] | 0) + 52 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 52 >> 2] | 0);
	                    if (c[(c[d >> 2] | 0) + 56 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 56 >> 2] | 0);
	                    if (c[(c[d >> 2] | 0) + 64 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 64 >> 2] | 0);
	                    if (c[(c[d >> 2] | 0) + 40 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 40 >> 2] | 0);
	                    if (c[(c[d >> 2] | 0) + 36 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 36 >> 2] | 0)
	                }
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function qd(b, e, f, g) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h + 36 | 0;
	                k = h + 32 | 0;
	                l = h + 28 | 0;
	                m = h + 24 | 0;
	                n = h + 20 | 0;
	                o = h + 16 | 0;
	                p = h + 12 | 0;
	                q = h + 8 | 0;
	                r = h + 4 | 0;
	                s = h;
	                c[k >> 2] = b;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                c[n >> 2] = g;
	                c[o >> 2] = c[k >> 2];
	                c[p >> 2] = c[m >> 2];
	                if ((c[k >> 2] | 0) == 0 | (c[m >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0 | (c[n >> 2] | 0) == 0) {
	                    c[j >> 2] = -1;
	                    t = c[j >> 2] | 0;
	                    i = h;
	                    return t | 0
	                }
	                c[q >> 2] = (c[k >> 2] | 0) + (c[c[l >> 2] >> 2] | 0);
	                c[r >> 2] = (c[m >> 2] | 0) + (c[c[n >> 2] >> 2] | 0);
	                c[s >> 2] = c[r >> 2];
	                a:while (1) {
	                    if ((c[m >> 2] | 0) >>> 0 < (c[r >> 2] | 0) >>> 0)u = (c[k >> 2] | 0) >>> 0 < ((c[q >> 2] | 0) + -1 | 0) >>> 0; else u = 0;
	                    v = c[m >> 2] | 0;
	                    if (!u)break;
	                    if ((d[v >> 0] | 0 | 0) >= 128) {
	                        g = ((d[c[m >> 2] >> 0] | 0) >> 6 & 31 | 192) & 255;
	                        f = c[k >> 2] | 0;
	                        c[k >> 2] = f + 1;
	                        a[f >> 0] = g;
	                        g = ((d[c[m >> 2] >> 0] | 0) & 63 | 128) & 255;
	                        f = c[k >> 2] | 0;
	                        c[k >> 2] = f + 1;
	                        a[f >> 0] = g;
	                        c[m >> 2] = (c[m >> 2] | 0) + 1
	                    }
	                    if (((c[s >> 2] | 0) - (c[m >> 2] | 0) | 0) > ((c[q >> 2] | 0) - (c[k >> 2] | 0) | 0))c[s >> 2] = (c[m >> 2] | 0) + ((c[q >> 2] | 0) - (c[k >> 2] | 0));
	                    while (1) {
	                        if ((c[m >> 2] | 0) >>> 0 >= (c[s >> 2] | 0) >>> 0)continue a;
	                        if ((d[c[m >> 2] >> 0] | 0 | 0) >= 128)continue a;
	                        g = c[m >> 2] | 0;
	                        c[m >> 2] = g + 1;
	                        f = a[g >> 0] | 0;
	                        g = c[k >> 2] | 0;
	                        c[k >> 2] = g + 1;
	                        a[g >> 0] = f
	                    }
	                }
	                if ((v >>> 0 < (c[r >> 2] | 0) >>> 0 ? (c[k >> 2] | 0) >>> 0 < (c[q >> 2] | 0) >>> 0 : 0) ? (d[c[m >> 2] >> 0] | 0 | 0) < 128 : 0) {
	                    q = c[m >> 2] | 0;
	                    c[m >> 2] = q + 1;
	                    r = a[q >> 0] | 0;
	                    q = c[k >> 2] | 0;
	                    c[k >> 2] = q + 1;
	                    a[q >> 0] = r
	                }
	                c[c[l >> 2] >> 2] = (c[k >> 2] | 0) - (c[o >> 2] | 0);
	                c[c[n >> 2] >> 2] = (c[m >> 2] | 0) - (c[p >> 2] | 0);
	                c[j >> 2] = c[c[l >> 2] >> 2];
	                t = c[j >> 2] | 0;
	                i = h;
	                return t | 0
	            }

	            function rd(b, e, f, g) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0;
	                h = i;
	                i = i + 64 | 0;
	                j = h + 48 | 0;
	                k = h + 44 | 0;
	                l = h + 40 | 0;
	                m = h + 36 | 0;
	                n = h + 32 | 0;
	                o = h + 28 | 0;
	                p = h + 24 | 0;
	                q = h + 20 | 0;
	                r = h + 16 | 0;
	                s = h + 12 | 0;
	                t = h + 8 | 0;
	                u = h + 4 | 0;
	                v = h;
	                c[k >> 2] = b;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                c[n >> 2] = g;
	                c[o >> 2] = c[m >> 2];
	                c[q >> 2] = c[k >> 2];
	                c[r >> 2] = c[m >> 2];
	                if ((c[k >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0 | (c[n >> 2] | 0) == 0) {
	                    c[j >> 2] = -1;
	                    w = c[j >> 2] | 0;
	                    i = h;
	                    return w | 0
	                }
	                if (!(c[m >> 2] | 0)) {
	                    c[c[l >> 2] >> 2] = 0;
	                    c[c[n >> 2] >> 2] = 0;
	                    c[j >> 2] = 0;
	                    w = c[j >> 2] | 0;
	                    i = h;
	                    return w | 0
	                }
	                c[s >> 2] = (c[m >> 2] | 0) + (c[c[n >> 2] >> 2] | 0);
	                c[p >> 2] = (c[k >> 2] | 0) + (c[c[l >> 2] >> 2] | 0);
	                a:while (1) {
	                    if ((c[m >> 2] | 0) >>> 0 >= (c[s >> 2] | 0) >>> 0) {
	                        x = 28;
	                        break
	                    }
	                    g = c[m >> 2] | 0;
	                    c[m >> 2] = g + 1;
	                    c[u >> 2] = d[g >> 0];
	                    g = c[u >> 2] | 0;
	                    do if ((c[u >> 2] | 0) >>> 0 < 128) {
	                        c[t >> 2] = g;
	                        c[v >> 2] = 0
	                    } else {
	                        if (g >>> 0 < 192) {
	                            x = 10;
	                            break a
	                        }
	                        f = c[u >> 2] | 0;
	                        if ((c[u >> 2] | 0) >>> 0 < 224) {
	                            c[t >> 2] = f & 31;
	                            c[v >> 2] = 1;
	                            break
	                        }
	                        e = c[u >> 2] | 0;
	                        if (f >>> 0 < 240) {
	                            c[t >> 2] = e & 15;
	                            c[v >> 2] = 2;
	                            break
	                        }
	                        if (e >>> 0 >= 248) {
	                            x = 17;
	                            break a
	                        }
	                        c[t >> 2] = c[u >> 2] & 7;
	                        c[v >> 2] = 3
	                    } while (0);
	                    if (((c[s >> 2] | 0) - (c[m >> 2] | 0) | 0) < (c[v >> 2] | 0)) {
	                        x = 28;
	                        break
	                    }
	                    while (1) {
	                        if (!(c[v >> 2] | 0))break;
	                        if ((c[m >> 2] | 0) >>> 0 >= (c[s >> 2] | 0) >>> 0)break;
	                        g = c[m >> 2] | 0;
	                        c[m >> 2] = g + 1;
	                        e = d[g >> 0] | 0;
	                        c[u >> 2] = e;
	                        if ((e & 192 | 0) != 128) {
	                            x = 22;
	                            break a
	                        }
	                        c[t >> 2] = c[t >> 2] << 6;
	                        c[t >> 2] = c[t >> 2] | c[u >> 2] & 63;
	                        c[v >> 2] = (c[v >> 2] | 0) + -1
	                    }
	                    y = c[k >> 2] | 0;
	                    if ((c[t >> 2] | 0) >>> 0 > 255) {
	                        x = 27;
	                        break
	                    }
	                    if (y >>> 0 >= (c[p >> 2] | 0) >>> 0) {
	                        x = 28;
	                        break
	                    }
	                    e = c[t >> 2] & 255;
	                    g = c[k >> 2] | 0;
	                    c[k >> 2] = g + 1;
	                    a[g >> 0] = e;
	                    c[o >> 2] = c[m >> 2]
	                }
	                if ((x | 0) == 10) {
	                    c[c[l >> 2] >> 2] = (c[k >> 2] | 0) - (c[q >> 2] | 0);
	                    c[c[n >> 2] >> 2] = (c[o >> 2] | 0) - (c[r >> 2] | 0);
	                    c[j >> 2] = -2;
	                    w = c[j >> 2] | 0;
	                    i = h;
	                    return w | 0
	                } else if ((x | 0) == 17) {
	                    c[c[l >> 2] >> 2] = (c[k >> 2] | 0) - (c[q >> 2] | 0);
	                    c[c[n >> 2] >> 2] = (c[o >> 2] | 0) - (c[r >> 2] | 0);
	                    c[j >> 2] = -2;
	                    w = c[j >> 2] | 0;
	                    i = h;
	                    return w | 0
	                } else if ((x | 0) == 22) {
	                    c[c[l >> 2] >> 2] = (c[k >> 2] | 0) - (c[q >> 2] | 0);
	                    c[c[n >> 2] >> 2] = (c[o >> 2] | 0) - (c[r >> 2] | 0);
	                    c[j >> 2] = -2;
	                    w = c[j >> 2] | 0;
	                    i = h;
	                    return w | 0
	                } else if ((x | 0) == 27) {
	                    c[c[l >> 2] >> 2] = y - (c[q >> 2] | 0);
	                    c[c[n >> 2] >> 2] = (c[o >> 2] | 0) - (c[r >> 2] | 0);
	                    c[j >> 2] = -2;
	                    w = c[j >> 2] | 0;
	                    i = h;
	                    return w | 0
	                } else if ((x | 0) == 28) {
	                    c[c[l >> 2] >> 2] = (c[k >> 2] | 0) - (c[q >> 2] | 0);
	                    c[c[n >> 2] >> 2] = (c[o >> 2] | 0) - (c[r >> 2] | 0);
	                    c[j >> 2] = c[c[l >> 2] >> 2];
	                    w = c[j >> 2] | 0;
	                    i = h;
	                    return w | 0
	                }
	                return 0
	            }

	            function sd(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    j = c[f >> 2] | 0;
	                    i = e;
	                    return j | 0
	                }
	                if ((c[h >> 2] | 0) >= 4) {
	                    if ((((d[c[g >> 2] >> 0] | 0 | 0) == 0 ? (d[(c[g >> 2] | 0) + 1 >> 0] | 0 | 0) == 0 : 0) ? (d[(c[g >> 2] | 0) + 2 >> 0] | 0 | 0) == 0 : 0) ? (d[(c[g >> 2] | 0) + 3 >> 0] | 0 | 0) == 60 : 0) {
	                        c[f >> 2] = 5;
	                        j = c[f >> 2] | 0;
	                        i = e;
	                        return j | 0
	                    }
	                    if ((((d[c[g >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[g >> 2] | 0) + 1 >> 0] | 0 | 0) == 0 : 0) ? (d[(c[g >> 2] | 0) + 2 >> 0] | 0 | 0) == 0 : 0) ? (d[(c[g >> 2] | 0) + 3 >> 0] | 0 | 0) == 0 : 0) {
	                        c[f >> 2] = 4;
	                        j = c[f >> 2] | 0;
	                        i = e;
	                        return j | 0
	                    }
	                    if ((((d[c[g >> 2] >> 0] | 0 | 0) == 0 ? (d[(c[g >> 2] | 0) + 1 >> 0] | 0 | 0) == 0 : 0) ? (d[(c[g >> 2] | 0) + 2 >> 0] | 0 | 0) == 60 : 0) ? (d[(c[g >> 2] | 0) + 3 >> 0] | 0 | 0) == 0 : 0) {
	                        c[f >> 2] = 7;
	                        j = c[f >> 2] | 0;
	                        i = e;
	                        return j | 0
	                    }
	                    if ((((d[c[g >> 2] >> 0] | 0 | 0) == 0 ? (d[(c[g >> 2] | 0) + 1 >> 0] | 0 | 0) == 60 : 0) ? (d[(c[g >> 2] | 0) + 2 >> 0] | 0 | 0) == 0 : 0) ? (d[(c[g >> 2] | 0) + 3 >> 0] | 0 | 0) == 0 : 0) {
	                        c[f >> 2] = 8;
	                        j = c[f >> 2] | 0;
	                        i = e;
	                        return j | 0
	                    }
	                    if ((((d[c[g >> 2] >> 0] | 0 | 0) == 76 ? (d[(c[g >> 2] | 0) + 1 >> 0] | 0 | 0) == 111 : 0) ? (d[(c[g >> 2] | 0) + 2 >> 0] | 0 | 0) == 167 : 0) ? (d[(c[g >> 2] | 0) + 3 >> 0] | 0 | 0) == 148 : 0) {
	                        c[f >> 2] = 6;
	                        j = c[f >> 2] | 0;
	                        i = e;
	                        return j | 0
	                    }
	                    if ((((d[c[g >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[g >> 2] | 0) + 1 >> 0] | 0 | 0) == 63 : 0) ? (d[(c[g >> 2] | 0) + 2 >> 0] | 0 | 0) == 120 : 0) ? (d[(c[g >> 2] | 0) + 3 >> 0] | 0 | 0) == 109 : 0) {
	                        c[f >> 2] = 1;
	                        j = c[f >> 2] | 0;
	                        i = e;
	                        return j | 0
	                    }
	                    if ((((d[c[g >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[g >> 2] | 0) + 1 >> 0] | 0 | 0) == 0 : 0) ? (d[(c[g >> 2] | 0) + 2 >> 0] | 0 | 0) == 63 : 0) ? (d[(c[g >> 2] | 0) + 3 >> 0] | 0 | 0) == 0 : 0) {
	                        c[f >> 2] = 2;
	                        j = c[f >> 2] | 0;
	                        i = e;
	                        return j | 0
	                    }
	                    if ((((d[c[g >> 2] >> 0] | 0 | 0) == 0 ? (d[(c[g >> 2] | 0) + 1 >> 0] | 0 | 0) == 60 : 0) ? (d[(c[g >> 2] | 0) + 2 >> 0] | 0 | 0) == 0 : 0) ? (d[(c[g >> 2] | 0) + 3 >> 0] | 0 | 0) == 63 : 0) {
	                        c[f >> 2] = 3;
	                        j = c[f >> 2] | 0;
	                        i = e;
	                        return j | 0
	                    }
	                }
	                if ((((c[h >> 2] | 0) >= 3 ? (d[c[g >> 2] >> 0] | 0 | 0) == 239 : 0) ? (d[(c[g >> 2] | 0) + 1 >> 0] | 0 | 0) == 187 : 0) ? (d[(c[g >> 2] | 0) + 2 >> 0] | 0 | 0) == 191 : 0) {
	                    c[f >> 2] = 1;
	                    j = c[f >> 2] | 0;
	                    i = e;
	                    return j | 0
	                }
	                if ((c[h >> 2] | 0) >= 2) {
	                    if ((d[c[g >> 2] >> 0] | 0 | 0) == 254 ? (d[(c[g >> 2] | 0) + 1 >> 0] | 0 | 0) == 255 : 0) {
	                        c[f >> 2] = 3;
	                        j = c[f >> 2] | 0;
	                        i = e;
	                        return j | 0
	                    }
	                    if ((d[c[g >> 2] >> 0] | 0 | 0) == 255 ? (d[(c[g >> 2] | 0) + 1 >> 0] | 0 | 0) == 254 : 0) {
	                        c[f >> 2] = 2;
	                        j = c[f >> 2] | 0;
	                        i = e;
	                        return j | 0
	                    }
	                }
	                c[f >> 2] = 0;
	                j = c[f >> 2] | 0;
	                i = e;
	                return j | 0
	            }

	            function td() {
	                var a = 0, b = 0;
	                a = i;
	                i = i + 16 | 0;
	                b = a;
	                if (!(c[15520] | 0)) {
	                    i = a;
	                    return
	                }
	                c[b >> 2] = 0;
	                while (1) {
	                    if ((c[b >> 2] | 0) >= (c[15522] | 0))break;
	                    if (c[(c[15520] | 0) + (c[b >> 2] << 3) >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[15520] | 0) + (c[b >> 2] << 3) >> 2] | 0);
	                    if (c[(c[15520] | 0) + (c[b >> 2] << 3) + 4 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[15520] | 0) + (c[b >> 2] << 3) + 4 >> 2] | 0);
	                    c[b >> 2] = (c[b >> 2] | 0) + 1
	                }
	                c[15522] = 0;
	                c[15524] = 0;
	                zb[c[135736 >> 2] & 511](c[15520] | 0);
	                c[15520] = 0;
	                i = a;
	                return
	            }

	            function ud(b) {
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 112 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                h = d + 12 | 0;
	                c[f >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                if (!(c[15520] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[g >> 2] = 0;
	                while (1) {
	                    if ((c[g >> 2] | 0) >= 99)break;
	                    b = (WS(a[(c[f >> 2] | 0) + (c[g >> 2] | 0) >> 0] | 0) | 0) & 255;
	                    a[h + (c[g >> 2] | 0) >> 0] = b;
	                    if (!(a[h + (c[g >> 2] | 0) >> 0] | 0))break;
	                    c[g >> 2] = (c[g >> 2] | 0) + 1
	                }
	                a[h + (c[g >> 2] | 0) >> 0] = 0;
	                c[g >> 2] = 0;
	                while (1) {
	                    if ((c[g >> 2] | 0) >= (c[15522] | 0)) {
	                        k = 14;
	                        break
	                    }
	                    f = (PT(c[(c[15520] | 0) + (c[g >> 2] << 3) + 4 >> 2] | 0, h) | 0) != 0;
	                    l = c[g >> 2] | 0;
	                    if (!f) {
	                        k = 12;
	                        break
	                    }
	                    c[g >> 2] = l + 1
	                }
	                if ((k | 0) == 12) {
	                    c[e >> 2] = c[(c[15520] | 0) + (l << 3) >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } else if ((k | 0) == 14) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                return 0
	            }

	            function vd(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 128 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                k = e + 16 | 0;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) {
	                    c[f >> 2] = -1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[j >> 2] = 0;
	                while (1) {
	                    if ((c[j >> 2] | 0) >= 99)break;
	                    d = (WS(a[(c[h >> 2] | 0) + (c[j >> 2] | 0) >> 0] | 0) | 0) & 255;
	                    a[k + (c[j >> 2] | 0) >> 0] = d;
	                    if (!(a[k + (c[j >> 2] | 0) >> 0] | 0))break;
	                    c[j >> 2] = (c[j >> 2] | 0) + 1
	                }
	                a[k + (c[j >> 2] | 0) >> 0] = 0;
	                if (!(c[15520] | 0)) {
	                    c[15522] = 0;
	                    c[15524] = 20;
	                    c[15520] = Cb[c[135744 >> 2] & 511](c[15524] << 3) | 0;
	                    if (!(c[15520] | 0)) {
	                        c[f >> 2] = -1;
	                        l = c[f >> 2] | 0;
	                        i = e;
	                        return l | 0
	                    }
	                } else if ((c[15522] | 0) >= (c[15524] | 0)) {
	                    c[15524] = c[15524] << 1;
	                    c[15520] = Hb[c[135760 >> 2] & 511](c[15520] | 0, c[15524] << 3) | 0
	                }
	                c[j >> 2] = 0;
	                while (1) {
	                    if ((c[j >> 2] | 0) >= (c[15522] | 0)) {
	                        m = 17;
	                        break
	                    }
	                    if (!(PT(c[(c[15520] | 0) + (c[j >> 2] << 3) + 4 >> 2] | 0, k) | 0)) {
	                        m = 15;
	                        break
	                    }
	                    c[j >> 2] = (c[j >> 2] | 0) + 1
	                }
	                if ((m | 0) == 15) {
	                    zb[c[135736 >> 2] & 511](c[(c[15520] | 0) + (c[j >> 2] << 3) >> 2] | 0);
	                    h = Cb[c[135768 >> 2] & 511](c[g >> 2] | 0) | 0;
	                    c[(c[15520] | 0) + (c[j >> 2] << 3) >> 2] = h;
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } else if ((m | 0) == 17) {
	                    m = Cb[c[135768 >> 2] & 511](c[g >> 2] | 0) | 0;
	                    c[(c[15520] | 0) + (c[15522] << 3) >> 2] = m;
	                    m = Cb[c[135768 >> 2] & 511](k) | 0;
	                    c[(c[15520] | 0) + (c[15522] << 3) + 4 >> 2] = m;
	                    c[15522] = (c[15522] | 0) + 1;
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                return 0
	            }

	            function wd(b) {
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 528 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d + 16 | 0;
	                j = d;
	                c[f >> 2] = b;
	                do if (c[f >> 2] | 0) {
	                    c[g >> 2] = ud(c[f >> 2] | 0) | 0;
	                    if (c[g >> 2] | 0)c[f >> 2] = c[g >> 2];
	                    c[j >> 2] = 0;
	                    while (1) {
	                        if ((c[j >> 2] | 0) >= 499)break;
	                        b = (WS(a[(c[f >> 2] | 0) + (c[j >> 2] | 0) >> 0] | 0) | 0) & 255;
	                        a[h + (c[j >> 2] | 0) >> 0] = b;
	                        if (!(a[h + (c[j >> 2] | 0) >> 0] | 0))break;
	                        c[j >> 2] = (c[j >> 2] | 0) + 1
	                    }
	                    a[h + (c[j >> 2] | 0) >> 0] = 0;
	                    if (!(PT(h, 62104) | 0)) {
	                        c[e >> 2] = 0;
	                        break
	                    }
	                    if (!(PT(h, 62112) | 0)) {
	                        c[e >> 2] = 1;
	                        break
	                    }
	                    if (!(PT(h, 62120) | 0)) {
	                        c[e >> 2] = 1;
	                        break
	                    }
	                    if (!(PT(h, 62128) | 0)) {
	                        c[e >> 2] = 2;
	                        break
	                    }
	                    if (!(PT(h, 62136) | 0)) {
	                        c[e >> 2] = 2;
	                        break
	                    }
	                    if (!(PT(h, 62144) | 0)) {
	                        c[e >> 2] = 9;
	                        break
	                    }
	                    if (!(PT(h, 62160) | 0)) {
	                        c[e >> 2] = 9;
	                        break
	                    }
	                    if (!(PT(h, 62168) | 0)) {
	                        c[e >> 2] = 9;
	                        break
	                    }
	                    if (!(PT(h, 62176) | 0)) {
	                        c[e >> 2] = 4;
	                        break
	                    }
	                    if (!(PT(h, 62192) | 0)) {
	                        c[e >> 2] = 4;
	                        break
	                    }
	                    if (!(PT(h, 62200) | 0)) {
	                        c[e >> 2] = 4;
	                        break
	                    }
	                    if (!(PT(h, 62208) | 0)) {
	                        c[e >> 2] = 10;
	                        break
	                    }
	                    if (!(PT(h, 62224) | 0)) {
	                        c[e >> 2] = 10;
	                        break
	                    }
	                    if (!(PT(h, 62240) | 0)) {
	                        c[e >> 2] = 10;
	                        break
	                    }
	                    if (!(PT(h, 62256) | 0)) {
	                        c[e >> 2] = 11;
	                        break
	                    }
	                    if (!(PT(h, 62272) | 0)) {
	                        c[e >> 2] = 11;
	                        break
	                    }
	                    if (!(PT(h, 62288) | 0)) {
	                        c[e >> 2] = 11;
	                        break
	                    }
	                    if (!(PT(h, 62304) | 0)) {
	                        c[e >> 2] = 12;
	                        break
	                    }
	                    if (!(PT(h, 62320) | 0)) {
	                        c[e >> 2] = 13;
	                        break
	                    }
	                    if (!(PT(h, 62336) | 0)) {
	                        c[e >> 2] = 14;
	                        break
	                    }
	                    if (!(PT(h, 62352) | 0)) {
	                        c[e >> 2] = 15;
	                        break
	                    }
	                    if (!(PT(h, 62368) | 0)) {
	                        c[e >> 2] = 16;
	                        break
	                    }
	                    if (!(PT(h, 62384) | 0)) {
	                        c[e >> 2] = 17;
	                        break
	                    }
	                    if (!(PT(h, 62400) | 0)) {
	                        c[e >> 2] = 18;
	                        break
	                    }
	                    if (!(PT(h, 62416) | 0)) {
	                        c[e >> 2] = 19;
	                        break
	                    }
	                    if (!(PT(h, 62432) | 0)) {
	                        c[e >> 2] = 20;
	                        break
	                    }
	                    if (PT(h, 62448) | 0) {
	                        c[e >> 2] = -1;
	                        break
	                    } else {
	                        c[e >> 2] = 21;
	                        break
	                    }
	                } else c[e >> 2] = 0; while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function xd(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                do switch (c[e >> 2] | 0) {
	                    case 4:
	                    {
	                        c[d >> 2] = 62176;
	                        break
	                    }
	                    case 10:
	                    {
	                        c[d >> 2] = 62208;
	                        break
	                    }
	                    case 20:
	                    {
	                        c[d >> 2] = 62464;
	                        break
	                    }
	                    case 3:
	                    {
	                        c[d >> 2] = 62128;
	                        break
	                    }
	                    case 15:
	                    {
	                        c[d >> 2] = 62352;
	                        break
	                    }
	                    case 12:
	                    {
	                        c[d >> 2] = 62304;
	                        break
	                    }
	                    case 6:
	                    {
	                        c[d >> 2] = 62456;
	                        break
	                    }
	                    case 21:
	                    {
	                        c[d >> 2] = 62448;
	                        break
	                    }
	                    case 13:
	                    {
	                        c[d >> 2] = 62320;
	                        break
	                    }
	                    case 19:
	                    {
	                        c[d >> 2] = 62416;
	                        break
	                    }
	                    case 7:
	                    {
	                        c[d >> 2] = 62176;
	                        break
	                    }
	                    case 5:
	                    {
	                        c[d >> 2] = 62176;
	                        break
	                    }
	                    case 1:
	                    {
	                        c[d >> 2] = 62112;
	                        break
	                    }
	                    case 9:
	                    {
	                        c[d >> 2] = 62144;
	                        break
	                    }
	                    case 11:
	                    {
	                        c[d >> 2] = 62256;
	                        break
	                    }
	                    case 8:
	                    {
	                        c[d >> 2] = 62176;
	                        break
	                    }
	                    case 17:
	                    {
	                        c[d >> 2] = 62384;
	                        break
	                    }
	                    case 14:
	                    {
	                        c[d >> 2] = 62336;
	                        break
	                    }
	                    case 18:
	                    {
	                        c[d >> 2] = 62400;
	                        break
	                    }
	                    case -1:
	                    {
	                        c[d >> 2] = 0;
	                        break
	                    }
	                    case 16:
	                    {
	                        c[d >> 2] = 62368;
	                        break
	                    }
	                    case 22:
	                    {
	                        c[d >> 2] = 0;
	                        break
	                    }
	                    case 0:
	                    {
	                        c[d >> 2] = 0;
	                        break
	                    }
	                    case 2:
	                    {
	                        c[d >> 2] = 62128;
	                        break
	                    }
	                    default:
	                        c[d >> 2] = 0
	                } while (0);
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function yd(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                f = i;
	                i = i + 544 | 0;
	                g = f + 28 | 0;
	                h = f + 24 | 0;
	                j = f + 20 | 0;
	                k = f + 16 | 0;
	                l = f + 12 | 0;
	                m = f + 8 | 0;
	                n = f + 32 | 0;
	                o = f + 4 | 0;
	                p = f;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[p >> 2] = 0;
	                c[m >> 2] = ud(c[h >> 2] | 0) | 0;
	                if (c[m >> 2] | 0)c[h >> 2] = c[m >> 2];
	                if (!(c[h >> 2] | 0)) {
	                    Id(6e3, 62480, 0);
	                    c[g >> 2] = 0;
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                c[o >> 2] = 0;
	                while (1) {
	                    if ((c[o >> 2] | 0) >= 499)break;
	                    m = (WS(a[(c[h >> 2] | 0) + (c[o >> 2] | 0) >> 0] | 0) | 0) & 255;
	                    a[n + (c[o >> 2] | 0) >> 0] = m;
	                    if (!(a[n + (c[o >> 2] | 0) >> 0] | 0))break;
	                    c[o >> 2] = (c[o >> 2] | 0) + 1
	                }
	                a[n + (c[o >> 2] | 0) >> 0] = 0;
	                c[p >> 2] = Cb[c[135768 >> 2] & 511](n) | 0;
	                if (!(c[p >> 2] | 0)) {
	                    Jd(62520);
	                    c[g >> 2] = 0;
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                c[l >> 2] = Cb[c[135744 >> 2] & 511](20) | 0;
	                if (!(c[l >> 2] | 0)) {
	                    zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                    Jd(62520);
	                    c[g >> 2] = 0;
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                } else {
	                    n = c[l >> 2] | 0;
	                    c[n + 0 >> 2] = 0;
	                    c[n + 4 >> 2] = 0;
	                    c[n + 8 >> 2] = 0;
	                    c[n + 12 >> 2] = 0;
	                    c[n + 16 >> 2] = 0;
	                    c[(c[l >> 2] | 0) + 4 >> 2] = c[j >> 2];
	                    c[(c[l >> 2] | 0) + 8 >> 2] = c[k >> 2];
	                    c[c[l >> 2] >> 2] = c[p >> 2];
	                    c[(c[l >> 2] | 0) + 12 >> 2] = 0;
	                    c[(c[l >> 2] | 0) + 16 >> 2] = 0;
	                    zd(c[l >> 2] | 0);
	                    c[g >> 2] = c[l >> 2];
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                return 0
	            }

	            function zd(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[15642] | 0))Ad();
	                if ((c[d >> 2] | 0) == 0 | (c[15642] | 0) == 0) {
	                    Id(6001, 62768, 0);
	                    i = b;
	                    return
	                }
	                if ((c[15688] | 0) >= 50) {
	                    Id(6002, 62816, 62888);
	                    i = b;
	                    return
	                } else {
	                    a = c[d >> 2] | 0;
	                    d = c[15688] | 0;
	                    c[15688] = d + 1;
	                    c[(c[15642] | 0) + (d << 2) >> 2] = a;
	                    i = b;
	                    return
	                }
	            }

	            function Ad() {
	                var a = 0, e = 0, f = 0;
	                a = i;
	                i = i + 16 | 0;
	                e = a + 4 | 0;
	                f = a;
	                b[e >> 1] = 4660;
	                c[f >> 2] = e;
	                if (c[15642] | 0) {
	                    i = a;
	                    return
	                }
	                c[15642] = Cb[c[135744 >> 2] & 511](200) | 0;
	                do if ((d[c[f >> 2] >> 0] | 0 | 0) != 18)if ((d[c[f >> 2] >> 0] | 0 | 0) == 52) {
	                    c[15644] = 1;
	                    break
	                } else {
	                    Id(1, 62584, 0);
	                    break
	                } else c[15644] = 0; while (0);
	                if (!(c[15642] | 0)) {
	                    Jd(62624);
	                    i = a;
	                    return
	                } else {
	                    yd(62112, 213, 213) | 0;
	                    c[15672] = yd(62672, 214, 215) | 0;
	                    c[15678] = yd(62696, 216, 217) | 0;
	                    yd(62128, 214, 218) | 0;
	                    yd(62208, 219, 220) | 0;
	                    yd(62720, 221, 222) | 0;
	                    yd(62728, 221, 222) | 0;
	                    yd(62744, 0, 223) | 0;
	                    i = a;
	                    return
	                }
	            }

	            function Bd() {
	                var a = 0;
	                a = i;
	                td();
	                if (!(c[15642] | 0)) {
	                    i = a;
	                    return
	                }
	                while (1) {
	                    if ((c[15688] | 0) <= 0)break;
	                    c[15688] = (c[15688] | 0) + -1;
	                    if (!(c[(c[15642] | 0) + (c[15688] << 2) >> 2] | 0))continue;
	                    if (c[c[(c[15642] | 0) + (c[15688] << 2) >> 2] >> 2] | 0)zb[c[135736 >> 2] & 511](c[c[(c[15642] | 0) + (c[15688] << 2) >> 2] >> 2] | 0);
	                    zb[c[135736 >> 2] & 511](c[(c[15642] | 0) + (c[15688] << 2) >> 2] | 0)
	                }
	                zb[c[135736 >> 2] & 511](c[15642] | 0);
	                c[15642] = 0;
	                c[15688] = 0;
	                c[15690] = 0;
	                i = a;
	                return
	            }

	            function Cd(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if (!(c[15642] | 0))Ad();
	                a:do switch (c[e >> 2] | 0) {
	                    case 6:
	                    {
	                        c[f >> 2] = Dd(62456) | 0;
	                        if (c[f >> 2] | 0) {
	                            c[d >> 2] = c[f >> 2];
	                            break a
	                        }
	                        c[f >> 2] = Dd(62912) | 0;
	                        if (c[f >> 2] | 0) {
	                            c[d >> 2] = c[f >> 2];
	                            break a
	                        }
	                        c[f >> 2] = Dd(62920) | 0;
	                        if (c[f >> 2] | 0) {
	                            c[d >> 2] = c[f >> 2];
	                            break a
	                        }
	                        c[f >> 2] = Dd(62936) | 0;
	                        if (c[f >> 2] | 0)c[d >> 2] = c[f >> 2]; else g = 63;
	                        break
	                    }
	                    case 2:
	                    {
	                        c[d >> 2] = c[15672];
	                        break
	                    }
	                    case 9:
	                    {
	                        c[f >> 2] = Dd(62144) | 0;
	                        if (c[f >> 2] | 0) {
	                            c[d >> 2] = c[f >> 2];
	                            break a
	                        }
	                        c[f >> 2] = Dd(62160) | 0;
	                        if (c[f >> 2] | 0) {
	                            c[d >> 2] = c[f >> 2];
	                            break a
	                        }
	                        c[f >> 2] = Dd(62168) | 0;
	                        if (c[f >> 2] | 0)c[d >> 2] = c[f >> 2]; else g = 63;
	                        break
	                    }
	                    case 18:
	                    {
	                        c[f >> 2] = Dd(62400) | 0;
	                        if (c[f >> 2] | 0)c[d >> 2] = c[f >> 2]; else g = 63;
	                        break
	                    }
	                    case 3:
	                    {
	                        c[d >> 2] = c[15678];
	                        break
	                    }
	                    case 10:
	                    {
	                        c[f >> 2] = Dd(62208) | 0;
	                        if (c[f >> 2] | 0)c[d >> 2] = c[f >> 2]; else g = 63;
	                        break
	                    }
	                    case -1:
	                    {
	                        c[d >> 2] = 0;
	                        break
	                    }
	                    case 12:
	                    {
	                        c[f >> 2] = Dd(62304) | 0;
	                        if (c[f >> 2] | 0)c[d >> 2] = c[f >> 2]; else g = 63;
	                        break
	                    }
	                    case 5:
	                    {
	                        c[f >> 2] = Dd(62176) | 0;
	                        if (c[f >> 2] | 0) {
	                            c[d >> 2] = c[f >> 2];
	                            break a
	                        }
	                        c[f >> 2] = Dd(62192) | 0;
	                        if (c[f >> 2] | 0) {
	                            c[d >> 2] = c[f >> 2];
	                            break a
	                        }
	                        c[f >> 2] = Dd(62200) | 0;
	                        if (c[f >> 2] | 0)c[d >> 2] = c[f >> 2]; else g = 63;
	                        break
	                    }
	                    case 14:
	                    {
	                        c[f >> 2] = Dd(62336) | 0;
	                        if (c[f >> 2] | 0)c[d >> 2] = c[f >> 2]; else g = 63;
	                        break
	                    }
	                    case 19:
	                    {
	                        c[f >> 2] = Dd(62416) | 0;
	                        if (c[f >> 2] | 0)c[d >> 2] = c[f >> 2]; else g = 63;
	                        break
	                    }
	                    case 20:
	                    {
	                        c[f >> 2] = Dd(62944) | 0;
	                        if (c[f >> 2] | 0) {
	                            c[d >> 2] = c[f >> 2];
	                            break a
	                        }
	                        c[f >> 2] = Dd(62432) | 0;
	                        if (c[f >> 2] | 0) {
	                            c[d >> 2] = c[f >> 2];
	                            break a
	                        }
	                        c[f >> 2] = Dd(62960) | 0;
	                        if (c[f >> 2] | 0)c[d >> 2] = c[f >> 2]; else g = 63;
	                        break
	                    }
	                    case 11:
	                    {
	                        c[f >> 2] = Dd(62256) | 0;
	                        if (c[f >> 2] | 0)c[d >> 2] = c[f >> 2]; else g = 63;
	                        break
	                    }
	                    case 0:
	                    {
	                        c[d >> 2] = 0;
	                        break
	                    }
	                    case 17:
	                    {
	                        c[f >> 2] = Dd(62384) | 0;
	                        if (c[f >> 2] | 0)c[d >> 2] = c[f >> 2]; else g = 63;
	                        break
	                    }
	                    case 15:
	                    {
	                        c[f >> 2] = Dd(62352) | 0;
	                        if (c[f >> 2] | 0)c[d >> 2] = c[f >> 2]; else g = 63;
	                        break
	                    }
	                    case 16:
	                    {
	                        c[f >> 2] = Dd(62368) | 0;
	                        if (c[f >> 2] | 0)c[d >> 2] = c[f >> 2]; else g = 63;
	                        break
	                    }
	                    case 13:
	                    {
	                        c[f >> 2] = Dd(62320) | 0;
	                        if (c[f >> 2] | 0)c[d >> 2] = c[f >> 2]; else g = 63;
	                        break
	                    }
	                    case 21:
	                    {
	                        c[f >> 2] = Dd(62448) | 0;
	                        if (c[f >> 2] | 0)c[d >> 2] = c[f >> 2]; else g = 63;
	                        break
	                    }
	                    case 1:
	                    {
	                        c[d >> 2] = 0;
	                        break
	                    }
	                    case 4:
	                    {
	                        c[f >> 2] = Dd(62176) | 0;
	                        if (c[f >> 2] | 0) {
	                            c[d >> 2] = c[f >> 2];
	                            break a
	                        }
	                        c[f >> 2] = Dd(62192) | 0;
	                        if (c[f >> 2] | 0) {
	                            c[d >> 2] = c[f >> 2];
	                            break a
	                        }
	                        c[f >> 2] = Dd(62200) | 0;
	                        if (c[f >> 2] | 0)c[d >> 2] = c[f >> 2]; else g = 63;
	                        break
	                    }
	                    default:
	                        g = 63
	                } while (0);
	                if ((g | 0) == 63)c[d >> 2] = 0;
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function Dd(b) {
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                d = i;
	                i = i + 144 | 0;
	                e = d + 36 | 0;
	                f = d + 32 | 0;
	                g = d + 28 | 0;
	                h = d + 24 | 0;
	                j = d + 20 | 0;
	                k = d + 16 | 0;
	                l = d + 12 | 0;
	                m = d + 8 | 0;
	                n = d + 40 | 0;
	                o = d + 4 | 0;
	                p = d;
	                c[f >> 2] = b;
	                if (!(c[15642] | 0))Ad();
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = c[15690];
	                    q = c[e >> 2] | 0;
	                    i = d;
	                    return q | 0
	                }
	                if (!(a[c[f >> 2] >> 0] | 0)) {
	                    c[e >> 2] = c[15690];
	                    q = c[e >> 2] | 0;
	                    i = d;
	                    return q | 0
	                }
	                c[h >> 2] = c[f >> 2];
	                c[g >> 2] = ud(c[f >> 2] | 0) | 0;
	                if (c[g >> 2] | 0)c[f >> 2] = c[g >> 2];
	                c[o >> 2] = 0;
	                while (1) {
	                    if ((c[o >> 2] | 0) >= 99)break;
	                    g = (WS(a[(c[f >> 2] | 0) + (c[o >> 2] | 0) >> 0] | 0) | 0) & 255;
	                    a[n + (c[o >> 2] | 0) >> 0] = g;
	                    if (!(a[n + (c[o >> 2] | 0) >> 0] | 0))break;
	                    c[o >> 2] = (c[o >> 2] | 0) + 1
	                }
	                a[n + (c[o >> 2] | 0) >> 0] = 0;
	                a:do if (c[15642] | 0) {
	                    c[o >> 2] = 0;
	                    while (1) {
	                        if ((c[o >> 2] | 0) >= (c[15688] | 0))break a;
	                        g = (PT(n, c[c[(c[15642] | 0) + (c[o >> 2] << 2) >> 2] >> 2] | 0) | 0) != 0;
	                        r = c[o >> 2] | 0;
	                        if (!g)break;
	                        c[o >> 2] = r + 1
	                    }
	                    c[e >> 2] = c[(c[15642] | 0) + (r << 2) >> 2];
	                    q = c[e >> 2] | 0;
	                    i = d;
	                    return q | 0
	                } while (0);
	                c[l >> 2] = XS(62112, c[f >> 2] | 0) | 0;
	                c[m >> 2] = XS(c[f >> 2] | 0, 62112) | 0;
	                if ((c[l >> 2] | 0) == (-1 | 0))c[l >> 2] = XS(62112, n) | 0;
	                if ((c[m >> 2] | 0) == (-1 | 0))c[m >> 2] = XS(n, 62112) | 0;
	                if ((c[l >> 2] | 0) != (-1 | 0) & (c[m >> 2] | 0) != (-1 | 0)) {
	                    c[k >> 2] = Cb[c[135744 >> 2] & 511](20) | 0;
	                    if (!(c[k >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        q = c[e >> 2] | 0;
	                        i = d;
	                        return q | 0
	                    } else {
	                        n = c[k >> 2] | 0;
	                        c[n + 0 >> 2] = 0;
	                        c[n + 4 >> 2] = 0;
	                        c[n + 8 >> 2] = 0;
	                        c[n + 12 >> 2] = 0;
	                        c[n + 16 >> 2] = 0;
	                        n = Cb[c[135768 >> 2] & 511](c[f >> 2] | 0) | 0;
	                        c[c[k >> 2] >> 2] = n;
	                        c[(c[k >> 2] | 0) + 4 >> 2] = 0;
	                        c[(c[k >> 2] | 0) + 8 >> 2] = 0;
	                        c[(c[k >> 2] | 0) + 12 >> 2] = c[l >> 2];
	                        c[(c[k >> 2] | 0) + 16 >> 2] = c[m >> 2];
	                        c[e >> 2] = c[k >> 2];
	                        q = c[e >> 2] | 0;
	                        i = d;
	                        return q | 0
	                    }
	                }
	                if ((c[l >> 2] | 0) != (-1 | 0) | (c[m >> 2] | 0) != (-1 | 0))Id(1, 62976, c[f >> 2] | 0);
	                c[j >> 2] = wd(c[h >> 2] | 0) | 0;
	                if (((c[j >> 2] | 0) != -1 ? (c[p >> 2] = xd(c[j >> 2] | 0) | 0, (c[p >> 2] | 0) != 0) : 0) ? (PT(c[f >> 2] | 0, c[p >> 2] | 0) | 0) != 0 : 0) {
	                    c[e >> 2] = Dd(c[p >> 2] | 0) | 0;
	                    q = c[e >> 2] | 0;
	                    i = d;
	                    return q | 0
	                }
	                c[e >> 2] = 0;
	                q = c[e >> 2] | 0;
	                i = d;
	                return q | 0
	            }

	            function Ed(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                f = i;
	                i = i + 112 | 0;
	                g = f;
	                h = f + 56 | 0;
	                j = f + 52 | 0;
	                k = f + 48 | 0;
	                l = f + 44 | 0;
	                m = f + 40 | 0;
	                n = f + 36 | 0;
	                o = f + 32 | 0;
	                p = f + 28 | 0;
	                q = f + 24 | 0;
	                r = f + 20 | 0;
	                s = f + 60 | 0;
	                t = f + 16 | 0;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[l >> 2] = -2;
	                if ((((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 16 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) {
	                    c[r >> 2] = c[(c[j >> 2] | 0) + 16 >> 2];
	                    c[q >> 2] = c[(c[j >> 2] | 0) + 20 >> 2];
	                    c[n >> 2] = _y(c[q >> 2] | 0) | 0;
	                    if (!(c[n >> 2] | 0)) {
	                        c[h >> 2] = 0;
	                        u = c[h >> 2] | 0;
	                        i = f;
	                        return u | 0
	                    }
	                    c[m >> 2] = ($y(c[r >> 2] | 0) | 0) - 1;
	                    e = c[n >> 2] | 0;
	                    if ((c[k >> 2] | 0) >= 0) {
	                        if (e >>> 0 > (c[k >> 2] | 0) >>> 0)c[n >> 2] = c[k >> 2]
	                    } else if (e >>> 0 > 180)c[n >> 2] = 180;
	                    if (c[n >> 2] << 1 >>> 0 >= (c[m >> 2] | 0) >>> 0) {
	                        Uy(c[r >> 2] | 0, c[n >> 2] << 1) | 0;
	                        c[m >> 2] = ($y(c[r >> 2] | 0) | 0) - 1
	                    }
	                    if ((c[m >> 2] | 0) >>> 0 > 360)c[m >> 2] = 360;
	                    c[o >> 2] = c[n >> 2];
	                    c[p >> 2] = c[m >> 2];
	                    m = c[(c[j >> 2] | 0) + 12 >> 2] | 0;
	                    if (!(c[(c[(c[j >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0)) {
	                        if ((c[m + 12 >> 2] | 0) != 0 ? (n = c[(c[(c[j >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2] | 0, j = Wy(c[r >> 2] | 0) | 0, c[l >> 2] = Sd(n, j, p, Vy(c[q >> 2] | 0) | 0, o) | 0, Ty(c[q >> 2] | 0, c[o >> 2] | 0) | 0, Xy(c[r >> 2] | 0, c[p >> 2] | 0) | 0, (c[l >> 2] | 0) == -1) : 0)c[l >> 2] = -3
	                    } else {
	                        j = c[m + 4 >> 2] | 0;
	                        m = Wy(c[r >> 2] | 0) | 0;
	                        n = Vy(c[q >> 2] | 0) | 0;
	                        c[l >> 2] = Fb[j & 511](m, p, n, o) | 0;
	                        Ty(c[q >> 2] | 0, c[o >> 2] | 0) | 0;
	                        Xy(c[r >> 2] | 0, c[p >> 2] | 0) | 0
	                    }
	                    if ((c[l >> 2] | 0) == -2) {
	                        c[t >> 2] = Vy(c[q >> 2] | 0) | 0;
	                        q = d[(c[t >> 2] | 0) + 1 >> 0] | 0;
	                        p = d[(c[t >> 2] | 0) + 2 >> 0] | 0;
	                        r = d[(c[t >> 2] | 0) + 3 >> 0] | 0;
	                        c[g >> 2] = d[c[t >> 2] >> 0];
	                        c[g + 4 >> 2] = q;
	                        c[g + 8 >> 2] = p;
	                        c[g + 12 >> 2] = r;
	                        JT(s, 49, 63016, g) | 0;
	                        a[s + 49 >> 0] = 0;
	                        Id(6003, 63048, s)
	                    }
	                    if ((c[l >> 2] | 0) == -3)c[l >> 2] = 0;
	                    if ((c[l >> 2] | 0) == -1)c[l >> 2] = 0;
	                    c[h >> 2] = c[l >> 2];
	                    u = c[h >> 2] | 0;
	                    i = f;
	                    return u | 0
	                }
	                c[h >> 2] = -1;
	                u = c[h >> 2] | 0;
	                i = f;
	                return u | 0
	            }

	            function Fd(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                f = i;
	                i = i + 112 | 0;
	                g = f;
	                h = f + 56 | 0;
	                j = f + 52 | 0;
	                k = f + 48 | 0;
	                l = f + 44 | 0;
	                m = f + 40 | 0;
	                n = f + 36 | 0;
	                o = f + 32 | 0;
	                p = f + 28 | 0;
	                q = f + 24 | 0;
	                r = f + 20 | 0;
	                s = f + 60 | 0;
	                t = f + 16 | 0;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[l >> 2] = -2;
	                if ((((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 16 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) {
	                    c[r >> 2] = c[(c[j >> 2] | 0) + 16 >> 2];
	                    c[q >> 2] = c[(c[j >> 2] | 0) + 20 >> 2];
	                    c[n >> 2] = _y(c[q >> 2] | 0) | 0;
	                    if (!(c[n >> 2] | 0)) {
	                        c[h >> 2] = 0;
	                        u = c[h >> 2] | 0;
	                        i = f;
	                        return u | 0
	                    }
	                    if ((c[n >> 2] | 0) >>> 0 > 65536 & (c[k >> 2] | 0) == 0)c[n >> 2] = 65536;
	                    c[m >> 2] = $y(c[r >> 2] | 0) | 0;
	                    if ((c[m >> 2] | 0) >>> 0 > 0)c[m >> 2] = (c[m >> 2] | 0) + -1;
	                    if (c[n >> 2] << 1 >>> 0 >= (c[m >> 2] | 0) >>> 0 ? (Uy(c[r >> 2] | 0, c[n >> 2] << 1) | 0, c[m >> 2] = $y(c[r >> 2] | 0) | 0, (c[m >> 2] | 0) >>> 0 > 0) : 0)c[m >> 2] = (c[m >> 2] | 0) + -1;
	                    if ((c[m >> 2] | 0) >>> 0 > 131072 & (c[k >> 2] | 0) == 0)c[m >> 2] = 131072;
	                    c[o >> 2] = c[n >> 2];
	                    c[p >> 2] = c[m >> 2];
	                    m = c[(c[j >> 2] | 0) + 12 >> 2] | 0;
	                    if (!(c[(c[(c[j >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0)) {
	                        if ((c[m + 12 >> 2] | 0) != 0 ? (n = c[(c[(c[j >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2] | 0, j = Wy(c[r >> 2] | 0) | 0, c[l >> 2] = Sd(n, j, p, Vy(c[q >> 2] | 0) | 0, o) | 0, Ty(c[q >> 2] | 0, c[o >> 2] | 0) | 0, Xy(c[r >> 2] | 0, c[p >> 2] | 0) | 0, (c[l >> 2] | 0) == -1) : 0)c[l >> 2] = -3
	                    } else {
	                        j = c[m + 4 >> 2] | 0;
	                        m = Wy(c[r >> 2] | 0) | 0;
	                        n = Vy(c[q >> 2] | 0) | 0;
	                        c[l >> 2] = Fb[j & 511](m, p, n, o) | 0;
	                        Ty(c[q >> 2] | 0, c[o >> 2] | 0) | 0;
	                        Xy(c[r >> 2] | 0, c[p >> 2] | 0) | 0
	                    }
	                    if ((c[l >> 2] | 0) == -2) {
	                        c[t >> 2] = Vy(c[q >> 2] | 0) | 0;
	                        q = d[(c[t >> 2] | 0) + 1 >> 0] | 0;
	                        r = d[(c[t >> 2] | 0) + 2 >> 0] | 0;
	                        o = d[(c[t >> 2] | 0) + 3 >> 0] | 0;
	                        c[g >> 2] = d[c[t >> 2] >> 0];
	                        c[g + 4 >> 2] = q;
	                        c[g + 8 >> 2] = r;
	                        c[g + 12 >> 2] = o;
	                        JT(s, 49, 63016, g) | 0;
	                        a[s + 49 >> 0] = 0;
	                        Id(6003, 63048, s)
	                    }
	                    if ((c[l >> 2] | 0) == -3)c[l >> 2] = 0;
	                    c[h >> 2] = (c[p >> 2] | 0) != 0 ? c[p >> 2] | 0 : c[l >> 2] | 0;
	                    u = c[h >> 2] | 0;
	                    i = f;
	                    return u | 0
	                }
	                c[h >> 2] = -1;
	                u = c[h >> 2] | 0;
	                i = f;
	                return u | 0
	            }

	            function Gd(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0;
	                f = i;
	                i = i + 160 | 0;
	                g = f;
	                h = f + 72 | 0;
	                j = f + 68 | 0;
	                k = f + 64 | 0;
	                l = f + 60 | 0;
	                m = f + 56 | 0;
	                n = f + 52 | 0;
	                o = f + 48 | 0;
	                p = f + 44 | 0;
	                q = f + 40 | 0;
	                r = f + 36 | 0;
	                s = f + 32 | 0;
	                t = f + 28 | 0;
	                u = f + 24 | 0;
	                v = f + 20 | 0;
	                w = f + 16 | 0;
	                x = f + 128 | 0;
	                y = f + 76 | 0;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[l >> 2] = -2;
	                c[n >> 2] = 0;
	                c[t >> 2] = 0;
	                if ((((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 16 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) {
	                    c[s >> 2] = c[(c[j >> 2] | 0) + 20 >> 2];
	                    c[r >> 2] = c[(c[j >> 2] | 0) + 16 >> 2];
	                    a:while (1) {
	                        c[m >> 2] = $y(c[s >> 2] | 0) | 0;
	                        if ((c[m >> 2] | 0) >>> 0 > 0)c[m >> 2] = (c[m >> 2] | 0) + -1;
	                        if (c[k >> 2] | 0) {
	                            z = 10;
	                            break
	                        }
	                        c[o >> 2] = _y(c[r >> 2] | 0) | 0;
	                        if (!(c[o >> 2] | 0)) {
	                            z = 17;
	                            break
	                        }
	                        if ((c[o >> 2] | 0) >>> 0 > 65536)c[o >> 2] = 65536;
	                        if (c[o >> 2] << 2 >>> 0 >= (c[m >> 2] | 0) >>> 0) {
	                            Uy(c[s >> 2] | 0, c[o >> 2] << 2) | 0;
	                            c[m >> 2] = ($y(c[s >> 2] | 0) | 0) - 1
	                        }
	                        if ((c[m >> 2] | 0) >>> 0 > 262144)c[m >> 2] = 262144;
	                        c[p >> 2] = c[o >> 2];
	                        c[q >> 2] = c[m >> 2];
	                        e = c[(c[j >> 2] | 0) + 12 >> 2] | 0;
	                        do if (c[(c[(c[j >> 2] | 0) + 12 >> 2] | 0) + 8 >> 2] | 0) {
	                            b = c[e + 8 >> 2] | 0;
	                            A = Wy(c[s >> 2] | 0) | 0;
	                            B = Vy(c[r >> 2] | 0) | 0;
	                            c[l >> 2] = Fb[b & 511](A, q, B, p) | 0;
	                            if ((c[q >> 2] | 0) > 0) {
	                                Ty(c[r >> 2] | 0, c[p >> 2] | 0) | 0;
	                                Xy(c[s >> 2] | 0, c[q >> 2] | 0) | 0;
	                                c[n >> 2] = (c[n >> 2] | 0) + (c[q >> 2] | 0)
	                            }
	                        } else {
	                            if (!(c[e + 16 >> 2] | 0)) {
	                                z = 32;
	                                break a
	                            }
	                            B = c[(c[(c[j >> 2] | 0) + 12 >> 2] | 0) + 16 >> 2] | 0;
	                            A = Wy(c[s >> 2] | 0) | 0;
	                            c[l >> 2] = Sd(B, A, q, Vy(c[r >> 2] | 0) | 0, p) | 0;
	                            Ty(c[r >> 2] | 0, c[p >> 2] | 0) | 0;
	                            Xy(c[s >> 2] | 0, c[q >> 2] | 0) | 0;
	                            c[n >> 2] = (c[n >> 2] | 0) + (c[q >> 2] | 0);
	                            if ((c[l >> 2] | 0) == -1)if ((c[q >> 2] | 0) > 0) {
	                                c[t >> 2] = 0;
	                                continue a
	                            } else {
	                                c[l >> 2] = -3;
	                                break
	                            }
	                        } while (0);
	                        if ((c[l >> 2] | 0) >= 0)c[j >> 2] = (c[j >> 2] | 0) + (c[l >> 2] << 5);
	                        if ((c[l >> 2] | 0) != -2)break;
	                        c[u >> 2] = _y(c[r >> 2] | 0) | 0;
	                        c[v >> 2] = Vy(c[r >> 2] | 0) | 0;
	                        c[w >> 2] = Ey(c[v >> 2] | 0, u) | 0;
	                        if ((c[t >> 2] | 0) != 0 ? (c[q >> 2] | 0) < (c[t >> 2] | 0) : 0) {
	                            z = 38;
	                            break
	                        }
	                        if ((c[w >> 2] | 0) <= 0) {
	                            z = 41;
	                            break
	                        }
	                        c[g >> 2] = c[w >> 2];
	                        c[t >> 2] = JT(x, 20, 63152, g) | 0;
	                        Ty(c[r >> 2] | 0, c[u >> 2] | 0) | 0;
	                        dz(c[r >> 2] | 0, x, -1) | 0
	                    }
	                    if ((z | 0) == 10) {
	                        c[p >> 2] = 0;
	                        c[q >> 2] = c[m >> 2];
	                        m = c[(c[j >> 2] | 0) + 12 >> 2] | 0;
	                        if (c[(c[(c[j >> 2] | 0) + 12 >> 2] | 0) + 8 >> 2] | 0) {
	                            x = c[m + 8 >> 2] | 0;
	                            u = Wy(c[s >> 2] | 0) | 0;
	                            c[l >> 2] = Fb[x & 511](u, q, 0, p) | 0;
	                            if ((c[l >> 2] | 0) > 0)Xy(c[s >> 2] | 0, c[q >> 2] | 0) | 0
	                        } else if (c[m + 16 >> 2] | 0) {
	                            m = c[(c[(c[j >> 2] | 0) + 12 >> 2] | 0) + 16 >> 2] | 0;
	                            c[l >> 2] = Sd(m, Wy(c[s >> 2] | 0) | 0, q, 0, p) | 0;
	                            Xy(c[s >> 2] | 0, c[q >> 2] | 0) | 0
	                        }
	                        c[h >> 2] = 0;
	                        C = c[h >> 2] | 0;
	                        i = f;
	                        return C | 0
	                    } else if ((z | 0) == 17) {
	                        c[h >> 2] = 0;
	                        C = c[h >> 2] | 0;
	                        i = f;
	                        return C | 0
	                    } else if ((z | 0) == 32) {
	                        Id(6004, 63104, 0);
	                        c[h >> 2] = -1;
	                        C = c[h >> 2] | 0;
	                        i = f;
	                        return C | 0
	                    } else if ((z | 0) == 38) {
	                        Yy(c[s >> 2] | 0, c[q >> 2] | 0) | 0;
	                        c[n >> 2] = (c[n >> 2] | 0) - (c[q >> 2] | 0);
	                        Ty(c[r >> 2] | 0, (c[t >> 2] | 0) - (c[q >> 2] | 0) | 0) | 0;
	                        c[t >> 2] = 0;
	                        c[l >> 2] = -1
	                    } else if ((z | 0) == 41 ? (z = d[(c[v >> 2] | 0) + 1 >> 0] | 0, t = d[(c[v >> 2] | 0) + 2 >> 0] | 0, q = d[(c[v >> 2] | 0) + 3 >> 0] | 0, c[g >> 2] = d[c[v >> 2] >> 0], c[g + 4 >> 2] = z, c[g + 8 >> 2] = t, c[g + 12 >> 2] = q, JT(y, 49, 63016, g) | 0, a[y + 49 >> 0] = 0, Id(6003, 63160, y), (Py(c[r >> 2] | 0) | 0) != 2) : 0)a[c[v >> 2] >> 0] = 32;
	                    c[h >> 2] = c[l >> 2];
	                    C = c[h >> 2] | 0;
	                    i = f;
	                    return C | 0
	                }
	                c[h >> 2] = -1;
	                C = c[h >> 2] | 0;
	                i = f;
	                return C | 0
	            }

	            function Hd(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 20 | 0;
	                e = b + 16 | 0;
	                f = b + 12 | 0;
	                g = b + 8 | 0;
	                h = b + 4 | 0;
	                j = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                c[g >> 2] = 0;
	                c[j >> 2] = 0;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = -1;
	                    k = c[d >> 2] | 0;
	                    i = b;
	                    return k | 0
	                }
	                if (!(c[c[e >> 2] >> 2] | 0)) {
	                    c[d >> 2] = -1;
	                    k = c[d >> 2] | 0;
	                    i = b;
	                    return k | 0
	                }
	                a:do if (c[15642] | 0) {
	                    c[h >> 2] = 0;
	                    while (1) {
	                        if ((c[h >> 2] | 0) >= (c[15688] | 0))break a;
	                        if ((c[e >> 2] | 0) == (c[(c[15642] | 0) + (c[h >> 2] << 2) >> 2] | 0))break;
	                        c[h >> 2] = (c[h >> 2] | 0) + 1
	                    }
	                    c[j >> 2] = 1
	                } while (0);
	                do if (!(c[j >> 2] | 0)) {
	                    if ((c[(c[e >> 2] | 0) + 16 >> 2] | 0) == 0 ? (c[(c[e >> 2] | 0) + 12 >> 2] | 0) == 0 : 0)break;
	                    c[g >> 2] = 1;
	                    if (c[(c[e >> 2] | 0) + 16 >> 2] | 0) {
	                        if (YS(c[(c[e >> 2] | 0) + 16 >> 2] | 0) | 0)c[f >> 2] = -1;
	                        c[(c[e >> 2] | 0) + 16 >> 2] = 0
	                    }
	                    if (c[(c[e >> 2] | 0) + 12 >> 2] | 0) {
	                        if (YS(c[(c[e >> 2] | 0) + 12 >> 2] | 0) | 0)c[f >> 2] = -1;
	                        c[(c[e >> 2] | 0) + 12 >> 2] = 0
	                    }
	                } while (0);
	                if (c[g >> 2] | 0) {
	                    if (c[c[e >> 2] >> 2] | 0)zb[c[135736 >> 2] & 511](c[c[e >> 2] >> 2] | 0);
	                    c[c[e >> 2] >> 2] = 0;
	                    zb[c[135736 >> 2] & 511](c[e >> 2] | 0)
	                }
	                c[d >> 2] = c[f >> 2];
	                k = c[d >> 2] | 0;
	                i = b;
	                return k | 0
	            }

	            function Id(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                d = c[g >> 2] | 0;
	                g = c[j >> 2] | 0;
	                b = c[h >> 2] | 0;
	                c[f >> 2] = c[j >> 2];
	                Xd(0, 0, 0, 0, 0, 27, d, 3, 0, 0, g, 0, 0, 0, 0, b, f);
	                i = e;
	                return
	            }

	            function Jd(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                ce(27, 2, 0, 0, c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function Kd(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if ((c[h >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0) {
	                    c[g >> 2] = -1;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                if ((c[c[j >> 2] >> 2] | 0) > (c[c[l >> 2] >> 2] | 0))c[m >> 2] = c[c[l >> 2] >> 2]; else c[m >> 2] = c[c[j >> 2] >> 2];
	                if ((c[m >> 2] | 0) < 0) {
	                    c[g >> 2] = -1;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                } else {
	                    eU(c[h >> 2] | 0, c[k >> 2] | 0, c[m >> 2] | 0) | 0;
	                    c[c[j >> 2] >> 2] = c[m >> 2];
	                    c[c[l >> 2] >> 2] = c[m >> 2];
	                    c[g >> 2] = c[c[j >> 2] >> 2];
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                return 0
	            }

	            function Ld(b, f, g, h) {
	                b = b | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0;
	                j = i;
	                i = i + 64 | 0;
	                k = j + 56 | 0;
	                l = j + 52 | 0;
	                m = j + 48 | 0;
	                n = j + 44 | 0;
	                o = j + 40 | 0;
	                p = j + 36 | 0;
	                q = j + 32 | 0;
	                r = j + 28 | 0;
	                s = j + 24 | 0;
	                t = j + 20 | 0;
	                u = j + 16 | 0;
	                v = j + 12 | 0;
	                w = j + 8 | 0;
	                x = j + 4 | 0;
	                y = j;
	                c[l >> 2] = b;
	                c[m >> 2] = f;
	                c[n >> 2] = g;
	                c[o >> 2] = h;
	                c[p >> 2] = c[l >> 2];
	                c[q >> 2] = c[n >> 2];
	                c[r >> 2] = (c[l >> 2] | 0) + (c[c[m >> 2] >> 2] | 0);
	                c[s >> 2] = c[n >> 2];
	                if (((c[c[o >> 2] >> 2] | 0) % 2 | 0 | 0) == 1) {
	                    h = c[o >> 2] | 0;
	                    c[h >> 2] = (c[h >> 2] | 0) + -1
	                }
	                c[w >> 2] = (c[c[o >> 2] >> 2] | 0) / 2 | 0;
	                c[t >> 2] = (c[s >> 2] | 0) + (c[w >> 2] << 1);
	                while (1) {
	                    if ((c[s >> 2] | 0) >>> 0 >= (c[t >> 2] | 0) >>> 0) {
	                        z = 29;
	                        break
	                    }
	                    if (((c[l >> 2] | 0) - (c[p >> 2] | 0) + 5 | 0) >= (c[c[m >> 2] >> 2] | 0)) {
	                        z = 29;
	                        break
	                    }
	                    w = c[s >> 2] | 0;
	                    if (c[15644] | 0) {
	                        c[s >> 2] = w + 2;
	                        c[u >> 2] = e[w >> 1]
	                    } else {
	                        c[x >> 2] = w;
	                        w = c[x >> 2] | 0;
	                        c[x >> 2] = w + 1;
	                        c[u >> 2] = d[w >> 0];
	                        c[u >> 2] = c[u >> 2] | (d[c[x >> 2] >> 0] | 0) << 8;
	                        c[s >> 2] = (c[s >> 2] | 0) + 2
	                    }
	                    if ((c[u >> 2] & 64512 | 0) == 55296) {
	                        if ((c[s >> 2] | 0) >>> 0 >= (c[t >> 2] | 0) >>> 0) {
	                            z = 29;
	                            break
	                        }
	                        w = c[s >> 2] | 0;
	                        if (c[15644] | 0) {
	                            c[s >> 2] = w + 2;
	                            c[v >> 2] = e[w >> 1]
	                        } else {
	                            c[x >> 2] = w;
	                            w = c[x >> 2] | 0;
	                            c[x >> 2] = w + 1;
	                            c[v >> 2] = d[w >> 0];
	                            c[v >> 2] = c[v >> 2] | (d[c[x >> 2] >> 0] | 0) << 8;
	                            c[s >> 2] = (c[s >> 2] | 0) + 2
	                        }
	                        if ((c[v >> 2] & 64512 | 0) != 56320) {
	                            z = 16;
	                            break
	                        }
	                        c[u >> 2] = c[u >> 2] & 1023;
	                        c[u >> 2] = c[u >> 2] << 10;
	                        c[u >> 2] = c[u >> 2] | c[v >> 2] & 1023;
	                        c[u >> 2] = (c[u >> 2] | 0) + 65536
	                    }
	                    if ((c[l >> 2] | 0) >>> 0 >= (c[r >> 2] | 0) >>> 0) {
	                        z = 29;
	                        break
	                    }
	                    w = c[u >> 2] | 0;
	                    do if ((c[u >> 2] | 0) >>> 0 >= 128) {
	                        h = c[u >> 2] | 0;
	                        if (w >>> 0 < 2048) {
	                            g = c[l >> 2] | 0;
	                            c[l >> 2] = g + 1;
	                            a[g >> 0] = h >>> 6 & 31 | 192;
	                            c[y >> 2] = 0;
	                            break
	                        }
	                        g = c[u >> 2] | 0;
	                        if (h >>> 0 < 65536) {
	                            h = c[l >> 2] | 0;
	                            c[l >> 2] = h + 1;
	                            a[h >> 0] = g >>> 12 & 15 | 224;
	                            c[y >> 2] = 6;
	                            break
	                        } else {
	                            h = c[l >> 2] | 0;
	                            c[l >> 2] = h + 1;
	                            a[h >> 0] = g >>> 18 & 7 | 240;
	                            c[y >> 2] = 12;
	                            break
	                        }
	                    } else {
	                        g = c[l >> 2] | 0;
	                        c[l >> 2] = g + 1;
	                        a[g >> 0] = w;
	                        c[y >> 2] = -6
	                    } while (0);
	                    while (1) {
	                        if ((c[y >> 2] | 0) < 0)break;
	                        if ((c[l >> 2] | 0) >>> 0 >= (c[r >> 2] | 0) >>> 0)break;
	                        w = ((c[u >> 2] | 0) >>> (c[y >> 2] | 0) & 63 | 128) & 255;
	                        g = c[l >> 2] | 0;
	                        c[l >> 2] = g + 1;
	                        a[g >> 0] = w;
	                        c[y >> 2] = (c[y >> 2] | 0) - 6
	                    }
	                    c[q >> 2] = c[s >> 2]
	                }
	                if ((z | 0) == 16) {
	                    c[c[m >> 2] >> 2] = (c[l >> 2] | 0) - (c[p >> 2] | 0);
	                    c[c[o >> 2] >> 2] = (c[q >> 2] | 0) - (c[n >> 2] | 0);
	                    c[k >> 2] = -2;
	                    A = c[k >> 2] | 0;
	                    i = j;
	                    return A | 0
	                } else if ((z | 0) == 29) {
	                    c[c[m >> 2] >> 2] = (c[l >> 2] | 0) - (c[p >> 2] | 0);
	                    c[c[o >> 2] >> 2] = (c[q >> 2] | 0) - (c[n >> 2] | 0);
	                    c[k >> 2] = c[c[m >> 2] >> 2];
	                    A = c[k >> 2] | 0;
	                    i = j;
	                    return A | 0
	                }
	                return 0
	            }

	            function Md(f, g, h, j) {
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                var k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0;
	                k = i;
	                i = i + 64 | 0;
	                l = k + 56 | 0;
	                m = k + 52 | 0;
	                n = k + 48 | 0;
	                o = k + 44 | 0;
	                p = k + 40 | 0;
	                q = k + 36 | 0;
	                r = k + 32 | 0;
	                s = k + 28 | 0;
	                t = k + 24 | 0;
	                u = k + 20 | 0;
	                v = k + 16 | 0;
	                w = k + 12 | 0;
	                x = k + 8 | 0;
	                y = k + 4 | 0;
	                z = k;
	                A = k + 62 | 0;
	                B = k + 60 | 0;
	                c[m >> 2] = f;
	                c[n >> 2] = g;
	                c[o >> 2] = h;
	                c[p >> 2] = j;
	                c[q >> 2] = c[m >> 2];
	                c[r >> 2] = c[o >> 2];
	                c[s >> 2] = c[o >> 2];
	                c[t >> 2] = c[q >> 2];
	                if ((c[q >> 2] | 0) == 0 | (c[n >> 2] | 0) == 0 | (c[p >> 2] | 0) == 0) {
	                    c[l >> 2] = -1;
	                    C = c[l >> 2] | 0;
	                    i = k;
	                    return C | 0
	                }
	                if (!(c[o >> 2] | 0)) {
	                    c[c[n >> 2] >> 2] = 0;
	                    c[c[p >> 2] >> 2] = 0;
	                    c[l >> 2] = 0;
	                    C = c[l >> 2] | 0;
	                    i = k;
	                    return C | 0
	                }
	                c[v >> 2] = (c[o >> 2] | 0) + (c[c[p >> 2] >> 2] | 0);
	                c[u >> 2] = (c[q >> 2] | 0) + (((c[c[n >> 2] >> 2] | 0) / 2 | 0) << 1);
	                a:while (1) {
	                    if ((c[o >> 2] | 0) >>> 0 >= (c[v >> 2] | 0) >>> 0) {
	                        D = 34;
	                        break
	                    }
	                    m = c[o >> 2] | 0;
	                    c[o >> 2] = m + 1;
	                    c[x >> 2] = d[m >> 0];
	                    m = c[x >> 2] | 0;
	                    do if ((c[x >> 2] | 0) >>> 0 < 128) {
	                        c[w >> 2] = m;
	                        c[y >> 2] = 0
	                    } else {
	                        if (m >>> 0 < 192) {
	                            D = 10;
	                            break a
	                        }
	                        j = c[x >> 2] | 0;
	                        if ((c[x >> 2] | 0) >>> 0 < 224) {
	                            c[w >> 2] = j & 31;
	                            c[y >> 2] = 1;
	                            break
	                        }
	                        h = c[x >> 2] | 0;
	                        if (j >>> 0 < 240) {
	                            c[w >> 2] = h & 15;
	                            c[y >> 2] = 2;
	                            break
	                        }
	                        if (h >>> 0 >= 248) {
	                            D = 17;
	                            break a
	                        }
	                        c[w >> 2] = c[x >> 2] & 7;
	                        c[y >> 2] = 3
	                    } while (0);
	                    if (((c[v >> 2] | 0) - (c[o >> 2] | 0) | 0) < (c[y >> 2] | 0)) {
	                        D = 34;
	                        break
	                    }
	                    while (1) {
	                        if (!(c[y >> 2] | 0))break;
	                        if ((c[o >> 2] | 0) >>> 0 >= (c[v >> 2] | 0) >>> 0)break;
	                        m = c[o >> 2] | 0;
	                        c[o >> 2] = m + 1;
	                        h = d[m >> 0] | 0;
	                        c[x >> 2] = h;
	                        if ((h & 192 | 0) != 128)break;
	                        c[w >> 2] = c[w >> 2] << 6;
	                        c[w >> 2] = c[w >> 2] | c[x >> 2] & 63;
	                        c[y >> 2] = (c[y >> 2] | 0) + -1
	                    }
	                    do if ((c[w >> 2] | 0) >>> 0 < 65536) {
	                        if ((c[q >> 2] | 0) >>> 0 >= (c[u >> 2] | 0) >>> 0) {
	                            D = 34;
	                            break a
	                        }
	                        if (c[15644] | 0) {
	                            h = c[w >> 2] & 65535;
	                            m = c[q >> 2] | 0;
	                            c[q >> 2] = m + 2;
	                            b[m >> 1] = h;
	                            break
	                        } else {
	                            c[z >> 2] = c[q >> 2];
	                            a[c[z >> 2] >> 0] = c[w >> 2];
	                            a[(c[z >> 2] | 0) + 1 >> 0] = (c[w >> 2] | 0) >>> 8;
	                            c[q >> 2] = (c[q >> 2] | 0) + 2;
	                            break
	                        }
	                    } else {
	                        if ((c[w >> 2] | 0) >>> 0 >= 1114112) {
	                            D = 34;
	                            break a
	                        }
	                        if (((c[q >> 2] | 0) + 2 | 0) >>> 0 >= (c[u >> 2] | 0) >>> 0) {
	                            D = 34;
	                            break a
	                        }
	                        c[w >> 2] = (c[w >> 2] | 0) - 65536;
	                        h = (55296 | (c[w >> 2] | 0) >>> 10) & 65535;
	                        if (c[15644] | 0) {
	                            m = c[q >> 2] | 0;
	                            c[q >> 2] = m + 2;
	                            b[m >> 1] = h;
	                            m = (56320 | c[w >> 2] & 1023) & 65535;
	                            j = c[q >> 2] | 0;
	                            c[q >> 2] = j + 2;
	                            b[j >> 1] = m;
	                            break
	                        } else {
	                            b[A >> 1] = h;
	                            c[z >> 2] = c[q >> 2];
	                            a[c[z >> 2] >> 0] = b[A >> 1];
	                            a[(c[z >> 2] | 0) + 1 >> 0] = (e[A >> 1] | 0) >> 8;
	                            c[q >> 2] = (c[q >> 2] | 0) + 2;
	                            b[B >> 1] = 56320 | c[w >> 2] & 1023;
	                            c[z >> 2] = c[q >> 2];
	                            a[c[z >> 2] >> 0] = b[B >> 1];
	                            a[(c[z >> 2] | 0) + 1 >> 0] = (e[B >> 1] | 0) >> 8;
	                            c[q >> 2] = (c[q >> 2] | 0) + 2;
	                            break
	                        }
	                    } while (0);
	                    c[r >> 2] = c[o >> 2]
	                }
	                if ((D | 0) == 10) {
	                    c[c[n >> 2] >> 2] = (((c[q >> 2] | 0) - (c[t >> 2] | 0) | 0) / 2 | 0) << 1;
	                    c[c[p >> 2] >> 2] = (c[r >> 2] | 0) - (c[s >> 2] | 0);
	                    c[l >> 2] = -2;
	                    C = c[l >> 2] | 0;
	                    i = k;
	                    return C | 0
	                } else if ((D | 0) == 17) {
	                    c[c[n >> 2] >> 2] = (((c[q >> 2] | 0) - (c[t >> 2] | 0) | 0) / 2 | 0) << 1;
	                    c[c[p >> 2] >> 2] = (c[r >> 2] | 0) - (c[s >> 2] | 0);
	                    c[l >> 2] = -2;
	                    C = c[l >> 2] | 0;
	                    i = k;
	                    return C | 0
	                } else if ((D | 0) == 34) {
	                    c[c[n >> 2] >> 2] = (((c[q >> 2] | 0) - (c[t >> 2] | 0) | 0) / 2 | 0) << 1;
	                    c[c[p >> 2] >> 2] = (c[r >> 2] | 0) - (c[s >> 2] | 0);
	                    c[l >> 2] = c[c[n >> 2] >> 2];
	                    C = c[l >> 2] | 0;
	                    i = k;
	                    return C | 0
	                }
	                return 0
	            }

	            function Nd(b, f, g, h) {
	                b = b | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0;
	                j = i;
	                i = i + 64 | 0;
	                k = j + 56 | 0;
	                l = j + 52 | 0;
	                m = j + 48 | 0;
	                n = j + 44 | 0;
	                o = j + 40 | 0;
	                p = j + 36 | 0;
	                q = j + 32 | 0;
	                r = j + 28 | 0;
	                s = j + 24 | 0;
	                t = j + 20 | 0;
	                u = j + 16 | 0;
	                v = j + 12 | 0;
	                w = j + 8 | 0;
	                x = j + 4 | 0;
	                y = j;
	                c[l >> 2] = b;
	                c[m >> 2] = f;
	                c[n >> 2] = g;
	                c[o >> 2] = h;
	                c[p >> 2] = c[l >> 2];
	                c[q >> 2] = c[n >> 2];
	                c[r >> 2] = (c[l >> 2] | 0) + (c[c[m >> 2] >> 2] | 0);
	                c[s >> 2] = c[n >> 2];
	                if (((c[c[o >> 2] >> 2] | 0) % 2 | 0 | 0) == 1) {
	                    h = c[o >> 2] | 0;
	                    c[h >> 2] = (c[h >> 2] | 0) + -1
	                }
	                c[w >> 2] = (c[c[o >> 2] >> 2] | 0) / 2 | 0;
	                c[t >> 2] = (c[s >> 2] | 0) + (c[w >> 2] << 1);
	                while (1) {
	                    if ((c[s >> 2] | 0) >>> 0 >= (c[t >> 2] | 0) >>> 0) {
	                        z = 29;
	                        break
	                    }
	                    w = c[s >> 2] | 0;
	                    if (c[15644] | 0) {
	                        c[x >> 2] = w;
	                        h = c[x >> 2] | 0;
	                        c[x >> 2] = h + 1;
	                        c[u >> 2] = d[h >> 0];
	                        c[u >> 2] = c[u >> 2] << 8;
	                        c[u >> 2] = c[u >> 2] | (d[c[x >> 2] >> 0] | 0);
	                        c[s >> 2] = (c[s >> 2] | 0) + 2
	                    } else {
	                        c[s >> 2] = w + 2;
	                        c[u >> 2] = e[w >> 1]
	                    }
	                    if ((c[u >> 2] & 64512 | 0) == 55296) {
	                        if ((c[s >> 2] | 0) >>> 0 >= (c[t >> 2] | 0) >>> 0) {
	                            z = 10;
	                            break
	                        }
	                        w = c[s >> 2] | 0;
	                        if (c[15644] | 0) {
	                            c[x >> 2] = w;
	                            h = c[x >> 2] | 0;
	                            c[x >> 2] = h + 1;
	                            c[v >> 2] = d[h >> 0];
	                            c[v >> 2] = c[v >> 2] << 8;
	                            c[v >> 2] = c[v >> 2] | (d[c[x >> 2] >> 0] | 0);
	                            c[s >> 2] = (c[s >> 2] | 0) + 2
	                        } else {
	                            c[s >> 2] = w + 2;
	                            c[v >> 2] = e[w >> 1]
	                        }
	                        if ((c[v >> 2] & 64512 | 0) != 56320) {
	                            z = 16;
	                            break
	                        }
	                        c[u >> 2] = c[u >> 2] & 1023;
	                        c[u >> 2] = c[u >> 2] << 10;
	                        c[u >> 2] = c[u >> 2] | c[v >> 2] & 1023;
	                        c[u >> 2] = (c[u >> 2] | 0) + 65536
	                    }
	                    if ((c[l >> 2] | 0) >>> 0 >= (c[r >> 2] | 0) >>> 0) {
	                        z = 29;
	                        break
	                    }
	                    w = c[u >> 2] | 0;
	                    do if ((c[u >> 2] | 0) >>> 0 >= 128) {
	                        h = c[u >> 2] | 0;
	                        if (w >>> 0 < 2048) {
	                            g = c[l >> 2] | 0;
	                            c[l >> 2] = g + 1;
	                            a[g >> 0] = h >>> 6 & 31 | 192;
	                            c[y >> 2] = 0;
	                            break
	                        }
	                        g = c[u >> 2] | 0;
	                        if (h >>> 0 < 65536) {
	                            h = c[l >> 2] | 0;
	                            c[l >> 2] = h + 1;
	                            a[h >> 0] = g >>> 12 & 15 | 224;
	                            c[y >> 2] = 6;
	                            break
	                        } else {
	                            h = c[l >> 2] | 0;
	                            c[l >> 2] = h + 1;
	                            a[h >> 0] = g >>> 18 & 7 | 240;
	                            c[y >> 2] = 12;
	                            break
	                        }
	                    } else {
	                        g = c[l >> 2] | 0;
	                        c[l >> 2] = g + 1;
	                        a[g >> 0] = w;
	                        c[y >> 2] = -6
	                    } while (0);
	                    while (1) {
	                        if ((c[y >> 2] | 0) < 0)break;
	                        if ((c[l >> 2] | 0) >>> 0 >= (c[r >> 2] | 0) >>> 0)break;
	                        w = ((c[u >> 2] | 0) >>> (c[y >> 2] | 0) & 63 | 128) & 255;
	                        g = c[l >> 2] | 0;
	                        c[l >> 2] = g + 1;
	                        a[g >> 0] = w;
	                        c[y >> 2] = (c[y >> 2] | 0) - 6
	                    }
	                    c[q >> 2] = c[s >> 2]
	                }
	                if ((z | 0) == 10) {
	                    c[c[m >> 2] >> 2] = (c[l >> 2] | 0) - (c[p >> 2] | 0);
	                    c[c[o >> 2] >> 2] = (c[q >> 2] | 0) - (c[n >> 2] | 0);
	                    c[k >> 2] = -2;
	                    A = c[k >> 2] | 0;
	                    i = j;
	                    return A | 0
	                } else if ((z | 0) == 16) {
	                    c[c[m >> 2] >> 2] = (c[l >> 2] | 0) - (c[p >> 2] | 0);
	                    c[c[o >> 2] >> 2] = (c[q >> 2] | 0) - (c[n >> 2] | 0);
	                    c[k >> 2] = -2;
	                    A = c[k >> 2] | 0;
	                    i = j;
	                    return A | 0
	                } else if ((z | 0) == 29) {
	                    c[c[m >> 2] >> 2] = (c[l >> 2] | 0) - (c[p >> 2] | 0);
	                    c[c[o >> 2] >> 2] = (c[q >> 2] | 0) - (c[n >> 2] | 0);
	                    c[k >> 2] = c[c[m >> 2] >> 2];
	                    A = c[k >> 2] | 0;
	                    i = j;
	                    return A | 0
	                }
	                return 0
	            }

	            function Od(f, g, h, j) {
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                var k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0;
	                k = i;
	                i = i + 64 | 0;
	                l = k + 56 | 0;
	                m = k + 52 | 0;
	                n = k + 48 | 0;
	                o = k + 44 | 0;
	                p = k + 40 | 0;
	                q = k + 36 | 0;
	                r = k + 32 | 0;
	                s = k + 28 | 0;
	                t = k + 24 | 0;
	                u = k + 20 | 0;
	                v = k + 16 | 0;
	                w = k + 12 | 0;
	                x = k + 8 | 0;
	                y = k + 4 | 0;
	                z = k;
	                A = k + 62 | 0;
	                B = k + 60 | 0;
	                c[m >> 2] = f;
	                c[n >> 2] = g;
	                c[o >> 2] = h;
	                c[p >> 2] = j;
	                c[q >> 2] = c[m >> 2];
	                c[r >> 2] = c[o >> 2];
	                c[s >> 2] = c[o >> 2];
	                c[t >> 2] = c[q >> 2];
	                if ((c[m >> 2] | 0) == 0 | (c[n >> 2] | 0) == 0 | (c[p >> 2] | 0) == 0) {
	                    c[l >> 2] = -1;
	                    C = c[l >> 2] | 0;
	                    i = k;
	                    return C | 0
	                }
	                if (!(c[o >> 2] | 0)) {
	                    c[c[n >> 2] >> 2] = 0;
	                    c[c[p >> 2] >> 2] = 0;
	                    c[l >> 2] = 0;
	                    C = c[l >> 2] | 0;
	                    i = k;
	                    return C | 0
	                }
	                c[v >> 2] = (c[o >> 2] | 0) + (c[c[p >> 2] >> 2] | 0);
	                c[u >> 2] = (c[q >> 2] | 0) + (((c[c[n >> 2] >> 2] | 0) / 2 | 0) << 1);
	                a:while (1) {
	                    if ((c[o >> 2] | 0) >>> 0 >= (c[v >> 2] | 0) >>> 0) {
	                        D = 34;
	                        break
	                    }
	                    m = c[o >> 2] | 0;
	                    c[o >> 2] = m + 1;
	                    c[x >> 2] = d[m >> 0];
	                    m = c[x >> 2] | 0;
	                    do if ((c[x >> 2] | 0) >>> 0 < 128) {
	                        c[w >> 2] = m;
	                        c[y >> 2] = 0
	                    } else {
	                        if (m >>> 0 < 192) {
	                            D = 10;
	                            break a
	                        }
	                        j = c[x >> 2] | 0;
	                        if ((c[x >> 2] | 0) >>> 0 < 224) {
	                            c[w >> 2] = j & 31;
	                            c[y >> 2] = 1;
	                            break
	                        }
	                        h = c[x >> 2] | 0;
	                        if (j >>> 0 < 240) {
	                            c[w >> 2] = h & 15;
	                            c[y >> 2] = 2;
	                            break
	                        }
	                        if (h >>> 0 >= 248) {
	                            D = 17;
	                            break a
	                        }
	                        c[w >> 2] = c[x >> 2] & 7;
	                        c[y >> 2] = 3
	                    } while (0);
	                    if (((c[v >> 2] | 0) - (c[o >> 2] | 0) | 0) < (c[y >> 2] | 0)) {
	                        D = 34;
	                        break
	                    }
	                    while (1) {
	                        if (!(c[y >> 2] | 0))break;
	                        if ((c[o >> 2] | 0) >>> 0 >= (c[v >> 2] | 0) >>> 0)break;
	                        m = c[o >> 2] | 0;
	                        c[o >> 2] = m + 1;
	                        h = d[m >> 0] | 0;
	                        c[x >> 2] = h;
	                        if ((h & 192 | 0) != 128)break;
	                        c[w >> 2] = c[w >> 2] << 6;
	                        c[w >> 2] = c[w >> 2] | c[x >> 2] & 63;
	                        c[y >> 2] = (c[y >> 2] | 0) + -1
	                    }
	                    do if ((c[w >> 2] | 0) >>> 0 < 65536) {
	                        if ((c[q >> 2] | 0) >>> 0 >= (c[u >> 2] | 0) >>> 0) {
	                            D = 34;
	                            break a
	                        }
	                        if (c[15644] | 0) {
	                            c[z >> 2] = c[q >> 2];
	                            a[c[z >> 2] >> 0] = (c[w >> 2] | 0) >>> 8;
	                            a[(c[z >> 2] | 0) + 1 >> 0] = c[w >> 2];
	                            c[q >> 2] = (c[q >> 2] | 0) + 2;
	                            break
	                        } else {
	                            h = c[w >> 2] & 65535;
	                            m = c[q >> 2] | 0;
	                            c[q >> 2] = m + 2;
	                            b[m >> 1] = h;
	                            break
	                        }
	                    } else {
	                        if ((c[w >> 2] | 0) >>> 0 >= 1114112) {
	                            D = 34;
	                            break a
	                        }
	                        if (((c[q >> 2] | 0) + 2 | 0) >>> 0 >= (c[u >> 2] | 0) >>> 0) {
	                            D = 34;
	                            break a
	                        }
	                        c[w >> 2] = (c[w >> 2] | 0) - 65536;
	                        h = (55296 | (c[w >> 2] | 0) >>> 10) & 65535;
	                        if (c[15644] | 0) {
	                            b[A >> 1] = h;
	                            c[z >> 2] = c[q >> 2];
	                            a[c[z >> 2] >> 0] = (e[A >> 1] | 0) >> 8;
	                            a[(c[z >> 2] | 0) + 1 >> 0] = b[A >> 1];
	                            c[q >> 2] = (c[q >> 2] | 0) + 2;
	                            b[B >> 1] = 56320 | c[w >> 2] & 1023;
	                            c[z >> 2] = c[q >> 2];
	                            a[c[z >> 2] >> 0] = (e[B >> 1] | 0) >> 8;
	                            a[(c[z >> 2] | 0) + 1 >> 0] = b[B >> 1];
	                            c[q >> 2] = (c[q >> 2] | 0) + 2;
	                            break
	                        } else {
	                            m = c[q >> 2] | 0;
	                            c[q >> 2] = m + 2;
	                            b[m >> 1] = h;
	                            h = (56320 | c[w >> 2] & 1023) & 65535;
	                            m = c[q >> 2] | 0;
	                            c[q >> 2] = m + 2;
	                            b[m >> 1] = h;
	                            break
	                        }
	                    } while (0);
	                    c[r >> 2] = c[o >> 2]
	                }
	                if ((D | 0) == 10) {
	                    c[c[n >> 2] >> 2] = ((c[q >> 2] | 0) - (c[t >> 2] | 0) | 0) / 2 | 0;
	                    c[c[p >> 2] >> 2] = (c[r >> 2] | 0) - (c[s >> 2] | 0);
	                    c[l >> 2] = -2;
	                    C = c[l >> 2] | 0;
	                    i = k;
	                    return C | 0
	                } else if ((D | 0) == 17) {
	                    c[c[n >> 2] >> 2] = ((c[q >> 2] | 0) - (c[t >> 2] | 0) | 0) / 2 | 0;
	                    c[c[p >> 2] >> 2] = (c[r >> 2] | 0) - (c[s >> 2] | 0);
	                    c[l >> 2] = -2;
	                    C = c[l >> 2] | 0;
	                    i = k;
	                    return C | 0
	                } else if ((D | 0) == 34) {
	                    c[c[n >> 2] >> 2] = (((c[q >> 2] | 0) - (c[t >> 2] | 0) | 0) / 2 | 0) << 1;
	                    c[c[p >> 2] >> 2] = (c[r >> 2] | 0) - (c[s >> 2] | 0);
	                    c[l >> 2] = c[c[n >> 2] >> 2];
	                    C = c[l >> 2] | 0;
	                    i = k;
	                    return C | 0
	                }
	                return 0
	            }

	            function Pd(b, d, e, f) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 16 | 0;
	                j = g + 12 | 0;
	                k = g + 8 | 0;
	                l = g + 4 | 0;
	                m = g;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                if (c[l >> 2] | 0) {
	                    c[h >> 2] = Md(c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0) | 0;
	                    n = c[h >> 2] | 0;
	                    i = g;
	                    return n | 0
	                }
	                if ((c[c[k >> 2] >> 2] | 0) >= 2) {
	                    a[c[j >> 2] >> 0] = -1;
	                    a[(c[j >> 2] | 0) + 1 >> 0] = -2;
	                    c[c[k >> 2] >> 2] = 2;
	                    c[c[m >> 2] >> 2] = 0;
	                    c[h >> 2] = 2;
	                    n = c[h >> 2] | 0;
	                    i = g;
	                    return n | 0
	                } else {
	                    c[c[k >> 2] >> 2] = 0;
	                    c[c[m >> 2] >> 2] = 0;
	                    c[h >> 2] = 0;
	                    n = c[h >> 2] | 0;
	                    i = g;
	                    return n | 0
	                }
	                return 0
	            }

	            function Qd(b, e, f, g) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h + 40 | 0;
	                k = h + 36 | 0;
	                l = h + 32 | 0;
	                m = h + 28 | 0;
	                n = h + 24 | 0;
	                o = h + 20 | 0;
	                p = h + 16 | 0;
	                q = h + 12 | 0;
	                r = h + 8 | 0;
	                s = h + 4 | 0;
	                t = h;
	                c[k >> 2] = b;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                c[n >> 2] = g;
	                c[o >> 2] = c[k >> 2];
	                c[p >> 2] = c[m >> 2];
	                c[q >> 2] = c[m >> 2];
	                c[r >> 2] = (c[k >> 2] | 0) + (c[c[l >> 2] >> 2] | 0);
	                c[s >> 2] = (c[m >> 2] | 0) + (c[c[n >> 2] >> 2] | 0);
	                while (1) {
	                    if ((c[m >> 2] | 0) >>> 0 >= (c[s >> 2] | 0) >>> 0) {
	                        u = 8;
	                        break
	                    }
	                    if (((c[k >> 2] | 0) - (c[o >> 2] | 0) + 5 | 0) >= (c[c[l >> 2] >> 2] | 0)) {
	                        u = 8;
	                        break
	                    }
	                    g = c[m >> 2] | 0;
	                    c[m >> 2] = g + 1;
	                    c[t >> 2] = d[g >> 0];
	                    if ((c[k >> 2] | 0) >>> 0 >= (c[r >> 2] | 0) >>> 0) {
	                        u = 8;
	                        break
	                    }
	                    if ((c[t >> 2] | 0) >>> 0 >= 128) {
	                        u = 7;
	                        break
	                    }
	                    g = c[t >> 2] & 255;
	                    f = c[k >> 2] | 0;
	                    c[k >> 2] = f + 1;
	                    a[f >> 0] = g;
	                    c[q >> 2] = c[m >> 2]
	                }
	                if ((u | 0) == 7) {
	                    c[c[l >> 2] >> 2] = (c[k >> 2] | 0) - (c[o >> 2] | 0);
	                    c[c[n >> 2] >> 2] = (c[q >> 2] | 0) - (c[p >> 2] | 0);
	                    c[j >> 2] = -1;
	                    v = c[j >> 2] | 0;
	                    i = h;
	                    return v | 0
	                } else if ((u | 0) == 8) {
	                    c[c[l >> 2] >> 2] = (c[k >> 2] | 0) - (c[o >> 2] | 0);
	                    c[c[n >> 2] >> 2] = (c[q >> 2] | 0) - (c[p >> 2] | 0);
	                    c[j >> 2] = c[c[l >> 2] >> 2];
	                    v = c[j >> 2] | 0;
	                    i = h;
	                    return v | 0
	                }
	                return 0
	            }

	            function Rd(b, e, f, g) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0;
	                h = i;
	                i = i + 64 | 0;
	                j = h + 48 | 0;
	                k = h + 44 | 0;
	                l = h + 40 | 0;
	                m = h + 36 | 0;
	                n = h + 32 | 0;
	                o = h + 28 | 0;
	                p = h + 24 | 0;
	                q = h + 20 | 0;
	                r = h + 16 | 0;
	                s = h + 12 | 0;
	                t = h + 8 | 0;
	                u = h + 4 | 0;
	                v = h;
	                c[k >> 2] = b;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                c[n >> 2] = g;
	                c[o >> 2] = c[m >> 2];
	                c[q >> 2] = c[k >> 2];
	                c[r >> 2] = c[m >> 2];
	                if ((c[k >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0 | (c[n >> 2] | 0) == 0) {
	                    c[j >> 2] = -1;
	                    w = c[j >> 2] | 0;
	                    i = h;
	                    return w | 0
	                }
	                if (!(c[m >> 2] | 0)) {
	                    c[c[l >> 2] >> 2] = 0;
	                    c[c[n >> 2] >> 2] = 0;
	                    c[j >> 2] = 0;
	                    w = c[j >> 2] | 0;
	                    i = h;
	                    return w | 0
	                }
	                c[s >> 2] = (c[m >> 2] | 0) + (c[c[n >> 2] >> 2] | 0);
	                c[p >> 2] = (c[k >> 2] | 0) + (c[c[l >> 2] >> 2] | 0);
	                a:while (1) {
	                    if ((c[m >> 2] | 0) >>> 0 >= (c[s >> 2] | 0) >>> 0) {
	                        x = 27;
	                        break
	                    }
	                    g = c[m >> 2] | 0;
	                    c[m >> 2] = g + 1;
	                    c[u >> 2] = d[g >> 0];
	                    g = c[u >> 2] | 0;
	                    do if ((c[u >> 2] | 0) >>> 0 < 128) {
	                        c[t >> 2] = g;
	                        c[v >> 2] = 0
	                    } else {
	                        if (g >>> 0 < 192) {
	                            x = 10;
	                            break a
	                        }
	                        f = c[u >> 2] | 0;
	                        if ((c[u >> 2] | 0) >>> 0 < 224) {
	                            c[t >> 2] = f & 31;
	                            c[v >> 2] = 1;
	                            break
	                        }
	                        e = c[u >> 2] | 0;
	                        if (f >>> 0 < 240) {
	                            c[t >> 2] = e & 15;
	                            c[v >> 2] = 2;
	                            break
	                        }
	                        if (e >>> 0 >= 248) {
	                            x = 17;
	                            break a
	                        }
	                        c[t >> 2] = c[u >> 2] & 7;
	                        c[v >> 2] = 3
	                    } while (0);
	                    if (((c[s >> 2] | 0) - (c[m >> 2] | 0) | 0) < (c[v >> 2] | 0)) {
	                        x = 27;
	                        break
	                    }
	                    while (1) {
	                        if (!(c[v >> 2] | 0))break;
	                        if ((c[m >> 2] | 0) >>> 0 >= (c[s >> 2] | 0) >>> 0)break;
	                        g = c[m >> 2] | 0;
	                        c[m >> 2] = g + 1;
	                        e = d[g >> 0] | 0;
	                        c[u >> 2] = e;
	                        if ((e & 192 | 0) != 128)break;
	                        c[t >> 2] = c[t >> 2] << 6;
	                        c[t >> 2] = c[t >> 2] | c[u >> 2] & 63;
	                        c[v >> 2] = (c[v >> 2] | 0) + -1
	                    }
	                    y = c[k >> 2] | 0;
	                    if ((c[t >> 2] | 0) >>> 0 >= 128) {
	                        x = 26;
	                        break
	                    }
	                    if (y >>> 0 >= (c[p >> 2] | 0) >>> 0) {
	                        x = 27;
	                        break
	                    }
	                    e = c[t >> 2] & 255;
	                    g = c[k >> 2] | 0;
	                    c[k >> 2] = g + 1;
	                    a[g >> 0] = e;
	                    c[o >> 2] = c[m >> 2]
	                }
	                if ((x | 0) == 10) {
	                    c[c[l >> 2] >> 2] = (c[k >> 2] | 0) - (c[q >> 2] | 0);
	                    c[c[n >> 2] >> 2] = (c[o >> 2] | 0) - (c[r >> 2] | 0);
	                    c[j >> 2] = -2;
	                    w = c[j >> 2] | 0;
	                    i = h;
	                    return w | 0
	                } else if ((x | 0) == 17) {
	                    c[c[l >> 2] >> 2] = (c[k >> 2] | 0) - (c[q >> 2] | 0);
	                    c[c[n >> 2] >> 2] = (c[o >> 2] | 0) - (c[r >> 2] | 0);
	                    c[j >> 2] = -2;
	                    w = c[j >> 2] | 0;
	                    i = h;
	                    return w | 0
	                } else if ((x | 0) == 26) {
	                    c[c[l >> 2] >> 2] = y - (c[q >> 2] | 0);
	                    c[c[n >> 2] >> 2] = (c[o >> 2] | 0) - (c[r >> 2] | 0);
	                    c[j >> 2] = -2;
	                    w = c[j >> 2] | 0;
	                    i = h;
	                    return w | 0
	                } else if ((x | 0) == 27) {
	                    c[c[l >> 2] >> 2] = (c[k >> 2] | 0) - (c[q >> 2] | 0);
	                    c[c[n >> 2] >> 2] = (c[o >> 2] | 0) - (c[r >> 2] | 0);
	                    c[j >> 2] = c[c[l >> 2] >> 2];
	                    w = c[j >> 2] | 0;
	                    i = h;
	                    return w | 0
	                }
	                return 0
	            }

	            function Sd(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                g = i;
	                i = i + 48 | 0;
	                h = g + 40 | 0;
	                j = g + 36 | 0;
	                k = g + 32 | 0;
	                l = g + 28 | 0;
	                m = g + 24 | 0;
	                n = g + 20 | 0;
	                o = g + 16 | 0;
	                p = g + 12 | 0;
	                q = g + 8 | 0;
	                r = g + 4 | 0;
	                s = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[q >> 2] = c[m >> 2];
	                c[r >> 2] = c[k >> 2];
	                if ((c[k >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0 | (c[n >> 2] | 0) == 0 | (c[m >> 2] | 0) == 0) {
	                    if (c[l >> 2] | 0)c[c[l >> 2] >> 2] = 0;
	                    c[h >> 2] = -1;
	                    t = c[h >> 2] | 0;
	                    i = g;
	                    return t | 0
	                }
	                c[o >> 2] = c[c[n >> 2] >> 2];
	                c[p >> 2] = c[c[l >> 2] >> 2];
	                c[s >> 2] = ZS(c[j >> 2] | 0, q, o, r, p) | 0;
	                r = c[n >> 2] | 0;
	                c[r >> 2] = (c[r >> 2] | 0) - (c[o >> 2] | 0);
	                r = c[l >> 2] | 0;
	                c[r >> 2] = (c[r >> 2] | 0) - (c[p >> 2] | 0);
	                if (!((c[o >> 2] | 0) != 0 | (c[s >> 2] | 0) == -1)) {
	                    c[h >> 2] = 0;
	                    t = c[h >> 2] | 0;
	                    i = g;
	                    return t | 0
	                }
	                if ((c[(_a() | 0) >> 2] | 0) == 84) {
	                    c[h >> 2] = -2;
	                    t = c[h >> 2] | 0;
	                    i = g;
	                    return t | 0
	                }
	                if ((c[(_a() | 0) >> 2] | 0) == 7) {
	                    c[h >> 2] = -1;
	                    t = c[h >> 2] | 0;
	                    i = g;
	                    return t | 0
	                } else {
	                    c[h >> 2] = -3;
	                    t = c[h >> 2] | 0;
	                    i = g;
	                    return t | 0
	                }
	                return 0
	            }

	            function Td(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e;
	                c[e + 20 >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[33980] | 0))c[33980] = c[o >> 2];
	                c[g >> 2] = d;
	                Ca(c[33980] | 0, c[f >> 2] | 0, g | 0) | 0;
	                i = e;
	                return
	            }

	            function Ud(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    c[33976] = 35;
	                    i = b;
	                    return
	                } else {
	                    c[33976] = c[c[d >> 2] >> 2];
	                    i = b;
	                    return
	                }
	            }

	            function Vd(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                e = b + 8 | 0;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                a = c[33976] | 0;
	                f = c[33980] | 0;
	                g = c[e >> 2] | 0;
	                if (c[(c[e >> 2] | 0) + 4 >> 2] | 0) {
	                    h = c[(c[e >> 2] | 0) + 28 >> 2] | 0;
	                    c[d >> 2] = c[g + 4 >> 2];
	                    c[d + 4 >> 2] = h;
	                    Db[a & 511](f, 63216, d);
	                    i = b;
	                    return
	                } else {
	                    c[d >> 2] = c[g + 28 >> 2];
	                    Db[a & 511](f, 63224, d);
	                    i = b;
	                    return
	                }
	            }

	            function Wd(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                fe(c[d >> 2] | 0, c[33976] | 0, c[33980] | 0);
	                i = b;
	                return
	            }

	            function Xd(a, b, d, f, g, h, j, k, l, m, n, o, p, q, r, s, t) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                k = k | 0;
	                l = l | 0;
	                m = m | 0;
	                n = n | 0;
	                o = o | 0;
	                p = p | 0;
	                q = q | 0;
	                r = r | 0;
	                s = s | 0;
	                t = t | 0;
	                var u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0, J = 0, K = 0, L = 0, M = 0, N = 0, O = 0, P = 0, Q = 0, R = 0, S = 0, T = 0, U = 0, V = 0, W = 0, X = 0, Y = 0, Z = 0, _ = 0, $ = 0;
	                u = i;
	                i = i + 144 | 0;
	                v = u;
	                w = u + 132 | 0;
	                x = u + 128 | 0;
	                y = u + 124 | 0;
	                z = u + 120 | 0;
	                A = u + 116 | 0;
	                B = u + 112 | 0;
	                C = u + 108 | 0;
	                D = u + 104 | 0;
	                E = u + 100 | 0;
	                F = u + 96 | 0;
	                G = u + 92 | 0;
	                H = u + 88 | 0;
	                I = u + 84 | 0;
	                J = u + 80 | 0;
	                K = u + 76 | 0;
	                L = u + 72 | 0;
	                M = u + 68 | 0;
	                N = u + 64 | 0;
	                O = u + 60 | 0;
	                P = u + 56 | 0;
	                Q = u + 52 | 0;
	                R = u + 48 | 0;
	                S = u + 44 | 0;
	                T = u + 40 | 0;
	                U = u + 36 | 0;
	                V = u + 32 | 0;
	                W = u + 16 | 0;
	                X = u + 12 | 0;
	                Y = u + 8 | 0;
	                Z = u + 4 | 0;
	                c[w >> 2] = a;
	                c[x >> 2] = b;
	                c[y >> 2] = d;
	                c[z >> 2] = f;
	                c[A >> 2] = g;
	                c[B >> 2] = h;
	                c[C >> 2] = j;
	                c[D >> 2] = k;
	                c[E >> 2] = l;
	                c[F >> 2] = m;
	                c[G >> 2] = n;
	                c[H >> 2] = o;
	                c[I >> 2] = p;
	                c[J >> 2] = q;
	                c[K >> 2] = r;
	                c[L >> 2] = s;
	                c[M >> 2] = 0;
	                c[N >> 2] = c[A >> 2];
	                c[O >> 2] = 0;
	                c[P >> 2] = 0;
	                c[Q >> 2] = 136208;
	                c[R >> 2] = 0;
	                if (!(c[C >> 2] | 0)) {
	                    i = u;
	                    return
	                }
	                if ((c[33956] | 0) == 0 & (c[D >> 2] | 0) == 1) {
	                    i = u;
	                    return
	                }
	                if (((((c[B >> 2] | 0) == 1 | (c[B >> 2] | 0) == 5 | (c[B >> 2] | 0) == 4 | (c[B >> 2] | 0) == 3 | (c[B >> 2] | 0) == 8 | (c[B >> 2] | 0) == 23 ? (c[M >> 2] = c[z >> 2], (c[w >> 2] | 0) == 0 & (c[M >> 2] | 0) != 0) : 0) ? (c[c[M >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[c[M >> 2] >> 2] | 0) + 108 >> 2] | 0) == -554844497 : 0) ? (c[(c[c[M >> 2] >> 2] | 0) + 124 >> 2] | 0) != 0 : 0) {
	                    c[w >> 2] = c[(c[c[M >> 2] >> 2] | 0) + 124 >> 2];
	                    c[y >> 2] = c[(c[M >> 2] | 0) + 4 >> 2]
	                }
	                if ((c[w >> 2] | 0) == 0 ? (c[w >> 2] = c[33978], (c[w >> 2] | 0) != 0) : 0)c[y >> 2] = c[33982];
	                a:do if (c[L >> 2] | 0) {
	                    c[T >> 2] = -1;
	                    c[O >> 2] = Cb[c[135744 >> 2] & 511](150) | 0;
	                    if (c[O >> 2] | 0) {
	                        c[S >> 2] = 150;
	                        while (1) {
	                            if ((c[S >> 2] | 0) >= 64e3)break a;
	                            c[W >> 2] = t;
	                            c[U >> 2] = LT(c[O >> 2] | 0, c[S >> 2] | 0, c[L >> 2] | 0, W) | 0;
	                            if ((c[U >> 2] | 0) > -1 ? (c[U >> 2] | 0) < (c[S >> 2] | 0) : 0) {
	                                if ((c[T >> 2] | 0) == (c[U >> 2] | 0))break a;
	                                c[T >> 2] = c[U >> 2]
	                            }
	                            if ((c[U >> 2] | 0) > -1)c[S >> 2] = (c[S >> 2] | 0) + ((c[U >> 2] | 0) + 1); else c[S >> 2] = (c[S >> 2] | 0) + 100;
	                            A = Hb[c[135760 >> 2] & 511](c[O >> 2] | 0, c[S >> 2] | 0) | 0;
	                            c[V >> 2] = A;
	                            if (!A)break a;
	                            c[O >> 2] = c[V >> 2]
	                        }
	                    }
	                } else c[O >> 2] = my(63248) | 0; while (0);
	                if (!(c[M >> 2] | 0)) {
	                    if ((c[N >> 2] | 0) != 0 & (c[E >> 2] | 0) == 0) {
	                        if ((c[(c[N >> 2] | 0) + 32 >> 2] | 0) != 0 ? (c[(c[(c[N >> 2] | 0) + 32 >> 2] | 0) + 72 >> 2] | 0) != 0 : 0)c[R >> 2] = c[N >> 2];
	                        c[X >> 2] = 0;
	                        while (1) {
	                            if (!((c[X >> 2] | 0) < 10 & (c[N >> 2] | 0) != 0))break;
	                            if ((c[(c[N >> 2] | 0) + 4 >> 2] | 0) == 1)break;
	                            c[N >> 2] = c[(c[N >> 2] | 0) + 20 >> 2];
	                            c[X >> 2] = (c[X >> 2] | 0) + 1
	                        }
	                        if (((c[R >> 2] | 0) == 0 & (c[N >> 2] | 0) != 0 ? (c[(c[N >> 2] | 0) + 32 >> 2] | 0) != 0 : 0) ? (c[(c[(c[N >> 2] | 0) + 32 >> 2] | 0) + 72 >> 2] | 0) != 0 : 0)c[R >> 2] = c[N >> 2];
	                        if ((c[N >> 2] | 0) != 0 ? (c[(c[N >> 2] | 0) + 4 >> 2] | 0) == 1 : 0)c[F >> 2] = e[(c[N >> 2] | 0) + 56 >> 1];
	                        if ((c[F >> 2] | 0) == 0 | (c[F >> 2] | 0) == 65535)c[F >> 2] = Ni(c[N >> 2] | 0) | 0
	                    }
	                } else {
	                    if (!(c[E >> 2] | 0)) {
	                        c[P >> 2] = c[(c[M >> 2] | 0) + 36 >> 2];
	                        if (((c[P >> 2] | 0) != 0 ? (c[(c[P >> 2] | 0) + 4 >> 2] | 0) == 0 : 0) ? (c[(c[M >> 2] | 0) + 40 >> 2] | 0) > 1 : 0)c[P >> 2] = c[(c[(c[M >> 2] | 0) + 48 >> 2] | 0) + ((c[(c[M >> 2] | 0) + 40 >> 2] | 0) - 2 << 2) >> 2];
	                        if (c[P >> 2] | 0) {
	                            c[E >> 2] = c[(c[P >> 2] | 0) + 4 >> 2];
	                            c[F >> 2] = c[(c[P >> 2] | 0) + 28 >> 2];
	                            c[K >> 2] = c[(c[P >> 2] | 0) + 32 >> 2]
	                        }
	                    }
	                    c[Q >> 2] = (c[M >> 2] | 0) + 384
	                }
	                Yd(c[Q >> 2] | 0);
	                c[c[Q >> 2] >> 2] = c[B >> 2];
	                c[(c[Q >> 2] | 0) + 4 >> 2] = c[C >> 2];
	                c[(c[Q >> 2] | 0) + 8 >> 2] = c[O >> 2];
	                c[(c[Q >> 2] | 0) + 12 >> 2] = c[D >> 2];
	                if (!(c[E >> 2] | 0)) {
	                    if (c[R >> 2] | 0) {
	                        c[Y >> 2] = c[R >> 2];
	                        c[Z >> 2] = 0;
	                        b:while (1) {
	                            if (!(c[Y >> 2] | 0))break;
	                            while (1) {
	                                _ = c[Y >> 2] | 0;
	                                if (!(c[(c[Y >> 2] | 0) + 28 >> 2] | 0)) {
	                                    $ = 58;
	                                    break
	                                }
	                                c[Y >> 2] = c[_ + 28 >> 2];
	                                if ((c[(c[Y >> 2] | 0) + 4 >> 2] | 0) != 19)break;
	                                C = (c[Z >> 2] | 0) + -1 | 0;
	                                c[Z >> 2] = C;
	                                if (!((C | 0) >= 0 & (c[Y >> 2] | 0) != 0))break b
	                            }
	                            if (($ | 0) == 58) {
	                                $ = 0;
	                                c[Y >> 2] = c[_ + 20 >> 2];
	                                continue
	                            }
	                            if ((c[(c[Y >> 2] | 0) + 4 >> 2] | 0) != 20)continue;
	                            c[Z >> 2] = (c[Z >> 2] | 0) + 1
	                        }
	                        do if (c[Y >> 2] | 0) {
	                            Z = c[Y >> 2] | 0;
	                            if ((c[(c[Y >> 2] | 0) + 4 >> 2] | 0) == 19) {
	                                c[Z + 4 >> 2] = 1;
	                                _ = Yi(c[Y >> 2] | 0, 63280) | 0;
	                                c[(c[Q >> 2] | 0) + 16 >> 2] = _;
	                                c[(c[Y >> 2] | 0) + 4 >> 2] = 19;
	                                break
	                            } else {
	                                _ = Yi(Z, 63280) | 0;
	                                c[(c[Q >> 2] | 0) + 16 >> 2] = _;
	                                break
	                            }
	                        } else {
	                            _ = my(c[(c[(c[R >> 2] | 0) + 32 >> 2] | 0) + 72 >> 2] | 0) | 0;
	                            c[(c[Q >> 2] | 0) + 16 >> 2] = _
	                        } while (0);
	                        if (((c[N >> 2] | 0) != 0 ? (c[(c[Q >> 2] | 0) + 16 >> 2] | 0) == 0 : 0) ? (c[(c[N >> 2] | 0) + 32 >> 2] | 0) != 0 : 0) {
	                            R = my(c[(c[(c[N >> 2] | 0) + 32 >> 2] | 0) + 72 >> 2] | 0) | 0;
	                            c[(c[Q >> 2] | 0) + 16 >> 2] = R
	                        }
	                    }
	                } else {
	                    R = my(c[E >> 2] | 0) | 0;
	                    c[(c[Q >> 2] | 0) + 16 >> 2] = R
	                }
	                c[(c[Q >> 2] | 0) + 20 >> 2] = c[F >> 2];
	                if (c[G >> 2] | 0) {
	                    F = my(c[G >> 2] | 0) | 0;
	                    c[(c[Q >> 2] | 0) + 24 >> 2] = F
	                }
	                if (c[H >> 2] | 0) {
	                    F = my(c[H >> 2] | 0) | 0;
	                    c[(c[Q >> 2] | 0) + 28 >> 2] = F
	                }
	                if (c[I >> 2] | 0) {
	                    F = my(c[I >> 2] | 0) | 0;
	                    c[(c[Q >> 2] | 0) + 32 >> 2] = F
	                }
	                c[(c[Q >> 2] | 0) + 36 >> 2] = c[J >> 2];
	                c[(c[Q >> 2] | 0) + 40 >> 2] = c[K >> 2];
	                c[(c[Q >> 2] | 0) + 48 >> 2] = c[N >> 2];
	                c[(c[Q >> 2] | 0) + 44 >> 2] = c[z >> 2];
	                if ((c[Q >> 2] | 0) != 136208)Zd(c[Q >> 2] | 0, 136208) | 0;
	                if (c[w >> 2] | 0) {
	                    Ab[c[w >> 2] & 511](c[y >> 2] | 0, c[Q >> 2] | 0);
	                    i = u;
	                    return
	                }
	                if ((c[M >> 2] | 0) != 0 & (c[x >> 2] | 0) == 0 & (c[33978] | 0) == 0 ? (c[c[M >> 2] >> 2] | 0) != 0 : 0) {
	                    w = c[c[M >> 2] >> 2] | 0;
	                    if ((c[D >> 2] | 0) == 1)c[x >> 2] = c[w + 84 >> 2]; else c[x >> 2] = c[w + 88 >> 2];
	                    c[y >> 2] = c[(c[M >> 2] | 0) + 4 >> 2]
	                } else $ = 87;
	                do if (($ | 0) == 87 ? (c[x >> 2] | 0) == 0 : 0) {
	                    c[x >> 2] = c[33976];
	                    if (c[M >> 2] | 0) {
	                        c[y >> 2] = c[M >> 2];
	                        break
	                    } else {
	                        c[y >> 2] = c[33980];
	                        break
	                    }
	                } while (0);
	                if (!(c[x >> 2] | 0)) {
	                    i = u;
	                    return
	                }
	                if ((c[x >> 2] | 0) == 57 | (c[x >> 2] | 0) == 56 | (c[x >> 2] | 0) == 224 | (c[x >> 2] | 0) == 225) {
	                    ge(c[Q >> 2] | 0, c[M >> 2] | 0, c[O >> 2] | 0, 0, 0);
	                    i = u;
	                    return
	                }
	                if ((c[x >> 2] | 0) == 203 | (c[x >> 2] | 0) == 35) {
	                    ge(c[Q >> 2] | 0, c[M >> 2] | 0, c[O >> 2] | 0, c[x >> 2] | 0, c[y >> 2] | 0);
	                    i = u;
	                    return
	                } else {
	                    M = c[x >> 2] | 0;
	                    x = c[y >> 2] | 0;
	                    c[v >> 2] = c[O >> 2];
	                    Db[M & 511](x, 63288, v);
	                    i = u;
	                    return
	                }
	            }

	            function Yd(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (!(c[(c[d >> 2] | 0) + 4 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 8 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 16 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 16 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 24 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 24 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 28 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 28 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 32 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 32 >> 2] | 0);
	                a = (c[d >> 2] | 0) + 0 | 0;
	                e = a + 52 | 0;
	                do {
	                    c[a >> 2] = 0;
	                    a = a + 4 | 0
	                } while ((a | 0) < (e | 0));
	                c[(c[d >> 2] | 0) + 4 >> 2] = 0;
	                i = b;
	                return
	            }

	            function Zd(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 28 | 0;
	                f = d + 24 | 0;
	                g = d + 20 | 0;
	                h = d + 16 | 0;
	                j = d + 12 | 0;
	                k = d + 8 | 0;
	                l = d + 4 | 0;
	                m = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = -1;
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                c[h >> 2] = my(c[(c[f >> 2] | 0) + 8 >> 2] | 0) | 0;
	                c[j >> 2] = my(c[(c[f >> 2] | 0) + 16 >> 2] | 0) | 0;
	                c[k >> 2] = my(c[(c[f >> 2] | 0) + 24 >> 2] | 0) | 0;
	                c[l >> 2] = my(c[(c[f >> 2] | 0) + 28 >> 2] | 0) | 0;
	                c[m >> 2] = my(c[(c[f >> 2] | 0) + 32 >> 2] | 0) | 0;
	                if (c[(c[g >> 2] | 0) + 8 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[g >> 2] | 0) + 8 >> 2] | 0);
	                if (c[(c[g >> 2] | 0) + 16 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[g >> 2] | 0) + 16 >> 2] | 0);
	                if (c[(c[g >> 2] | 0) + 24 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[g >> 2] | 0) + 24 >> 2] | 0);
	                if (c[(c[g >> 2] | 0) + 28 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[g >> 2] | 0) + 28 >> 2] | 0);
	                if (c[(c[g >> 2] | 0) + 32 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[g >> 2] | 0) + 32 >> 2] | 0);
	                c[c[g >> 2] >> 2] = c[c[f >> 2] >> 2];
	                c[(c[g >> 2] | 0) + 4 >> 2] = c[(c[f >> 2] | 0) + 4 >> 2];
	                c[(c[g >> 2] | 0) + 12 >> 2] = c[(c[f >> 2] | 0) + 12 >> 2];
	                c[(c[g >> 2] | 0) + 20 >> 2] = c[(c[f >> 2] | 0) + 20 >> 2];
	                c[(c[g >> 2] | 0) + 48 >> 2] = c[(c[f >> 2] | 0) + 48 >> 2];
	                c[(c[g >> 2] | 0) + 36 >> 2] = c[(c[f >> 2] | 0) + 36 >> 2];
	                c[(c[g >> 2] | 0) + 40 >> 2] = c[(c[f >> 2] | 0) + 40 >> 2];
	                c[(c[g >> 2] | 0) + 48 >> 2] = c[(c[f >> 2] | 0) + 48 >> 2];
	                c[(c[g >> 2] | 0) + 44 >> 2] = c[(c[f >> 2] | 0) + 44 >> 2];
	                c[(c[g >> 2] | 0) + 8 >> 2] = c[h >> 2];
	                c[(c[g >> 2] | 0) + 16 >> 2] = c[j >> 2];
	                c[(c[g >> 2] | 0) + 24 >> 2] = c[k >> 2];
	                c[(c[g >> 2] | 0) + 28 >> 2] = c[l >> 2];
	                c[(c[g >> 2] | 0) + 32 >> 2] = c[m >> 2];
	                c[e >> 2] = 0;
	                n = c[e >> 2] | 0;
	                i = d;
	                return n | 0
	            }

	            function _d(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                e = i;
	                i = i + 64 | 0;
	                f = e;
	                g = e + 60 | 0;
	                h = e + 56 | 0;
	                j = e + 52 | 0;
	                k = e + 48 | 0;
	                l = e + 44 | 0;
	                m = e + 40 | 0;
	                n = e + 36 | 0;
	                o = e + 32 | 0;
	                p = e + 28 | 0;
	                q = e + 24 | 0;
	                r = e + 8 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = c[g >> 2];
	                c[k >> 2] = 0;
	                c[l >> 2] = 0;
	                if (c[j >> 2] | 0) {
	                    c[k >> 2] = c[(c[j >> 2] | 0) + 36 >> 2];
	                    if (((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 0 : 0) ? (c[(c[j >> 2] | 0) + 40 >> 2] | 0) > 1 : 0) {
	                        c[l >> 2] = c[k >> 2];
	                        c[k >> 2] = c[(c[(c[j >> 2] | 0) + 48 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 40 >> 2] | 0) - 2 << 2) >> 2]
	                    }
	                    Vd(c[k >> 2] | 0)
	                }
	                Db[c[135904 >> 2] & 511](c[33980] | 0, 63360, f);
	                c[o >> 2] = -1;
	                c[m >> 2] = Cb[c[135744 >> 2] & 511](150) | 0;
	                a:do if (c[m >> 2] | 0) {
	                    c[n >> 2] = 150;
	                    while (1) {
	                        if ((c[n >> 2] | 0) >= 64e3)break a;
	                        c[r >> 2] = d;
	                        c[p >> 2] = LT(c[m >> 2] | 0, c[n >> 2] | 0, c[h >> 2] | 0, r) | 0;
	                        if ((c[p >> 2] | 0) > -1 ? (c[p >> 2] | 0) < (c[n >> 2] | 0) : 0) {
	                            if ((c[o >> 2] | 0) == (c[p >> 2] | 0))break a;
	                            c[o >> 2] = c[p >> 2]
	                        }
	                        if ((c[p >> 2] | 0) > -1)c[n >> 2] = (c[n >> 2] | 0) + ((c[p >> 2] | 0) + 1); else c[n >> 2] = (c[n >> 2] | 0) + 100;
	                        g = Hb[c[135760 >> 2] & 511](c[m >> 2] | 0, c[n >> 2] | 0) | 0;
	                        c[q >> 2] = g;
	                        if (!g)break a;
	                        c[m >> 2] = c[q >> 2]
	                    }
	                } while (0);
	                q = c[33976] | 0;
	                n = c[33980] | 0;
	                c[f >> 2] = c[m >> 2];
	                Db[q & 511](n, 63288, f);
	                if (c[m >> 2] | 0)zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                if (!(c[j >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                Wd(c[k >> 2] | 0);
	                if (!(c[l >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                Vd(c[l >> 2] | 0);
	                Db[c[135904 >> 2] & 511](c[33980] | 0, 63368, f);
	                Wd(c[l >> 2] | 0);
	                i = e;
	                return
	            }

	            function $d(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                e = i;
	                i = i + 64 | 0;
	                f = e;
	                g = e + 60 | 0;
	                h = e + 56 | 0;
	                j = e + 52 | 0;
	                k = e + 48 | 0;
	                l = e + 44 | 0;
	                m = e + 40 | 0;
	                n = e + 36 | 0;
	                o = e + 32 | 0;
	                p = e + 28 | 0;
	                q = e + 24 | 0;
	                r = e + 8 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = c[g >> 2];
	                c[k >> 2] = 0;
	                c[l >> 2] = 0;
	                if (c[j >> 2] | 0) {
	                    c[k >> 2] = c[(c[j >> 2] | 0) + 36 >> 2];
	                    if (((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 0 : 0) ? (c[(c[j >> 2] | 0) + 40 >> 2] | 0) > 1 : 0) {
	                        c[l >> 2] = c[k >> 2];
	                        c[k >> 2] = c[(c[(c[j >> 2] | 0) + 48 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 40 >> 2] | 0) - 2 << 2) >> 2]
	                    }
	                    Vd(c[k >> 2] | 0)
	                }
	                Db[c[135904 >> 2] & 511](c[33980] | 0, 63376, f);
	                c[o >> 2] = -1;
	                c[m >> 2] = Cb[c[135744 >> 2] & 511](150) | 0;
	                a:do if (c[m >> 2] | 0) {
	                    c[n >> 2] = 150;
	                    while (1) {
	                        if ((c[n >> 2] | 0) >= 64e3)break a;
	                        c[r >> 2] = d;
	                        c[p >> 2] = LT(c[m >> 2] | 0, c[n >> 2] | 0, c[h >> 2] | 0, r) | 0;
	                        if ((c[p >> 2] | 0) > -1 ? (c[p >> 2] | 0) < (c[n >> 2] | 0) : 0) {
	                            if ((c[o >> 2] | 0) == (c[p >> 2] | 0))break a;
	                            c[o >> 2] = c[p >> 2]
	                        }
	                        if ((c[p >> 2] | 0) > -1)c[n >> 2] = (c[n >> 2] | 0) + ((c[p >> 2] | 0) + 1); else c[n >> 2] = (c[n >> 2] | 0) + 100;
	                        g = Hb[c[135760 >> 2] & 511](c[m >> 2] | 0, c[n >> 2] | 0) | 0;
	                        c[q >> 2] = g;
	                        if (!g)break a;
	                        c[m >> 2] = c[q >> 2]
	                    }
	                } while (0);
	                q = c[33976] | 0;
	                n = c[33980] | 0;
	                c[f >> 2] = c[m >> 2];
	                Db[q & 511](n, 63288, f);
	                if (c[m >> 2] | 0)zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                if (!(c[j >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                Wd(c[k >> 2] | 0);
	                if (!(c[l >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                Vd(c[l >> 2] | 0);
	                Db[c[135904 >> 2] & 511](c[33980] | 0, 63368, f);
	                Wd(c[l >> 2] | 0);
	                i = e;
	                return
	            }

	            function ae(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                f = i;
	                i = i + 64 | 0;
	                g = f;
	                h = f + 60 | 0;
	                j = f + 56 | 0;
	                k = f + 52 | 0;
	                l = f + 48 | 0;
	                m = f + 44 | 0;
	                n = f + 40 | 0;
	                o = f + 36 | 0;
	                p = f + 32 | 0;
	                q = f + 28 | 0;
	                r = f + 24 | 0;
	                s = f + 8 | 0;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = c[h >> 2];
	                c[l >> 2] = 0;
	                c[n >> 2] = xy(c[j >> 2] | 0) | 0;
	                if ((c[n >> 2] | 0) > 1 ? (a[(c[j >> 2] | 0) + ((c[n >> 2] | 0) - 2) >> 0] | 0) != 58 : 0) {
	                    if (c[k >> 2] | 0) {
	                        c[l >> 2] = c[(c[k >> 2] | 0) + 36 >> 2];
	                        if ((c[(c[l >> 2] | 0) + 4 >> 2] | 0) == 0 ? (c[(c[k >> 2] | 0) + 40 >> 2] | 0) > 1 : 0)c[l >> 2] = c[(c[(c[k >> 2] | 0) + 48 >> 2] | 0) + ((c[(c[k >> 2] | 0) + 40 >> 2] | 0) - 2 << 2) >> 2];
	                        if (!(c[15848] | 0))Vd(c[l >> 2] | 0)
	                    }
	                    Db[c[135904 >> 2] & 511](c[33980] | 0, 63400, g);
	                    c[15848] = 0
	                } else c[15848] = 1;
	                c[p >> 2] = -1;
	                c[m >> 2] = Cb[c[135744 >> 2] & 511](150) | 0;
	                a:do if (c[m >> 2] | 0) {
	                    c[o >> 2] = 150;
	                    while (1) {
	                        if ((c[o >> 2] | 0) >= 64e3)break a;
	                        c[s >> 2] = e;
	                        c[q >> 2] = LT(c[m >> 2] | 0, c[o >> 2] | 0, c[j >> 2] | 0, s) | 0;
	                        if ((c[q >> 2] | 0) > -1 ? (c[q >> 2] | 0) < (c[o >> 2] | 0) : 0) {
	                            if ((c[p >> 2] | 0) == (c[q >> 2] | 0))break a;
	                            c[p >> 2] = c[q >> 2]
	                        }
	                        if ((c[q >> 2] | 0) > -1)c[o >> 2] = (c[o >> 2] | 0) + ((c[q >> 2] | 0) + 1); else c[o >> 2] = (c[o >> 2] | 0) + 100;
	                        n = Hb[c[135760 >> 2] & 511](c[m >> 2] | 0, c[o >> 2] | 0) | 0;
	                        c[r >> 2] = n;
	                        if (!n)break a;
	                        c[m >> 2] = c[r >> 2]
	                    }
	                } while (0);
	                r = c[33976] | 0;
	                o = c[33980] | 0;
	                c[g >> 2] = c[m >> 2];
	                Db[r & 511](o, 63288, g);
	                if (c[m >> 2] | 0)zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                if (!((c[k >> 2] | 0) != 0 & (c[l >> 2] | 0) != 0)) {
	                    i = f;
	                    return
	                }
	                Wd(c[l >> 2] | 0);
	                i = f;
	                return
	            }

	            function be(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                f = i;
	                i = i + 64 | 0;
	                g = f;
	                h = f + 60 | 0;
	                j = f + 56 | 0;
	                k = f + 52 | 0;
	                l = f + 48 | 0;
	                m = f + 44 | 0;
	                n = f + 40 | 0;
	                o = f + 36 | 0;
	                p = f + 32 | 0;
	                q = f + 28 | 0;
	                r = f + 24 | 0;
	                s = f + 8 | 0;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = c[h >> 2];
	                c[l >> 2] = 0;
	                c[n >> 2] = xy(c[j >> 2] | 0) | 0;
	                if ((c[k >> 2] | 0) != 0 & (c[n >> 2] | 0) != 0 ? (a[(c[j >> 2] | 0) + ((c[n >> 2] | 0) - 1) >> 0] | 0) != 58 : 0) {
	                    c[l >> 2] = c[(c[k >> 2] | 0) + 36 >> 2];
	                    if ((c[(c[l >> 2] | 0) + 4 >> 2] | 0) == 0 ? (c[(c[k >> 2] | 0) + 40 >> 2] | 0) > 1 : 0)c[l >> 2] = c[(c[(c[k >> 2] | 0) + 48 >> 2] | 0) + ((c[(c[k >> 2] | 0) + 40 >> 2] | 0) - 2 << 2) >> 2];
	                    Vd(c[l >> 2] | 0)
	                }
	                Db[c[135904 >> 2] & 511](c[33980] | 0, 63424, g);
	                c[p >> 2] = -1;
	                c[m >> 2] = Cb[c[135744 >> 2] & 511](150) | 0;
	                a:do if (c[m >> 2] | 0) {
	                    c[o >> 2] = 150;
	                    while (1) {
	                        if ((c[o >> 2] | 0) >= 64e3)break a;
	                        c[s >> 2] = e;
	                        c[q >> 2] = LT(c[m >> 2] | 0, c[o >> 2] | 0, c[j >> 2] | 0, s) | 0;
	                        if ((c[q >> 2] | 0) > -1 ? (c[q >> 2] | 0) < (c[o >> 2] | 0) : 0) {
	                            if ((c[p >> 2] | 0) == (c[q >> 2] | 0))break a;
	                            c[p >> 2] = c[q >> 2]
	                        }
	                        if ((c[q >> 2] | 0) > -1)c[o >> 2] = (c[o >> 2] | 0) + ((c[q >> 2] | 0) + 1); else c[o >> 2] = (c[o >> 2] | 0) + 100;
	                        n = Hb[c[135760 >> 2] & 511](c[m >> 2] | 0, c[o >> 2] | 0) | 0;
	                        c[r >> 2] = n;
	                        if (!n)break a;
	                        c[m >> 2] = c[r >> 2]
	                    }
	                } while (0);
	                r = c[33976] | 0;
	                o = c[33980] | 0;
	                c[g >> 2] = c[m >> 2];
	                Db[r & 511](o, 63288, g);
	                if (c[m >> 2] | 0)zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                if (!(c[k >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                Wd(c[l >> 2] | 0);
	                i = f;
	                return
	            }

	            function ce(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g;
	                j = g + 20 | 0;
	                k = g + 16 | 0;
	                l = g + 12 | 0;
	                m = g + 8 | 0;
	                n = g + 4 | 0;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                if ((c[k >> 2] | 0) != 2) {
	                    f = c[l >> 2] | 0;
	                    e = c[j >> 2] | 0;
	                    d = c[k >> 2] | 0;
	                    k = c[n >> 2] | 0;
	                    b = c[m >> 2] | 0;
	                    c[h >> 2] = c[n >> 2];
	                    Xd(0, 0, 0, 0, f, e, d, 2, 0, 0, k, 0, 0, 0, 0, b, h);
	                    i = g;
	                    return
	                }
	                b = c[l >> 2] | 0;
	                l = c[j >> 2] | 0;
	                if (c[n >> 2] | 0) {
	                    j = c[n >> 2] | 0;
	                    c[h >> 2] = c[n >> 2];
	                    Xd(0, 0, 0, 0, b, l, 2, 3, 0, 0, j, 0, 0, 0, 0, 63296, h);
	                    i = g;
	                    return
	                } else {
	                    Xd(0, 0, 0, 0, b, l, 2, 3, 0, 0, 0, 0, 0, 0, 0, 63328, h);
	                    i = g;
	                    return
	                }
	            }

	            function de() {
	                var a = 0, b = 0;
	                a = i;
	                i = i + 16 | 0;
	                b = a;
	                if (!(c[34053] | 0))c[b >> 2] = 0; else c[b >> 2] = 136208;
	                i = a;
	                return c[b >> 2] | 0
	            }

	            function ee() {
	                var a = 0;
	                a = i;
	                if (c[34053] | 0)Yd(136208);
	                i = a;
	                return
	            }

	            function fe(b, e, f) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                g = i;
	                i = i + 128 | 0;
	                h = g;
	                j = g + 32 | 0;
	                k = g + 28 | 0;
	                l = g + 24 | 0;
	                m = g + 20 | 0;
	                n = g + 16 | 0;
	                o = g + 12 | 0;
	                p = g + 8 | 0;
	                q = g + 36 | 0;
	                r = g + 4 | 0;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[l >> 2] = f;
	                if (!(c[j >> 2] | 0)) {
	                    i = g;
	                    return
	                }
	                c[m >> 2] = c[(c[j >> 2] | 0) + 16 >> 2];
	                c[n >> 2] = c[(c[j >> 2] | 0) + 12 >> 2];
	                while (1) {
	                    if ((c[m >> 2] | 0) >>> 0 <= (c[n >> 2] | 0) >>> 0)break;
	                    if ((d[c[m >> 2] >> 0] | 0 | 0) != 10 ? (d[c[m >> 2] >> 0] | 0 | 0) != 13 : 0)break;
	                    c[m >> 2] = (c[m >> 2] | 0) + -1
	                }
	                c[o >> 2] = 0;
	                while (1) {
	                    f = c[o >> 2] | 0;
	                    c[o >> 2] = f + 1;
	                    if ((f >>> 0 < 80 ? (c[m >> 2] | 0) >>> 0 > (c[n >> 2] | 0) >>> 0 : 0) ? (d[c[m >> 2] >> 0] | 0 | 0) != 10 : 0)s = (d[c[m >> 2] >> 0] | 0 | 0) != 13; else s = 0;
	                    t = c[m >> 2] | 0;
	                    if (!s)break;
	                    c[m >> 2] = t + -1
	                }
	                if (!((d[t >> 0] | 0 | 0) != 10 ? (d[c[m >> 2] >> 0] | 0 | 0) != 13 : 0))c[m >> 2] = (c[m >> 2] | 0) + 1;
	                c[p >> 2] = (c[(c[j >> 2] | 0) + 16 >> 2] | 0) - (c[m >> 2] | 0);
	                c[o >> 2] = 0;
	                c[r >> 2] = q;
	                while (1) {
	                    if (!(d[c[m >> 2] >> 0] | 0))break;
	                    if ((d[c[m >> 2] >> 0] | 0 | 0) == 10)break;
	                    if (!((c[o >> 2] | 0) >>> 0 < 80 ? (d[c[m >> 2] >> 0] | 0 | 0) != 13 : 0))break;
	                    j = c[m >> 2] | 0;
	                    c[m >> 2] = j + 1;
	                    t = a[j >> 0] | 0;
	                    j = c[r >> 2] | 0;
	                    c[r >> 2] = j + 1;
	                    a[j >> 0] = t;
	                    c[o >> 2] = (c[o >> 2] | 0) + 1
	                }
	                a[c[r >> 2] >> 0] = 0;
	                m = c[k >> 2] | 0;
	                t = c[l >> 2] | 0;
	                c[h >> 2] = q;
	                Db[m & 511](t, 63808, h);
	                c[o >> 2] = 0;
	                c[r >> 2] = q;
	                while (1) {
	                    if ((c[o >> 2] | 0) >>> 0 < (c[p >> 2] | 0) >>> 0 ? (t = c[o >> 2] | 0, c[o >> 2] = t + 1, t >>> 0 < 79) : 0)u = (d[c[r >> 2] >> 0] | 0 | 0) != 0; else u = 0;
	                    v = c[r >> 2] | 0;
	                    if (!u)break;
	                    if ((d[v >> 0] | 0 | 0) != 9)a[c[r >> 2] >> 0] = 32;
	                    c[r >> 2] = (c[r >> 2] | 0) + 1
	                }
	                c[r >> 2] = v + 1;
	                a[v >> 0] = 94;
	                a[c[r >> 2] >> 0] = 0;
	                r = c[k >> 2] | 0;
	                k = c[l >> 2] | 0;
	                c[h >> 2] = q;
	                Db[r & 511](k, 63808, h);
	                i = g;
	                return
	            }

	            function ge(b, d, e, f, g) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0;
	                h = i;
	                i = i + 224 | 0;
	                j = h;
	                k = h + 68 | 0;
	                l = h + 64 | 0;
	                m = h + 60 | 0;
	                n = h + 56 | 0;
	                o = h + 52 | 0;
	                p = h + 48 | 0;
	                q = h + 44 | 0;
	                r = h + 40 | 0;
	                s = h + 36 | 0;
	                t = h + 32 | 0;
	                u = h + 28 | 0;
	                v = h + 24 | 0;
	                w = h + 20 | 0;
	                x = h + 16 | 0;
	                y = h + 12 | 0;
	                z = h + 72 | 0;
	                A = h + 8 | 0;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                c[p >> 2] = 0;
	                c[q >> 2] = 0;
	                c[r >> 2] = -1;
	                c[t >> 2] = 0;
	                c[w >> 2] = 0;
	                c[x >> 2] = 0;
	                if (!(c[k >> 2] | 0)) {
	                    i = h;
	                    return
	                }
	                if (!(c[n >> 2] | 0)) {
	                    c[n >> 2] = c[33976];
	                    c[o >> 2] = c[33980]
	                }
	                c[p >> 2] = c[(c[k >> 2] | 0) + 16 >> 2];
	                c[q >> 2] = c[(c[k >> 2] | 0) + 20 >> 2];
	                c[r >> 2] = c[(c[k >> 2] | 0) + 4 >> 2];
	                c[s >> 2] = c[c[k >> 2] >> 2];
	                c[v >> 2] = c[(c[k >> 2] | 0) + 12 >> 2];
	                c[u >> 2] = c[(c[k >> 2] | 0) + 48 >> 2];
	                if (!(c[r >> 2] | 0)) {
	                    i = h;
	                    return
	                }
	                if ((c[u >> 2] | 0) != 0 ? (c[(c[u >> 2] | 0) + 4 >> 2] | 0) == 1 : 0)c[t >> 2] = c[(c[u >> 2] | 0) + 8 >> 2];
	                do if (c[l >> 2] | 0) {
	                    c[w >> 2] = c[(c[l >> 2] | 0) + 36 >> 2];
	                    if (((c[w >> 2] | 0) != 0 ? (c[(c[w >> 2] | 0) + 4 >> 2] | 0) == 0 : 0) ? (c[(c[l >> 2] | 0) + 40 >> 2] | 0) > 1 : 0) {
	                        c[x >> 2] = c[w >> 2];
	                        c[w >> 2] = c[(c[(c[l >> 2] | 0) + 48 >> 2] | 0) + ((c[(c[l >> 2] | 0) + 40 >> 2] | 0) - 2 << 2) >> 2]
	                    }
	                    if (c[w >> 2] | 0) {
	                        if (c[(c[w >> 2] | 0) + 4 >> 2] | 0) {
	                            u = c[n >> 2] | 0;
	                            r = c[o >> 2] | 0;
	                            g = c[(c[w >> 2] | 0) + 28 >> 2] | 0;
	                            c[j >> 2] = c[(c[w >> 2] | 0) + 4 >> 2];
	                            c[j + 4 >> 2] = g;
	                            Db[u & 511](r, 63216, j);
	                            break
	                        }
	                        if ((c[q >> 2] | 0) != 0 & (c[s >> 2] | 0) == 1) {
	                            r = c[n >> 2] | 0;
	                            u = c[o >> 2] | 0;
	                            c[j >> 2] = c[(c[w >> 2] | 0) + 28 >> 2];
	                            Db[r & 511](u, 63224, j)
	                        }
	                    }
	                } else {
	                    if (c[p >> 2] | 0) {
	                        u = c[n >> 2] | 0;
	                        r = c[o >> 2] | 0;
	                        g = c[q >> 2] | 0;
	                        c[j >> 2] = c[p >> 2];
	                        c[j + 4 >> 2] = g;
	                        Db[u & 511](r, 63216, j);
	                        break
	                    }
	                    if ((c[q >> 2] | 0) != 0 ? (c[s >> 2] | 0) == 1 | (c[s >> 2] | 0) == 17 | (c[s >> 2] | 0) == 16 | (c[s >> 2] | 0) == 4 | (c[s >> 2] | 0) == 18 | (c[s >> 2] | 0) == 19 : 0) {
	                        r = c[n >> 2] | 0;
	                        u = c[o >> 2] | 0;
	                        c[j >> 2] = c[q >> 2];
	                        Db[r & 511](u, 63224, j)
	                    }
	                } while (0);
	                if (c[t >> 2] | 0) {
	                    p = c[n >> 2] | 0;
	                    u = c[o >> 2] | 0;
	                    c[j >> 2] = c[t >> 2];
	                    Db[p & 511](u, 63448, j)
	                }
	                do switch (c[s >> 2] | 0) {
	                    case 29:
	                    {
	                        Db[c[n >> 2] & 511](c[o >> 2] | 0, 63736, j);
	                        break
	                    }
	                    case 30:
	                    {
	                        Db[c[n >> 2] & 511](c[o >> 2] | 0, 63760, j);
	                        break
	                    }
	                    case 20:
	                    {
	                        Db[c[n >> 2] & 511](c[o >> 2] | 0, 63672, j);
	                        break
	                    }
	                    case 5:
	                    {
	                        Db[c[n >> 2] & 511](c[o >> 2] | 0, 63504, j);
	                        break
	                    }
	                    case 1:
	                    {
	                        Db[c[n >> 2] & 511](c[o >> 2] | 0, 63464, j);
	                        break
	                    }
	                    case 13:
	                    {
	                        Db[c[n >> 2] & 511](c[o >> 2] | 0, 63464, j);
	                        break
	                    }
	                    case 18:
	                    {
	                        Db[c[n >> 2] & 511](c[o >> 2] | 0, 63624, j);
	                        break
	                    }
	                    case 19:
	                    {
	                        Db[c[n >> 2] & 511](c[o >> 2] | 0, 63648, j);
	                        break
	                    }
	                    case 14:
	                    {
	                        Db[c[n >> 2] & 511](c[o >> 2] | 0, 63568, j);
	                        break
	                    }
	                    case 26:
	                    {
	                        Db[c[n >> 2] & 511](c[o >> 2] | 0, 63576, j);
	                        break
	                    }
	                    case 23:
	                    case 4:
	                    {
	                        Db[c[n >> 2] & 511](c[o >> 2] | 0, 63488, j);
	                        break
	                    }
	                    case 3:
	                    {
	                        Db[c[n >> 2] & 511](c[o >> 2] | 0, 63472, j);
	                        break
	                    }
	                    case 17:
	                    {
	                        Db[c[n >> 2] & 511](c[o >> 2] | 0, 63584, j);
	                        break
	                    }
	                    case 16:
	                    {
	                        Db[c[n >> 2] & 511](c[o >> 2] | 0, 63608, j);
	                        break
	                    }
	                    case 21:
	                    {
	                        Db[c[n >> 2] & 511](c[o >> 2] | 0, 63688, j);
	                        break
	                    }
	                    case 22:
	                    {
	                        Db[c[n >> 2] & 511](c[o >> 2] | 0, 63696, j);
	                        break
	                    }
	                    case 27:
	                    {
	                        Db[c[n >> 2] & 511](c[o >> 2] | 0, 63704, j);
	                        break
	                    }
	                    case 28:
	                    {
	                        Db[c[n >> 2] & 511](c[o >> 2] | 0, 63720, j);
	                        break
	                    }
	                    case 6:
	                    {
	                        Db[c[n >> 2] & 511](c[o >> 2] | 0, 63520, j);
	                        break
	                    }
	                    case 7:
	                    {
	                        Db[c[n >> 2] & 511](c[o >> 2] | 0, 63528, j);
	                        break
	                    }
	                    case 8:
	                    {
	                        Db[c[n >> 2] & 511](c[o >> 2] | 0, 63536, j);
	                        break
	                    }
	                    case 11:
	                    {
	                        Db[c[n >> 2] & 511](c[o >> 2] | 0, 63544, j);
	                        break
	                    }
	                    case 12:
	                    {
	                        Db[c[n >> 2] & 511](c[o >> 2] | 0, 63560, j);
	                        break
	                    }
	                    default:
	                    {
	                    }
	                } while (0);
	                u = c[v >> 2] | 0;
	                if ((u | 0) == 1)Db[c[n >> 2] & 511](c[o >> 2] | 0, 63776, j); else if ((u | 0) == 2)Db[c[n >> 2] & 511](c[o >> 2] | 0, 63792, j); else if ((u | 0) == 3)Db[c[n >> 2] & 511](c[o >> 2] | 0, 63792, j); else if (!u)Db[c[n >> 2] & 511](c[o >> 2] | 0, 63768, j);
	                do if (c[m >> 2] | 0) {
	                    c[y >> 2] = xy(c[m >> 2] | 0) | 0;
	                    if ((c[y >> 2] | 0) > 0 ? (a[(c[m >> 2] | 0) + ((c[y >> 2] | 0) - 1) >> 0] | 0) != 10 : 0) {
	                        u = c[n >> 2] | 0;
	                        v = c[o >> 2] | 0;
	                        c[j >> 2] = c[m >> 2];
	                        Db[u & 511](v, 63808, j);
	                        break
	                    }
	                    v = c[n >> 2] | 0;
	                    u = c[o >> 2] | 0;
	                    c[j >> 2] = c[m >> 2];
	                    Db[v & 511](u, 63288, j)
	                } else {
	                    u = c[n >> 2] | 0;
	                    v = c[o >> 2] | 0;
	                    c[j >> 2] = 63816;
	                    Db[u & 511](v, 63808, j)
	                } while (0);
	                if ((c[l >> 2] | 0) != 0 ? (fe(c[w >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0), (c[x >> 2] | 0) != 0) : 0) {
	                    if (!(c[(c[x >> 2] | 0) + 4 >> 2] | 0)) {
	                        if ((c[q >> 2] | 0) != 0 & (c[s >> 2] | 0) == 1) {
	                            q = c[n >> 2] | 0;
	                            w = c[o >> 2] | 0;
	                            c[j >> 2] = c[(c[x >> 2] | 0) + 28 >> 2];
	                            Db[q & 511](w, 63856, j)
	                        }
	                    } else {
	                        w = c[n >> 2] | 0;
	                        q = c[o >> 2] | 0;
	                        l = c[(c[x >> 2] | 0) + 28 >> 2] | 0;
	                        c[j >> 2] = c[(c[x >> 2] | 0) + 4 >> 2];
	                        c[j + 4 >> 2] = l;
	                        Db[w & 511](q, 63840, j)
	                    }
	                    fe(c[x >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0)
	                }
	                if ((c[s >> 2] | 0) != 12) {
	                    i = h;
	                    return
	                }
	                if (!(c[(c[k >> 2] | 0) + 24 >> 2] | 0)) {
	                    i = h;
	                    return
	                }
	                if ((c[(c[k >> 2] | 0) + 36 >> 2] | 0) >= 100) {
	                    i = h;
	                    return
	                }
	                s = c[(c[k >> 2] | 0) + 36 >> 2] | 0;
	                if ((s | 0) >= (xy(c[(c[k >> 2] | 0) + 24 >> 2] | 0) | 0)) {
	                    i = h;
	                    return
	                }
	                s = c[n >> 2] | 0;
	                x = c[o >> 2] | 0;
	                c[j >> 2] = c[(c[k >> 2] | 0) + 24 >> 2];
	                Db[s & 511](x, 63808, j);
	                c[A >> 2] = 0;
	                while (1) {
	                    B = c[A >> 2] | 0;
	                    if ((c[A >> 2] | 0) >= (c[(c[k >> 2] | 0) + 36 >> 2] | 0))break;
	                    a[z + B >> 0] = 32;
	                    c[A >> 2] = (c[A >> 2] | 0) + 1
	                }
	                c[A >> 2] = B + 1;
	                a[z + B >> 0] = 94;
	                a[z + (c[A >> 2] | 0) >> 0] = 0;
	                A = c[n >> 2] | 0;
	                n = c[o >> 2] | 0;
	                c[j >> 2] = z;
	                Db[A & 511](n, 63808, j);
	                i = h;
	                return
	            }

	            function he(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                c[e >> 2] = a;
	                c[f >> 2] = 20902;
	                Rf();
	                if (((c[f >> 2] | 0) / 1e4 | 0 | 0) != ((c[e >> 2] | 0) / 1e4 | 0 | 0)) {
	                    a = c[33976] | 0;
	                    g = c[33980] | 0;
	                    h = (c[f >> 2] | 0) / 1e4 | 0;
	                    c[d >> 2] = (c[e >> 2] | 0) / 1e4 | 0;
	                    c[d + 4 >> 2] = h;
	                    Db[a & 511](g, 63880, d);
	                    g = c[o >> 2] | 0;
	                    a = (c[f >> 2] | 0) / 1e4 | 0;
	                    c[d >> 2] = (c[e >> 2] | 0) / 1e4 | 0;
	                    c[d + 4 >> 2] = a;
	                    Ka(g | 0, 63880, d | 0) | 0
	                }
	                if (((c[f >> 2] | 0) / 100 | 0 | 0) >= ((c[e >> 2] | 0) / 100 | 0 | 0)) {
	                    i = b;
	                    return
	                }
	                g = c[33976] | 0;
	                a = c[33980] | 0;
	                h = (c[f >> 2] | 0) / 100 | 0;
	                c[d >> 2] = (c[e >> 2] | 0) / 100 | 0;
	                c[d + 4 >> 2] = h;
	                Db[g & 511](a, 63944, d);
	                i = b;
	                return
	            }

	            function ie(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 212 >> 2] | 0) != 0 : 0) ? (c[(c[f >> 2] | 0) + 172 >> 2] | 0) == -1 : 0) {
	                    i = d;
	                    return
	                }
	                if (c[f >> 2] | 0) {
	                    c[(c[f >> 2] | 0) + 84 >> 2] = 2;
	                    c[(c[f >> 2] | 0) + 172 >> 2] = -1;
	                    c[(c[f >> 2] | 0) + 212 >> 2] = 1
	                }
	                b = c[f >> 2] | 0;
	                if (c[g >> 2] | 0) {
	                    f = c[g >> 2] | 0;
	                    c[e >> 2] = c[g >> 2];
	                    Xd(0, 0, 0, b, 0, 1, 2, 3, 0, 0, f, 0, 0, 0, 0, 64008, e);
	                    i = d;
	                    return
	                } else {
	                    Xd(0, 0, 0, b, 0, 1, 2, 3, 0, 0, 0, 0, 0, 0, 0, 64040, e);
	                    i = d;
	                    return
	                }
	            }

	            function je(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g;
	                j = g + 24 | 0;
	                k = g + 20 | 0;
	                l = g + 16 | 0;
	                m = g + 12 | 0;
	                n = g + 8 | 0;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                if (((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 212 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 172 >> 2] | 0) == -1 : 0) {
	                    i = g;
	                    return
	                }
	                if (c[j >> 2] | 0)c[(c[j >> 2] | 0) + 84 >> 2] = c[k >> 2];
	                f = c[j >> 2] | 0;
	                e = c[k >> 2] | 0;
	                k = c[m >> 2] | 0;
	                d = c[n >> 2] | 0;
	                b = c[l >> 2] | 0;
	                l = c[n >> 2] | 0;
	                c[h >> 2] = c[m >> 2];
	                c[h + 4 >> 2] = l;
	                Xd(0, 0, 0, f, 0, 1, e, 3, 0, 0, k, d, 0, 0, 0, b, h);
	                if (!(c[j >> 2] | 0)) {
	                    i = g;
	                    return
	                }
	                c[(c[j >> 2] | 0) + 12 >> 2] = 0;
	                if (c[(c[j >> 2] | 0) + 288 >> 2] | 0) {
	                    i = g;
	                    return
	                }
	                c[(c[j >> 2] | 0) + 212 >> 2] = 1;
	                i = g;
	                return
	            }

	            function ke(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) < 0) {
	                    c[e >> 2] = -1;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                if (!(c[c[f >> 2] >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                if (!(c[(c[f >> 2] | 0) + 12 >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                if (!(c[(c[f >> 2] | 0) + 16 >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                if (!(c[(c[c[f >> 2] >> 2] | 0) + 16 >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                c[j >> 2] = (c[(c[f >> 2] | 0) + 16 >> 2] | 0) - (c[(c[f >> 2] | 0) + 12 >> 2] | 0);
	                b = _y(c[(c[c[f >> 2] >> 2] | 0) + 16 >> 2] | 0) | 0;
	                if (b >>> 0 > ((c[j >> 2] | 0) + 250 | 0) >>> 0) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                if (!(c[(c[c[f >> 2] >> 2] | 0) + 4 >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                c[h >> 2] = Mk(c[c[f >> 2] >> 2] | 0, c[g >> 2] | 0) | 0;
	                c[k >> 2] = Vy(c[(c[c[f >> 2] >> 2] | 0) + 16 >> 2] | 0) | 0;
	                if ((c[(c[f >> 2] | 0) + 12 >> 2] | 0) != (c[k >> 2] | 0)) {
	                    c[j >> 2] = (c[(c[f >> 2] | 0) + 16 >> 2] | 0) - (c[(c[f >> 2] | 0) + 12 >> 2] | 0);
	                    c[(c[f >> 2] | 0) + 12 >> 2] = c[k >> 2];
	                    c[(c[f >> 2] | 0) + 16 >> 2] = (c[k >> 2] | 0) + (c[j >> 2] | 0)
	                }
	                j = Wy(c[(c[c[f >> 2] >> 2] | 0) + 16 >> 2] | 0) | 0;
	                c[(c[f >> 2] | 0) + 20 >> 2] = j;
	                c[e >> 2] = c[h >> 2];
	                l = c[e >> 2] | 0;
	                i = d;
	                return l | 0
	            }

	            function le(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 16 | 0;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                g = b + 4 | 0;
	                h = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (!(c[c[d >> 2] >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (!(c[(c[d >> 2] | 0) + 12 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (!(c[(c[d >> 2] | 0) + 16 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (!(c[(c[c[d >> 2] >> 2] | 0) + 16 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                a = c[(c[d >> 2] | 0) + 16 >> 2] | 0;
	                c[e >> 2] = a - (Vy(c[(c[c[d >> 2] >> 2] | 0) + 16 >> 2] | 0) | 0);
	                if ((c[e >> 2] | 0) >>> 0 > 250) {
	                    c[f >> 2] = Ty(c[(c[c[d >> 2] >> 2] | 0) + 16 >> 2] | 0, (c[e >> 2] | 0) - 80 | 0) | 0;
	                    if ((c[f >> 2] | 0) >>> 0 > 0) {
	                        e = (c[d >> 2] | 0) + 16 | 0;
	                        c[e >> 2] = (c[e >> 2] | 0) + (0 - (c[f >> 2] | 0));
	                        e = (c[d >> 2] | 0) + 36 | 0;
	                        c[e >> 2] = (c[e >> 2] | 0) + (c[f >> 2] | 0)
	                    }
	                    f = Wy(c[(c[c[d >> 2] >> 2] | 0) + 16 >> 2] | 0) | 0;
	                    c[(c[d >> 2] | 0) + 20 >> 2] = f
	                }
	                if ((_y(c[(c[c[d >> 2] >> 2] | 0) + 16 >> 2] | 0) | 0) >>> 0 > 250) {
	                    i = b;
	                    return
	                }
	                Nk(c[c[d >> 2] >> 2] | 0, 500) | 0;
	                c[h >> 2] = Vy(c[(c[c[d >> 2] >> 2] | 0) + 16 >> 2] | 0) | 0;
	                if ((c[(c[d >> 2] | 0) + 12 >> 2] | 0) != (c[h >> 2] | 0)) {
	                    c[g >> 2] = (c[(c[d >> 2] | 0) + 16 >> 2] | 0) - (c[(c[d >> 2] | 0) + 12 >> 2] | 0);
	                    c[(c[d >> 2] | 0) + 12 >> 2] = c[h >> 2];
	                    c[(c[d >> 2] | 0) + 16 >> 2] = (c[h >> 2] | 0) + (c[g >> 2] | 0)
	                }
	                g = Wy(c[(c[c[d >> 2] >> 2] | 0) + 16 >> 2] | 0) | 0;
	                c[(c[d >> 2] | 0) + 20 >> 2] = g;
	                i = b;
	                return
	            }

	            function me(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 192 | 0;
	                f = e;
	                g = e + 24 | 0;
	                h = e + 20 | 0;
	                j = e + 178 | 0;
	                k = e + 16 | 0;
	                l = e + 28 | 0;
	                c[g >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                if ((c[(c[g >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                    i = e;
	                    return
	                }
	                if (!(c[(c[g >> 2] | 0) + 36 >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                b = d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                do if ((c[(c[g >> 2] | 0) + 256 >> 2] | 0) == 1) {
	                    if (((b | 0) == 0 ? (ke(c[(c[g >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0) ? (c[(c[g >> 2] | 0) + 172 >> 2] | 0) != 5 : 0) {
	                        Ve(c[g >> 2] | 0) | 0;
	                        break
	                    }
	                    m = c[(c[g >> 2] | 0) + 36 >> 2] | 0;
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                        n = m + 28 | 0;
	                        c[n >> 2] = (c[n >> 2] | 0) + 1;
	                        c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                    } else {
	                        n = m + 32 | 0;
	                        c[n >> 2] = (c[n >> 2] | 0) + 1
	                    }
	                    c[h >> 2] = c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                    a[j >> 0] = a[c[h >> 2] >> 0] | 0;
	                    a:do if ((d[j >> 0] | 0) & 128) {
	                        do if ((d[j >> 0] | 0 | 0) != 192) {
	                            if (!(d[(c[h >> 2] | 0) + 1 >> 0] | 0)) {
	                                ke(c[(c[g >> 2] | 0) + 36 >> 2] | 0, 250) | 0;
	                                c[h >> 2] = c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2]
	                            }
	                            if (((d[(c[h >> 2] | 0) + 1 >> 0] | 0) & 192 | 0) == 128) {
	                                if (((d[j >> 0] | 0) & 224 | 0) != 224) {
	                                    n = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                                    c[n >> 2] = (c[n >> 2] | 0) + 2;
	                                    break a
	                                }
	                                if (!(d[(c[h >> 2] | 0) + 2 >> 0] | 0)) {
	                                    ke(c[(c[g >> 2] | 0) + 36 >> 2] | 0, 250) | 0;
	                                    c[h >> 2] = c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2]
	                                }
	                                if (((d[(c[h >> 2] | 0) + 2 >> 0] | 0) & 192 | 0) == 128) {
	                                    if (((d[j >> 0] | 0) & 240 | 0) == 240) {
	                                        if (!(d[(c[h >> 2] | 0) + 3 >> 0] | 0)) {
	                                            ke(c[(c[g >> 2] | 0) + 36 >> 2] | 0, 250) | 0;
	                                            c[h >> 2] = c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2]
	                                        }
	                                        if (((d[j >> 0] | 0) & 248 | 0) != 240)break;
	                                        if (((d[(c[h >> 2] | 0) + 3 >> 0] | 0) & 192 | 0) != 128)break;
	                                        n = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                                        c[n >> 2] = (c[n >> 2] | 0) + 4;
	                                        c[k >> 2] = ((d[c[h >> 2] >> 0] | 0) & 7) << 18;
	                                        c[k >> 2] = c[k >> 2] | ((d[(c[h >> 2] | 0) + 1 >> 0] | 0) & 63) << 12;
	                                        c[k >> 2] = c[k >> 2] | ((d[(c[h >> 2] | 0) + 2 >> 0] | 0) & 63) << 6;
	                                        c[k >> 2] = c[k >> 2] | (d[(c[h >> 2] | 0) + 3 >> 0] | 0) & 63
	                                    } else {
	                                        n = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                                        c[n >> 2] = (c[n >> 2] | 0) + 3;
	                                        c[k >> 2] = ((d[c[h >> 2] >> 0] | 0) & 15) << 12;
	                                        c[k >> 2] = c[k >> 2] | ((d[(c[h >> 2] | 0) + 1 >> 0] | 0) & 63) << 6;
	                                        c[k >> 2] = c[k >> 2] | (d[(c[h >> 2] | 0) + 2 >> 0] | 0) & 63
	                                    }
	                                    if (!((c[k >> 2] | 0) >>> 0 > 55295 & (c[k >> 2] | 0) >>> 0 < 57344) ? !((c[k >> 2] | 0) >>> 0 > 65533 & (c[k >> 2] | 0) >>> 0 < 65536 | (c[k >> 2] | 0) >>> 0 >= 1114112) : 0)break a;
	                                    Ie(c[g >> 2] | 0, 9, 64072, c[k >> 2] | 0);
	                                    break a
	                                }
	                            }
	                        } while (0);
	                        if (((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) >= 4 : 0) {
	                            n = d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0;
	                            m = d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0;
	                            o = d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0;
	                            c[f >> 2] = d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0];
	                            c[f + 4 >> 2] = n;
	                            c[f + 8 >> 2] = m;
	                            c[f + 12 >> 2] = o;
	                            JT(l, 149, 64152, f) | 0;
	                            je(c[g >> 2] | 0, 9, 64192, l, 0)
	                        } else je(c[g >> 2] | 0, 9, 64104, 0, 0);
	                        c[(c[g >> 2] | 0) + 256 >> 2] = 10;
	                        o = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                        c[o >> 2] = (c[o >> 2] | 0) + 1;
	                        i = e;
	                        return
	                    } else {
	                        o = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                        c[o >> 2] = (c[o >> 2] | 0) + 1
	                    } while (0);
	                    o = (c[g >> 2] | 0) + 200 | 0;
	                    c[o >> 2] = (c[o >> 2] | 0) + 1;
	                    if (!(d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0))ke(c[(c[g >> 2] | 0) + 36 >> 2] | 0, 250) | 0
	                } else {
	                    o = c[(c[g >> 2] | 0) + 36 >> 2] | 0;
	                    if ((b | 0) == 10) {
	                        m = o + 28 | 0;
	                        c[m >> 2] = (c[m >> 2] | 0) + 1;
	                        c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                    } else {
	                        m = o + 32 | 0;
	                        c[m >> 2] = (c[m >> 2] | 0) + 1
	                    }
	                    m = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[m >> 2] = (c[m >> 2] | 0) + 1;
	                    m = (c[g >> 2] | 0) + 200 | 0;
	                    c[m >> 2] = (c[m >> 2] | 0) + 1;
	                    if (!(d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0))ke(c[(c[g >> 2] | 0) + 36 >> 2] | 0, 250) | 0
	                } while (0);
	                if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37 ? (c[(c[g >> 2] | 0) + 32 >> 2] | 0) == 0 : 0)We(c[g >> 2] | 0);
	                if (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) {
	                    i = e;
	                    return
	                }
	                if ((ke(c[(c[g >> 2] | 0) + 36 >> 2] | 0, 250) | 0) > 0) {
	                    i = e;
	                    return
	                }
	                Ve(c[g >> 2] | 0) | 0;
	                i = e;
	                return
	            }

	            function ne(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                f = i;
	                i = i + 192 | 0;
	                g = f;
	                h = f + 32 | 0;
	                j = f + 28 | 0;
	                k = f + 24 | 0;
	                l = f + 20 | 0;
	                m = f + 186 | 0;
	                n = f + 16 | 0;
	                o = f + 36 | 0;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                if (!((c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0) ? (c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) {
	                    if ((c[(c[j >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                        c[h >> 2] = 0;
	                        p = c[h >> 2] | 0;
	                        i = f;
	                        return p | 0
	                    }
	                    if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) >= 32 ? (d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 127 : 0) {
	                        c[c[k >> 2] >> 2] = 1;
	                        c[h >> 2] = d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0];
	                        p = c[h >> 2] | 0;
	                        i = f;
	                        return p | 0
	                    }
	                    if ((c[(c[j >> 2] | 0) + 256 >> 2] | 0) != 1) {
	                        c[c[k >> 2] >> 2] = 1;
	                        e = c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0;
	                        if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13) {
	                            c[h >> 2] = d[e >> 0];
	                            p = c[h >> 2] | 0;
	                            i = f;
	                            return p | 0
	                        }
	                        if ((d[e + 1 >> 0] | 0 | 0) == 10) {
	                            e = (c[j >> 2] | 0) + 200 | 0;
	                            c[e >> 2] = (c[e >> 2] | 0) + 1;
	                            e = (c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                            c[e >> 2] = (c[e >> 2] | 0) + 1
	                        }
	                        c[h >> 2] = 10;
	                        p = c[h >> 2] | 0;
	                        i = f;
	                        return p | 0
	                    }
	                    c[l >> 2] = c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                    a[m >> 0] = a[c[l >> 2] >> 0] | 0;
	                    if (!((d[m >> 0] | 0) & 128)) {
	                        c[c[k >> 2] >> 2] = 1;
	                        if (!(d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0))ke(c[(c[j >> 2] | 0) + 36 >> 2] | 0, 250) | 0;
	                        if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) >>> 0 > (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) >>> 0 : 0)Ie(c[j >> 2] | 0, 9, 64248, 0);
	                        e = c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0;
	                        if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13) {
	                            c[h >> 2] = d[e >> 0];
	                            p = c[h >> 2] | 0;
	                            i = f;
	                            return p | 0
	                        }
	                        if ((d[e + 1 >> 0] | 0 | 0) == 10) {
	                            e = (c[j >> 2] | 0) + 200 | 0;
	                            c[e >> 2] = (c[e >> 2] | 0) + 1;
	                            e = (c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                            c[e >> 2] = (c[e >> 2] | 0) + 1
	                        }
	                        c[h >> 2] = 10;
	                        p = c[h >> 2] | 0;
	                        i = f;
	                        return p | 0
	                    }
	                    a:do if (((d[m >> 0] | 0) & 64 | 0) != 0 ? (d[m >> 0] | 0 | 0) != 192 : 0) {
	                        if (!(d[(c[l >> 2] | 0) + 1 >> 0] | 0)) {
	                            ke(c[(c[j >> 2] | 0) + 36 >> 2] | 0, 250) | 0;
	                            c[l >> 2] = c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2]
	                        }
	                        if (((d[(c[l >> 2] | 0) + 1 >> 0] | 0) & 192 | 0) == 128) {
	                            do if (((d[m >> 0] | 0) & 224 | 0) == 224) {
	                                if (!(d[(c[l >> 2] | 0) + 2 >> 0] | 0)) {
	                                    ke(c[(c[j >> 2] | 0) + 36 >> 2] | 0, 250) | 0;
	                                    c[l >> 2] = c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2]
	                                }
	                                if (((d[(c[l >> 2] | 0) + 2 >> 0] | 0) & 192 | 0) != 128)break a;
	                                if (((d[m >> 0] | 0) & 240 | 0) != 240) {
	                                    c[c[k >> 2] >> 2] = 3;
	                                    c[n >> 2] = ((d[c[l >> 2] >> 0] | 0) & 15) << 12;
	                                    c[n >> 2] = c[n >> 2] | ((d[(c[l >> 2] | 0) + 1 >> 0] | 0) & 63) << 6;
	                                    c[n >> 2] = c[n >> 2] | (d[(c[l >> 2] | 0) + 2 >> 0] | 0) & 63;
	                                    if ((c[n >> 2] | 0) >>> 0 < 2048)break a; else break
	                                }
	                                if (!(d[(c[l >> 2] | 0) + 3 >> 0] | 0)) {
	                                    ke(c[(c[j >> 2] | 0) + 36 >> 2] | 0, 250) | 0;
	                                    c[l >> 2] = c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2]
	                                }
	                                if (((d[m >> 0] | 0) & 248 | 0) != 240)break a;
	                                if (((d[(c[l >> 2] | 0) + 3 >> 0] | 0) & 192 | 0) != 128)break a;
	                                c[c[k >> 2] >> 2] = 4;
	                                c[n >> 2] = ((d[c[l >> 2] >> 0] | 0) & 7) << 18;
	                                c[n >> 2] = c[n >> 2] | ((d[(c[l >> 2] | 0) + 1 >> 0] | 0) & 63) << 12;
	                                c[n >> 2] = c[n >> 2] | ((d[(c[l >> 2] | 0) + 2 >> 0] | 0) & 63) << 6;
	                                c[n >> 2] = c[n >> 2] | (d[(c[l >> 2] | 0) + 3 >> 0] | 0) & 63;
	                                if ((c[n >> 2] | 0) >>> 0 < 65536)break a
	                            } else {
	                                c[c[k >> 2] >> 2] = 2;
	                                c[n >> 2] = ((d[c[l >> 2] >> 0] | 0) & 31) << 6;
	                                c[n >> 2] = c[n >> 2] | (d[(c[l >> 2] | 0) + 1 >> 0] | 0) & 63;
	                                if ((c[n >> 2] | 0) >>> 0 < 128)break a
	                            } while (0);
	                            e = c[n >> 2] | 0;
	                            if ((c[n >> 2] | 0) >>> 0 < 256) {
	                                if (!(9 <= e >>> 0 & (c[n >> 2] | 0) >>> 0 <= 10 | (c[n >> 2] | 0) == 13 | 32 <= (c[n >> 2] | 0) >>> 0))q = 33
	                            } else if ((!(256 <= e >>> 0 & (c[n >> 2] | 0) >>> 0 <= 55295) ? !(57344 <= (c[n >> 2] | 0) >>> 0 & (c[n >> 2] | 0) >>> 0 <= 65533) : 0) ? !(65536 <= (c[n >> 2] | 0) >>> 0 & (c[n >> 2] | 0) >>> 0 <= 1114111) : 0)q = 33;
	                            if ((q | 0) == 33)Ie(c[j >> 2] | 0, 9, 64072, c[n >> 2] | 0);
	                            c[h >> 2] = c[n >> 2];
	                            p = c[h >> 2] | 0;
	                            i = f;
	                            return p | 0
	                        }
	                    } while (0);
	                    if (((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 4) {
	                        c[c[k >> 2] >> 2] = 0;
	                        c[h >> 2] = 0;
	                        p = c[h >> 2] | 0;
	                        i = f;
	                        return p | 0
	                    } else {
	                        n = d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0;
	                        q = d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0;
	                        l = d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0;
	                        c[g >> 2] = d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0];
	                        c[g + 4 >> 2] = n;
	                        c[g + 8 >> 2] = q;
	                        c[g + 12 >> 2] = l;
	                        JT(o, 149, 64152, g) | 0;
	                        je(c[j >> 2] | 0, 9, 64192, o, 0);
	                        c[(c[j >> 2] | 0) + 256 >> 2] = 10;
	                        c[c[k >> 2] >> 2] = 1;
	                        c[h >> 2] = d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0];
	                        p = c[h >> 2] | 0;
	                        i = f;
	                        return p | 0
	                    }
	                }
	                c[h >> 2] = 0;
	                p = c[h >> 2] | 0;
	                i = f;
	                return p | 0
	            }

	            function oe(b, e, f) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                g = i;
	                i = i + 192 | 0;
	                h = g;
	                j = g + 32 | 0;
	                k = g + 28 | 0;
	                l = g + 24 | 0;
	                m = g + 20 | 0;
	                n = g + 186 | 0;
	                o = g + 16 | 0;
	                p = g + 36 | 0;
	                c[k >> 2] = b;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                if ((c[m >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0) {
	                    c[j >> 2] = 0;
	                    q = c[j >> 2] | 0;
	                    i = g;
	                    return q | 0
	                }
	                if ((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 256 >> 2] | 0) != 1 : 0) {
	                    c[c[m >> 2] >> 2] = 1;
	                    c[j >> 2] = d[c[l >> 2] >> 0];
	                    q = c[j >> 2] | 0;
	                    i = g;
	                    return q | 0
	                }
	                a[n >> 0] = a[c[l >> 2] >> 0] | 0;
	                if (!((d[n >> 0] | 0) & 128)) {
	                    c[c[m >> 2] >> 2] = 1;
	                    c[j >> 2] = d[c[l >> 2] >> 0];
	                    q = c[j >> 2] | 0;
	                    i = g;
	                    return q | 0
	                }
	                a:do if (((d[(c[l >> 2] | 0) + 1 >> 0] | 0) & 192 | 0) == 128) {
	                    do if (((d[n >> 0] | 0) & 224 | 0) == 224) {
	                        if (((d[(c[l >> 2] | 0) + 2 >> 0] | 0) & 192 | 0) != 128)break a;
	                        if (((d[n >> 0] | 0) & 240 | 0) != 240) {
	                            c[c[m >> 2] >> 2] = 3;
	                            c[o >> 2] = ((d[c[l >> 2] >> 0] | 0) & 15) << 12;
	                            c[o >> 2] = c[o >> 2] | ((d[(c[l >> 2] | 0) + 1 >> 0] | 0) & 63) << 6;
	                            c[o >> 2] = c[o >> 2] | (d[(c[l >> 2] | 0) + 2 >> 0] | 0) & 63;
	                            break
	                        }
	                        if (((d[n >> 0] | 0) & 248 | 0) != 240)break a;
	                        if (((d[(c[l >> 2] | 0) + 3 >> 0] | 0) & 192 | 0) != 128)break a;
	                        c[c[m >> 2] >> 2] = 4;
	                        c[o >> 2] = ((d[c[l >> 2] >> 0] | 0) & 7) << 18;
	                        c[o >> 2] = c[o >> 2] | ((d[(c[l >> 2] | 0) + 1 >> 0] | 0) & 63) << 12;
	                        c[o >> 2] = c[o >> 2] | ((d[(c[l >> 2] | 0) + 2 >> 0] | 0) & 63) << 6;
	                        c[o >> 2] = c[o >> 2] | (d[(c[l >> 2] | 0) + 3 >> 0] | 0) & 63
	                    } else {
	                        c[c[m >> 2] >> 2] = 2;
	                        c[o >> 2] = ((d[c[l >> 2] >> 0] | 0) & 31) << 6;
	                        c[o >> 2] = c[o >> 2] | (d[(c[l >> 2] | 0) + 1 >> 0] | 0) & 63
	                    } while (0);
	                    f = c[o >> 2] | 0;
	                    if ((c[o >> 2] | 0) >>> 0 < 256) {
	                        if (!(9 <= f >>> 0 & (c[o >> 2] | 0) >>> 0 <= 10 | (c[o >> 2] | 0) == 13 | 32 <= (c[o >> 2] | 0) >>> 0))r = 20
	                    } else if ((!(256 <= f >>> 0 & (c[o >> 2] | 0) >>> 0 <= 55295) ? !(57344 <= (c[o >> 2] | 0) >>> 0 & (c[o >> 2] | 0) >>> 0 <= 65533) : 0) ? !(65536 <= (c[o >> 2] | 0) >>> 0 & (c[o >> 2] | 0) >>> 0 <= 1114111) : 0)r = 20;
	                    if ((r | 0) == 20)Ie(c[k >> 2] | 0, 9, 64072, c[o >> 2] | 0);
	                    c[j >> 2] = c[o >> 2];
	                    q = c[j >> 2] | 0;
	                    i = g;
	                    return q | 0
	                } while (0);
	                if (((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? ((c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) >= 4 : 0) {
	                    o = d[(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0;
	                    r = d[(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0;
	                    n = d[(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0;
	                    c[h >> 2] = d[c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0];
	                    c[h + 4 >> 2] = o;
	                    c[h + 8 >> 2] = r;
	                    c[h + 12 >> 2] = n;
	                    JT(p, 149, 64152, h) | 0;
	                    je(c[k >> 2] | 0, 9, 64192, p, 0);
	                    c[c[m >> 2] >> 2] = 1;
	                    c[j >> 2] = d[c[l >> 2] >> 0];
	                    q = c[j >> 2] | 0;
	                    i = g;
	                    return q | 0
	                }
	                c[c[m >> 2] >> 2] = 0;
	                c[j >> 2] = 0;
	                q = c[j >> 2] | 0;
	                i = g;
	                return q | 0
	            }

	            function pe(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                if ((c[h >> 2] | 0) < 128) {
	                    a[c[g >> 2] >> 0] = c[h >> 2];
	                    c[f >> 2] = 1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[j >> 2] = c[g >> 2];
	                d = c[h >> 2] | 0;
	                do if ((c[h >> 2] | 0) < 2048) {
	                    b = c[g >> 2] | 0;
	                    c[g >> 2] = b + 1;
	                    a[b >> 0] = d >> 6 | 192;
	                    c[k >> 2] = 0
	                } else {
	                    b = c[h >> 2] | 0;
	                    if ((d | 0) < 65536) {
	                        m = c[g >> 2] | 0;
	                        c[g >> 2] = m + 1;
	                        a[m >> 0] = b >> 12 | 224;
	                        c[k >> 2] = 6;
	                        break
	                    }
	                    m = c[h >> 2] | 0;
	                    if ((b | 0) < 1114112) {
	                        b = c[g >> 2] | 0;
	                        c[g >> 2] = b + 1;
	                        a[b >> 0] = m >> 18 | 240;
	                        c[k >> 2] = 12;
	                        break
	                    }
	                    Ie(0, 9, 64280, m);
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } while (0);
	                while (1) {
	                    if ((c[k >> 2] | 0) < 0)break;
	                    d = (c[h >> 2] >> c[k >> 2] & 63 | 128) & 255;
	                    m = c[g >> 2] | 0;
	                    c[g >> 2] = m + 1;
	                    a[m >> 0] = d;
	                    c[k >> 2] = (c[k >> 2] | 0) - 6
	                }
	                c[f >> 2] = (c[g >> 2] | 0) - (c[j >> 2] | 0);
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function qe(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 12 | 0;
	                h = f + 4 | 0;
	                j = f;
	                c[f + 8 >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = e;
	                do if (c[h >> 2] | 0)if ((c[j >> 2] | 0) >= 128) {
	                    c[g >> 2] = pe(c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                    break
	                } else {
	                    a[c[h >> 2] >> 0] = c[j >> 2];
	                    c[g >> 2] = 1;
	                    break
	                } else c[g >> 2] = 0; while (0);
	                i = f;
	                return c[g >> 2] | 0
	            }

	            function re(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[k >> 2] = -1;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = -1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                switch (c[h >> 2] | 0) {
	                    case 1:
	                    {
	                        c[(c[g >> 2] | 0) + 256 >> 2] = 1;
	                        if ((((c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 ? (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 239 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 187 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 191 : 0) {
	                            b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                            c[b >> 2] = (c[b >> 2] | 0) + 3
	                        }
	                        c[f >> 2] = 0;
	                        l = c[f >> 2] | 0;
	                        i = e;
	                        return l | 0
	                    }
	                    case 21:
	                    case 20:
	                    case 19:
	                    case 22:
	                    case 18:
	                    case 17:
	                    case 16:
	                    case 15:
	                    case 14:
	                    case 13:
	                    case 12:
	                    case 11:
	                    case 10:
	                    case 6:
	                    {
	                        c[k >> 2] = 45;
	                        break
	                    }
	                    case -1:
	                    {
	                        je(c[g >> 2] | 0, 31, 64336, 0, 0);
	                        c[f >> 2] = -1;
	                        l = c[f >> 2] | 0;
	                        i = e;
	                        return l | 0
	                    }
	                    case 0:
	                    {
	                        c[(c[g >> 2] | 0) + 256 >> 2] = 1;
	                        c[f >> 2] = 0;
	                        l = c[f >> 2] | 0;
	                        i = e;
	                        return l | 0
	                    }
	                    case 9:
	                    {
	                        c[k >> 2] = 90;
	                        break
	                    }
	                    case 8:
	                    case 7:
	                    case 4:
	                    case 5:
	                    {
	                        c[k >> 2] = 180;
	                        break
	                    }
	                    case 3:
	                    case 2:
	                    {
	                        if (((((c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) != 0 : 0) ? (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 239 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 187 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 191 : 0) {
	                            b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                            c[b >> 2] = (c[b >> 2] | 0) + 3
	                        }
	                        c[k >> 2] = 90;
	                        break
	                    }
	                    default:
	                    {
	                    }
	                }
	                c[j >> 2] = Cd(c[h >> 2] | 0) | 0;
	                a:do if (!(c[j >> 2] | 0))do switch (c[h >> 2] | 0) {
	                    case 8:
	                    {
	                        je(c[g >> 2] | 0, 32, 64360, 64456, 0);
	                        break a;
	                        break
	                    }
	                    case 9:
	                    {
	                        je(c[g >> 2] | 0, 32, 64360, 64472, 0);
	                        break a;
	                        break
	                    }
	                    case 7:
	                    {
	                        je(c[g >> 2] | 0, 32, 64360, 64440, 0);
	                        break a;
	                        break
	                    }
	                    case 18:
	                    case 17:
	                    case 16:
	                    case 15:
	                    case 14:
	                    case 13:
	                    case 12:
	                    case 11:
	                    case 10:
	                    {
	                        if ((((c[(c[g >> 2] | 0) + 40 >> 2] | 0) == 1 ? (c[(c[g >> 2] | 0) + 24 >> 2] | 0) == 0 : 0) ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 44 >> 2] | 0) != 0 : 0) {
	                            b = my(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 44 >> 2] | 0) | 0;
	                            c[(c[g >> 2] | 0) + 24 >> 2] = b
	                        }
	                        c[(c[g >> 2] | 0) + 256 >> 2] = c[h >> 2];
	                        c[f >> 2] = 0;
	                        l = c[f >> 2] | 0;
	                        i = e;
	                        return l | 0
	                    }
	                    case 19:
	                    {
	                        je(c[g >> 2] | 0, 32, 64360, 64480, 0);
	                        break a;
	                        break
	                    }
	                    case 20:
	                    {
	                        je(c[g >> 2] | 0, 32, 64360, 64496, 0);
	                        break a;
	                        break
	                    }
	                    case 22:
	                    {
	                        c[(c[g >> 2] | 0) + 256 >> 2] = 1;
	                        c[f >> 2] = 0;
	                        l = c[f >> 2] | 0;
	                        i = e;
	                        return l | 0
	                    }
	                    case 4:
	                    {
	                        je(c[g >> 2] | 0, 32, 64360, 64392, 0);
	                        break a;
	                        break
	                    }
	                    case 5:
	                    {
	                        je(c[g >> 2] | 0, 32, 64360, 64416, 0);
	                        break a;
	                        break
	                    }
	                    case 21:
	                    {
	                        je(c[g >> 2] | 0, 32, 64360, 64512, 0);
	                        break a;
	                        break
	                    }
	                    case 6:
	                    {
	                        je(c[g >> 2] | 0, 32, 64360, 64432, 0);
	                        break a;
	                        break
	                    }
	                    default:
	                        break a
	                } while (0); while (0);
	                if (!(c[j >> 2] | 0)) {
	                    c[f >> 2] = -1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } else {
	                    c[(c[g >> 2] | 0) + 256 >> 2] = 1;
	                    c[f >> 2] = Je(c[g >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                return 0
	            }

	            function se(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                b = Je(c[e >> 2] | 0, c[f >> 2] | 0, -1) | 0;
	                i = d;
	                return b | 0
	            }

	            function te(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 4 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 4 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 8 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 44 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 44 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 48 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 48 >> 2] | 0);
	                if ((c[(c[d >> 2] | 0) + 40 >> 2] | 0) != 0 ? (c[(c[d >> 2] | 0) + 12 >> 2] | 0) != 0 : 0)zb[c[(c[d >> 2] | 0) + 40 >> 2] & 511](c[(c[d >> 2] | 0) + 12 >> 2] | 0);
	                if (c[c[d >> 2] >> 2] | 0)yk(c[c[d >> 2] >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function ue(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](60) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    ie(c[e >> 2] | 0, 64520);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = (c[f >> 2] | 0) + 0 | 0;
	                h = a + 60 | 0;
	                do {
	                    c[a >> 2] = 0;
	                    a = a + 4 | 0
	                } while ((a | 0) < (h | 0));
	                c[(c[f >> 2] | 0) + 28 >> 2] = 1;
	                c[(c[f >> 2] | 0) + 32 >> 2] = 1;
	                c[(c[f >> 2] | 0) + 52 >> 2] = -1;
	                if (c[e >> 2] | 0) {
	                    a = (c[e >> 2] | 0) + 464 | 0;
	                    e = c[a >> 2] | 0;
	                    c[a >> 2] = e + 1;
	                    c[(c[f >> 2] | 0) + 56 >> 2] = e
	                }
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function ve(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                if (c[33952] | 0)Db[c[135904 >> 2] & 511](c[33980] | 0, 64560, e);
	                c[k >> 2] = ue(c[g >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[(c[k >> 2] | 0) + 4 >> 2] = 0;
	                c[c[k >> 2] >> 2] = c[h >> 2];
	                iz(c[(c[c[k >> 2] >> 2] | 0) + 16 >> 2] | 0, c[k >> 2] | 0) | 0;
	                if (c[j >> 2] | 0)re(c[g >> 2] | 0, c[j >> 2] | 0) | 0;
	                c[f >> 2] = c[k >> 2];
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function we(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                if (!(c[h >> 2] | 0)) {
	                    Le(c[g >> 2] | 0, 64584, 0);
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                if (c[33952] | 0) {
	                    b = c[33976] | 0;
	                    a = c[33980] | 0;
	                    c[e >> 2] = c[(c[h >> 2] | 0) + 8 >> 2];
	                    Db[b & 511](a, 64624, e)
	                }
	                if (c[(c[h >> 2] | 0) + 40 >> 2] | 0) {
	                    c[j >> 2] = ue(c[g >> 2] | 0) | 0;
	                    if (!(c[j >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        k = c[f >> 2] | 0;
	                        i = d;
	                        return k | 0
	                    }
	                    if (c[(c[h >> 2] | 0) + 64 >> 2] | 0) {
	                        e = my(c[(c[h >> 2] | 0) + 64 >> 2] | 0) | 0;
	                        c[(c[j >> 2] | 0) + 4 >> 2] = e
	                    }
	                    c[(c[j >> 2] | 0) + 12 >> 2] = c[(c[h >> 2] | 0) + 40 >> 2];
	                    c[(c[j >> 2] | 0) + 16 >> 2] = c[(c[h >> 2] | 0) + 40 >> 2];
	                    c[(c[j >> 2] | 0) + 24 >> 2] = c[(c[h >> 2] | 0) + 44 >> 2];
	                    c[(c[j >> 2] | 0) + 20 >> 2] = (c[(c[h >> 2] | 0) + 40 >> 2] | 0) + (c[(c[j >> 2] | 0) + 24 >> 2] | 0);
	                    c[f >> 2] = c[j >> 2];
	                    k = c[f >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                switch (c[(c[h >> 2] | 0) + 48 >> 2] | 0) {
	                    case 4:
	                    {
	                        Le(c[g >> 2] | 0, 64720, c[(c[h >> 2] | 0) + 8 >> 2] | 0);
	                        break
	                    }
	                    case 1:
	                    {
	                        Le(c[g >> 2] | 0, 64680, c[(c[h >> 2] | 0) + 8 >> 2] | 0);
	                        break
	                    }
	                    case 6:
	                    {
	                        Le(c[g >> 2] | 0, 64768, c[(c[h >> 2] | 0) + 8 >> 2] | 0);
	                        break
	                    }
	                    case 3:
	                    {
	                        Le(c[g >> 2] | 0, 64656, c[(c[h >> 2] | 0) + 8 >> 2] | 0);
	                        break
	                    }
	                    case 5:
	                    case 2:
	                    {
	                        c[f >> 2] = Vk(c[(c[h >> 2] | 0) + 64 >> 2] | 0, c[(c[h >> 2] | 0) + 52 >> 2] | 0, c[g >> 2] | 0) | 0;
	                        k = c[f >> 2] | 0;
	                        i = d;
	                        return k | 0
	                    }
	                    default:
	                    {
	                    }
	                }
	                c[f >> 2] = 0;
	                k = c[f >> 2] | 0;
	                i = d;
	                return k | 0
	            }

	            function xe(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 28 | 0;
	                g = d + 24 | 0;
	                h = d + 20 | 0;
	                j = d + 16 | 0;
	                k = d + 12 | 0;
	                l = d + 8 | 0;
	                m = d + 4 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[l >> 2] = 0;
	                c[m >> 2] = 0;
	                if (c[33952] | 0) {
	                    b = c[33976] | 0;
	                    a = c[33980] | 0;
	                    c[e >> 2] = c[h >> 2];
	                    Db[b & 511](a, 64808, e)
	                }
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                c[j >> 2] = Ck(c[h >> 2] | 0, 0) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    e = c[g >> 2] | 0;
	                    if (!(c[h >> 2] | 0))ik(e, 64840, 0); else ik(e, 64888, c[h >> 2] | 0);
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                c[k >> 2] = ue(c[g >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                c[c[k >> 2] >> 2] = c[j >> 2];
	                c[k >> 2] = Sk(c[g >> 2] | 0, c[k >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                if (!(c[(c[k >> 2] | 0) + 4 >> 2] | 0))c[m >> 2] = my(c[h >> 2] | 0) | 0; else c[m >> 2] = my(c[(c[k >> 2] | 0) + 4 >> 2] | 0) | 0;
	                c[l >> 2] = Rk(c[m >> 2] | 0) | 0;
	                if (c[(c[k >> 2] | 0) + 4 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[k >> 2] | 0) + 4 >> 2] | 0);
	                h = Jl(c[m >> 2] | 0) | 0;
	                c[(c[k >> 2] | 0) + 4 >> 2] = h;
	                if (c[m >> 2] | 0)zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                c[(c[k >> 2] | 0) + 8 >> 2] = c[l >> 2];
	                iz(c[(c[c[k >> 2] >> 2] | 0) + 16 >> 2] | 0, c[k >> 2] | 0) | 0;
	                if ((c[l >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 180 >> 2] | 0) == 0 : 0) {
	                    m = my(c[l >> 2] | 0) | 0;
	                    c[(c[g >> 2] | 0) + 180 >> 2] = m
	                }
	                c[f >> 2] = c[k >> 2];
	                n = c[f >> 2] | 0;
	                i = d;
	                return n | 0
	            }

	            function ye(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    Le(0, 64928, 0);
	                    c[d >> 2] = -1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                pQ();
	                if (!(c[(c[e >> 2] | 0) + 296 >> 2] | 0)) {
	                    a = xP() | 0;
	                    c[(c[e >> 2] | 0) + 296 >> 2] = a
	                }
	                if (!(c[(c[e >> 2] | 0) + 296 >> 2] | 0)) {
	                    ie(0, 64960);
	                    c[d >> 2] = -1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                DP(c[(c[e >> 2] | 0) + 296 >> 2] | 0, 1e7) | 0;
	                if (!(c[c[e >> 2] >> 2] | 0)) {
	                    a = Cb[c[135744 >> 2] & 511](128) | 0;
	                    c[c[e >> 2] >> 2] = a
	                }
	                if (!(c[c[e >> 2] >> 2] | 0)) {
	                    ie(0, 64960);
	                    c[d >> 2] = -1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                oQ(c[c[e >> 2] >> 2] | 0, 2) | 0;
	                c[(c[e >> 2] | 0) + 304 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 300 >> 2] = 0;
	                if (!(c[(c[e >> 2] | 0) + 48 >> 2] | 0)) {
	                    a = Cb[c[135744 >> 2] & 511](20) | 0;
	                    c[(c[e >> 2] | 0) + 48 >> 2] = a;
	                    c[(c[e >> 2] | 0) + 44 >> 2] = 5
	                }
	                if (!(c[(c[e >> 2] | 0) + 48 >> 2] | 0)) {
	                    ie(0, 64960);
	                    c[(c[e >> 2] | 0) + 40 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 44 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 36 >> 2] = 0;
	                    c[d >> 2] = -1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                while (1) {
	                    a = Pe(c[e >> 2] | 0) | 0;
	                    c[f >> 2] = a;
	                    if (!a)break;
	                    te(c[f >> 2] | 0)
	                }
	                c[(c[e >> 2] | 0) + 40 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 36 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 20 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 24 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 28 >> 2] = -1;
	                c[(c[e >> 2] | 0) + 88 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 92 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 32 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 96 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 172 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 176 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 180 >> 2] = 0;
	                if (!(c[(c[e >> 2] | 0) + 64 >> 2] | 0)) {
	                    f = Cb[c[135744 >> 2] & 511](40) | 0;
	                    c[(c[e >> 2] | 0) + 64 >> 2] = f;
	                    c[(c[e >> 2] | 0) + 60 >> 2] = 10
	                }
	                if (!(c[(c[e >> 2] | 0) + 64 >> 2] | 0)) {
	                    ie(0, 64960);
	                    c[(c[e >> 2] | 0) + 56 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 60 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 52 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 40 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 44 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 36 >> 2] = 0;
	                    c[d >> 2] = -1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[(c[e >> 2] | 0) + 56 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 52 >> 2] = 0;
	                if (!(c[(c[e >> 2] | 0) + 196 >> 2] | 0)) {
	                    f = Cb[c[135744 >> 2] & 511](40) | 0;
	                    c[(c[e >> 2] | 0) + 196 >> 2] = f;
	                    c[(c[e >> 2] | 0) + 192 >> 2] = 10
	                }
	                if (!(c[(c[e >> 2] | 0) + 196 >> 2] | 0)) {
	                    ie(0, 64960);
	                    c[(c[e >> 2] | 0) + 56 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 60 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 52 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 40 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 44 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 36 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 188 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 192 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 184 >> 2] = 0;
	                    c[d >> 2] = -1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[(c[e >> 2] | 0) + 188 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 184 >> 2] = 0;
	                if (!(c[(c[e >> 2] | 0) + 244 >> 2] | 0)) {
	                    f = Cb[c[135744 >> 2] & 511](40) | 0;
	                    c[(c[e >> 2] | 0) + 244 >> 2] = f;
	                    c[(c[e >> 2] | 0) + 240 >> 2] = 10
	                }
	                if (!(c[(c[e >> 2] | 0) + 244 >> 2] | 0)) {
	                    ie(0, 64960);
	                    c[(c[e >> 2] | 0) + 56 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 60 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 52 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 40 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 44 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 36 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 188 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 192 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 184 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 236 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 240 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 232 >> 2] = 0;
	                    c[d >> 2] = -1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[(c[e >> 2] | 0) + 236 >> 2] = 1;
	                c[(c[e >> 2] | 0) + 240 >> 2] = 10;
	                c[c[(c[e >> 2] | 0) + 244 >> 2] >> 2] = -1;
	                c[(c[e >> 2] | 0) + 232 >> 2] = c[(c[e >> 2] | 0) + 244 >> 2];
	                c[(c[e >> 2] | 0) + 4 >> 2] = c[e >> 2];
	                c[(c[e >> 2] | 0) + 8 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 12 >> 2] = 1;
	                c[(c[e >> 2] | 0) + 356 >> 2] = 1;
	                c[(c[e >> 2] | 0) + 100 >> 2] = 1;
	                c[(c[e >> 2] | 0) + 276 >> 2] = c[33958];
	                if (c[(c[e >> 2] | 0) + 276 >> 2] | 0) {
	                    f = (c[e >> 2] | 0) + 360 | 0;
	                    c[f >> 2] = c[f >> 2] | 4
	                }
	                c[(c[e >> 2] | 0) + 104 >> 2] = c[33954];
	                c[(c[e >> 2] | 0) + 268 >> 2] = c[33960];
	                if (c[(c[e >> 2] | 0) + 268 >> 2] | 0) {
	                    f = (c[e >> 2] | 0) + 360 | 0;
	                    c[f >> 2] = c[f >> 2] | 128
	                }
	                c[(c[e >> 2] | 0) + 280 >> 2] = c[33962];
	                c[(c[e >> 2] | 0) + 208 >> 2] = c[33964];
	                if (!(c[(c[e >> 2] | 0) + 208 >> 2] | 0)) {
	                    c[(c[c[e >> 2] >> 2] | 0) + 72 >> 2] = 65;
	                    f = (c[e >> 2] | 0) + 360 | 0;
	                    c[f >> 2] = c[f >> 2] | 256
	                }
	                c[(c[e >> 2] | 0) + 136 >> 2] = -1412623820;
	                c[(c[e >> 2] | 0) + 108 >> 2] = c[e >> 2];
	                c[(c[e >> 2] | 0) + 112 >> 2] = 224;
	                c[(c[e >> 2] | 0) + 116 >> 2] = 225;
	                if (c[(c[e >> 2] | 0) + 104 >> 2] | 0) {
	                    f = (c[e >> 2] | 0) + 116 | 0;
	                    if (!(c[33956] | 0))c[f >> 2] = 0; else c[f >> 2] = 225;
	                    c[(c[e >> 2] | 0) + 128 >> 2] = 0;
	                    f = (c[e >> 2] | 0) + 360 | 0;
	                    c[f >> 2] = c[f >> 2] | 16
	                }
	                c[(c[e >> 2] | 0) + 16 >> 2] = c[33966];
	                if (c[(c[e >> 2] | 0) + 16 >> 2] | 0) {
	                    f = (c[e >> 2] | 0) + 360 | 0;
	                    c[f >> 2] = c[f >> 2] | 2
	                }
	                c[(c[e >> 2] | 0) + 68 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 200 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 204 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 216 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 84 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 248 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 256 >> 2] = 1;
	                c[(c[e >> 2] | 0) + 284 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 440 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 444 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 468 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 464 >> 2] = 1;
	                ze((c[e >> 2] | 0) + 72 | 0);
	                c[d >> 2] = 0;
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function ze(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                c[(c[d >> 2] | 0) + 4 >> 2] = 0;
	                c[c[d >> 2] >> 2] = 0;
	                c[(c[d >> 2] | 0) + 8 >> 2] = 0;
	                i = b;
	                return
	            }

	            function Ae(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 20 | 0;
	                e = b + 16 | 0;
	                f = b + 12 | 0;
	                g = b + 8 | 0;
	                h = b + 4 | 0;
	                j = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                while (1) {
	                    a = Pe(c[d >> 2] | 0) | 0;
	                    c[e >> 2] = a;
	                    if (!a)break;
	                    te(c[e >> 2] | 0)
	                }
	                if (c[(c[d >> 2] | 0) + 244 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 244 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 196 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 196 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 64 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 64 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 460 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 460 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 48 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 48 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 20 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 20 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 24 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 24 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 224 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 224 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 228 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 228 >> 2] | 0);
	                if ((c[c[d >> 2] >> 2] | 0) != 0 ? (c[c[d >> 2] >> 2] | 0) != 135968 : 0)zb[c[135736 >> 2] & 511](c[c[d >> 2] >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 180 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 180 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 132 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 132 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 300 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 300 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 296 >> 2] | 0)zP(c[(c[d >> 2] | 0) + 296 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 336 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 336 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 344 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 344 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 340 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 340 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 348 >> 2] | 0)Kj(c[(c[d >> 2] | 0) + 348 >> 2] | 0, c[33934] | 0);
	                if (c[(c[d >> 2] | 0) + 352 >> 2] | 0)Kj(c[(c[d >> 2] | 0) + 352 >> 2] | 0, 0);
	                a:do if (c[(c[d >> 2] | 0) + 372 >> 2] | 0) {
	                    c[f >> 2] = c[(c[d >> 2] | 0) + 372 >> 2];
	                    while (1) {
	                        if (!(c[f >> 2] | 0))break a;
	                        c[g >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                        zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                        c[f >> 2] = c[g >> 2]
	                    }
	                } while (0);
	                b:do if (c[(c[d >> 2] | 0) + 380 >> 2] | 0) {
	                    c[h >> 2] = c[(c[d >> 2] | 0) + 380 >> 2];
	                    while (1) {
	                        if (!(c[h >> 2] | 0))break b;
	                        c[j >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                        zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                        c[h >> 2] = c[j >> 2]
	                    }
	                } while (0);
	                if (c[(c[d >> 2] | 0) + 392 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 392 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 400 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 400 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 408 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 408 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 412 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 412 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 416 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 416 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 284 >> 2] | 0)Hw(c[(c[d >> 2] | 0) + 284 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function Be() {
	                var a = 0, b = 0, d = 0, e = 0, f = 0;
	                a = i;
	                i = i + 16 | 0;
	                b = a + 4 | 0;
	                d = a;
	                c[d >> 2] = Cb[c[135744 >> 2] & 511](472) | 0;
	                do if (c[d >> 2] | 0) {
	                    cU(c[d >> 2] | 0, 0, 472) | 0;
	                    e = (ye(c[d >> 2] | 0) | 0) < 0;
	                    f = c[d >> 2] | 0;
	                    if (e) {
	                        Ae(f);
	                        c[b >> 2] = 0;
	                        break
	                    } else {
	                        c[b >> 2] = f;
	                        break
	                    }
	                } else {
	                    ie(0, 65e3);
	                    c[b >> 2] = 0
	                } while (0);
	                i = a;
	                return c[b >> 2] | 0
	            }

	            function Ce(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 24 | 0;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                l = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[l >> 2] = 0;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = -1;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                c[j >> 2] = 1;
	                c[h >> 2] = c[(c[f >> 2] | 0) + 4 >> 2];
	                c[k >> 2] = 0;
	                while (1) {
	                    if ((c[j >> 2] | 0) >>> 0 > (c[h >> 2] | 0) >>> 0)break;
	                    if (!((c[l >> 2] | 0) != 0 ^ 1))break;
	                    c[k >> 2] = (c[j >> 2] | 0) + ((((c[h >> 2] | 0) - (c[j >> 2] | 0) | 0) >>> 0) / 2 | 0);
	                    if ((c[g >> 2] | 0) == (c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + (((c[k >> 2] | 0) - 1 | 0) * 20 | 0) >> 2] | 0)) {
	                        c[l >> 2] = 1;
	                        continue
	                    }
	                    b = c[k >> 2] | 0;
	                    if ((c[g >> 2] | 0) >>> 0 < (c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + (((c[k >> 2] | 0) - 1 | 0) * 20 | 0) >> 2] | 0) >>> 0) {
	                        c[h >> 2] = b - 1;
	                        continue
	                    } else {
	                        c[j >> 2] = b + 1;
	                        continue
	                    }
	                }
	                if ((c[k >> 2] | 0) != 0 ? (c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + (((c[k >> 2] | 0) - 1 | 0) * 20 | 0) >> 2] | 0) >>> 0 >= (c[g >> 2] | 0) >>> 0 : 0) {
	                    c[e >> 2] = (c[k >> 2] | 0) - 1;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                c[e >> 2] = c[k >> 2];
	                m = c[e >> 2] | 0;
	                i = d;
	                return m | 0
	            }

	            function De(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if ((c[e >> 2] | 0) == 0 | (c[f >> 2] | 0) == 0) {
	                    i = d;
	                    return
	                }
	                c[g >> 2] = Ce((c[e >> 2] | 0) + 72 | 0, c[c[f >> 2] >> 2] | 0) | 0;
	                if (((c[g >> 2] | 0) >>> 0 < (c[(c[e >> 2] | 0) + 76 >> 2] | 0) >>> 0 ? (c[(c[e >> 2] | 0) + 80 >> 2] | 0) != 0 : 0) ? (c[(c[(c[e >> 2] | 0) + 80 >> 2] | 0) + ((c[g >> 2] | 0) * 20 | 0) >> 2] | 0) == (c[c[f >> 2] >> 2] | 0) : 0) {
	                    b = (c[(c[e >> 2] | 0) + 80 >> 2] | 0) + ((c[g >> 2] | 0) * 20 | 0) | 0;
	                    a = c[f >> 2] | 0;
	                    c[b + 0 >> 2] = c[a + 0 >> 2];
	                    c[b + 4 >> 2] = c[a + 4 >> 2];
	                    c[b + 8 >> 2] = c[a + 8 >> 2];
	                    c[b + 12 >> 2] = c[a + 12 >> 2];
	                    c[b + 16 >> 2] = c[a + 16 >> 2];
	                    i = d;
	                    return
	                }
	                if (!(((c[(c[e >> 2] | 0) + 76 >> 2] | 0) + 1 | 0) >>> 0 <= (c[(c[e >> 2] | 0) + 72 >> 2] | 0) >>> 0 ? (c[(c[e >> 2] | 0) + 80 >> 2] | 0) != 0 : 0))l = 8;
	                do if ((l | 0) == 8) {
	                    if (!(c[(c[e >> 2] | 0) + 72 >> 2] | 0))c[(c[e >> 2] | 0) + 72 >> 2] = 2;
	                    c[j >> 2] = (c[(c[e >> 2] | 0) + 72 >> 2] << 1) * 20;
	                    if (!(c[(c[e >> 2] | 0) + 80 >> 2] | 0))c[h >> 2] = Cb[c[135744 >> 2] & 511](c[j >> 2] | 0) | 0; else c[h >> 2] = Hb[c[135760 >> 2] & 511](c[(c[e >> 2] | 0) + 80 >> 2] | 0, c[j >> 2] | 0) | 0;
	                    if (c[h >> 2] | 0) {
	                        c[(c[e >> 2] | 0) + 80 >> 2] = c[h >> 2];
	                        a = (c[e >> 2] | 0) + 72 | 0;
	                        c[a >> 2] = c[a >> 2] << 1;
	                        break
	                    }
	                    ie(c[e >> 2] | 0, 65032);
	                    i = d;
	                    return
	                } while (0);
	                a:do if ((c[g >> 2] | 0) != (c[(c[e >> 2] | 0) + 76 >> 2] | 0)) {
	                    c[k >> 2] = c[(c[e >> 2] | 0) + 76 >> 2];
	                    while (1) {
	                        if ((c[k >> 2] | 0) >>> 0 <= (c[g >> 2] | 0) >>> 0)break a;
	                        h = (c[(c[e >> 2] | 0) + 80 >> 2] | 0) + ((c[k >> 2] | 0) * 20 | 0) | 0;
	                        j = (c[(c[e >> 2] | 0) + 80 >> 2] | 0) + (((c[k >> 2] | 0) - 1 | 0) * 20 | 0) | 0;
	                        c[h + 0 >> 2] = c[j + 0 >> 2];
	                        c[h + 4 >> 2] = c[j + 4 >> 2];
	                        c[h + 8 >> 2] = c[j + 8 >> 2];
	                        c[h + 12 >> 2] = c[j + 12 >> 2];
	                        c[h + 16 >> 2] = c[j + 16 >> 2];
	                        c[k >> 2] = (c[k >> 2] | 0) + -1
	                    }
	                } while (0);
	                k = (c[(c[e >> 2] | 0) + 80 >> 2] | 0) + ((c[g >> 2] | 0) * 20 | 0) | 0;
	                g = c[f >> 2] | 0;
	                c[k + 0 >> 2] = c[g + 0 >> 2];
	                c[k + 4 >> 2] = c[g + 4 >> 2];
	                c[k + 8 >> 2] = c[g + 8 >> 2];
	                c[k + 12 >> 2] = c[g + 12 >> 2];
	                c[k + 16 >> 2] = c[g + 16 >> 2];
	                g = (c[e >> 2] | 0) + 76 | 0;
	                c[g >> 2] = (c[g >> 2] | 0) + 1;
	                i = d;
	                return
	            }

	            function Ee(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                c[e >> 2] = c[33960];
	                c[33960] = c[d >> 2];
	                i = b;
	                return c[e >> 2] | 0
	            }

	            function Fe(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                c[e >> 2] = c[33962];
	                c[33962] = c[d >> 2];
	                i = b;
	                return c[e >> 2] | 0
	            }

	            function Ge(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                c[e >> 2] = c[33966];
	                c[33966] = c[d >> 2];
	                i = b;
	                return c[e >> 2] | 0
	            }

	            function He(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                c[e >> 2] = c[33964];
	                c[33964] = c[d >> 2];
	                if (!(c[d >> 2] | 0))c[33984] = 1;
	                i = b;
	                return c[e >> 2] | 0
	            }

	            function Ie(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if (((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 212 >> 2] | 0) != 0 : 0) ? (c[(c[h >> 2] | 0) + 172 >> 2] | 0) == -1 : 0) {
	                    i = f;
	                    return
	                }
	                if (c[h >> 2] | 0)c[(c[h >> 2] | 0) + 84 >> 2] = c[j >> 2];
	                e = c[h >> 2] | 0;
	                d = c[j >> 2] | 0;
	                j = c[l >> 2] | 0;
	                b = c[k >> 2] | 0;
	                c[g >> 2] = c[l >> 2];
	                Xd(0, 0, 0, e, 0, 1, d, 3, 0, 0, 0, 0, 0, j, 0, b, g);
	                if (!(c[h >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                c[(c[h >> 2] | 0) + 12 >> 2] = 0;
	                if (c[(c[h >> 2] | 0) + 288 >> 2] | 0) {
	                    i = f;
	                    return
	                }
	                c[(c[h >> 2] | 0) + 212 >> 2] = 1;
	                i = f;
	                return
	            }

	            function Je(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = -1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                d = c[g >> 2] | 0;
	                if (c[(c[g >> 2] | 0) + 36 >> 2] | 0) {
	                    c[k >> 2] = Ke(d, c[(c[g >> 2] | 0) + 36 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                    c[(c[g >> 2] | 0) + 256 >> 2] = 1;
	                    c[f >> 2] = c[k >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } else {
	                    Le(d, 65064, 0);
	                    c[f >> 2] = -1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                return 0
	            }

	            function Ke(a, b, e, f) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 28 | 0;
	                j = g + 24 | 0;
	                k = g + 20 | 0;
	                l = g + 16 | 0;
	                m = g + 12 | 0;
	                n = g + 8 | 0;
	                o = g + 4 | 0;
	                p = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                if (!(c[l >> 2] | 0)) {
	                    c[h >> 2] = -1;
	                    q = c[h >> 2] | 0;
	                    i = g;
	                    return q | 0
	                }
	                if (!(c[k >> 2] | 0)) {
	                    c[h >> 2] = -1;
	                    q = c[h >> 2] | 0;
	                    i = g;
	                    return q | 0
	                }
	                f = c[k >> 2] | 0;
	                if (!(c[c[k >> 2] >> 2] | 0))if (!(c[f + 24 >> 2] | 0)) {
	                    Le(c[j >> 2] | 0, 65184, 0);
	                    c[h >> 2] = -1;
	                    q = c[h >> 2] | 0;
	                    i = g;
	                    return q | 0
	                } else {
	                    c[h >> 2] = 0;
	                    q = c[h >> 2] | 0;
	                    i = g;
	                    return q | 0
	                }
	                if (c[(c[f >> 2] | 0) + 12 >> 2] | 0)if ((c[(c[c[k >> 2] >> 2] | 0) + 12 >> 2] | 0) == (c[l >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    q = c[h >> 2] | 0;
	                    i = g;
	                    return q | 0
	                } else {
	                    Hd(c[(c[c[k >> 2] >> 2] | 0) + 12 >> 2] | 0) | 0;
	                    c[(c[c[k >> 2] >> 2] | 0) + 12 >> 2] = c[l >> 2];
	                    c[h >> 2] = 0;
	                    q = c[h >> 2] | 0;
	                    i = g;
	                    return q | 0
	                }
	                c[(c[c[k >> 2] >> 2] | 0) + 12 >> 2] = c[l >> 2];
	                do if (!(az(c[(c[c[k >> 2] >> 2] | 0) + 16 >> 2] | 0) | 0)) {
	                    do if (c[c[l >> 2] >> 2] | 0) {
	                        if ((PT(c[c[l >> 2] >> 2] | 0, 65096) | 0) != 0 ? (PT(c[c[l >> 2] >> 2] | 0, 65112) | 0) != 0 : 0)break;
	                        if ((d[c[(c[k >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 255 ? (d[(c[(c[k >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 254 : 0) {
	                            f = (c[k >> 2] | 0) + 16 | 0;
	                            c[f >> 2] = (c[f >> 2] | 0) + 2
	                        }
	                    } while (0);
	                    if ((((c[c[l >> 2] >> 2] | 0) != 0 ? (PT(c[c[l >> 2] >> 2] | 0, 65120) | 0) == 0 : 0) ? (d[c[(c[k >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 254 : 0) ? (d[(c[(c[k >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 255 : 0) {
	                        f = (c[k >> 2] | 0) + 16 | 0;
	                        c[f >> 2] = (c[f >> 2] | 0) + 2
	                    }
	                    if (((((c[c[l >> 2] >> 2] | 0) != 0 ? (PT(c[c[l >> 2] >> 2] | 0, 65136) | 0) == 0 : 0) ? (d[c[(c[k >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 239 : 0) ? (d[(c[(c[k >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 187 : 0) ? (d[(c[(c[k >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 191 : 0) {
	                        f = (c[k >> 2] | 0) + 16 | 0;
	                        c[f >> 2] = (c[f >> 2] | 0) + 3
	                    }
	                    c[o >> 2] = (c[(c[k >> 2] | 0) + 16 >> 2] | 0) - (c[(c[k >> 2] | 0) + 12 >> 2] | 0);
	                    Ty(c[(c[c[k >> 2] >> 2] | 0) + 16 >> 2] | 0, c[o >> 2] | 0) | 0;
	                    c[(c[c[k >> 2] >> 2] | 0) + 20 >> 2] = c[(c[c[k >> 2] >> 2] | 0) + 16 >> 2];
	                    f = Ly() | 0;
	                    c[(c[c[k >> 2] >> 2] | 0) + 16 >> 2] = f;
	                    c[(c[c[k >> 2] >> 2] | 0) + 32 >> 2] = c[o >> 2];
	                    c[p >> 2] = _y(c[(c[c[k >> 2] >> 2] | 0) + 20 >> 2] | 0) | 0;
	                    f = c[c[k >> 2] >> 2] | 0;
	                    if (c[(c[j >> 2] | 0) + 32 >> 2] | 0)c[n >> 2] = Fd(f, 1) | 0; else c[n >> 2] = Ed(f, c[m >> 2] | 0) | 0;
	                    if ((c[n >> 2] | 0) >= 0) {
	                        f = c[p >> 2] | 0;
	                        e = f - (_y(c[(c[c[k >> 2] >> 2] | 0) + 20 >> 2] | 0) | 0) | 0;
	                        f = (c[c[k >> 2] >> 2] | 0) + 32 | 0;
	                        c[f >> 2] = (c[f >> 2] | 0) + e;
	                        iz(c[(c[c[k >> 2] >> 2] | 0) + 16 >> 2] | 0, c[k >> 2] | 0) | 0;
	                        break
	                    }
	                    Le(c[j >> 2] | 0, 65144, 0);
	                    c[h >> 2] = -1;
	                    q = c[h >> 2] | 0;
	                    i = g;
	                    return q | 0
	                } while (0);
	                c[h >> 2] = 0;
	                q = c[h >> 2] | 0;
	                i = g;
	                return q | 0
	            }

	            function Le(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 212 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 172 >> 2] | 0) == -1 : 0) {
	                    i = e;
	                    return
	                }
	                if (c[g >> 2] | 0)c[(c[g >> 2] | 0) + 84 >> 2] = 1;
	                d = c[g >> 2] | 0;
	                b = c[j >> 2] | 0;
	                a = c[h >> 2] | 0;
	                c[f >> 2] = c[j >> 2];
	                Xd(0, 0, 0, d, 0, 1, 1, 3, 0, 0, b, 0, 0, 0, 0, a, f);
	                if (!(c[g >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                c[(c[g >> 2] | 0) + 12 >> 2] = 0;
	                if (c[(c[g >> 2] | 0) + 288 >> 2] | 0) {
	                    i = e;
	                    return
	                }
	                c[(c[g >> 2] | 0) + 212 >> 2] = 1;
	                i = e;
	                return
	            }

	            function Me(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                do switch (c[e >> 2] | 0) {
	                    case 21:
	                    {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    case 18:
	                    {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    case 30:
	                    {
	                        c[d >> 2] = 0;
	                        break
	                    }
	                    case 29:
	                    {
	                        c[d >> 2] = 0;
	                        break
	                    }
	                    case 33:
	                    {
	                        c[d >> 2] = 0;
	                        break
	                    }
	                    case 10:
	                    {
	                        c[d >> 2] = 0;
	                        break
	                    }
	                    case 16:
	                    {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    case 14:
	                    {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    case 28:
	                    {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    case 8:
	                    {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    case 15:
	                    {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    case 27:
	                    {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    case 13:
	                    {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    case 20:
	                    {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    case 3:
	                    {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    case 17:
	                    {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    case 4:
	                    {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    case 12:
	                    {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    case 2:
	                    {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    case 11:
	                    {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    case 19:
	                    {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    case 9:
	                    {
	                        c[d >> 2] = 0;
	                        break
	                    }
	                    case 24:
	                    {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    case 26:
	                    {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    case 1:
	                    {
	                        c[d >> 2] = 0;
	                        break
	                    }
	                    case 22:
	                    {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    case 5:
	                    {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    case 23:
	                    {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    case 32:
	                    {
	                        c[d >> 2] = 0;
	                        break
	                    }
	                    case 25:
	                    {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    case 6:
	                    {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    case 31:
	                    {
	                        c[d >> 2] = 0;
	                        break
	                    }
	                    case 7:
	                    {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    default:
	                        c[d >> 2] = 0
	                } while (0);
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function Ne(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                g = b + 4 | 0;
	                h = b;
	                c[f >> 2] = a;
	                c[g >> 2] = c[f >> 2];
	                if (!(c[g >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                if (!((d[c[g >> 2] >> 0] | 0 | 0) == 105 ? (d[(c[g >> 2] | 0) + 1 >> 0] | 0 | 0) == 45 : 0))k = 5;
	                do if ((k | 0) == 5) {
	                    if ((d[c[g >> 2] >> 0] | 0 | 0) == 73 ? (d[(c[g >> 2] | 0) + 1 >> 0] | 0 | 0) == 45 : 0)break;
	                    if ((d[c[g >> 2] >> 0] | 0 | 0) == 120 ? (d[(c[g >> 2] | 0) + 1 >> 0] | 0 | 0) == 45 : 0)break;
	                    if ((d[c[g >> 2] >> 0] | 0 | 0) == 88 ? (d[(c[g >> 2] | 0) + 1 >> 0] | 0 | 0) == 45 : 0)break;
	                    c[h >> 2] = c[g >> 2];
	                    while (1) {
	                        if ((d[c[h >> 2] >> 0] | 0 | 0) >= 65 ? (d[c[h >> 2] >> 0] | 0 | 0) <= 90 : 0)l = 1; else if ((d[c[h >> 2] >> 0] | 0 | 0) >= 97)l = (d[c[h >> 2] >> 0] | 0 | 0) <= 122; else l = 0;
	                        m = c[h >> 2] | 0;
	                        if (!l)break;
	                        c[h >> 2] = m + 1
	                    }
	                    f = (c[h >> 2] | 0) - (c[g >> 2] | 0) | 0;
	                    if ((m - (c[g >> 2] | 0) | 0) >= 4) {
	                        if ((f | 0) <= 8 ? (d[c[h >> 2] >> 0] | 0 | 0) == 0 : 0) {
	                            c[e >> 2] = 1;
	                            j = c[e >> 2] | 0;
	                            i = b;
	                            return j | 0
	                        }
	                        c[e >> 2] = 0;
	                        j = c[e >> 2] | 0;
	                        i = b;
	                        return j | 0
	                    }
	                    if ((f | 0) < 2) {
	                        c[e >> 2] = 0;
	                        j = c[e >> 2] | 0;
	                        i = b;
	                        return j | 0
	                    }
	                    if (!(d[c[h >> 2] >> 0] | 0)) {
	                        c[e >> 2] = 1;
	                        j = c[e >> 2] | 0;
	                        i = b;
	                        return j | 0
	                    }
	                    if ((d[c[h >> 2] >> 0] | 0 | 0) != 45) {
	                        c[e >> 2] = 0;
	                        j = c[e >> 2] | 0;
	                        i = b;
	                        return j | 0
	                    }
	                    c[h >> 2] = (c[h >> 2] | 0) + 1;
	                    c[g >> 2] = c[h >> 2];
	                    if ((d[c[h >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[h >> 2] >> 0] | 0 | 0) <= 57 : 0)k = 103; else k = 39;
	                    a:do if ((k | 0) == 39) {
	                        while (1) {
	                            k = 0;
	                            if ((d[c[h >> 2] >> 0] | 0 | 0) >= 65 ? (d[c[h >> 2] >> 0] | 0 | 0) <= 90 : 0)n = 1; else if ((d[c[h >> 2] >> 0] | 0 | 0) >= 97)n = (d[c[h >> 2] >> 0] | 0 | 0) <= 122; else n = 0;
	                            o = c[h >> 2] | 0;
	                            if (!n)break;
	                            c[h >> 2] = o + 1;
	                            k = 39
	                        }
	                        do if ((o - (c[g >> 2] | 0) | 0) != 4) {
	                            if (((c[h >> 2] | 0) - (c[g >> 2] | 0) | 0) == 2) {
	                                k = 84;
	                                break a
	                            }
	                            if (((c[h >> 2] | 0) - (c[g >> 2] | 0) | 0) >= 5 ? ((c[h >> 2] | 0) - (c[g >> 2] | 0) | 0) <= 8 : 0)break a;
	                            if (((c[h >> 2] | 0) - (c[g >> 2] | 0) | 0) != 3) {
	                                c[e >> 2] = 0;
	                                j = c[e >> 2] | 0;
	                                i = b;
	                                return j | 0
	                            }
	                            if (!(d[c[h >> 2] >> 0] | 0)) {
	                                c[e >> 2] = 1;
	                                j = c[e >> 2] | 0;
	                                i = b;
	                                return j | 0
	                            }
	                            if ((d[c[h >> 2] >> 0] | 0 | 0) != 45) {
	                                c[e >> 2] = 0;
	                                j = c[e >> 2] | 0;
	                                i = b;
	                                return j | 0
	                            }
	                            c[h >> 2] = (c[h >> 2] | 0) + 1;
	                            c[g >> 2] = c[h >> 2];
	                            if ((d[c[h >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[h >> 2] >> 0] | 0 | 0) <= 57 : 0) {
	                                k = 103;
	                                break a
	                            }
	                            while (1) {
	                                if ((d[c[h >> 2] >> 0] | 0 | 0) >= 65 ? (d[c[h >> 2] >> 0] | 0 | 0) <= 90 : 0)p = 1; else k = 59;
	                                do if ((k | 0) == 59) {
	                                    k = 0;
	                                    if ((d[c[h >> 2] >> 0] | 0 | 0) < 97) {
	                                        p = 0;
	                                        break
	                                    }
	                                    p = (d[c[h >> 2] >> 0] | 0 | 0) <= 122
	                                } while (0);
	                                q = c[h >> 2] | 0;
	                                if (!p)break;
	                                c[h >> 2] = q + 1
	                            }
	                            if ((q - (c[g >> 2] | 0) | 0) == 2) {
	                                k = 84;
	                                break a
	                            }
	                            if (((c[h >> 2] | 0) - (c[g >> 2] | 0) | 0) >= 5 ? ((c[h >> 2] | 0) - (c[g >> 2] | 0) | 0) <= 8 : 0)break a;
	                            if (((c[h >> 2] | 0) - (c[g >> 2] | 0) | 0) == 4)break;
	                            c[e >> 2] = 0;
	                            j = c[e >> 2] | 0;
	                            i = b;
	                            return j | 0
	                        } while (0);
	                        if (!(d[c[h >> 2] >> 0] | 0)) {
	                            c[e >> 2] = 1;
	                            j = c[e >> 2] | 0;
	                            i = b;
	                            return j | 0
	                        }
	                        if ((d[c[h >> 2] >> 0] | 0 | 0) != 45) {
	                            c[e >> 2] = 0;
	                            j = c[e >> 2] | 0;
	                            i = b;
	                            return j | 0
	                        }
	                        c[h >> 2] = (c[h >> 2] | 0) + 1;
	                        c[g >> 2] = c[h >> 2];
	                        if ((d[c[h >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[h >> 2] >> 0] | 0 | 0) <= 57 : 0) {
	                            k = 103;
	                            break
	                        }
	                        while (1) {
	                            if ((d[c[h >> 2] >> 0] | 0 | 0) >= 65 ? (d[c[h >> 2] >> 0] | 0 | 0) <= 90 : 0)r = 1; else if ((d[c[h >> 2] >> 0] | 0 | 0) >= 97)r = (d[c[h >> 2] >> 0] | 0 | 0) <= 122; else r = 0;
	                            s = c[h >> 2] | 0;
	                            if (!r)break;
	                            c[h >> 2] = s + 1
	                        }
	                        if ((s - (c[g >> 2] | 0) | 0) >= 5 ? ((c[h >> 2] | 0) - (c[g >> 2] | 0) | 0) <= 8 : 0)break;
	                        if (((c[h >> 2] | 0) - (c[g >> 2] | 0) | 0) != 2) {
	                            c[e >> 2] = 0;
	                            j = c[e >> 2] | 0;
	                            i = b;
	                            return j | 0
	                        } else k = 84
	                    } while (0);
	                    do if ((k | 0) == 103) {
	                        if ((((d[(c[h >> 2] | 0) + 1 >> 0] | 0 | 0) >= 48 ? (d[(c[h >> 2] | 0) + 1 >> 0] | 0 | 0) <= 57 : 0) ? (d[(c[h >> 2] | 0) + 2 >> 0] | 0 | 0) >= 48 : 0) ? (d[(c[h >> 2] | 0) + 2 >> 0] | 0 | 0) <= 57 : 0) {
	                            c[h >> 2] = (c[h >> 2] | 0) + 3;
	                            k = 84;
	                            break
	                        }
	                        c[e >> 2] = 0;
	                        j = c[e >> 2] | 0;
	                        i = b;
	                        return j | 0
	                    } while (0);
	                    do if ((k | 0) == 84) {
	                        if (!(d[c[h >> 2] >> 0] | 0)) {
	                            c[e >> 2] = 1;
	                            j = c[e >> 2] | 0;
	                            i = b;
	                            return j | 0
	                        }
	                        if ((d[c[h >> 2] >> 0] | 0 | 0) != 45) {
	                            c[e >> 2] = 0;
	                            j = c[e >> 2] | 0;
	                            i = b;
	                            return j | 0
	                        }
	                        c[h >> 2] = (c[h >> 2] | 0) + 1;
	                        c[g >> 2] = c[h >> 2];
	                        while (1) {
	                            if ((d[c[h >> 2] >> 0] | 0 | 0) >= 65 ? (d[c[h >> 2] >> 0] | 0 | 0) <= 90 : 0)t = 1; else if ((d[c[h >> 2] >> 0] | 0 | 0) >= 97)t = (d[c[h >> 2] >> 0] | 0 | 0) <= 122; else t = 0;
	                            u = c[h >> 2] | 0;
	                            if (!t)break;
	                            c[h >> 2] = u + 1
	                        }
	                        if ((u - (c[g >> 2] | 0) | 0) >= 5 ? ((c[h >> 2] | 0) - (c[g >> 2] | 0) | 0) <= 8 : 0)break;
	                        c[e >> 2] = 0;
	                        j = c[e >> 2] | 0;
	                        i = b;
	                        return j | 0
	                    } while (0);
	                    if (!(d[c[h >> 2] >> 0] | 0)) {
	                        c[e >> 2] = 1;
	                        j = c[e >> 2] | 0;
	                        i = b;
	                        return j | 0
	                    }
	                    if ((d[c[h >> 2] >> 0] | 0 | 0) != 45) {
	                        c[e >> 2] = 0;
	                        j = c[e >> 2] | 0;
	                        i = b;
	                        return j | 0
	                    } else {
	                        c[e >> 2] = 1;
	                        j = c[e >> 2] | 0;
	                        i = b;
	                        return j | 0
	                    }
	                } while (0);
	                c[g >> 2] = (c[g >> 2] | 0) + 2;
	                while (1) {
	                    if ((d[c[g >> 2] >> 0] | 0 | 0) >= 65 ? (d[c[g >> 2] >> 0] | 0 | 0) <= 90 : 0)v = 1; else if ((d[c[g >> 2] >> 0] | 0 | 0) >= 97)v = (d[c[g >> 2] >> 0] | 0 | 0) <= 122; else v = 0;
	                    w = c[g >> 2] | 0;
	                    if (!v)break;
	                    c[g >> 2] = w + 1
	                }
	                c[e >> 2] = (d[w >> 0] | 0 | 0) == 0 & 1;
	                j = c[e >> 2] | 0;
	                i = b;
	                return j | 0
	            }

	            function Oe(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = -1;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                if ((c[(c[f >> 2] | 0) + 40 >> 2] | 0) >= (c[(c[f >> 2] | 0) + 44 >> 2] | 0) ? (b = (c[f >> 2] | 0) + 44 | 0, c[b >> 2] = c[b >> 2] << 1, b = Hb[c[135760 >> 2] & 511](c[(c[f >> 2] | 0) + 48 >> 2] | 0, c[(c[f >> 2] | 0) + 44 >> 2] << 2) | 0, c[(c[f >> 2] | 0) + 48 >> 2] = b, (c[(c[f >> 2] | 0) + 48 >> 2] | 0) == 0) : 0) {
	                    ie(c[f >> 2] | 0, 0);
	                    te(c[g >> 2] | 0);
	                    b = (c[f >> 2] | 0) + 44 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) / 2 | 0;
	                    c[g >> 2] = 0;
	                    c[e >> 2] = -1;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                c[(c[(c[f >> 2] | 0) + 48 >> 2] | 0) + (c[(c[f >> 2] | 0) + 40 >> 2] << 2) >> 2] = c[g >> 2];
	                c[(c[f >> 2] | 0) + 36 >> 2] = c[g >> 2];
	                g = (c[f >> 2] | 0) + 40 | 0;
	                f = c[g >> 2] | 0;
	                c[g >> 2] = f + 1;
	                c[e >> 2] = f;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function Pe(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                if ((c[(c[e >> 2] | 0) + 40 >> 2] | 0) <= 0) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = (c[e >> 2] | 0) + 40 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + -1;
	                a = c[e >> 2] | 0;
	                if ((c[(c[e >> 2] | 0) + 40 >> 2] | 0) > 0)c[(c[e >> 2] | 0) + 36 >> 2] = c[(c[(c[e >> 2] | 0) + 48 >> 2] | 0) + ((c[a + 40 >> 2] | 0) - 1 << 2) >> 2]; else c[a + 36 >> 2] = 0;
	                c[f >> 2] = c[(c[(c[e >> 2] | 0) + 48 >> 2] | 0) + (c[(c[e >> 2] | 0) + 40 >> 2] << 2) >> 2];
	                c[(c[(c[e >> 2] | 0) + 48 >> 2] | 0) + (c[(c[e >> 2] | 0) + 40 >> 2] << 2) >> 2] = 0;
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function Qe(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                do if ((c[(c[f >> 2] | 0) + 56 >> 2] | 0) >= (c[(c[f >> 2] | 0) + 60 >> 2] | 0)) {
	                    c[h >> 2] = Hb[c[135760 >> 2] & 511](c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[(c[f >> 2] | 0) + 60 >> 2] << 1 << 2) | 0;
	                    if (c[h >> 2] | 0) {
	                        c[(c[f >> 2] | 0) + 64 >> 2] = c[h >> 2];
	                        b = (c[f >> 2] | 0) + 60 | 0;
	                        c[b >> 2] = c[b >> 2] << 1;
	                        break
	                    }
	                    ie(c[f >> 2] | 0, 0);
	                    c[e >> 2] = -1;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } while (0);
	                if ((c[(c[f >> 2] | 0) + 56 >> 2] | 0) >>> 0 > (c[16304] | 0) >>> 0 ? (c[(c[f >> 2] | 0) + 360 >> 2] & 524288 | 0) == 0 : 0) {
	                    ng(c[f >> 2] | 0, 1, 65224, c[16304] | 0);
	                    c[(c[f >> 2] | 0) + 172 >> 2] = -1;
	                    c[e >> 2] = -1;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + (c[(c[f >> 2] | 0) + 56 >> 2] << 2) >> 2] = c[g >> 2];
	                c[(c[f >> 2] | 0) + 52 >> 2] = c[g >> 2];
	                g = (c[f >> 2] | 0) + 56 | 0;
	                f = c[g >> 2] | 0;
	                c[g >> 2] = f + 1;
	                c[e >> 2] = f;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function Re(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                if ((c[(c[e >> 2] | 0) + 56 >> 2] | 0) <= 0) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = (c[e >> 2] | 0) + 56 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + -1;
	                a = c[e >> 2] | 0;
	                if ((c[(c[e >> 2] | 0) + 56 >> 2] | 0) > 0)c[(c[e >> 2] | 0) + 52 >> 2] = c[(c[(c[e >> 2] | 0) + 64 >> 2] | 0) + ((c[a + 56 >> 2] | 0) - 1 << 2) >> 2]; else c[a + 52 >> 2] = 0;
	                c[f >> 2] = c[(c[(c[e >> 2] | 0) + 64 >> 2] | 0) + (c[(c[e >> 2] | 0) + 56 >> 2] << 2) >> 2];
	                c[(c[(c[e >> 2] | 0) + 64 >> 2] | 0) + (c[(c[e >> 2] | 0) + 56 >> 2] << 2) >> 2] = 0;
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function Se(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                do if ((c[(c[f >> 2] | 0) + 188 >> 2] | 0) >= (c[(c[f >> 2] | 0) + 192 >> 2] | 0)) {
	                    c[h >> 2] = Hb[c[135760 >> 2] & 511](c[(c[f >> 2] | 0) + 196 >> 2] | 0, c[(c[f >> 2] | 0) + 192 >> 2] << 1 << 2) | 0;
	                    if (c[h >> 2] | 0) {
	                        c[(c[f >> 2] | 0) + 196 >> 2] = c[h >> 2];
	                        b = (c[f >> 2] | 0) + 192 | 0;
	                        c[b >> 2] = c[b >> 2] << 1;
	                        break
	                    }
	                    ie(c[f >> 2] | 0, 0);
	                    c[e >> 2] = -1;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } while (0);
	                c[(c[(c[f >> 2] | 0) + 196 >> 2] | 0) + (c[(c[f >> 2] | 0) + 188 >> 2] << 2) >> 2] = c[g >> 2];
	                c[(c[f >> 2] | 0) + 184 >> 2] = c[g >> 2];
	                g = (c[f >> 2] | 0) + 188 | 0;
	                f = c[g >> 2] | 0;
	                c[g >> 2] = f + 1;
	                c[e >> 2] = f;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function Te(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 188 >> 2] | 0) > 0 : 0) {
	                    a = (c[e >> 2] | 0) + 188 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + -1;
	                    a = c[e >> 2] | 0;
	                    if ((c[(c[e >> 2] | 0) + 188 >> 2] | 0) > 0)c[(c[e >> 2] | 0) + 184 >> 2] = c[(c[(c[e >> 2] | 0) + 196 >> 2] | 0) + ((c[a + 188 >> 2] | 0) - 1 << 2) >> 2]; else c[a + 184 >> 2] = 0;
	                    c[f >> 2] = c[(c[(c[e >> 2] | 0) + 196 >> 2] | 0) + (c[(c[e >> 2] | 0) + 188 >> 2] << 2) >> 2];
	                    c[(c[(c[e >> 2] | 0) + 196 >> 2] | 0) + (c[(c[e >> 2] | 0) + 188 >> 2] << 2) >> 2] = 0;
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[d >> 2] = 0;
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function Ue(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                g = b + 4 | 0;
	                h = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                if ((c[(c[e >> 2] | 0) + 40 >> 2] | 0) == 1 ? (c[(c[e >> 2] | 0) + 172 >> 2] | 0) != 3 : 0) {
	                    c[g >> 2] = c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                    while (1) {
	                        do if ((d[c[g >> 2] >> 0] | 0 | 0) == 32)j = 1; else {
	                            if (9 <= (d[c[g >> 2] >> 0] | 0 | 0) ? (d[c[g >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                j = 1;
	                                break
	                            }
	                            j = (d[c[g >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        k = c[g >> 2] | 0;
	                        if (!j)break;
	                        a = c[(c[e >> 2] | 0) + 36 >> 2] | 0;
	                        if ((d[k >> 0] | 0 | 0) == 10) {
	                            l = a + 28 | 0;
	                            c[l >> 2] = (c[l >> 2] | 0) + 1;
	                            c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                        } else {
	                            l = a + 32 | 0;
	                            c[l >> 2] = (c[l >> 2] | 0) + 1
	                        }
	                        c[g >> 2] = (c[g >> 2] | 0) + 1;
	                        c[f >> 2] = (c[f >> 2] | 0) + 1;
	                        if (d[c[g >> 2] >> 0] | 0)continue;
	                        c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] = c[g >> 2];
	                        ke(c[(c[e >> 2] | 0) + 36 >> 2] | 0, 250) | 0;
	                        c[g >> 2] = c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2]
	                    }
	                    c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] = k;
	                    m = c[f >> 2] | 0;
	                    i = b;
	                    return m | 0
	                }
	                do {
	                    c[h >> 2] = d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0];
	                    while (1) {
	                        if ((c[h >> 2] | 0) != 32 ? !(9 <= (c[h >> 2] | 0) & (c[h >> 2] | 0) <= 10 | (c[h >> 2] | 0) == 13) : 0)break;
	                        me(c[e >> 2] | 0);
	                        c[h >> 2] = d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0];
	                        c[f >> 2] = (c[f >> 2] | 0) + 1
	                    }
	                    while (1) {
	                        if ((c[h >> 2] | 0) == 0 ? (c[(c[e >> 2] | 0) + 40 >> 2] | 0) > 1 : 0)n = (c[(c[e >> 2] | 0) + 172 >> 2] | 0) != 5; else n = 0;
	                        o = c[e >> 2] | 0;
	                        if (!n)break;
	                        Ve(o) | 0;
	                        c[h >> 2] = d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0]
	                    }
	                    if ((d[c[(c[o + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[e >> 2] | 0);
	                    if ((c[h >> 2] | 0) < 256) {
	                        if ((c[h >> 2] | 0) != 32 ? !(9 <= (c[h >> 2] | 0) & (c[h >> 2] | 0) <= 10) : 0)p = (c[h >> 2] | 0) == 13; else p = 1;
	                        q = p & 1
	                    } else q = 0
	                } while ((q | 0) != 0);
	                m = c[f >> 2] | 0;
	                i = b;
	                return m | 0
	            }

	            function Ve(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                c[h >> 2] = b;
	                if ((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 40 >> 2] | 0) > 1 : 0) {
	                    if (c[33952] | 0) {
	                        b = c[33976] | 0;
	                        j = c[33980] | 0;
	                        c[f >> 2] = c[(c[h >> 2] | 0) + 40 >> 2];
	                        Db[b & 511](j, 65288, f)
	                    }
	                    te(Pe(c[h >> 2] | 0) | 0);
	                    if ((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[h >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0) {
	                        a[g >> 0] = Ve(c[h >> 2] | 0) | 0;
	                        k = a[g >> 0] | 0;
	                        i = e;
	                        return k | 0
	                    }
	                    a[g >> 0] = a[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                    k = a[g >> 0] | 0;
	                    i = e;
	                    return k | 0
	                }
	                a[g >> 0] = 0;
	                k = a[g >> 0] | 0;
	                i = e;
	                return k | 0
	            }

	            function We(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e;
	                g = e + 20 | 0;
	                h = e + 16 | 0;
	                j = e + 12 | 0;
	                k = e + 8 | 0;
	                l = e + 24 | 0;
	                m = e + 4 | 0;
	                c[g >> 2] = b;
	                c[j >> 2] = 0;
	                if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 37) {
	                    i = e;
	                    return
	                }
	                switch (c[(c[g >> 2] | 0) + 172 >> 2] | 0) {
	                    case 14:
	                    {
	                        og(c[g >> 2] | 0, 20, 0);
	                        i = e;
	                        return
	                    }
	                    case 3:
	                    {
	                        if ((c[(c[g >> 2] | 0) + 96 >> 2] | 0) == 0 ? (c[(c[g >> 2] | 0) + 40 >> 2] | 0) == 1 : 0) {
	                            i = e;
	                            return
	                        }
	                        if ((d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 32) {
	                            i = e;
	                            return
	                        }
	                        if (9 <= (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) <= 10 : 0) {
	                            i = e;
	                            return
	                        }
	                        if ((d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 13) {
	                            i = e;
	                            return
	                        }
	                        if (!(d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0)) {
	                            i = e;
	                            return
	                        }
	                        break
	                    }
	                    case 15:
	                    case 11:
	                    case 16:
	                    case 13:
	                    case 2:
	                    case 12:
	                    case 7:
	                    case 10:
	                    case 9:
	                    case 6:
	                    case 5:
	                    case 8:
	                    {
	                        i = e;
	                        return
	                    }
	                    case 1:
	                    case 0:
	                    case 4:
	                    {
	                        og(c[g >> 2] | 0, 19, 0);
	                        i = e;
	                        return
	                    }
	                    case -1:
	                    {
	                        og(c[g >> 2] | 0, 18, 0);
	                        i = e;
	                        return
	                    }
	                    default:
	                    {
	                    }
	                }
	                me(c[g >> 2] | 0);
	                c[h >> 2] = Ze(c[g >> 2] | 0) | 0;
	                if (c[33952] | 0) {
	                    b = c[33976] | 0;
	                    n = c[33980] | 0;
	                    c[f >> 2] = c[h >> 2];
	                    Db[b & 511](n, 65408, f)
	                }
	                f = c[g >> 2] | 0;
	                if (!(c[h >> 2] | 0)) {
	                    og(f, 24, 0);
	                    i = e;
	                    return
	                }
	                n = c[g >> 2] | 0;
	                if ((d[c[(c[f + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 59) {
	                    og(n, 25, 0);
	                    i = e;
	                    return
	                }
	                me(n);
	                if ((c[c[g >> 2] >> 2] | 0) != 0 ? (c[(c[c[g >> 2] >> 2] | 0) + 96 >> 2] | 0) != 0 : 0)c[j >> 2] = Hb[c[(c[c[g >> 2] >> 2] | 0) + 96 >> 2] & 511](c[(c[g >> 2] | 0) + 4 >> 2] | 0, c[h >> 2] | 0) | 0;
	                if ((c[(c[g >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                    i = e;
	                    return
	                }
	                n = c[g >> 2] | 0;
	                if (!(c[j >> 2] | 0)) {
	                    do if ((c[n + 28 >> 2] | 0) == 1)o = 26; else {
	                        if ((c[(c[g >> 2] | 0) + 88 >> 2] | 0) == 0 ? (c[(c[g >> 2] | 0) + 92 >> 2] | 0) == 0 : 0) {
	                            o = 26;
	                            break
	                        }
	                        if ((c[(c[g >> 2] | 0) + 104 >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 112 >> 2] | 0) != 0 : 0)qg(c[g >> 2] | 0, 27, 65432, c[h >> 2] | 0, 0); else rg(c[g >> 2] | 0, 27, 65432, c[h >> 2] | 0, 0);
	                        c[(c[g >> 2] | 0) + 100 >> 2] = 0
	                    } while (0);
	                    if ((o | 0) == 26)pg(c[g >> 2] | 0, 26, 65432, c[h >> 2] | 0);
	                    sg(c[g >> 2] | 0, 0, 0, 0) | 0;
	                    i = e;
	                    return
	                }
	                if ((c[(c[n + 36 >> 2] | 0) + 40 >> 2] | 0) != 226) {
	                    c[k >> 2] = ug(c[g >> 2] | 0, c[j >> 2] | 0) | 0;
	                    Xe(c[g >> 2] | 0, c[k >> 2] | 0) | 0;
	                    i = e;
	                    return
	                }
	                if ((c[(c[j >> 2] | 0) + 48 >> 2] | 0) != 4 ? (c[(c[j >> 2] | 0) + 48 >> 2] | 0) != 5 : 0) {
	                    pg(c[g >> 2] | 0, 30, 65464, c[h >> 2] | 0);
	                    i = e;
	                    return
	                }
	                if (((((((c[(c[j >> 2] | 0) + 48 >> 2] | 0) == 5 ? (c[(c[g >> 2] | 0) + 360 >> 2] & 2 | 0) == 0 : 0) ? (c[(c[g >> 2] | 0) + 360 >> 2] & 16 | 0) == 0 : 0) ? (c[(c[g >> 2] | 0) + 360 >> 2] & 4 | 0) == 0 : 0) ? (c[(c[g >> 2] | 0) + 360 >> 2] & 8 | 0) == 0 : 0) ? (c[(c[g >> 2] | 0) + 16 >> 2] | 0) == 0 : 0) ? (c[(c[g >> 2] | 0) + 104 >> 2] | 0) == 0 : 0) {
	                    i = e;
	                    return
	                }
	                c[k >> 2] = we(c[g >> 2] | 0, c[j >> 2] | 0) | 0;
	                if ((Xe(c[g >> 2] | 0, c[k >> 2] | 0) | 0) < 0) {
	                    i = e;
	                    return
	                }
	                if ((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[g >> 2] | 0);
	                if ((c[(c[g >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                    i = e;
	                    return
	                }
	                if (((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) >= 4 ? (a[l >> 0] = a[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0, a[l + 1 >> 0] = a[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0, a[l + 2 >> 0] = a[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0, a[l + 3 >> 0] = a[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0, c[m >> 2] = sd(l, 4) | 0, (c[m >> 2] | 0) != 0) : 0)re(c[g >> 2] | 0, c[m >> 2] | 0) | 0;
	                if ((c[(c[j >> 2] | 0) + 48 >> 2] | 0) != 5) {
	                    i = e;
	                    return
	                }
	                if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 60) {
	                    i = e;
	                    return
	                }
	                if ((d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) != 63) {
	                    i = e;
	                    return
	                }
	                if ((d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) != 120) {
	                    i = e;
	                    return
	                }
	                if ((d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) != 109) {
	                    i = e;
	                    return
	                }
	                if ((d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) != 108) {
	                    i = e;
	                    return
	                }
	                do if ((d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) != 32) {
	                    if (9 <= (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) <= 10 : 0)break;
	                    if ((d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) == 13)break;
	                    i = e;
	                    return
	                } while (0);
	                _e(c[g >> 2] | 0);
	                i = e;
	                return
	            }

	            function Xe(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = -1;
	                    k = c[f >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                if (c[33952] | 0) {
	                    if ((c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                        b = c[33976] | 0;
	                        a = c[33980] | 0;
	                        l = c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2] | 0;
	                        c[e >> 2] = c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2];
	                        c[e + 4 >> 2] = l;
	                        Db[b & 511](a, 65312, e)
	                    }
	                    a = c[33976] | 0;
	                    b = c[33980] | 0;
	                    l = c[(c[h >> 2] | 0) + 16 >> 2] | 0;
	                    c[e >> 2] = (c[(c[g >> 2] | 0) + 40 >> 2] | 0) + 1;
	                    c[e + 4 >> 2] = l;
	                    Db[a & 511](b, 65328, e)
	                }
	                c[j >> 2] = Oe(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                if ((c[(c[g >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                    c[f >> 2] = -1;
	                    k = c[f >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                if ((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[g >> 2] | 0);
	                c[f >> 2] = c[j >> 2];
	                k = c[f >> 2] | 0;
	                i = d;
	                return k | 0
	            }

	            function Ye(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                b = i;
	                i = i + 32 | 0;
	                e = b + 16 | 0;
	                f = b + 12 | 0;
	                g = b + 8 | 0;
	                h = b + 4 | 0;
	                j = b;
	                c[f >> 2] = a;
	                c[g >> 2] = 0;
	                c[h >> 2] = 0;
	                c[j >> 2] = 0;
	                if (((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 38 ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 35 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 120 : 0) {
	                    a = (c[f >> 2] | 0) + 200 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 3;
	                    a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 3;
	                    a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 3;
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[f >> 2] | 0) | 0;
	                    if ((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[f >> 2] | 0);
	                    a:while (1) {
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 59)break;
	                        a = c[h >> 2] | 0;
	                        c[h >> 2] = a + 1;
	                        if ((a | 0) > 20) {
	                            c[h >> 2] = 0;
	                            if ((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[f >> 2] | 0);
	                            if ((c[(c[f >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                                k = 18;
	                                break
	                            }
	                        }
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 57 : 0)c[g >> 2] = (c[g >> 2] << 4) + ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) - 48); else k = 22;
	                        do if ((k | 0) == 22) {
	                            k = 0;
	                            if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) >= 97 ? ((c[h >> 2] | 0) < 20 ? (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 102 : 0) : 0) {
	                                c[g >> 2] = (c[g >> 2] << 4) + ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) - 97) + 10;
	                                break
	                            }
	                            if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) < 65) {
	                                k = 28;
	                                break a
	                            }
	                            if (!((c[h >> 2] | 0) < 20 ? (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 70 : 0)) {
	                                k = 28;
	                                break a
	                            }
	                            c[g >> 2] = (c[g >> 2] << 4) + ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) - 65) + 10
	                        } while (0);
	                        if ((c[g >> 2] | 0) >>> 0 > 1114111)c[j >> 2] = c[g >> 2];
	                        me(c[f >> 2] | 0);
	                        c[h >> 2] = (c[h >> 2] | 0) + 1
	                    }
	                    if ((k | 0) == 18) {
	                        c[e >> 2] = 0;
	                        l = c[e >> 2] | 0;
	                        i = b;
	                        return l | 0
	                    } else if ((k | 0) == 28) {
	                        og(c[f >> 2] | 0, 6, 0);
	                        c[g >> 2] = 0
	                    }
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 59) {
	                        a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1;
	                        a = (c[f >> 2] | 0) + 200 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1;
	                        a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1
	                    }
	                } else k = 34;
	                do if ((k | 0) == 34) {
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 38 ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 35 : 0) {
	                        a = (c[f >> 2] | 0) + 200 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 2;
	                        a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 2;
	                        a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 2;
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[f >> 2] | 0) | 0;
	                        if ((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[f >> 2] | 0);
	                        while (1) {
	                            if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 59)break;
	                            a = c[h >> 2] | 0;
	                            c[h >> 2] = a + 1;
	                            if ((a | 0) > 20) {
	                                c[h >> 2] = 0;
	                                if ((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[f >> 2] | 0);
	                                if ((c[(c[f >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                                    k = 50;
	                                    break
	                                }
	                            }
	                            if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) < 48) {
	                                k = 54;
	                                break
	                            }
	                            if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) > 57) {
	                                k = 54;
	                                break
	                            }
	                            c[g >> 2] = ((c[g >> 2] | 0) * 10 | 0) + ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) - 48);
	                            if ((c[g >> 2] | 0) >>> 0 > 1114111)c[j >> 2] = c[g >> 2];
	                            me(c[f >> 2] | 0);
	                            c[h >> 2] = (c[h >> 2] | 0) + 1
	                        }
	                        if ((k | 0) == 50) {
	                            c[e >> 2] = 0;
	                            l = c[e >> 2] | 0;
	                            i = b;
	                            return l | 0
	                        } else if ((k | 0) == 54) {
	                            og(c[f >> 2] | 0, 7, 0);
	                            c[g >> 2] = 0
	                        }
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 59)break;
	                        a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1;
	                        a = (c[f >> 2] | 0) + 200 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1;
	                        a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1;
	                        break
	                    }
	                    og(c[f >> 2] | 0, 8, 0)
	                } while (0);
	                h = c[g >> 2] | 0;
	                do if ((c[g >> 2] | 0) >>> 0 < 256)if ((9 <= h >>> 0 & (c[g >> 2] | 0) >>> 0 <= 10 | (c[g >> 2] | 0) == 13 | 32 <= (c[g >> 2] | 0) >>> 0) & (c[j >> 2] | 0) == 0)k = 66; else k = 67; else {
	                    if (!(256 <= h >>> 0 & (c[g >> 2] | 0) >>> 0 <= 55295) ? !(57344 <= (c[g >> 2] | 0) >>> 0 & (c[g >> 2] | 0) >>> 0 <= 65533) : 0)if (65536 <= (c[g >> 2] | 0) >>> 0 & (c[g >> 2] | 0) >>> 0 <= 1114111 & (c[j >> 2] | 0) == 0) {
	                        k = 66;
	                        break
	                    } else {
	                        k = 67;
	                        break
	                    }
	                    if (!(c[j >> 2] | 0))k = 66; else k = 67
	                } while (0);
	                if ((k | 0) == 66) {
	                    c[e >> 2] = c[g >> 2];
	                    l = c[e >> 2] | 0;
	                    i = b;
	                    return l | 0
	                } else if ((k | 0) == 67) {
	                    ng(c[f >> 2] | 0, 9, 65360, c[g >> 2] | 0);
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = b;
	                    return l | 0
	                }
	                return 0
	            }

	            function Ze(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                b = i;
	                i = i + 32 | 0;
	                e = b + 16 | 0;
	                f = b + 12 | 0;
	                g = b + 8 | 0;
	                h = b + 4 | 0;
	                j = b;
	                c[f >> 2] = a;
	                c[j >> 2] = 0;
	                if ((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[f >> 2] | 0);
	                c[g >> 2] = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                if ((d[c[g >> 2] >> 0] | 0 | 0) >= 97 ? (d[c[g >> 2] >> 0] | 0 | 0) <= 122 : 0)k = 10; else k = 6;
	                do if ((k | 0) == 6) {
	                    if ((d[c[g >> 2] >> 0] | 0 | 0) >= 65 ? (d[c[g >> 2] >> 0] | 0 | 0) <= 90 : 0) {
	                        k = 10;
	                        break
	                    }
	                    if (!((d[c[g >> 2] >> 0] | 0 | 0) != 95 ? (d[c[g >> 2] >> 0] | 0 | 0) != 58 : 0))k = 10
	                } while (0);
	                if ((k | 0) == 10) {
	                    c[g >> 2] = (c[g >> 2] | 0) + 1;
	                    while (1) {
	                        if ((d[c[g >> 2] >> 0] | 0 | 0) >= 97 ? (d[c[g >> 2] >> 0] | 0 | 0) <= 122 : 0)l = 1; else k = 13;
	                        do if ((k | 0) == 13) {
	                            k = 0;
	                            if ((d[c[g >> 2] >> 0] | 0 | 0) >= 65 ? (d[c[g >> 2] >> 0] | 0 | 0) <= 90 : 0) {
	                                l = 1;
	                                break
	                            }
	                            if ((d[c[g >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[g >> 2] >> 0] | 0 | 0) <= 57 : 0) {
	                                l = 1;
	                                break
	                            }
	                            if (((d[c[g >> 2] >> 0] | 0 | 0) != 95 ? (d[c[g >> 2] >> 0] | 0 | 0) != 45 : 0) ? (d[c[g >> 2] >> 0] | 0 | 0) != 58 : 0)l = (d[c[g >> 2] >> 0] | 0 | 0) == 46; else l = 1
	                        } while (0);
	                        m = c[g >> 2] | 0;
	                        if (!l)break;
	                        c[g >> 2] = m + 1
	                    }
	                    if ((d[m >> 0] | 0 | 0) > 0 ? (d[c[g >> 2] >> 0] | 0 | 0) < 128 : 0) {
	                        c[j >> 2] = (c[g >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0);
	                        if ((c[j >> 2] | 0) > 5e4 ? (c[(c[f >> 2] | 0) + 360 >> 2] & 524288 | 0) == 0 : 0) {
	                            og(c[f >> 2] | 0, 110, 65688);
	                            c[e >> 2] = 0;
	                            n = c[e >> 2] | 0;
	                            i = b;
	                            return n | 0
	                        }
	                        c[h >> 2] = AP(c[(c[f >> 2] | 0) + 296 >> 2] | 0, c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0, c[j >> 2] | 0) | 0;
	                        c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] = c[g >> 2];
	                        g = (c[f >> 2] | 0) + 200 | 0;
	                        c[g >> 2] = (c[g >> 2] | 0) + (c[j >> 2] | 0);
	                        g = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                        c[g >> 2] = (c[g >> 2] | 0) + (c[j >> 2] | 0);
	                        if (!(c[h >> 2] | 0))ie(c[f >> 2] | 0, 0);
	                        c[e >> 2] = c[h >> 2];
	                        n = c[e >> 2] | 0;
	                        i = b;
	                        return n | 0
	                    }
	                }
	                c[e >> 2] = wg(c[f >> 2] | 0) | 0;
	                n = c[e >> 2] | 0;
	                i = b;
	                return n | 0
	            }

	            function _e(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                a:do if (((((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 63 : 0) ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 120 : 0) ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 109 : 0) ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) == 108 : 0) {
	                    do if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    a = (c[e >> 2] | 0) + 200 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 5;
	                    a = (c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 5;
	                    a = (c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 5;
	                    if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[e >> 2] | 0);
	                    if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[e >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[e >> 2] | 0) | 0;
	                    do if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13)xg(c[e >> 2] | 0, 65, 68456)
	                    } while (0);
	                    Ue(c[e >> 2] | 0) | 0;
	                    c[f >> 2] = Af(c[e >> 2] | 0) | 0;
	                    do if (c[f >> 2] | 0) {
	                        if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13)xg(c[e >> 2] | 0, 65, 68496)
	                        }
	                    } else c[f >> 2] = oy(68488) | 0; while (0);
	                    c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 48 >> 2] = c[f >> 2];
	                    c[g >> 2] = Bf(c[e >> 2] | 0) | 0;
	                    if ((c[(c[e >> 2] | 0) + 84 >> 2] | 0) == 32) {
	                        i = b;
	                        return
	                    }
	                    if ((c[g >> 2] | 0) == 0 ? (c[(c[e >> 2] | 0) + 84 >> 2] | 0) == 0 : 0)xg(c[e >> 2] | 0, 101, 68520);
	                    Ue(c[e >> 2] | 0) | 0;
	                    if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 63 ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 62 : 0) {
	                        a = (c[e >> 2] | 0) + 200 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 2;
	                        a = (c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 2;
	                        a = (c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 2;
	                        if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[e >> 2] | 0);
	                        if (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) {
	                            i = b;
	                            return
	                        }
	                        if ((ke(c[(c[e >> 2] | 0) + 36 >> 2] | 0, 250) | 0) > 0) {
	                            i = b;
	                            return
	                        }
	                        Ve(c[e >> 2] | 0) | 0;
	                        i = b;
	                        return
	                    }
	                    a = (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 62;
	                    og(c[e >> 2] | 0, 57, 0);
	                    if (a) {
	                        me(c[e >> 2] | 0);
	                        i = b;
	                        return
	                    }
	                    while (1) {
	                        if (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0)h = (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 62; else h = 0;
	                        j = c[e >> 2] | 0;
	                        if (!h)break;
	                        a = (c[j + 36 >> 2] | 0) + 16 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1
	                    }
	                    me(j);
	                    i = b;
	                    return
	                } while (0);
	                og(c[e >> 2] | 0, 56, 0);
	                i = b;
	                return
	            }

	            function $e(b, e, f, g, h, j, k) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                k = k | 0;
	                var l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0, J = 0, K = 0, L = 0, M = 0, N = 0, O = 0, P = 0, Q = 0, R = 0, S = 0, T = 0, U = 0;
	                l = i;
	                i = i + 128 | 0;
	                m = l;
	                n = l + 116 | 0;
	                o = l + 112 | 0;
	                p = l + 108 | 0;
	                q = l + 104 | 0;
	                r = l + 100 | 0;
	                s = l + 122 | 0;
	                t = l + 121 | 0;
	                u = l + 120 | 0;
	                v = l + 96 | 0;
	                w = l + 92 | 0;
	                x = l + 88 | 0;
	                y = l + 84 | 0;
	                z = l + 80 | 0;
	                A = l + 76 | 0;
	                B = l + 72 | 0;
	                C = l + 68 | 0;
	                D = l + 64 | 0;
	                E = l + 60 | 0;
	                F = l + 56 | 0;
	                G = l + 52 | 0;
	                H = l + 48 | 0;
	                I = l + 44 | 0;
	                J = l + 40 | 0;
	                K = l + 36 | 0;
	                L = l + 32 | 0;
	                M = l + 28 | 0;
	                N = l + 24 | 0;
	                O = l + 20 | 0;
	                P = l + 16 | 0;
	                Q = l + 12 | 0;
	                R = l + 8 | 0;
	                S = l + 4 | 0;
	                c[o >> 2] = b;
	                c[p >> 2] = e;
	                c[q >> 2] = f;
	                c[r >> 2] = g;
	                a[s >> 0] = h;
	                a[t >> 0] = j;
	                a[u >> 0] = k;
	                c[v >> 2] = 0;
	                c[w >> 2] = 0;
	                c[x >> 2] = 0;
	                c[y >> 2] = 0;
	                c[z >> 2] = 0;
	                if ((c[o >> 2] | 0) == 0 | (c[p >> 2] | 0) == 0 | (c[q >> 2] | 0) < 0) {
	                    c[n >> 2] = 0;
	                    T = c[n >> 2] | 0;
	                    i = l;
	                    return T | 0
	                }
	                c[A >> 2] = (c[p >> 2] | 0) + (c[q >> 2] | 0);
	                if (!((c[(c[o >> 2] | 0) + 248 >> 2] | 0) > 40 ? (c[(c[o >> 2] | 0) + 360 >> 2] & 524288 | 0) == 0 : 0))U = 5;
	                if ((U | 0) == 5 ? (c[(c[o >> 2] | 0) + 248 >> 2] | 0) <= 1024 : 0) {
	                    c[w >> 2] = 300;
	                    c[v >> 2] = Cb[c[135752 >> 2] & 511](c[w >> 2] | 0) | 0;
	                    a:do if (!(c[v >> 2] | 0))U = 88; else {
	                        if ((c[p >> 2] | 0) >>> 0 < (c[A >> 2] | 0) >>> 0)c[C >> 2] = oe(c[o >> 2] | 0, c[p >> 2] | 0, D) | 0; else c[C >> 2] = 0;
	                        while (1) {
	                            if (!(c[C >> 2] | 0))break;
	                            if ((c[C >> 2] | 0) == (d[s >> 0] | 0 | 0))break;
	                            if ((c[C >> 2] | 0) == (d[t >> 0] | 0 | 0))break;
	                            if ((c[C >> 2] | 0) == 0 ? 1 : (c[C >> 2] | 0) == (d[u >> 0] | 0 | 0))break;
	                            if ((c[C >> 2] | 0) == 38 ? (d[(c[p >> 2] | 0) + 1 >> 0] | 0 | 0) == 35 : 0) {
	                                c[E >> 2] = yg(c[o >> 2] | 0, p) | 0;
	                                if (c[E >> 2] | 0) {
	                                    q = pe((c[v >> 2] | 0) + (c[x >> 2] | 0) | 0, c[E >> 2] | 0) | 0;
	                                    c[x >> 2] = (c[x >> 2] | 0) + q
	                                }
	                                if (((c[x >> 2] | 0) + 100 | 0) >>> 0 > (c[w >> 2] | 0) >>> 0) {
	                                    c[G >> 2] = (c[w >> 2] << 1) + 100;
	                                    if ((c[G >> 2] | 0) >>> 0 < (c[w >> 2] | 0) >>> 0) {
	                                        U = 88;
	                                        break a
	                                    }
	                                    c[F >> 2] = Hb[c[135760 >> 2] & 511](c[v >> 2] | 0, c[G >> 2] | 0) | 0;
	                                    if (!(c[F >> 2] | 0)) {
	                                        U = 88;
	                                        break a
	                                    }
	                                    c[v >> 2] = c[F >> 2];
	                                    c[w >> 2] = c[G >> 2]
	                                }
	                            } else U = 23;
	                            b:do if ((U | 0) == 23) {
	                                U = 0;
	                                if ((c[C >> 2] | 0) == 38 ? (c[r >> 2] & 1 | 0) != 0 : 0) {
	                                    if (c[33952] | 0) {
	                                        q = c[33976] | 0;
	                                        k = c[33980] | 0;
	                                        c[m >> 2] = c[p >> 2];
	                                        Db[q & 511](k, 65512, m)
	                                    }
	                                    c[B >> 2] = zg(c[o >> 2] | 0, p) | 0;
	                                    if ((c[(c[o >> 2] | 0) + 388 >> 2] | 0) == 89)break a;
	                                    if ((c[(c[o >> 2] | 0) + 388 >> 2] | 0) == 1)break a;
	                                    sg(c[o >> 2] | 0, 0, c[B >> 2] | 0, 0) | 0;
	                                    if (c[B >> 2] | 0) {
	                                        k = (c[o >> 2] | 0) + 440 | 0;
	                                        c[k >> 2] = (c[k >> 2] | 0) + ((c[(c[B >> 2] | 0) + 72 >> 2] | 0) / 2 | 0)
	                                    }
	                                    do if (c[B >> 2] | 0) {
	                                        if ((c[(c[B >> 2] | 0) + 48 >> 2] | 0) != 6)break;
	                                        if (!(c[(c[B >> 2] | 0) + 40 >> 2] | 0)) {
	                                            xg(c[o >> 2] | 0, 1, 65560);
	                                            break b
	                                        }
	                                        k = pe((c[v >> 2] | 0) + (c[x >> 2] | 0) | 0, d[c[(c[B >> 2] | 0) + 40 >> 2] >> 0] | 0) | 0;
	                                        c[x >> 2] = (c[x >> 2] | 0) + k;
	                                        if (((c[x >> 2] | 0) + 100 | 0) >>> 0 <= (c[w >> 2] | 0) >>> 0)break b;
	                                        c[I >> 2] = (c[w >> 2] << 1) + 100;
	                                        if ((c[I >> 2] | 0) >>> 0 < (c[w >> 2] | 0) >>> 0) {
	                                            U = 88;
	                                            break a
	                                        }
	                                        c[H >> 2] = Hb[c[135760 >> 2] & 511](c[v >> 2] | 0, c[I >> 2] | 0) | 0;
	                                        if (!(c[H >> 2] | 0)) {
	                                            U = 88;
	                                            break a
	                                        }
	                                        c[v >> 2] = c[H >> 2];
	                                        c[w >> 2] = c[I >> 2];
	                                        break b
	                                    } while (0);
	                                    do if (c[B >> 2] | 0) {
	                                        if (!(c[(c[B >> 2] | 0) + 40 >> 2] | 0))break;
	                                        k = (c[o >> 2] | 0) + 248 | 0;
	                                        c[k >> 2] = (c[k >> 2] | 0) + 1;
	                                        c[z >> 2] = af(c[o >> 2] | 0, c[(c[B >> 2] | 0) + 40 >> 2] | 0, c[r >> 2] | 0, 0, 0, 0) | 0;
	                                        k = (c[o >> 2] | 0) + 248 | 0;
	                                        c[k >> 2] = (c[k >> 2] | 0) + -1;
	                                        if (!(c[z >> 2] | 0))break b;
	                                        c[y >> 2] = c[z >> 2];
	                                        while (1) {
	                                            if (!(d[c[y >> 2] >> 0] | 0))break;
	                                            k = c[y >> 2] | 0;
	                                            c[y >> 2] = k + 1;
	                                            q = a[k >> 0] | 0;
	                                            k = c[x >> 2] | 0;
	                                            c[x >> 2] = k + 1;
	                                            a[(c[v >> 2] | 0) + k >> 0] = q;
	                                            if (((c[x >> 2] | 0) + 100 | 0) >>> 0 <= (c[w >> 2] | 0) >>> 0)continue;
	                                            if (sg(c[o >> 2] | 0, c[x >> 2] | 0, c[B >> 2] | 0, 0) | 0)break a;
	                                            c[K >> 2] = (c[w >> 2] << 1) + 100;
	                                            if ((c[K >> 2] | 0) >>> 0 < (c[w >> 2] | 0) >>> 0) {
	                                                U = 88;
	                                                break a
	                                            }
	                                            c[J >> 2] = Hb[c[135760 >> 2] & 511](c[v >> 2] | 0, c[K >> 2] | 0) | 0;
	                                            if (!(c[J >> 2] | 0)) {
	                                                U = 88;
	                                                break a
	                                            }
	                                            c[v >> 2] = c[J >> 2];
	                                            c[w >> 2] = c[K >> 2]
	                                        }
	                                        zb[c[135736 >> 2] & 511](c[z >> 2] | 0);
	                                        c[z >> 2] = 0;
	                                        break b
	                                    } while (0);
	                                    if (!(c[B >> 2] | 0))break;
	                                    c[L >> 2] = xy(c[(c[B >> 2] | 0) + 8 >> 2] | 0) | 0;
	                                    c[M >> 2] = c[(c[B >> 2] | 0) + 8 >> 2];
	                                    q = c[x >> 2] | 0;
	                                    c[x >> 2] = q + 1;
	                                    a[(c[v >> 2] | 0) + q >> 0] = 38;
	                                    if (((c[x >> 2] | 0) + (c[L >> 2] | 0) + 100 | 0) >>> 0 > (c[w >> 2] | 0) >>> 0) {
	                                        c[O >> 2] = (c[w >> 2] << 1) + (c[L >> 2] | 0) + 100;
	                                        if ((c[O >> 2] | 0) >>> 0 < (c[w >> 2] | 0) >>> 0) {
	                                            U = 88;
	                                            break a
	                                        }
	                                        c[N >> 2] = Hb[c[135760 >> 2] & 511](c[v >> 2] | 0, c[O >> 2] | 0) | 0;
	                                        if (!(c[N >> 2] | 0)) {
	                                            U = 88;
	                                            break a
	                                        }
	                                        c[v >> 2] = c[N >> 2];
	                                        c[w >> 2] = c[O >> 2]
	                                    }
	                                    while (1) {
	                                        if ((c[L >> 2] | 0) <= 0)break;
	                                        q = c[M >> 2] | 0;
	                                        c[M >> 2] = q + 1;
	                                        k = a[q >> 0] | 0;
	                                        q = c[x >> 2] | 0;
	                                        c[x >> 2] = q + 1;
	                                        a[(c[v >> 2] | 0) + q >> 0] = k;
	                                        c[L >> 2] = (c[L >> 2] | 0) + -1
	                                    }
	                                    k = c[x >> 2] | 0;
	                                    c[x >> 2] = k + 1;
	                                    a[(c[v >> 2] | 0) + k >> 0] = 59;
	                                    break
	                                }
	                                if ((c[C >> 2] | 0) == 37 ? (c[r >> 2] & 2 | 0) != 0 : 0) {
	                                    if (c[33952] | 0) {
	                                        k = c[33976] | 0;
	                                        q = c[33980] | 0;
	                                        c[m >> 2] = c[p >> 2];
	                                        Db[k & 511](q, 65600, m)
	                                    }
	                                    c[B >> 2] = Ag(c[o >> 2] | 0, p) | 0;
	                                    if ((c[(c[o >> 2] | 0) + 388 >> 2] | 0) == 89)break a;
	                                    sg(c[o >> 2] | 0, 0, c[B >> 2] | 0, 0) | 0;
	                                    if (c[B >> 2] | 0) {
	                                        q = (c[o >> 2] | 0) + 440 | 0;
	                                        c[q >> 2] = (c[q >> 2] | 0) + ((c[(c[B >> 2] | 0) + 72 >> 2] | 0) / 2 | 0)
	                                    }
	                                    if (!(c[B >> 2] | 0))break;
	                                    if (!(c[(c[B >> 2] | 0) + 40 >> 2] | 0))Bg(c[o >> 2] | 0, c[B >> 2] | 0) | 0;
	                                    q = (c[o >> 2] | 0) + 248 | 0;
	                                    c[q >> 2] = (c[q >> 2] | 0) + 1;
	                                    c[z >> 2] = af(c[o >> 2] | 0, c[(c[B >> 2] | 0) + 40 >> 2] | 0, c[r >> 2] | 0, 0, 0, 0) | 0;
	                                    q = (c[o >> 2] | 0) + 248 | 0;
	                                    c[q >> 2] = (c[q >> 2] | 0) + -1;
	                                    if (!(c[z >> 2] | 0))break;
	                                    c[y >> 2] = c[z >> 2];
	                                    while (1) {
	                                        if (!(d[c[y >> 2] >> 0] | 0))break;
	                                        q = c[y >> 2] | 0;
	                                        c[y >> 2] = q + 1;
	                                        k = a[q >> 0] | 0;
	                                        q = c[x >> 2] | 0;
	                                        c[x >> 2] = q + 1;
	                                        a[(c[v >> 2] | 0) + q >> 0] = k;
	                                        if (((c[x >> 2] | 0) + 100 | 0) >>> 0 <= (c[w >> 2] | 0) >>> 0)continue;
	                                        if (sg(c[o >> 2] | 0, c[x >> 2] | 0, c[B >> 2] | 0, 0) | 0)break a;
	                                        c[Q >> 2] = (c[w >> 2] << 1) + 100;
	                                        if ((c[Q >> 2] | 0) >>> 0 < (c[w >> 2] | 0) >>> 0) {
	                                            U = 88;
	                                            break a
	                                        }
	                                        c[P >> 2] = Hb[c[135760 >> 2] & 511](c[v >> 2] | 0, c[Q >> 2] | 0) | 0;
	                                        if (!(c[P >> 2] | 0)) {
	                                            U = 88;
	                                            break a
	                                        }
	                                        c[v >> 2] = c[P >> 2];
	                                        c[w >> 2] = c[Q >> 2]
	                                    }
	                                    zb[c[135736 >> 2] & 511](c[z >> 2] | 0);
	                                    c[z >> 2] = 0;
	                                    break
	                                }
	                                if ((c[D >> 2] | 0) == 1) {
	                                    k = c[C >> 2] & 255;
	                                    q = c[x >> 2] | 0;
	                                    c[x >> 2] = q + 1;
	                                    a[(c[v >> 2] | 0) + q >> 0] = k
	                                } else {
	                                    k = pe((c[v >> 2] | 0) + (c[x >> 2] | 0) | 0, c[C >> 2] | 0) | 0;
	                                    c[x >> 2] = (c[x >> 2] | 0) + k
	                                }
	                                c[p >> 2] = (c[p >> 2] | 0) + (c[D >> 2] | 0);
	                                if (((c[x >> 2] | 0) + 100 | 0) >>> 0 > (c[w >> 2] | 0) >>> 0) {
	                                    c[S >> 2] = (c[w >> 2] << 1) + 100;
	                                    if ((c[S >> 2] | 0) >>> 0 < (c[w >> 2] | 0) >>> 0) {
	                                        U = 88;
	                                        break a
	                                    }
	                                    c[R >> 2] = Hb[c[135760 >> 2] & 511](c[v >> 2] | 0, c[S >> 2] | 0) | 0;
	                                    if (!(c[R >> 2] | 0)) {
	                                        U = 88;
	                                        break a
	                                    }
	                                    c[v >> 2] = c[R >> 2];
	                                    c[w >> 2] = c[S >> 2]
	                                }
	                            } while (0);
	                            if ((c[p >> 2] | 0) >>> 0 < (c[A >> 2] | 0) >>> 0) {
	                                c[C >> 2] = oe(c[o >> 2] | 0, c[p >> 2] | 0, D) | 0;
	                                continue
	                            } else {
	                                c[C >> 2] = 0;
	                                continue
	                            }
	                        }
	                        a[(c[v >> 2] | 0) + (c[x >> 2] | 0) >> 0] = 0;
	                        c[n >> 2] = c[v >> 2];
	                        T = c[n >> 2] | 0;
	                        i = l;
	                        return T | 0
	                    } while (0);
	                    if ((U | 0) == 88)ie(c[o >> 2] | 0, 0);
	                    if (c[z >> 2] | 0)zb[c[135736 >> 2] & 511](c[z >> 2] | 0);
	                    if (c[v >> 2] | 0)zb[c[135736 >> 2] & 511](c[v >> 2] | 0);
	                    c[n >> 2] = 0;
	                    T = c[n >> 2] | 0;
	                    i = l;
	                    return T | 0
	                }
	                og(c[o >> 2] | 0, 89, 0);
	                c[n >> 2] = 0;
	                T = c[n >> 2] | 0;
	                i = l;
	                return T | 0
	            }

	            function af(b, d, e, f, g, h) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                j = i;
	                i = i + 32 | 0;
	                k = j + 12 | 0;
	                l = j + 8 | 0;
	                m = j + 4 | 0;
	                n = j;
	                o = j + 18 | 0;
	                p = j + 17 | 0;
	                q = j + 16 | 0;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                a[o >> 0] = f;
	                a[p >> 0] = g;
	                a[q >> 0] = h;
	                if ((c[l >> 2] | 0) == 0 | (c[m >> 2] | 0) == 0) {
	                    c[k >> 2] = 0;
	                    r = c[k >> 2] | 0;
	                    i = j;
	                    return r | 0
	                } else {
	                    h = c[l >> 2] | 0;
	                    l = c[m >> 2] | 0;
	                    g = xy(c[m >> 2] | 0) | 0;
	                    c[k >> 2] = $e(h, l, g, c[n >> 2] | 0, a[o >> 0] | 0, a[p >> 0] | 0, a[q >> 0] | 0) | 0;
	                    r = c[k >> 2] | 0;
	                    i = j;
	                    return r | 0
	                }
	                return 0
	            }

	            function bf(b, e, f) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0;
	                g = i;
	                i = i + 176 | 0;
	                h = g + 52 | 0;
	                j = g + 48 | 0;
	                k = g + 44 | 0;
	                l = g + 40 | 0;
	                m = g + 56 | 0;
	                n = g + 36 | 0;
	                o = g + 32 | 0;
	                p = g + 28 | 0;
	                q = g + 24 | 0;
	                r = g + 20 | 0;
	                s = g + 16 | 0;
	                t = g + 12 | 0;
	                u = g + 8 | 0;
	                v = g + 4 | 0;
	                w = g;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[l >> 2] = f;
	                c[n >> 2] = 0;
	                c[o >> 2] = 0;
	                c[p >> 2] = 100;
	                c[q >> 2] = 0;
	                c[r >> 2] = c[k >> 2];
	                if (!(c[l >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    x = c[h >> 2] | 0;
	                    i = g;
	                    return x | 0
	                }
	                c[c[l >> 2] >> 2] = 0;
	                if (!(c[r >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    x = c[h >> 2] | 0;
	                    i = g;
	                    return x | 0
	                }
	                if ((d[c[r >> 2] >> 0] | 0 | 0) == 58) {
	                    c[h >> 2] = my(c[k >> 2] | 0) | 0;
	                    x = c[h >> 2] | 0;
	                    i = g;
	                    return x | 0
	                }
	                f = c[r >> 2] | 0;
	                c[r >> 2] = f + 1;
	                c[s >> 2] = d[f >> 0];
	                while (1) {
	                    if (!((c[s >> 2] | 0) != 0 & (c[s >> 2] | 0) != 58))break;
	                    if ((c[o >> 2] | 0) >= (c[p >> 2] | 0))break;
	                    f = c[s >> 2] & 255;
	                    e = c[o >> 2] | 0;
	                    c[o >> 2] = e + 1;
	                    a[m + e >> 0] = f;
	                    f = c[r >> 2] | 0;
	                    c[r >> 2] = f + 1;
	                    c[s >> 2] = d[f >> 0]
	                }
	                do if ((c[o >> 2] | 0) >= (c[p >> 2] | 0)) {
	                    c[p >> 2] = c[o >> 2] << 1;
	                    c[n >> 2] = Cb[c[135752 >> 2] & 511](c[p >> 2] | 0) | 0;
	                    if (!(c[n >> 2] | 0)) {
	                        ie(c[j >> 2] | 0, 0);
	                        c[h >> 2] = 0;
	                        x = c[h >> 2] | 0;
	                        i = g;
	                        return x | 0
	                    }
	                    eU(c[n >> 2] | 0, m | 0, c[o >> 2] | 0) | 0;
	                    while (1) {
	                        if (c[s >> 2] | 0)y = (c[s >> 2] | 0) != 58; else y = 0;
	                        z = c[o >> 2] | 0;
	                        if (!y) {
	                            A = 23;
	                            break
	                        }
	                        if ((z + 10 | 0) > (c[p >> 2] | 0)) {
	                            c[p >> 2] = c[p >> 2] << 1;
	                            c[t >> 2] = Hb[c[135760 >> 2] & 511](c[n >> 2] | 0, c[p >> 2] | 0) | 0;
	                            if (!(c[t >> 2] | 0))break;
	                            c[n >> 2] = c[t >> 2]
	                        }
	                        f = c[s >> 2] & 255;
	                        e = c[o >> 2] | 0;
	                        c[o >> 2] = e + 1;
	                        a[(c[n >> 2] | 0) + e >> 0] = f;
	                        f = c[r >> 2] | 0;
	                        c[r >> 2] = f + 1;
	                        c[s >> 2] = d[f >> 0]
	                    }
	                    if ((A | 0) == 23) {
	                        a[(c[n >> 2] | 0) + z >> 0] = 0;
	                        break
	                    }
	                    zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                    ie(c[j >> 2] | 0, 0);
	                    c[h >> 2] = 0;
	                    x = c[h >> 2] | 0;
	                    i = g;
	                    return x | 0
	                } while (0);
	                if ((c[s >> 2] | 0) == 58 ? (d[c[r >> 2] >> 0] | 0 | 0) == 0 : 0) {
	                    if (c[n >> 2] | 0)zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                    c[c[l >> 2] >> 2] = 0;
	                    c[h >> 2] = my(c[k >> 2] | 0) | 0;
	                    x = c[h >> 2] | 0;
	                    i = g;
	                    return x | 0
	                }
	                if (!(c[n >> 2] | 0))c[q >> 2] = ly(m, c[o >> 2] | 0) | 0; else {
	                    c[q >> 2] = c[n >> 2];
	                    c[n >> 2] = 0;
	                    c[p >> 2] = 100
	                }
	                do if ((c[s >> 2] | 0) == 58) {
	                    c[s >> 2] = d[c[r >> 2] >> 0];
	                    c[c[l >> 2] >> 2] = c[q >> 2];
	                    if (!(c[s >> 2] | 0)) {
	                        c[h >> 2] = ly(65640, 0) | 0;
	                        x = c[h >> 2] | 0;
	                        i = g;
	                        return x | 0
	                    }
	                    c[o >> 2] = 0;
	                    do if (!((c[s >> 2] | 0) >= 97 & (c[s >> 2] | 0) <= 122) ? !((c[s >> 2] | 0) >= 65 & (c[s >> 2] | 0) <= 90 | (c[s >> 2] | 0) == 95 | (c[s >> 2] | 0) == 58) : 0) {
	                        c[v >> 2] = oe(c[j >> 2] | 0, c[r >> 2] | 0, u) | 0;
	                        z = c[v >> 2] | 0;
	                        if ((c[v >> 2] | 0) < 256) {
	                            if (65 <= (z | 0) & (c[v >> 2] | 0) <= 90)break;
	                            if (97 <= (c[v >> 2] | 0) & (c[v >> 2] | 0) <= 122)break;
	                            if (192 <= (c[v >> 2] | 0) & (c[v >> 2] | 0) <= 214)break;
	                            if (216 <= (c[v >> 2] | 0) & (c[v >> 2] | 0) <= 246 | 248 <= (c[v >> 2] | 0))break
	                        } else if (DQ(z, 199744) | 0)break;
	                        z = c[v >> 2] | 0;
	                        if ((c[v >> 2] | 0) < 256) {
	                            if ((z | 0) == 95)break
	                        } else {
	                            if (19968 <= (z | 0) & (c[v >> 2] | 0) <= 40869 | (c[v >> 2] | 0) == 12295)break;
	                            if (!((12321 <= (c[v >> 2] | 0) & (c[v >> 2] | 0) <= 12329 ^ 1) & (c[v >> 2] | 0) != 95))break
	                        }
	                        pg(c[j >> 2] | 0, 202, 65648, c[k >> 2] | 0)
	                    } while (0);
	                    c[r >> 2] = (c[r >> 2] | 0) + 1;
	                    while (1) {
	                        if (!(c[s >> 2] | 0))break;
	                        if ((c[o >> 2] | 0) >= (c[p >> 2] | 0))break;
	                        z = c[s >> 2] & 255;
	                        t = c[o >> 2] | 0;
	                        c[o >> 2] = t + 1;
	                        a[m + t >> 0] = z;
	                        z = c[r >> 2] | 0;
	                        c[r >> 2] = z + 1;
	                        c[s >> 2] = d[z >> 0]
	                    }
	                    do if ((c[o >> 2] | 0) >= (c[p >> 2] | 0)) {
	                        c[p >> 2] = c[o >> 2] << 1;
	                        c[n >> 2] = Cb[c[135752 >> 2] & 511](c[p >> 2] | 0) | 0;
	                        if (!(c[n >> 2] | 0)) {
	                            ie(c[j >> 2] | 0, 0);
	                            c[h >> 2] = 0;
	                            x = c[h >> 2] | 0;
	                            i = g;
	                            return x | 0
	                        }
	                        eU(c[n >> 2] | 0, m | 0, c[o >> 2] | 0) | 0;
	                        while (1) {
	                            B = c[o >> 2] | 0;
	                            if (!(c[s >> 2] | 0)) {
	                                A = 62;
	                                break
	                            }
	                            if ((B + 10 | 0) > (c[p >> 2] | 0)) {
	                                c[p >> 2] = c[p >> 2] << 1;
	                                c[w >> 2] = Hb[c[135760 >> 2] & 511](c[n >> 2] | 0, c[p >> 2] | 0) | 0;
	                                if (!(c[w >> 2] | 0))break;
	                                c[n >> 2] = c[w >> 2]
	                            }
	                            z = c[s >> 2] & 255;
	                            t = c[o >> 2] | 0;
	                            c[o >> 2] = t + 1;
	                            a[(c[n >> 2] | 0) + t >> 0] = z;
	                            z = c[r >> 2] | 0;
	                            c[r >> 2] = z + 1;
	                            c[s >> 2] = d[z >> 0]
	                        }
	                        if ((A | 0) == 62) {
	                            a[(c[n >> 2] | 0) + B >> 0] = 0;
	                            break
	                        }
	                        ie(c[j >> 2] | 0, 0);
	                        zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                        c[h >> 2] = 0;
	                        x = c[h >> 2] | 0;
	                        i = g;
	                        return x | 0
	                    } while (0);
	                    if (!(c[n >> 2] | 0)) {
	                        c[q >> 2] = ly(m, c[o >> 2] | 0) | 0;
	                        break
	                    } else {
	                        c[q >> 2] = c[n >> 2];
	                        break
	                    }
	                } while (0);
	                c[h >> 2] = c[q >> 2];
	                x = c[h >> 2] | 0;
	                i = g;
	                return x | 0
	            }

	            function cf(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                e = i;
	                i = i + 144 | 0;
	                f = e + 32 | 0;
	                g = e + 28 | 0;
	                h = e + 36 | 0;
	                j = e + 24 | 0;
	                k = e + 20 | 0;
	                l = e + 16 | 0;
	                m = e + 12 | 0;
	                n = e + 8 | 0;
	                o = e + 4 | 0;
	                p = e;
	                c[g >> 2] = b;
	                c[j >> 2] = 0;
	                c[m >> 2] = 0;
	                if ((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[g >> 2] | 0);
	                if ((c[(c[g >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                    c[f >> 2] = 0;
	                    q = c[f >> 2] | 0;
	                    i = e;
	                    return q | 0
	                }
	                c[l >> 2] = ne(c[g >> 2] | 0, k) | 0;
	                while (1) {
	                    if (!(Cg(c[g >> 2] | 0, c[l >> 2] | 0) | 0)) {
	                        r = 55;
	                        break
	                    }
	                    b = c[m >> 2] | 0;
	                    c[m >> 2] = b + 1;
	                    if (((b | 0) > 100 ? (c[m >> 2] = 0, (c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0) : 0) ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[g >> 2] | 0);
	                    if ((c[k >> 2] | 0) == 1) {
	                        b = c[l >> 2] & 255;
	                        s = c[j >> 2] | 0;
	                        c[j >> 2] = s + 1;
	                        a[h + s >> 0] = b
	                    } else {
	                        b = pe(h + (c[j >> 2] | 0) | 0, c[l >> 2] | 0) | 0;
	                        c[j >> 2] = (c[j >> 2] | 0) + b
	                    }
	                    b = c[(c[g >> 2] | 0) + 36 >> 2] | 0;
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                        s = b + 28 | 0;
	                        c[s >> 2] = (c[s >> 2] | 0) + 1;
	                        c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                    } else {
	                        s = b + 32 | 0;
	                        c[s >> 2] = (c[s >> 2] | 0) + 1
	                    }
	                    s = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[s >> 2] = (c[s >> 2] | 0) + (c[k >> 2] | 0);
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[g >> 2] | 0);
	                    c[l >> 2] = ne(c[g >> 2] | 0, k) | 0;
	                    if (!(c[l >> 2] | 0)) {
	                        c[m >> 2] = 0;
	                        if ((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[g >> 2] | 0);
	                        if ((c[(c[g >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                            r = 25;
	                            break
	                        }
	                        c[l >> 2] = ne(c[g >> 2] | 0, k) | 0
	                    }
	                    if ((c[j >> 2] | 0) >= 100) {
	                        r = 28;
	                        break
	                    }
	                }
	                if ((r | 0) == 25) {
	                    c[f >> 2] = 0;
	                    q = c[f >> 2] | 0;
	                    i = e;
	                    return q | 0
	                } else if ((r | 0) == 28) {
	                    c[o >> 2] = c[j >> 2] << 1;
	                    c[n >> 2] = Cb[c[135752 >> 2] & 511](c[o >> 2] | 0) | 0;
	                    if (!(c[n >> 2] | 0)) {
	                        ie(c[g >> 2] | 0, 0);
	                        c[f >> 2] = 0;
	                        q = c[f >> 2] | 0;
	                        i = e;
	                        return q | 0
	                    }
	                    eU(c[n >> 2] | 0, h | 0, c[j >> 2] | 0) | 0;
	                    while (1) {
	                        if (!(Cg(c[g >> 2] | 0, c[l >> 2] | 0) | 0)) {
	                            r = 54;
	                            break
	                        }
	                        s = c[m >> 2] | 0;
	                        c[m >> 2] = s + 1;
	                        if ((s | 0) > 100) {
	                            c[m >> 2] = 0;
	                            if ((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[g >> 2] | 0);
	                            if ((c[(c[g >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                                r = 37;
	                                break
	                            }
	                        }
	                        if (((c[j >> 2] | 0) + 10 | 0) > (c[o >> 2] | 0)) {
	                            if ((c[o >> 2] | 0) > 5e4 ? (c[(c[g >> 2] | 0) + 360 >> 2] & 524288 | 0) == 0 : 0) {
	                                r = 41;
	                                break
	                            }
	                            c[o >> 2] = c[o >> 2] << 1;
	                            c[p >> 2] = Hb[c[135760 >> 2] & 511](c[n >> 2] | 0, c[o >> 2] | 0) | 0;
	                            if (!(c[p >> 2] | 0)) {
	                                r = 43;
	                                break
	                            }
	                            c[n >> 2] = c[p >> 2]
	                        }
	                        if ((c[k >> 2] | 0) == 1) {
	                            s = c[l >> 2] & 255;
	                            b = c[j >> 2] | 0;
	                            c[j >> 2] = b + 1;
	                            a[(c[n >> 2] | 0) + b >> 0] = s
	                        } else {
	                            s = pe((c[n >> 2] | 0) + (c[j >> 2] | 0) | 0, c[l >> 2] | 0) | 0;
	                            c[j >> 2] = (c[j >> 2] | 0) + s
	                        }
	                        s = c[(c[g >> 2] | 0) + 36 >> 2] | 0;
	                        if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                            b = s + 28 | 0;
	                            c[b >> 2] = (c[b >> 2] | 0) + 1;
	                            c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                        } else {
	                            b = s + 32 | 0;
	                            c[b >> 2] = (c[b >> 2] | 0) + 1
	                        }
	                        b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                        c[b >> 2] = (c[b >> 2] | 0) + (c[k >> 2] | 0);
	                        if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[g >> 2] | 0);
	                        c[l >> 2] = ne(c[g >> 2] | 0, k) | 0
	                    }
	                    if ((r | 0) == 37) {
	                        zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                        c[f >> 2] = 0;
	                        q = c[f >> 2] | 0;
	                        i = e;
	                        return q | 0
	                    } else if ((r | 0) == 41) {
	                        og(c[g >> 2] | 0, 110, 65696);
	                        zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                        c[f >> 2] = 0;
	                        q = c[f >> 2] | 0;
	                        i = e;
	                        return q | 0
	                    } else if ((r | 0) == 43) {
	                        ie(c[g >> 2] | 0, 0);
	                        zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                        c[f >> 2] = 0;
	                        q = c[f >> 2] | 0;
	                        i = e;
	                        return q | 0
	                    } else if ((r | 0) == 54) {
	                        a[(c[n >> 2] | 0) + (c[j >> 2] | 0) >> 0] = 0;
	                        c[f >> 2] = c[n >> 2];
	                        q = c[f >> 2] | 0;
	                        i = e;
	                        return q | 0
	                    }
	                } else if ((r | 0) == 55) {
	                    if (!(c[j >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        q = c[f >> 2] | 0;
	                        i = e;
	                        return q | 0
	                    }
	                    if ((c[j >> 2] | 0) > 5e4 ? (c[(c[g >> 2] | 0) + 360 >> 2] & 524288 | 0) == 0 : 0) {
	                        og(c[g >> 2] | 0, 110, 65696);
	                        c[f >> 2] = 0;
	                        q = c[f >> 2] | 0;
	                        i = e;
	                        return q | 0
	                    }
	                    c[f >> 2] = ly(h, c[j >> 2] | 0) | 0;
	                    q = c[f >> 2] | 0;
	                    i = e;
	                    return q | 0
	                }
	                return 0
	            }

	            function df(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0;
	                f = i;
	                i = i + 64 | 0;
	                g = f + 48 | 0;
	                h = f + 44 | 0;
	                j = f + 40 | 0;
	                k = f + 36 | 0;
	                l = f + 32 | 0;
	                m = f + 28 | 0;
	                n = f + 24 | 0;
	                o = f + 20 | 0;
	                p = f + 53 | 0;
	                q = f + 16 | 0;
	                r = f + 12 | 0;
	                s = f + 8 | 0;
	                t = f + 4 | 0;
	                u = f;
	                v = f + 52 | 0;
	                c[h >> 2] = b;
	                c[j >> 2] = e;
	                c[k >> 2] = 0;
	                c[l >> 2] = 0;
	                c[m >> 2] = 100;
	                c[q >> 2] = 0;
	                c[r >> 2] = 0;
	                do if ((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 34)a[p >> 0] = 34; else {
	                    if ((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 39) {
	                        a[p >> 0] = 39;
	                        break
	                    }
	                    og(c[h >> 2] | 0, 36, 0);
	                    c[g >> 2] = 0;
	                    w = c[g >> 2] | 0;
	                    i = f;
	                    return w | 0
	                } while (0);
	                c[k >> 2] = Cb[c[135752 >> 2] & 511](c[m >> 2] | 0) | 0;
	                e = c[h >> 2] | 0;
	                if (!(c[k >> 2] | 0)) {
	                    ie(e, 0);
	                    c[g >> 2] = 0;
	                    w = c[g >> 2] | 0;
	                    i = f;
	                    return w | 0
	                }
	                c[e + 172 >> 2] = 11;
	                c[s >> 2] = c[(c[h >> 2] | 0) + 36 >> 2];
	                if ((c[(c[h >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[h >> 2] | 0);
	                if ((c[(c[h >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                    zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    c[g >> 2] = 0;
	                    w = c[g >> 2] | 0;
	                    i = f;
	                    return w | 0
	                }
	                me(c[h >> 2] | 0);
	                c[n >> 2] = ne(c[h >> 2] | 0, o) | 0;
	                while (1) {
	                    e = c[n >> 2] | 0;
	                    if ((c[n >> 2] | 0) < 256)if (9 <= (e | 0) & (c[n >> 2] | 0) <= 10 | (c[n >> 2] | 0) == 13 | 32 <= (c[n >> 2] | 0))x = 19; else y = 0; else if ((!(256 <= (e | 0) & (c[n >> 2] | 0) <= 55295) ? !(57344 <= (c[n >> 2] | 0) & (c[n >> 2] | 0) <= 65533) : 0) ? !(65536 <= (c[n >> 2] | 0) & (c[n >> 2] | 0) <= 1114111) : 0)y = 0; else x = 19;
	                    do if ((x | 0) == 19) {
	                        x = 0;
	                        if ((c[n >> 2] | 0) == (d[p >> 0] | 0 | 0) ? (c[(c[h >> 2] | 0) + 36 >> 2] | 0) == (c[s >> 2] | 0) : 0) {
	                            y = 0;
	                            break
	                        }
	                        y = (c[(c[h >> 2] | 0) + 172 >> 2] | 0) != -1
	                    } while (0);
	                    z = c[l >> 2] | 0;
	                    if (!y)break;
	                    if ((z + 5 | 0) >= (c[m >> 2] | 0)) {
	                        c[m >> 2] = c[m >> 2] << 1;
	                        c[t >> 2] = Hb[c[135760 >> 2] & 511](c[k >> 2] | 0, c[m >> 2] | 0) | 0;
	                        if (!(c[t >> 2] | 0)) {
	                            x = 25;
	                            break
	                        }
	                        c[k >> 2] = c[t >> 2]
	                    }
	                    if ((c[o >> 2] | 0) == 1) {
	                        e = c[n >> 2] & 255;
	                        b = c[l >> 2] | 0;
	                        c[l >> 2] = b + 1;
	                        a[(c[k >> 2] | 0) + b >> 0] = e
	                    } else {
	                        e = pe((c[k >> 2] | 0) + (c[l >> 2] | 0) | 0, c[n >> 2] | 0) | 0;
	                        c[l >> 2] = (c[l >> 2] | 0) + e
	                    }
	                    e = c[(c[h >> 2] | 0) + 36 >> 2] | 0;
	                    if ((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                        b = e + 28 | 0;
	                        c[b >> 2] = (c[b >> 2] | 0) + 1;
	                        c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                    } else {
	                        b = e + 32 | 0;
	                        c[b >> 2] = (c[b >> 2] | 0) + 1
	                    }
	                    b = (c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + (c[o >> 2] | 0);
	                    if ((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[h >> 2] | 0);
	                    while (1) {
	                        if (!(d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0))A = (c[(c[h >> 2] | 0) + 40 >> 2] | 0) > 1; else A = 0;
	                        B = c[h >> 2] | 0;
	                        if (!A)break;
	                        Ve(B) | 0
	                    }
	                    if ((c[B + 292 >> 2] | 0) == 0 ? ((c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[h >> 2] | 0);
	                    c[n >> 2] = ne(c[h >> 2] | 0, o) | 0;
	                    if (c[n >> 2] | 0)continue;
	                    if ((c[(c[h >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[h >> 2] | 0);
	                    c[n >> 2] = ne(c[h >> 2] | 0, o) | 0
	                }
	                if ((x | 0) == 25) {
	                    ie(c[h >> 2] | 0, 0);
	                    zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    c[g >> 2] = 0;
	                    w = c[g >> 2] | 0;
	                    i = f;
	                    return w | 0
	                }
	                a[(c[k >> 2] | 0) + z >> 0] = 0;
	                if ((c[(c[h >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                    zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    c[g >> 2] = 0;
	                    w = c[g >> 2] | 0;
	                    i = f;
	                    return w | 0
	                }
	                c[r >> 2] = c[k >> 2];
	                while (1) {
	                    if (!(d[c[r >> 2] >> 0] | 0))break;
	                    if ((d[c[r >> 2] >> 0] | 0 | 0) != 37) {
	                        if ((d[c[r >> 2] >> 0] | 0 | 0) == 38 ? (d[(c[r >> 2] | 0) + 1 >> 0] | 0 | 0) != 35 : 0)x = 54
	                    } else x = 54;
	                    if ((x | 0) == 54) {
	                        x = 0;
	                        a[v >> 0] = a[c[r >> 2] >> 0] | 0;
	                        c[r >> 2] = (c[r >> 2] | 0) + 1;
	                        c[u >> 2] = Dg(c[h >> 2] | 0, r) | 0;
	                        if (!((c[u >> 2] | 0) != 0 ? (d[c[r >> 2] >> 0] | 0 | 0) == 59 : 0))ng(c[h >> 2] | 0, 87, 65704, d[v >> 0] | 0);
	                        if (((d[v >> 0] | 0 | 0) == 37 ? (c[(c[h >> 2] | 0) + 216 >> 2] | 0) == 1 : 0) ? (c[(c[h >> 2] | 0) + 40 >> 2] | 0) == 1 : 0)og(c[h >> 2] | 0, 88, 0);
	                        if (c[u >> 2] | 0)zb[c[135736 >> 2] & 511](c[u >> 2] | 0);
	                        if (!(d[c[r >> 2] >> 0] | 0))break
	                    }
	                    c[r >> 2] = (c[r >> 2] | 0) + 1
	                }
	                r = c[h >> 2] | 0;
	                do if ((c[n >> 2] | 0) == (d[p >> 0] | 0 | 0)) {
	                    me(r);
	                    c[q >> 2] = af(c[h >> 2] | 0, c[k >> 2] | 0, 2, 0, 0, 0) | 0;
	                    if (c[j >> 2] | 0) {
	                        c[c[j >> 2] >> 2] = c[k >> 2];
	                        break
	                    } else {
	                        zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                        break
	                    }
	                } else {
	                    og(r, 37, 0);
	                    zb[c[135736 >> 2] & 511](c[k >> 2] | 0)
	                } while (0);
	                c[g >> 2] = c[q >> 2];
	                w = c[g >> 2] | 0;
	                i = f;
	                return w | 0
	            }

	            function ef(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) {
	                    c[d >> 2] = Eg(c[e >> 2] | 0, 0, 0, 0) | 0;
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                }
	                c[d >> 2] = 0;
	                f = c[d >> 2] | 0;
	                i = b;
	                return f | 0
	            }

	            function ff(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 36 | 0;
	                g = e + 32 | 0;
	                h = e + 28 | 0;
	                j = e + 24 | 0;
	                k = e + 20 | 0;
	                l = e + 16 | 0;
	                m = e + 12 | 0;
	                n = e + 40 | 0;
	                o = e + 8 | 0;
	                p = e + 4 | 0;
	                q = e;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                c[j >> 2] = 0;
	                c[k >> 2] = 100;
	                c[o >> 2] = c[(c[g >> 2] | 0) + 172 >> 2];
	                c[p >> 2] = 0;
	                if (((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 : 0) ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)Fg(c[g >> 2] | 0);
	                b = c[g >> 2] | 0;
	                do if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 34) {
	                    me(b);
	                    a[n >> 0] = 34
	                } else {
	                    r = c[g >> 2] | 0;
	                    if ((d[c[(c[b + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 39) {
	                        me(r);
	                        a[n >> 0] = 39;
	                        break
	                    }
	                    og(r, 43, 0);
	                    c[f >> 2] = 0;
	                    s = c[f >> 2] | 0;
	                    i = e;
	                    return s | 0
	                } while (0);
	                c[h >> 2] = Cb[c[135752 >> 2] & 511](c[k >> 2] | 0) | 0;
	                b = c[g >> 2] | 0;
	                if (!(c[h >> 2] | 0)) {
	                    ie(b, 0);
	                    c[f >> 2] = 0;
	                    s = c[f >> 2] | 0;
	                    i = e;
	                    return s | 0
	                }
	                c[b + 172 >> 2] = 13;
	                c[l >> 2] = ne(c[g >> 2] | 0, m) | 0;
	                while (1) {
	                    b = c[l >> 2] | 0;
	                    if ((c[l >> 2] | 0) < 256)if (9 <= (b | 0) & (c[l >> 2] | 0) <= 10 | (c[l >> 2] | 0) == 13 | 32 <= (c[l >> 2] | 0))t = 18; else u = 0; else if ((!(256 <= (b | 0) & (c[l >> 2] | 0) <= 55295) ? !(57344 <= (c[l >> 2] | 0) & (c[l >> 2] | 0) <= 65533) : 0) ? !(65536 <= (c[l >> 2] | 0) & (c[l >> 2] | 0) <= 1114111) : 0)u = 0; else t = 18;
	                    if ((t | 0) == 18) {
	                        t = 0;
	                        u = (c[l >> 2] | 0) != (d[n >> 0] | 0 | 0)
	                    }
	                    v = c[j >> 2] | 0;
	                    if (!u) {
	                        t = 50;
	                        break
	                    }
	                    if ((v + 5 | 0) >= (c[k >> 2] | 0)) {
	                        if ((c[k >> 2] | 0) > 5e4 ? (c[(c[g >> 2] | 0) + 360 >> 2] & 524288 | 0) == 0 : 0) {
	                            t = 23;
	                            break
	                        }
	                        c[k >> 2] = c[k >> 2] << 1;
	                        c[q >> 2] = Hb[c[135760 >> 2] & 511](c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                        if (!(c[q >> 2] | 0)) {
	                            t = 25;
	                            break
	                        }
	                        c[h >> 2] = c[q >> 2]
	                    }
	                    c[p >> 2] = (c[p >> 2] | 0) + 1;
	                    if ((c[p >> 2] | 0) > 50) {
	                        if ((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[g >> 2] | 0);
	                        c[p >> 2] = 0;
	                        if ((c[(c[g >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                            t = 32;
	                            break
	                        }
	                    }
	                    if ((c[m >> 2] | 0) == 1) {
	                        b = c[l >> 2] & 255;
	                        r = c[j >> 2] | 0;
	                        c[j >> 2] = r + 1;
	                        a[(c[h >> 2] | 0) + r >> 0] = b
	                    } else {
	                        b = pe((c[h >> 2] | 0) + (c[j >> 2] | 0) | 0, c[l >> 2] | 0) | 0;
	                        c[j >> 2] = (c[j >> 2] | 0) + b
	                    }
	                    b = c[(c[g >> 2] | 0) + 36 >> 2] | 0;
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                        r = b + 28 | 0;
	                        c[r >> 2] = (c[r >> 2] | 0) + 1;
	                        c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                    } else {
	                        r = b + 32 | 0;
	                        c[r >> 2] = (c[r >> 2] | 0) + 1
	                    }
	                    r = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[r >> 2] = (c[r >> 2] | 0) + (c[m >> 2] | 0);
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[g >> 2] | 0);
	                    c[l >> 2] = ne(c[g >> 2] | 0, m) | 0;
	                    if (c[l >> 2] | 0)continue;
	                    if ((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[g >> 2] | 0);
	                    if (((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 : 0) ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)Fg(c[g >> 2] | 0);
	                    c[l >> 2] = ne(c[g >> 2] | 0, m) | 0
	                }
	                if ((t | 0) == 23) {
	                    og(c[g >> 2] | 0, 110, 65768);
	                    zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                    c[(c[g >> 2] | 0) + 172 >> 2] = c[o >> 2];
	                    c[f >> 2] = 0;
	                    s = c[f >> 2] | 0;
	                    i = e;
	                    return s | 0
	                } else if ((t | 0) == 25) {
	                    zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                    ie(c[g >> 2] | 0, 0);
	                    c[(c[g >> 2] | 0) + 172 >> 2] = c[o >> 2];
	                    c[f >> 2] = 0;
	                    s = c[f >> 2] | 0;
	                    i = e;
	                    return s | 0
	                } else if ((t | 0) == 32) {
	                    zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                    c[f >> 2] = 0;
	                    s = c[f >> 2] | 0;
	                    i = e;
	                    return s | 0
	                } else if ((t | 0) == 50) {
	                    a[(c[h >> 2] | 0) + v >> 0] = 0;
	                    c[(c[g >> 2] | 0) + 172 >> 2] = c[o >> 2];
	                    o = c[l >> 2] | 0;
	                    if ((c[l >> 2] | 0) < 256)if (9 <= (o | 0) & (c[l >> 2] | 0) <= 10 | (c[l >> 2] | 0) == 13 | 32 <= (c[l >> 2] | 0))t = 56; else t = 55; else if ((!(256 <= (o | 0) & (c[l >> 2] | 0) <= 55295) ? !(57344 <= (c[l >> 2] | 0) & (c[l >> 2] | 0) <= 65533) : 0) ? !(65536 <= (c[l >> 2] | 0) & (c[l >> 2] | 0) <= 1114111) : 0)t = 55; else t = 56;
	                    if ((t | 0) == 55)og(c[g >> 2] | 0, 44, 0); else if ((t | 0) == 56)me(c[g >> 2] | 0);
	                    c[f >> 2] = c[h >> 2];
	                    s = c[f >> 2] | 0;
	                    i = e;
	                    return s | 0
	                }
	                return 0
	            }

	            function gf(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 28 | 0;
	                g = e + 24 | 0;
	                h = e + 20 | 0;
	                j = e + 16 | 0;
	                k = e + 12 | 0;
	                l = e + 33 | 0;
	                m = e + 32 | 0;
	                n = e + 8 | 0;
	                o = e + 4 | 0;
	                p = e;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                c[j >> 2] = 0;
	                c[k >> 2] = 100;
	                c[n >> 2] = 0;
	                c[o >> 2] = c[(c[g >> 2] | 0) + 172 >> 2];
	                if (((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 : 0) ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)Fg(c[g >> 2] | 0);
	                b = c[g >> 2] | 0;
	                do if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 34) {
	                    me(b);
	                    a[m >> 0] = 34
	                } else {
	                    q = c[g >> 2] | 0;
	                    if ((d[c[(c[b + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 39) {
	                        me(q);
	                        a[m >> 0] = 39;
	                        break
	                    }
	                    og(q, 43, 0);
	                    c[f >> 2] = 0;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                } while (0);
	                c[h >> 2] = Cb[c[135752 >> 2] & 511](c[k >> 2] | 0) | 0;
	                b = c[g >> 2] | 0;
	                if (!(c[h >> 2] | 0)) {
	                    ie(b, 0);
	                    c[f >> 2] = 0;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                }
	                c[b + 172 >> 2] = 16;
	                a[l >> 0] = a[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                while (1) {
	                    if (d[198696 + (d[l >> 0] | 0) >> 0] | 0)s = (d[l >> 0] | 0 | 0) != (d[m >> 0] | 0 | 0); else s = 0;
	                    t = c[j >> 2] | 0;
	                    if (!s) {
	                        u = 38;
	                        break
	                    }
	                    if ((t + 1 | 0) >= (c[k >> 2] | 0)) {
	                        if ((c[k >> 2] | 0) > 5e4 ? (c[(c[g >> 2] | 0) + 360 >> 2] & 524288 | 0) == 0 : 0) {
	                            u = 19;
	                            break
	                        }
	                        c[k >> 2] = c[k >> 2] << 1;
	                        c[p >> 2] = Hb[c[135760 >> 2] & 511](c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                        if (!(c[p >> 2] | 0)) {
	                            u = 21;
	                            break
	                        }
	                        c[h >> 2] = c[p >> 2]
	                    }
	                    b = a[l >> 0] | 0;
	                    q = c[j >> 2] | 0;
	                    c[j >> 2] = q + 1;
	                    a[(c[h >> 2] | 0) + q >> 0] = b;
	                    c[n >> 2] = (c[n >> 2] | 0) + 1;
	                    if ((c[n >> 2] | 0) > 50) {
	                        if ((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[g >> 2] | 0);
	                        c[n >> 2] = 0;
	                        if ((c[(c[g >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                            u = 28;
	                            break
	                        }
	                    }
	                    me(c[g >> 2] | 0);
	                    a[l >> 0] = a[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                    if (d[l >> 0] | 0)continue;
	                    if ((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[g >> 2] | 0);
	                    if (((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 : 0) ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)Fg(c[g >> 2] | 0);
	                    a[l >> 0] = a[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0
	                }
	                if ((u | 0) == 19) {
	                    og(c[g >> 2] | 0, 110, 65784);
	                    zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                    c[f >> 2] = 0;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                } else if ((u | 0) == 21) {
	                    ie(c[g >> 2] | 0, 0);
	                    zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                    c[f >> 2] = 0;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                } else if ((u | 0) == 28) {
	                    zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                    c[f >> 2] = 0;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                } else if ((u | 0) == 38) {
	                    a[(c[h >> 2] | 0) + t >> 0] = 0;
	                    t = c[g >> 2] | 0;
	                    if ((d[l >> 0] | 0 | 0) != (d[m >> 0] | 0 | 0))og(t, 44, 0); else me(t);
	                    c[(c[g >> 2] | 0) + 172 >> 2] = c[o >> 2];
	                    c[f >> 2] = c[h >> 2];
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                }
	                return 0
	            }

	            function hf(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f + 32 | 0;
	                h = f + 28 | 0;
	                j = f + 24 | 0;
	                k = f + 20 | 0;
	                l = f + 16 | 0;
	                m = f + 12 | 0;
	                n = f + 8 | 0;
	                o = f + 4 | 0;
	                p = f;
	                c[g >> 2] = b;
	                c[h >> 2] = e;
	                c[k >> 2] = 0;
	                c[l >> 2] = c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2];
	                c[m >> 2] = c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2];
	                if (((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 : 0) ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)Fg(c[g >> 2] | 0);
	                if ((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[g >> 2] | 0);
	                do if (!(c[h >> 2] | 0)) {
	                    c[j >> 2] = c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                    a:while (1) {
	                        e = c[j >> 2] | 0;
	                        if ((d[c[j >> 2] >> 0] | 0) == 32) {
	                            c[j >> 2] = e + 1;
	                            b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                            c[b >> 2] = (c[b >> 2] | 0) + 1;
	                            continue
	                        }
	                        if ((d[e >> 0] | 0) == 10)while (1) {
	                            e = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 28 | 0;
	                            c[e >> 2] = (c[e >> 2] | 0) + 1;
	                            c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1;
	                            c[j >> 2] = (c[j >> 2] | 0) + 1;
	                            if ((d[c[j >> 2] >> 0] | 0) != 10)continue a
	                        }
	                        if ((d[c[j >> 2] >> 0] | 0) == 60) {
	                            q = 15;
	                            break
	                        }
	                        b:while (1) {
	                            c[n >> 2] = c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2];
	                            while (1) {
	                                if (!(a[65800 + (d[c[j >> 2] >> 0] | 0) >> 0] | 0))break;
	                                c[j >> 2] = (c[j >> 2] | 0) + 1;
	                                c[n >> 2] = (c[n >> 2] | 0) + 1
	                            }
	                            c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = c[n >> 2];
	                            if ((d[c[j >> 2] >> 0] | 0) == 10)while (1) {
	                                e = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 28 | 0;
	                                c[e >> 2] = (c[e >> 2] | 0) + 1;
	                                c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1;
	                                c[j >> 2] = (c[j >> 2] | 0) + 1;
	                                if ((d[c[j >> 2] >> 0] | 0) != 10)continue b
	                            }
	                            r = c[j >> 2] | 0;
	                            if ((d[c[j >> 2] >> 0] | 0) != 93)break;
	                            if ((d[r + 1 >> 0] | 0) == 93 ? (d[(c[j >> 2] | 0) + 2 >> 0] | 0) == 62 : 0) {
	                                q = 36;
	                                break a
	                            }
	                            c[j >> 2] = (c[j >> 2] | 0) + 1;
	                            e = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                            c[e >> 2] = (c[e >> 2] | 0) + 1
	                        }
	                        c[k >> 2] = r - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0);
	                        if ((c[k >> 2] | 0) > 0) {
	                            c:do if ((c[c[g >> 2] >> 2] | 0) != 0 ? (c[(c[c[g >> 2] >> 2] | 0) + 72 >> 2] | 0) != (c[(c[c[g >> 2] >> 2] | 0) + 68 >> 2] | 0) : 0) {
	                                do if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) != 32) {
	                                    if (9 <= (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) ? (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) <= 10 : 0)break;
	                                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) != 13) {
	                                        q = 53;
	                                        break c
	                                    }
	                                } while (0);
	                                c[p >> 2] = c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                                c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] = c[j >> 2];
	                                e = (Gg(c[g >> 2] | 0, c[p >> 2] | 0, c[k >> 2] | 0, 0) | 0) != 0;
	                                b = c[c[g >> 2] >> 2] | 0;
	                                if (e) {
	                                    if (c[b + 72 >> 2] | 0)Db[c[(c[c[g >> 2] >> 2] | 0) + 72 >> 2] & 511](c[(c[g >> 2] | 0) + 4 >> 2] | 0, c[p >> 2] | 0, c[k >> 2] | 0)
	                                } else {
	                                    if (c[b + 68 >> 2] | 0)Db[c[(c[c[g >> 2] >> 2] | 0) + 68 >> 2] & 511](c[(c[g >> 2] | 0) + 4 >> 2] | 0, c[p >> 2] | 0, c[k >> 2] | 0);
	                                    if ((c[c[(c[g >> 2] | 0) + 232 >> 2] >> 2] | 0) == -1)c[c[(c[g >> 2] | 0) + 232 >> 2] >> 2] = -2
	                                }
	                                c[l >> 2] = c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2];
	                                c[m >> 2] = c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2]
	                            } else q = 53; while (0);
	                            if ((q | 0) == 53 ? (q = 0, (c[c[g >> 2] >> 2] | 0) != 0) : 0) {
	                                if (c[(c[c[g >> 2] >> 2] | 0) + 68 >> 2] | 0)Db[c[(c[c[g >> 2] >> 2] | 0) + 68 >> 2] & 511](c[(c[g >> 2] | 0) + 4 >> 2] | 0, c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0, c[k >> 2] | 0);
	                                c[l >> 2] = c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2];
	                                c[m >> 2] = c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2]
	                            }
	                            if ((c[(c[g >> 2] | 0) + 172 >> 2] | 0) != 7) {
	                                q = 78;
	                                break
	                            }
	                        }
	                        c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] = c[j >> 2];
	                        do if ((d[c[j >> 2] >> 0] | 0) == 13) {
	                            c[j >> 2] = (c[j >> 2] | 0) + 1;
	                            b = c[j >> 2] | 0;
	                            if ((d[c[j >> 2] >> 0] | 0) == 10) {
	                                c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] = b;
	                                c[j >> 2] = (c[j >> 2] | 0) + 1;
	                                e = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 28 | 0;
	                                c[e >> 2] = (c[e >> 2] | 0) + 1;
	                                c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1;
	                                break
	                            } else {
	                                c[j >> 2] = b + -1;
	                                q = 62;
	                                break
	                            }
	                        } else q = 62; while (0);
	                        if ((q | 0) == 62) {
	                            q = 0;
	                            if ((d[c[j >> 2] >> 0] | 0) == 60) {
	                                q = 78;
	                                break
	                            }
	                            if ((d[c[j >> 2] >> 0] | 0) == 38) {
	                                q = 78;
	                                break
	                            }
	                            if (((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 : 0) ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)Fg(c[g >> 2] | 0);
	                            if ((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[g >> 2] | 0);
	                            if ((c[(c[g >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                                q = 78;
	                                break
	                            }
	                            c[j >> 2] = c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2]
	                        }
	                        if ((d[c[j >> 2] >> 0] | 0) >= 32 ? (d[c[j >> 2] >> 0] | 0) <= 127 : 0)continue;
	                        if ((d[c[j >> 2] >> 0] | 0) != 9) {
	                            q = 76;
	                            break
	                        }
	                    }
	                    if ((q | 0) == 15) {
	                        c[k >> 2] = (c[j >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0);
	                        if ((c[k >> 2] | 0) <= 0) {
	                            i = f;
	                            return
	                        }
	                        c[o >> 2] = c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                        c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] = c[j >> 2];
	                        if ((c[c[g >> 2] >> 2] | 0) != 0 ? (c[(c[c[g >> 2] >> 2] | 0) + 72 >> 2] | 0) != (c[(c[c[g >> 2] >> 2] | 0) + 68 >> 2] | 0) : 0) {
	                            b = (Gg(c[g >> 2] | 0, c[o >> 2] | 0, c[k >> 2] | 0, 1) | 0) != 0;
	                            e = c[c[g >> 2] >> 2] | 0;
	                            if (b) {
	                                if (!(c[e + 72 >> 2] | 0)) {
	                                    i = f;
	                                    return
	                                }
	                                Db[c[(c[c[g >> 2] >> 2] | 0) + 72 >> 2] & 511](c[(c[g >> 2] | 0) + 4 >> 2] | 0, c[o >> 2] | 0, c[k >> 2] | 0);
	                                i = f;
	                                return
	                            }
	                            if (c[e + 68 >> 2] | 0)Db[c[(c[c[g >> 2] >> 2] | 0) + 68 >> 2] & 511](c[(c[g >> 2] | 0) + 4 >> 2] | 0, c[o >> 2] | 0, c[k >> 2] | 0);
	                            if ((c[c[(c[g >> 2] | 0) + 232 >> 2] >> 2] | 0) != -1) {
	                                i = f;
	                                return
	                            }
	                            c[c[(c[g >> 2] | 0) + 232 >> 2] >> 2] = -2;
	                            i = f;
	                            return
	                        }
	                        if (!(c[c[g >> 2] >> 2] | 0)) {
	                            i = f;
	                            return
	                        }
	                        if (!(c[(c[c[g >> 2] >> 2] | 0) + 68 >> 2] | 0)) {
	                            i = f;
	                            return
	                        }
	                        Db[c[(c[c[g >> 2] >> 2] | 0) + 68 >> 2] & 511](c[(c[g >> 2] | 0) + 4 >> 2] | 0, c[o >> 2] | 0, c[k >> 2] | 0);
	                        i = f;
	                        return
	                    } else if ((q | 0) == 36) {
	                        og(c[g >> 2] | 0, 62, 0);
	                        c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] = c[j >> 2];
	                        i = f;
	                        return
	                    } else if ((q | 0) == 76) {
	                        c[k >> 2] = 0;
	                        break
	                    } else if ((q | 0) == 78) {
	                        i = f;
	                        return
	                    }
	                } while (0);
	                c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2] = c[l >> 2];
	                c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = c[m >> 2];
	                Hg(c[g >> 2] | 0, c[h >> 2] | 0);
	                i = f;
	                return
	            }

	            function jf(a, b, e) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[l >> 2] = 0;
	                if (((c[(c[h >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 : 0) ? ((c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)Fg(c[h >> 2] | 0);
	                c[c[j >> 2] >> 2] = 0;
	                if ((((((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 83 ? (d[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 89 : 0) ? (d[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 83 : 0) ? (d[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 84 : 0) ? (d[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) == 69 : 0) ? (d[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) == 77 : 0) {
	                    e = (c[h >> 2] | 0) + 200 | 0;
	                    c[e >> 2] = (c[e >> 2] | 0) + 6;
	                    e = (c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[e >> 2] = (c[e >> 2] | 0) + 6;
	                    e = (c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[e >> 2] = (c[e >> 2] | 0) + 6;
	                    if ((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[h >> 2] | 0);
	                    if ((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[h >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[h >> 2] | 0) | 0;
	                    do if ((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13)xg(c[h >> 2] | 0, 65, 66056)
	                    } while (0);
	                    Ue(c[h >> 2] | 0) | 0;
	                    c[l >> 2] = ff(c[h >> 2] | 0) | 0;
	                    if (!(c[l >> 2] | 0))og(c[h >> 2] | 0, 70, 0)
	                } else n = 23;
	                if (((((((n | 0) == 23 ? (d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 80 : 0) ? (d[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 85 : 0) ? (d[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 66 : 0) ? (d[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 76 : 0) ? (d[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) == 73 : 0) ? (d[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) == 67 : 0) {
	                    n = (c[h >> 2] | 0) + 200 | 0;
	                    c[n >> 2] = (c[n >> 2] | 0) + 6;
	                    n = (c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[n >> 2] = (c[n >> 2] | 0) + 6;
	                    n = (c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[n >> 2] = (c[n >> 2] | 0) + 6;
	                    if ((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[h >> 2] | 0);
	                    if ((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[h >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[h >> 2] | 0) | 0;
	                    do if ((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13)xg(c[h >> 2] | 0, 65, 66088)
	                    } while (0);
	                    Ue(c[h >> 2] | 0) | 0;
	                    n = gf(c[h >> 2] | 0) | 0;
	                    c[c[j >> 2] >> 2] = n;
	                    if (!(c[c[j >> 2] >> 2] | 0))og(c[h >> 2] | 0, 71, 0);
	                    j = c[h >> 2] | 0;
	                    do if (c[k >> 2] | 0) {
	                        if ((d[c[(c[j + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13)xg(c[h >> 2] | 0, 65, 66120)
	                        }
	                    } else {
	                        if ((c[j + 292 >> 2] | 0) == 0 ? ((c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[h >> 2] | 0);
	                        c[m >> 2] = c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                        do if ((d[c[m >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[m >> 2] >> 0] | 0 | 0) ? (d[c[m >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[m >> 2] >> 0] | 0 | 0) != 13) {
	                                c[g >> 2] = 0;
	                                o = c[g >> 2] | 0;
	                                i = f;
	                                return o | 0
	                            }
	                        } while (0);
	                        while (1) {
	                            do if ((d[c[m >> 2] >> 0] | 0 | 0) == 32)p = 1; else {
	                                if (9 <= (d[c[m >> 2] >> 0] | 0 | 0) ? (d[c[m >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                    p = 1;
	                                    break
	                                }
	                                p = (d[c[m >> 2] >> 0] | 0 | 0) == 13
	                            } while (0);
	                            q = c[m >> 2] | 0;
	                            if (!p)break;
	                            c[m >> 2] = q + 1
	                        }
	                        if ((d[q >> 0] | 0 | 0) != 39 ? (d[c[m >> 2] >> 0] | 0 | 0) != 34 : 0) {
	                            c[g >> 2] = 0;
	                            o = c[g >> 2] | 0;
	                            i = f;
	                            return o | 0
	                        }
	                    } while (0);
	                    Ue(c[h >> 2] | 0) | 0;
	                    c[l >> 2] = ff(c[h >> 2] | 0) | 0;
	                    if (!(c[l >> 2] | 0))og(c[h >> 2] | 0, 70, 0)
	                }
	                c[g >> 2] = c[l >> 2];
	                o = c[g >> 2] | 0;
	                i = f;
	                return o | 0
	            }

	            function kf(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 36 | 0;
	                g = e + 32 | 0;
	                h = e + 28 | 0;
	                j = e + 24 | 0;
	                k = e + 20 | 0;
	                l = e + 16 | 0;
	                m = e + 12 | 0;
	                n = e + 8 | 0;
	                o = e + 4 | 0;
	                p = e;
	                c[f >> 2] = b;
	                c[g >> 2] = 0;
	                c[h >> 2] = 100;
	                c[j >> 2] = 0;
	                c[m >> 2] = 0;
	                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 60) {
	                    i = e;
	                    return
	                }
	                if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) != 33) {
	                    i = e;
	                    return
	                }
	                if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) != 45) {
	                    i = e;
	                    return
	                }
	                if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) != 45) {
	                    i = e;
	                    return
	                }
	                c[k >> 2] = c[(c[f >> 2] | 0) + 172 >> 2];
	                c[(c[f >> 2] | 0) + 172 >> 2] = 5;
	                c[o >> 2] = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 56 >> 2];
	                b = (c[f >> 2] | 0) + 200 | 0;
	                c[b >> 2] = (c[b >> 2] | 0) + 4;
	                b = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                c[b >> 2] = (c[b >> 2] | 0) + 4;
	                b = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                c[b >> 2] = (c[b >> 2] | 0) + 4;
	                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[f >> 2] | 0) | 0;
	                if (((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 : 0) ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)Fg(c[f >> 2] | 0);
	                if ((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[f >> 2] | 0);
	                c[l >> 2] = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                a:while (1) {
	                    if ((d[c[l >> 2] >> 0] | 0 | 0) == 10)do {
	                        b = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 28 | 0;
	                        c[b >> 2] = (c[b >> 2] | 0) + 1;
	                        c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1;
	                        c[l >> 2] = (c[l >> 2] | 0) + 1
	                    } while ((d[c[l >> 2] >> 0] | 0 | 0) == 10);
	                    b:while (1) {
	                        c[n >> 2] = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2];
	                        c:while (1) {
	                            if (!((d[c[l >> 2] >> 0] | 0 | 0) > 45 ? (d[c[l >> 2] >> 0] | 0 | 0) <= 127 : 0))q = 23;
	                            do if ((q | 0) == 23) {
	                                q = 0;
	                                if ((d[c[l >> 2] >> 0] | 0 | 0) >= 32 ? (d[c[l >> 2] >> 0] | 0 | 0) < 45 : 0)break;
	                                if ((d[c[l >> 2] >> 0] | 0 | 0) != 9)break c
	                            } while (0);
	                            c[l >> 2] = (c[l >> 2] | 0) + 1;
	                            c[n >> 2] = (c[n >> 2] | 0) + 1
	                        }
	                        c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = c[n >> 2];
	                        if ((d[c[l >> 2] >> 0] | 0 | 0) == 10)while (1) {
	                            b = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 28 | 0;
	                            c[b >> 2] = (c[b >> 2] | 0) + 1;
	                            c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1;
	                            c[l >> 2] = (c[l >> 2] | 0) + 1;
	                            if ((d[c[l >> 2] >> 0] | 0 | 0) != 10)continue b
	                        }
	                        c[m >> 2] = (c[l >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0);
	                        if (((c[m >> 2] | 0) >>> 0 > 0 ? (c[c[f >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[c[f >> 2] >> 2] | 0) + 80 >> 2] | 0) != 0 : 0) {
	                            if (c[g >> 2] | 0) {
	                                if (((c[j >> 2] | 0) + (c[m >> 2] | 0) + 1 | 0) >>> 0 >= (c[h >> 2] | 0) >>> 0) {
	                                    c[h >> 2] = (c[h >> 2] | 0) + ((c[j >> 2] | 0) + (c[m >> 2] | 0) + 100);
	                                    c[p >> 2] = Hb[c[135760 >> 2] & 511](c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                                    if (!(c[p >> 2] | 0)) {
	                                        q = 42;
	                                        break a
	                                    }
	                                    c[g >> 2] = c[p >> 2]
	                                }
	                            } else {
	                                do if ((d[c[l >> 2] >> 0] | 0 | 0) == 45) {
	                                    if ((d[(c[l >> 2] | 0) + 1 >> 0] | 0 | 0) != 45) {
	                                        q = 36;
	                                        break
	                                    }
	                                    c[h >> 2] = (c[m >> 2] | 0) + 1
	                                } else q = 36; while (0);
	                                if ((q | 0) == 36) {
	                                    q = 0;
	                                    c[h >> 2] = 100 + (c[m >> 2] | 0)
	                                }
	                                c[g >> 2] = Cb[c[135752 >> 2] & 511](c[h >> 2] | 0) | 0;
	                                if (!(c[g >> 2] | 0)) {
	                                    q = 38;
	                                    break a
	                                }
	                                c[j >> 2] = 0
	                            }
	                            eU((c[g >> 2] | 0) + (c[j >> 2] | 0) | 0, c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0, c[m >> 2] | 0) | 0;
	                            c[j >> 2] = (c[j >> 2] | 0) + (c[m >> 2] | 0);
	                            a[(c[g >> 2] | 0) + (c[j >> 2] | 0) >> 0] = 0
	                        }
	                        if ((c[j >> 2] | 0) >>> 0 > 1e7 ? (c[(c[f >> 2] | 0) + 360 >> 2] & 524288 | 0) == 0 : 0) {
	                            q = 47;
	                            break a
	                        }
	                        c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] = c[l >> 2];
	                        if ((d[c[l >> 2] >> 0] | 0 | 0) == 10) {
	                            c[l >> 2] = (c[l >> 2] | 0) + 1;
	                            b = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 28 | 0;
	                            c[b >> 2] = (c[b >> 2] | 0) + 1;
	                            c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                        }
	                        if ((d[c[l >> 2] >> 0] | 0 | 0) == 13) {
	                            c[l >> 2] = (c[l >> 2] | 0) + 1;
	                            r = c[l >> 2] | 0;
	                            if ((d[c[l >> 2] >> 0] | 0 | 0) == 10) {
	                                q = 52;
	                                break
	                            }
	                            c[l >> 2] = r + -1
	                        }
	                        if (((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 : 0) ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)Fg(c[f >> 2] | 0);
	                        if ((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[f >> 2] | 0);
	                        if ((c[(c[f >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                            q = 62;
	                            break a
	                        }
	                        c[l >> 2] = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                        if ((d[c[l >> 2] >> 0] | 0 | 0) != 45)break;
	                        if ((d[(c[l >> 2] | 0) + 1 >> 0] | 0 | 0) == 45) {
	                            if ((d[(c[l >> 2] | 0) + 2 >> 0] | 0 | 0) == 62) {
	                                q = 66;
	                                break a
	                            }
	                            b = c[f >> 2] | 0;
	                            if (c[g >> 2] | 0)pg(b, 80, 66248, c[g >> 2] | 0); else pg(b, 80, 66296, 0);
	                            c[l >> 2] = (c[l >> 2] | 0) + 1;
	                            b = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                            c[b >> 2] = (c[b >> 2] | 0) + 1
	                        }
	                        c[l >> 2] = (c[l >> 2] | 0) + 1;
	                        b = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                        c[b >> 2] = (c[b >> 2] | 0) + 1
	                    }
	                    if ((q | 0) == 52) {
	                        q = 0;
	                        c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] = r;
	                        c[l >> 2] = (c[l >> 2] | 0) + 1;
	                        b = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 28 | 0;
	                        c[b >> 2] = (c[b >> 2] | 0) + 1;
	                        c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                    }
	                    if ((d[c[l >> 2] >> 0] | 0 | 0) >= 32 ? (d[c[l >> 2] >> 0] | 0 | 0) <= 127 : 0)continue;
	                    if ((d[c[l >> 2] >> 0] | 0 | 0) != 9) {
	                        q = 91;
	                        break
	                    }
	                }
	                if ((q | 0) == 38) {
	                    ie(c[f >> 2] | 0, 0);
	                    c[(c[f >> 2] | 0) + 172 >> 2] = c[k >> 2];
	                    i = e;
	                    return
	                } else if ((q | 0) == 42) {
	                    zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                    ie(c[f >> 2] | 0, 0);
	                    c[(c[f >> 2] | 0) + 172 >> 2] = c[k >> 2];
	                    i = e;
	                    return
	                } else if ((q | 0) == 47) {
	                    pg(c[f >> 2] | 0, 45, 66168, 0);
	                    zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                    i = e;
	                    return
	                } else if ((q | 0) == 62) {
	                    zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                    i = e;
	                    return
	                } else if ((q | 0) == 66) {
	                    if ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 56 >> 2] | 0) != (c[o >> 2] | 0))xg(c[f >> 2] | 0, 90, 66192);
	                    o = (c[f >> 2] | 0) + 200 | 0;
	                    c[o >> 2] = (c[o >> 2] | 0) + 3;
	                    o = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[o >> 2] = (c[o >> 2] | 0) + 3;
	                    o = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[o >> 2] = (c[o >> 2] | 0) + 3;
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[f >> 2] | 0) | 0;
	                    do if (((c[c[f >> 2] >> 2] | 0) != 0 ? (c[(c[c[f >> 2] >> 2] | 0) + 80 >> 2] | 0) != 0 : 0) ? (c[(c[f >> 2] | 0) + 212 >> 2] | 0) == 0 : 0) {
	                        o = c[(c[c[f >> 2] >> 2] | 0) + 80 >> 2] | 0;
	                        l = c[(c[f >> 2] | 0) + 4 >> 2] | 0;
	                        if (c[g >> 2] | 0) {
	                            Ab[o & 511](l, c[g >> 2] | 0);
	                            break
	                        } else {
	                            Ab[o & 511](l, 65640);
	                            break
	                        }
	                    } while (0);
	                    if (c[g >> 2] | 0)zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                    if ((c[(c[f >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                        i = e;
	                        return
	                    }
	                    c[(c[f >> 2] | 0) + 172 >> 2] = c[k >> 2];
	                    i = e;
	                    return
	                } else if ((q | 0) == 91) {
	                    Ig(c[f >> 2] | 0, c[g >> 2] | 0, c[j >> 2] | 0, c[h >> 2] | 0);
	                    c[(c[f >> 2] | 0) + 172 >> 2] = c[k >> 2];
	                    i = e;
	                    return
	                }
	            }

	            function lf(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                g = b + 4 | 0;
	                h = b;
	                c[f >> 2] = a;
	                c[g >> 2] = Ze(c[f >> 2] | 0) | 0;
	                do if (c[g >> 2] | 0) {
	                    if ((d[c[g >> 2] >> 0] | 0 | 0) != 120 ? (d[c[g >> 2] >> 0] | 0 | 0) != 88 : 0)break;
	                    if ((d[(c[g >> 2] | 0) + 1 >> 0] | 0 | 0) != 109 ? (d[(c[g >> 2] | 0) + 1 >> 0] | 0 | 0) != 77 : 0)break;
	                    if ((d[(c[g >> 2] | 0) + 2 >> 0] | 0 | 0) != 108 ? (d[(c[g >> 2] | 0) + 2 >> 0] | 0 | 0) != 76 : 0)break;
	                    if ((((d[c[g >> 2] >> 0] | 0 | 0) == 120 ? (d[(c[g >> 2] | 0) + 1 >> 0] | 0 | 0) == 109 : 0) ? (d[(c[g >> 2] | 0) + 2 >> 0] | 0 | 0) == 108 : 0) ? (d[(c[g >> 2] | 0) + 3 >> 0] | 0 | 0) == 0 : 0) {
	                        xg(c[f >> 2] | 0, 64, 66328);
	                        c[e >> 2] = c[g >> 2];
	                        j = c[e >> 2] | 0;
	                        i = b;
	                        return j | 0
	                    }
	                    if (!(d[(c[g >> 2] | 0) + 3 >> 0] | 0)) {
	                        og(c[f >> 2] | 0, 64, 0);
	                        c[e >> 2] = c[g >> 2];
	                        j = c[e >> 2] | 0;
	                        i = b;
	                        return j | 0
	                    }
	                    c[h >> 2] = 0;
	                    while (1) {
	                        if (!(c[66392 + (c[h >> 2] << 2) >> 2] | 0)) {
	                            k = 20;
	                            break
	                        }
	                        if (qy(c[g >> 2] | 0, c[66392 + (c[h >> 2] << 2) >> 2] | 0) | 0)break;
	                        c[h >> 2] = (c[h >> 2] | 0) + 1
	                    }
	                    if ((k | 0) == 20) {
	                        rg(c[f >> 2] | 0, 64, 66408, 0, 0);
	                        break
	                    }
	                    c[e >> 2] = c[g >> 2];
	                    j = c[e >> 2] | 0;
	                    i = b;
	                    return j | 0
	                } while (0);
	                if ((c[g >> 2] | 0) != 0 ? (vy(c[g >> 2] | 0, 58) | 0) != 0 : 0)Jg(c[f >> 2] | 0, 205, 66456, c[g >> 2] | 0, 0, 0);
	                c[e >> 2] = c[g >> 2];
	                j = c[e >> 2] | 0;
	                i = b;
	                return j | 0
	            }

	            function mf(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0;
	                e = i;
	                i = i + 64 | 0;
	                f = e + 48 | 0;
	                g = e + 44 | 0;
	                h = e + 40 | 0;
	                j = e + 36 | 0;
	                k = e + 32 | 0;
	                l = e + 28 | 0;
	                m = e + 24 | 0;
	                n = e + 20 | 0;
	                o = e + 16 | 0;
	                p = e + 12 | 0;
	                q = e + 8 | 0;
	                r = e + 4 | 0;
	                s = e;
	                c[f >> 2] = b;
	                c[g >> 2] = 0;
	                c[h >> 2] = 0;
	                c[j >> 2] = 100;
	                c[o >> 2] = 0;
	                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 60) {
	                    i = e;
	                    return
	                }
	                if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) != 63) {
	                    i = e;
	                    return
	                }
	                c[p >> 2] = c[(c[f >> 2] | 0) + 36 >> 2];
	                c[n >> 2] = c[(c[f >> 2] | 0) + 172 >> 2];
	                c[(c[f >> 2] | 0) + 172 >> 2] = 2;
	                b = (c[f >> 2] | 0) + 200 | 0;
	                c[b >> 2] = (c[b >> 2] | 0) + 2;
	                b = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                c[b >> 2] = (c[b >> 2] | 0) + 2;
	                b = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                c[b >> 2] = (c[b >> 2] | 0) + 2;
	                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[f >> 2] | 0) | 0;
	                if (((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 : 0) ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)Fg(c[f >> 2] | 0);
	                c[m >> 2] = lf(c[f >> 2] | 0) | 0;
	                b = c[f >> 2] | 0;
	                do if (c[m >> 2] | 0) {
	                    if ((d[c[(c[b + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 63 ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 62 : 0) {
	                        if ((c[p >> 2] | 0) != (c[(c[f >> 2] | 0) + 36 >> 2] | 0))xg(c[f >> 2] | 0, 90, 66504);
	                        t = (c[f >> 2] | 0) + 200 | 0;
	                        c[t >> 2] = (c[t >> 2] | 0) + 2;
	                        t = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                        c[t >> 2] = (c[t >> 2] | 0) + 2;
	                        t = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                        c[t >> 2] = (c[t >> 2] | 0) + 2;
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[f >> 2] | 0) | 0;
	                        if (((c[c[f >> 2] >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 212 >> 2] | 0) == 0 : 0) ? (c[(c[c[f >> 2] >> 2] | 0) + 76 >> 2] | 0) != 0 : 0)Db[c[(c[c[f >> 2] >> 2] | 0) + 76 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0, c[m >> 2] | 0, 0);
	                        if ((c[(c[f >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                            i = e;
	                            return
	                        }
	                        c[(c[f >> 2] | 0) + 172 >> 2] = c[n >> 2];
	                        i = e;
	                        return
	                    }
	                    c[g >> 2] = Cb[c[135752 >> 2] & 511](c[j >> 2] | 0) | 0;
	                    t = c[f >> 2] | 0;
	                    if (!(c[g >> 2] | 0)) {
	                        ie(t, 0);
	                        c[(c[f >> 2] | 0) + 172 >> 2] = c[n >> 2];
	                        i = e;
	                        return
	                    }
	                    c[k >> 2] = d[c[(c[t + 36 >> 2] | 0) + 16 >> 2] >> 0];
	                    if ((c[k >> 2] | 0) < 256) {
	                        if ((c[k >> 2] | 0) != 32 ? !(9 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 10 | (c[k >> 2] | 0) == 13) : 0)u = 33
	                    } else u = 33;
	                    if ((u | 0) == 33)pg(c[f >> 2] | 0, 65, 66568, c[m >> 2] | 0);
	                    Ue(c[f >> 2] | 0) | 0;
	                    c[k >> 2] = ne(c[f >> 2] | 0, l) | 0;
	                    while (1) {
	                        t = c[k >> 2] | 0;
	                        if ((c[k >> 2] | 0) < 256)if (9 <= (t | 0) & (c[k >> 2] | 0) <= 10 | (c[k >> 2] | 0) == 13 | 32 <= (c[k >> 2] | 0))u = 40; else v = 0; else if ((!(256 <= (t | 0) & (c[k >> 2] | 0) <= 55295) ? !(57344 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 65533) : 0) ? !(65536 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 1114111) : 0)v = 0; else u = 40;
	                        if ((u | 0) == 40) {
	                            u = 0;
	                            if ((c[k >> 2] | 0) != 63)v = 1; else v = (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) != 62
	                        }
	                        w = c[h >> 2] | 0;
	                        if (!v) {
	                            u = 73;
	                            break
	                        }
	                        if ((w + 5 | 0) >>> 0 >= (c[j >> 2] | 0) >>> 0) {
	                            c[r >> 2] = c[j >> 2] << 1;
	                            c[q >> 2] = Hb[c[135760 >> 2] & 511](c[g >> 2] | 0, c[r >> 2] | 0) | 0;
	                            if (!(c[q >> 2] | 0)) {
	                                u = 45;
	                                break
	                            }
	                            c[g >> 2] = c[q >> 2];
	                            c[j >> 2] = c[r >> 2]
	                        }
	                        c[o >> 2] = (c[o >> 2] | 0) + 1;
	                        if ((c[o >> 2] | 0) > 50) {
	                            if ((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[f >> 2] | 0);
	                            if ((c[(c[f >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                                u = 52;
	                                break
	                            }
	                            c[o >> 2] = 0;
	                            if ((c[h >> 2] | 0) >>> 0 > 1e7 ? (c[(c[f >> 2] | 0) + 360 >> 2] & 524288 | 0) == 0 : 0) {
	                                u = 55;
	                                break
	                            }
	                        }
	                        if ((c[l >> 2] | 0) == 1) {
	                            t = c[k >> 2] & 255;
	                            x = c[h >> 2] | 0;
	                            c[h >> 2] = x + 1;
	                            a[(c[g >> 2] | 0) + x >> 0] = t
	                        } else {
	                            t = pe((c[g >> 2] | 0) + (c[h >> 2] | 0) | 0, c[k >> 2] | 0) | 0;
	                            c[h >> 2] = (c[h >> 2] | 0) + t
	                        }
	                        t = c[(c[f >> 2] | 0) + 36 >> 2] | 0;
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                            x = t + 28 | 0;
	                            c[x >> 2] = (c[x >> 2] | 0) + 1;
	                            c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                        } else {
	                            x = t + 32 | 0;
	                            c[x >> 2] = (c[x >> 2] | 0) + 1
	                        }
	                        x = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                        c[x >> 2] = (c[x >> 2] | 0) + (c[l >> 2] | 0);
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                        c[k >> 2] = ne(c[f >> 2] | 0, l) | 0;
	                        if (c[k >> 2] | 0)continue;
	                        do if (!(c[(c[f >> 2] | 0) + 292 >> 2] | 0)) {
	                            if (((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) <= 500)break;
	                            if (((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) >= 500)break;
	                            Fg(c[f >> 2] | 0)
	                        } while (0);
	                        do if (!(c[(c[f >> 2] | 0) + 292 >> 2] | 0)) {
	                            if (((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) >= 250)break;
	                            vg(c[f >> 2] | 0)
	                        } while (0);
	                        c[k >> 2] = ne(c[f >> 2] | 0, l) | 0
	                    }
	                    if ((u | 0) == 45) {
	                        ie(c[f >> 2] | 0, 0);
	                        zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                        c[(c[f >> 2] | 0) + 172 >> 2] = c[n >> 2];
	                        i = e;
	                        return
	                    } else if ((u | 0) == 52) {
	                        zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                        i = e;
	                        return
	                    } else if ((u | 0) == 55) {
	                        pg(c[f >> 2] | 0, 47, 66600, c[m >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                        c[(c[f >> 2] | 0) + 172 >> 2] = c[n >> 2];
	                        i = e;
	                        return
	                    } else if ((u | 0) == 73) {
	                        if (w >>> 0 > 1e7 ? (c[(c[f >> 2] | 0) + 360 >> 2] & 524288 | 0) == 0 : 0) {
	                            pg(c[f >> 2] | 0, 47, 66600, c[m >> 2] | 0);
	                            zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                            c[(c[f >> 2] | 0) + 172 >> 2] = c[n >> 2];
	                            i = e;
	                            return
	                        }
	                        a[(c[g >> 2] | 0) + (c[h >> 2] | 0) >> 0] = 0;
	                        do if ((c[k >> 2] | 0) == 63) {
	                            if ((c[p >> 2] | 0) != (c[(c[f >> 2] | 0) + 36 >> 2] | 0))xg(c[f >> 2] | 0, 65, 66504);
	                            x = (c[f >> 2] | 0) + 200 | 0;
	                            c[x >> 2] = (c[x >> 2] | 0) + 2;
	                            x = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                            c[x >> 2] = (c[x >> 2] | 0) + 2;
	                            x = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                            c[x >> 2] = (c[x >> 2] | 0) + 2;
	                            if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                            if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[f >> 2] | 0) | 0;
	                            do if ((c[n >> 2] | 0) == 1 | (c[n >> 2] | 0) == 0 ? (qy(c[m >> 2] | 0, 66656) | 0) != 0 : 0) {
	                                c[s >> 2] = Gw() | 0;
	                                if (!((c[s >> 2] | 0) == 2 | (c[s >> 2] | 0) == 3))break;
	                                Kg(c[f >> 2] | 0, c[g >> 2] | 0)
	                            } while (0);
	                            if ((c[c[f >> 2] >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 212 >> 2] | 0) == 0 : 0) {
	                                if (!(c[(c[c[f >> 2] >> 2] | 0) + 76 >> 2] | 0))break;
	                                Db[c[(c[c[f >> 2] >> 2] | 0) + 76 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0, c[m >> 2] | 0, c[g >> 2] | 0)
	                            }
	                        } else pg(c[f >> 2] | 0, 47, 66624, c[m >> 2] | 0); while (0);
	                        zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                        break
	                    }
	                } else og(b, 46, 0); while (0);
	                if ((c[(c[f >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                    i = e;
	                    return
	                }
	                c[(c[f >> 2] | 0) + 172 >> 2] = c[n >> 2];
	                i = e;
	                return
	            }

	            function nf(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                b = i;
	                i = i + 32 | 0;
	                e = b + 16 | 0;
	                f = b + 12 | 0;
	                g = b + 8 | 0;
	                h = b + 4 | 0;
	                j = b;
	                c[e >> 2] = a;
	                if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 60) {
	                    i = b;
	                    return
	                }
	                if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) != 33) {
	                    i = b;
	                    return
	                }
	                if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) != 78) {
	                    i = b;
	                    return
	                }
	                if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) != 79) {
	                    i = b;
	                    return
	                }
	                if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) != 84) {
	                    i = b;
	                    return
	                }
	                if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) != 65) {
	                    i = b;
	                    return
	                }
	                if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 6 >> 0] | 0 | 0) != 84) {
	                    i = b;
	                    return
	                }
	                if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 7 >> 0] | 0 | 0) != 73) {
	                    i = b;
	                    return
	                }
	                if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 8 >> 0] | 0 | 0) != 79) {
	                    i = b;
	                    return
	                }
	                if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 9 >> 0] | 0 | 0) != 78) {
	                    i = b;
	                    return
	                }
	                c[j >> 2] = c[(c[e >> 2] | 0) + 36 >> 2];
	                if (((c[(c[e >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 : 0) ? ((c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)Fg(c[e >> 2] | 0);
	                a = (c[e >> 2] | 0) + 200 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + 10;
	                a = (c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + 10;
	                a = (c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + 10;
	                if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[e >> 2] | 0);
	                if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[e >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[e >> 2] | 0) | 0;
	                do if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32) {
	                    if (9 <= (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                    if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13) {
	                        xg(c[e >> 2] | 0, 65, 66680);
	                        i = b;
	                        return
	                    }
	                } while (0);
	                Ue(c[e >> 2] | 0) | 0;
	                c[f >> 2] = Ze(c[e >> 2] | 0) | 0;
	                a = c[e >> 2] | 0;
	                if (!(c[f >> 2] | 0)) {
	                    og(a, 48, 0);
	                    i = b;
	                    return
	                }
	                do if ((d[c[(c[a + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32) {
	                    if (9 <= (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                    if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13) {
	                        xg(c[e >> 2] | 0, 65, 66720);
	                        i = b;
	                        return
	                    }
	                } while (0);
	                if (vy(c[f >> 2] | 0, 58) | 0)Jg(c[e >> 2] | 0, 205, 66768, c[f >> 2] | 0, 0, 0);
	                Ue(c[e >> 2] | 0) | 0;
	                c[h >> 2] = jf(c[e >> 2] | 0, g, 0) | 0;
	                Ue(c[e >> 2] | 0) | 0;
	                do if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 62) {
	                    if ((c[j >> 2] | 0) != (c[(c[e >> 2] | 0) + 36 >> 2] | 0))xg(c[e >> 2] | 0, 65, 66816);
	                    me(c[e >> 2] | 0);
	                    if (!(c[c[e >> 2] >> 2] | 0))break;
	                    if (c[(c[e >> 2] | 0) + 212 >> 2] | 0)break;
	                    if (!(c[(c[c[e >> 2] >> 2] | 0) + 28 >> 2] | 0))break;
	                    Jb[c[(c[c[e >> 2] >> 2] | 0) + 28 >> 2] & 511](c[(c[e >> 2] | 0) + 4 >> 2] | 0, c[f >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0)
	                } else og(c[e >> 2] | 0, 49, 0); while (0);
	                if (c[h >> 2] | 0)zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                if (!(c[g >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                i = b;
	                return
	            }

	            function of(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                b = i;
	                i = i + 64 | 0;
	                e = b + 48 | 0;
	                f = b + 44 | 0;
	                g = b + 40 | 0;
	                h = b + 36 | 0;
	                j = b + 32 | 0;
	                k = b + 28 | 0;
	                l = b + 24 | 0;
	                m = b + 20 | 0;
	                n = b + 16 | 0;
	                o = b + 12 | 0;
	                p = b + 8 | 0;
	                q = b + 4 | 0;
	                r = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                c[g >> 2] = 0;
	                c[h >> 2] = 0;
	                c[j >> 2] = 0;
	                c[k >> 2] = 0;
	                c[l >> 2] = 0;
	                c[m >> 2] = 0;
	                if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 60) {
	                    i = b;
	                    return
	                }
	                if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) != 33) {
	                    i = b;
	                    return
	                }
	                if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) != 69) {
	                    i = b;
	                    return
	                }
	                if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) != 78) {
	                    i = b;
	                    return
	                }
	                if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) != 84) {
	                    i = b;
	                    return
	                }
	                if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) != 73) {
	                    i = b;
	                    return
	                }
	                if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 6 >> 0] | 0 | 0) != 84) {
	                    i = b;
	                    return
	                }
	                if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 7 >> 0] | 0 | 0) != 89) {
	                    i = b;
	                    return
	                }
	                c[o >> 2] = c[(c[e >> 2] | 0) + 36 >> 2];
	                if (((c[(c[e >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 : 0) ? ((c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)Fg(c[e >> 2] | 0);
	                a = (c[e >> 2] | 0) + 200 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + 8;
	                a = (c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + 8;
	                a = (c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + 8;
	                if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[e >> 2] | 0);
	                if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[e >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[e >> 2] | 0) | 0;
	                c[n >> 2] = Ue(c[e >> 2] | 0) | 0;
	                if (!(c[n >> 2] | 0))xg(c[e >> 2] | 0, 65, 66880);
	                if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37) {
	                    me(c[e >> 2] | 0);
	                    c[n >> 2] = Ue(c[e >> 2] | 0) | 0;
	                    if (!(c[n >> 2] | 0))xg(c[e >> 2] | 0, 65, 66920);
	                    c[l >> 2] = 1
	                }
	                c[f >> 2] = Ze(c[e >> 2] | 0) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    xg(c[e >> 2] | 0, 68, 66952);
	                    i = b;
	                    return
	                }
	                if (vy(c[f >> 2] | 0, 58) | 0)Jg(c[e >> 2] | 0, 205, 66984, c[f >> 2] | 0, 0, 0);
	                c[n >> 2] = Ue(c[e >> 2] | 0) | 0;
	                if (!(c[n >> 2] | 0))xg(c[e >> 2] | 0, 65, 67032);
	                c[(c[e >> 2] | 0) + 172 >> 2] = 10;
	                n = (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 34;
	                a:do if (c[l >> 2] | 0) {
	                    do if (!n) {
	                        if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 39)break;
	                        c[h >> 2] = jf(c[e >> 2] | 0, j, 1) | 0;
	                        if ((c[h >> 2] | 0) == 0 & (c[j >> 2] | 0) == 0)og(c[e >> 2] | 0, 84, 0);
	                        if (!(c[h >> 2] | 0))break a;
	                        c[p >> 2] = yl(c[h >> 2] | 0) | 0;
	                        if (!(c[p >> 2] | 0)) {
	                            Lg(c[e >> 2] | 0, 91, 67072, c[h >> 2] | 0);
	                            break a
	                        }
	                        a = c[e >> 2] | 0;
	                        do if (c[(c[p >> 2] | 0) + 32 >> 2] | 0)og(a, 92, 0); else {
	                            if (!(c[a >> 2] | 0))break;
	                            if (c[(c[e >> 2] | 0) + 212 >> 2] | 0)break;
	                            if (!(c[(c[c[e >> 2] >> 2] | 0) + 24 >> 2] | 0))break;
	                            Gb[c[(c[c[e >> 2] >> 2] | 0) + 24 >> 2] & 511](c[(c[e >> 2] | 0) + 4 >> 2] | 0, c[f >> 2] | 0, 5, c[j >> 2] | 0, c[h >> 2] | 0, 0)
	                        } while (0);
	                        Al(c[p >> 2] | 0);
	                        break a
	                    } while (0);
	                    c[g >> 2] = df(c[e >> 2] | 0, m) | 0;
	                    if (c[g >> 2] | 0) {
	                        if (!(c[c[e >> 2] >> 2] | 0))break;
	                        if (c[(c[e >> 2] | 0) + 212 >> 2] | 0)break;
	                        if (!(c[(c[c[e >> 2] >> 2] | 0) + 24 >> 2] | 0))break;
	                        Gb[c[(c[c[e >> 2] >> 2] | 0) + 24 >> 2] & 511](c[(c[e >> 2] | 0) + 4 >> 2] | 0, c[f >> 2] | 0, 4, 0, 0, c[g >> 2] | 0)
	                    }
	                } else {
	                    do if (!n) {
	                        if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 39)break;
	                        c[h >> 2] = jf(c[e >> 2] | 0, j, 1) | 0;
	                        if ((c[h >> 2] | 0) == 0 & (c[j >> 2] | 0) == 0)og(c[e >> 2] | 0, 84, 0);
	                        do if (c[h >> 2] | 0) {
	                            c[q >> 2] = yl(c[h >> 2] | 0) | 0;
	                            if (!(c[q >> 2] | 0)) {
	                                Lg(c[e >> 2] | 0, 91, 67072, c[h >> 2] | 0);
	                                break
	                            }
	                            if (c[(c[q >> 2] | 0) + 32 >> 2] | 0)og(c[e >> 2] | 0, 92, 0);
	                            Al(c[q >> 2] | 0)
	                        } while (0);
	                        do if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 62) {
	                            if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 32)break;
	                            if (9 <= (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 13)break;
	                            xg(c[e >> 2] | 0, 65, 67152)
	                        } while (0);
	                        Ue(c[e >> 2] | 0) | 0;
	                        do if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 78) {
	                            if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) != 68)break;
	                            if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) != 65)break;
	                            if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) != 84)break;
	                            if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) != 65)break;
	                            a = (c[e >> 2] | 0) + 200 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 5;
	                            a = (c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 5;
	                            a = (c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 5;
	                            if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[e >> 2] | 0);
	                            do if (!(d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0)) {
	                                if ((ke(c[(c[e >> 2] | 0) + 36 >> 2] | 0, 250) | 0) > 0)break;
	                                Ve(c[e >> 2] | 0) | 0
	                            } while (0);
	                            do if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32) {
	                                if (9 <= (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                                if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 13)break;
	                                xg(c[e >> 2] | 0, 65, 67184)
	                            } while (0);
	                            Ue(c[e >> 2] | 0) | 0;
	                            c[k >> 2] = Ze(c[e >> 2] | 0) | 0;
	                            if (!(c[c[e >> 2] >> 2] | 0))break a;
	                            if (c[(c[e >> 2] | 0) + 212 >> 2] | 0)break a;
	                            if (!(c[(c[c[e >> 2] >> 2] | 0) + 40 >> 2] | 0))break a;
	                            xb[c[(c[c[e >> 2] >> 2] | 0) + 40 >> 2] & 511](c[(c[e >> 2] | 0) + 4 >> 2] | 0, c[f >> 2] | 0, c[j >> 2] | 0, c[h >> 2] | 0, c[k >> 2] | 0);
	                            break a
	                        } while (0);
	                        do if (c[c[e >> 2] >> 2] | 0) {
	                            if (c[(c[e >> 2] | 0) + 212 >> 2] | 0)break;
	                            if (!(c[(c[c[e >> 2] >> 2] | 0) + 24 >> 2] | 0))break;
	                            Gb[c[(c[c[e >> 2] >> 2] | 0) + 24 >> 2] & 511](c[(c[e >> 2] | 0) + 4 >> 2] | 0, c[f >> 2] | 0, 2, c[j >> 2] | 0, c[h >> 2] | 0, 0)
	                        } while (0);
	                        if (!(c[(c[e >> 2] | 0) + 16 >> 2] | 0))break a;
	                        if ((c[(c[e >> 2] | 0) + 8 >> 2] | 0) != 0 ? (qy(c[(c[(c[e >> 2] | 0) + 8 >> 2] | 0) + 56 >> 2] | 0, 67096) | 0) == 0 : 0)break a;
	                        do if (!(c[(c[e >> 2] | 0) + 8 >> 2] | 0)) {
	                            a = Sh(67096) | 0;
	                            c[(c[e >> 2] | 0) + 8 >> 2] = a;
	                            a = c[e >> 2] | 0;
	                            if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                                c[(c[a + 8 >> 2] | 0) + 92 >> 2] = 64;
	                                break
	                            }
	                            ie(a, 67128);
	                            i = b;
	                            return
	                        } while (0);
	                        if (!(c[(c[(c[e >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0)) {
	                            a = Mh(c[(c[e >> 2] | 0) + 8 >> 2] | 0, 67144, 0, 0) | 0;
	                            c[(c[(c[e >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] = a
	                        }
	                        XP(c[e >> 2] | 0, c[f >> 2] | 0, 2, c[j >> 2] | 0, c[h >> 2] | 0, 0);
	                        break a
	                    } while (0);
	                    c[g >> 2] = df(c[e >> 2] | 0, m) | 0;
	                    do if (c[c[e >> 2] >> 2] | 0) {
	                        if (c[(c[e >> 2] | 0) + 212 >> 2] | 0)break;
	                        if (!(c[(c[c[e >> 2] >> 2] | 0) + 24 >> 2] | 0))break;
	                        Gb[c[(c[c[e >> 2] >> 2] | 0) + 24 >> 2] & 511](c[(c[e >> 2] | 0) + 4 >> 2] | 0, c[f >> 2] | 0, 1, 0, 0, c[g >> 2] | 0)
	                    } while (0);
	                    if ((c[(c[e >> 2] | 0) + 8 >> 2] | 0) != 0 ? (qy(c[(c[(c[e >> 2] | 0) + 8 >> 2] | 0) + 56 >> 2] | 0, 67096) | 0) == 0 : 0)break;
	                    do if (!(c[(c[e >> 2] | 0) + 8 >> 2] | 0)) {
	                        a = Sh(67096) | 0;
	                        c[(c[e >> 2] | 0) + 8 >> 2] = a;
	                        a = c[e >> 2] | 0;
	                        if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                            c[(c[a + 8 >> 2] | 0) + 92 >> 2] = 64;
	                            break
	                        }
	                        ie(a, 67128);
	                        i = b;
	                        return
	                    } while (0);
	                    if (!(c[(c[(c[e >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0)) {
	                        a = Mh(c[(c[e >> 2] | 0) + 8 >> 2] | 0, 67144, 0, 0) | 0;
	                        c[(c[(c[e >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] = a
	                    }
	                    XP(c[e >> 2] | 0, c[f >> 2] | 0, 1, 0, 0, c[g >> 2] | 0)
	                } while (0);
	                if ((c[(c[e >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                    i = b;
	                    return
	                }
	                Ue(c[e >> 2] | 0) | 0;
	                if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 62)pg(c[e >> 2] | 0, 37, 67216, c[f >> 2] | 0); else {
	                    if ((c[o >> 2] | 0) != (c[(c[e >> 2] | 0) + 36 >> 2] | 0))xg(c[e >> 2] | 0, 90, 67264);
	                    me(c[e >> 2] | 0)
	                }
	                do if (c[m >> 2] | 0) {
	                    c[r >> 2] = 0;
	                    o = (c[c[e >> 2] >> 2] | 0) != 0;
	                    do if (c[l >> 2] | 0) {
	                        if (!o)break;
	                        if (!(c[(c[c[e >> 2] >> 2] | 0) + 96 >> 2] | 0))break;
	                        c[r >> 2] = Hb[c[(c[c[e >> 2] >> 2] | 0) + 96 >> 2] & 511](c[(c[e >> 2] | 0) + 4 >> 2] | 0, c[f >> 2] | 0) | 0
	                    } else {
	                        do if (o) {
	                            if (!(c[(c[c[e >> 2] >> 2] | 0) + 20 >> 2] | 0))break;
	                            c[r >> 2] = Hb[c[(c[c[e >> 2] >> 2] | 0) + 20 >> 2] & 511](c[(c[e >> 2] | 0) + 4 >> 2] | 0, c[f >> 2] | 0) | 0
	                        } while (0);
	                        if (c[r >> 2] | 0)break;
	                        if ((c[(c[e >> 2] | 0) + 4 >> 2] | 0) != (c[e >> 2] | 0))break;
	                        c[r >> 2] = VP(c[e >> 2] | 0, c[f >> 2] | 0) | 0
	                    } while (0);
	                    if (!(c[r >> 2] | 0)) {
	                        zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                        break
	                    }
	                    if (c[(c[r >> 2] | 0) + 36 >> 2] | 0) {
	                        zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                        break
	                    } else {
	                        c[(c[r >> 2] | 0) + 36 >> 2] = c[m >> 2];
	                        break
	                    }
	                } while (0);
	                if (c[g >> 2] | 0)zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                if (c[h >> 2] | 0)zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                if (!(c[j >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                i = b;
	                return
	            }

	            function pf(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[c[h >> 2] >> 2] = 0;
	                if (((((((((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 35 ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 82 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 69 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 81 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) == 85 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) == 73 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 6 >> 0] | 0 | 0) == 82 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 7 >> 0] | 0 | 0) == 69 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 8 >> 0] | 0 | 0) == 68 : 0) {
	                    b = (c[g >> 2] | 0) + 200 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 9;
	                    b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 9;
	                    b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 9;
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[g >> 2] | 0);
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[g >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[g >> 2] | 0) | 0;
	                    c[f >> 2] = 2;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                if ((((((((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 35 ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 73 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 77 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 80 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) == 76 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) == 73 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 6 >> 0] | 0 | 0) == 69 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 7 >> 0] | 0 | 0) == 68 : 0) {
	                    b = (c[g >> 2] | 0) + 200 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 8;
	                    b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 8;
	                    b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 8;
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[g >> 2] | 0);
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[g >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[g >> 2] | 0) | 0;
	                    c[f >> 2] = 3;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[j >> 2] = 1;
	                if ((((((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 35 ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 70 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 73 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 88 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) == 69 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) == 68 : 0) {
	                    b = (c[g >> 2] | 0) + 200 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 6;
	                    b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 6;
	                    b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 6;
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[g >> 2] | 0);
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[g >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[g >> 2] | 0) | 0;
	                    c[j >> 2] = 4;
	                    do if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13)xg(c[g >> 2] | 0, 65, 67328)
	                    } while (0);
	                    Ue(c[g >> 2] | 0) | 0
	                }
	                c[k >> 2] = ef(c[g >> 2] | 0) | 0;
	                c[(c[g >> 2] | 0) + 172 >> 2] = 3;
	                if (!(c[k >> 2] | 0))xg(c[g >> 2] | 0, c[(c[g >> 2] | 0) + 84 >> 2] | 0, 67360); else c[c[h >> 2] >> 2] = c[k >> 2];
	                c[f >> 2] = c[j >> 2];
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function qf(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                b = i;
	                i = i + 32 | 0;
	                e = b + 24 | 0;
	                f = b + 20 | 0;
	                g = b + 16 | 0;
	                h = b + 12 | 0;
	                j = b + 8 | 0;
	                k = b + 4 | 0;
	                l = b;
	                c[f >> 2] = a;
	                c[h >> 2] = 0;
	                c[j >> 2] = 0;
	                a = c[f >> 2] | 0;
	                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 40) {
	                    og(a, 48, 0);
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = b;
	                    return m | 0
	                }
	                if (((c[a + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 : 0) ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)Fg(c[f >> 2] | 0);
	                a:while (1) {
	                    me(c[f >> 2] | 0);
	                    Ue(c[f >> 2] | 0) | 0;
	                    c[g >> 2] = Ze(c[f >> 2] | 0) | 0;
	                    if (!(c[g >> 2] | 0)) {
	                        n = 8;
	                        break
	                    }
	                    c[l >> 2] = c[h >> 2];
	                    while (1) {
	                        if (!(c[l >> 2] | 0))break;
	                        if (qy(c[g >> 2] | 0, c[(c[l >> 2] | 0) + 4 >> 2] | 0) | 0) {
	                            n = 12;
	                            break
	                        }
	                        c[l >> 2] = c[c[l >> 2] >> 2]
	                    }
	                    if ((n | 0) == 12 ? (n = 0, qg(c[f >> 2] | 0, 541, 67448, c[g >> 2] | 0, 0), (CP(c[(c[f >> 2] | 0) + 296 >> 2] | 0, c[g >> 2] | 0) | 0) == 0) : 0)zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                    do if (!(c[l >> 2] | 0)) {
	                        c[k >> 2] = qm(c[g >> 2] | 0) | 0;
	                        if (!(c[k >> 2] | 0)) {
	                            n = 17;
	                            break a
	                        }
	                        a = c[k >> 2] | 0;
	                        if (!(c[j >> 2] | 0)) {
	                            c[j >> 2] = a;
	                            c[h >> 2] = a;
	                            break
	                        } else {
	                            c[c[j >> 2] >> 2] = a;
	                            c[j >> 2] = c[k >> 2];
	                            break
	                        }
	                    } while (0);
	                    Ue(c[f >> 2] | 0) | 0;
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 124) {
	                        n = 22;
	                        break
	                    }
	                }
	                if ((n | 0) == 8) {
	                    xg(c[f >> 2] | 0, 68, 67408);
	                    rm(c[h >> 2] | 0);
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = b;
	                    return m | 0
	                } else if ((n | 0) == 17) {
	                    rm(c[h >> 2] | 0);
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = b;
	                    return m | 0
	                } else if ((n | 0) == 22) {
	                    n = c[f >> 2] | 0;
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 41) {
	                        og(n, 49, 0);
	                        rm(c[h >> 2] | 0);
	                        c[e >> 2] = 0;
	                        m = c[e >> 2] | 0;
	                        i = b;
	                        return m | 0
	                    } else {
	                        me(n);
	                        c[e >> 2] = c[h >> 2];
	                        m = c[e >> 2] | 0;
	                        i = b;
	                        return m | 0
	                    }
	                }
	                return 0
	            }

	            function rf(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                b = i;
	                i = i + 32 | 0;
	                e = b + 24 | 0;
	                f = b + 20 | 0;
	                g = b + 16 | 0;
	                h = b + 12 | 0;
	                j = b + 8 | 0;
	                k = b + 4 | 0;
	                l = b;
	                c[f >> 2] = a;
	                c[h >> 2] = 0;
	                c[j >> 2] = 0;
	                a = c[f >> 2] | 0;
	                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 40) {
	                    og(a, 50, 0);
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = b;
	                    return m | 0
	                }
	                if (((c[a + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 : 0) ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)Fg(c[f >> 2] | 0);
	                a:while (1) {
	                    me(c[f >> 2] | 0);
	                    Ue(c[f >> 2] | 0) | 0;
	                    c[g >> 2] = cf(c[f >> 2] | 0) | 0;
	                    if (!(c[g >> 2] | 0)) {
	                        n = 8;
	                        break
	                    }
	                    c[l >> 2] = c[h >> 2];
	                    while (1) {
	                        if (!(c[l >> 2] | 0))break;
	                        if (qy(c[g >> 2] | 0, c[(c[l >> 2] | 0) + 4 >> 2] | 0) | 0) {
	                            n = 12;
	                            break
	                        }
	                        c[l >> 2] = c[c[l >> 2] >> 2]
	                    }
	                    if ((n | 0) == 12 ? (n = 0, qg(c[f >> 2] | 0, 541, 67512, c[g >> 2] | 0, 0), (CP(c[(c[f >> 2] | 0) + 296 >> 2] | 0, c[g >> 2] | 0) | 0) == 0) : 0)zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                    do if (!(c[l >> 2] | 0)) {
	                        c[k >> 2] = qm(c[g >> 2] | 0) | 0;
	                        if (!(CP(c[(c[f >> 2] | 0) + 296 >> 2] | 0, c[g >> 2] | 0) | 0))zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                        if (!(c[k >> 2] | 0)) {
	                            n = 19;
	                            break a
	                        }
	                        a = c[k >> 2] | 0;
	                        if (!(c[j >> 2] | 0)) {
	                            c[j >> 2] = a;
	                            c[h >> 2] = a;
	                            break
	                        } else {
	                            c[c[j >> 2] >> 2] = a;
	                            c[j >> 2] = c[k >> 2];
	                            break
	                        }
	                    } while (0);
	                    Ue(c[f >> 2] | 0) | 0;
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 124) {
	                        n = 24;
	                        break
	                    }
	                }
	                if ((n | 0) == 8) {
	                    og(c[f >> 2] | 0, 67, 0);
	                    c[e >> 2] = c[h >> 2];
	                    m = c[e >> 2] | 0;
	                    i = b;
	                    return m | 0
	                } else if ((n | 0) == 19) {
	                    rm(c[h >> 2] | 0);
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = b;
	                    return m | 0
	                } else if ((n | 0) == 24) {
	                    n = c[f >> 2] | 0;
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 41) {
	                        og(n, 51, 0);
	                        c[e >> 2] = c[h >> 2];
	                        m = c[e >> 2] | 0;
	                        i = b;
	                        return m | 0
	                    } else {
	                        me(n);
	                        c[e >> 2] = c[h >> 2];
	                        m = c[e >> 2] | 0;
	                        i = b;
	                        return m | 0
	                    }
	                }
	                return 0
	            }

	            function sf(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                if ((((((((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 78 ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 79 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 84 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 65 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) == 84 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) == 73 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 6 >> 0] | 0 | 0) == 79 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 7 >> 0] | 0 | 0) == 78 : 0) {
	                    b = (c[g >> 2] | 0) + 200 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 8;
	                    b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 8;
	                    b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 8;
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[g >> 2] | 0);
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[g >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[g >> 2] | 0) | 0;
	                    do if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13) {
	                            xg(c[g >> 2] | 0, 65, 67576);
	                            c[f >> 2] = 0;
	                            j = c[f >> 2] | 0;
	                            i = e;
	                            return j | 0
	                        }
	                    } while (0);
	                    Ue(c[g >> 2] | 0) | 0;
	                    b = qf(c[g >> 2] | 0) | 0;
	                    c[c[h >> 2] >> 2] = b;
	                    if (!(c[c[h >> 2] >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        j = c[f >> 2] | 0;
	                        i = e;
	                        return j | 0
	                    } else {
	                        c[f >> 2] = 10;
	                        j = c[f >> 2] | 0;
	                        i = e;
	                        return j | 0
	                    }
	                }
	                b = rf(c[g >> 2] | 0) | 0;
	                c[c[h >> 2] >> 2] = b;
	                if (!(c[c[h >> 2] >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    j = c[f >> 2] | 0;
	                    i = e;
	                    return j | 0
	                } else {
	                    c[f >> 2] = 9;
	                    j = c[f >> 2] | 0;
	                    i = e;
	                    return j | 0
	                }
	                return 0
	            }

	            function tf(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                if (((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 : 0) ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)Fg(c[g >> 2] | 0);
	                if (((((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 67 ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 68 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 65 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 84 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) == 65 : 0) {
	                    b = (c[g >> 2] | 0) + 200 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 5;
	                    b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 5;
	                    b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 5;
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[g >> 2] | 0);
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[g >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[g >> 2] | 0) | 0;
	                    c[f >> 2] = 1;
	                    j = c[f >> 2] | 0;
	                    i = e;
	                    return j | 0
	                }
	                if ((((((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 73 ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 68 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 82 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 69 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) == 70 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) == 83 : 0) {
	                    b = (c[g >> 2] | 0) + 200 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 6;
	                    b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 6;
	                    b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 6;
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[g >> 2] | 0);
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[g >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[g >> 2] | 0) | 0;
	                    c[f >> 2] = 4;
	                    j = c[f >> 2] | 0;
	                    i = e;
	                    return j | 0
	                }
	                if (((((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 73 ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 68 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 82 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 69 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) == 70 : 0) {
	                    b = (c[g >> 2] | 0) + 200 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 5;
	                    b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 5;
	                    b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 5;
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[g >> 2] | 0);
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[g >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[g >> 2] | 0) | 0;
	                    c[f >> 2] = 3;
	                    j = c[f >> 2] | 0;
	                    i = e;
	                    return j | 0
	                }
	                if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 73 ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 68 : 0) {
	                    b = (c[g >> 2] | 0) + 200 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 2;
	                    b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 2;
	                    b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 2;
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[g >> 2] | 0);
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[g >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[g >> 2] | 0) | 0;
	                    c[f >> 2] = 2;
	                    j = c[f >> 2] | 0;
	                    i = e;
	                    return j | 0
	                }
	                if ((((((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 69 ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 78 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 84 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 73 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) == 84 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) == 89 : 0) {
	                    b = (c[g >> 2] | 0) + 200 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 6;
	                    b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 6;
	                    b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 6;
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[g >> 2] | 0);
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[g >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[g >> 2] | 0) | 0;
	                    c[f >> 2] = 5;
	                    j = c[f >> 2] | 0;
	                    i = e;
	                    return j | 0
	                }
	                if ((((((((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 69 ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 78 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 84 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 73 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) == 84 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) == 73 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 6 >> 0] | 0 | 0) == 69 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 7 >> 0] | 0 | 0) == 83 : 0) {
	                    b = (c[g >> 2] | 0) + 200 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 8;
	                    b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 8;
	                    b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 8;
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[g >> 2] | 0);
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[g >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[g >> 2] | 0) | 0;
	                    c[f >> 2] = 6;
	                    j = c[f >> 2] | 0;
	                    i = e;
	                    return j | 0
	                }
	                if ((((((((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 78 ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 77 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 84 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 79 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) == 75 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) == 69 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 6 >> 0] | 0 | 0) == 78 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 7 >> 0] | 0 | 0) == 83 : 0) {
	                    b = (c[g >> 2] | 0) + 200 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 8;
	                    b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 8;
	                    b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 8;
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[g >> 2] | 0);
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[g >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[g >> 2] | 0) | 0;
	                    c[f >> 2] = 8;
	                    j = c[f >> 2] | 0;
	                    i = e;
	                    return j | 0
	                }
	                if (((((((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 78 ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 77 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 84 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 79 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) == 75 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) == 69 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 6 >> 0] | 0 | 0) == 78 : 0) {
	                    b = (c[g >> 2] | 0) + 200 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 7;
	                    b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 7;
	                    b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 7;
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[g >> 2] | 0);
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[g >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[g >> 2] | 0) | 0;
	                    c[f >> 2] = 7;
	                    j = c[f >> 2] | 0;
	                    i = e;
	                    return j | 0
	                }
	                c[f >> 2] = sf(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                j = c[f >> 2] | 0;
	                i = e;
	                return j | 0
	            }

	            function uf(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                b = i;
	                i = i + 48 | 0;
	                e = b + 32 | 0;
	                f = b + 28 | 0;
	                g = b + 24 | 0;
	                h = b + 20 | 0;
	                j = b + 16 | 0;
	                k = b + 12 | 0;
	                l = b + 8 | 0;
	                m = b + 4 | 0;
	                n = b;
	                c[e >> 2] = a;
	                if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 60) {
	                    i = b;
	                    return
	                }
	                if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) != 33) {
	                    i = b;
	                    return
	                }
	                if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) != 65) {
	                    i = b;
	                    return
	                }
	                if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) != 84) {
	                    i = b;
	                    return
	                }
	                if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) != 84) {
	                    i = b;
	                    return
	                }
	                if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) != 76) {
	                    i = b;
	                    return
	                }
	                if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 6 >> 0] | 0 | 0) != 73) {
	                    i = b;
	                    return
	                }
	                if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 7 >> 0] | 0 | 0) != 83) {
	                    i = b;
	                    return
	                }
	                if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 8 >> 0] | 0 | 0) != 84) {
	                    i = b;
	                    return
	                }
	                c[j >> 2] = c[(c[e >> 2] | 0) + 36 >> 2];
	                a = (c[e >> 2] | 0) + 200 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + 9;
	                a = (c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + 9;
	                a = (c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + 9;
	                if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[e >> 2] | 0);
	                if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[e >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[e >> 2] | 0) | 0;
	                do if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32) {
	                    if (9 <= (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                    if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13)xg(c[e >> 2] | 0, 65, 67616)
	                } while (0);
	                Ue(c[e >> 2] | 0) | 0;
	                c[f >> 2] = Ze(c[e >> 2] | 0) | 0;
	                a = c[e >> 2] | 0;
	                if (!(c[f >> 2] | 0)) {
	                    xg(a, 68, 67656);
	                    i = b;
	                    return
	                }
	                Ue(a) | 0;
	                if ((c[(c[e >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[e >> 2] | 0);
	                a:while (1) {
	                    if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 62)break;
	                    if ((c[(c[e >> 2] | 0) + 172 >> 2] | 0) == -1)break;
	                    c[k >> 2] = c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                    c[n >> 2] = 0;
	                    if ((c[(c[e >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[e >> 2] | 0);
	                    c[h >> 2] = 0;
	                    c[g >> 2] = Ze(c[e >> 2] | 0) | 0;
	                    o = c[e >> 2] | 0;
	                    if (!(c[g >> 2] | 0)) {
	                        p = 31;
	                        break
	                    }
	                    do if (!(c[o + 292 >> 2] | 0)) {
	                        if (((c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) >= 250)break;
	                        vg(c[e >> 2] | 0)
	                    } while (0);
	                    do if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13) {
	                            p = 39;
	                            break a
	                        }
	                    } while (0);
	                    Ue(c[e >> 2] | 0) | 0;
	                    c[l >> 2] = tf(c[e >> 2] | 0, h) | 0;
	                    if ((c[l >> 2] | 0) <= 0)break;
	                    do if (!(c[(c[e >> 2] | 0) + 292 >> 2] | 0)) {
	                        if (((c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) >= 250)break;
	                        vg(c[e >> 2] | 0)
	                    } while (0);
	                    do if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13) {
	                            p = 48;
	                            break a
	                        }
	                    } while (0);
	                    Ue(c[e >> 2] | 0) | 0;
	                    c[m >> 2] = pf(c[e >> 2] | 0, n) | 0;
	                    if ((c[m >> 2] | 0) <= 0) {
	                        p = 51;
	                        break
	                    }
	                    if ((c[l >> 2] | 0) != 1 & (c[n >> 2] | 0) != 0)Mg(c[n >> 2] | 0, c[n >> 2] | 0) | 0;
	                    do if (!(c[(c[e >> 2] | 0) + 292 >> 2] | 0)) {
	                        if (((c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) >= 250)break;
	                        vg(c[e >> 2] | 0)
	                    } while (0);
	                    if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 62) {
	                        do if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13) {
	                                p = 65;
	                                break a
	                            }
	                        } while (0);
	                        Ue(c[e >> 2] | 0) | 0
	                    }
	                    q = c[e >> 2] | 0;
	                    if ((c[k >> 2] | 0) == (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0)) {
	                        p = 71;
	                        break
	                    }
	                    do if (c[q >> 2] | 0) {
	                        if (c[(c[e >> 2] | 0) + 212 >> 2] | 0) {
	                            p = 79;
	                            break
	                        }
	                        if (!(c[(c[c[e >> 2] >> 2] | 0) + 32 >> 2] | 0)) {
	                            p = 79;
	                            break
	                        }
	                        wb[c[(c[c[e >> 2] >> 2] | 0) + 32 >> 2] & 511](c[(c[e >> 2] | 0) + 4 >> 2] | 0, c[f >> 2] | 0, c[g >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0, c[h >> 2] | 0)
	                    } else p = 79; while (0);
	                    do if ((p | 0) == 79) {
	                        p = 0;
	                        if (!(c[h >> 2] | 0))break;
	                        rm(c[h >> 2] | 0)
	                    } while (0);
	                    if (((c[n >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 324 >> 2] | 0) != 0 : 0) & (c[m >> 2] | 0) != 3 & (c[m >> 2] | 0) != 2)Ng(c[e >> 2] | 0, c[f >> 2] | 0, c[g >> 2] | 0, c[n >> 2] | 0);
	                    if (c[(c[e >> 2] | 0) + 324 >> 2] | 0)Og(c[e >> 2] | 0, c[f >> 2] | 0, c[g >> 2] | 0, c[l >> 2] | 0);
	                    if (c[n >> 2] | 0)zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                    if (c[(c[e >> 2] | 0) + 292 >> 2] | 0)continue;
	                    if (((c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) >= 250)continue;
	                    vg(c[e >> 2] | 0)
	                }
	                if ((p | 0) == 31)xg(o, 68, 67688); else if ((p | 0) == 39)xg(c[e >> 2] | 0, 65, 67720); else if ((p | 0) == 48) {
	                    xg(c[e >> 2] | 0, 65, 67768);
	                    if (c[h >> 2] | 0)rm(c[h >> 2] | 0)
	                } else if ((p | 0) == 51) {
	                    if (c[n >> 2] | 0)zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                    if (c[h >> 2] | 0)rm(c[h >> 2] | 0)
	                } else if ((p | 0) == 65) {
	                    xg(c[e >> 2] | 0, 65, 67816);
	                    if (c[n >> 2] | 0)zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                    if (c[h >> 2] | 0)rm(c[h >> 2] | 0)
	                } else if ((p | 0) == 71) {
	                    og(q, 1, 67872);
	                    if (c[n >> 2] | 0)zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                    if (c[h >> 2] | 0)rm(c[h >> 2] | 0)
	                }
	                if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 62) {
	                    i = b;
	                    return
	                }
	                if ((c[j >> 2] | 0) != (c[(c[e >> 2] | 0) + 36 >> 2] | 0))qg(c[e >> 2] | 0, 90, 67904, 0, 0);
	                me(c[e >> 2] | 0);
	                i = b;
	                return
	            }

	            function vf(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 20 | 0;
	                h = e + 16 | 0;
	                j = e + 12 | 0;
	                k = e + 8 | 0;
	                l = e + 4 | 0;
	                m = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = 0;
	                c[k >> 2] = 0;
	                c[m >> 2] = 0;
	                if ((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[g >> 2] | 0);
	                do if (((((((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 35 ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 80 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 67 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 68 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) == 65 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) == 84 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 6 >> 0] | 0 | 0) == 65 : 0) {
	                    b = (c[g >> 2] | 0) + 200 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 7;
	                    b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 7;
	                    b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 7;
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[g >> 2] | 0);
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[g >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[g >> 2] | 0) | 0;
	                    Ue(c[g >> 2] | 0) | 0;
	                    if (((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 : 0) ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)Fg(c[g >> 2] | 0);
	                    b = c[g >> 2] | 0;
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 41) {
	                        if ((c[b + 104 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 56 >> 2] | 0) != (c[h >> 2] | 0) : 0)qg(c[g >> 2] | 0, 90, 67976, 0, 0);
	                        me(c[g >> 2] | 0);
	                        c[j >> 2] = im(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 0, 1) | 0;
	                        if (!(c[j >> 2] | 0)) {
	                            c[f >> 2] = 0;
	                            n = c[f >> 2] | 0;
	                            i = e;
	                            return n | 0
	                        }
	                        if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 42) {
	                            c[(c[j >> 2] | 0) + 4 >> 2] = 3;
	                            me(c[g >> 2] | 0)
	                        }
	                        c[f >> 2] = c[j >> 2];
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    }
	                    if (!((d[c[(c[b + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 40 ? (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 124 : 0))o = 31;
	                    if ((o | 0) == 31 ? (b = im(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 0, 1) | 0, c[k >> 2] = b, c[j >> 2] = b, (c[j >> 2] | 0) == 0) : 0) {
	                        c[f >> 2] = 0;
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    }
	                    while (1) {
	                        if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 124)p = (c[(c[g >> 2] | 0) + 172 >> 2] | 0) != -1; else p = 0;
	                        q = c[g >> 2] | 0;
	                        if (!p) {
	                            o = 54;
	                            break
	                        }
	                        me(q);
	                        b = (c[m >> 2] | 0) == 0;
	                        a = im(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 0, 4) | 0;
	                        if (b) {
	                            c[j >> 2] = a;
	                            if (!(c[j >> 2] | 0)) {
	                                o = 38;
	                                break
	                            }
	                            c[(c[j >> 2] | 0) + 12 >> 2] = c[k >> 2];
	                            if (c[k >> 2] | 0)c[(c[k >> 2] | 0) + 20 >> 2] = c[j >> 2];
	                            c[k >> 2] = c[j >> 2]
	                        } else {
	                            c[l >> 2] = a;
	                            if (!(c[l >> 2] | 0)) {
	                                o = 43;
	                                break
	                            }
	                            a = im(c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[m >> 2] | 0, 2) | 0;
	                            c[(c[l >> 2] | 0) + 12 >> 2] = a;
	                            if (c[(c[l >> 2] | 0) + 12 >> 2] | 0)c[(c[(c[l >> 2] | 0) + 12 >> 2] | 0) + 20 >> 2] = c[l >> 2];
	                            c[(c[k >> 2] | 0) + 16 >> 2] = c[l >> 2];
	                            if (c[l >> 2] | 0)c[(c[l >> 2] | 0) + 20 >> 2] = c[k >> 2];
	                            c[k >> 2] = c[l >> 2]
	                        }
	                        Ue(c[g >> 2] | 0) | 0;
	                        c[m >> 2] = Ze(c[g >> 2] | 0) | 0;
	                        r = c[g >> 2] | 0;
	                        if (!(c[m >> 2] | 0)) {
	                            o = 50;
	                            break
	                        }
	                        Ue(r) | 0;
	                        if (c[(c[g >> 2] | 0) + 292 >> 2] | 0)continue;
	                        if (((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) >= 250)continue;
	                        vg(c[g >> 2] | 0)
	                    }
	                    if ((o | 0) == 38) {
	                        c[f >> 2] = 0;
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    } else if ((o | 0) == 43) {
	                        c[f >> 2] = 0;
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    } else if ((o | 0) == 50) {
	                        xg(r, 68, 68048);
	                        lm(c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[k >> 2] | 0);
	                        c[f >> 2] = 0;
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    } else if ((o | 0) == 54) {
	                        if ((d[c[(c[q + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 41 ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 42 : 0) {
	                            do if (c[m >> 2] | 0) {
	                                a = im(c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[m >> 2] | 0, 2) | 0;
	                                c[(c[k >> 2] | 0) + 16 >> 2] = a;
	                                if (!(c[(c[k >> 2] | 0) + 16 >> 2] | 0))break;
	                                c[(c[(c[k >> 2] | 0) + 16 >> 2] | 0) + 20 >> 2] = c[k >> 2]
	                            } while (0);
	                            if (c[j >> 2] | 0)c[(c[j >> 2] | 0) + 4 >> 2] = 3;
	                            do if (c[(c[g >> 2] | 0) + 104 >> 2] | 0) {
	                                if ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 56 >> 2] | 0) == (c[h >> 2] | 0))break;
	                                qg(c[g >> 2] | 0, 90, 67976, 0, 0)
	                            } while (0);
	                            a = (c[g >> 2] | 0) + 200 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 2;
	                            a = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 2;
	                            a = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 2;
	                            if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[g >> 2] | 0);
	                            if (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0)break;
	                            if ((ke(c[(c[g >> 2] | 0) + 36 >> 2] | 0, 250) | 0) > 0)break;
	                            Ve(c[g >> 2] | 0) | 0;
	                            break
	                        }
	                        lm(c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[j >> 2] | 0);
	                        og(c[g >> 2] | 0, 52, 0);
	                        c[f >> 2] = 0;
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    }
	                } else o = 70; while (0);
	                if ((o | 0) == 70)og(c[g >> 2] | 0, 69, 0);
	                c[f >> 2] = c[j >> 2];
	                n = c[f >> 2] | 0;
	                i = e;
	                return n | 0
	            }

	            function wf(a, b, e) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 24 | 0;
	                h = f + 20 | 0;
	                j = f + 16 | 0;
	                k = f + 12 | 0;
	                l = f + 8 | 0;
	                m = f + 4 | 0;
	                n = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[l >> 2] = 0;
	                c[m >> 2] = c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 56 >> 2];
	                c[c[k >> 2] >> 2] = 0;
	                e = c[h >> 2] | 0;
	                if ((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 40) {
	                    pg(e, 54, 68104, c[j >> 2] | 0);
	                    c[g >> 2] = -1;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                me(e);
	                if ((c[(c[h >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[h >> 2] | 0);
	                if ((c[(c[h >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                    c[g >> 2] = -1;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                Ue(c[h >> 2] | 0) | 0;
	                if (((((((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 35 ? (d[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 80 : 0) ? (d[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 67 : 0) ? (d[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 68 : 0) ? (d[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) == 65 : 0) ? (d[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) == 84 : 0) ? (d[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 6 >> 0] | 0 | 0) == 65 : 0) {
	                    c[l >> 2] = vf(c[h >> 2] | 0, c[m >> 2] | 0) | 0;
	                    c[n >> 2] = 3
	                } else {
	                    c[l >> 2] = Pg(c[h >> 2] | 0, c[m >> 2] | 0, 1) | 0;
	                    c[n >> 2] = 4
	                }
	                Ue(c[h >> 2] | 0) | 0;
	                c[c[k >> 2] >> 2] = c[l >> 2];
	                c[g >> 2] = c[n >> 2];
	                o = c[g >> 2] | 0;
	                i = f;
	                return o | 0
	            }

	            function xf(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                b = i;
	                i = i + 32 | 0;
	                e = b + 20 | 0;
	                f = b + 16 | 0;
	                g = b + 12 | 0;
	                h = b + 8 | 0;
	                j = b + 4 | 0;
	                k = b;
	                c[f >> 2] = a;
	                c[h >> 2] = -1;
	                c[j >> 2] = 0;
	                a:do if (((((((((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 33 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 69 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 76 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) == 69 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) == 77 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 6 >> 0] | 0 | 0) == 69 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 7 >> 0] | 0 | 0) == 78 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 8 >> 0] | 0 | 0) == 84 : 0) {
	                    c[k >> 2] = c[(c[f >> 2] | 0) + 36 >> 2];
	                    a = (c[f >> 2] | 0) + 200 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 9;
	                    a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 9;
	                    a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 9;
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[f >> 2] | 0) | 0;
	                    do if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13)xg(c[f >> 2] | 0, 65, 68152)
	                    } while (0);
	                    Ue(c[f >> 2] | 0) | 0;
	                    c[g >> 2] = Ze(c[f >> 2] | 0) | 0;
	                    if (!(c[g >> 2] | 0)) {
	                        xg(c[f >> 2] | 0, 68, 68184);
	                        c[e >> 2] = -1;
	                        l = c[e >> 2] | 0;
	                        i = b;
	                        return l | 0
	                    }
	                    while (1) {
	                        if (!(d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0))m = (c[(c[f >> 2] | 0) + 40 >> 2] | 0) > 1; else m = 0;
	                        n = c[f >> 2] | 0;
	                        if (!m)break;
	                        Ve(n) | 0
	                    }
	                    do if ((d[c[(c[n + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13)xg(c[f >> 2] | 0, 65, 68232)
	                    } while (0);
	                    Ue(c[f >> 2] | 0) | 0;
	                    do if ((((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 69 ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 77 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 80 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 84 : 0) {
	                        if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) != 89) {
	                            o = 42;
	                            break
	                        }
	                        a = (c[f >> 2] | 0) + 200 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 5;
	                        a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 5;
	                        a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 5;
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                        do if (!(d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0)) {
	                            if ((ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0) > 0)break;
	                            Ve(c[f >> 2] | 0) | 0
	                        } while (0);
	                        c[h >> 2] = 1
	                    } else o = 42; while (0);
	                    b:do if ((o | 0) == 42) {
	                        do if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 65 ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 78 : 0) {
	                            if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) != 89)break;
	                            a = (c[f >> 2] | 0) + 200 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 3;
	                            a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 3;
	                            a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 3;
	                            if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                            do if (!(d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0)) {
	                                if ((ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0) > 0)break;
	                                Ve(c[f >> 2] | 0) | 0
	                            } while (0);
	                            c[h >> 2] = 2;
	                            break b
	                        } while (0);
	                        a = c[f >> 2] | 0;
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 40) {
	                            c[h >> 2] = wf(a, c[g >> 2] | 0, j) | 0;
	                            break
	                        }
	                        do if ((d[c[(c[a + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37) {
	                            if (c[(c[f >> 2] | 0) + 96 >> 2] | 0) {
	                                o = 57;
	                                break
	                            }
	                            if ((c[(c[f >> 2] | 0) + 40 >> 2] | 0) != 1) {
	                                o = 57;
	                                break
	                            }
	                            xg(c[f >> 2] | 0, 21, 68272)
	                        } else o = 57; while (0);
	                        if ((o | 0) == 57)xg(c[f >> 2] | 0, 54, 68336);
	                        c[e >> 2] = -1;
	                        l = c[e >> 2] | 0;
	                        i = b;
	                        return l | 0
	                    } while (0);
	                    Ue(c[f >> 2] | 0) | 0;
	                    while (1) {
	                        if (!(d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0))p = (c[(c[f >> 2] | 0) + 40 >> 2] | 0) > 1; else p = 0;
	                        q = c[f >> 2] | 0;
	                        if (!p)break;
	                        Ve(q) | 0
	                    }
	                    Ue(q) | 0;
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 62) {
	                        og(c[f >> 2] | 0, 73, 0);
	                        if (!(c[j >> 2] | 0))break;
	                        lm(c[(c[f >> 2] | 0) + 8 >> 2] | 0, c[j >> 2] | 0);
	                        break
	                    }
	                    if ((c[k >> 2] | 0) != (c[(c[f >> 2] | 0) + 36 >> 2] | 0))xg(c[f >> 2] | 0, 90, 68392);
	                    me(c[f >> 2] | 0);
	                    do if (c[c[f >> 2] >> 2] | 0) {
	                        if (c[(c[f >> 2] | 0) + 212 >> 2] | 0)break;
	                        if (!(c[(c[c[f >> 2] >> 2] | 0) + 36 >> 2] | 0))break;
	                        if (c[j >> 2] | 0)c[(c[j >> 2] | 0) + 20 >> 2] = 0;
	                        Jb[c[(c[c[f >> 2] >> 2] | 0) + 36 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0);
	                        if (!(c[j >> 2] | 0))break a;
	                        if (c[(c[j >> 2] | 0) + 20 >> 2] | 0)break a;
	                        lm(c[(c[f >> 2] | 0) + 8 >> 2] | 0, c[j >> 2] | 0);
	                        break a
	                    } while (0);
	                    if (c[j >> 2] | 0)lm(c[(c[f >> 2] | 0) + 8 >> 2] | 0, c[j >> 2] | 0)
	                } while (0);
	                c[e >> 2] = c[h >> 2];
	                l = c[e >> 2] | 0;
	                i = b;
	                return l | 0
	            }

	            function yf(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b;
	                c[e >> 2] = a;
	                if ((c[(c[e >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[e >> 2] | 0);
	                do if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60) {
	                    a = c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0;
	                    if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) != 33) {
	                        if ((d[a + 1 >> 0] | 0 | 0) != 63)break;
	                        mf(c[e >> 2] | 0);
	                        break
	                    }
	                    f = d[a + 2 >> 0] | 0;
	                    if ((f | 0) == 78) {
	                        nf(c[e >> 2] | 0);
	                        break
	                    } else if ((f | 0) == 65) {
	                        uf(c[e >> 2] | 0);
	                        break
	                    } else if ((f | 0) == 45) {
	                        kf(c[e >> 2] | 0);
	                        break
	                    } else if ((f | 0) == 69) {
	                        f = c[e >> 2] | 0;
	                        if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 76) {
	                            xf(f) | 0;
	                            break
	                        }
	                        if ((d[(c[(c[f + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) != 78)break;
	                        of(c[e >> 2] | 0);
	                        break
	                    } else break
	                } while (0);
	                if ((c[(c[e >> 2] | 0) + 96 >> 2] | 0) == 0 ? (c[(c[e >> 2] | 0) + 40 >> 2] | 0) == 1 : 0)zf(c[e >> 2] | 0);
	                if (c[(c[e >> 2] | 0) + 96 >> 2] | 0) {
	                    g = c[e >> 2] | 0;
	                    h = g + 172 | 0;
	                    c[h >> 2] = 3;
	                    i = b;
	                    return
	                }
	                if ((c[(c[e >> 2] | 0) + 40 >> 2] | 0) <= 1) {
	                    g = c[e >> 2] | 0;
	                    h = g + 172 | 0;
	                    c[h >> 2] = 3;
	                    i = b;
	                    return
	                }
	                if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 60) {
	                    g = c[e >> 2] | 0;
	                    h = g + 172 | 0;
	                    c[h >> 2] = 3;
	                    i = b;
	                    return
	                }
	                if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) != 33) {
	                    g = c[e >> 2] | 0;
	                    h = g + 172 | 0;
	                    c[h >> 2] = 3;
	                    i = b;
	                    return
	                }
	                if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) != 91) {
	                    g = c[e >> 2] | 0;
	                    h = g + 172 | 0;
	                    c[h >> 2] = 3;
	                    i = b;
	                    return
	                }
	                Qg(c[e >> 2] | 0);
	                g = c[e >> 2] | 0;
	                h = g + 172 | 0;
	                c[h >> 2] = 3;
	                i = b;
	                return
	            }

	            function zf(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                g = b + 4 | 0;
	                h = b;
	                c[e >> 2] = a;
	                c[g >> 2] = 0;
	                if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 37) {
	                    i = b;
	                    return
	                }
	                me(c[e >> 2] | 0);
	                c[f >> 2] = Ze(c[e >> 2] | 0) | 0;
	                a = c[e >> 2] | 0;
	                if (!(c[f >> 2] | 0)) {
	                    xg(a, 68, 68904);
	                    i = b;
	                    return
	                }
	                j = c[e >> 2] | 0;
	                if ((d[c[(c[a + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 59) {
	                    og(j, 23, 0);
	                    i = b;
	                    return
	                }
	                me(j);
	                j = (c[e >> 2] | 0) + 440 | 0;
	                c[j >> 2] = (c[j >> 2] | 0) + 1;
	                if ((c[c[e >> 2] >> 2] | 0) != 0 ? (c[(c[c[e >> 2] >> 2] | 0) + 96 >> 2] | 0) != 0 : 0)c[g >> 2] = Hb[c[(c[c[e >> 2] >> 2] | 0) + 96 >> 2] & 511](c[(c[e >> 2] | 0) + 4 >> 2] | 0, c[f >> 2] | 0) | 0;
	                if ((c[(c[e >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                    i = b;
	                    return
	                }
	                a:do if (c[g >> 2] | 0) {
	                    if ((c[(c[g >> 2] | 0) + 48 >> 2] | 0) != 4 ? (c[(c[g >> 2] | 0) + 48 >> 2] | 0) != 5 : 0) {
	                        rg(c[e >> 2] | 0, 27, 68936, c[f >> 2] | 0, 0);
	                        break
	                    }
	                    j = c[e >> 2] | 0;
	                    a = c[g >> 2] | 0;
	                    if ((c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 40 >> 2] | 0) != 226) {
	                        c[h >> 2] = ug(j, a) | 0;
	                        if ((Xe(c[e >> 2] | 0, c[h >> 2] | 0) | 0) >= 0)break;
	                        i = b;
	                        return
	                    }
	                    c[h >> 2] = we(j, a) | 0;
	                    if ((Xe(c[e >> 2] | 0, c[h >> 2] | 0) | 0) < 0) {
	                        i = b;
	                        return
	                    }
	                    if ((((((c[(c[g >> 2] | 0) + 48 >> 2] | 0) == 5 ? (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 : 0) ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 63 : 0) ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 120 : 0) ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 109 : 0) ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) == 108 : 0) {
	                        do if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) != 13)break a
	                        } while (0);
	                        _e(c[e >> 2] | 0);
	                        if ((c[(c[e >> 2] | 0) + 84 >> 2] | 0) == 32) {
	                            c[(c[e >> 2] | 0) + 172 >> 2] = -1;
	                            i = b;
	                            return
	                        }
	                    }
	                } else {
	                    do if ((c[(c[e >> 2] | 0) + 28 >> 2] | 0) == 1)k = 14; else {
	                        if ((c[(c[e >> 2] | 0) + 88 >> 2] | 0) == 0 ? (c[(c[e >> 2] | 0) + 92 >> 2] | 0) == 0 : 0) {
	                            k = 14;
	                            break
	                        }
	                        rg(c[e >> 2] | 0, 27, 65432, c[f >> 2] | 0, 0);
	                        c[(c[e >> 2] | 0) + 100 >> 2] = 0
	                    } while (0);
	                    if ((k | 0) == 14)pg(c[e >> 2] | 0, 26, 65432, c[f >> 2] | 0);
	                    sg(c[e >> 2] | 0, 0, 0, 0) | 0
	                } while (0);
	                c[(c[e >> 2] | 0) + 92 >> 2] = 1;
	                i = b;
	                return
	            }

	            function Af(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[f >> 2] = a;
	                c[g >> 2] = 0;
	                do if (((((((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 118 ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 101 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 114 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 115 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) == 105 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) == 111 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 6 >> 0] | 0 | 0) == 110 : 0) {
	                    a = (c[f >> 2] | 0) + 200 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 7;
	                    a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 7;
	                    a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 7;
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[f >> 2] | 0) | 0;
	                    Ue(c[f >> 2] | 0) | 0;
	                    a = c[f >> 2] | 0;
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 61) {
	                        og(a, 75, 0);
	                        c[e >> 2] = 0;
	                        h = c[e >> 2] | 0;
	                        i = b;
	                        return h | 0
	                    }
	                    me(a);
	                    Ue(c[f >> 2] | 0) | 0;
	                    a = c[f >> 2] | 0;
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 34) {
	                        me(a);
	                        c[g >> 2] = Lf(c[f >> 2] | 0) | 0;
	                        j = c[f >> 2] | 0;
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 34) {
	                            og(j, 34, 0);
	                            break
	                        } else {
	                            me(j);
	                            break
	                        }
	                    }
	                    j = c[f >> 2] | 0;
	                    if ((d[c[(c[a + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 39) {
	                        og(j, 33, 0);
	                        break
	                    }
	                    me(j);
	                    c[g >> 2] = Lf(c[f >> 2] | 0) | 0;
	                    j = c[f >> 2] | 0;
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 39) {
	                        og(j, 34, 0);
	                        break
	                    } else {
	                        me(j);
	                        break
	                    }
	                } while (0);
	                c[e >> 2] = c[g >> 2];
	                h = c[e >> 2] | 0;
	                i = b;
	                return h | 0
	            }

	            function Bf(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                g = b + 4 | 0;
	                h = b;
	                c[f >> 2] = a;
	                c[g >> 2] = 0;
	                Ue(c[f >> 2] | 0) | 0;
	                a:do if ((((((((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 101 ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 110 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 99 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 111 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) == 100 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) == 105 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 6 >> 0] | 0 | 0) == 110 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 7 >> 0] | 0 | 0) == 103 : 0) {
	                    a = (c[f >> 2] | 0) + 200 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 8;
	                    a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 8;
	                    a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 8;
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[f >> 2] | 0) | 0;
	                    Ue(c[f >> 2] | 0) | 0;
	                    a = c[f >> 2] | 0;
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 61) {
	                        og(a, 75, 0);
	                        c[e >> 2] = 0;
	                        j = c[e >> 2] | 0;
	                        i = b;
	                        return j | 0
	                    }
	                    me(a);
	                    Ue(c[f >> 2] | 0) | 0;
	                    a = c[f >> 2] | 0;
	                    do if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 34) {
	                        me(a);
	                        c[g >> 2] = Mf(c[f >> 2] | 0) | 0;
	                        k = c[f >> 2] | 0;
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 34) {
	                            og(k, 34, 0);
	                            break
	                        } else {
	                            me(k);
	                            break
	                        }
	                    } else {
	                        k = c[f >> 2] | 0;
	                        if ((d[c[(c[a + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 39) {
	                            og(k, 33, 0);
	                            break
	                        }
	                        me(k);
	                        c[g >> 2] = Mf(c[f >> 2] | 0) | 0;
	                        k = c[f >> 2] | 0;
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 39) {
	                            og(k, 34, 0);
	                            break
	                        } else {
	                            me(k);
	                            break
	                        }
	                    } while (0);
	                    if (c[(c[f >> 2] | 0) + 360 >> 2] & 2097152) {
	                        zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                        c[e >> 2] = 0;
	                        j = c[e >> 2] | 0;
	                        i = b;
	                        return j | 0
	                    }
	                    do if (c[g >> 2] | 0) {
	                        if ((ty(c[g >> 2] | 0, 69608) | 0) != 0 ? (ty(c[g >> 2] | 0, 69616) | 0) != 0 : 0)break;
	                        do if ((c[(c[f >> 2] | 0) + 24 >> 2] | 0) == 0 ? (c[c[(c[f >> 2] | 0) + 36 >> 2] >> 2] | 0) != 0 : 0) {
	                            if (c[(c[c[(c[f >> 2] | 0) + 36 >> 2] >> 2] | 0) + 12 >> 2] | 0)break;
	                            xg(c[f >> 2] | 0, 81, 69624)
	                        } while (0);
	                        if (c[(c[f >> 2] | 0) + 24 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 24 >> 2] | 0);
	                        c[(c[f >> 2] | 0) + 24 >> 2] = c[g >> 2];
	                        break a
	                    } while (0);
	                    do if (c[g >> 2] | 0) {
	                        if ((ty(c[g >> 2] | 0, 69672) | 0) != 0 ? (ty(c[g >> 2] | 0, 69680) | 0) != 0 : 0)break;
	                        if (c[(c[f >> 2] | 0) + 24 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 24 >> 2] | 0);
	                        c[(c[f >> 2] | 0) + 24 >> 2] = c[g >> 2];
	                        break a
	                    } while (0);
	                    if (c[g >> 2] | 0) {
	                        if (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 44 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 44 >> 2] | 0);
	                        c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 44 >> 2] = c[g >> 2];
	                        c[h >> 2] = Dd(c[g >> 2] | 0) | 0;
	                        a = c[f >> 2] | 0;
	                        if (c[h >> 2] | 0) {
	                            se(a, c[h >> 2] | 0) | 0;
	                            break
	                        }
	                        pg(a, 32, 69688, c[g >> 2] | 0);
	                        c[e >> 2] = 0;
	                        j = c[e >> 2] | 0;
	                        i = b;
	                        return j | 0
	                    }
	                } while (0);
	                c[e >> 2] = c[g >> 2];
	                j = c[e >> 2] | 0;
	                i = b;
	                return j | 0
	            }

	            function Cf(b, e, f) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 20 | 0;
	                j = g + 16 | 0;
	                k = g + 12 | 0;
	                l = g + 24 | 0;
	                m = g + 8 | 0;
	                n = g + 4 | 0;
	                o = g;
	                c[h >> 2] = b;
	                c[j >> 2] = e;
	                c[k >> 2] = f;
	                Rg(c[h >> 2] | 0);
	                if ((c[(c[h >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[h >> 2] | 0);
	                if (((c[(c[h >> 2] | 0) + 24 >> 2] | 0) == 0 ? ((c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) >= 4 : 0) ? (a[l >> 0] = a[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0, a[l + 1 >> 0] = a[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0, a[l + 2 >> 0] = a[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0, a[l + 3 >> 0] = a[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0, c[m >> 2] = sd(l, 4) | 0, (c[m >> 2] | 0) != 0) : 0)re(c[h >> 2] | 0, c[m >> 2] | 0) | 0;
	                if ((((((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 63 : 0) ? (d[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 120 : 0) ? (d[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 109 : 0) ? (d[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) == 108 : 0) ? (_e(c[h >> 2] | 0), (c[(c[h >> 2] | 0) + 84 >> 2] | 0) == 32) : 0) {
	                    c[(c[h >> 2] | 0) + 172 >> 2] = -1;
	                    i = g;
	                    return
	                }
	                do if (!(c[(c[h >> 2] | 0) + 8 >> 2] | 0)) {
	                    m = Sh(68488) | 0;
	                    c[(c[h >> 2] | 0) + 8 >> 2] = m;
	                    m = c[h >> 2] | 0;
	                    if (c[(c[h >> 2] | 0) + 8 >> 2] | 0) {
	                        c[(c[m + 8 >> 2] | 0) + 92 >> 2] = 64;
	                        break
	                    }
	                    ie(m, 67128);
	                    i = g;
	                    return
	                } while (0);
	                if ((c[(c[h >> 2] | 0) + 8 >> 2] | 0) != 0 ? (c[(c[(c[h >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0) == 0 : 0)Oh(c[(c[h >> 2] | 0) + 8 >> 2] | 0, 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                c[(c[h >> 2] | 0) + 172 >> 2] = 3;
	                c[(c[h >> 2] | 0) + 96 >> 2] = 1;
	                a:while (1) {
	                    if (!((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 63 : 0))p = 25;
	                    do if ((p | 0) == 25) {
	                        p = 0;
	                        if ((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 33 : 0)break;
	                        if ((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 37 ? (d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32 : 0) {
	                            if (9 <= (d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13)break a
	                        }
	                    } while (0);
	                    c[n >> 2] = c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                    c[o >> 2] = c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 36 >> 2];
	                    if ((c[(c[h >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[h >> 2] | 0);
	                    if (((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 33 : 0) ? (d[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 91 : 0)Qg(c[h >> 2] | 0); else p = 39;
	                    b:do if ((p | 0) == 39) {
	                        p = 0;
	                        do if ((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13) {
	                                k = c[h >> 2] | 0;
	                                if ((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37) {
	                                    zf(k);
	                                    break b
	                                } else {
	                                    yf(k);
	                                    break b
	                                }
	                            }
	                        } while (0);
	                        me(c[h >> 2] | 0)
	                    } while (0);
	                    while (1) {
	                        if (!(d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0))q = (c[(c[h >> 2] | 0) + 40 >> 2] | 0) > 1; else q = 0;
	                        r = c[h >> 2] | 0;
	                        if (!q)break;
	                        Ve(r) | 0
	                    }
	                    if ((c[(c[r + 36 >> 2] | 0) + 16 >> 2] | 0) != (c[n >> 2] | 0))continue;
	                    if ((c[o >> 2] | 0) == (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 36 >> 2] | 0)) {
	                        p = 53;
	                        break
	                    }
	                }
	                if ((p | 0) == 53)og(c[h >> 2] | 0, 60, 0);
	                if (!(d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0)) {
	                    i = g;
	                    return
	                }
	                og(c[h >> 2] | 0, 60, 0);
	                i = g;
	                return
	            }

	            function Df(e) {
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0;
	                f = i;
	                i = i + 112 | 0;
	                g = f;
	                h = f + 84 | 0;
	                j = f + 80 | 0;
	                k = f + 76 | 0;
	                l = f + 72 | 0;
	                m = f + 68 | 0;
	                n = f + 64 | 0;
	                o = f + 60 | 0;
	                p = f + 88 | 0;
	                q = f + 56 | 0;
	                r = f + 52 | 0;
	                s = f + 48 | 0;
	                t = f + 44 | 0;
	                u = f + 40 | 0;
	                v = f + 36 | 0;
	                w = f + 32 | 0;
	                x = f + 28 | 0;
	                y = f + 24 | 0;
	                z = f + 20 | 0;
	                A = f + 16 | 0;
	                B = f + 12 | 0;
	                C = f + 8 | 0;
	                D = f + 4 | 0;
	                c[h >> 2] = e;
	                c[m >> 2] = 0;
	                c[n >> 2] = 0;
	                if ((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 38) {
	                    i = f;
	                    return
	                }
	                if ((d[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 35) {
	                    c[o >> 2] = 0;
	                    c[q >> 2] = d[(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0];
	                    c[r >> 2] = Ye(c[h >> 2] | 0) | 0;
	                    if (!(c[r >> 2] | 0)) {
	                        i = f;
	                        return
	                    }
	                    if ((c[(c[h >> 2] | 0) + 256 >> 2] | 0) == 1) {
	                        e = pe(p + (c[o >> 2] | 0) | 0, c[r >> 2] | 0) | 0;
	                        c[o >> 2] = (c[o >> 2] | 0) + e;
	                        a[p + (c[o >> 2] | 0) >> 0] = 0;
	                        if (!(c[c[h >> 2] >> 2] | 0)) {
	                            i = f;
	                            return
	                        }
	                        if (!(c[(c[c[h >> 2] >> 2] | 0) + 68 >> 2] | 0)) {
	                            i = f;
	                            return
	                        }
	                        if (c[(c[h >> 2] | 0) + 212 >> 2] | 0) {
	                            i = f;
	                            return
	                        }
	                        Db[c[(c[c[h >> 2] >> 2] | 0) + 68 >> 2] & 511](c[(c[h >> 2] | 0) + 4 >> 2] | 0, p, c[o >> 2] | 0);
	                        i = f;
	                        return
	                    }
	                    if ((c[r >> 2] | 0) <= 255) {
	                        a[p >> 0] = c[r >> 2];
	                        a[p + 1 >> 0] = 0;
	                        if (!(c[c[h >> 2] >> 2] | 0)) {
	                            i = f;
	                            return
	                        }
	                        if (!(c[(c[c[h >> 2] >> 2] | 0) + 68 >> 2] | 0)) {
	                            i = f;
	                            return
	                        }
	                        if (c[(c[h >> 2] | 0) + 212 >> 2] | 0) {
	                            i = f;
	                            return
	                        }
	                        Db[c[(c[c[h >> 2] >> 2] | 0) + 68 >> 2] & 511](c[(c[h >> 2] | 0) + 4 >> 2] | 0, p, 1);
	                        i = f;
	                        return
	                    }
	                    o = c[r >> 2] | 0;
	                    if ((c[q >> 2] | 0) == 120 | (c[q >> 2] | 0) == 88) {
	                        c[g >> 2] = o;
	                        JT(p, 10, 68560, g) | 0
	                    } else {
	                        c[g >> 2] = o;
	                        JT(p, 10, 68568, g) | 0
	                    }
	                    if (!(c[c[h >> 2] >> 2] | 0)) {
	                        i = f;
	                        return
	                    }
	                    if (!(c[(c[c[h >> 2] >> 2] | 0) + 64 >> 2] | 0)) {
	                        i = f;
	                        return
	                    }
	                    if (c[(c[h >> 2] | 0) + 212 >> 2] | 0) {
	                        i = f;
	                        return
	                    }
	                    Ab[c[(c[c[h >> 2] >> 2] | 0) + 64 >> 2] & 511](c[(c[h >> 2] | 0) + 4 >> 2] | 0, p);
	                    i = f;
	                    return
	                }
	                c[j >> 2] = Ef(c[h >> 2] | 0) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                if (!(c[(c[h >> 2] | 0) + 12 >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                c[l >> 2] = c[(c[j >> 2] | 0) + 72 >> 2];
	                if ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 48 >> 2] | 0) != 6 : 0) {
	                    do if (!(c[(c[j >> 2] | 0) + 72 >> 2] | 0)) {
	                        if ((c[(c[j >> 2] | 0) + 48 >> 2] | 0) == 2 ? (c[(c[h >> 2] | 0) + 360 >> 2] & 18 | 0) == 0 : 0) {
	                            E = 76;
	                            break
	                        }
	                        c[s >> 2] = c[(c[h >> 2] | 0) + 440 >> 2];
	                        if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == (c[h >> 2] | 0))c[t >> 2] = 0; else c[t >> 2] = c[(c[h >> 2] | 0) + 4 >> 2];
	                        do if ((c[(c[j >> 2] | 0) + 48 >> 2] | 0) != 1)if ((c[(c[j >> 2] | 0) + 48 >> 2] | 0) == 2) {
	                            p = (c[h >> 2] | 0) + 248 | 0;
	                            c[p >> 2] = (c[p >> 2] | 0) + 1;
	                            c[n >> 2] = Tg(c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[h >> 2] | 0, c[c[h >> 2] >> 2] | 0, c[t >> 2] | 0, c[(c[h >> 2] | 0) + 248 >> 2] | 0, c[(c[j >> 2] | 0) + 64 >> 2] | 0, c[(c[j >> 2] | 0) + 52 >> 2] | 0, m) | 0;
	                            p = (c[h >> 2] | 0) + 248 | 0;
	                            c[p >> 2] = (c[p >> 2] | 0) + -1;
	                            break
	                        } else {
	                            c[n >> 2] = 88;
	                            Lg(c[h >> 2] | 0, 1, 68576, 0);
	                            break
	                        } else {
	                            p = (c[h >> 2] | 0) + 248 | 0;
	                            c[p >> 2] = (c[p >> 2] | 0) + 1;
	                            c[n >> 2] = Sg(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 40 >> 2] | 0, c[t >> 2] | 0, m) | 0;
	                            p = (c[h >> 2] | 0) + 248 | 0;
	                            c[p >> 2] = (c[p >> 2] | 0) + -1
	                        } while (0);
	                        c[(c[j >> 2] | 0) + 72 >> 2] = (c[(c[h >> 2] | 0) + 440 >> 2] | 0) - (c[s >> 2] | 0) + 1 << 1;
	                        if ((c[(c[j >> 2] | 0) + 40 >> 2] | 0) != 0 ? (vy(c[(c[j >> 2] | 0) + 40 >> 2] | 0, 60) | 0) != 0 : 0) {
	                            p = (c[j >> 2] | 0) + 72 | 0;
	                            c[p >> 2] = c[p >> 2] | 1
	                        }
	                        p = c[h >> 2] | 0;
	                        if ((c[n >> 2] | 0) == 89) {
	                            og(p, 89, 0);
	                            Uh(c[m >> 2] | 0);
	                            i = f;
	                            return
	                        }
	                        if (sg(p, 0, c[j >> 2] | 0, 0) | 0) {
	                            Uh(c[m >> 2] | 0);
	                            i = f;
	                            return
	                        }
	                        a:do if (!((c[n >> 2] | 0) == 0 & (c[m >> 2] | 0) != 0)) {
	                            if ((c[n >> 2] | 0) != 0 & (c[n >> 2] | 0) != 27) {
	                                pg(c[h >> 2] | 0, 26, 68608, c[(c[j >> 2] | 0) + 8 >> 2] | 0);
	                                sg(c[h >> 2] | 0, 0, c[j >> 2] | 0, 0) | 0;
	                                break
	                            }
	                            if (c[m >> 2] | 0) {
	                                Uh(c[m >> 2] | 0);
	                                c[m >> 2] = 0
	                            }
	                        } else {
	                            if (!((c[(c[j >> 2] | 0) + 48 >> 2] | 0) != 1 ? (c[(c[j >> 2] | 0) + 48 >> 2] | 0) != 2 : 0))E = 51;
	                            if ((E | 0) == 51 ? (c[(c[j >> 2] | 0) + 12 >> 2] | 0) == 0 : 0) {
	                                c[(c[j >> 2] | 0) + 12 >> 2] = c[m >> 2];
	                                if (!(c[(c[h >> 2] | 0) + 16 >> 2] | 0)) {
	                                    c[(c[j >> 2] | 0) + 68 >> 2] = 1;
	                                    while (1) {
	                                        if (!(c[m >> 2] | 0))break a;
	                                        c[(c[m >> 2] | 0) + 20 >> 2] = c[j >> 2];
	                                        ri(c[m >> 2] | 0, c[(c[j >> 2] | 0) + 32 >> 2] | 0);
	                                        if (!(c[(c[m >> 2] | 0) + 24 >> 2] | 0))c[(c[j >> 2] | 0) + 16 >> 2] = c[m >> 2];
	                                        c[m >> 2] = c[(c[m >> 2] | 0) + 24 >> 2]
	                                    }
	                                }
	                                if (!((c[(c[m >> 2] | 0) + 4 >> 2] | 0) == 3 ? (c[(c[m >> 2] | 0) + 24 >> 2] | 0) == 0 : 0))E = 55;
	                                do if ((E | 0) == 55) {
	                                    if ((c[(c[h >> 2] | 0) + 436 >> 2] | 0) == 5)break;
	                                    c[(c[j >> 2] | 0) + 68 >> 2] = 0;
	                                    while (1) {
	                                        if (!(c[m >> 2] | 0))break;
	                                        c[(c[m >> 2] | 0) + 20 >> 2] = c[(c[h >> 2] | 0) + 52 >> 2];
	                                        c[(c[m >> 2] | 0) + 32 >> 2] = c[(c[h >> 2] | 0) + 8 >> 2];
	                                        if (!(c[(c[m >> 2] | 0) + 24 >> 2] | 0))c[(c[j >> 2] | 0) + 16 >> 2] = c[m >> 2];
	                                        c[m >> 2] = c[(c[m >> 2] | 0) + 24 >> 2]
	                                    }
	                                    c[m >> 2] = c[(c[j >> 2] | 0) + 12 >> 2];
	                                    if ((c[(c[j >> 2] | 0) + 48 >> 2] | 0) != 2)break a;
	                                    Ug(c[j >> 2] | 0, c[m >> 2] | 0, 0);
	                                    break a
	                                } while (0);
	                                c[(c[m >> 2] | 0) + 20 >> 2] = c[j >> 2];
	                                c[m >> 2] = 0;
	                                c[(c[j >> 2] | 0) + 68 >> 2] = 1;
	                                break
	                            }
	                            Uh(c[m >> 2] | 0);
	                            c[m >> 2] = 0
	                        } while (0);
	                        if (!(c[(c[j >> 2] | 0) + 72 >> 2] | 0))c[(c[j >> 2] | 0) + 72 >> 2] = 2
	                    } else E = 76; while (0);
	                    if ((E | 0) == 76 ? (c[(c[j >> 2] | 0) + 72 >> 2] | 0) != 1 : 0) {
	                        s = (c[h >> 2] | 0) + 440 | 0;
	                        c[s >> 2] = (c[s >> 2] | 0) + ((c[(c[j >> 2] | 0) + 72 >> 2] | 0) / 2 | 0)
	                    }
	                    if (!(c[(c[j >> 2] | 0) + 12 >> 2] | 0)) {
	                        if (c[l >> 2] | 0) {
	                            if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == (c[h >> 2] | 0))c[u >> 2] = 0; else c[u >> 2] = c[(c[h >> 2] | 0) + 4 >> 2];
	                            do if ((c[(c[j >> 2] | 0) + 48 >> 2] | 0) != 1)if ((c[(c[j >> 2] | 0) + 48 >> 2] | 0) == 2) {
	                                l = (c[h >> 2] | 0) + 248 | 0;
	                                c[l >> 2] = (c[l >> 2] | 0) + 1;
	                                c[n >> 2] = Tg(c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[h >> 2] | 0, c[c[h >> 2] >> 2] | 0, c[u >> 2] | 0, c[(c[h >> 2] | 0) + 248 >> 2] | 0, c[(c[j >> 2] | 0) + 64 >> 2] | 0, c[(c[j >> 2] | 0) + 52 >> 2] | 0, 0) | 0;
	                                l = (c[h >> 2] | 0) + 248 | 0;
	                                c[l >> 2] = (c[l >> 2] | 0) + -1;
	                                break
	                            } else {
	                                c[n >> 2] = 88;
	                                Lg(c[h >> 2] | 0, 1, 68576, 0);
	                                break
	                            } else {
	                                l = (c[h >> 2] | 0) + 248 | 0;
	                                c[l >> 2] = (c[l >> 2] | 0) + 1;
	                                c[n >> 2] = Sg(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 40 >> 2] | 0, c[u >> 2] | 0, 0) | 0;
	                                l = (c[h >> 2] | 0) + 248 | 0;
	                                c[l >> 2] = (c[l >> 2] | 0) + -1
	                            } while (0);
	                            if ((c[n >> 2] | 0) == 89) {
	                                og(c[h >> 2] | 0, 89, 0);
	                                i = f;
	                                return
	                            }
	                        }
	                        if (!(c[c[h >> 2] >> 2] | 0)) {
	                            i = f;
	                            return
	                        }
	                        if (!(c[(c[c[h >> 2] >> 2] | 0) + 64 >> 2] | 0)) {
	                            i = f;
	                            return
	                        }
	                        if (c[(c[h >> 2] | 0) + 16 >> 2] | 0) {
	                            i = f;
	                            return
	                        }
	                        if (c[(c[h >> 2] | 0) + 212 >> 2] | 0) {
	                            i = f;
	                            return
	                        }
	                        Ab[c[(c[c[h >> 2] >> 2] | 0) + 64 >> 2] & 511](c[(c[h >> 2] | 0) + 4 >> 2] | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0);
	                        i = f;
	                        return
	                    }
	                    if ((((c[c[h >> 2] >> 2] | 0) != 0 ? (c[(c[c[h >> 2] >> 2] | 0) + 64 >> 2] | 0) != 0 : 0) ? (c[(c[h >> 2] | 0) + 16 >> 2] | 0) == 0 : 0) ? (c[(c[h >> 2] | 0) + 212 >> 2] | 0) == 0 : 0) {
	                        Ab[c[(c[c[h >> 2] >> 2] | 0) + 64 >> 2] & 511](c[(c[h >> 2] | 0) + 4 >> 2] | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0);
	                        i = f;
	                        return
	                    }
	                    if ((c[(c[h >> 2] | 0) + 16 >> 2] | 0) == 0 ? (c[(c[j >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                        i = f;
	                        return
	                    }
	                    if (!(c[(c[h >> 2] | 0) + 52 >> 2] | 0)) {
	                        i = f;
	                        return
	                    }
	                    if (!(c[(c[j >> 2] | 0) + 12 >> 2] | 0)) {
	                        i = f;
	                        return
	                    }
	                    if ((c[m >> 2] | 0) == 0 ? (c[(c[j >> 2] | 0) + 68 >> 2] | 0) == 0 : 0)E = 107; else E = 106;
	                    do if ((E | 0) == 106)if ((c[(c[h >> 2] | 0) + 436 >> 2] | 0) != 5) {
	                        if ((c[m >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 40 >> 2] | 0) <= 0 : 0) {
	                            c[D >> 2] = AP(c[(c[h >> 2] | 0) + 296 >> 2] | 0, 68640, -1) | 0;
	                            if ((c[(c[(c[j >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) == 3)c[(c[(c[j >> 2] | 0) + 12 >> 2] | 0) + 8 >> 2] = c[D >> 2];
	                            do if ((c[(c[j >> 2] | 0) + 16 >> 2] | 0) != (c[(c[j >> 2] | 0) + 12 >> 2] | 0)) {
	                                if ((c[(c[(c[j >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) != 3)break;
	                                c[(c[(c[j >> 2] | 0) + 16 >> 2] | 0) + 8 >> 2] = c[D >> 2]
	                            } while (0);
	                            yi(c[(c[h >> 2] | 0) + 52 >> 2] | 0, c[(c[j >> 2] | 0) + 12 >> 2] | 0) | 0;
	                            break
	                        }
	                        c[y >> 2] = 0;
	                        c[C >> 2] = 0;
	                        n = (c[h >> 2] | 0) + 468 | 0;
	                        c[n >> 2] = (c[n >> 2] | 0) + ((c[(c[j >> 2] | 0) + 44 >> 2] | 0) + 5);
	                        if (sg(c[h >> 2] | 0, 0, c[j >> 2] | 0, c[(c[h >> 2] | 0) + 468 >> 2] | 0) | 0) {
	                            i = f;
	                            return
	                        }
	                        c[z >> 2] = c[(c[j >> 2] | 0) + 12 >> 2];
	                        c[(c[j >> 2] | 0) + 12 >> 2] = 0;
	                        c[B >> 2] = c[(c[j >> 2] | 0) + 16 >> 2];
	                        c[(c[j >> 2] | 0) + 16 >> 2] = 0;
	                        while (1) {
	                            if (!(c[z >> 2] | 0))break;
	                            c[A >> 2] = c[(c[z >> 2] | 0) + 24 >> 2];
	                            c[(c[z >> 2] | 0) + 24 >> 2] = 0;
	                            c[(c[z >> 2] | 0) + 20 >> 2] = 0;
	                            c[y >> 2] = Ii(c[z >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0, 1) | 0;
	                            if (c[y >> 2] | 0) {
	                                if (!(c[c[y >> 2] >> 2] | 0))c[c[y >> 2] >> 2] = c[c[z >> 2] >> 2];
	                                if (!(c[C >> 2] | 0))c[C >> 2] = c[z >> 2];
	                                zi(c[j >> 2] | 0, c[y >> 2] | 0) | 0;
	                                zi(c[(c[h >> 2] | 0) + 52 >> 2] | 0, c[z >> 2] | 0) | 0
	                            }
	                            if ((c[z >> 2] | 0) == (c[B >> 2] | 0))break;
	                            c[z >> 2] = c[A >> 2]
	                        }
	                        if (!(c[(c[j >> 2] | 0) + 68 >> 2] | 0))c[(c[j >> 2] | 0) + 68 >> 2] = 1;
	                        if ((c[(c[j >> 2] | 0) + 48 >> 2] | 0) == 2)Ug(c[j >> 2] | 0, c[C >> 2] | 0, c[y >> 2] | 0)
	                    } else E = 107; while (0);
	                    if ((E | 0) == 107) {
	                        c[v >> 2] = 0;
	                        c[x >> 2] = 0;
	                        y = (c[h >> 2] | 0) + 468 | 0;
	                        c[y >> 2] = (c[y >> 2] | 0) + ((c[(c[j >> 2] | 0) + 44 >> 2] | 0) + 5);
	                        if (sg(c[h >> 2] | 0, 0, c[j >> 2] | 0, c[(c[h >> 2] | 0) + 468 >> 2] | 0) | 0) {
	                            i = f;
	                            return
	                        }
	                        c[w >> 2] = c[(c[j >> 2] | 0) + 12 >> 2];
	                        while (1) {
	                            if (!(c[w >> 2] | 0))break;
	                            c[v >> 2] = Ii(c[w >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0, 1) | 0;
	                            if (c[v >> 2] | 0) {
	                                if (!(c[c[v >> 2] >> 2] | 0))c[c[v >> 2] >> 2] = c[c[w >> 2] >> 2];
	                                if (!(c[x >> 2] | 0))c[x >> 2] = c[v >> 2];
	                                c[v >> 2] = zi(c[(c[h >> 2] | 0) + 52 >> 2] | 0, c[v >> 2] | 0) | 0
	                            }
	                            if ((c[w >> 2] | 0) == (c[(c[j >> 2] | 0) + 16 >> 2] | 0)) {
	                                E = 117;
	                                break
	                            }
	                            c[w >> 2] = c[(c[w >> 2] | 0) + 24 >> 2]
	                        }
	                        if ((((E | 0) == 117 ? ((c[v >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 436 >> 2] | 0) == 5 : 0) : 0) ? (c[(c[v >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (c[(c[v >> 2] | 0) + 12 >> 2] | 0) == 0 : 0)b[(c[v >> 2] | 0) + 58 >> 1] = 1;
	                        if ((c[(c[j >> 2] | 0) + 48 >> 2] | 0) == 2)Ug(c[j >> 2] | 0, c[x >> 2] | 0, c[v >> 2] | 0)
	                    }
	                    c[(c[h >> 2] | 0) + 264 >> 2] = 0;
	                    c[(c[h >> 2] | 0) + 260 >> 2] = 0;
	                    i = f;
	                    return
	                }
	                c[k >> 2] = c[(c[j >> 2] | 0) + 40 >> 2];
	                if (!(c[k >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                if (!(c[c[h >> 2] >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                if (!(c[(c[c[h >> 2] >> 2] | 0) + 68 >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                if (c[(c[h >> 2] | 0) + 212 >> 2] | 0) {
	                    i = f;
	                    return
	                }
	                j = c[(c[c[h >> 2] >> 2] | 0) + 68 >> 2] | 0;
	                v = c[(c[h >> 2] | 0) + 4 >> 2] | 0;
	                h = c[k >> 2] | 0;
	                x = xy(c[k >> 2] | 0) | 0;
	                Db[j & 511](v, h, x);
	                i = f;
	                return
	            }

	            function Ef(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                g = b + 4 | 0;
	                h = b;
	                c[f >> 2] = a;
	                c[h >> 2] = 0;
	                if ((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[f >> 2] | 0);
	                if ((c[(c[f >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 38) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                me(c[f >> 2] | 0);
	                c[g >> 2] = Ze(c[f >> 2] | 0) | 0;
	                a = c[f >> 2] | 0;
	                if (!(c[g >> 2] | 0)) {
	                    xg(a, 68, 68648);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                k = c[f >> 2] | 0;
	                if ((d[c[(c[a + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 59) {
	                    og(k, 23, 0);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                me(k);
	                if ((c[(c[f >> 2] | 0) + 360 >> 2] & 1048576 | 0) == 0 ? (c[h >> 2] = Yc(c[g >> 2] | 0) | 0, (c[h >> 2] | 0) != 0) : 0) {
	                    c[e >> 2] = c[h >> 2];
	                    j = c[e >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                k = (c[f >> 2] | 0) + 440 | 0;
	                c[k >> 2] = (c[k >> 2] | 0) + 1;
	                if (c[c[f >> 2] >> 2] | 0) {
	                    if (c[(c[c[f >> 2] >> 2] | 0) + 20 >> 2] | 0)c[h >> 2] = Hb[c[(c[c[f >> 2] >> 2] | 0) + 20 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0, c[g >> 2] | 0) | 0;
	                    if (((c[h >> 2] | 0) == 0 ? (c[(c[f >> 2] | 0) + 12 >> 2] | 0) == 1 : 0) ? (c[(c[f >> 2] | 0) + 360 >> 2] & 1048576 | 0) != 0 : 0)c[h >> 2] = Yc(c[g >> 2] | 0) | 0;
	                    if (((c[h >> 2] | 0) == 0 ? (c[(c[f >> 2] | 0) + 12 >> 2] | 0) == 1 : 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) == (c[f >> 2] | 0) : 0)c[h >> 2] = VP(c[f >> 2] | 0, c[g >> 2] | 0) | 0
	                }
	                if ((c[(c[f >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                do if (c[h >> 2] | 0) {
	                    k = c[f >> 2] | 0;
	                    if ((c[(c[h >> 2] | 0) + 48 >> 2] | 0) == 3) {
	                        pg(k, 28, 68712, c[g >> 2] | 0);
	                        break
	                    }
	                    if ((c[k + 172 >> 2] | 0) == 12 ? (c[(c[h >> 2] | 0) + 48 >> 2] | 0) == 2 : 0) {
	                        pg(c[f >> 2] | 0, 29, 68752, c[g >> 2] | 0);
	                        break
	                    }
	                    if (((c[h >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 172 >> 2] | 0) == 12 : 0) ? (c[(c[h >> 2] | 0) + 48 >> 2] | 0) != 6 : 0) {
	                        if ((c[(c[h >> 2] | 0) + 72 >> 2] & 1 | 0) == 0 ? (c[(c[h >> 2] | 0) + 72 >> 2] | 0) != 0 : 0)break;
	                        if (!(c[(c[h >> 2] | 0) + 40 >> 2] | 0))break;
	                        if (!(vy(c[(c[h >> 2] | 0) + 40 >> 2] | 0, 60) | 0))break;
	                        pg(c[f >> 2] | 0, 38, 68800, c[g >> 2] | 0);
	                        break
	                    }
	                    if (((c[(c[h >> 2] | 0) + 48 >> 2] | 0) + -4 | 0) >>> 0 < 2)pg(c[f >> 2] | 0, 30, 68856, c[g >> 2] | 0)
	                } else {
	                    do if ((c[(c[f >> 2] | 0) + 28 >> 2] | 0) != 1) {
	                        if ((c[(c[f >> 2] | 0) + 88 >> 2] | 0) == 0 ? (c[(c[f >> 2] | 0) + 92 >> 2] | 0) == 0 : 0) {
	                            l = 30;
	                            break
	                        }
	                        Lg(c[f >> 2] | 0, 27, 68680, c[g >> 2] | 0);
	                        if (((c[(c[f >> 2] | 0) + 216 >> 2] | 0) == 0 ? (c[c[f >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[c[f >> 2] >> 2] | 0) + 64 >> 2] | 0) != 0 : 0)Ab[c[(c[c[f >> 2] >> 2] | 0) + 64 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0, c[g >> 2] | 0)
	                    } else l = 30; while (0);
	                    if ((l | 0) == 30)pg(c[f >> 2] | 0, 26, 68680, c[g >> 2] | 0);
	                    sg(c[f >> 2] | 0, 0, c[h >> 2] | 0, 0) | 0;
	                    c[(c[f >> 2] | 0) + 100 >> 2] = 0
	                } while (0);
	                c[e >> 2] = c[h >> 2];
	                j = c[e >> 2] | 0;
	                i = b;
	                return j | 0
	            }

	            function Ff(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                g = b + 4 | 0;
	                h = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                c[g >> 2] = 0;
	                c[h >> 2] = 0;
	                a = (c[e >> 2] | 0) + 200 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + 9;
	                a = (c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + 9;
	                a = (c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + 9;
	                if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[e >> 2] | 0);
	                if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[e >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[e >> 2] | 0) | 0;
	                Ue(c[e >> 2] | 0) | 0;
	                c[f >> 2] = Ze(c[e >> 2] | 0) | 0;
	                if (!(c[f >> 2] | 0))xg(c[e >> 2] | 0, 68, 68984);
	                c[(c[e >> 2] | 0) + 220 >> 2] = c[f >> 2];
	                Ue(c[e >> 2] | 0) | 0;
	                c[h >> 2] = jf(c[e >> 2] | 0, g, 1) | 0;
	                if ((c[h >> 2] | 0) != 0 | (c[g >> 2] | 0) != 0)c[(c[e >> 2] | 0) + 88 >> 2] = 1;
	                c[(c[e >> 2] | 0) + 224 >> 2] = c[h >> 2];
	                c[(c[e >> 2] | 0) + 228 >> 2] = c[g >> 2];
	                Ue(c[e >> 2] | 0) | 0;
	                if (((c[c[e >> 2] >> 2] | 0) != 0 ? (c[c[c[e >> 2] >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[e >> 2] | 0) + 212 >> 2] | 0) == 0 : 0)Jb[c[c[c[e >> 2] >> 2] >> 2] & 511](c[(c[e >> 2] | 0) + 4 >> 2] | 0, c[f >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0);
	                if ((c[(c[e >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                    i = b;
	                    return
	                }
	                if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 91) {
	                    i = b;
	                    return
	                }
	                if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 62)og(c[e >> 2] | 0, 61, 0);
	                me(c[e >> 2] | 0);
	                i = b;
	                return
	            }

	            function Gf(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[c[h >> 2] >> 2] = 0;
	                if ((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[g >> 2] | 0);
	                c[j >> 2] = Ze(c[g >> 2] | 0) | 0;
	                b = c[g >> 2] | 0;
	                if (!(c[j >> 2] | 0)) {
	                    xg(b, 68, 69032);
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                Ue(b) | 0;
	                b = c[g >> 2] | 0;
	                if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 61) {
	                    pg(b, 41, 69064, c[j >> 2] | 0);
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                me(b);
	                Ue(c[g >> 2] | 0) | 0;
	                c[k >> 2] = ef(c[g >> 2] | 0) | 0;
	                c[(c[g >> 2] | 0) + 172 >> 2] = 7;
	                if (((c[(c[g >> 2] | 0) + 268 >> 2] | 0) != 0 ? (qy(c[j >> 2] | 0, 69112) | 0) != 0 : 0) ? (Ne(c[k >> 2] | 0) | 0) == 0 : 0)rg(c[g >> 2] | 0, 98, 69128, c[k >> 2] | 0, 0);
	                do if (qy(c[j >> 2] | 0, 69168) | 0) {
	                    if (qy(c[k >> 2] | 0, 69184) | 0) {
	                        c[c[(c[g >> 2] | 0) + 232 >> 2] >> 2] = 0;
	                        break
	                    }
	                    b = (qy(c[k >> 2] | 0, 69192) | 0) != 0;
	                    a = c[g >> 2] | 0;
	                    if (b) {
	                        c[c[a + 232 >> 2] >> 2] = 1;
	                        break
	                    } else {
	                        rg(a, 102, 69208, c[k >> 2] | 0, 0);
	                        break
	                    }
	                } while (0);
	                c[c[h >> 2] >> 2] = c[k >> 2];
	                c[f >> 2] = c[j >> 2];
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function Hf(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                b = i;
	                i = i + 48 | 0;
	                e = b + 44 | 0;
	                f = b + 40 | 0;
	                g = b + 36 | 0;
	                h = b + 32 | 0;
	                j = b + 28 | 0;
	                k = b + 24 | 0;
	                l = b + 20 | 0;
	                m = b + 16 | 0;
	                n = b + 12 | 0;
	                o = b + 8 | 0;
	                p = b + 4 | 0;
	                q = b;
	                c[f >> 2] = a;
	                c[k >> 2] = c[(c[f >> 2] | 0) + 300 >> 2];
	                c[l >> 2] = 0;
	                c[m >> 2] = c[(c[f >> 2] | 0) + 304 >> 2];
	                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 60) {
	                    c[e >> 2] = 0;
	                    r = c[e >> 2] | 0;
	                    i = b;
	                    return r | 0
	                }
	                a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + 1;
	                a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + 1;
	                a = (c[f >> 2] | 0) + 200 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + 1;
	                if (!(d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0))ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0;
	                c[g >> 2] = Ze(c[f >> 2] | 0) | 0;
	                a = c[f >> 2] | 0;
	                if (!(c[g >> 2] | 0)) {
	                    xg(a, 68, 69280);
	                    c[e >> 2] = 0;
	                    r = c[e >> 2] | 0;
	                    i = b;
	                    return r | 0
	                }
	                Ue(a) | 0;
	                if ((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[f >> 2] | 0);
	                while (1) {
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 62)break;
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 47 ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 62 : 0)break;
	                    if (!(9 <= (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0))s = 15;
	                    if (((s | 0) == 15 ? (s = 0, (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13) : 0) ? 32 > (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) : 0)break;
	                    if ((c[(c[f >> 2] | 0) + 172 >> 2] | 0) == -1)break;
	                    c[o >> 2] = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                    c[p >> 2] = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 36 >> 2];
	                    c[h >> 2] = Gf(c[f >> 2] | 0, j) | 0;
	                    a:do if (!((c[h >> 2] | 0) != 0 & (c[j >> 2] | 0) != 0)) {
	                        if (c[j >> 2] | 0)zb[c[135736 >> 2] & 511](c[j >> 2] | 0)
	                    } else {
	                        c[n >> 2] = 0;
	                        while (1) {
	                            if ((c[n >> 2] | 0) >= (c[l >> 2] | 0))break;
	                            if (qy(c[(c[k >> 2] | 0) + (c[n >> 2] << 2) >> 2] | 0, c[h >> 2] | 0) | 0) {
	                                s = 22;
	                                break
	                            }
	                            c[n >> 2] = (c[n >> 2] | 0) + 2
	                        }
	                        if ((s | 0) == 22) {
	                            s = 0;
	                            Vg(c[f >> 2] | 0, 0, c[h >> 2] | 0);
	                            zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                            break
	                        }
	                        do if (c[k >> 2] | 0) {
	                            if (((c[l >> 2] | 0) + 4 | 0) > (c[m >> 2] | 0)) {
	                                c[m >> 2] = c[m >> 2] << 1;
	                                c[q >> 2] = Hb[c[135760 >> 2] & 511](c[k >> 2] | 0, c[m >> 2] << 2) | 0;
	                                if (c[q >> 2] | 0) {
	                                    c[k >> 2] = c[q >> 2];
	                                    c[(c[f >> 2] | 0) + 300 >> 2] = c[k >> 2];
	                                    c[(c[f >> 2] | 0) + 304 >> 2] = c[m >> 2];
	                                    break
	                                }
	                                ie(c[f >> 2] | 0, 0);
	                                if (!(c[j >> 2] | 0))break a;
	                                zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                                break a
	                            }
	                        } else {
	                            c[m >> 2] = 22;
	                            c[k >> 2] = Cb[c[135744 >> 2] & 511](c[m >> 2] << 2) | 0;
	                            if (c[k >> 2] | 0) {
	                                c[(c[f >> 2] | 0) + 300 >> 2] = c[k >> 2];
	                                c[(c[f >> 2] | 0) + 304 >> 2] = c[m >> 2];
	                                break
	                            }
	                            ie(c[f >> 2] | 0, 0);
	                            if (!(c[j >> 2] | 0))break a;
	                            zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                            break a
	                        } while (0);
	                        a = c[h >> 2] | 0;
	                        t = c[l >> 2] | 0;
	                        c[l >> 2] = t + 1;
	                        c[(c[k >> 2] | 0) + (t << 2) >> 2] = a;
	                        a = c[j >> 2] | 0;
	                        t = c[l >> 2] | 0;
	                        c[l >> 2] = t + 1;
	                        c[(c[k >> 2] | 0) + (t << 2) >> 2] = a;
	                        c[(c[k >> 2] | 0) + (c[l >> 2] << 2) >> 2] = 0;
	                        c[(c[k >> 2] | 0) + ((c[l >> 2] | 0) + 1 << 2) >> 2] = 0
	                    } while (0);
	                    if ((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[f >> 2] | 0);
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 62)break;
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 47 ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 62 : 0)break;
	                    do if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13)xg(c[f >> 2] | 0, 65, 69320)
	                    } while (0);
	                    Ue(c[f >> 2] | 0) | 0;
	                    if ((c[p >> 2] | 0) == (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 36 >> 2] | 0) ? ((c[h >> 2] | 0) == 0 ? (c[o >> 2] | 0) == (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) : 0) & (c[j >> 2] | 0) == 0 : 0) {
	                        s = 50;
	                        break
	                    }
	                    if (((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 : 0) ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)Fg(c[f >> 2] | 0);
	                    if (c[(c[f >> 2] | 0) + 292 >> 2] | 0)continue;
	                    if (((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) >= 250)continue;
	                    vg(c[f >> 2] | 0)
	                }
	                if ((s | 0) == 50)xg(c[f >> 2] | 0, 1, 69352);
	                do if (((c[c[f >> 2] >> 2] | 0) != 0 ? (c[(c[c[f >> 2] >> 2] | 0) + 56 >> 2] | 0) != 0 : 0) ? (c[(c[f >> 2] | 0) + 212 >> 2] | 0) == 0 : 0) {
	                    s = c[(c[c[f >> 2] >> 2] | 0) + 56 >> 2] | 0;
	                    j = c[(c[f >> 2] | 0) + 4 >> 2] | 0;
	                    o = c[g >> 2] | 0;
	                    if ((c[l >> 2] | 0) > 0) {
	                        Db[s & 511](j, o, c[k >> 2] | 0);
	                        break
	                    } else {
	                        Db[s & 511](j, o, 0);
	                        break
	                    }
	                } while (0);
	                b:do if (c[k >> 2] | 0) {
	                    c[n >> 2] = 1;
	                    while (1) {
	                        if ((c[n >> 2] | 0) >= (c[l >> 2] | 0))break b;
	                        if (c[(c[k >> 2] | 0) + (c[n >> 2] << 2) >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[k >> 2] | 0) + (c[n >> 2] << 2) >> 2] | 0);
	                        c[n >> 2] = (c[n >> 2] | 0) + 2
	                    }
	                } while (0);
	                c[e >> 2] = c[g >> 2];
	                r = c[e >> 2] | 0;
	                i = b;
	                return r | 0
	            }

	            function If(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 44 | 0;
	                g = e + 40 | 0;
	                h = e + 36 | 0;
	                j = e + 32 | 0;
	                k = e + 28 | 0;
	                l = e + 24 | 0;
	                m = e + 20 | 0;
	                n = e + 16 | 0;
	                o = e + 12 | 0;
	                p = e + 8 | 0;
	                q = e + 4 | 0;
	                r = e;
	                c[f >> 2] = b;
	                c[g >> 2] = 0;
	                c[h >> 2] = 0;
	                c[j >> 2] = 100;
	                c[q >> 2] = 0;
	                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 60) {
	                    i = e;
	                    return
	                }
	                if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) != 33) {
	                    i = e;
	                    return
	                }
	                if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) != 91) {
	                    i = e;
	                    return
	                }
	                if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) != 67) {
	                    i = e;
	                    return
	                }
	                if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) != 68) {
	                    i = e;
	                    return
	                }
	                if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) != 65) {
	                    i = e;
	                    return
	                }
	                if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 6 >> 0] | 0 | 0) != 84) {
	                    i = e;
	                    return
	                }
	                if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 7 >> 0] | 0 | 0) != 65) {
	                    i = e;
	                    return
	                }
	                if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 8 >> 0] | 0 | 0) != 91) {
	                    i = e;
	                    return
	                }
	                b = (c[f >> 2] | 0) + 200 | 0;
	                c[b >> 2] = (c[b >> 2] | 0) + 9;
	                b = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                c[b >> 2] = (c[b >> 2] | 0) + 9;
	                b = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                c[b >> 2] = (c[b >> 2] | 0) + 9;
	                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[f >> 2] | 0) | 0;
	                c[(c[f >> 2] | 0) + 172 >> 2] = 8;
	                c[k >> 2] = ne(c[f >> 2] | 0, l) | 0;
	                b = c[k >> 2] | 0;
	                if ((c[k >> 2] | 0) < 256) {
	                    if (!(9 <= (b | 0) & (c[k >> 2] | 0) <= 10 | (c[k >> 2] | 0) == 13 | 32 <= (c[k >> 2] | 0)))s = 20
	                } else if ((!(256 <= (b | 0) & (c[k >> 2] | 0) <= 55295) ? !(57344 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 65533) : 0) ? !(65536 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 1114111) : 0)s = 20;
	                if ((s | 0) == 20) {
	                    og(c[f >> 2] | 0, 63, 0);
	                    c[(c[f >> 2] | 0) + 172 >> 2] = 7;
	                    i = e;
	                    return
	                }
	                b = c[(c[f >> 2] | 0) + 36 >> 2] | 0;
	                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                    t = b + 28 | 0;
	                    c[t >> 2] = (c[t >> 2] | 0) + 1;
	                    c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                } else {
	                    t = b + 32 | 0;
	                    c[t >> 2] = (c[t >> 2] | 0) + 1
	                }
	                t = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                c[t >> 2] = (c[t >> 2] | 0) + (c[l >> 2] | 0);
	                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                c[m >> 2] = ne(c[f >> 2] | 0, n) | 0;
	                t = c[m >> 2] | 0;
	                if ((c[m >> 2] | 0) < 256) {
	                    if (!(9 <= (t | 0) & (c[m >> 2] | 0) <= 10 | (c[m >> 2] | 0) == 13 | 32 <= (c[m >> 2] | 0)))s = 31
	                } else if ((!(256 <= (t | 0) & (c[m >> 2] | 0) <= 55295) ? !(57344 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 65533) : 0) ? !(65536 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 1114111) : 0)s = 31;
	                if ((s | 0) == 31) {
	                    og(c[f >> 2] | 0, 63, 0);
	                    c[(c[f >> 2] | 0) + 172 >> 2] = 7;
	                    i = e;
	                    return
	                }
	                t = c[(c[f >> 2] | 0) + 36 >> 2] | 0;
	                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                    b = t + 28 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 1;
	                    c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                } else {
	                    b = t + 32 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 1
	                }
	                b = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                c[b >> 2] = (c[b >> 2] | 0) + (c[n >> 2] | 0);
	                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                c[o >> 2] = ne(c[f >> 2] | 0, p) | 0;
	                c[g >> 2] = Cb[c[135752 >> 2] & 511](c[j >> 2] | 0) | 0;
	                if (!(c[g >> 2] | 0)) {
	                    ie(c[f >> 2] | 0, 0);
	                    i = e;
	                    return
	                }
	                while (1) {
	                    b = c[o >> 2] | 0;
	                    do if ((c[o >> 2] | 0) < 256)if (9 <= (b | 0) & (c[o >> 2] | 0) <= 10 | (c[o >> 2] | 0) == 13 | 32 <= (c[o >> 2] | 0))s = 44; else u = 0; else {
	                        if (256 <= (b | 0) & (c[o >> 2] | 0) <= 55295) {
	                            s = 44;
	                            break
	                        }
	                        if (57344 <= (c[o >> 2] | 0) & (c[o >> 2] | 0) <= 65533) {
	                            s = 44;
	                            break
	                        }
	                        if (65536 <= (c[o >> 2] | 0) & (c[o >> 2] | 0) <= 1114111)s = 44; else u = 0
	                    } while (0);
	                    do if ((s | 0) == 44) {
	                        s = 0;
	                        if ((c[k >> 2] | 0) != 93 | (c[m >> 2] | 0) != 93) {
	                            u = 1;
	                            break
	                        }
	                        u = (c[o >> 2] | 0) != 62
	                    } while (0);
	                    v = c[h >> 2] | 0;
	                    if (!u) {
	                        s = 70;
	                        break
	                    }
	                    if ((v + 5 | 0) >= (c[j >> 2] | 0)) {
	                        if ((c[j >> 2] | 0) > 1e7 ? (c[(c[f >> 2] | 0) + 360 >> 2] & 524288 | 0) == 0 : 0) {
	                            s = 50;
	                            break
	                        }
	                        c[r >> 2] = Hb[c[135760 >> 2] & 511](c[g >> 2] | 0, c[j >> 2] << 1) | 0;
	                        if (!(c[r >> 2] | 0)) {
	                            s = 52;
	                            break
	                        }
	                        c[g >> 2] = c[r >> 2];
	                        c[j >> 2] = c[j >> 2] << 1
	                    }
	                    if ((c[l >> 2] | 0) == 1) {
	                        b = c[k >> 2] & 255;
	                        t = c[h >> 2] | 0;
	                        c[h >> 2] = t + 1;
	                        a[(c[g >> 2] | 0) + t >> 0] = b
	                    } else {
	                        b = pe((c[g >> 2] | 0) + (c[h >> 2] | 0) | 0, c[k >> 2] | 0) | 0;
	                        c[h >> 2] = (c[h >> 2] | 0) + b
	                    }
	                    c[k >> 2] = c[m >> 2];
	                    c[l >> 2] = c[n >> 2];
	                    c[m >> 2] = c[o >> 2];
	                    c[n >> 2] = c[p >> 2];
	                    c[q >> 2] = (c[q >> 2] | 0) + 1;
	                    if ((c[q >> 2] | 0) > 50) {
	                        do if (!(c[(c[f >> 2] | 0) + 292 >> 2] | 0)) {
	                            if (((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) >= 250)break;
	                            vg(c[f >> 2] | 0)
	                        } while (0);
	                        if ((c[(c[f >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                            s = 62;
	                            break
	                        }
	                        c[q >> 2] = 0
	                    }
	                    b = c[(c[f >> 2] | 0) + 36 >> 2] | 0;
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                        t = b + 28 | 0;
	                        c[t >> 2] = (c[t >> 2] | 0) + 1;
	                        c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                    } else {
	                        t = b + 32 | 0;
	                        c[t >> 2] = (c[t >> 2] | 0) + 1
	                    }
	                    t = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[t >> 2] = (c[t >> 2] | 0) + (c[p >> 2] | 0);
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                    c[o >> 2] = ne(c[f >> 2] | 0, p) | 0
	                }
	                if ((s | 0) == 50) {
	                    pg(c[f >> 2] | 0, 63, 69400, 0);
	                    zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                    i = e;
	                    return
	                } else if ((s | 0) == 52) {
	                    zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                    ie(c[f >> 2] | 0, 0);
	                    i = e;
	                    return
	                } else if ((s | 0) == 62) {
	                    zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                    i = e;
	                    return
	                } else if ((s | 0) == 70) {
	                    a[(c[g >> 2] | 0) + v >> 0] = 0;
	                    c[(c[f >> 2] | 0) + 172 >> 2] = 7;
	                    v = c[f >> 2] | 0;
	                    if ((c[o >> 2] | 0) != 62) {
	                        pg(v, 63, 69432, c[g >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                        i = e;
	                        return
	                    }
	                    o = c[(c[f >> 2] | 0) + 36 >> 2] | 0;
	                    if ((d[c[(c[v + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                        v = o + 28 | 0;
	                        c[v >> 2] = (c[v >> 2] | 0) + 1;
	                        c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                    } else {
	                        v = o + 32 | 0;
	                        c[v >> 2] = (c[v >> 2] | 0) + 1
	                    }
	                    v = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[v >> 2] = (c[v >> 2] | 0) + (c[p >> 2] | 0);
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                    do if (c[c[f >> 2] >> 2] | 0) {
	                        if (c[(c[f >> 2] | 0) + 212 >> 2] | 0)break;
	                        p = c[c[f >> 2] >> 2] | 0;
	                        if (c[(c[c[f >> 2] >> 2] | 0) + 100 >> 2] | 0) {
	                            Db[c[p + 100 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0);
	                            break
	                        }
	                        if (!(c[p + 68 >> 2] | 0))break;
	                        Db[c[(c[c[f >> 2] >> 2] | 0) + 68 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0)
	                    } while (0);
	                    zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                    i = e;
	                    return
	                }
	            }

	            function Jf(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                g = b + 4 | 0;
	                h = b;
	                c[e >> 2] = a;
	                if ((c[(c[e >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[e >> 2] | 0);
	                while (1) {
	                    if (!(d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0)) {
	                        j = 45;
	                        break
	                    }
	                    if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 47 : 0) {
	                        j = 45;
	                        break
	                    }
	                    if ((c[(c[e >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                        j = 45;
	                        break
	                    }
	                    c[f >> 2] = c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                    c[g >> 2] = c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 36 >> 2];
	                    c[h >> 2] = c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                    if ((d[c[h >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[h >> 2] | 0) + 1 >> 0] | 0 | 0) == 63 : 0)mf(c[e >> 2] | 0); else j = 11;
	                    do if ((j | 0) == 11) {
	                        j = 0;
	                        if (((((((((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 33 : 0) ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 91 : 0) ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 67 : 0) ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) == 68 : 0) ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) == 65 : 0) ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 6 >> 0] | 0 | 0) == 84 : 0) ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 7 >> 0] | 0 | 0) == 65 : 0) ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 8 >> 0] | 0 | 0) == 91 : 0) {
	                            If(c[e >> 2] | 0);
	                            break
	                        }
	                        if ((((d[c[h >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 33 : 0) ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 45 : 0) ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 45 : 0) {
	                            kf(c[e >> 2] | 0);
	                            c[(c[e >> 2] | 0) + 172 >> 2] = 7;
	                            break
	                        }
	                        if ((d[c[h >> 2] >> 0] | 0 | 0) == 60) {
	                            Kf(c[e >> 2] | 0);
	                            break
	                        }
	                        a = c[e >> 2] | 0;
	                        if ((d[c[h >> 2] >> 0] | 0 | 0) == 38) {
	                            Df(a);
	                            break
	                        } else {
	                            hf(a, 0);
	                            break
	                        }
	                    } while (0);
	                    if ((c[(c[e >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[e >> 2] | 0);
	                    while (1) {
	                        if (!(d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0))k = (c[(c[e >> 2] | 0) + 40 >> 2] | 0) > 1; else k = 0;
	                        l = c[e >> 2] | 0;
	                        if (!k)break;
	                        Ve(l) | 0
	                    }
	                    if (((c[l + 292 >> 2] | 0) == 0 ? ((c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 : 0) ? ((c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)Fg(c[e >> 2] | 0);
	                    if ((c[g >> 2] | 0) != (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 36 >> 2] | 0))continue;
	                    if ((c[f >> 2] | 0) == (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0)) {
	                        j = 44;
	                        break
	                    }
	                }
	                if ((j | 0) == 44) {
	                    og(c[e >> 2] | 0, 1, 69472);
	                    c[(c[e >> 2] | 0) + 172 >> 2] = -1;
	                    i = b;
	                    return
	                } else if ((j | 0) == 45) {
	                    i = b;
	                    return
	                }
	            }

	            function Kf(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                b = i;
	                i = i + 64 | 0;
	                e = b + 48 | 0;
	                f = b + 44 | 0;
	                g = b + 40 | 0;
	                h = b + 36 | 0;
	                j = b + 16 | 0;
	                k = b + 12 | 0;
	                l = b + 8 | 0;
	                m = b + 4 | 0;
	                n = b;
	                c[e >> 2] = a;
	                c[g >> 2] = 0;
	                c[h >> 2] = 0;
	                c[l >> 2] = 0;
	                c[n >> 2] = c[(c[e >> 2] | 0) + 328 >> 2];
	                if ((c[(c[e >> 2] | 0) + 188 >> 2] | 0) >>> 0 > (c[16304] | 0) >>> 0 ? (c[(c[e >> 2] | 0) + 360 >> 2] & 524288 | 0) == 0 : 0) {
	                    ng(c[e >> 2] | 0, 1, 65224, c[16304] | 0);
	                    c[(c[e >> 2] | 0) + 172 >> 2] = -1;
	                    i = b;
	                    return
	                }
	                if (c[(c[e >> 2] | 0) + 68 >> 2] | 0) {
	                    c[j + 4 >> 2] = (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 36 >> 2] | 0) + ((c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0));
	                    c[j + 8 >> 2] = c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2]
	                }
	                a = c[e >> 2] | 0;
	                do if (c[(c[e >> 2] | 0) + 236 >> 2] | 0) {
	                    o = c[e >> 2] | 0;
	                    if ((c[c[a + 232 >> 2] >> 2] | 0) == -2) {
	                        Xg(o, -1) | 0;
	                        break
	                    } else {
	                        Xg(o, c[c[(c[e >> 2] | 0) + 232 >> 2] >> 2] | 0) | 0;
	                        break
	                    }
	                } else Xg(a, -1) | 0; while (0);
	                c[k >> 2] = c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2];
	                a = c[e >> 2] | 0;
	                if (c[(c[e >> 2] | 0) + 324 >> 2] | 0)c[f >> 2] = Yg(a, g, h, l) | 0; else c[f >> 2] = Hf(a) | 0;
	                if ((c[(c[e >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                    i = b;
	                    return
	                }
	                a = c[e >> 2] | 0;
	                if (!(c[f >> 2] | 0)) {
	                    Zg(a) | 0;
	                    i = b;
	                    return
	                }
	                Se(a, c[f >> 2] | 0) | 0;
	                c[m >> 2] = c[(c[e >> 2] | 0) + 52 >> 2];
	                if (((((c[(c[e >> 2] | 0) + 104 >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[(c[e >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (c[(c[e >> 2] | 0) + 52 >> 2] | 0) != 0 : 0) ? (c[(c[e >> 2] | 0) + 52 >> 2] | 0) == (c[(c[(c[e >> 2] | 0) + 8 >> 2] | 0) + 12 >> 2] | 0) : 0) {
	                    a = an((c[e >> 2] | 0) + 108 | 0, c[(c[e >> 2] | 0) + 8 >> 2] | 0) | 0;
	                    o = (c[e >> 2] | 0) + 100 | 0;
	                    c[o >> 2] = c[o >> 2] & a
	                }
	                if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 47 ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 62 : 0) {
	                    a = (c[e >> 2] | 0) + 200 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 2;
	                    a = (c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 2;
	                    a = (c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 2;
	                    if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[e >> 2] | 0);
	                    if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[e >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[e >> 2] | 0) | 0;
	                    a = (c[c[e >> 2] >> 2] | 0) != 0;
	                    if (c[(c[e >> 2] | 0) + 324 >> 2] | 0) {
	                        if ((a ? (c[(c[c[e >> 2] >> 2] | 0) + 120 >> 2] | 0) != 0 : 0) ? (c[(c[e >> 2] | 0) + 212 >> 2] | 0) == 0 : 0)Jb[c[(c[c[e >> 2] >> 2] | 0) + 120 >> 2] & 511](c[(c[e >> 2] | 0) + 4 >> 2] | 0, c[f >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0)
	                    } else if ((a ? (c[(c[c[e >> 2] >> 2] | 0) + 60 >> 2] | 0) != 0 : 0) ? (c[(c[e >> 2] | 0) + 212 >> 2] | 0) == 0 : 0)Ab[c[(c[c[e >> 2] >> 2] | 0) + 60 >> 2] & 511](c[(c[e >> 2] | 0) + 4 >> 2] | 0, c[f >> 2] | 0);
	                    Te(c[e >> 2] | 0) | 0;
	                    Zg(c[e >> 2] | 0) | 0;
	                    if ((c[n >> 2] | 0) != (c[(c[e >> 2] | 0) + 328 >> 2] | 0))_g(c[e >> 2] | 0, (c[(c[e >> 2] | 0) + 328 >> 2] | 0) - (c[n >> 2] | 0) | 0) | 0;
	                    if (!(c[m >> 2] | 0)) {
	                        i = b;
	                        return
	                    }
	                    if (!(c[(c[e >> 2] | 0) + 68 >> 2] | 0)) {
	                        i = b;
	                        return
	                    }
	                    c[j + 12 >> 2] = (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 36 >> 2] | 0) + ((c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0));
	                    c[j + 16 >> 2] = c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2];
	                    c[j >> 2] = c[m >> 2];
	                    De(c[e >> 2] | 0, j);
	                    i = b;
	                    return
	                }
	                a = c[e >> 2] | 0;
	                if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 62) {
	                    $g(a, 73, 69512, c[f >> 2] | 0, c[k >> 2] | 0, 0);
	                    Re(c[e >> 2] | 0) | 0;
	                    Te(c[e >> 2] | 0) | 0;
	                    Zg(c[e >> 2] | 0) | 0;
	                    if ((c[n >> 2] | 0) != (c[(c[e >> 2] | 0) + 328 >> 2] | 0))_g(c[e >> 2] | 0, (c[(c[e >> 2] | 0) + 328 >> 2] | 0) - (c[n >> 2] | 0) | 0) | 0;
	                    if (!(c[m >> 2] | 0)) {
	                        i = b;
	                        return
	                    }
	                    if (!(c[(c[e >> 2] | 0) + 68 >> 2] | 0)) {
	                        i = b;
	                        return
	                    }
	                    c[j + 12 >> 2] = (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 36 >> 2] | 0) + ((c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0));
	                    c[j + 16 >> 2] = c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2];
	                    c[j >> 2] = c[m >> 2];
	                    De(c[e >> 2] | 0, j);
	                    i = b;
	                    return
	                }
	                o = (c[a + 36 >> 2] | 0) + 32 | 0;
	                c[o >> 2] = (c[o >> 2] | 0) + 1;
	                o = (c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                c[o >> 2] = (c[o >> 2] | 0) + 1;
	                o = (c[e >> 2] | 0) + 200 | 0;
	                c[o >> 2] = (c[o >> 2] | 0) + 1;
	                if (!(d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0))ke(c[(c[e >> 2] | 0) + 36 >> 2] | 0, 250) | 0;
	                Jf(c[e >> 2] | 0);
	                if ((c[(c[e >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                    i = b;
	                    return
	                }
	                if (!(9 <= (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0))p = 55;
	                if (((p | 0) == 55 ? (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13 : 0) ? 32 > (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) : 0) {
	                    $g(c[e >> 2] | 0, 77, 69560, c[f >> 2] | 0, c[k >> 2] | 0, 0);
	                    Re(c[e >> 2] | 0) | 0;
	                    Te(c[e >> 2] | 0) | 0;
	                    Zg(c[e >> 2] | 0) | 0;
	                    if ((c[n >> 2] | 0) == (c[(c[e >> 2] | 0) + 328 >> 2] | 0)) {
	                        i = b;
	                        return
	                    }
	                    _g(c[e >> 2] | 0, (c[(c[e >> 2] | 0) + 328 >> 2] | 0) - (c[n >> 2] | 0) | 0) | 0;
	                    i = b;
	                    return
	                }
	                f = c[e >> 2] | 0;
	                if (c[(c[e >> 2] | 0) + 324 >> 2] | 0) {
	                    ah(f, c[g >> 2] | 0, c[h >> 2] | 0, c[k >> 2] | 0, (c[(c[e >> 2] | 0) + 328 >> 2] | 0) - (c[n >> 2] | 0) | 0, c[l >> 2] | 0);
	                    Te(c[e >> 2] | 0) | 0
	                } else Wg(f, c[k >> 2] | 0);
	                if (!(c[m >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (!(c[(c[e >> 2] | 0) + 68 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                c[j + 12 >> 2] = (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 36 >> 2] | 0) + ((c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0));
	                c[j + 16 >> 2] = c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2];
	                c[j >> 2] = c[m >> 2];
	                De(c[e >> 2] | 0, j);
	                i = b;
	                return
	            }

	            function Lf(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e + 24 | 0;
	                m = e;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                c[j >> 2] = 0;
	                c[k >> 2] = 10;
	                c[h >> 2] = Cb[c[135752 >> 2] & 511](c[k >> 2] | 0) | 0;
	                b = c[g >> 2] | 0;
	                if (!(c[h >> 2] | 0)) {
	                    ie(b, 0);
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                a[l >> 0] = a[c[(c[b + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                if ((d[l >> 0] | 0 | 0) >= 48 ? (d[l >> 0] | 0 | 0) <= 57 : 0) {
	                    b = a[l >> 0] | 0;
	                    o = c[j >> 2] | 0;
	                    c[j >> 2] = o + 1;
	                    a[(c[h >> 2] | 0) + o >> 0] = b;
	                    me(c[g >> 2] | 0);
	                    a[l >> 0] = a[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                    if ((d[l >> 0] | 0 | 0) != 46) {
	                        zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                        c[f >> 2] = 0;
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    }
	                    b = a[l >> 0] | 0;
	                    o = c[j >> 2] | 0;
	                    c[j >> 2] = o + 1;
	                    a[(c[h >> 2] | 0) + o >> 0] = b;
	                    me(c[g >> 2] | 0);
	                    a[l >> 0] = a[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                    while (1) {
	                        if ((d[l >> 0] | 0 | 0) >= 48)p = (d[l >> 0] | 0 | 0) <= 57; else p = 0;
	                        q = c[j >> 2] | 0;
	                        if (!p) {
	                            r = 17;
	                            break
	                        }
	                        if ((q + 1 | 0) >= (c[k >> 2] | 0)) {
	                            c[k >> 2] = c[k >> 2] << 1;
	                            c[m >> 2] = Hb[c[135760 >> 2] & 511](c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                            if (!(c[m >> 2] | 0)) {
	                                r = 14;
	                                break
	                            }
	                            c[h >> 2] = c[m >> 2]
	                        }
	                        b = a[l >> 0] | 0;
	                        o = c[j >> 2] | 0;
	                        c[j >> 2] = o + 1;
	                        a[(c[h >> 2] | 0) + o >> 0] = b;
	                        me(c[g >> 2] | 0);
	                        a[l >> 0] = a[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0
	                    }
	                    if ((r | 0) == 14) {
	                        zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                        ie(c[g >> 2] | 0, 0);
	                        c[f >> 2] = 0;
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    } else if ((r | 0) == 17) {
	                        a[(c[h >> 2] | 0) + q >> 0] = 0;
	                        c[f >> 2] = c[h >> 2];
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    }
	                }
	                zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                c[f >> 2] = 0;
	                n = c[f >> 2] | 0;
	                i = e;
	                return n | 0
	            }

	            function Mf(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e + 24 | 0;
	                m = e;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                c[j >> 2] = 0;
	                c[k >> 2] = 10;
	                a[l >> 0] = a[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                if ((d[l >> 0] | 0 | 0) >= 97 ? (d[l >> 0] | 0 | 0) <= 122 : 0)n = 5; else n = 3;
	                do if ((n | 0) == 3) {
	                    if ((d[l >> 0] | 0 | 0) >= 65 ? (d[l >> 0] | 0 | 0) <= 90 : 0) {
	                        n = 5;
	                        break
	                    }
	                    og(c[g >> 2] | 0, 79, 0)
	                } while (0);
	                do if ((n | 0) == 5) {
	                    c[h >> 2] = Cb[c[135752 >> 2] & 511](c[k >> 2] | 0) | 0;
	                    if (!(c[h >> 2] | 0)) {
	                        ie(c[g >> 2] | 0, 0);
	                        c[f >> 2] = 0;
	                        o = c[f >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    }
	                    b = a[l >> 0] | 0;
	                    p = c[j >> 2] | 0;
	                    c[j >> 2] = p + 1;
	                    a[(c[h >> 2] | 0) + p >> 0] = b;
	                    me(c[g >> 2] | 0);
	                    a[l >> 0] = a[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                    while (1) {
	                        if ((d[l >> 0] | 0 | 0) >= 97 ? (d[l >> 0] | 0 | 0) <= 122 : 0)q = 1; else n = 10;
	                        do if ((n | 0) == 10) {
	                            n = 0;
	                            if ((d[l >> 0] | 0 | 0) >= 65 ? (d[l >> 0] | 0 | 0) <= 90 : 0) {
	                                q = 1;
	                                break
	                            }
	                            if ((d[l >> 0] | 0 | 0) >= 48 ? (d[l >> 0] | 0 | 0) <= 57 : 0) {
	                                q = 1;
	                                break
	                            }
	                            if ((d[l >> 0] | 0 | 0) != 46 ? (d[l >> 0] | 0 | 0) != 95 : 0)q = (d[l >> 0] | 0 | 0) == 45; else q = 1
	                        } while (0);
	                        r = c[j >> 2] | 0;
	                        if (!q) {
	                            n = 31;
	                            break
	                        }
	                        if ((r + 1 | 0) >= (c[k >> 2] | 0)) {
	                            c[k >> 2] = c[k >> 2] << 1;
	                            c[m >> 2] = Hb[c[135760 >> 2] & 511](c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                            if (!(c[m >> 2] | 0))break;
	                            c[h >> 2] = c[m >> 2]
	                        }
	                        b = a[l >> 0] | 0;
	                        p = c[j >> 2] | 0;
	                        c[j >> 2] = p + 1;
	                        a[(c[h >> 2] | 0) + p >> 0] = b;
	                        me(c[g >> 2] | 0);
	                        a[l >> 0] = a[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                        if (d[l >> 0] | 0)continue;
	                        if (((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 : 0) ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)Fg(c[g >> 2] | 0);
	                        if ((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[g >> 2] | 0);
	                        a[l >> 0] = a[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0
	                    }
	                    if ((n | 0) == 31) {
	                        a[(c[h >> 2] | 0) + r >> 0] = 0;
	                        break
	                    }
	                    ie(c[g >> 2] | 0, 0);
	                    zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                } while (0);
	                c[f >> 2] = c[h >> 2];
	                o = c[f >> 2] | 0;
	                i = e;
	                return o | 0
	            }

	            function Nf(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[f >> 2] = a;
	                c[g >> 2] = -2;
	                Ue(c[f >> 2] | 0) | 0;
	                do if ((((((((((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 115 ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 116 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 97 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 110 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) == 100 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) == 97 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 6 >> 0] | 0 | 0) == 108 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 7 >> 0] | 0 | 0) == 111 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 8 >> 0] | 0 | 0) == 110 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 9 >> 0] | 0 | 0) == 101 : 0) {
	                    a = (c[f >> 2] | 0) + 200 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 10;
	                    a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 10;
	                    a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 10;
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[f >> 2] | 0) | 0;
	                    Ue(c[f >> 2] | 0) | 0;
	                    a = c[f >> 2] | 0;
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 61) {
	                        og(a, 75, 0);
	                        c[e >> 2] = c[g >> 2];
	                        h = c[e >> 2] | 0;
	                        i = b;
	                        return h | 0
	                    }
	                    me(a);
	                    Ue(c[f >> 2] | 0) | 0;
	                    a = c[f >> 2] | 0;
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 39) {
	                        me(a);
	                        do if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 110 ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 111 : 0) {
	                            c[g >> 2] = 0;
	                            j = (c[f >> 2] | 0) + 200 | 0;
	                            c[j >> 2] = (c[j >> 2] | 0) + 2;
	                            j = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                            c[j >> 2] = (c[j >> 2] | 0) + 2;
	                            j = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                            c[j >> 2] = (c[j >> 2] | 0) + 2;
	                            if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                            if (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0)break;
	                            if ((ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0) > 0)break;
	                            Ve(c[f >> 2] | 0) | 0
	                        } else k = 26; while (0);
	                        a:do if ((k | 0) == 26) {
	                            do if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 121) {
	                                if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) != 101)break;
	                                if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) != 115)break;
	                                c[g >> 2] = 1;
	                                j = (c[f >> 2] | 0) + 200 | 0;
	                                c[j >> 2] = (c[j >> 2] | 0) + 3;
	                                j = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                                c[j >> 2] = (c[j >> 2] | 0) + 3;
	                                j = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                                c[j >> 2] = (c[j >> 2] | 0) + 3;
	                                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                                if (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0)break a;
	                                if ((ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0) > 0)break a;
	                                Ve(c[f >> 2] | 0) | 0;
	                                break a
	                            } while (0);
	                            og(c[f >> 2] | 0, 78, 0)
	                        } while (0);
	                        j = c[f >> 2] | 0;
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 39) {
	                            og(j, 34, 0);
	                            break
	                        } else {
	                            me(j);
	                            break
	                        }
	                    }
	                    j = c[f >> 2] | 0;
	                    if ((d[c[(c[a + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 34) {
	                        og(j, 33, 0);
	                        break
	                    }
	                    me(j);
	                    do if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 110 ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 111 : 0) {
	                        c[g >> 2] = 0;
	                        j = (c[f >> 2] | 0) + 200 | 0;
	                        c[j >> 2] = (c[j >> 2] | 0) + 2;
	                        j = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                        c[j >> 2] = (c[j >> 2] | 0) + 2;
	                        j = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                        c[j >> 2] = (c[j >> 2] | 0) + 2;
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                        if (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0)break;
	                        if ((ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0) > 0)break;
	                        Ve(c[f >> 2] | 0) | 0
	                    } else k = 46; while (0);
	                    b:do if ((k | 0) == 46) {
	                        do if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 121) {
	                            if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) != 101)break;
	                            if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) != 115)break;
	                            c[g >> 2] = 1;
	                            a = (c[f >> 2] | 0) + 200 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 3;
	                            a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 3;
	                            a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 3;
	                            if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                            if (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0)break b;
	                            if ((ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0) > 0)break b;
	                            Ve(c[f >> 2] | 0) | 0;
	                            break b
	                        } while (0);
	                        og(c[f >> 2] | 0, 78, 0)
	                    } while (0);
	                    a = c[f >> 2] | 0;
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 34) {
	                        og(a, 34, 0);
	                        break
	                    } else {
	                        me(a);
	                        break
	                    }
	                } while (0);
	                c[e >> 2] = c[g >> 2];
	                h = c[e >> 2] | 0;
	                i = b;
	                return h | 0
	            }

	            function Of(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 52 >> 2] = -2;
	                a = (c[e >> 2] | 0) + 200 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + 5;
	                a = (c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + 5;
	                a = (c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + 5;
	                if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[e >> 2] | 0);
	                if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[e >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[e >> 2] | 0) | 0;
	                do if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32) {
	                    if (9 <= (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                    if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13)xg(c[e >> 2] | 0, 65, 69720)
	                } while (0);
	                Ue(c[e >> 2] | 0) | 0;
	                c[f >> 2] = Af(c[e >> 2] | 0) | 0;
	                if (!(c[f >> 2] | 0))og(c[e >> 2] | 0, 96, 0); else {
	                    do if (!(qy(c[f >> 2] | 0, 68488) | 0)) {
	                        if (c[(c[e >> 2] | 0) + 360 >> 2] & 131072) {
	                            pg(c[e >> 2] | 0, 108, 69752, c[f >> 2] | 0);
	                            break
	                        }
	                        if ((d[c[f >> 2] >> 0] | 0 | 0) == 49 ? (d[(c[f >> 2] | 0) + 1 >> 0] | 0 | 0) == 46 : 0) {
	                            rg(c[e >> 2] | 0, 97, 69752, c[f >> 2] | 0, 0);
	                            break
	                        }
	                        pg(c[e >> 2] | 0, 108, 69752, c[f >> 2] | 0)
	                    } while (0);
	                    if (c[(c[e >> 2] | 0) + 20 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[e >> 2] | 0) + 20 >> 2] | 0);
	                    c[(c[e >> 2] | 0) + 20 >> 2] = c[f >> 2]
	                }
	                do if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32) {
	                    if (9 <= (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                    if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13) {
	                        if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 63 ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 62 : 0) {
	                            f = (c[e >> 2] | 0) + 200 | 0;
	                            c[f >> 2] = (c[f >> 2] | 0) + 2;
	                            f = (c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                            c[f >> 2] = (c[f >> 2] | 0) + 2;
	                            f = (c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                            c[f >> 2] = (c[f >> 2] | 0) + 2;
	                            if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[e >> 2] | 0);
	                            if (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) {
	                                i = b;
	                                return
	                            }
	                            if ((ke(c[(c[e >> 2] | 0) + 36 >> 2] | 0, 250) | 0) > 0) {
	                                i = b;
	                                return
	                            }
	                            Ve(c[e >> 2] | 0) | 0;
	                            i = b;
	                            return
	                        }
	                        xg(c[e >> 2] | 0, 65, 69784)
	                    }
	                } while (0);
	                Bf(c[e >> 2] | 0) | 0;
	                if ((c[(c[e >> 2] | 0) + 84 >> 2] | 0) == 32) {
	                    i = b;
	                    return
	                }
	                do if ((c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 44 >> 2] | 0) != 0 ? (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32 : 0) {
	                    if (9 <= (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                    if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13) {
	                        if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 63 ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 62 : 0) {
	                            f = (c[e >> 2] | 0) + 200 | 0;
	                            c[f >> 2] = (c[f >> 2] | 0) + 2;
	                            f = (c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                            c[f >> 2] = (c[f >> 2] | 0) + 2;
	                            f = (c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                            c[f >> 2] = (c[f >> 2] | 0) + 2;
	                            if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[e >> 2] | 0);
	                            if (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) {
	                                i = b;
	                                return
	                            }
	                            if ((ke(c[(c[e >> 2] | 0) + 36 >> 2] | 0, 250) | 0) > 0) {
	                                i = b;
	                                return
	                            }
	                            Ve(c[e >> 2] | 0) | 0;
	                            i = b;
	                            return
	                        }
	                        xg(c[e >> 2] | 0, 65, 69784)
	                    }
	                } while (0);
	                if ((c[(c[e >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[e >> 2] | 0);
	                Ue(c[e >> 2] | 0) | 0;
	                f = Nf(c[e >> 2] | 0) | 0;
	                c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 52 >> 2] = f;
	                Ue(c[e >> 2] | 0) | 0;
	                if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 63 ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 62 : 0) {
	                    f = (c[e >> 2] | 0) + 200 | 0;
	                    c[f >> 2] = (c[f >> 2] | 0) + 2;
	                    f = (c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[f >> 2] = (c[f >> 2] | 0) + 2;
	                    f = (c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[f >> 2] = (c[f >> 2] | 0) + 2;
	                    if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[e >> 2] | 0);
	                    if (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) {
	                        i = b;
	                        return
	                    }
	                    if ((ke(c[(c[e >> 2] | 0) + 36 >> 2] | 0, 250) | 0) > 0) {
	                        i = b;
	                        return
	                    }
	                    Ve(c[e >> 2] | 0) | 0;
	                    i = b;
	                    return
	                }
	                f = (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 62;
	                og(c[e >> 2] | 0, 57, 0);
	                if (f) {
	                    me(c[e >> 2] | 0);
	                    i = b;
	                    return
	                }
	                while (1) {
	                    if (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0)g = (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 62; else g = 0;
	                    h = c[e >> 2] | 0;
	                    if (!g)break;
	                    f = (c[h + 36 >> 2] | 0) + 16 | 0;
	                    c[f >> 2] = (c[f >> 2] | 0) + 1
	                }
	                me(h);
	                i = b;
	                return
	            }

	            function Pf(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b;
	                c[e >> 2] = a;
	                a:while (1) {
	                    if ((c[(c[e >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                        f = 22;
	                        break
	                    }
	                    if (!((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 63 : 0))f = 5;
	                    do if ((f | 0) == 5) {
	                        f = 0;
	                        if ((((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 33 : 0) ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 45 : 0) ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 45 : 0)break;
	                        if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13) {
	                                f = 22;
	                                break a
	                            }
	                        }
	                    } while (0);
	                    if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 63 : 0) {
	                        mf(c[e >> 2] | 0);
	                        continue
	                    }
	                    do if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13) {
	                            kf(c[e >> 2] | 0);
	                            continue a
	                        }
	                    } while (0);
	                    me(c[e >> 2] | 0)
	                }
	                if ((f | 0) == 22) {
	                    i = b;
	                    return
	                }
	            }

	            function Qf(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e + 12 | 0;
	                j = e;
	                c[g >> 2] = b;
	                Rf();
	                if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) {
	                    if ((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[g >> 2] | 0);
	                    Rg(c[g >> 2] | 0);
	                    if ((c[c[g >> 2] >> 2] | 0) != 0 ? (c[(c[c[g >> 2] >> 2] | 0) + 44 >> 2] | 0) != 0 : 0)Ab[c[(c[c[g >> 2] >> 2] | 0) + 44 >> 2] & 511](c[(c[g >> 2] | 0) + 4 >> 2] | 0, 136080);
	                    if ((c[(c[g >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                        c[f >> 2] = -1;
	                        k = c[f >> 2] | 0;
	                        i = e;
	                        return k | 0
	                    }
	                    if (((c[(c[g >> 2] | 0) + 24 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) >= 4 : 0) ? (a[h >> 0] = a[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0, a[h + 1 >> 0] = a[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0, a[h + 2 >> 0] = a[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0, a[h + 3 >> 0] = a[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0, c[j >> 2] = sd(h, 4) | 0, (c[j >> 2] | 0) != 0) : 0)re(c[g >> 2] | 0, c[j >> 2] | 0) | 0;
	                    if (!(d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0))og(c[g >> 2] | 0, 4, 0);
	                    if ((((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 35 ? (c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 : 0) ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[g >> 2] | 0);
	                    a:do if (((((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 63 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 120 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 109 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) == 108 : 0) {
	                        do if ((d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) != 13) {
	                                l = 34;
	                                break a
	                            }
	                        } while (0);
	                        Of(c[g >> 2] | 0);
	                        if ((c[(c[g >> 2] | 0) + 84 >> 2] | 0) != 32) {
	                            c[(c[g >> 2] | 0) + 28 >> 2] = c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 52 >> 2];
	                            Ue(c[g >> 2] | 0) | 0;
	                            break
	                        }
	                        c[f >> 2] = -1;
	                        k = c[f >> 2] | 0;
	                        i = e;
	                        return k | 0
	                    } else l = 34; while (0);
	                    if ((l | 0) == 34) {
	                        l = oy(68488) | 0;
	                        c[(c[g >> 2] | 0) + 20 >> 2] = l
	                    }
	                    if (((c[c[g >> 2] >> 2] | 0) != 0 ? (c[(c[c[g >> 2] >> 2] | 0) + 48 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 212 >> 2] | 0) == 0 : 0)zb[c[(c[c[g >> 2] >> 2] | 0) + 48 >> 2] & 511](c[(c[g >> 2] | 0) + 4 >> 2] | 0);
	                    if ((c[(c[g >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                        c[f >> 2] = -1;
	                        k = c[f >> 2] | 0;
	                        i = e;
	                        return k | 0
	                    }
	                    if ((((c[(c[g >> 2] | 0) + 8 >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[c[(c[g >> 2] | 0) + 36 >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[c[(c[g >> 2] | 0) + 36 >> 2] >> 2] | 0) + 24 >> 2] | 0) >= 0 : 0)c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 36 >> 2] = c[(c[c[(c[g >> 2] | 0) + 36 >> 2] >> 2] | 0) + 24 >> 2];
	                    if ((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[g >> 2] | 0);
	                    Pf(c[g >> 2] | 0);
	                    if ((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[g >> 2] | 0);
	                    do if ((((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 33 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 68 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 79 : 0) {
	                        if ((d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) != 67)break;
	                        if ((d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) != 84)break;
	                        if ((d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 6 >> 0] | 0 | 0) != 89)break;
	                        if ((d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 7 >> 0] | 0 | 0) != 80)break;
	                        if ((d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 8 >> 0] | 0 | 0) != 69)break;
	                        c[(c[g >> 2] | 0) + 216 >> 2] = 1;
	                        Ff(c[g >> 2] | 0);
	                        do if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 91) {
	                            c[(c[g >> 2] | 0) + 172 >> 2] = 3;
	                            bh(c[g >> 2] | 0);
	                            if ((c[(c[g >> 2] | 0) + 172 >> 2] | 0) != -1)break;
	                            c[f >> 2] = -1;
	                            k = c[f >> 2] | 0;
	                            i = e;
	                            return k | 0
	                        } while (0);
	                        c[(c[g >> 2] | 0) + 216 >> 2] = 2;
	                        do if (c[c[g >> 2] >> 2] | 0) {
	                            if (!(c[(c[c[g >> 2] >> 2] | 0) + 104 >> 2] | 0))break;
	                            if (c[(c[g >> 2] | 0) + 212 >> 2] | 0)break;
	                            Jb[c[(c[c[g >> 2] >> 2] | 0) + 104 >> 2] & 511](c[(c[g >> 2] | 0) + 4 >> 2] | 0, c[(c[g >> 2] | 0) + 220 >> 2] | 0, c[(c[g >> 2] | 0) + 228 >> 2] | 0, c[(c[g >> 2] | 0) + 224 >> 2] | 0)
	                        } while (0);
	                        if ((c[(c[g >> 2] | 0) + 172 >> 2] | 0) != -1) {
	                            c[(c[g >> 2] | 0) + 216 >> 2] = 0;
	                            ch(c[g >> 2] | 0);
	                            c[(c[g >> 2] | 0) + 172 >> 2] = 4;
	                            Pf(c[g >> 2] | 0);
	                            break
	                        }
	                        c[f >> 2] = -1;
	                        k = c[f >> 2] | 0;
	                        i = e;
	                        return k | 0
	                    } while (0);
	                    if ((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[g >> 2] | 0);
	                    l = c[g >> 2] | 0;
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 60)xg(l, 4, 69808); else {
	                        c[l + 172 >> 2] = 7;
	                        Kf(c[g >> 2] | 0);
	                        c[(c[g >> 2] | 0) + 172 >> 2] = 14;
	                        Pf(c[g >> 2] | 0);
	                        if (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0)og(c[g >> 2] | 0, 5, 0);
	                        c[(c[g >> 2] | 0) + 172 >> 2] = -1
	                    }
	                    do if (c[c[g >> 2] >> 2] | 0) {
	                        if (!(c[(c[c[g >> 2] >> 2] | 0) + 52 >> 2] | 0))break;
	                        zb[c[(c[c[g >> 2] >> 2] | 0) + 52 >> 2] & 511](c[(c[g >> 2] | 0) + 4 >> 2] | 0)
	                    } while (0);
	                    do if (c[(c[g >> 2] | 0) + 8 >> 2] | 0) {
	                        if (!(qy(c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 56 >> 2] | 0, 67096) | 0))break;
	                        Th(c[(c[g >> 2] | 0) + 8 >> 2] | 0);
	                        c[(c[g >> 2] | 0) + 8 >> 2] = 0
	                    } while (0);
	                    do if (c[(c[g >> 2] | 0) + 12 >> 2] | 0) {
	                        if (!(c[(c[g >> 2] | 0) + 8 >> 2] | 0))break;
	                        l = (c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 92 | 0;
	                        c[l >> 2] = c[l >> 2] | 1;
	                        if (c[(c[g >> 2] | 0) + 100 >> 2] | 0) {
	                            l = (c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 92 | 0;
	                            c[l >> 2] = c[l >> 2] | 8
	                        }
	                        if (c[(c[g >> 2] | 0) + 356 >> 2] | 0) {
	                            l = (c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 92 | 0;
	                            c[l >> 2] = c[l >> 2] | 2
	                        }
	                        if (!(c[(c[g >> 2] | 0) + 360 >> 2] & 131072))break;
	                        l = (c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 92 | 0;
	                        c[l >> 2] = c[l >> 2] | 4
	                    } while (0);
	                    if (c[(c[g >> 2] | 0) + 12 >> 2] | 0) {
	                        c[f >> 2] = 0;
	                        k = c[f >> 2] | 0;
	                        i = e;
	                        return k | 0
	                    } else {
	                        c[(c[g >> 2] | 0) + 100 >> 2] = 0;
	                        c[f >> 2] = -1;
	                        k = c[f >> 2] | 0;
	                        i = e;
	                        return k | 0
	                    }
	                }
	                c[f >> 2] = -1;
	                k = c[f >> 2] | 0;
	                i = e;
	                return k | 0
	            }

	            function Rf() {
	                var a = 0;
	                a = i;
	                if (c[17532] | 0) {
	                    i = a;
	                    return
	                }
	                zx();
	                lx();
	                if ((c[33976] | 0) == 35 | (c[33976] | 0) == 0)Ud(0);
	                ll() | 0;
	                tP() | 0;
	                Ad();
	                pQ();
	                tk();
	                uk();
	                ao();
	                rQ();
	                Kq();
	                Aw();
	                c[17532] = 1;
	                i = a;
	                return
	            }

	            function Sf(b, d, e, f) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0;
	                g = i;
	                i = i + 96 | 0;
	                h = g;
	                j = g + 80 | 0;
	                k = g + 76 | 0;
	                l = g + 72 | 0;
	                m = g + 68 | 0;
	                n = g + 64 | 0;
	                o = g + 60 | 0;
	                p = g + 56 | 0;
	                q = g + 52 | 0;
	                r = g + 48 | 0;
	                s = g + 44 | 0;
	                t = g + 40 | 0;
	                u = g + 36 | 0;
	                v = g + 32 | 0;
	                w = g + 28 | 0;
	                x = g + 24 | 0;
	                y = g + 20 | 0;
	                z = g + 16 | 0;
	                A = g + 12 | 0;
	                B = g + 8 | 0;
	                C = g + 4 | 0;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = 0;
	                c[p >> 2] = 0;
	                c[q >> 2] = 0;
	                c[r >> 2] = 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[j >> 2] = 1;
	                    D = c[j >> 2] | 0;
	                    i = g;
	                    return D | 0
	                }
	                if ((c[(c[k >> 2] | 0) + 84 >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 212 >> 2] | 0) == 1 : 0) {
	                    c[j >> 2] = c[(c[k >> 2] | 0) + 84 >> 2];
	                    D = c[j >> 2] | 0;
	                    i = g;
	                    return D | 0
	                }
	                if ((c[(c[k >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                    c[j >> 2] = -1;
	                    D = c[j >> 2] | 0;
	                    i = g;
	                    return D | 0
	                }
	                if (!(c[(c[k >> 2] | 0) + 172 >> 2] | 0))Rg(c[k >> 2] | 0);
	                if (!((c[m >> 2] | 0) > 0 & (c[l >> 2] | 0) != 0 ^ 1 | (c[n >> 2] | 0) != 0) ? (a[(c[l >> 2] | 0) + ((c[m >> 2] | 0) - 1) >> 0] | 0) == 13 : 0) {
	                    c[o >> 2] = 1;
	                    c[m >> 2] = (c[m >> 2] | 0) + -1
	                }
	                while (1) {
	                    if ((((c[m >> 2] | 0) > 0 & (c[l >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[c[(c[k >> 2] | 0) + 36 >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[k >> 2] | 0) + 172 >> 2] | 0) != -1 : 0) {
	                        c[s >> 2] = jz(c[(c[c[(c[k >> 2] | 0) + 36 >> 2] >> 2] | 0) + 16 >> 2] | 0, c[(c[k >> 2] | 0) + 36 >> 2] | 0) | 0;
	                        c[t >> 2] = (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0);
	                        c[q >> 2] = _y(c[(c[c[(c[k >> 2] | 0) + 36 >> 2] >> 2] | 0) + 16 >> 2] | 0) | 0;
	                        do if ((((c[(c[k >> 2] | 0) + 172 >> 2] | 0) == 0 ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[c[(c[k >> 2] | 0) + 36 >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[c[(c[k >> 2] | 0) + 36 >> 2] >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                            c[v >> 2] = 45;
	                            do if ((yy(c[c[(c[c[(c[k >> 2] | 0) + 36 >> 2] >> 2] | 0) + 12 >> 2] >> 2] | 0, 69608) | 0) == 0 ? (yy(c[c[(c[c[(c[k >> 2] | 0) + 36 >> 2] >> 2] | 0) + 12 >> 2] >> 2] | 0, 69616) | 0) == 0 : 0) {
	                                if ((yy(c[c[(c[c[(c[k >> 2] | 0) + 36 >> 2] >> 2] | 0) + 12 >> 2] >> 2] | 0, 69848) | 0) == 0 ? (yy(c[c[(c[c[(c[k >> 2] | 0) + 36 >> 2] >> 2] | 0) + 12 >> 2] >> 2] | 0, 69856) | 0) == 0 : 0)break;
	                                c[v >> 2] = 180
	                            } else E = 23; while (0);
	                            if ((E | 0) == 23) {
	                                E = 0;
	                                c[v >> 2] = 90
	                            }
	                            if ((c[(c[c[(c[k >> 2] | 0) + 36 >> 2] >> 2] | 0) + 32 >> 2] | 0) >>> 0 < (c[v >> 2] | 0) >>> 0)c[v >> 2] = (c[v >> 2] | 0) - (c[(c[c[(c[k >> 2] | 0) + 36 >> 2] >> 2] | 0) + 32 >> 2] | 0);
	                            if ((c[m >> 2] | 0) >>> 0 > (c[v >> 2] | 0) >>> 0) {
	                                c[p >> 2] = (c[m >> 2] | 0) - (c[v >> 2] | 0);
	                                c[m >> 2] = c[v >> 2];
	                                break
	                            } else {
	                                c[p >> 2] = 0;
	                                break
	                            }
	                        } while (0);
	                        c[u >> 2] = Lk(c[c[(c[k >> 2] | 0) + 36 >> 2] >> 2] | 0, c[m >> 2] | 0, c[l >> 2] | 0) | 0;
	                        F = c[k >> 2] | 0;
	                        if ((c[u >> 2] | 0) < 0) {
	                            E = 33;
	                            break
	                        }
	                        kz(c[(c[c[F + 36 >> 2] >> 2] | 0) + 16 >> 2] | 0, c[(c[k >> 2] | 0) + 36 >> 2] | 0, c[s >> 2] | 0, c[t >> 2] | 0) | 0
	                    } else E = 35;
	                    if (((((((E | 0) == 35 ? (E = 0, (c[(c[k >> 2] | 0) + 172 >> 2] | 0) != -1) : 0) ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[c[(c[k >> 2] | 0) + 36 >> 2] >> 2] | 0) != 0 : 0) ? (c[w >> 2] = c[c[(c[k >> 2] | 0) + 36 >> 2] >> 2], (c[(c[w >> 2] | 0) + 12 >> 2] | 0) != 0) : 0) ? (c[(c[w >> 2] | 0) + 16 >> 2] | 0) != 0 : 0) ? (c[(c[w >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) {
	                        c[y >> 2] = jz(c[(c[w >> 2] | 0) + 16 >> 2] | 0, c[(c[k >> 2] | 0) + 36 >> 2] | 0) | 0;
	                        c[z >> 2] = (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0);
	                        c[x >> 2] = Fd(c[w >> 2] | 0, c[n >> 2] | 0) | 0;
	                        if ((c[x >> 2] | 0) < 0) {
	                            E = 42;
	                            break
	                        }
	                        kz(c[(c[w >> 2] | 0) + 16 >> 2] | 0, c[(c[k >> 2] | 0) + 36 >> 2] | 0, c[y >> 2] | 0, c[z >> 2] | 0) | 0
	                    }
	                    f = c[k >> 2] | 0;
	                    do if (c[p >> 2] | 0)dh(f, 0) | 0; else {
	                        if ((c[f + 36 >> 2] | 0) != 0 ? (c[c[(c[k >> 2] | 0) + 36 >> 2] >> 2] | 0) != 0 : 0)c[r >> 2] = _y(c[(c[c[(c[k >> 2] | 0) + 36 >> 2] >> 2] | 0) + 16 >> 2] | 0) | 0;
	                        if (!((c[n >> 2] | 0) != 0 | (c[r >> 2] | 0) >>> 0 > 1e7 | (c[q >> 2] | 0) == 0 | (c[r >> 2] | 0) == 0) ? (eh(c[k >> 2] | 0, (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) + (c[q >> 2] | 0) | 0, (c[r >> 2] | 0) - (c[q >> 2] | 0) | 0) | 0) == 0 : 0)break;
	                        dh(c[k >> 2] | 0, c[n >> 2] | 0) | 0
	                    } while (0);
	                    G = c[k >> 2] | 0;
	                    if ((c[(c[k >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                        E = 53;
	                        break
	                    }
	                    do if (c[G + 36 >> 2] | 0) {
	                        if (((c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) <= 1e7 ? ((c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) <= 1e7 : 0)break;
	                        if (!(c[(c[k >> 2] | 0) + 360 >> 2] & 524288)) {
	                            og(c[k >> 2] | 0, 1, 69896);
	                            c[(c[k >> 2] | 0) + 172 >> 2] = -1
	                        }
	                    } while (0);
	                    if ((c[(c[k >> 2] | 0) + 84 >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 212 >> 2] | 0) == 1 : 0) {
	                        E = 61;
	                        break
	                    }
	                    if (!(c[p >> 2] | 0)) {
	                        E = 64;
	                        break
	                    }
	                    c[l >> 2] = (c[l >> 2] | 0) + (c[m >> 2] | 0);
	                    c[m >> 2] = c[p >> 2];
	                    c[p >> 2] = 0
	                }
	                if ((E | 0) == 33) {
	                    c[F + 84 >> 2] = -1;
	                    c[(c[k >> 2] | 0) + 212 >> 2] = 1;
	                    c[j >> 2] = -1;
	                    D = c[j >> 2] | 0;
	                    i = g;
	                    return D | 0
	                } else if ((E | 0) == 42) {
	                    Db[c[135904 >> 2] & 511](c[33980] | 0, 69864, h);
	                    c[j >> 2] = 81;
	                    D = c[j >> 2] | 0;
	                    i = g;
	                    return D | 0
	                } else if ((E | 0) == 53) {
	                    c[j >> 2] = c[G + 84 >> 2];
	                    D = c[j >> 2] | 0;
	                    i = g;
	                    return D | 0
	                } else if ((E | 0) == 61) {
	                    c[j >> 2] = c[(c[k >> 2] | 0) + 84 >> 2];
	                    D = c[j >> 2] | 0;
	                    i = g;
	                    return D | 0
	                } else if ((E | 0) == 64) {
	                    if (((c[o >> 2] | 0) == 1 ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[c[(c[k >> 2] | 0) + 36 >> 2] >> 2] | 0) != 0 : 0) {
	                        c[A >> 2] = jz(c[(c[c[(c[k >> 2] | 0) + 36 >> 2] >> 2] | 0) + 16 >> 2] | 0, c[(c[k >> 2] | 0) + 36 >> 2] | 0) | 0;
	                        c[B >> 2] = (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0);
	                        Lk(c[c[(c[k >> 2] | 0) + 36 >> 2] >> 2] | 0, 1, 69920) | 0;
	                        kz(c[(c[c[(c[k >> 2] | 0) + 36 >> 2] >> 2] | 0) + 16 >> 2] | 0, c[(c[k >> 2] | 0) + 36 >> 2] | 0, c[A >> 2] | 0, c[B >> 2] | 0) | 0
	                    }
	                    if (c[n >> 2] | 0) {
	                        c[C >> 2] = 0;
	                        do if (c[(c[k >> 2] | 0) + 36 >> 2] | 0) {
	                            n = c[(c[k >> 2] | 0) + 36 >> 2] | 0;
	                            if (!(c[c[(c[k >> 2] | 0) + 36 >> 2] >> 2] | 0)) {
	                                c[C >> 2] = (c[n + 24 >> 2] | 0) - ((c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0));
	                                break
	                            } else {
	                                B = _y(c[(c[n >> 2] | 0) + 16 >> 2] | 0) | 0;
	                                c[C >> 2] = B - ((c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0));
	                                break
	                            }
	                        } while (0);
	                        if ((c[(c[k >> 2] | 0) + 172 >> 2] | 0) != -1 ? (c[(c[k >> 2] | 0) + 172 >> 2] | 0) != 14 : 0)og(c[k >> 2] | 0, 5, 0);
	                        if ((c[C >> 2] | 0) > 0 ? (c[(c[k >> 2] | 0) + 172 >> 2] | 0) == 14 : 0)og(c[k >> 2] | 0, 5, 0);
	                        if (((c[(c[k >> 2] | 0) + 172 >> 2] | 0) != -1 ? (c[c[k >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[c[k >> 2] >> 2] | 0) + 52 >> 2] | 0) != 0 : 0)zb[c[(c[c[k >> 2] >> 2] | 0) + 52 >> 2] & 511](c[(c[k >> 2] | 0) + 4 >> 2] | 0);
	                        c[(c[k >> 2] | 0) + 172 >> 2] = -1
	                    }
	                    if (!(c[(c[k >> 2] | 0) + 12 >> 2] | 0)) {
	                        c[j >> 2] = c[(c[k >> 2] | 0) + 84 >> 2];
	                        D = c[j >> 2] | 0;
	                        i = g;
	                        return D | 0
	                    } else {
	                        c[j >> 2] = 0;
	                        D = c[j >> 2] | 0;
	                        i = g;
	                        return D | 0
	                    }
	                }
	                return 0
	            }

	            function Tf(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                g = i;
	                i = i + 48 | 0;
	                h = g + 44 | 0;
	                j = g + 40 | 0;
	                k = g + 36 | 0;
	                l = g + 32 | 0;
	                m = g + 28 | 0;
	                n = g + 24 | 0;
	                o = g + 20 | 0;
	                p = g + 16 | 0;
	                q = g + 12 | 0;
	                r = g + 8 | 0;
	                s = g + 4 | 0;
	                t = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[r >> 2] = 0;
	                if ((c[l >> 2] | 0) != 0 & (c[m >> 2] | 0) >= 4)c[r >> 2] = sd(c[l >> 2] | 0, c[m >> 2] | 0) | 0;
	                c[q >> 2] = vk(c[r >> 2] | 0) | 0;
	                if (!(c[q >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    u = c[h >> 2] | 0;
	                    i = g;
	                    return u | 0
	                }
	                c[o >> 2] = Be() | 0;
	                if (!(c[o >> 2] | 0)) {
	                    ie(0, 69928);
	                    yk(c[q >> 2] | 0);
	                    c[h >> 2] = 0;
	                    u = c[h >> 2] | 0;
	                    i = g;
	                    return u | 0
	                }
	                c[(c[o >> 2] | 0) + 364 >> 2] = 1;
	                f = Cb[c[135744 >> 2] & 511]((c[(c[o >> 2] | 0) + 192 >> 2] | 0) * 3 << 2) | 0;
	                c[(c[o >> 2] | 0) + 344 >> 2] = f;
	                if (!(c[(c[o >> 2] | 0) + 344 >> 2] | 0)) {
	                    ie(c[o >> 2] | 0, 0);
	                    yk(c[q >> 2] | 0);
	                    Ae(c[o >> 2] | 0);
	                    c[h >> 2] = 0;
	                    u = c[h >> 2] | 0;
	                    i = g;
	                    return u | 0
	                }
	                if (c[j >> 2] | 0) {
	                    if ((c[c[o >> 2] >> 2] | 0) != 135968)zb[c[135736 >> 2] & 511](c[c[o >> 2] >> 2] | 0);
	                    f = Cb[c[135744 >> 2] & 511](128) | 0;
	                    c[c[o >> 2] >> 2] = f;
	                    f = c[o >> 2] | 0;
	                    if (!(c[c[o >> 2] >> 2] | 0)) {
	                        ie(f, 0);
	                        yk(c[q >> 2] | 0);
	                        Ae(c[o >> 2] | 0);
	                        c[h >> 2] = 0;
	                        u = c[h >> 2] | 0;
	                        i = g;
	                        return u | 0
	                    }
	                    e = (c[f >> 2] | 0) + 0 | 0;
	                    f = e + 128 | 0;
	                    do {
	                        c[e >> 2] = 0;
	                        e = e + 4 | 0
	                    } while ((e | 0) < (f | 0));
	                    d = c[c[o >> 2] >> 2] | 0;
	                    b = c[j >> 2] | 0;
	                    if ((c[(c[j >> 2] | 0) + 108 >> 2] | 0) == -554844497) {
	                        e = d + 0 | 0;
	                        v = b + 0 | 0;
	                        f = e + 128 | 0;
	                        do {
	                            c[e >> 2] = c[v >> 2];
	                            e = e + 4 | 0;
	                            v = v + 4 | 0
	                        } while ((e | 0) < (f | 0))
	                    } else {
	                        e = d + 0 | 0;
	                        v = b + 0 | 0;
	                        f = e + 112 | 0;
	                        do {
	                            c[e >> 2] = c[v >> 2];
	                            e = e + 4 | 0;
	                            v = v + 4 | 0
	                        } while ((e | 0) < (f | 0))
	                    }
	                    if (c[k >> 2] | 0)c[(c[o >> 2] | 0) + 4 >> 2] = c[k >> 2]
	                }
	                if (!(c[n >> 2] | 0))c[(c[o >> 2] | 0) + 180 >> 2] = 0; else {
	                    k = Rk(c[n >> 2] | 0) | 0;
	                    c[(c[o >> 2] | 0) + 180 >> 2] = k
	                }
	                c[p >> 2] = ue(c[o >> 2] | 0) | 0;
	                if (!(c[p >> 2] | 0)) {
	                    Ae(c[o >> 2] | 0);
	                    yk(c[q >> 2] | 0);
	                    c[h >> 2] = 0;
	                    u = c[h >> 2] | 0;
	                    i = g;
	                    return u | 0
	                }
	                if (c[n >> 2] | 0) {
	                    k = Jl(c[n >> 2] | 0) | 0;
	                    c[(c[p >> 2] | 0) + 4 >> 2] = k;
	                    if (!(c[(c[p >> 2] | 0) + 4 >> 2] | 0)) {
	                        Ae(c[o >> 2] | 0);
	                        yk(c[q >> 2] | 0);
	                        c[h >> 2] = 0;
	                        u = c[h >> 2] | 0;
	                        i = g;
	                        return u | 0
	                    }
	                } else c[(c[p >> 2] | 0) + 4 >> 2] = 0;
	                c[c[p >> 2] >> 2] = c[q >> 2];
	                iz(c[(c[c[p >> 2] >> 2] | 0) + 16 >> 2] | 0, c[p >> 2] | 0) | 0;
	                Oe(c[o >> 2] | 0, c[p >> 2] | 0) | 0;
	                p = c[o >> 2] | 0;
	                if (!((c[m >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0)) {
	                    if ((c[p + 36 >> 2] | 0) != 0 ? (c[c[(c[o >> 2] | 0) + 36 >> 2] >> 2] | 0) != 0 : 0) {
	                        c[s >> 2] = jz(c[(c[c[(c[o >> 2] | 0) + 36 >> 2] >> 2] | 0) + 16 >> 2] | 0, c[(c[o >> 2] | 0) + 36 >> 2] | 0) | 0;
	                        c[t >> 2] = (c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0);
	                        Lk(c[c[(c[o >> 2] | 0) + 36 >> 2] >> 2] | 0, c[m >> 2] | 0, c[l >> 2] | 0) | 0;
	                        kz(c[(c[c[(c[o >> 2] | 0) + 36 >> 2] >> 2] | 0) + 16 >> 2] | 0, c[(c[o >> 2] | 0) + 36 >> 2] | 0, c[s >> 2] | 0, c[t >> 2] | 0) | 0
	                    }
	                } else c[p + 256 >> 2] = 0;
	                if (c[r >> 2] | 0)re(c[o >> 2] | 0, c[r >> 2] | 0) | 0;
	                c[h >> 2] = c[o >> 2];
	                u = c[h >> 2] | 0;
	                i = g;
	                return u | 0
	            }

	            function Uf(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                c[(c[d >> 2] | 0) + 172 >> 2] = -1;
	                c[(c[d >> 2] | 0) + 84 >> 2] = 111;
	                c[(c[d >> 2] | 0) + 212 >> 2] = 1;
	                if (!(c[(c[d >> 2] | 0) + 36 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                c[(c[(c[d >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] = 65640;
	                c[(c[(c[d >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] = c[(c[(c[d >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                i = b;
	                return
	            }

	            function Vf(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 36 | 0;
	                g = e + 32 | 0;
	                h = e + 28 | 0;
	                j = e + 24 | 0;
	                k = e + 20 | 0;
	                l = e + 16 | 0;
	                m = e + 12 | 0;
	                n = e + 8 | 0;
	                o = e + 4 | 0;
	                p = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 0;
	                c[m >> 2] = 0;
	                if ((c[h >> 2] | 0) == 0 & (c[j >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    q = c[f >> 2] | 0;
	                    i = e;
	                    return q | 0
	                }
	                c[l >> 2] = Be() | 0;
	                if (!(c[l >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    q = c[f >> 2] | 0;
	                    i = e;
	                    return q | 0
	                }
	                d = (c[l >> 2] | 0) + 360 | 0;
	                c[d >> 2] = c[d >> 2] | 4;
	                if (c[g >> 2] | 0) {
	                    if (c[c[l >> 2] >> 2] | 0)zb[c[135736 >> 2] & 511](c[c[l >> 2] >> 2] | 0);
	                    c[c[l >> 2] >> 2] = c[g >> 2];
	                    c[(c[l >> 2] | 0) + 4 >> 2] = c[l >> 2]
	                }
	                c[o >> 2] = Jl(c[j >> 2] | 0) | 0;
	                d = c[l >> 2] | 0;
	                if ((c[j >> 2] | 0) != 0 & (c[o >> 2] | 0) == 0) {
	                    Ae(d);
	                    c[f >> 2] = 0;
	                    q = c[f >> 2] | 0;
	                    i = e;
	                    return q | 0
	                }
	                if ((c[d >> 2] | 0) != 0 ? (c[(c[c[l >> 2] >> 2] | 0) + 16 >> 2] | 0) != 0 : 0)c[m >> 2] = vb[c[(c[c[l >> 2] >> 2] | 0) + 16 >> 2] & 511](c[(c[l >> 2] | 0) + 4 >> 2] | 0, c[h >> 2] | 0, c[o >> 2] | 0) | 0;
	                if (!(c[m >> 2] | 0)) {
	                    if (c[g >> 2] | 0)c[c[l >> 2] >> 2] = 0;
	                    Ae(c[l >> 2] | 0);
	                    if (c[o >> 2] | 0)zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                    c[f >> 2] = 0;
	                    q = c[f >> 2] | 0;
	                    i = e;
	                    return q | 0
	                }
	                if ((Xe(c[l >> 2] | 0, c[m >> 2] | 0) | 0) < 0) {
	                    if (c[g >> 2] | 0)c[c[l >> 2] >> 2] = 0;
	                    Ae(c[l >> 2] | 0);
	                    if (c[o >> 2] | 0)zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                    c[f >> 2] = 0;
	                    q = c[f >> 2] | 0;
	                    i = e;
	                    return q | 0
	                }
	                if (((c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) >= 4) {
	                    c[n >> 2] = sd(c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0, 4) | 0;
	                    re(c[l >> 2] | 0, c[n >> 2] | 0) | 0
	                }
	                if (!(c[(c[m >> 2] | 0) + 4 >> 2] | 0))c[(c[m >> 2] | 0) + 4 >> 2] = c[o >> 2]; else zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                c[(c[m >> 2] | 0) + 28 >> 2] = 1;
	                c[(c[m >> 2] | 0) + 32 >> 2] = 1;
	                c[(c[m >> 2] | 0) + 12 >> 2] = c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                c[(c[m >> 2] | 0) + 16 >> 2] = c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                c[(c[m >> 2] | 0) + 40 >> 2] = 0;
	                c[(c[l >> 2] | 0) + 216 >> 2] = 2;
	                m = Sh(68488) | 0;
	                c[(c[l >> 2] | 0) + 8 >> 2] = m;
	                m = c[l >> 2] | 0;
	                if (!(c[(c[l >> 2] | 0) + 8 >> 2] | 0)) {
	                    ie(m, 67128);
	                    if (c[g >> 2] | 0)c[c[l >> 2] >> 2] = 0;
	                    Ae(c[l >> 2] | 0);
	                    c[f >> 2] = 0;
	                    q = c[f >> 2] | 0;
	                    i = e;
	                    return q | 0
	                }
	                c[(c[m + 8 >> 2] | 0) + 92 >> 2] = 64;
	                m = Mh(c[(c[l >> 2] | 0) + 8 >> 2] | 0, 69960, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 48 >> 2] = m;
	                Cf(c[l >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0);
	                if (c[(c[l >> 2] | 0) + 8 >> 2] | 0) {
	                    a:do if (c[(c[l >> 2] | 0) + 12 >> 2] | 0) {
	                        c[k >> 2] = c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 48 >> 2];
	                        c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 48 >> 2] = 0;
	                        if (c[k >> 2] | 0) {
	                            c[(c[k >> 2] | 0) + 32 >> 2] = 0;
	                            c[p >> 2] = c[(c[k >> 2] | 0) + 12 >> 2];
	                            while (1) {
	                                if (!(c[p >> 2] | 0))break a;
	                                c[(c[p >> 2] | 0) + 32 >> 2] = 0;
	                                c[p >> 2] = c[(c[p >> 2] | 0) + 24 >> 2]
	                            }
	                        }
	                    } else c[k >> 2] = 0; while (0);
	                    Th(c[(c[l >> 2] | 0) + 8 >> 2] | 0);
	                    c[(c[l >> 2] | 0) + 8 >> 2] = 0
	                }
	                if (c[g >> 2] | 0)c[c[l >> 2] >> 2] = 0;
	                Ae(c[l >> 2] | 0);
	                c[f >> 2] = c[k >> 2];
	                q = c[f >> 2] | 0;
	                i = e;
	                return q | 0
	            }

	            function Wf(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                b = Vf(0, c[e >> 2] | 0, c[f >> 2] | 0) | 0;
	                i = d;
	                return b | 0
	            }

	            function Xf(b, e, f, g) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0;
	                h = i;
	                i = i + 64 | 0;
	                j = h + 44 | 0;
	                k = h + 40 | 0;
	                l = h + 36 | 0;
	                m = h + 32 | 0;
	                n = h + 28 | 0;
	                o = h + 24 | 0;
	                p = h + 20 | 0;
	                q = h + 16 | 0;
	                r = h + 12 | 0;
	                s = h + 8 | 0;
	                t = h + 48 | 0;
	                u = h + 4 | 0;
	                v = h;
	                c[k >> 2] = b;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                c[n >> 2] = g;
	                c[r >> 2] = 0;
	                c[s >> 2] = 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[j >> 2] = -1;
	                    w = c[j >> 2] | 0;
	                    i = h;
	                    return w | 0
	                }
	                if (!((c[(c[k >> 2] | 0) + 248 >> 2] | 0) > 40 ? (c[(c[k >> 2] | 0) + 360 >> 2] & 524288 | 0) == 0 : 0))x = 5;
	                if ((x | 0) == 5 ? (c[(c[k >> 2] | 0) + 248 >> 2] | 0) <= 1024 : 0) {
	                    if (c[n >> 2] | 0)c[c[n >> 2] >> 2] = 0;
	                    if ((c[l >> 2] | 0) == 0 & (c[m >> 2] | 0) == 0) {
	                        c[j >> 2] = -1;
	                        w = c[j >> 2] | 0;
	                        i = h;
	                        return w | 0
	                    }
	                    if (!(c[(c[k >> 2] | 0) + 8 >> 2] | 0)) {
	                        c[j >> 2] = -1;
	                        w = c[j >> 2] | 0;
	                        i = h;
	                        return w | 0
	                    }
	                    c[o >> 2] = fh(c[l >> 2] | 0, c[m >> 2] | 0, 0, c[k >> 2] | 0) | 0;
	                    if (!(c[o >> 2] | 0)) {
	                        c[j >> 2] = -1;
	                        w = c[j >> 2] | 0;
	                        i = h;
	                        return w | 0
	                    }
	                    c[r >> 2] = c[c[o >> 2] >> 2];
	                    c[c[o >> 2] >> 2] = c[c[k >> 2] >> 2];
	                    Rg(c[o >> 2] | 0);
	                    c[p >> 2] = Sh(68488) | 0;
	                    if (!(c[p >> 2] | 0)) {
	                        Ae(c[o >> 2] | 0);
	                        c[j >> 2] = -1;
	                        w = c[j >> 2] | 0;
	                        i = h;
	                        return w | 0
	                    }
	                    c[(c[p >> 2] | 0) + 92 >> 2] = 64;
	                    if (c[(c[(c[k >> 2] | 0) + 8 >> 2] | 0) + 80 >> 2] | 0) {
	                        c[(c[p >> 2] | 0) + 80 >> 2] = c[(c[(c[k >> 2] | 0) + 8 >> 2] | 0) + 80 >> 2];
	                        yP(c[(c[p >> 2] | 0) + 80 >> 2] | 0) | 0
	                    }
	                    if (c[(c[k >> 2] | 0) + 8 >> 2] | 0) {
	                        c[(c[p >> 2] | 0) + 44 >> 2] = c[(c[(c[k >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2];
	                        c[(c[p >> 2] | 0) + 48 >> 2] = c[(c[(c[k >> 2] | 0) + 8 >> 2] | 0) + 48 >> 2]
	                    }
	                    if (c[(c[(c[k >> 2] | 0) + 8 >> 2] | 0) + 72 >> 2] | 0) {
	                        m = my(c[(c[(c[k >> 2] | 0) + 8 >> 2] | 0) + 72 >> 2] | 0) | 0;
	                        c[(c[p >> 2] | 0) + 72 >> 2] = m
	                    }
	                    c[q >> 2] = ji(c[p >> 2] | 0, 0, 69968, 0) | 0;
	                    if (!(c[q >> 2] | 0)) {
	                        c[c[o >> 2] >> 2] = c[r >> 2];
	                        Ae(c[o >> 2] | 0);
	                        c[(c[p >> 2] | 0) + 44 >> 2] = 0;
	                        c[(c[p >> 2] | 0) + 48 >> 2] = 0;
	                        Th(c[p >> 2] | 0);
	                        c[j >> 2] = -1;
	                        w = c[j >> 2] | 0;
	                        i = h;
	                        return w | 0
	                    }
	                    zi(c[p >> 2] | 0, c[q >> 2] | 0) | 0;
	                    Qe(c[o >> 2] | 0, c[(c[p >> 2] | 0) + 12 >> 2] | 0) | 0;
	                    if (!(c[(c[k >> 2] | 0) + 8 >> 2] | 0))c[(c[o >> 2] | 0) + 8 >> 2] = c[p >> 2]; else {
	                        c[(c[o >> 2] | 0) + 8 >> 2] = c[(c[k >> 2] | 0) + 8 >> 2];
	                        c[(c[(c[p >> 2] | 0) + 12 >> 2] | 0) + 32 >> 2] = c[(c[k >> 2] | 0) + 8 >> 2]
	                    }
	                    if ((c[(c[o >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[o >> 2] | 0);
	                    if (((c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) >= 4 ? (a[t >> 0] = a[c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0, a[t + 1 >> 0] = a[(c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0, a[t + 2 >> 0] = a[(c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0, a[t + 3 >> 0] = a[(c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0, c[u >> 2] = sd(t, 4) | 0, (c[u >> 2] | 0) != 0) : 0)re(c[o >> 2] | 0, c[u >> 2] | 0) | 0;
	                    a:do if (((d[c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 63 : 0) ? (d[(c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 120 : 0) {
	                        if ((d[(c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) != 109)break;
	                        if ((d[(c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) != 108)break;
	                        do if ((d[(c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[(c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) ? (d[(c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[(c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) != 13)break a
	                        } while (0);
	                        _e(c[o >> 2] | 0);
	                        if (!(qy(c[(c[k >> 2] | 0) + 20 >> 2] | 0, 68488) | 0))break;
	                        if (qy(c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 48 >> 2] | 0, 68488) | 0)break;
	                        xg(c[o >> 2] | 0, 109, 69984)
	                    } while (0);
	                    if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == (c[k >> 2] | 0))c[(c[o >> 2] | 0) + 4 >> 2] = c[o >> 2]; else c[(c[o >> 2] | 0) + 4 >> 2] = c[(c[k >> 2] | 0) + 4 >> 2];
	                    c[(c[o >> 2] | 0) + 172 >> 2] = 7;
	                    c[(c[o >> 2] | 0) + 104 >> 2] = c[(c[k >> 2] | 0) + 104 >> 2];
	                    c[(c[o >> 2] | 0) + 100 >> 2] = c[(c[k >> 2] | 0) + 100 >> 2];
	                    c[(c[o >> 2] | 0) + 276 >> 2] = c[(c[k >> 2] | 0) + 276 >> 2];
	                    c[(c[o >> 2] | 0) + 248 >> 2] = (c[(c[k >> 2] | 0) + 248 >> 2] | 0) + 1;
	                    c[(c[o >> 2] | 0) + 16 >> 2] = c[(c[k >> 2] | 0) + 16 >> 2];
	                    if (c[(c[o >> 2] | 0) + 104 >> 2] | 0) {
	                        c[(c[o >> 2] | 0) + 112 >> 2] = c[(c[k >> 2] | 0) + 112 >> 2];
	                        c[(c[o >> 2] | 0) + 116 >> 2] = c[(c[k >> 2] | 0) + 116 >> 2]
	                    } else {
	                        c[(c[o >> 2] | 0) + 112 >> 2] = 0;
	                        c[(c[o >> 2] | 0) + 116 >> 2] = 0
	                    }
	                    c[(c[o >> 2] | 0) + 132 >> 2] = 0;
	                    c[(c[o >> 2] | 0) + 124 >> 2] = 0;
	                    c[(c[o >> 2] | 0) + 128 >> 2] = 0;
	                    c[(c[o >> 2] | 0) + 120 >> 2] = 0;
	                    if (c[(c[o >> 2] | 0) + 296 >> 2] | 0)zP(c[(c[o >> 2] | 0) + 296 >> 2] | 0);
	                    c[(c[o >> 2] | 0) + 296 >> 2] = c[(c[k >> 2] | 0) + 296 >> 2];
	                    u = AP(c[(c[o >> 2] | 0) + 296 >> 2] | 0, 70032, 3) | 0;
	                    c[(c[o >> 2] | 0) + 312 >> 2] = u;
	                    u = AP(c[(c[o >> 2] | 0) + 296 >> 2] | 0, 70040, 5) | 0;
	                    c[(c[o >> 2] | 0) + 316 >> 2] = u;
	                    u = AP(c[(c[o >> 2] | 0) + 296 >> 2] | 0, 70048, 36) | 0;
	                    c[(c[o >> 2] | 0) + 320 >> 2] = u;
	                    c[(c[o >> 2] | 0) + 364 >> 2] = c[(c[k >> 2] | 0) + 364 >> 2];
	                    c[(c[o >> 2] | 0) + 348 >> 2] = c[(c[k >> 2] | 0) + 348 >> 2];
	                    c[(c[o >> 2] | 0) + 352 >> 2] = c[(c[k >> 2] | 0) + 352 >> 2];
	                    c[(c[o >> 2] | 0) + 280 >> 2] = c[(c[k >> 2] | 0) + 280 >> 2];
	                    Jf(c[o >> 2] | 0);
	                    c[(c[k >> 2] | 0) + 104 >> 2] = c[(c[o >> 2] | 0) + 104 >> 2];
	                    c[(c[k >> 2] | 0) + 100 >> 2] = c[(c[o >> 2] | 0) + 100 >> 2];
	                    do if ((d[c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60) {
	                        if ((d[(c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) != 47) {
	                            x = 57;
	                            break
	                        }
	                        og(c[o >> 2] | 0, 85, 0)
	                    } else x = 57; while (0);
	                    do if ((x | 0) == 57) {
	                        if (!(d[c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0))break;
	                        og(c[o >> 2] | 0, 86, 0)
	                    } while (0);
	                    if ((c[(c[o >> 2] | 0) + 52 >> 2] | 0) != (c[(c[p >> 2] | 0) + 12 >> 2] | 0))og(c[o >> 2] | 0, 85, 0);
	                    do if (!(c[(c[o >> 2] | 0) + 12 >> 2] | 0))if (!(c[(c[o >> 2] | 0) + 84 >> 2] | 0)) {
	                        c[s >> 2] = 1;
	                        break
	                    } else {
	                        c[s >> 2] = c[(c[o >> 2] | 0) + 84 >> 2];
	                        break
	                    } else {
	                        if (c[n >> 2] | 0) {
	                            c[v >> 2] = c[(c[(c[p >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2];
	                            c[c[n >> 2] >> 2] = c[v >> 2];
	                            while (1) {
	                                if (!(c[v >> 2] | 0))break;
	                                c[(c[v >> 2] | 0) + 20 >> 2] = 0;
	                                c[v >> 2] = c[(c[v >> 2] | 0) + 24 >> 2]
	                            }
	                            c[(c[(c[p >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2] = 0
	                        }
	                        c[s >> 2] = 0
	                    } while (0);
	                    c[c[o >> 2] >> 2] = c[r >> 2];
	                    c[(c[o >> 2] | 0) + 296 >> 2] = 0;
	                    c[(c[o >> 2] | 0) + 348 >> 2] = 0;
	                    c[(c[o >> 2] | 0) + 352 >> 2] = 0;
	                    Ae(c[o >> 2] | 0);
	                    c[(c[p >> 2] | 0) + 44 >> 2] = 0;
	                    c[(c[p >> 2] | 0) + 48 >> 2] = 0;
	                    Th(c[p >> 2] | 0);
	                    c[j >> 2] = c[s >> 2];
	                    w = c[j >> 2] | 0;
	                    i = h;
	                    return w | 0
	                }
	                c[j >> 2] = 89;
	                w = c[j >> 2] | 0;
	                i = h;
	                return w | 0
	            }

	            function Yf(a, b, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0;
	                h = i;
	                i = i + 64 | 0;
	                j = h + 60 | 0;
	                k = h + 56 | 0;
	                l = h + 52 | 0;
	                m = h + 48 | 0;
	                n = h + 44 | 0;
	                o = h + 40 | 0;
	                p = h + 36 | 0;
	                q = h + 32 | 0;
	                r = h + 28 | 0;
	                s = h + 24 | 0;
	                t = h + 20 | 0;
	                u = h + 16 | 0;
	                v = h + 12 | 0;
	                w = h + 8 | 0;
	                x = h + 4 | 0;
	                y = h;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                c[q >> 2] = 0;
	                c[t >> 2] = 0;
	                c[u >> 2] = 0;
	                if ((c[o >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0 | (c[m >> 2] | 0) < 0) {
	                    c[j >> 2] = 1;
	                    z = c[j >> 2] | 0;
	                    i = h;
	                    return z | 0
	                }
	                switch (c[(c[k >> 2] | 0) + 4 >> 2] | 0) {
	                    case 13:
	                    case 9:
	                    case 8:
	                    case 7:
	                    case 5:
	                    case 4:
	                    case 3:
	                    case 2:
	                    case 1:
	                        break;
	                    default:
	                    {
	                        c[j >> 2] = 1;
	                        z = c[j >> 2] | 0;
	                        i = h;
	                        return z | 0
	                    }
	                }
	                while (1) {
	                    if (((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 4 >> 2] | 0) != 1 : 0) ? (c[(c[k >> 2] | 0) + 4 >> 2] | 0) != 9 : 0)A = (c[(c[k >> 2] | 0) + 4 >> 2] | 0) != 13; else A = 0;
	                    B = c[k >> 2] | 0;
	                    if (!A)break;
	                    c[k >> 2] = c[B + 20 >> 2]
	                }
	                if (!B) {
	                    c[j >> 2] = 1;
	                    z = c[j >> 2] | 0;
	                    i = h;
	                    return z | 0
	                }
	                B = c[k >> 2] | 0;
	                if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 1)c[q >> 2] = c[B + 32 >> 2]; else c[q >> 2] = B;
	                if (!(c[q >> 2] | 0)) {
	                    c[j >> 2] = 1;
	                    z = c[j >> 2] | 0;
	                    i = h;
	                    return z | 0
	                }
	                do if ((c[(c[q >> 2] | 0) + 4 >> 2] | 0) == 9)c[p >> 2] = Zf(c[l >> 2] | 0, c[m >> 2] | 0) | 0; else {
	                    if ((c[(c[q >> 2] | 0) + 4 >> 2] | 0) == 13) {
	                        c[p >> 2] = no(c[l >> 2] | 0, c[m >> 2] | 0) | 0;
	                        c[n >> 2] = c[n >> 2] | 8192;
	                        break
	                    }
	                    c[j >> 2] = 1;
	                    z = c[j >> 2] | 0;
	                    i = h;
	                    return z | 0
	                } while (0);
	                if (!(c[p >> 2] | 0)) {
	                    c[j >> 2] = 2;
	                    z = c[j >> 2] | 0;
	                    i = h;
	                    return z | 0
	                }
	                if (c[(c[q >> 2] | 0) + 80 >> 2] | 0) {
	                    if (c[(c[p >> 2] | 0) + 296 >> 2] | 0)zP(c[(c[p >> 2] | 0) + 296 >> 2] | 0);
	                    c[(c[p >> 2] | 0) + 296 >> 2] = c[(c[q >> 2] | 0) + 80 >> 2]
	                } else c[n >> 2] = c[n >> 2] | 4096;
	                do if (c[(c[q >> 2] | 0) + 60 >> 2] | 0) {
	                    if (c[(c[p >> 2] | 0) + 24 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[p >> 2] | 0) + 24 >> 2] | 0);
	                    m = my(c[(c[q >> 2] | 0) + 60 >> 2] | 0) | 0;
	                    c[(c[p >> 2] | 0) + 24 >> 2] = m;
	                    c[v >> 2] = Dd(c[(c[q >> 2] | 0) + 60 >> 2] | 0) | 0;
	                    if (c[v >> 2] | 0) {
	                        se(c[p >> 2] | 0, c[v >> 2] | 0) | 0;
	                        break
	                    }
	                    c[j >> 2] = 32;
	                    z = c[j >> 2] | 0;
	                    i = h;
	                    return z | 0
	                } while (0);
	                gh(c[p >> 2] | 0, c[n >> 2] | 0, 0) | 0;
	                Rg(c[p >> 2] | 0);
	                c[(c[p >> 2] | 0) + 8 >> 2] = c[q >> 2];
	                c[(c[p >> 2] | 0) + 172 >> 2] = 7;
	                c[r >> 2] = oi(0) | 0;
	                if (!(c[r >> 2] | 0)) {
	                    Ae(c[p >> 2] | 0);
	                    c[j >> 2] = 2;
	                    z = c[j >> 2] | 0;
	                    i = h;
	                    return z | 0
	                }
	                zi(c[k >> 2] | 0, c[r >> 2] | 0) | 0;
	                a:do if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                    Qe(c[p >> 2] | 0, c[k >> 2] | 0) | 0;
	                    c[s >> 2] = c[k >> 2];
	                    while (1) {
	                        if (!(c[s >> 2] | 0))break a;
	                        if ((c[(c[s >> 2] | 0) + 4 >> 2] | 0) != 1)break a;
	                        c[w >> 2] = c[(c[s >> 2] | 0) + 48 >> 2];
	                        while (1) {
	                            if (!(c[w >> 2] | 0))break;
	                            if (c[(c[p >> 2] | 0) + 296 >> 2] | 0) {
	                                c[x >> 2] = AP(c[(c[p >> 2] | 0) + 296 >> 2] | 0, c[(c[w >> 2] | 0) + 12 >> 2] | 0, -1) | 0;
	                                c[y >> 2] = AP(c[(c[p >> 2] | 0) + 296 >> 2] | 0, c[(c[w >> 2] | 0) + 8 >> 2] | 0, -1) | 0
	                            } else {
	                                c[x >> 2] = c[(c[w >> 2] | 0) + 12 >> 2];
	                                c[y >> 2] = c[(c[w >> 2] | 0) + 8 >> 2]
	                            }
	                            if (!(hh(c[p >> 2] | 0, c[x >> 2] | 0) | 0)) {
	                                ih(c[p >> 2] | 0, c[x >> 2] | 0, c[y >> 2] | 0) | 0;
	                                c[t >> 2] = (c[t >> 2] | 0) + 1
	                            }
	                            c[w >> 2] = c[c[w >> 2] >> 2]
	                        }
	                        c[s >> 2] = c[(c[s >> 2] | 0) + 20 >> 2]
	                    }
	                } while (0);
	                if (!((c[(c[p >> 2] | 0) + 104 >> 2] | 0) == 0 ? (c[(c[p >> 2] | 0) + 16 >> 2] | 0) == 0 : 0)) {
	                    w = (c[p >> 2] | 0) + 276 | 0;
	                    c[w >> 2] = c[w >> 2] | 8
	                }
	                w = c[p >> 2] | 0;
	                if ((c[(c[q >> 2] | 0) + 4 >> 2] | 0) == 13)jo(w); else Jf(w);
	                _g(c[p >> 2] | 0, c[t >> 2] | 0) | 0;
	                if ((d[c[(c[(c[p >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[p >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 47 : 0)og(c[p >> 2] | 0, 85, 0); else C = 60;
	                if ((C | 0) == 60 ? (d[c[(c[(c[p >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 0 : 0)og(c[p >> 2] | 0, 86, 0);
	                if ((c[(c[p >> 2] | 0) + 52 >> 2] | 0) != 0 ? (c[(c[p >> 2] | 0) + 52 >> 2] | 0) != (c[k >> 2] | 0) : 0) {
	                    og(c[p >> 2] | 0, 85, 0);
	                    c[(c[p >> 2] | 0) + 12 >> 2] = 0
	                }
	                do if (!(c[(c[p >> 2] | 0) + 12 >> 2] | 0))if (!(c[(c[p >> 2] | 0) + 84 >> 2] | 0)) {
	                    c[u >> 2] = 1;
	                    break
	                } else {
	                    c[u >> 2] = c[(c[p >> 2] | 0) + 84 >> 2];
	                    break
	                } else c[u >> 2] = 0; while (0);
	                c[s >> 2] = c[(c[r >> 2] | 0) + 24 >> 2];
	                c[(c[r >> 2] | 0) + 24 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 16 >> 2] = c[r >> 2];
	                if (c[s >> 2] | 0)c[(c[s >> 2] | 0) + 28 >> 2] = 0;
	                c[c[o >> 2] >> 2] = c[s >> 2];
	                while (1) {
	                    if (!(c[s >> 2] | 0))break;
	                    c[(c[s >> 2] | 0) + 20 >> 2] = 0;
	                    c[s >> 2] = c[(c[s >> 2] | 0) + 24 >> 2]
	                }
	                Qh(c[r >> 2] | 0);
	                Rh(c[r >> 2] | 0);
	                if (c[u >> 2] | 0) {
	                    Uh(c[c[o >> 2] >> 2] | 0);
	                    c[c[o >> 2] >> 2] = 0
	                }
	                if (c[(c[q >> 2] | 0) + 80 >> 2] | 0)c[(c[p >> 2] | 0) + 296 >> 2] = 0;
	                Ae(c[p >> 2] | 0);
	                c[j >> 2] = c[u >> 2];
	                z = c[j >> 2] | 0;
	                i = h;
	                return z | 0
	            }

	            function Zf(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                if ((c[g >> 2] | 0) <= 0) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                c[h >> 2] = Be() | 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                c[k >> 2] = Hk(c[f >> 2] | 0, c[g >> 2] | 0, 0) | 0;
	                g = c[h >> 2] | 0;
	                if (!(c[k >> 2] | 0)) {
	                    Ae(g);
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                c[j >> 2] = ue(g) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    yk(c[k >> 2] | 0);
	                    Ae(c[h >> 2] | 0);
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                } else {
	                    c[(c[j >> 2] | 0) + 4 >> 2] = 0;
	                    c[c[j >> 2] >> 2] = c[k >> 2];
	                    iz(c[(c[c[j >> 2] >> 2] | 0) + 16 >> 2] | 0, c[j >> 2] | 0) | 0;
	                    Oe(c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                    c[e >> 2] = c[h >> 2];
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                return 0
	            }

	            function _f(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = $f(c[d >> 2] | 0, 0) | 0;
	                i = b;
	                return a | 0
	            }

	            function $f(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[k >> 2] = 0;
	                c[h >> 2] = Be() | 0;
	                if (!(c[h >> 2] | 0)) {
	                    ie(0, 70088);
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                if (c[g >> 2] | 0)gh(c[h >> 2] | 0, c[g >> 2] | 0, 0) | 0;
	                c[(c[h >> 2] | 0) + 280 >> 2] = 1;
	                c[j >> 2] = Vk(c[f >> 2] | 0, 0, c[h >> 2] | 0) | 0;
	                g = c[h >> 2] | 0;
	                if (!(c[j >> 2] | 0)) {
	                    Ae(g);
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                Oe(g, c[j >> 2] | 0) | 0;
	                if ((c[k >> 2] | 0) == 0 ? (c[(c[h >> 2] | 0) + 180 >> 2] | 0) == 0 : 0)c[k >> 2] = Rk(c[f >> 2] | 0) | 0;
	                if ((c[k >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 180 >> 2] | 0) == 0 : 0)c[(c[h >> 2] | 0) + 180 >> 2] = c[k >> 2];
	                c[e >> 2] = c[h >> 2];
	                l = c[e >> 2] | 0;
	                i = d;
	                return l | 0
	            }

	            function ag(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 24 | 0;
	                h = f + 20 | 0;
	                j = f + 16 | 0;
	                k = f + 12 | 0;
	                l = f + 8 | 0;
	                m = f + 4 | 0;
	                n = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                Rf();
	                c[n >> 2] = _f(c[j >> 2] | 0) | 0;
	                if (!(c[n >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                if (c[h >> 2] | 0) {
	                    if (c[c[n >> 2] >> 2] | 0)zb[c[135736 >> 2] & 511](c[c[n >> 2] >> 2] | 0);
	                    c[c[n >> 2] >> 2] = c[h >> 2]
	                }
	                Rg(c[n >> 2] | 0);
	                if (c[l >> 2] | 0)c[(c[n >> 2] | 0) + 272 >> 2] = c[l >> 2];
	                if (!(c[(c[n >> 2] | 0) + 180 >> 2] | 0)) {
	                    l = Rk(c[j >> 2] | 0) | 0;
	                    c[(c[n >> 2] | 0) + 180 >> 2] = l
	                }
	                c[(c[n >> 2] | 0) + 288 >> 2] = c[k >> 2];
	                Qf(c[n >> 2] | 0) | 0;
	                do if ((c[k >> 2] | 0) != 0 ? 1 : (c[(c[n >> 2] | 0) + 12 >> 2] | 0) != 0) {
	                    c[m >> 2] = c[(c[n >> 2] | 0) + 8 >> 2];
	                    if (c[m >> 2] | 0)if ((c[(c[c[(c[n >> 2] | 0) + 36 >> 2] >> 2] | 0) + 24 >> 2] | 0) > 0) {
	                        c[(c[m >> 2] | 0) + 36 >> 2] = 9;
	                        break
	                    } else {
	                        c[(c[m >> 2] | 0) + 36 >> 2] = c[(c[c[(c[n >> 2] | 0) + 36 >> 2] >> 2] | 0) + 24 >> 2];
	                        break
	                    }
	                } else {
	                    c[m >> 2] = 0;
	                    Th(c[(c[n >> 2] | 0) + 8 >> 2] | 0);
	                    c[(c[n >> 2] | 0) + 8 >> 2] = 0
	                } while (0);
	                if (c[h >> 2] | 0)c[c[n >> 2] >> 2] = 0;
	                Ae(c[n >> 2] | 0);
	                c[g >> 2] = c[m >> 2];
	                o = c[g >> 2] | 0;
	                i = f;
	                return o | 0
	            }

	            function bg(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                d = ag(c[f >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0, 0) | 0;
	                i = e;
	                return d | 0
	            }

	            function cg(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = bg(0, c[d >> 2] | 0, 0) | 0;
	                i = b;
	                return a | 0
	            }

	            function dg() {
	                var a = 0;
	                a = i;
	                if (!(c[17532] | 0)) {
	                    i = a;
	                    return
	                }
	                Bd();
	                Dw();
	                wP();
	                jk();
	                kk();
	                GH();
	                XM();
	                ee();
	                mx();
	                Ax();
	                vl();
	                c[17532] = 0;
	                i = a;
	                return
	            }

	            function eg(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                c[f >> 2] = c[(c[d >> 2] | 0) + 296 >> 2];
	                while (1) {
	                    a = Pe(c[d >> 2] | 0) | 0;
	                    c[e >> 2] = a;
	                    if (!a)break;
	                    te(c[e >> 2] | 0)
	                }
	                c[(c[d >> 2] | 0) + 40 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 36 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 236 >> 2] = 0;
	                e = c[d >> 2] | 0;
	                if (c[(c[d >> 2] | 0) + 244 >> 2] | 0) {
	                    c[c[e + 244 >> 2] >> 2] = -1;
	                    c[(c[d >> 2] | 0) + 232 >> 2] = c[(c[d >> 2] | 0) + 244 >> 2]
	                } else c[e + 232 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 56 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 52 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 188 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 184 >> 2] = 0;
	                do if (c[(c[d >> 2] | 0) + 20 >> 2] | 0) {
	                    if ((c[f >> 2] | 0) != 0 ? (CP(c[f >> 2] | 0, c[(c[d >> 2] | 0) + 20 >> 2] | 0) | 0) != 0 : 0)break;
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 20 >> 2] | 0)
	                } while (0);
	                c[(c[d >> 2] | 0) + 20 >> 2] = 0;
	                do if (c[(c[d >> 2] | 0) + 24 >> 2] | 0) {
	                    if ((c[f >> 2] | 0) != 0 ? (CP(c[f >> 2] | 0, c[(c[d >> 2] | 0) + 24 >> 2] | 0) | 0) != 0 : 0)break;
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 24 >> 2] | 0)
	                } while (0);
	                c[(c[d >> 2] | 0) + 24 >> 2] = 0;
	                do if (c[(c[d >> 2] | 0) + 180 >> 2] | 0) {
	                    if ((c[f >> 2] | 0) != 0 ? (CP(c[f >> 2] | 0, c[(c[d >> 2] | 0) + 180 >> 2] | 0) | 0) != 0 : 0)break;
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 180 >> 2] | 0)
	                } while (0);
	                c[(c[d >> 2] | 0) + 180 >> 2] = 0;
	                do if (c[(c[d >> 2] | 0) + 224 >> 2] | 0) {
	                    if ((c[f >> 2] | 0) != 0 ? (CP(c[f >> 2] | 0, c[(c[d >> 2] | 0) + 224 >> 2] | 0) | 0) != 0 : 0)break;
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 224 >> 2] | 0)
	                } while (0);
	                c[(c[d >> 2] | 0) + 224 >> 2] = 0;
	                do if (c[(c[d >> 2] | 0) + 228 >> 2] | 0) {
	                    if ((c[f >> 2] | 0) != 0 ? (CP(c[f >> 2] | 0, c[(c[d >> 2] | 0) + 228 >> 2] | 0) | 0) != 0 : 0)break;
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 228 >> 2] | 0)
	                } while (0);
	                c[(c[d >> 2] | 0) + 228 >> 2] = 0;
	                if (c[(c[d >> 2] | 0) + 8 >> 2] | 0)Th(c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                c[(c[d >> 2] | 0) + 8 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 28 >> 2] = -1;
	                c[(c[d >> 2] | 0) + 88 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 92 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 32 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 96 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 172 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 176 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 12 >> 2] = 1;
	                c[(c[d >> 2] | 0) + 356 >> 2] = 1;
	                c[(c[d >> 2] | 0) + 212 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 100 >> 2] = 1;
	                c[(c[d >> 2] | 0) + 68 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 200 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 204 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 216 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 84 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 248 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 256 >> 2] = 1;
	                c[(c[d >> 2] | 0) + 284 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 440 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 444 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 468 >> 2] = 0;
	                ze((c[d >> 2] | 0) + 72 | 0);
	                if (c[(c[d >> 2] | 0) + 348 >> 2] | 0) {
	                    Kj(c[(c[d >> 2] | 0) + 348 >> 2] | 0, c[33934] | 0);
	                    c[(c[d >> 2] | 0) + 348 >> 2] = 0
	                }
	                if (c[(c[d >> 2] | 0) + 352 >> 2] | 0) {
	                    Kj(c[(c[d >> 2] | 0) + 352 >> 2] | 0, 0);
	                    c[(c[d >> 2] | 0) + 352 >> 2] = 0
	                }
	                if (c[(c[d >> 2] | 0) + 284 >> 2] | 0)Hw(c[(c[d >> 2] | 0) + 284 >> 2] | 0);
	                if (!(c[(c[d >> 2] | 0) + 388 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                Yd((c[d >> 2] | 0) + 384 | 0);
	                i = b;
	                return
	            }

	            function fg(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                b = gh(c[e >> 2] | 0, c[f >> 2] | 0, 0) | 0;
	                i = d;
	                return b | 0
	            }

	            function gg(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                Rf();
	                c[k >> 2] = $f(c[g >> 2] | 0, c[j >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } else {
	                    c[f >> 2] = jh(c[k >> 2] | 0, 0, c[h >> 2] | 0, c[j >> 2] | 0, 0) | 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                return 0
	            }

	            function hg(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 24 | 0;
	                j = g + 20 | 0;
	                k = g + 16 | 0;
	                l = g + 12 | 0;
	                m = g + 8 | 0;
	                n = g + 4 | 0;
	                o = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                Rf();
	                c[o >> 2] = Zf(c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                if (!(c[o >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    p = c[h >> 2] | 0;
	                    i = g;
	                    return p | 0
	                } else {
	                    c[h >> 2] = jh(c[o >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0, 0) | 0;
	                    p = c[h >> 2] | 0;
	                    i = g;
	                    return p | 0
	                }
	                return 0
	            }

	            function ig(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 28 | 0;
	                h = f + 24 | 0;
	                j = f + 20 | 0;
	                k = f + 16 | 0;
	                l = f + 12 | 0;
	                m = f + 8 | 0;
	                n = f + 4 | 0;
	                o = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if ((c[h >> 2] | 0) < 0) {
	                    c[g >> 2] = 0;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                Rf();
	                c[n >> 2] = Gk(c[h >> 2] | 0, 0) | 0;
	                if (!(c[n >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                c[(c[n >> 2] | 0) + 8 >> 2] = 0;
	                c[m >> 2] = Be() | 0;
	                if (!(c[m >> 2] | 0)) {
	                    yk(c[n >> 2] | 0);
	                    c[g >> 2] = 0;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                c[o >> 2] = ve(c[m >> 2] | 0, c[n >> 2] | 0, 0) | 0;
	                if (!(c[o >> 2] | 0)) {
	                    yk(c[n >> 2] | 0);
	                    Ae(c[m >> 2] | 0);
	                    c[g >> 2] = 0;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                } else {
	                    Oe(c[m >> 2] | 0, c[o >> 2] | 0) | 0;
	                    c[g >> 2] = jh(c[m >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, 0) | 0;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                return 0
	            }

	            function jg(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h + 36 | 0;
	                k = h + 32 | 0;
	                l = h + 28 | 0;
	                m = h + 24 | 0;
	                n = h + 20 | 0;
	                o = h + 16 | 0;
	                p = h + 12 | 0;
	                q = h + 8 | 0;
	                r = h + 4 | 0;
	                s = h;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                if (!(c[k >> 2] | 0)) {
	                    c[j >> 2] = 0;
	                    t = c[j >> 2] | 0;
	                    i = h;
	                    return t | 0
	                }
	                Rf();
	                c[r >> 2] = Kk(c[k >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0, 0) | 0;
	                if (!(c[r >> 2] | 0)) {
	                    if (c[l >> 2] | 0)Cb[c[l >> 2] & 511](c[m >> 2] | 0) | 0;
	                    c[j >> 2] = 0;
	                    t = c[j >> 2] | 0;
	                    i = h;
	                    return t | 0
	                }
	                c[q >> 2] = Be() | 0;
	                if (!(c[q >> 2] | 0)) {
	                    yk(c[r >> 2] | 0);
	                    c[j >> 2] = 0;
	                    t = c[j >> 2] | 0;
	                    i = h;
	                    return t | 0
	                }
	                c[s >> 2] = ve(c[q >> 2] | 0, c[r >> 2] | 0, 0) | 0;
	                if (!(c[s >> 2] | 0)) {
	                    yk(c[r >> 2] | 0);
	                    Ae(c[q >> 2] | 0);
	                    c[j >> 2] = 0;
	                    t = c[j >> 2] | 0;
	                    i = h;
	                    return t | 0
	                } else {
	                    Oe(c[q >> 2] | 0, c[s >> 2] | 0) | 0;
	                    c[j >> 2] = jh(c[q >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0, 0) | 0;
	                    t = c[j >> 2] | 0;
	                    i = h;
	                    return t | 0
	                }
	                return 0
	            }

	            function kg(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if (!(c[j >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                if (!(c[h >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                Rf();
	                eg(c[h >> 2] | 0);
	                c[m >> 2] = Vk(c[j >> 2] | 0, 0, c[h >> 2] | 0) | 0;
	                if (!(c[m >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                } else {
	                    Oe(c[h >> 2] | 0, c[m >> 2] | 0) | 0;
	                    c[g >> 2] = jh(c[h >> 2] | 0, 0, c[k >> 2] | 0, c[l >> 2] | 0, 1) | 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                return 0
	            }

	            function lg(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h + 32 | 0;
	                k = h + 28 | 0;
	                l = h + 24 | 0;
	                m = h + 20 | 0;
	                n = h + 16 | 0;
	                o = h + 12 | 0;
	                p = h + 8 | 0;
	                q = h + 4 | 0;
	                r = h;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                if (!(c[k >> 2] | 0)) {
	                    c[j >> 2] = 0;
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                }
	                if (!(c[l >> 2] | 0)) {
	                    c[j >> 2] = 0;
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                }
	                Rf();
	                eg(c[k >> 2] | 0);
	                c[q >> 2] = Hk(c[l >> 2] | 0, c[m >> 2] | 0, 0) | 0;
	                if (!(c[q >> 2] | 0)) {
	                    c[j >> 2] = 0;
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                }
	                c[r >> 2] = ve(c[k >> 2] | 0, c[q >> 2] | 0, 0) | 0;
	                if (!(c[r >> 2] | 0)) {
	                    yk(c[q >> 2] | 0);
	                    c[j >> 2] = 0;
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                } else {
	                    Oe(c[k >> 2] | 0, c[r >> 2] | 0) | 0;
	                    c[j >> 2] = jh(c[k >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0, 1) | 0;
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                }
	                return 0
	            }

	            function mg(a, b, d, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                j = i;
	                i = i + 48 | 0;
	                k = j + 36 | 0;
	                l = j + 32 | 0;
	                m = j + 28 | 0;
	                n = j + 24 | 0;
	                o = j + 20 | 0;
	                p = j + 16 | 0;
	                q = j + 12 | 0;
	                r = j + 8 | 0;
	                s = j + 4 | 0;
	                t = j;
	                c[l >> 2] = a;
	                c[m >> 2] = b;
	                c[n >> 2] = d;
	                c[o >> 2] = e;
	                c[p >> 2] = f;
	                c[q >> 2] = g;
	                c[r >> 2] = h;
	                if (!(c[m >> 2] | 0)) {
	                    c[k >> 2] = 0;
	                    u = c[k >> 2] | 0;
	                    i = j;
	                    return u | 0
	                }
	                if (!(c[l >> 2] | 0)) {
	                    c[k >> 2] = 0;
	                    u = c[k >> 2] | 0;
	                    i = j;
	                    return u | 0
	                }
	                Rf();
	                eg(c[l >> 2] | 0);
	                c[s >> 2] = Kk(c[m >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, 0) | 0;
	                if (!(c[s >> 2] | 0)) {
	                    if (c[n >> 2] | 0)Cb[c[n >> 2] & 511](c[o >> 2] | 0) | 0;
	                    c[k >> 2] = 0;
	                    u = c[k >> 2] | 0;
	                    i = j;
	                    return u | 0
	                }
	                c[t >> 2] = ve(c[l >> 2] | 0, c[s >> 2] | 0, 0) | 0;
	                if (!(c[t >> 2] | 0)) {
	                    yk(c[s >> 2] | 0);
	                    c[k >> 2] = 0;
	                    u = c[k >> 2] | 0;
	                    i = j;
	                    return u | 0
	                } else {
	                    Oe(c[l >> 2] | 0, c[t >> 2] | 0) | 0;
	                    c[k >> 2] = jh(c[l >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0, c[r >> 2] | 0, 1) | 0;
	                    u = c[k >> 2] | 0;
	                    i = j;
	                    return u | 0
	                }
	                return 0
	            }

	            function ng(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if (((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 212 >> 2] | 0) != 0 : 0) ? (c[(c[h >> 2] | 0) + 172 >> 2] | 0) == -1 : 0) {
	                    i = f;
	                    return
	                }
	                if (c[h >> 2] | 0)c[(c[h >> 2] | 0) + 84 >> 2] = c[j >> 2];
	                e = c[h >> 2] | 0;
	                d = c[j >> 2] | 0;
	                j = c[l >> 2] | 0;
	                b = c[k >> 2] | 0;
	                c[g >> 2] = c[l >> 2];
	                Xd(0, 0, 0, e, 0, 1, d, 3, 0, 0, 0, 0, 0, j, 0, b, g);
	                if (!(c[h >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                c[(c[h >> 2] | 0) + 12 >> 2] = 0;
	                if (c[(c[h >> 2] | 0) + 288 >> 2] | 0) {
	                    i = f;
	                    return
	                }
	                c[(c[h >> 2] | 0) + 212 >> 2] = 1;
	                i = f;
	                return
	            }

	            function og(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 160 | 0;
	                f = e;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e + 20 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                cU(l | 0, 0, 129) | 0;
	                if (((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 212 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 172 >> 2] | 0) == -1 : 0) {
	                    i = e;
	                    return
	                }
	                do switch (c[h >> 2] | 0) {
	                    case 69:
	                    {
	                        c[k >> 2] = 74048;
	                        break
	                    }
	                    case 33:
	                    {
	                        c[k >> 2] = 74696;
	                        break
	                    }
	                    case 55:
	                    {
	                        c[k >> 2] = 74128;
	                        break
	                    }
	                    case 34:
	                    {
	                        c[k >> 2] = 74656;
	                        break
	                    }
	                    case 71:
	                    {
	                        c[k >> 2] = 73600;
	                        break
	                    }
	                    case 89:
	                    {
	                        c[k >> 2] = 73240;
	                        break
	                    }
	                    case 52:
	                    {
	                        c[k >> 2] = 74008;
	                        break
	                    }
	                    case 19:
	                    {
	                        c[k >> 2] = 73136;
	                        break
	                    }
	                    case 67:
	                    {
	                        c[k >> 2] = 73920;
	                        break
	                    }
	                    case 79:
	                    {
	                        c[k >> 2] = 74736;
	                        break
	                    }
	                    case 38:
	                    {
	                        c[k >> 2] = 73392;
	                        break
	                    }
	                    case 82:
	                    {
	                        c[k >> 2] = 74504;
	                        break
	                    }
	                    case 50:
	                    {
	                        c[k >> 2] = 73872;
	                        break
	                    }
	                    case 73:
	                    {
	                        c[k >> 2] = 74232;
	                        break
	                    }
	                    case 18:
	                    {
	                        c[k >> 2] = 73104;
	                        break
	                    }
	                    case 80:
	                    {
	                        c[k >> 2] = 73648;
	                        break
	                    }
	                    case 49:
	                    {
	                        c[k >> 2] = 73776;
	                        break
	                    }
	                    case 44:
	                    {
	                        c[k >> 2] = 73472;
	                        break
	                    }
	                    case 85:
	                    {
	                        c[k >> 2] = 74880;
	                        break
	                    }
	                    case 4:
	                    {
	                        c[k >> 2] = 74808;
	                        break
	                    }
	                    case 48:
	                    {
	                        c[k >> 2] = 73744;
	                        break
	                    }
	                    case 84:
	                    {
	                        c[k >> 2] = 73824;
	                        break
	                    }
	                    case 46:
	                    {
	                        c[k >> 2] = 73696;
	                        break
	                    }
	                    case 110:
	                    {
	                        c[k >> 2] = 75e3;
	                        break
	                    }
	                    case 74:
	                    {
	                        c[k >> 2] = 74616;
	                        break
	                    }
	                    case 7:
	                    {
	                        c[k >> 2] = 73032;
	                        break
	                    }
	                    case 8:
	                    {
	                        c[k >> 2] = 73064;
	                        break
	                    }
	                    case 88:
	                    {
	                        c[k >> 2] = 73312;
	                        break
	                    }
	                    case 70:
	                    {
	                        c[k >> 2] = 73560;
	                        break
	                    }
	                    case 25:
	                    {
	                        c[k >> 2] = 73208;
	                        break
	                    }
	                    case 20:
	                    {
	                        c[k >> 2] = 73160;
	                        break
	                    }
	                    case 5:
	                    {
	                        c[k >> 2] = 74832;
	                        break
	                    }
	                    case 61:
	                    {
	                        c[k >> 2] = 74584;
	                        break
	                    }
	                    case 54:
	                    {
	                        c[k >> 2] = 74088;
	                        break
	                    }
	                    case 78:
	                    {
	                        c[k >> 2] = 74768;
	                        break
	                    }
	                    case 62:
	                    {
	                        c[k >> 2] = 73520;
	                        break
	                    }
	                    case 96:
	                    {
	                        c[k >> 2] = 74960;
	                        break
	                    }
	                    case 23:
	                    {
	                        c[k >> 2] = 74552;
	                        break
	                    }
	                    case 36:
	                    {
	                        c[k >> 2] = 73280;
	                        break
	                    }
	                    case 6:
	                    {
	                        c[k >> 2] = 72992;
	                        break
	                    }
	                    case 51:
	                    {
	                        c[k >> 2] = 73960;
	                        break
	                    }
	                    case 1:
	                    {
	                        c[k >> 2] = 73088;
	                        break
	                    }
	                    case 56:
	                    {
	                        c[k >> 2] = 74424;
	                        break
	                    }
	                    case 75:
	                    {
	                        c[k >> 2] = 74640;
	                        break
	                    }
	                    case 60:
	                    {
	                        c[k >> 2] = 74288;
	                        break
	                    }
	                    case 83:
	                    {
	                        c[k >> 2] = 74248;
	                        break
	                    }
	                    case 57:
	                    {
	                        c[k >> 2] = 74464;
	                        break
	                    }
	                    case 21:
	                    {
	                        c[k >> 2] = 74168;
	                        break
	                    }
	                    case 95:
	                    {
	                        c[k >> 2] = 74328;
	                        break
	                    }
	                    case 59:
	                    {
	                        c[k >> 2] = 74384;
	                        break
	                    }
	                    case 64:
	                    {
	                        c[k >> 2] = 73728;
	                        break
	                    }
	                    case 43:
	                    {
	                        c[k >> 2] = 73440;
	                        break
	                    }
	                    case 24:
	                    {
	                        c[k >> 2] = 73184;
	                        break
	                    }
	                    case 92:
	                    {
	                        c[k >> 2] = 73848;
	                        break
	                    }
	                    case 37:
	                    {
	                        c[k >> 2] = 73280;
	                        break
	                    }
	                    case 86:
	                    {
	                        c[k >> 2] = 74912;
	                        break
	                    }
	                    case 39:
	                    {
	                        c[k >> 2] = 73360;
	                        break
	                    }
	                    default:
	                        c[k >> 2] = 75040
	                } while (0);
	                d = c[k >> 2] | 0;
	                if (!(c[j >> 2] | 0)) {
	                    c[f >> 2] = d;
	                    JT(l, 128, 75072, f) | 0
	                } else {
	                    c[f >> 2] = d;
	                    JT(l, 128, 75080, f) | 0
	                }
	                if (c[g >> 2] | 0)c[(c[g >> 2] | 0) + 84 >> 2] = c[h >> 2];
	                d = c[g >> 2] | 0;
	                k = c[h >> 2] | 0;
	                h = c[j >> 2] | 0;
	                c[f >> 2] = c[j >> 2];
	                Xd(0, 0, 0, d, 0, 1, k, 3, 0, 0, h, 0, 0, 0, 0, l, f);
	                if (!(c[g >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                c[(c[g >> 2] | 0) + 12 >> 2] = 0;
	                if (c[(c[g >> 2] | 0) + 288 >> 2] | 0) {
	                    i = e;
	                    return
	                }
	                c[(c[g >> 2] | 0) + 212 >> 2] = 1;
	                i = e;
	                return
	            }

	            function pg(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if (((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 212 >> 2] | 0) != 0 : 0) ? (c[(c[h >> 2] | 0) + 172 >> 2] | 0) == -1 : 0) {
	                    i = f;
	                    return
	                }
	                if (c[h >> 2] | 0)c[(c[h >> 2] | 0) + 84 >> 2] = c[j >> 2];
	                e = c[h >> 2] | 0;
	                d = c[j >> 2] | 0;
	                j = c[l >> 2] | 0;
	                b = c[k >> 2] | 0;
	                c[g >> 2] = c[l >> 2];
	                Xd(0, 0, 0, e, 0, 1, d, 3, 0, 0, j, 0, 0, 0, 0, b, g);
	                if (!(c[h >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                c[(c[h >> 2] | 0) + 12 >> 2] = 0;
	                if (c[(c[h >> 2] | 0) + 288 >> 2] | 0) {
	                    i = f;
	                    return
	                }
	                c[(c[h >> 2] | 0) + 212 >> 2] = 1;
	                i = f;
	                return
	            }

	            function qg(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g;
	                j = g + 28 | 0;
	                k = g + 24 | 0;
	                l = g + 20 | 0;
	                m = g + 16 | 0;
	                n = g + 12 | 0;
	                o = g + 8 | 0;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = 0;
	                if (((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 212 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 172 >> 2] | 0) == -1 : 0) {
	                    i = g;
	                    return
	                }
	                if (((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 84 >> 2] = c[k >> 2], (c[c[j >> 2] >> 2] | 0) != 0) : 0) ? (c[(c[c[j >> 2] >> 2] | 0) + 108 >> 2] | 0) == -554844497 : 0)c[o >> 2] = c[(c[c[j >> 2] >> 2] | 0) + 124 >> 2];
	                f = c[o >> 2] | 0;
	                o = c[j >> 2] | 0;
	                if (c[j >> 2] | 0) {
	                    e = c[o + 112 >> 2] | 0;
	                    d = c[(c[j >> 2] | 0) + 108 >> 2] | 0;
	                    b = c[j >> 2] | 0;
	                    a = c[k >> 2] | 0;
	                    p = c[m >> 2] | 0;
	                    q = c[n >> 2] | 0;
	                    r = c[l >> 2] | 0;
	                    s = c[n >> 2] | 0;
	                    c[h >> 2] = c[m >> 2];
	                    c[h + 4 >> 2] = s;
	                    Xd(f, e, d, b, 0, 4, a, 2, 0, 0, p, q, 0, 0, 0, r, h);
	                    c[(c[j >> 2] | 0) + 100 >> 2] = 0;
	                    i = g;
	                    return
	                } else {
	                    j = c[k >> 2] | 0;
	                    k = c[m >> 2] | 0;
	                    r = c[n >> 2] | 0;
	                    q = c[l >> 2] | 0;
	                    l = c[n >> 2] | 0;
	                    c[h >> 2] = c[m >> 2];
	                    c[h + 4 >> 2] = l;
	                    Xd(f, 0, 0, o, 0, 4, j, 2, 0, 0, k, r, 0, 0, 0, q, h);
	                    i = g;
	                    return
	                }
	            }

	            function rg(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g;
	                j = g + 28 | 0;
	                k = g + 24 | 0;
	                l = g + 20 | 0;
	                m = g + 16 | 0;
	                n = g + 12 | 0;
	                o = g + 8 | 0;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = 0;
	                if (((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 212 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 172 >> 2] | 0) == -1 : 0) {
	                    i = g;
	                    return
	                }
	                if (((c[j >> 2] | 0) != 0 ? (c[c[j >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[c[j >> 2] >> 2] | 0) + 108 >> 2] | 0) == -554844497 : 0)c[o >> 2] = c[(c[c[j >> 2] >> 2] | 0) + 124 >> 2];
	                f = c[o >> 2] | 0;
	                o = c[j >> 2] | 0;
	                if (!(c[j >> 2] | 0)) {
	                    e = c[k >> 2] | 0;
	                    d = c[m >> 2] | 0;
	                    b = c[n >> 2] | 0;
	                    a = c[l >> 2] | 0;
	                    p = c[n >> 2] | 0;
	                    c[h >> 2] = c[m >> 2];
	                    c[h + 4 >> 2] = p;
	                    Xd(f, 0, 0, o, 0, 1, e, 1, 0, 0, d, b, 0, 0, 0, a, h);
	                    i = g;
	                    return
	                }
	                if (c[o >> 2] | 0)q = c[(c[c[j >> 2] >> 2] | 0) + 84 >> 2] | 0; else q = 0;
	                o = c[(c[j >> 2] | 0) + 4 >> 2] | 0;
	                a = c[j >> 2] | 0;
	                j = c[k >> 2] | 0;
	                k = c[m >> 2] | 0;
	                b = c[n >> 2] | 0;
	                d = c[l >> 2] | 0;
	                l = c[n >> 2] | 0;
	                c[h >> 2] = c[m >> 2];
	                c[h + 4 >> 2] = l;
	                Xd(f, q, o, a, 0, 1, j, 1, 0, 0, k, b, 0, 0, 0, d, h);
	                i = g;
	                return
	            }

	            function sg(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 28 | 0;
	                h = f + 24 | 0;
	                j = f + 20 | 0;
	                k = f + 16 | 0;
	                l = f + 12 | 0;
	                m = f + 8 | 0;
	                n = f + 4 | 0;
	                o = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = 0;
	                if ((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 360 >> 2] & 524288 | 0) == 0 : 0) {
	                    if ((c[(c[h >> 2] | 0) + 388 >> 2] | 0) == 89) {
	                        c[g >> 2] = 1;
	                        p = c[g >> 2] | 0;
	                        i = f;
	                        return p | 0
	                    }
	                    if (((((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 48 >> 2] | 0) != 6 : 0) ? (c[(c[k >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) ? (c[(c[k >> 2] | 0) + 72 >> 2] | 0) == 0 : 0) ? (c[n >> 2] = c[(c[h >> 2] | 0) + 440 >> 2], c[(c[k >> 2] | 0) + 72 >> 2] = 1, c[o >> 2] = af(c[h >> 2] | 0, c[(c[k >> 2] | 0) + 40 >> 2] | 0, 1, 0, 0, 0) | 0, c[(c[k >> 2] | 0) + 72 >> 2] = (c[(c[h >> 2] | 0) + 440 >> 2] | 0) - (c[n >> 2] | 0) + 1 << 1, (c[o >> 2] | 0) != 0) : 0) {
	                        if (vy(c[o >> 2] | 0, 60) | 0) {
	                            n = (c[k >> 2] | 0) + 72 | 0;
	                            c[n >> 2] = c[n >> 2] | 1
	                        }
	                        zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                        c[o >> 2] = 0
	                    }
	                    do if (c[l >> 2] | 0) {
	                        if ((c[l >> 2] | 0) >>> 0 < 1e7) {
	                            c[g >> 2] = 0;
	                            p = c[g >> 2] | 0;
	                            i = f;
	                            return p | 0
	                        }
	                        if (c[(c[h >> 2] | 0) + 36 >> 2] | 0)c[m >> 2] = (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 36 >> 2] | 0) + ((c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0));
	                        c[m >> 2] = (c[m >> 2] | 0) + (c[(c[h >> 2] | 0) + 444 >> 2] | 0);
	                        if ((c[l >> 2] | 0) >>> 0 < ((c[m >> 2] | 0) * 10 | 0) >>> 0) {
	                            c[g >> 2] = 0;
	                            p = c[g >> 2] | 0;
	                            i = f;
	                            return p | 0
	                        }
	                    } else {
	                        if (c[j >> 2] | 0) {
	                            if ((c[j >> 2] | 0) >>> 0 < 1e3) {
	                                c[g >> 2] = 0;
	                                p = c[g >> 2] | 0;
	                                i = f;
	                                return p | 0
	                            }
	                            if (c[(c[h >> 2] | 0) + 36 >> 2] | 0)c[m >> 2] = (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 36 >> 2] | 0) + ((c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0));
	                            c[m >> 2] = (c[m >> 2] | 0) + (c[(c[h >> 2] | 0) + 444 >> 2] | 0);
	                            if ((c[j >> 2] | 0) >>> 0 >= ((c[m >> 2] | 0) * 10 | 0) >>> 0)break;
	                            if (((c[(c[h >> 2] | 0) + 440 >> 2] | 0) * 3 | 0) >>> 0 >= ((c[m >> 2] | 0) * 10 | 0) >>> 0)break;
	                            c[g >> 2] = 0;
	                            p = c[g >> 2] | 0;
	                            i = f;
	                            return p | 0
	                        }
	                        if (c[k >> 2] | 0) {
	                            c[j >> 2] = (c[(c[k >> 2] | 0) + 72 >> 2] | 0) / 2 | 0;
	                            if (c[(c[h >> 2] | 0) + 36 >> 2] | 0)c[m >> 2] = (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 36 >> 2] | 0) + ((c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0));
	                            c[m >> 2] = (c[m >> 2] | 0) + (c[(c[h >> 2] | 0) + 444 >> 2] | 0);
	                            if (((c[j >> 2] | 0) * 3 | 0) >>> 0 >= ((c[m >> 2] | 0) * 10 | 0) >>> 0)break;
	                            c[g >> 2] = 0;
	                            p = c[g >> 2] | 0;
	                            i = f;
	                            return p | 0
	                        } else {
	                            if (!((c[(c[h >> 2] | 0) + 388 >> 2] | 0) != 26 ? (c[(c[h >> 2] | 0) + 388 >> 2] | 0) != 27 : 0))q = 36;
	                            if ((q | 0) == 36 ? (c[(c[h >> 2] | 0) + 440 >> 2] | 0) >>> 0 > 1e4 : 0)break;
	                            c[g >> 2] = 0;
	                            p = c[g >> 2] | 0;
	                            i = f;
	                            return p | 0
	                        }
	                    } while (0);
	                    og(c[h >> 2] | 0, 89, 0);
	                    c[g >> 2] = 1;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                c[g >> 2] = 0;
	                p = c[g >> 2] | 0;
	                i = f;
	                return p | 0
	            }

	            function tg(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function ug(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e;
	                g = e + 24 | 0;
	                h = e + 20 | 0;
	                j = e + 16 | 0;
	                k = e + 12 | 0;
	                l = e + 8 | 0;
	                m = e + 4 | 0;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (!(c[j >> 2] | 0)) {
	                    og(c[h >> 2] | 0, 1, 72912);
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                if (c[33952] | 0) {
	                    d = c[33976] | 0;
	                    b = c[33980] | 0;
	                    c[f >> 2] = c[(c[j >> 2] | 0) + 8 >> 2];
	                    Db[d & 511](b, 72952, f)
	                }
	                c[k >> 2] = ue(c[h >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                c[m >> 2] = (xy(c[(c[j >> 2] | 0) + 8 >> 2] | 0) | 0) + 5;
	                c[l >> 2] = Cb[c[135752 >> 2] & 511](c[m >> 2] | 0) | 0;
	                if (!(c[l >> 2] | 0)) {
	                    ie(c[h >> 2] | 0, 0);
	                    zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = e;
	                    return n | 0
	                } else {
	                    a[c[l >> 2] >> 0] = 32;
	                    a[(c[l >> 2] | 0) + 1 >> 0] = 37;
	                    a[(c[l >> 2] | 0) + ((c[m >> 2] | 0) - 3) >> 0] = 59;
	                    a[(c[l >> 2] | 0) + ((c[m >> 2] | 0) - 2) >> 0] = 32;
	                    a[(c[l >> 2] | 0) + ((c[m >> 2] | 0) - 1) >> 0] = 0;
	                    eU((c[l >> 2] | 0) + 2 | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0, (c[m >> 2] | 0) - 5 | 0) | 0;
	                    c[(c[k >> 2] | 0) + 40 >> 2] = 226;
	                    c[(c[k >> 2] | 0) + 12 >> 2] = c[l >> 2];
	                    c[(c[k >> 2] | 0) + 16 >> 2] = c[l >> 2];
	                    c[(c[k >> 2] | 0) + 24 >> 2] = c[m >> 2];
	                    c[(c[k >> 2] | 0) + 20 >> 2] = (c[l >> 2] | 0) + (c[m >> 2] | 0);
	                    c[g >> 2] = c[k >> 2];
	                    n = c[g >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                return 0
	            }

	            function vg(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                c[f >> 2] = (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0);
	                c[g >> 2] = (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0);
	                if ((((c[f >> 2] | 0) >>> 0 > 1e7 | (c[g >> 2] | 0) >>> 0 > 1e7 ? (c[c[(c[e >> 2] | 0) + 36 >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[c[(c[e >> 2] | 0) + 36 >> 2] >> 2] | 0) + 4 >> 2] | 0) != 227 : 0) ? (c[(c[e >> 2] | 0) + 360 >> 2] & 524288 | 0) == 0 : 0) {
	                    og(c[e >> 2] | 0, 1, 69896);
	                    c[(c[e >> 2] | 0) + 172 >> 2] = -1
	                }
	                ke(c[(c[e >> 2] | 0) + 36 >> 2] | 0, 250) | 0;
	                if (!(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) {
	                    i = b;
	                    return
	                }
	                if ((ke(c[(c[e >> 2] | 0) + 36 >> 2] | 0, 250) | 0) > 0) {
	                    i = b;
	                    return
	                }
	                Ve(c[e >> 2] | 0) | 0;
	                i = b;
	                return
	            }

	            function wg(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                b = i;
	                i = i + 32 | 0;
	                e = b + 20 | 0;
	                f = b + 16 | 0;
	                g = b + 12 | 0;
	                h = b + 8 | 0;
	                j = b + 4 | 0;
	                k = b;
	                c[f >> 2] = a;
	                c[g >> 2] = 0;
	                c[k >> 2] = 0;
	                if ((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[f >> 2] | 0);
	                if ((c[(c[f >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = b;
	                    return l | 0
	                }
	                c[j >> 2] = ne(c[f >> 2] | 0, h) | 0;
	                a = (c[j >> 2] | 0) == 32 | (c[j >> 2] | 0) == 62 | (c[j >> 2] | 0) == 47;
	                a:do if (!(c[(c[f >> 2] | 0) + 360 >> 2] & 131072)) {
	                    do if (!a) {
	                        if (((((((((((((!((c[j >> 2] | 0) >= 97 & (c[j >> 2] | 0) <= 122) ? !((c[j >> 2] | 0) >= 65 & (c[j >> 2] | 0) <= 90 | (c[j >> 2] | 0) == 95 | (c[j >> 2] | 0) == 58) : 0) ? !((c[j >> 2] | 0) >= 192 & (c[j >> 2] | 0) <= 214) : 0) ? !((c[j >> 2] | 0) >= 216 & (c[j >> 2] | 0) <= 246) : 0) ? !((c[j >> 2] | 0) >= 248 & (c[j >> 2] | 0) <= 767) : 0) ? !((c[j >> 2] | 0) >= 880 & (c[j >> 2] | 0) <= 893) : 0) ? !((c[j >> 2] | 0) >= 895 & (c[j >> 2] | 0) <= 8191) : 0) ? !((c[j >> 2] | 0) >= 8204 & (c[j >> 2] | 0) <= 8205) : 0) ? !((c[j >> 2] | 0) >= 8304 & (c[j >> 2] | 0) <= 8591) : 0) ? !((c[j >> 2] | 0) >= 11264 & (c[j >> 2] | 0) <= 12271) : 0) ? !((c[j >> 2] | 0) >= 12289 & (c[j >> 2] | 0) <= 55295) : 0) ? !((c[j >> 2] | 0) >= 63744 & (c[j >> 2] | 0) <= 64975) : 0) ? !((c[j >> 2] | 0) >= 65008 & (c[j >> 2] | 0) <= 65533) : 0) ? !((c[j >> 2] | 0) >= 65536 & (c[j >> 2] | 0) <= 983039) : 0)break;
	                        c[g >> 2] = (c[g >> 2] | 0) + (c[h >> 2] | 0);
	                        m = c[(c[f >> 2] | 0) + 36 >> 2] | 0;
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                            n = m + 28 | 0;
	                            c[n >> 2] = (c[n >> 2] | 0) + 1;
	                            c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                        } else {
	                            n = m + 32 | 0;
	                            c[n >> 2] = (c[n >> 2] | 0) + 1
	                        }
	                        n = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                        c[n >> 2] = (c[n >> 2] | 0) + (c[h >> 2] | 0);
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                        c[j >> 2] = ne(c[f >> 2] | 0, h) | 0;
	                        while (1) {
	                            if (!((c[j >> 2] | 0) != 32 & (c[j >> 2] | 0) != 62 & (c[j >> 2] | 0) != 47))break a;
	                            do if (((((((!((c[j >> 2] | 0) >= 97 & (c[j >> 2] | 0) <= 122) ? !((c[j >> 2] | 0) >= 65 & (c[j >> 2] | 0) <= 90) : 0) ? !((c[j >> 2] | 0) >= 48 & (c[j >> 2] | 0) <= 57 | (c[j >> 2] | 0) == 95 | (c[j >> 2] | 0) == 58 | (c[j >> 2] | 0) == 45 | (c[j >> 2] | 0) == 46 | (c[j >> 2] | 0) == 183) : 0) ? !((c[j >> 2] | 0) >= 192 & (c[j >> 2] | 0) <= 214) : 0) ? !((c[j >> 2] | 0) >= 216 & (c[j >> 2] | 0) <= 246) : 0) ? !((c[j >> 2] | 0) >= 248 & (c[j >> 2] | 0) <= 767) : 0) ? !((c[j >> 2] | 0) >= 768 & (c[j >> 2] | 0) <= 879) : 0) ? !((c[j >> 2] | 0) >= 880 & (c[j >> 2] | 0) <= 893) : 0) {
	                                if ((c[j >> 2] | 0) >= 895 & (c[j >> 2] | 0) <= 8191)break;
	                                if ((c[j >> 2] | 0) >= 8204 & (c[j >> 2] | 0) <= 8205)break;
	                                if ((c[j >> 2] | 0) >= 8255 & (c[j >> 2] | 0) <= 8256)break;
	                                if ((c[j >> 2] | 0) >= 8304 & (c[j >> 2] | 0) <= 8591)break;
	                                if ((c[j >> 2] | 0) >= 11264 & (c[j >> 2] | 0) <= 12271)break;
	                                if ((c[j >> 2] | 0) >= 12289 & (c[j >> 2] | 0) <= 55295)break;
	                                if ((c[j >> 2] | 0) >= 63744 & (c[j >> 2] | 0) <= 64975)break;
	                                if ((c[j >> 2] | 0) >= 65008 & (c[j >> 2] | 0) <= 65533)break;
	                                if (!((c[j >> 2] | 0) >= 65536 & (c[j >> 2] | 0) <= 983039))break a
	                            } while (0);
	                            n = c[k >> 2] | 0;
	                            c[k >> 2] = n + 1;
	                            if ((n | 0) > 100) {
	                                c[k >> 2] = 0;
	                                if ((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[f >> 2] | 0);
	                                if ((c[(c[f >> 2] | 0) + 172 >> 2] | 0) == -1)break
	                            }
	                            c[g >> 2] = (c[g >> 2] | 0) + (c[h >> 2] | 0);
	                            n = c[(c[f >> 2] | 0) + 36 >> 2] | 0;
	                            if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                                m = n + 28 | 0;
	                                c[m >> 2] = (c[m >> 2] | 0) + 1;
	                                c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                            } else {
	                                m = n + 32 | 0;
	                                c[m >> 2] = (c[m >> 2] | 0) + 1
	                            }
	                            m = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                            c[m >> 2] = (c[m >> 2] | 0) + (c[h >> 2] | 0);
	                            if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                            c[j >> 2] = ne(c[f >> 2] | 0, h) | 0
	                        }
	                        c[e >> 2] = 0;
	                        l = c[e >> 2] | 0;
	                        i = b;
	                        return l | 0
	                    } while (0);
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = b;
	                    return l | 0
	                } else {
	                    b:do if (!a) {
	                        m = c[j >> 2] | 0;
	                        if ((c[j >> 2] | 0) < 256) {
	                            if (((!(65 <= (m | 0) & (c[j >> 2] | 0) <= 90) ? !(97 <= (c[j >> 2] | 0) & (c[j >> 2] | 0) <= 122) : 0) ? !(192 <= (c[j >> 2] | 0) & (c[j >> 2] | 0) <= 214) : 0) ? !(216 <= (c[j >> 2] | 0) & (c[j >> 2] | 0) <= 246 | 248 <= (c[j >> 2] | 0)) : 0)o = 66
	                        } else if (!(DQ(m, 199744) | 0))o = 66;
	                        do if ((o | 0) == 66) {
	                            m = c[j >> 2] | 0;
	                            if ((c[j >> 2] | 0) < 256)if ((m | 0) != 95 & (c[j >> 2] | 0) != 58)break b; else break;
	                            if (!(19968 <= (m | 0) & (c[j >> 2] | 0) <= 40869 | (c[j >> 2] | 0) == 12295) ? (12321 <= (c[j >> 2] | 0) & (c[j >> 2] | 0) <= 12329 ^ 1) & (c[j >> 2] | 0) != 95 & (c[j >> 2] | 0) != 58 : 0)break b
	                        } while (0);
	                        c[g >> 2] = (c[g >> 2] | 0) + (c[h >> 2] | 0);
	                        m = c[(c[f >> 2] | 0) + 36 >> 2] | 0;
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                            n = m + 28 | 0;
	                            c[n >> 2] = (c[n >> 2] | 0) + 1;
	                            c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                        } else {
	                            n = m + 32 | 0;
	                            c[n >> 2] = (c[n >> 2] | 0) + 1
	                        }
	                        n = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                        c[n >> 2] = (c[n >> 2] | 0) + (c[h >> 2] | 0);
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                        c[j >> 2] = ne(c[f >> 2] | 0, h) | 0;
	                        while (1) {
	                            if (!((c[j >> 2] | 0) != 32 & (c[j >> 2] | 0) != 62 & (c[j >> 2] | 0) != 47))break a;
	                            n = c[j >> 2] | 0;
	                            if ((c[j >> 2] | 0) < 256) {
	                                if (((!(65 <= (n | 0) & (c[j >> 2] | 0) <= 90) ? !(97 <= (c[j >> 2] | 0) & (c[j >> 2] | 0) <= 122) : 0) ? !(192 <= (c[j >> 2] | 0) & (c[j >> 2] | 0) <= 214) : 0) ? !(216 <= (c[j >> 2] | 0) & (c[j >> 2] | 0) <= 246 | 248 <= (c[j >> 2] | 0)) : 0)o = 84
	                            } else if (!(DQ(n, 199744) | 0))o = 84;
	                            do if ((o | 0) == 84) {
	                                o = 0;
	                                if ((c[j >> 2] | 0) >= 256) {
	                                    if (19968 <= (c[j >> 2] | 0) & (c[j >> 2] | 0) <= 40869 | (c[j >> 2] | 0) == 12295)break;
	                                    if (12321 <= (c[j >> 2] | 0) & (c[j >> 2] | 0) <= 12329)break
	                                }
	                                n = c[j >> 2] | 0;
	                                if ((c[j >> 2] | 0) < 256) {
	                                    if (48 <= (n | 0) & (c[j >> 2] | 0) <= 57 | (c[j >> 2] | 0) == 46 | (c[j >> 2] | 0) == 45 | (c[j >> 2] | 0) == 95 | (c[j >> 2] | 0) == 58)break
	                                } else {
	                                    m = (DQ(n, 200216) | 0) != 0;
	                                    if (m | (c[j >> 2] | 0) == 46 | (c[j >> 2] | 0) == 45 | (c[j >> 2] | 0) == 95 | (c[j >> 2] | 0) == 58)break
	                                }
	                                if ((c[j >> 2] | 0) >= 256 ? (DQ(c[j >> 2] | 0, 200144) | 0) != 0 : 0)break;
	                                m = c[j >> 2] | 0;
	                                if ((c[j >> 2] | 0) < 256)p = (m | 0) == 183 & 1; else p = DQ(m, 200272) | 0;
	                                if (!p)break a
	                            } while (0);
	                            m = c[k >> 2] | 0;
	                            c[k >> 2] = m + 1;
	                            if ((m | 0) > 100) {
	                                c[k >> 2] = 0;
	                                if ((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[f >> 2] | 0);
	                                if ((c[(c[f >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                                    o = 101;
	                                    break
	                                }
	                            }
	                            c[g >> 2] = (c[g >> 2] | 0) + (c[h >> 2] | 0);
	                            m = c[(c[f >> 2] | 0) + 36 >> 2] | 0;
	                            if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                                n = m + 28 | 0;
	                                c[n >> 2] = (c[n >> 2] | 0) + 1;
	                                c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                            } else {
	                                n = m + 32 | 0;
	                                c[n >> 2] = (c[n >> 2] | 0) + 1
	                            }
	                            n = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                            c[n >> 2] = (c[n >> 2] | 0) + (c[h >> 2] | 0);
	                            if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                            c[j >> 2] = ne(c[f >> 2] | 0, h) | 0;
	                            if (c[j >> 2] | 0)continue;
	                            c[k >> 2] = 0;
	                            if ((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[f >> 2] | 0);
	                            if ((c[(c[f >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                                o = 112;
	                                break
	                            }
	                            c[j >> 2] = ne(c[f >> 2] | 0, h) | 0
	                        }
	                        if ((o | 0) == 101) {
	                            c[e >> 2] = 0;
	                            l = c[e >> 2] | 0;
	                            i = b;
	                            return l | 0
	                        } else if ((o | 0) == 112) {
	                            c[e >> 2] = 0;
	                            l = c[e >> 2] | 0;
	                            i = b;
	                            return l | 0
	                        }
	                    } while (0);
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = b;
	                    return l | 0
	                } while (0);
	                if ((c[g >> 2] | 0) > 5e4 ? (c[(c[f >> 2] | 0) + 360 >> 2] & 524288 | 0) == 0 : 0) {
	                    og(c[f >> 2] | 0, 110, 65688);
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = b;
	                    return l | 0
	                }
	                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10 ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + -1 >> 0] | 0 | 0) == 13 : 0) {
	                    c[e >> 2] = AP(c[(c[f >> 2] | 0) + 296 >> 2] | 0, (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + (0 - ((c[g >> 2] | 0) + 1)) | 0, c[g >> 2] | 0) | 0;
	                    l = c[e >> 2] | 0;
	                    i = b;
	                    return l | 0
	                }
	                c[e >> 2] = AP(c[(c[f >> 2] | 0) + 296 >> 2] | 0, (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + (0 - (c[g >> 2] | 0)) | 0, c[g >> 2] | 0) | 0;
	                l = c[e >> 2] | 0;
	                i = b;
	                return l | 0
	            }

	            function xg(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 212 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 172 >> 2] | 0) == -1 : 0) {
	                    i = e;
	                    return
	                }
	                if (c[g >> 2] | 0)c[(c[g >> 2] | 0) + 84 >> 2] = c[h >> 2];
	                d = c[g >> 2] | 0;
	                b = c[h >> 2] | 0;
	                c[f >> 2] = c[j >> 2];
	                Xd(0, 0, 0, d, 0, 1, b, 3, 0, 0, 0, 0, 0, 0, 0, 72848, f);
	                if (!(c[g >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                c[(c[g >> 2] | 0) + 12 >> 2] = 0;
	                if (c[(c[g >> 2] | 0) + 288 >> 2] | 0) {
	                    i = e;
	                    return
	                }
	                c[(c[g >> 2] | 0) + 212 >> 2] = 1;
	                i = e;
	                return
	            }

	            function yg(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 24 | 0;
	                m = f + 4 | 0;
	                n = f;
	                c[h >> 2] = b;
	                c[j >> 2] = e;
	                c[m >> 2] = 0;
	                c[n >> 2] = 0;
	                if ((c[j >> 2] | 0) != 0 ? (c[c[j >> 2] >> 2] | 0) != 0 : 0) {
	                    c[k >> 2] = c[c[j >> 2] >> 2];
	                    a[l >> 0] = a[c[k >> 2] >> 0] | 0;
	                    if (((d[l >> 0] | 0 | 0) == 38 ? (d[(c[k >> 2] | 0) + 1 >> 0] | 0 | 0) == 35 : 0) ? (d[(c[k >> 2] | 0) + 2 >> 0] | 0 | 0) == 120 : 0) {
	                        c[k >> 2] = (c[k >> 2] | 0) + 3;
	                        a[l >> 0] = a[c[k >> 2] >> 0] | 0;
	                        a:while (1) {
	                            if ((d[l >> 0] | 0 | 0) == 59)break;
	                            if ((d[l >> 0] | 0 | 0) >= 48 ? (d[l >> 0] | 0 | 0) <= 57 : 0)c[m >> 2] = (c[m >> 2] << 4) + ((d[l >> 0] | 0) - 48); else o = 12;
	                            do if ((o | 0) == 12) {
	                                o = 0;
	                                if ((d[l >> 0] | 0 | 0) >= 97 ? (d[l >> 0] | 0 | 0) <= 102 : 0) {
	                                    c[m >> 2] = (c[m >> 2] << 4) + ((d[l >> 0] | 0) - 97) + 10;
	                                    break
	                                }
	                                if ((d[l >> 0] | 0 | 0) < 65) {
	                                    o = 18;
	                                    break a
	                                }
	                                if ((d[l >> 0] | 0 | 0) > 70) {
	                                    o = 18;
	                                    break a
	                                }
	                                c[m >> 2] = (c[m >> 2] << 4) + ((d[l >> 0] | 0) - 65) + 10
	                            } while (0);
	                            if ((c[m >> 2] | 0) >>> 0 > 1114111)c[n >> 2] = c[m >> 2];
	                            c[k >> 2] = (c[k >> 2] | 0) + 1;
	                            a[l >> 0] = a[c[k >> 2] >> 0] | 0
	                        }
	                        if ((o | 0) == 18) {
	                            og(c[h >> 2] | 0, 6, 0);
	                            c[m >> 2] = 0
	                        }
	                        if ((d[l >> 0] | 0 | 0) == 59)c[k >> 2] = (c[k >> 2] | 0) + 1
	                    } else o = 24;
	                    do if ((o | 0) == 24) {
	                        if ((d[l >> 0] | 0 | 0) == 38 ? (d[(c[k >> 2] | 0) + 1 >> 0] | 0 | 0) == 35 : 0) {
	                            c[k >> 2] = (c[k >> 2] | 0) + 2;
	                            a[l >> 0] = a[c[k >> 2] >> 0] | 0;
	                            while (1) {
	                                if ((d[l >> 0] | 0 | 0) == 59)break;
	                                if ((d[l >> 0] | 0 | 0) < 48) {
	                                    o = 31;
	                                    break
	                                }
	                                if ((d[l >> 0] | 0 | 0) > 57) {
	                                    o = 31;
	                                    break
	                                }
	                                c[m >> 2] = ((c[m >> 2] | 0) * 10 | 0) + ((d[l >> 0] | 0) - 48);
	                                if ((c[m >> 2] | 0) >>> 0 > 1114111)c[n >> 2] = c[m >> 2];
	                                c[k >> 2] = (c[k >> 2] | 0) + 1;
	                                a[l >> 0] = a[c[k >> 2] >> 0] | 0
	                            }
	                            if ((o | 0) == 31) {
	                                og(c[h >> 2] | 0, 7, 0);
	                                c[m >> 2] = 0
	                            }
	                            if ((d[l >> 0] | 0 | 0) != 59)break;
	                            c[k >> 2] = (c[k >> 2] | 0) + 1;
	                            break
	                        }
	                        og(c[h >> 2] | 0, 8, 0);
	                        c[g >> 2] = 0;
	                        p = c[g >> 2] | 0;
	                        i = f;
	                        return p | 0
	                    } while (0);
	                    c[c[j >> 2] >> 2] = c[k >> 2];
	                    k = c[m >> 2] | 0;
	                    do if ((c[m >> 2] | 0) >>> 0 < 256)if ((9 <= k >>> 0 & (c[m >> 2] | 0) >>> 0 <= 10 | (c[m >> 2] | 0) == 13 | 32 <= (c[m >> 2] | 0) >>> 0) & (c[n >> 2] | 0) == 0)o = 43; else o = 44; else {
	                        if (!(256 <= k >>> 0 & (c[m >> 2] | 0) >>> 0 <= 55295) ? !(57344 <= (c[m >> 2] | 0) >>> 0 & (c[m >> 2] | 0) >>> 0 <= 65533) : 0)if (65536 <= (c[m >> 2] | 0) >>> 0 & (c[m >> 2] | 0) >>> 0 <= 1114111 & (c[n >> 2] | 0) == 0) {
	                            o = 43;
	                            break
	                        } else {
	                            o = 44;
	                            break
	                        }
	                        if (!(c[n >> 2] | 0))o = 43; else o = 44
	                    } while (0);
	                    if ((o | 0) == 43) {
	                        c[g >> 2] = c[m >> 2];
	                        p = c[g >> 2] | 0;
	                        i = f;
	                        return p | 0
	                    } else if ((o | 0) == 44) {
	                        ng(c[h >> 2] | 0, 9, 72856, c[m >> 2] | 0);
	                        c[g >> 2] = 0;
	                        p = c[g >> 2] | 0;
	                        i = f;
	                        return p | 0
	                    }
	                }
	                c[g >> 2] = 0;
	                p = c[g >> 2] | 0;
	                i = f;
	                return p | 0
	            }

	            function zg(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f + 24 | 0;
	                n = f;
	                c[h >> 2] = b;
	                c[j >> 2] = e;
	                c[n >> 2] = 0;
	                if ((c[j >> 2] | 0) != 0 ? (c[c[j >> 2] >> 2] | 0) != 0 : 0) {
	                    c[l >> 2] = c[c[j >> 2] >> 2];
	                    a[m >> 0] = a[c[l >> 2] >> 0] | 0;
	                    if ((d[m >> 0] | 0 | 0) != 38) {
	                        c[g >> 2] = 0;
	                        o = c[g >> 2] | 0;
	                        i = f;
	                        return o | 0
	                    }
	                    c[l >> 2] = (c[l >> 2] | 0) + 1;
	                    c[k >> 2] = Dg(c[h >> 2] | 0, l) | 0;
	                    if (!(c[k >> 2] | 0)) {
	                        xg(c[h >> 2] | 0, 68, 72152);
	                        c[c[j >> 2] >> 2] = c[l >> 2];
	                        c[g >> 2] = 0;
	                        o = c[g >> 2] | 0;
	                        i = f;
	                        return o | 0
	                    }
	                    if ((d[c[l >> 2] >> 0] | 0 | 0) != 59) {
	                        og(c[h >> 2] | 0, 23, 0);
	                        zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                        c[c[j >> 2] >> 2] = c[l >> 2];
	                        c[g >> 2] = 0;
	                        o = c[g >> 2] | 0;
	                        i = f;
	                        return o | 0
	                    }
	                    c[l >> 2] = (c[l >> 2] | 0) + 1;
	                    if ((c[(c[h >> 2] | 0) + 360 >> 2] & 1048576 | 0) == 0 ? (c[n >> 2] = Yc(c[k >> 2] | 0) | 0, (c[n >> 2] | 0) != 0) : 0) {
	                        zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                        c[c[j >> 2] >> 2] = c[l >> 2];
	                        c[g >> 2] = c[n >> 2];
	                        o = c[g >> 2] | 0;
	                        i = f;
	                        return o | 0
	                    }
	                    m = (c[h >> 2] | 0) + 440 | 0;
	                    c[m >> 2] = (c[m >> 2] | 0) + 1;
	                    if (c[c[h >> 2] >> 2] | 0) {
	                        if (c[(c[c[h >> 2] >> 2] | 0) + 20 >> 2] | 0)c[n >> 2] = Hb[c[(c[c[h >> 2] >> 2] | 0) + 20 >> 2] & 511](c[(c[h >> 2] | 0) + 4 >> 2] | 0, c[k >> 2] | 0) | 0;
	                        if ((c[n >> 2] | 0) == 0 ? (c[(c[h >> 2] | 0) + 360 >> 2] & 1048576 | 0) != 0 : 0)c[n >> 2] = Yc(c[k >> 2] | 0) | 0;
	                        if ((c[n >> 2] | 0) == 0 ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) == (c[h >> 2] | 0) : 0)c[n >> 2] = VP(c[h >> 2] | 0, c[k >> 2] | 0) | 0
	                    }
	                    if ((c[(c[h >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                        zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                        c[g >> 2] = 0;
	                        o = c[g >> 2] | 0;
	                        i = f;
	                        return o | 0
	                    }
	                    do if (c[n >> 2] | 0) {
	                        m = c[h >> 2] | 0;
	                        if ((c[(c[n >> 2] | 0) + 48 >> 2] | 0) == 3) {
	                            pg(m, 28, 68712, c[k >> 2] | 0);
	                            break
	                        }
	                        if ((c[m + 172 >> 2] | 0) == 12 ? (c[(c[n >> 2] | 0) + 48 >> 2] | 0) == 2 : 0) {
	                            pg(c[h >> 2] | 0, 29, 68752, c[k >> 2] | 0);
	                            break
	                        }
	                        if (((((c[n >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 172 >> 2] | 0) == 12 : 0) ? (c[(c[n >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) ? (c[(c[n >> 2] | 0) + 48 >> 2] | 0) != 6 : 0) ? (vy(c[(c[n >> 2] | 0) + 40 >> 2] | 0, 60) | 0) != 0 : 0) {
	                            pg(c[h >> 2] | 0, 38, 68800, c[k >> 2] | 0);
	                            break
	                        }
	                        if (((c[(c[n >> 2] | 0) + 48 >> 2] | 0) + -4 | 0) >>> 0 < 2)pg(c[h >> 2] | 0, 30, 68856, c[k >> 2] | 0)
	                    } else {
	                        do if ((c[(c[h >> 2] | 0) + 28 >> 2] | 0) == 1)p = 28; else {
	                            if ((c[(c[h >> 2] | 0) + 88 >> 2] | 0) == 0 ? (c[(c[h >> 2] | 0) + 92 >> 2] | 0) == 0 : 0) {
	                                p = 28;
	                                break
	                            }
	                            Lg(c[h >> 2] | 0, 27, 68680, c[k >> 2] | 0)
	                        } while (0);
	                        if ((p | 0) == 28)pg(c[h >> 2] | 0, 26, 68680, c[k >> 2] | 0);
	                        sg(c[h >> 2] | 0, 0, c[n >> 2] | 0, 0) | 0
	                    } while (0);
	                    zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    c[c[j >> 2] >> 2] = c[l >> 2];
	                    c[g >> 2] = c[n >> 2];
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                c[g >> 2] = 0;
	                o = c[g >> 2] | 0;
	                i = f;
	                return o | 0
	            }

	            function Ag(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 24 | 0;
	                m = f + 4 | 0;
	                n = f;
	                c[h >> 2] = b;
	                c[j >> 2] = e;
	                c[n >> 2] = 0;
	                if ((c[j >> 2] | 0) != 0 ? (c[c[j >> 2] >> 2] | 0) != 0 : 0) {
	                    c[k >> 2] = c[c[j >> 2] >> 2];
	                    a[l >> 0] = a[c[k >> 2] >> 0] | 0;
	                    if ((d[l >> 0] | 0 | 0) != 37) {
	                        c[g >> 2] = 0;
	                        o = c[g >> 2] | 0;
	                        i = f;
	                        return o | 0
	                    }
	                    c[k >> 2] = (c[k >> 2] | 0) + 1;
	                    c[m >> 2] = Dg(c[h >> 2] | 0, k) | 0;
	                    if (!(c[m >> 2] | 0)) {
	                        xg(c[h >> 2] | 0, 68, 71904);
	                        c[c[j >> 2] >> 2] = c[k >> 2];
	                        c[g >> 2] = 0;
	                        o = c[g >> 2] | 0;
	                        i = f;
	                        return o | 0
	                    }
	                    a[l >> 0] = a[c[k >> 2] >> 0] | 0;
	                    if ((d[l >> 0] | 0 | 0) != 59) {
	                        og(c[h >> 2] | 0, 23, 0);
	                        zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                        c[c[j >> 2] >> 2] = c[k >> 2];
	                        c[g >> 2] = 0;
	                        o = c[g >> 2] | 0;
	                        i = f;
	                        return o | 0
	                    }
	                    c[k >> 2] = (c[k >> 2] | 0) + 1;
	                    l = (c[h >> 2] | 0) + 440 | 0;
	                    c[l >> 2] = (c[l >> 2] | 0) + 1;
	                    if ((c[c[h >> 2] >> 2] | 0) != 0 ? (c[(c[c[h >> 2] >> 2] | 0) + 96 >> 2] | 0) != 0 : 0)c[n >> 2] = Hb[c[(c[c[h >> 2] >> 2] | 0) + 96 >> 2] & 511](c[(c[h >> 2] | 0) + 4 >> 2] | 0, c[m >> 2] | 0) | 0;
	                    if ((c[(c[h >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                        zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                        c[g >> 2] = 0;
	                        o = c[g >> 2] | 0;
	                        i = f;
	                        return o | 0
	                    }
	                    if (c[n >> 2] | 0) {
	                        if ((c[(c[n >> 2] | 0) + 48 >> 2] | 0) != 4 ? (c[(c[n >> 2] | 0) + 48 >> 2] | 0) != 5 : 0)rg(c[h >> 2] | 0, 27, 71944, c[m >> 2] | 0, 0)
	                    } else {
	                        do if ((c[(c[h >> 2] | 0) + 28 >> 2] | 0) == 1)p = 19; else {
	                            if ((c[(c[h >> 2] | 0) + 88 >> 2] | 0) == 0 ? (c[(c[h >> 2] | 0) + 92 >> 2] | 0) == 0 : 0) {
	                                p = 19;
	                                break
	                            }
	                            rg(c[h >> 2] | 0, 27, 65432, c[m >> 2] | 0, 0);
	                            c[(c[h >> 2] | 0) + 100 >> 2] = 0
	                        } while (0);
	                        if ((p | 0) == 19)pg(c[h >> 2] | 0, 26, 65432, c[m >> 2] | 0);
	                        sg(c[h >> 2] | 0, 0, 0, 0) | 0
	                    }
	                    c[(c[h >> 2] | 0) + 92 >> 2] = 1;
	                    zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                    c[c[j >> 2] >> 2] = c[k >> 2];
	                    c[g >> 2] = c[n >> 2];
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                c[g >> 2] = 0;
	                o = c[g >> 2] | 0;
	                i = f;
	                return o | 0
	            }

	            function Bg(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e;
	                g = e + 32 | 0;
	                h = e + 28 | 0;
	                j = e + 24 | 0;
	                k = e + 20 | 0;
	                l = e + 16 | 0;
	                m = e + 12 | 0;
	                n = e + 8 | 0;
	                o = e + 4 | 0;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[o >> 2] = 0;
	                do if (!((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0)) {
	                    if ((c[(c[j >> 2] | 0) + 48 >> 2] | 0) != 5 ? (c[(c[j >> 2] | 0) + 48 >> 2] | 0) != 2 : 0)break;
	                    if (!(c[(c[j >> 2] | 0) + 40 >> 2] | 0)) {
	                        if (c[33952] | 0) {
	                            b = c[33976] | 0;
	                            a = c[33980] | 0;
	                            c[f >> 2] = c[(c[j >> 2] | 0) + 8 >> 2];
	                            Db[b & 511](a, 72024, f)
	                        }
	                        c[l >> 2] = kj() | 0;
	                        a = c[h >> 2] | 0;
	                        if (!(c[l >> 2] | 0)) {
	                            og(a, 1, 71984);
	                            c[g >> 2] = -1;
	                            p = c[g >> 2] | 0;
	                            i = e;
	                            return p | 0
	                        }
	                        c[k >> 2] = we(a, c[j >> 2] | 0) | 0;
	                        a = c[h >> 2] | 0;
	                        if (!(c[k >> 2] | 0)) {
	                            og(a, 1, 72064);
	                            lj(c[l >> 2] | 0);
	                            c[g >> 2] = -1;
	                            p = c[g >> 2] | 0;
	                            i = e;
	                            return p | 0
	                        }
	                        if ((Xe(a, c[k >> 2] | 0) | 0) < 0) {
	                            lj(c[l >> 2] | 0);
	                            c[g >> 2] = -1;
	                            p = c[g >> 2] | 0;
	                            i = e;
	                            return p | 0
	                        }
	                        if ((c[(c[h >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[h >> 2] | 0);
	                        c[n >> 2] = ne(c[h >> 2] | 0, m) | 0;
	                        while (1) {
	                            if ((c[(c[h >> 2] | 0) + 36 >> 2] | 0) != (c[k >> 2] | 0)) {
	                                q = 46;
	                                break
	                            }
	                            if ((c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) >>> 0 >= (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) >>> 0) {
	                                q = 46;
	                                break
	                            }
	                            a = c[n >> 2] | 0;
	                            if ((c[n >> 2] | 0) < 256)if (9 <= (a | 0) & (c[n >> 2] | 0) <= 10 | (c[n >> 2] | 0) == 13)r = 1; else r = 32 <= (c[n >> 2] | 0); else if (!(256 <= (a | 0) & (c[n >> 2] | 0) <= 55295) ? !(57344 <= (c[n >> 2] | 0) & (c[n >> 2] | 0) <= 65533) : 0)if (65536 <= (c[n >> 2] | 0))r = (c[n >> 2] | 0) <= 1114111; else r = 0; else r = 1;
	                            if (!(r & 1)) {
	                                q = 46;
	                                break
	                            }
	                            nj(c[l >> 2] | 0, c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0, c[m >> 2] | 0) | 0;
	                            a = c[o >> 2] | 0;
	                            c[o >> 2] = a + 1;
	                            if ((a | 0) > 100) {
	                                c[o >> 2] = 0;
	                                if ((c[(c[h >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[h >> 2] | 0);
	                                if ((c[(c[h >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                                    q = 33;
	                                    break
	                                }
	                            }
	                            a = c[(c[h >> 2] | 0) + 36 >> 2] | 0;
	                            if ((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                                b = a + 28 | 0;
	                                c[b >> 2] = (c[b >> 2] | 0) + 1;
	                                c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                            } else {
	                                b = a + 32 | 0;
	                                c[b >> 2] = (c[b >> 2] | 0) + 1
	                            }
	                            b = (c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                            c[b >> 2] = (c[b >> 2] | 0) + (c[m >> 2] | 0);
	                            if ((d[c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[h >> 2] | 0);
	                            c[n >> 2] = ne(c[h >> 2] | 0, m) | 0;
	                            if (c[n >> 2] | 0)continue;
	                            c[o >> 2] = 0;
	                            do if (!(c[(c[h >> 2] | 0) + 292 >> 2] | 0)) {
	                                if (((c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) >= 250)break;
	                                vg(c[h >> 2] | 0)
	                            } while (0);
	                            if ((c[(c[h >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                                q = 44;
	                                break
	                            }
	                            c[n >> 2] = ne(c[h >> 2] | 0, m) | 0
	                        }
	                        if ((q | 0) == 33) {
	                            lj(c[l >> 2] | 0);
	                            c[g >> 2] = -1;
	                            p = c[g >> 2] | 0;
	                            i = e;
	                            return p | 0
	                        } else if ((q | 0) == 44) {
	                            lj(c[l >> 2] | 0);
	                            c[g >> 2] = -1;
	                            p = c[g >> 2] | 0;
	                            i = e;
	                            return p | 0
	                        } else if ((q | 0) == 46) {
	                            if ((c[(c[h >> 2] | 0) + 36 >> 2] | 0) == (c[k >> 2] | 0) ? (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) >>> 0 >= (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) >>> 0 : 0)Ve(c[h >> 2] | 0) | 0; else q = 49;
	                            do if ((q | 0) == 49) {
	                                b = c[n >> 2] | 0;
	                                if ((c[n >> 2] | 0) < 256) {
	                                    if (9 <= (b | 0) & (c[n >> 2] | 0) <= 10 | (c[n >> 2] | 0) == 13 | 32 <= (c[n >> 2] | 0))break
	                                } else {
	                                    if (256 <= (b | 0) & (c[n >> 2] | 0) <= 55295)break;
	                                    if (57344 <= (c[n >> 2] | 0) & (c[n >> 2] | 0) <= 65533)break;
	                                    if (65536 <= (c[n >> 2] | 0) & (c[n >> 2] | 0) <= 1114111)break
	                                }
	                                ng(c[h >> 2] | 0, 9, 72104, c[n >> 2] | 0);
	                                lj(c[l >> 2] | 0);
	                                c[g >> 2] = -1;
	                                p = c[g >> 2] | 0;
	                                i = e;
	                                return p | 0
	                            } while (0);
	                            c[(c[j >> 2] | 0) + 40 >> 2] = c[c[l >> 2] >> 2];
	                            c[c[l >> 2] >> 2] = 0;
	                            lj(c[l >> 2] | 0);
	                            c[g >> 2] = 0;
	                            p = c[g >> 2] | 0;
	                            i = e;
	                            return p | 0
	                        }
	                    }
	                } while (0);
	                og(c[h >> 2] | 0, 1, 71984);
	                c[g >> 2] = -1;
	                p = c[g >> 2] | 0;
	                i = e;
	                return p | 0
	            }

	            function Cg(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                b = c[g >> 2] | 0;
	                a:do if (!(c[(c[f >> 2] | 0) + 360 >> 2] & 131072)) {
	                    if ((b | 0) != 32 & (c[g >> 2] | 0) != 62 & (c[g >> 2] | 0) != 47) {
	                        if ((((((((((((((((!((c[g >> 2] | 0) >= 97 & (c[g >> 2] | 0) <= 122) ? !((c[g >> 2] | 0) >= 65 & (c[g >> 2] | 0) <= 90) : 0) ? !((c[g >> 2] | 0) >= 48 & (c[g >> 2] | 0) <= 57 | (c[g >> 2] | 0) == 95 | (c[g >> 2] | 0) == 58 | (c[g >> 2] | 0) == 45 | (c[g >> 2] | 0) == 46 | (c[g >> 2] | 0) == 183) : 0) ? !((c[g >> 2] | 0) >= 192 & (c[g >> 2] | 0) <= 214) : 0) ? !((c[g >> 2] | 0) >= 216 & (c[g >> 2] | 0) <= 246) : 0) ? !((c[g >> 2] | 0) >= 248 & (c[g >> 2] | 0) <= 767) : 0) ? !((c[g >> 2] | 0) >= 768 & (c[g >> 2] | 0) <= 879) : 0) ? !((c[g >> 2] | 0) >= 880 & (c[g >> 2] | 0) <= 893) : 0) ? !((c[g >> 2] | 0) >= 895 & (c[g >> 2] | 0) <= 8191) : 0) ? !((c[g >> 2] | 0) >= 8204 & (c[g >> 2] | 0) <= 8205) : 0) ? !((c[g >> 2] | 0) >= 8255 & (c[g >> 2] | 0) <= 8256) : 0) ? !((c[g >> 2] | 0) >= 8304 & (c[g >> 2] | 0) <= 8591) : 0) ? !((c[g >> 2] | 0) >= 11264 & (c[g >> 2] | 0) <= 12271) : 0) ? !((c[g >> 2] | 0) >= 12289 & (c[g >> 2] | 0) <= 55295) : 0) ? !((c[g >> 2] | 0) >= 63744 & (c[g >> 2] | 0) <= 64975) : 0) ? !((c[g >> 2] | 0) >= 65008 & (c[g >> 2] | 0) <= 65533) : 0) ? !((c[g >> 2] | 0) >= 65536 & (c[g >> 2] | 0) <= 983039) : 0)break;
	                        c[e >> 2] = 1;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                } else {
	                    a = c[g >> 2] | 0;
	                    if ((b | 0) < 256) {
	                        if (((!(65 <= (a | 0) & (c[g >> 2] | 0) <= 90) ? !(97 <= (c[g >> 2] | 0) & (c[g >> 2] | 0) <= 122) : 0) ? !(192 <= (c[g >> 2] | 0) & (c[g >> 2] | 0) <= 214) : 0) ? !(216 <= (c[g >> 2] | 0) & (c[g >> 2] | 0) <= 246 | 248 <= (c[g >> 2] | 0)) : 0)j = 27
	                    } else if (!(DQ(a, 199744) | 0))j = 27;
	                    do if ((j | 0) == 27) {
	                        if ((c[g >> 2] | 0) >= 256) {
	                            if (19968 <= (c[g >> 2] | 0) & (c[g >> 2] | 0) <= 40869 | (c[g >> 2] | 0) == 12295)break;
	                            if (12321 <= (c[g >> 2] | 0) & (c[g >> 2] | 0) <= 12329)break
	                        }
	                        a = c[g >> 2] | 0;
	                        if ((c[g >> 2] | 0) < 256) {
	                            if (48 <= (a | 0) & (c[g >> 2] | 0) <= 57 | (c[g >> 2] | 0) == 46 | (c[g >> 2] | 0) == 45 | (c[g >> 2] | 0) == 95 | (c[g >> 2] | 0) == 58)break
	                        } else {
	                            k = (DQ(a, 200216) | 0) != 0;
	                            if (k | (c[g >> 2] | 0) == 46 | (c[g >> 2] | 0) == 45 | (c[g >> 2] | 0) == 95 | (c[g >> 2] | 0) == 58)break
	                        }
	                        if ((c[g >> 2] | 0) >= 256 ? (DQ(c[g >> 2] | 0, 200144) | 0) != 0 : 0)break;
	                        k = c[g >> 2] | 0;
	                        if ((c[g >> 2] | 0) < 256)if ((k | 0) == 183)break; else break a; else if (DQ(k, 200272) | 0)break; else break a
	                    } while (0);
	                    c[e >> 2] = 1;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                } while (0);
	                c[e >> 2] = 0;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function Dg(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                e = i;
	                i = i + 160 | 0;
	                f = e + 36 | 0;
	                g = e + 32 | 0;
	                h = e + 28 | 0;
	                j = e + 40 | 0;
	                k = e + 24 | 0;
	                l = e + 20 | 0;
	                m = e + 16 | 0;
	                n = e + 12 | 0;
	                o = e + 8 | 0;
	                p = e + 4 | 0;
	                q = e;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[k >> 2] = c[c[h >> 2] >> 2];
	                c[l >> 2] = 0;
	                c[n >> 2] = oe(c[g >> 2] | 0, c[k >> 2] | 0, m) | 0;
	                if (!(kh(c[g >> 2] | 0, c[n >> 2] | 0) | 0)) {
	                    c[f >> 2] = 0;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                }
	                if ((c[m >> 2] | 0) == 1) {
	                    d = c[n >> 2] & 255;
	                    b = c[l >> 2] | 0;
	                    c[l >> 2] = b + 1;
	                    a[j + b >> 0] = d
	                } else {
	                    d = pe(j + (c[l >> 2] | 0) | 0, c[n >> 2] | 0) | 0;
	                    c[l >> 2] = (c[l >> 2] | 0) + d
	                }
	                c[k >> 2] = (c[k >> 2] | 0) + (c[m >> 2] | 0);
	                c[n >> 2] = oe(c[g >> 2] | 0, c[k >> 2] | 0, m) | 0;
	                do {
	                    if (!(Cg(c[g >> 2] | 0, c[n >> 2] | 0) | 0)) {
	                        s = 28;
	                        break
	                    }
	                    if ((c[m >> 2] | 0) == 1) {
	                        d = c[n >> 2] & 255;
	                        b = c[l >> 2] | 0;
	                        c[l >> 2] = b + 1;
	                        a[j + b >> 0] = d
	                    } else {
	                        d = pe(j + (c[l >> 2] | 0) | 0, c[n >> 2] | 0) | 0;
	                        c[l >> 2] = (c[l >> 2] | 0) + d
	                    }
	                    c[k >> 2] = (c[k >> 2] | 0) + (c[m >> 2] | 0);
	                    c[n >> 2] = oe(c[g >> 2] | 0, c[k >> 2] | 0, m) | 0
	                } while ((c[l >> 2] | 0) < 100);
	                if ((s | 0) == 28) {
	                    if ((c[l >> 2] | 0) > 5e4 ? (c[(c[g >> 2] | 0) + 360 >> 2] & 524288 | 0) == 0 : 0) {
	                        og(c[g >> 2] | 0, 110, 70920);
	                        c[f >> 2] = 0;
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    }
	                    c[c[h >> 2] >> 2] = c[k >> 2];
	                    c[f >> 2] = ly(j, c[l >> 2] | 0) | 0;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                }
	                c[p >> 2] = c[l >> 2] << 1;
	                c[o >> 2] = Cb[c[135752 >> 2] & 511](c[p >> 2] | 0) | 0;
	                if (!(c[o >> 2] | 0)) {
	                    ie(c[g >> 2] | 0, 0);
	                    c[f >> 2] = 0;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                }
	                eU(c[o >> 2] | 0, j | 0, c[l >> 2] | 0) | 0;
	                while (1) {
	                    j = (Cg(c[g >> 2] | 0, c[n >> 2] | 0) | 0) != 0;
	                    t = c[l >> 2] | 0;
	                    if (!j) {
	                        s = 27;
	                        break
	                    }
	                    if ((t + 10 | 0) > (c[p >> 2] | 0)) {
	                        if ((c[l >> 2] | 0) > 5e4 ? (c[(c[g >> 2] | 0) + 360 >> 2] & 524288 | 0) == 0 : 0) {
	                            s = 19;
	                            break
	                        }
	                        c[p >> 2] = c[p >> 2] << 1;
	                        c[q >> 2] = Hb[c[135760 >> 2] & 511](c[o >> 2] | 0, c[p >> 2] | 0) | 0;
	                        if (!(c[q >> 2] | 0)) {
	                            s = 21;
	                            break
	                        }
	                        c[o >> 2] = c[q >> 2]
	                    }
	                    if ((c[m >> 2] | 0) == 1) {
	                        j = c[n >> 2] & 255;
	                        d = c[l >> 2] | 0;
	                        c[l >> 2] = d + 1;
	                        a[(c[o >> 2] | 0) + d >> 0] = j
	                    } else {
	                        j = pe((c[o >> 2] | 0) + (c[l >> 2] | 0) | 0, c[n >> 2] | 0) | 0;
	                        c[l >> 2] = (c[l >> 2] | 0) + j
	                    }
	                    c[k >> 2] = (c[k >> 2] | 0) + (c[m >> 2] | 0);
	                    c[n >> 2] = oe(c[g >> 2] | 0, c[k >> 2] | 0, m) | 0
	                }
	                if ((s | 0) == 19) {
	                    og(c[g >> 2] | 0, 110, 70920);
	                    zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                    c[f >> 2] = 0;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                } else if ((s | 0) == 21) {
	                    ie(c[g >> 2] | 0, 0);
	                    zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                    c[f >> 2] = 0;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                } else if ((s | 0) == 27) {
	                    a[(c[o >> 2] | 0) + t >> 0] = 0;
	                    c[c[h >> 2] >> 2] = c[k >> 2];
	                    c[f >> 2] = c[o >> 2];
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                }
	                return 0
	            }

	            function Eg(b, e, f, g) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0, J = 0, K = 0, L = 0;
	                h = i;
	                i = i + 96 | 0;
	                j = h + 84 | 0;
	                k = h + 80 | 0;
	                l = h + 76 | 0;
	                m = h + 72 | 0;
	                n = h + 68 | 0;
	                o = h + 88 | 0;
	                p = h + 64 | 0;
	                q = h + 60 | 0;
	                r = h + 56 | 0;
	                s = h + 52 | 0;
	                t = h + 48 | 0;
	                u = h + 44 | 0;
	                v = h + 40 | 0;
	                w = h + 36 | 0;
	                x = h + 32 | 0;
	                y = h + 28 | 0;
	                z = h + 24 | 0;
	                A = h + 20 | 0;
	                B = h + 16 | 0;
	                C = h + 12 | 0;
	                D = h + 8 | 0;
	                E = h + 4 | 0;
	                F = h;
	                c[k >> 2] = b;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                c[n >> 2] = g;
	                a[o >> 0] = 0;
	                c[p >> 2] = 0;
	                c[t >> 2] = 0;
	                if ((c[(c[k >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[k >> 2] | 0);
	                c[p >> 2] = c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                c[u >> 2] = c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2];
	                c[v >> 2] = c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2];
	                if ((d[c[p >> 2] >> 0] | 0 | 0) != 34 ? (d[c[p >> 2] >> 0] | 0 | 0) != 39 : 0) {
	                    og(c[k >> 2] | 0, 39, 0);
	                    c[j >> 2] = 0;
	                    G = c[j >> 2] | 0;
	                    i = h;
	                    return G | 0
	                }
	                c[(c[k >> 2] | 0) + 172 >> 2] = 12;
	                g = c[p >> 2] | 0;
	                c[p >> 2] = g + 1;
	                a[o >> 0] = a[g >> 0] | 0;
	                c[v >> 2] = (c[v >> 2] | 0) + 1;
	                c[r >> 2] = c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2];
	                c[q >> 2] = c[p >> 2];
	                if ((c[p >> 2] | 0) >>> 0 >= (c[r >> 2] | 0) >>> 0) {
	                    c[w >> 2] = c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2];
	                    if ((c[(c[k >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[k >> 2] | 0);
	                    if ((c[w >> 2] | 0) != (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0)) {
	                        c[x >> 2] = (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) - (c[w >> 2] | 0);
	                        c[q >> 2] = (c[q >> 2] | 0) + (c[x >> 2] | 0);
	                        c[p >> 2] = (c[p >> 2] | 0) + (c[x >> 2] | 0)
	                    }
	                    c[r >> 2] = c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2]
	                }
	                do if (c[n >> 2] | 0) {
	                    while (1) {
	                        if ((c[p >> 2] | 0) >>> 0 >= (c[r >> 2] | 0) >>> 0) {
	                            H = 35;
	                            break
	                        }
	                        if ((d[c[p >> 2] >> 0] | 0 | 0) == (d[o >> 0] | 0 | 0)) {
	                            H = 35;
	                            break
	                        }
	                        if ((((d[c[p >> 2] >> 0] | 0 | 0) != 32 ? (d[c[p >> 2] >> 0] | 0 | 0) != 9 : 0) ? (d[c[p >> 2] >> 0] | 0 | 0) != 10 : 0) ? (d[c[p >> 2] >> 0] | 0 | 0) != 13 : 0) {
	                            H = 35;
	                            break
	                        }
	                        if ((d[c[p >> 2] >> 0] | 0 | 0) == 10) {
	                            c[u >> 2] = (c[u >> 2] | 0) + 1;
	                            c[v >> 2] = 1
	                        } else c[v >> 2] = (c[v >> 2] | 0) + 1;
	                        c[p >> 2] = (c[p >> 2] | 0) + 1;
	                        c[q >> 2] = c[p >> 2];
	                        if ((c[p >> 2] | 0) >>> 0 < (c[r >> 2] | 0) >>> 0)continue;
	                        c[y >> 2] = c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2];
	                        if ((c[(c[k >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[k >> 2] | 0);
	                        if ((c[(c[k >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                            H = 29;
	                            break
	                        }
	                        if ((c[y >> 2] | 0) != (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0)) {
	                            c[z >> 2] = (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) - (c[y >> 2] | 0);
	                            c[q >> 2] = (c[q >> 2] | 0) + (c[z >> 2] | 0);
	                            c[p >> 2] = (c[p >> 2] | 0) + (c[z >> 2] | 0)
	                        }
	                        c[r >> 2] = c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2];
	                        if (((c[p >> 2] | 0) - (c[q >> 2] | 0) | 0) <= 1e7)continue;
	                        if (!(c[(c[k >> 2] | 0) + 360 >> 2] & 524288)) {
	                            H = 34;
	                            break
	                        }
	                    }
	                    if ((H | 0) == 29) {
	                        c[j >> 2] = 0;
	                        G = c[j >> 2] | 0;
	                        i = h;
	                        return G | 0
	                    } else if ((H | 0) == 34) {
	                        xg(c[k >> 2] | 0, 40, 71720);
	                        c[j >> 2] = 0;
	                        G = c[j >> 2] | 0;
	                        i = h;
	                        return G | 0
	                    } else if ((H | 0) == 35) {
	                        while (1) {
	                            H = 0;
	                            if ((c[p >> 2] | 0) >>> 0 >= (c[r >> 2] | 0) >>> 0) {
	                                H = 54;
	                                break
	                            }
	                            if ((d[c[p >> 2] >> 0] | 0 | 0) == (d[o >> 0] | 0 | 0)) {
	                                H = 54;
	                                break
	                            }
	                            if ((d[c[p >> 2] >> 0] | 0 | 0) < 32) {
	                                H = 54;
	                                break
	                            }
	                            if ((d[c[p >> 2] >> 0] | 0 | 0) > 127) {
	                                H = 54;
	                                break
	                            }
	                            if ((d[c[p >> 2] >> 0] | 0 | 0) == 38) {
	                                H = 54;
	                                break
	                            }
	                            if ((d[c[p >> 2] >> 0] | 0 | 0) == 60) {
	                                H = 54;
	                                break
	                            }
	                            c[v >> 2] = (c[v >> 2] | 0) + 1;
	                            x = c[p >> 2] | 0;
	                            c[p >> 2] = x + 1;
	                            if ((d[x >> 0] | 0 | 0) == 32 ? (d[c[p >> 2] >> 0] | 0 | 0) == 32 : 0) {
	                                H = 54;
	                                break
	                            }
	                            if ((c[p >> 2] | 0) >>> 0 < (c[r >> 2] | 0) >>> 0) {
	                                H = 35;
	                                continue
	                            }
	                            c[A >> 2] = c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2];
	                            if ((c[(c[k >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[k >> 2] | 0);
	                            if ((c[(c[k >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                                H = 48;
	                                break
	                            }
	                            if ((c[A >> 2] | 0) != (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0)) {
	                                c[B >> 2] = (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) - (c[A >> 2] | 0);
	                                c[q >> 2] = (c[q >> 2] | 0) + (c[B >> 2] | 0);
	                                c[p >> 2] = (c[p >> 2] | 0) + (c[B >> 2] | 0)
	                            }
	                            c[r >> 2] = c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2];
	                            if (((c[p >> 2] | 0) - (c[q >> 2] | 0) | 0) <= 1e7) {
	                                H = 35;
	                                continue
	                            }
	                            if (!(c[(c[k >> 2] | 0) + 360 >> 2] & 524288)) {
	                                H = 53;
	                                break
	                            } else H = 35
	                        }
	                        if ((H | 0) == 48) {
	                            c[j >> 2] = 0;
	                            G = c[j >> 2] | 0;
	                            i = h;
	                            return G | 0
	                        } else if ((H | 0) == 53) {
	                            xg(c[k >> 2] | 0, 40, 71720);
	                            c[j >> 2] = 0;
	                            G = c[j >> 2] | 0;
	                            i = h;
	                            return G | 0
	                        } else if ((H | 0) == 54) {
	                            c[s >> 2] = c[p >> 2];
	                            while (1) {
	                                if ((d[(c[s >> 2] | 0) + -1 >> 0] | 0 | 0) != 32)break;
	                                if ((c[s >> 2] | 0) >>> 0 <= (c[q >> 2] | 0) >>> 0)break;
	                                c[s >> 2] = (c[s >> 2] | 0) + -1
	                            }
	                            while (1) {
	                                if ((c[p >> 2] | 0) >>> 0 < (c[r >> 2] | 0) >>> 0 ? (d[c[p >> 2] >> 0] | 0 | 0) != (d[o >> 0] | 0 | 0) : 0)if (((d[c[p >> 2] >> 0] | 0 | 0) != 32 ? (d[c[p >> 2] >> 0] | 0 | 0) != 9 : 0) ? (d[c[p >> 2] >> 0] | 0 | 0) != 10 : 0)I = (d[c[p >> 2] >> 0] | 0 | 0) == 13; else I = 1; else I = 0;
	                                J = c[p >> 2] | 0;
	                                if (!I) {
	                                    H = 79;
	                                    break
	                                }
	                                if ((d[J >> 0] | 0 | 0) == 10) {
	                                    c[u >> 2] = (c[u >> 2] | 0) + 1;
	                                    c[v >> 2] = 1
	                                } else c[v >> 2] = (c[v >> 2] | 0) + 1;
	                                c[p >> 2] = (c[p >> 2] | 0) + 1;
	                                if ((c[p >> 2] | 0) >>> 0 < (c[r >> 2] | 0) >>> 0)continue;
	                                c[C >> 2] = c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2];
	                                if ((c[(c[k >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[k >> 2] | 0);
	                                if ((c[(c[k >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                                    H = 73;
	                                    break
	                                }
	                                if ((c[C >> 2] | 0) != (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0)) {
	                                    c[D >> 2] = (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) - (c[C >> 2] | 0);
	                                    c[q >> 2] = (c[q >> 2] | 0) + (c[D >> 2] | 0);
	                                    c[p >> 2] = (c[p >> 2] | 0) + (c[D >> 2] | 0);
	                                    c[s >> 2] = (c[s >> 2] | 0) + (c[D >> 2] | 0)
	                                }
	                                c[r >> 2] = c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2];
	                                if (((c[p >> 2] | 0) - (c[q >> 2] | 0) | 0) <= 1e7)continue;
	                                if (!(c[(c[k >> 2] | 0) + 360 >> 2] & 524288)) {
	                                    H = 78;
	                                    break
	                                }
	                            }
	                            if ((H | 0) == 73) {
	                                c[j >> 2] = 0;
	                                G = c[j >> 2] | 0;
	                                i = h;
	                                return G | 0
	                            } else if ((H | 0) == 78) {
	                                xg(c[k >> 2] | 0, 40, 71720);
	                                c[j >> 2] = 0;
	                                G = c[j >> 2] | 0;
	                                i = h;
	                                return G | 0
	                            } else if ((H | 0) == 79) {
	                                if ((J - (c[q >> 2] | 0) | 0) > 1e7 ? (c[(c[k >> 2] | 0) + 360 >> 2] & 524288 | 0) == 0 : 0) {
	                                    xg(c[k >> 2] | 0, 40, 71720);
	                                    c[j >> 2] = 0;
	                                    G = c[j >> 2] | 0;
	                                    i = h;
	                                    return G | 0
	                                }
	                                if ((d[c[p >> 2] >> 0] | 0 | 0) != (d[o >> 0] | 0 | 0)) {
	                                    H = 113;
	                                    break
	                                } else break
	                            }
	                        }
	                    }
	                } else {
	                    while (1) {
	                        if (((((c[p >> 2] | 0) >>> 0 < (c[r >> 2] | 0) >>> 0 ? (d[c[p >> 2] >> 0] | 0 | 0) != (d[o >> 0] | 0 | 0) : 0) ? (d[c[p >> 2] >> 0] | 0 | 0) >= 32 : 0) ? (d[c[p >> 2] >> 0] | 0 | 0) <= 127 : 0) ? (d[c[p >> 2] >> 0] | 0 | 0) != 38 : 0)K = (d[c[p >> 2] >> 0] | 0 | 0) != 60; else K = 0;
	                        L = c[p >> 2] | 0;
	                        if (!K) {
	                            H = 101;
	                            break
	                        }
	                        c[p >> 2] = L + 1;
	                        c[v >> 2] = (c[v >> 2] | 0) + 1;
	                        if ((c[p >> 2] | 0) >>> 0 < (c[r >> 2] | 0) >>> 0)continue;
	                        c[E >> 2] = c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2];
	                        if ((c[(c[k >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[k >> 2] | 0);
	                        if ((c[(c[k >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                            H = 95;
	                            break
	                        }
	                        if ((c[E >> 2] | 0) != (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0)) {
	                            c[F >> 2] = (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) - (c[E >> 2] | 0);
	                            c[q >> 2] = (c[q >> 2] | 0) + (c[F >> 2] | 0);
	                            c[p >> 2] = (c[p >> 2] | 0) + (c[F >> 2] | 0)
	                        }
	                        c[r >> 2] = c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2];
	                        if (((c[p >> 2] | 0) - (c[q >> 2] | 0) | 0) <= 1e7)continue;
	                        if (!(c[(c[k >> 2] | 0) + 360 >> 2] & 524288)) {
	                            H = 100;
	                            break
	                        }
	                    }
	                    if ((H | 0) == 95) {
	                        c[j >> 2] = 0;
	                        G = c[j >> 2] | 0;
	                        i = h;
	                        return G | 0
	                    } else if ((H | 0) == 100) {
	                        xg(c[k >> 2] | 0, 40, 71720);
	                        c[j >> 2] = 0;
	                        G = c[j >> 2] | 0;
	                        i = h;
	                        return G | 0
	                    } else if ((H | 0) == 101) {
	                        c[s >> 2] = L;
	                        if (((c[p >> 2] | 0) - (c[q >> 2] | 0) | 0) > 1e7 ? (c[(c[k >> 2] | 0) + 360 >> 2] & 524288 | 0) == 0 : 0) {
	                            xg(c[k >> 2] | 0, 40, 71720);
	                            c[j >> 2] = 0;
	                            G = c[j >> 2] | 0;
	                            i = h;
	                            return G | 0
	                        }
	                        if ((d[c[p >> 2] >> 0] | 0 | 0) != (d[o >> 0] | 0 | 0)) {
	                            H = 113;
	                            break
	                        } else break
	                    }
	                } while (0);
	                if ((H | 0) == 113) {
	                    if (c[m >> 2] | 0)c[c[m >> 2] >> 2] = 1;
	                    c[j >> 2] = lh(c[k >> 2] | 0, c[l >> 2] | 0, c[n >> 2] | 0) | 0;
	                    G = c[j >> 2] | 0;
	                    i = h;
	                    return G | 0
	                }
	                c[p >> 2] = (c[p >> 2] | 0) + 1;
	                c[v >> 2] = (c[v >> 2] | 0) + 1;
	                if (c[l >> 2] | 0) {
	                    c[c[l >> 2] >> 2] = (c[s >> 2] | 0) - (c[q >> 2] | 0);
	                    c[t >> 2] = c[q >> 2]
	                } else {
	                    if (c[m >> 2] | 0)c[c[m >> 2] >> 2] = 1;
	                    c[t >> 2] = ly(c[q >> 2] | 0, (c[s >> 2] | 0) - (c[q >> 2] | 0) | 0) | 0
	                }
	                c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] = c[p >> 2];
	                c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2] = c[u >> 2];
	                c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = c[v >> 2];
	                if (c[m >> 2] | 0)c[c[m >> 2] >> 2] = 0;
	                c[j >> 2] = c[t >> 2];
	                G = c[j >> 2] | 0;
	                i = h;
	                return G | 0
	            }

	            function Fg(a) {
	                a = a | 0;
	                var b = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b;
	                c[e >> 2] = a;
	                le(c[(c[e >> 2] | 0) + 36 >> 2] | 0);
	                if (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) {
	                    i = b;
	                    return
	                }
	                if ((ke(c[(c[e >> 2] | 0) + 36 >> 2] | 0, 250) | 0) > 0) {
	                    i = b;
	                    return
	                }
	                Ve(c[e >> 2] | 0) | 0;
	                i = b;
	                return
	            }

	            function Gg(a, b, e, f) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 28 | 0;
	                j = g + 24 | 0;
	                k = g + 20 | 0;
	                l = g + 16 | 0;
	                m = g + 12 | 0;
	                n = g + 8 | 0;
	                o = g + 4 | 0;
	                p = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                if ((c[(c[c[j >> 2] >> 2] | 0) + 72 >> 2] | 0) == (c[(c[c[j >> 2] >> 2] | 0) + 68 >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    q = c[h >> 2] | 0;
	                    i = g;
	                    return q | 0
	                }
	                if (((c[(c[j >> 2] | 0) + 232 >> 2] | 0) != 0 ? (c[c[(c[j >> 2] | 0) + 232 >> 2] >> 2] | 0) != 1 : 0) ? (c[c[(c[j >> 2] | 0) + 232 >> 2] >> 2] | 0) != -2 : 0) {
	                    a:do if (!(c[m >> 2] | 0)) {
	                        c[n >> 2] = 0;
	                        b:while (1) {
	                            if ((c[n >> 2] | 0) >= (c[l >> 2] | 0))break a;
	                            do if ((d[(c[k >> 2] | 0) + (c[n >> 2] | 0) >> 0] | 0 | 0) != 32) {
	                                if (9 <= (d[(c[k >> 2] | 0) + (c[n >> 2] | 0) >> 0] | 0 | 0) ? (d[(c[k >> 2] | 0) + (c[n >> 2] | 0) >> 0] | 0 | 0) <= 10 : 0)break;
	                                if ((d[(c[k >> 2] | 0) + (c[n >> 2] | 0) >> 0] | 0 | 0) != 13)break b
	                            } while (0);
	                            c[n >> 2] = (c[n >> 2] | 0) + 1
	                        }
	                        c[h >> 2] = 0;
	                        q = c[h >> 2] | 0;
	                        i = g;
	                        return q | 0
	                    } while (0);
	                    if (!(c[(c[j >> 2] | 0) + 52 >> 2] | 0)) {
	                        c[h >> 2] = 0;
	                        q = c[h >> 2] | 0;
	                        i = g;
	                        return q | 0
	                    }
	                    if (c[(c[j >> 2] | 0) + 8 >> 2] | 0) {
	                        c[o >> 2] = Qm(c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[(c[(c[j >> 2] | 0) + 52 >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        if (!(c[o >> 2] | 0)) {
	                            c[h >> 2] = 1;
	                            q = c[h >> 2] | 0;
	                            i = g;
	                            return q | 0
	                        }
	                        if ((c[o >> 2] | 0) == 1) {
	                            c[h >> 2] = 0;
	                            q = c[h >> 2] | 0;
	                            i = g;
	                            return q | 0
	                        }
	                    }
	                    if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 60 ? (d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13 : 0) {
	                        c[h >> 2] = 0;
	                        q = c[h >> 2] | 0;
	                        i = g;
	                        return q | 0
	                    }
	                    if (((c[(c[(c[j >> 2] | 0) + 52 >> 2] | 0) + 12 >> 2] | 0) == 0 ? (d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 : 0) ? (d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 47 : 0) {
	                        c[h >> 2] = 0;
	                        q = c[h >> 2] | 0;
	                        i = g;
	                        return q | 0
	                    }
	                    c[p >> 2] = Bi(c[(c[j >> 2] | 0) + 52 >> 2] | 0) | 0;
	                    if (!(c[p >> 2] | 0)) {
	                        if ((c[(c[(c[j >> 2] | 0) + 52 >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[(c[j >> 2] | 0) + 52 >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) {
	                            c[h >> 2] = 0;
	                            q = c[h >> 2] | 0;
	                            i = g;
	                            return q | 0
	                        }
	                    } else {
	                        if (hj(c[p >> 2] | 0) | 0) {
	                            c[h >> 2] = 0;
	                            q = c[h >> 2] | 0;
	                            i = g;
	                            return q | 0
	                        }
	                        if ((c[(c[(c[j >> 2] | 0) + 52 >> 2] | 0) + 12 >> 2] | 0) != 0 ? (hj(c[(c[(c[j >> 2] | 0) + 52 >> 2] | 0) + 12 >> 2] | 0) | 0) != 0 : 0) {
	                            c[h >> 2] = 0;
	                            q = c[h >> 2] | 0;
	                            i = g;
	                            return q | 0
	                        }
	                    }
	                    c[h >> 2] = 1;
	                    q = c[h >> 2] | 0;
	                    i = g;
	                    return q | 0
	                }
	                c[h >> 2] = 0;
	                q = c[h >> 2] | 0;
	                i = g;
	                return q | 0
	            }

	            function Hg(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                f = i;
	                i = i + 336 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 24 | 0;
	                k = f + 12 | 0;
	                l = f + 8 | 0;
	                m = f + 4 | 0;
	                n = f;
	                c[g >> 2] = b;
	                c[h >> 2] = e;
	                c[k >> 2] = 0;
	                c[n >> 2] = 0;
	                if (((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 : 0) ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)Fg(c[g >> 2] | 0);
	                if ((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[g >> 2] | 0);
	                c[l >> 2] = ne(c[g >> 2] | 0, m) | 0;
	                while (1) {
	                    if (!((c[l >> 2] | 0) != 60 & (c[l >> 2] | 0) != 38)) {
	                        o = 49;
	                        break
	                    }
	                    e = c[l >> 2] | 0;
	                    if ((c[l >> 2] | 0) < 256)if (9 <= (e | 0) & (c[l >> 2] | 0) <= 10 | (c[l >> 2] | 0) == 13)p = 1; else p = 32 <= (c[l >> 2] | 0); else if (!(256 <= (e | 0) & (c[l >> 2] | 0) <= 55295) ? !(57344 <= (c[l >> 2] | 0) & (c[l >> 2] | 0) <= 65533) : 0)if (65536 <= (c[l >> 2] | 0))p = (c[l >> 2] | 0) <= 1114111; else p = 0; else p = 1;
	                    if (!(p & 1)) {
	                        o = 49;
	                        break
	                    }
	                    if (((c[l >> 2] | 0) == 93 ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 93 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 62 : 0) {
	                        if (c[h >> 2] | 0) {
	                            o = 49;
	                            break
	                        }
	                        og(c[g >> 2] | 0, 62, 0)
	                    }
	                    if ((c[m >> 2] | 0) == 1) {
	                        e = c[l >> 2] & 255;
	                        b = c[k >> 2] | 0;
	                        c[k >> 2] = b + 1;
	                        a[j + b >> 0] = e
	                    } else {
	                        e = pe(j + (c[k >> 2] | 0) | 0, c[l >> 2] | 0) | 0;
	                        c[k >> 2] = (c[k >> 2] | 0) + e
	                    }
	                    if ((c[k >> 2] | 0) >= 300) {
	                        a[j + (c[k >> 2] | 0) >> 0] = 0;
	                        do if ((c[c[g >> 2] >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 212 >> 2] | 0) == 0 : 0) {
	                            e = (Gg(c[g >> 2] | 0, j, c[k >> 2] | 0, 0) | 0) != 0;
	                            b = c[c[g >> 2] >> 2] | 0;
	                            if (e) {
	                                if (!(c[b + 72 >> 2] | 0))break;
	                                Db[c[(c[c[g >> 2] >> 2] | 0) + 72 >> 2] & 511](c[(c[g >> 2] | 0) + 4 >> 2] | 0, j, c[k >> 2] | 0);
	                                break
	                            }
	                            if (c[b + 68 >> 2] | 0)Db[c[(c[c[g >> 2] >> 2] | 0) + 68 >> 2] & 511](c[(c[g >> 2] | 0) + 4 >> 2] | 0, j, c[k >> 2] | 0);
	                            if ((c[(c[c[g >> 2] >> 2] | 0) + 68 >> 2] | 0) != (c[(c[c[g >> 2] >> 2] | 0) + 72 >> 2] | 0) ? (c[c[(c[g >> 2] | 0) + 232 >> 2] >> 2] | 0) == -1 : 0)c[c[(c[g >> 2] | 0) + 232 >> 2] >> 2] = -2
	                        } while (0);
	                        c[k >> 2] = 0;
	                        if ((c[(c[g >> 2] | 0) + 172 >> 2] | 0) != 7) {
	                            o = 71;
	                            break
	                        }
	                    }
	                    c[n >> 2] = (c[n >> 2] | 0) + 1;
	                    if ((c[n >> 2] | 0) > 50) {
	                        if ((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[g >> 2] | 0);
	                        c[n >> 2] = 0;
	                        if ((c[(c[g >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                            o = 71;
	                            break
	                        }
	                    }
	                    b = c[(c[g >> 2] | 0) + 36 >> 2] | 0;
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                        e = b + 28 | 0;
	                        c[e >> 2] = (c[e >> 2] | 0) + 1;
	                        c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                    } else {
	                        e = b + 32 | 0;
	                        c[e >> 2] = (c[e >> 2] | 0) + 1
	                    }
	                    e = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[e >> 2] = (c[e >> 2] | 0) + (c[m >> 2] | 0);
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[g >> 2] | 0);
	                    c[l >> 2] = ne(c[g >> 2] | 0, m) | 0
	                }
	                if ((o | 0) == 49) {
	                    do if (((c[k >> 2] | 0) != 0 ? (a[j + (c[k >> 2] | 0) >> 0] = 0, (c[c[g >> 2] >> 2] | 0) != 0) : 0) ? (c[(c[g >> 2] | 0) + 212 >> 2] | 0) == 0 : 0) {
	                        n = (Gg(c[g >> 2] | 0, j, c[k >> 2] | 0, 0) | 0) != 0;
	                        h = c[c[g >> 2] >> 2] | 0;
	                        if (n) {
	                            if (!(c[h + 72 >> 2] | 0))break;
	                            Db[c[(c[c[g >> 2] >> 2] | 0) + 72 >> 2] & 511](c[(c[g >> 2] | 0) + 4 >> 2] | 0, j, c[k >> 2] | 0);
	                            break
	                        }
	                        if (c[h + 68 >> 2] | 0)Db[c[(c[c[g >> 2] >> 2] | 0) + 68 >> 2] & 511](c[(c[g >> 2] | 0) + 4 >> 2] | 0, j, c[k >> 2] | 0);
	                        if ((c[(c[c[g >> 2] >> 2] | 0) + 68 >> 2] | 0) != (c[(c[c[g >> 2] >> 2] | 0) + 72 >> 2] | 0) ? (c[c[(c[g >> 2] | 0) + 232 >> 2] >> 2] | 0) == -1 : 0)c[c[(c[g >> 2] | 0) + 232 >> 2] >> 2] = -2
	                    } while (0);
	                    if (!(c[l >> 2] | 0)) {
	                        i = f;
	                        return
	                    }
	                    k = c[l >> 2] | 0;
	                    if ((c[l >> 2] | 0) < 256) {
	                        if (9 <= (k | 0) & (c[l >> 2] | 0) <= 10 | (c[l >> 2] | 0) == 13 | 32 <= (c[l >> 2] | 0)) {
	                            i = f;
	                            return
	                        }
	                    } else {
	                        if (256 <= (k | 0) & (c[l >> 2] | 0) <= 55295) {
	                            i = f;
	                            return
	                        }
	                        if (57344 <= (c[l >> 2] | 0) & (c[l >> 2] | 0) <= 65533) {
	                            i = f;
	                            return
	                        }
	                        if (65536 <= (c[l >> 2] | 0) & (c[l >> 2] | 0) <= 1114111) {
	                            i = f;
	                            return
	                        }
	                    }
	                    ng(c[g >> 2] | 0, 9, 72816, c[l >> 2] | 0);
	                    l = c[(c[g >> 2] | 0) + 36 >> 2] | 0;
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                        k = l + 28 | 0;
	                        c[k >> 2] = (c[k >> 2] | 0) + 1;
	                        c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                    } else {
	                        k = l + 32 | 0;
	                        c[k >> 2] = (c[k >> 2] | 0) + 1
	                    }
	                    k = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[k >> 2] = (c[k >> 2] | 0) + (c[m >> 2] | 0);
	                    if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 37) {
	                        i = f;
	                        return
	                    }
	                    We(c[g >> 2] | 0);
	                    i = f;
	                    return
	                } else if ((o | 0) == 71) {
	                    i = f;
	                    return
	                }
	            }

	            function Ig(b, e, f, g) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0;
	                h = i;
	                i = i + 64 | 0;
	                j = h + 52 | 0;
	                k = h + 48 | 0;
	                l = h + 44 | 0;
	                m = h + 40 | 0;
	                n = h + 36 | 0;
	                o = h + 32 | 0;
	                p = h + 28 | 0;
	                q = h + 24 | 0;
	                r = h + 20 | 0;
	                s = h + 16 | 0;
	                t = h + 12 | 0;
	                u = h + 8 | 0;
	                v = h + 4 | 0;
	                w = h;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[l >> 2] = f;
	                c[m >> 2] = g;
	                c[t >> 2] = 0;
	                c[u >> 2] = c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 56 >> 2];
	                if ((c[k >> 2] | 0) == 0 ? (c[l >> 2] = 0, c[m >> 2] = 100, c[k >> 2] = Cb[c[135752 >> 2] & 511](c[m >> 2] | 0) | 0, (c[k >> 2] | 0) == 0) : 0) {
	                    ie(c[j >> 2] | 0, 0);
	                    i = h;
	                    return
	                }
	                if ((c[(c[j >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[j >> 2] | 0);
	                c[n >> 2] = ne(c[j >> 2] | 0, o) | 0;
	                if (c[n >> 2] | 0) {
	                    g = c[n >> 2] | 0;
	                    if ((c[n >> 2] | 0) < 256) {
	                        if (!(9 <= (g | 0) & (c[n >> 2] | 0) <= 10 | (c[n >> 2] | 0) == 13 | 32 <= (c[n >> 2] | 0)))x = 13
	                    } else if ((!(256 <= (g | 0) & (c[n >> 2] | 0) <= 55295) ? !(57344 <= (c[n >> 2] | 0) & (c[n >> 2] | 0) <= 65533) : 0) ? !(65536 <= (c[n >> 2] | 0) & (c[n >> 2] | 0) <= 1114111) : 0)x = 13;
	                    if ((x | 0) == 13) {
	                        ng(c[j >> 2] | 0, 9, 72648, c[n >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                        i = h;
	                        return
	                    }
	                    g = c[(c[j >> 2] | 0) + 36 >> 2] | 0;
	                    if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                        f = g + 28 | 0;
	                        c[f >> 2] = (c[f >> 2] | 0) + 1;
	                        c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                    } else {
	                        f = g + 32 | 0;
	                        c[f >> 2] = (c[f >> 2] | 0) + 1
	                    }
	                    f = (c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[f >> 2] = (c[f >> 2] | 0) + (c[o >> 2] | 0);
	                    if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[j >> 2] | 0);
	                    c[p >> 2] = ne(c[j >> 2] | 0, q) | 0;
	                    if (c[p >> 2] | 0) {
	                        f = c[p >> 2] | 0;
	                        if ((c[p >> 2] | 0) < 256) {
	                            if (!(9 <= (f | 0) & (c[p >> 2] | 0) <= 10 | (c[p >> 2] | 0) == 13 | 32 <= (c[p >> 2] | 0)))x = 25
	                        } else if ((!(256 <= (f | 0) & (c[p >> 2] | 0) <= 55295) ? !(57344 <= (c[p >> 2] | 0) & (c[p >> 2] | 0) <= 65533) : 0) ? !(65536 <= (c[p >> 2] | 0) & (c[p >> 2] | 0) <= 1114111) : 0)x = 25;
	                        if ((x | 0) == 25) {
	                            ng(c[j >> 2] | 0, 9, 72648, c[n >> 2] | 0);
	                            zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                            i = h;
	                            return
	                        }
	                        f = c[(c[j >> 2] | 0) + 36 >> 2] | 0;
	                        if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                            g = f + 28 | 0;
	                            c[g >> 2] = (c[g >> 2] | 0) + 1;
	                            c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                        } else {
	                            g = f + 32 | 0;
	                            c[g >> 2] = (c[g >> 2] | 0) + 1
	                        }
	                        g = (c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                        c[g >> 2] = (c[g >> 2] | 0) + (c[q >> 2] | 0);
	                        if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[j >> 2] | 0);
	                        c[r >> 2] = ne(c[j >> 2] | 0, s) | 0;
	                        if (c[r >> 2] | 0) {
	                            while (1) {
	                                g = c[r >> 2] | 0;
	                                if ((c[r >> 2] | 0) < 256) {
	                                    if (!(9 <= (g | 0) & (c[r >> 2] | 0) <= 10 | (c[r >> 2] | 0) == 13 | 32 <= (c[r >> 2] | 0))) {
	                                        x = 70;
	                                        break
	                                    }
	                                } else if ((!(256 <= (g | 0) & (c[r >> 2] | 0) <= 55295) ? !(57344 <= (c[r >> 2] | 0) & (c[r >> 2] | 0) <= 65533) : 0) ? !(65536 <= (c[r >> 2] | 0) & (c[r >> 2] | 0) <= 1114111) : 0) {
	                                    x = 70;
	                                    break
	                                }
	                                if (!((c[r >> 2] | 0) != 62 | (c[p >> 2] | 0) != 45 | (c[n >> 2] | 0) != 45)) {
	                                    x = 70;
	                                    break
	                                }
	                                if ((c[p >> 2] | 0) == 45 & (c[n >> 2] | 0) == 45)og(c[j >> 2] | 0, 80, 0);
	                                if ((c[l >> 2] | 0) >>> 0 > 1e7 ? (c[(c[j >> 2] | 0) + 360 >> 2] & 524288 | 0) == 0 : 0) {
	                                    x = 42;
	                                    break
	                                }
	                                if (((c[l >> 2] | 0) + 5 | 0) >>> 0 >= (c[m >> 2] | 0) >>> 0) {
	                                    c[w >> 2] = c[m >> 2] << 1;
	                                    c[v >> 2] = Hb[c[135760 >> 2] & 511](c[k >> 2] | 0, c[w >> 2] | 0) | 0;
	                                    if (!(c[v >> 2] | 0)) {
	                                        x = 45;
	                                        break
	                                    }
	                                    c[k >> 2] = c[v >> 2];
	                                    c[m >> 2] = c[w >> 2]
	                                }
	                                if ((c[o >> 2] | 0) == 1) {
	                                    g = c[n >> 2] & 255;
	                                    f = c[l >> 2] | 0;
	                                    c[l >> 2] = f + 1;
	                                    a[(c[k >> 2] | 0) + f >> 0] = g
	                                } else {
	                                    g = pe((c[k >> 2] | 0) + (c[l >> 2] | 0) | 0, c[n >> 2] | 0) | 0;
	                                    c[l >> 2] = (c[l >> 2] | 0) + g
	                                }
	                                c[n >> 2] = c[p >> 2];
	                                c[o >> 2] = c[q >> 2];
	                                c[p >> 2] = c[r >> 2];
	                                c[q >> 2] = c[s >> 2];
	                                c[t >> 2] = (c[t >> 2] | 0) + 1;
	                                if ((c[t >> 2] | 0) >>> 0 > 50) {
	                                    do if (!(c[(c[j >> 2] | 0) + 292 >> 2] | 0)) {
	                                        if (((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) >= 250)break;
	                                        vg(c[j >> 2] | 0)
	                                    } while (0);
	                                    c[t >> 2] = 0;
	                                    if ((c[(c[j >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                                        x = 55;
	                                        break
	                                    }
	                                }
	                                g = c[(c[j >> 2] | 0) + 36 >> 2] | 0;
	                                if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                                    f = g + 28 | 0;
	                                    c[f >> 2] = (c[f >> 2] | 0) + 1;
	                                    c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                                } else {
	                                    f = g + 32 | 0;
	                                    c[f >> 2] = (c[f >> 2] | 0) + 1
	                                }
	                                f = (c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                                c[f >> 2] = (c[f >> 2] | 0) + (c[s >> 2] | 0);
	                                if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[j >> 2] | 0);
	                                c[r >> 2] = ne(c[j >> 2] | 0, s) | 0;
	                                if (c[r >> 2] | 0)continue;
	                                do if (!(c[(c[j >> 2] | 0) + 292 >> 2] | 0)) {
	                                    if (((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) <= 500)break;
	                                    if (((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) >= 500)break;
	                                    Fg(c[j >> 2] | 0)
	                                } while (0);
	                                do if (!(c[(c[j >> 2] | 0) + 292 >> 2] | 0)) {
	                                    if (((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) >= 250)break;
	                                    vg(c[j >> 2] | 0)
	                                } while (0);
	                                c[r >> 2] = ne(c[j >> 2] | 0, s) | 0
	                            }
	                            if ((x | 0) == 42) {
	                                pg(c[j >> 2] | 0, 45, 66168, 0);
	                                zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                                i = h;
	                                return
	                            } else if ((x | 0) == 45) {
	                                zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                                ie(c[j >> 2] | 0, 0);
	                                i = h;
	                                return
	                            } else if ((x | 0) == 55) {
	                                zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                                i = h;
	                                return
	                            } else if ((x | 0) == 70) {
	                                a[(c[k >> 2] | 0) + (c[l >> 2] | 0) >> 0] = 0;
	                                do if (c[r >> 2] | 0) {
	                                    l = c[r >> 2] | 0;
	                                    if ((c[r >> 2] | 0) < 256) {
	                                        if (!(9 <= (l | 0) & (c[r >> 2] | 0) <= 10 | (c[r >> 2] | 0) == 13 | 32 <= (c[r >> 2] | 0)))x = 77
	                                    } else if ((!(256 <= (l | 0) & (c[r >> 2] | 0) <= 55295) ? !(57344 <= (c[r >> 2] | 0) & (c[r >> 2] | 0) <= 65533) : 0) ? !(65536 <= (c[r >> 2] | 0) & (c[r >> 2] | 0) <= 1114111) : 0)x = 77;
	                                    if ((x | 0) == 77) {
	                                        ng(c[j >> 2] | 0, 9, 72648, c[r >> 2] | 0);
	                                        break
	                                    }
	                                    if ((c[u >> 2] | 0) != (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 56 >> 2] | 0))xg(c[j >> 2] | 0, 90, 72736);
	                                    me(c[j >> 2] | 0);
	                                    if (((c[c[j >> 2] >> 2] | 0) != 0 ? (c[(c[c[j >> 2] >> 2] | 0) + 80 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 212 >> 2] | 0) == 0 : 0)Ab[c[(c[c[j >> 2] >> 2] | 0) + 80 >> 2] & 511](c[(c[j >> 2] | 0) + 4 >> 2] | 0, c[k >> 2] | 0)
	                                } else pg(c[j >> 2] | 0, 45, 72696, c[k >> 2] | 0); while (0);
	                                zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                                i = h;
	                                return
	                            }
	                        }
	                    }
	                }
	                pg(c[j >> 2] | 0, 45, 72792, 0);
	                zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                i = h;
	                return
	            }

	            function Jg(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h;
	                k = h + 32 | 0;
	                l = h + 28 | 0;
	                m = h + 24 | 0;
	                n = h + 20 | 0;
	                o = h + 16 | 0;
	                p = h + 12 | 0;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                if (((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 212 >> 2] | 0) != 0 : 0) ? (c[(c[k >> 2] | 0) + 172 >> 2] | 0) == -1 : 0) {
	                    i = h;
	                    return
	                }
	                if (c[k >> 2] | 0)c[(c[k >> 2] | 0) + 84 >> 2] = c[l >> 2];
	                g = c[k >> 2] | 0;
	                f = c[l >> 2] | 0;
	                l = c[n >> 2] | 0;
	                e = c[o >> 2] | 0;
	                d = c[p >> 2] | 0;
	                b = c[m >> 2] | 0;
	                m = c[o >> 2] | 0;
	                o = c[p >> 2] | 0;
	                c[j >> 2] = c[n >> 2];
	                c[j + 4 >> 2] = m;
	                c[j + 8 >> 2] = o;
	                Xd(0, 0, 0, g, 0, 3, f, 2, 0, 0, l, e, d, 0, 0, b, j);
	                if (!(c[k >> 2] | 0)) {
	                    i = h;
	                    return
	                }
	                c[(c[k >> 2] | 0) + 356 >> 2] = 0;
	                i = h;
	                return
	            }

	            function Kg(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                m = f + 20 | 0;
	                c[g >> 2] = b;
	                c[h >> 2] = e;
	                c[j >> 2] = 0;
	                c[k >> 2] = c[h >> 2];
	                while (1) {
	                    do if ((d[c[k >> 2] >> 0] | 0 | 0) == 32)n = 1; else {
	                        if (9 <= (d[c[k >> 2] >> 0] | 0 | 0) ? (d[c[k >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            n = 1;
	                            break
	                        }
	                        n = (d[c[k >> 2] >> 0] | 0 | 0) == 13
	                    } while (0);
	                    o = c[k >> 2] | 0;
	                    if (!n)break;
	                    c[k >> 2] = o + 1
	                }
	                do if (!(sy(o, 72576, 7) | 0)) {
	                    c[k >> 2] = (c[k >> 2] | 0) + 7;
	                    while (1) {
	                        do if ((d[c[k >> 2] >> 0] | 0 | 0) == 32)p = 1; else {
	                            if (9 <= (d[c[k >> 2] >> 0] | 0 | 0) ? (d[c[k >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                p = 1;
	                                break
	                            }
	                            p = (d[c[k >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        q = c[k >> 2] | 0;
	                        if (!p)break;
	                        c[k >> 2] = q + 1
	                    }
	                    if ((d[q >> 0] | 0 | 0) != 61) {
	                        i = f;
	                        return
	                    }
	                    c[k >> 2] = (c[k >> 2] | 0) + 1;
	                    while (1) {
	                        do if ((d[c[k >> 2] >> 0] | 0 | 0) == 32)r = 1; else {
	                            if (9 <= (d[c[k >> 2] >> 0] | 0 | 0) ? (d[c[k >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                r = 1;
	                                break
	                            }
	                            r = (d[c[k >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        s = c[k >> 2] | 0;
	                        if (!r)break;
	                        c[k >> 2] = s + 1
	                    }
	                    a[m >> 0] = a[s >> 0] | 0;
	                    if ((d[m >> 0] | 0 | 0) != 39 ? (d[m >> 0] | 0 | 0) != 34 : 0)break;
	                    c[k >> 2] = (c[k >> 2] | 0) + 1;
	                    c[l >> 2] = c[k >> 2];
	                    while (1) {
	                        if (d[c[k >> 2] >> 0] | 0)t = (d[c[k >> 2] >> 0] | 0 | 0) != (d[m >> 0] | 0 | 0); else t = 0;
	                        u = c[k >> 2] | 0;
	                        if (!t)break;
	                        c[k >> 2] = u + 1
	                    }
	                    if (d[u >> 0] | 0) {
	                        c[j >> 2] = ly(c[l >> 2] | 0, (c[k >> 2] | 0) - (c[l >> 2] | 0) | 0) | 0;
	                        c[k >> 2] = (c[k >> 2] | 0) + 1;
	                        while (1) {
	                            do if ((d[c[k >> 2] >> 0] | 0 | 0) == 32)v = 1; else {
	                                if (9 <= (d[c[k >> 2] >> 0] | 0 | 0) ? (d[c[k >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                    v = 1;
	                                    break
	                                }
	                                v = (d[c[k >> 2] >> 0] | 0 | 0) == 13
	                            } while (0);
	                            w = c[k >> 2] | 0;
	                            if (!v)break;
	                            c[k >> 2] = w + 1
	                        }
	                        if (!(d[w >> 0] | 0)) {
	                            if (!(c[j >> 2] | 0)) {
	                                i = f;
	                                return
	                            }
	                            n = Iw(c[(c[g >> 2] | 0) + 284 >> 2] | 0, c[j >> 2] | 0) | 0;
	                            c[(c[g >> 2] | 0) + 284 >> 2] = n;
	                            zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                            i = f;
	                            return
	                        }
	                    }
	                } while (0);
	                rg(c[g >> 2] | 0, 93, 72584, c[h >> 2] | 0, 0);
	                if (!(c[j >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                i = f;
	                return
	            }

	            function Lg(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if (((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 212 >> 2] | 0) != 0 : 0) ? (c[(c[h >> 2] | 0) + 172 >> 2] | 0) == -1 : 0) {
	                    i = f;
	                    return
	                }
	                if (c[h >> 2] | 0)c[(c[h >> 2] | 0) + 84 >> 2] = c[j >> 2];
	                e = c[h >> 2] | 0;
	                h = c[j >> 2] | 0;
	                j = c[l >> 2] | 0;
	                d = c[k >> 2] | 0;
	                c[g >> 2] = c[l >> 2];
	                Xd(0, 0, 0, e, 0, 1, h, 2, 0, 0, j, 0, 0, 0, 0, d, g);
	                i = f;
	                return
	            }

	            function Mg(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 8 | 0;
	                h = f + 4 | 0;
	                j = f;
	                c[h >> 2] = b;
	                c[j >> 2] = e;
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    c[g >> 2] = 0;
	                    k = c[g >> 2] | 0;
	                    i = f;
	                    return k | 0
	                }
	                while (1) {
	                    if ((d[c[h >> 2] >> 0] | 0 | 0) != 32)break;
	                    c[h >> 2] = (c[h >> 2] | 0) + 1
	                }
	                while (1) {
	                    if (!(d[c[h >> 2] >> 0] | 0))break;
	                    if ((d[c[h >> 2] >> 0] | 0 | 0) != 32) {
	                        e = c[h >> 2] | 0;
	                        c[h >> 2] = e + 1;
	                        b = a[e >> 0] | 0;
	                        e = c[j >> 2] | 0;
	                        c[j >> 2] = e + 1;
	                        a[e >> 0] = b;
	                        continue
	                    }
	                    while (1) {
	                        l = c[h >> 2] | 0;
	                        if ((d[c[h >> 2] >> 0] | 0 | 0) != 32)break;
	                        c[h >> 2] = l + 1
	                    }
	                    if (!(d[l >> 0] | 0))continue;
	                    b = c[j >> 2] | 0;
	                    c[j >> 2] = b + 1;
	                    a[b >> 0] = 32
	                }
	                a[c[j >> 2] >> 0] = 0;
	                if ((c[j >> 2] | 0) == (c[h >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    k = c[g >> 2] | 0;
	                    i = f;
	                    return k | 0
	                } else {
	                    c[g >> 2] = c[j >> 2];
	                    k = c[g >> 2] | 0;
	                    i = f;
	                    return k | 0
	                }
	                return 0
	            }

	            function Ng(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f + 32 | 0;
	                h = f + 28 | 0;
	                j = f + 24 | 0;
	                k = f + 20 | 0;
	                l = f + 16 | 0;
	                m = f + 12 | 0;
	                n = f + 8 | 0;
	                o = f + 4 | 0;
	                p = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                if ((c[(c[g >> 2] | 0) + 352 >> 2] | 0) != 0 ? (Tj(c[(c[g >> 2] | 0) + 352 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0) != 0 : 0) {
	                    i = f;
	                    return
	                }
	                if (!((c[(c[g >> 2] | 0) + 348 >> 2] | 0) == 0 ? (e = Jj(10, c[(c[g >> 2] | 0) + 296 >> 2] | 0) | 0, c[(c[g >> 2] | 0) + 348 >> 2] = e, (c[(c[g >> 2] | 0) + 348 >> 2] | 0) == 0) : 0))q = 5;
	                do if ((q | 0) == 5) {
	                    c[n >> 2] = Dh(c[h >> 2] | 0, m) | 0;
	                    e = c[(c[g >> 2] | 0) + 296 >> 2] | 0;
	                    if (!(c[n >> 2] | 0)) {
	                        c[n >> 2] = AP(e, c[h >> 2] | 0, -1) | 0;
	                        c[o >> 2] = 0
	                    } else {
	                        c[n >> 2] = AP(e, c[n >> 2] | 0, -1) | 0;
	                        c[o >> 2] = AP(c[(c[g >> 2] | 0) + 296 >> 2] | 0, c[h >> 2] | 0, c[m >> 2] | 0) | 0
	                    }
	                    c[l >> 2] = Tj(c[(c[g >> 2] | 0) + 348 >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0) | 0;
	                    if (!(c[l >> 2] | 0)) {
	                        c[l >> 2] = Cb[c[135744 >> 2] & 511](108) | 0;
	                        if (!(c[l >> 2] | 0))break;
	                        c[c[l >> 2] >> 2] = 0;
	                        c[(c[l >> 2] | 0) + 4 >> 2] = 4;
	                        if ((Qj(c[(c[g >> 2] | 0) + 348 >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, c[l >> 2] | 0, 0) | 0) < 0) {
	                            zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                            break
	                        }
	                    } else if ((c[c[l >> 2] >> 2] | 0) >= (c[(c[l >> 2] | 0) + 4 >> 2] | 0)) {
	                        c[p >> 2] = Hb[c[135760 >> 2] & 511](c[l >> 2] | 0, 28 + ((c[(c[l >> 2] | 0) + 4 >> 2] << 1) * 5 << 2) | 0) | 0;
	                        if (!(c[p >> 2] | 0))break;
	                        c[l >> 2] = c[p >> 2];
	                        e = (c[l >> 2] | 0) + 4 | 0;
	                        c[e >> 2] = c[e >> 2] << 1;
	                        if ((Qj(c[(c[g >> 2] | 0) + 348 >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, c[l >> 2] | 0, 0) | 0) < 0) {
	                            zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                            break
	                        }
	                    }
	                    c[n >> 2] = Dh(c[j >> 2] | 0, m) | 0;
	                    e = c[(c[g >> 2] | 0) + 296 >> 2] | 0;
	                    if (!(c[n >> 2] | 0)) {
	                        c[n >> 2] = AP(e, c[j >> 2] | 0, -1) | 0;
	                        c[o >> 2] = 0
	                    } else {
	                        c[n >> 2] = AP(e, c[n >> 2] | 0, -1) | 0;
	                        c[o >> 2] = AP(c[(c[g >> 2] | 0) + 296 >> 2] | 0, c[j >> 2] | 0, c[m >> 2] | 0) | 0
	                    }
	                    c[(c[l >> 2] | 0) + 8 + ((c[c[l >> 2] >> 2] | 0) * 5 << 2) >> 2] = c[n >> 2];
	                    c[(c[l >> 2] | 0) + 8 + (((c[c[l >> 2] >> 2] | 0) * 5 | 0) + 1 << 2) >> 2] = c[o >> 2];
	                    c[m >> 2] = xy(c[k >> 2] | 0) | 0;
	                    c[k >> 2] = AP(c[(c[g >> 2] | 0) + 296 >> 2] | 0, c[k >> 2] | 0, c[m >> 2] | 0) | 0;
	                    c[(c[l >> 2] | 0) + 8 + (((c[c[l >> 2] >> 2] | 0) * 5 | 0) + 2 << 2) >> 2] = c[k >> 2];
	                    c[(c[l >> 2] | 0) + 8 + (((c[c[l >> 2] >> 2] | 0) * 5 | 0) + 3 << 2) >> 2] = (c[k >> 2] | 0) + (c[m >> 2] | 0);
	                    e = (c[l >> 2] | 0) + 8 + (((c[c[l >> 2] >> 2] | 0) * 5 | 0) + 4 << 2) | 0;
	                    if (c[(c[g >> 2] | 0) + 96 >> 2] | 0)c[e >> 2] = 72560; else c[e >> 2] = 0;
	                    e = c[l >> 2] | 0;
	                    c[e >> 2] = (c[e >> 2] | 0) + 1;
	                    i = f;
	                    return
	                } while (0);
	                ie(c[g >> 2] | 0, 0);
	                i = f;
	                return
	            }

	            function Og(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 12 | 0;
	                h = f + 8 | 0;
	                j = f + 4 | 0;
	                k = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                if ((c[(c[g >> 2] | 0) + 352 >> 2] | 0) == 0 ? (e = Jj(10, c[(c[g >> 2] | 0) + 296 >> 2] | 0) | 0, c[(c[g >> 2] | 0) + 352 >> 2] = e, (c[(c[g >> 2] | 0) + 352 >> 2] | 0) == 0) : 0) {
	                    ie(c[g >> 2] | 0, 0);
	                    i = f;
	                    return
	                }
	                if (Tj(c[(c[g >> 2] | 0) + 352 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0) {
	                    i = f;
	                    return
	                }
	                Nj(c[(c[g >> 2] | 0) + 352 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                i = f;
	                return
	            }

	            function Pg(b, e, f) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0;
	                g = i;
	                i = i + 64 | 0;
	                h = g + 44 | 0;
	                j = g + 40 | 0;
	                k = g + 36 | 0;
	                l = g + 32 | 0;
	                m = g + 28 | 0;
	                n = g + 24 | 0;
	                o = g + 20 | 0;
	                p = g + 16 | 0;
	                q = g + 12 | 0;
	                r = g + 48 | 0;
	                s = g + 8 | 0;
	                t = g + 4 | 0;
	                u = g;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[l >> 2] = f;
	                c[m >> 2] = 0;
	                c[n >> 2] = 0;
	                c[o >> 2] = 0;
	                c[p >> 2] = 0;
	                a[r >> 0] = 0;
	                if ((c[l >> 2] | 0) > 128) {
	                    if ((c[l >> 2] | 0) > 2048 ? 1 : (c[(c[j >> 2] | 0) + 360 >> 2] & 524288 | 0) == 0)v = 4
	                } else if ((c[l >> 2] | 0) > 2048)v = 4;
	                if ((v | 0) == 4) {
	                    ng(c[j >> 2] | 0, 55, 72424, c[l >> 2] | 0);
	                    c[h >> 2] = 0;
	                    w = c[h >> 2] | 0;
	                    i = g;
	                    return w | 0
	                }
	                Ue(c[j >> 2] | 0) | 0;
	                if ((c[(c[j >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[j >> 2] | 0);
	                f = c[j >> 2] | 0;
	                if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 40) {
	                    c[s >> 2] = c[(c[f + 36 >> 2] | 0) + 56 >> 2];
	                    me(c[j >> 2] | 0);
	                    Ue(c[j >> 2] | 0) | 0;
	                    e = Pg(c[j >> 2] | 0, c[s >> 2] | 0, (c[l >> 2] | 0) + 1 | 0) | 0;
	                    c[m >> 2] = e;
	                    c[n >> 2] = e;
	                    Ue(c[j >> 2] | 0) | 0;
	                    if ((c[(c[j >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[j >> 2] | 0)
	                } else {
	                    c[q >> 2] = Ze(f) | 0;
	                    f = c[j >> 2] | 0;
	                    if (!(c[q >> 2] | 0)) {
	                        og(f, 54, 0);
	                        c[h >> 2] = 0;
	                        w = c[h >> 2] | 0;
	                        i = g;
	                        return w | 0
	                    }
	                    e = im(c[f + 8 >> 2] | 0, c[q >> 2] | 0, 2) | 0;
	                    c[m >> 2] = e;
	                    c[n >> 2] = e;
	                    e = c[j >> 2] | 0;
	                    if (!(c[n >> 2] | 0)) {
	                        ie(e, 0);
	                        c[h >> 2] = 0;
	                        w = c[h >> 2] | 0;
	                        i = g;
	                        return w | 0
	                    }
	                    if ((c[e + 292 >> 2] | 0) == 0 ? ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[j >> 2] | 0);
	                    do if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 63) {
	                        if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 42) {
	                            c[(c[n >> 2] | 0) + 4 >> 2] = 3;
	                            me(c[j >> 2] | 0);
	                            break
	                        }
	                        e = (c[n >> 2] | 0) + 4 | 0;
	                        if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 43) {
	                            c[e >> 2] = 4;
	                            me(c[j >> 2] | 0);
	                            break
	                        } else {
	                            c[e >> 2] = 1;
	                            break
	                        }
	                    } else {
	                        c[(c[n >> 2] | 0) + 4 >> 2] = 2;
	                        me(c[j >> 2] | 0)
	                    } while (0);
	                    if ((c[(c[j >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[j >> 2] | 0)
	                }
	                Ue(c[j >> 2] | 0) | 0;
	                if (((c[(c[j >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 : 0) ? ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)Fg(c[j >> 2] | 0);
	                a:while (1) {
	                    if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 41) {
	                        v = 117;
	                        break
	                    }
	                    if ((c[(c[j >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                        v = 117;
	                        break
	                    }
	                    do if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 44) {
	                        if (d[r >> 0] | 0) {
	                            if ((d[r >> 0] | 0 | 0) != (d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0)) {
	                                v = 39;
	                                break a
	                            }
	                        } else a[r >> 0] = a[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                        me(c[j >> 2] | 0);
	                        c[p >> 2] = im(c[(c[j >> 2] | 0) + 8 >> 2] | 0, 0, 3) | 0;
	                        x = c[o >> 2] | 0;
	                        if (!(c[p >> 2] | 0)) {
	                            v = 46;
	                            break a
	                        }
	                        if (!x) {
	                            c[(c[p >> 2] | 0) + 12 >> 2] = c[m >> 2];
	                            if (c[m >> 2] | 0)c[(c[m >> 2] | 0) + 20 >> 2] = c[p >> 2];
	                            e = c[p >> 2] | 0;
	                            c[n >> 2] = e;
	                            c[m >> 2] = e;
	                            break
	                        }
	                        c[(c[n >> 2] | 0) + 16 >> 2] = c[p >> 2];
	                        if (c[p >> 2] | 0)c[(c[p >> 2] | 0) + 20 >> 2] = c[n >> 2];
	                        c[(c[p >> 2] | 0) + 12 >> 2] = c[o >> 2];
	                        if (c[o >> 2] | 0)c[(c[o >> 2] | 0) + 20 >> 2] = c[p >> 2];
	                        c[n >> 2] = c[p >> 2];
	                        c[o >> 2] = 0
	                    } else {
	                        if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 124) {
	                            v = 85;
	                            break a
	                        }
	                        if (d[r >> 0] | 0) {
	                            if ((d[r >> 0] | 0 | 0) != (d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0)) {
	                                v = 63;
	                                break a
	                            }
	                        } else a[r >> 0] = a[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                        me(c[j >> 2] | 0);
	                        c[p >> 2] = im(c[(c[j >> 2] | 0) + 8 >> 2] | 0, 0, 4) | 0;
	                        y = c[o >> 2] | 0;
	                        if (!(c[p >> 2] | 0)) {
	                            v = 70;
	                            break a
	                        }
	                        if (!y) {
	                            c[(c[p >> 2] | 0) + 12 >> 2] = c[m >> 2];
	                            if (c[m >> 2] | 0)c[(c[m >> 2] | 0) + 20 >> 2] = c[p >> 2];
	                            e = c[p >> 2] | 0;
	                            c[n >> 2] = e;
	                            c[m >> 2] = e;
	                            break
	                        }
	                        c[(c[n >> 2] | 0) + 16 >> 2] = c[p >> 2];
	                        if (c[p >> 2] | 0)c[(c[p >> 2] | 0) + 20 >> 2] = c[n >> 2];
	                        c[(c[p >> 2] | 0) + 12 >> 2] = c[o >> 2];
	                        if (c[o >> 2] | 0)c[(c[o >> 2] | 0) + 20 >> 2] = c[p >> 2];
	                        c[n >> 2] = c[p >> 2];
	                        c[o >> 2] = 0
	                    } while (0);
	                    if ((c[(c[j >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[j >> 2] | 0);
	                    Ue(c[j >> 2] | 0) | 0;
	                    if ((c[(c[j >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[j >> 2] | 0);
	                    e = c[j >> 2] | 0;
	                    do if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 40) {
	                        c[q >> 2] = Ze(e) | 0;
	                        z = c[j >> 2] | 0;
	                        if (!(c[q >> 2] | 0)) {
	                            v = 100;
	                            break a
	                        }
	                        c[o >> 2] = im(c[z + 8 >> 2] | 0, c[q >> 2] | 0, 2) | 0;
	                        if (!(c[o >> 2] | 0)) {
	                            v = 104;
	                            break a
	                        }
	                        if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 63) {
	                            c[(c[o >> 2] | 0) + 4 >> 2] = 2;
	                            me(c[j >> 2] | 0);
	                            break
	                        }
	                        if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 42) {
	                            c[(c[o >> 2] | 0) + 4 >> 2] = 3;
	                            me(c[j >> 2] | 0);
	                            break
	                        }
	                        f = (c[o >> 2] | 0) + 4 | 0;
	                        if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 43) {
	                            c[f >> 2] = 4;
	                            me(c[j >> 2] | 0);
	                            break
	                        } else {
	                            c[f >> 2] = 1;
	                            break
	                        }
	                    } else {
	                        c[t >> 2] = c[(c[e + 36 >> 2] | 0) + 56 >> 2];
	                        me(c[j >> 2] | 0);
	                        Ue(c[j >> 2] | 0) | 0;
	                        c[o >> 2] = Pg(c[j >> 2] | 0, c[t >> 2] | 0, (c[l >> 2] | 0) + 1 | 0) | 0;
	                        Ue(c[j >> 2] | 0) | 0
	                    } while (0);
	                    Ue(c[j >> 2] | 0) | 0;
	                    if (c[(c[j >> 2] | 0) + 292 >> 2] | 0)continue;
	                    if (((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) >= 250)continue;
	                    vg(c[j >> 2] | 0)
	                }
	                if ((v | 0) == 39) {
	                    ng(c[j >> 2] | 0, 66, 72504, d[r >> 0] | 0);
	                    if ((c[o >> 2] | 0) != 0 ? (c[o >> 2] | 0) != (c[m >> 2] | 0) : 0)lm(c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[o >> 2] | 0);
	                    if (c[m >> 2] | 0)lm(c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[m >> 2] | 0);
	                    c[h >> 2] = 0;
	                    w = c[h >> 2] | 0;
	                    i = g;
	                    return w | 0
	                } else if ((v | 0) == 46) {
	                    if ((x | 0) != 0 ? (c[o >> 2] | 0) != (c[m >> 2] | 0) : 0)lm(c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[o >> 2] | 0);
	                    lm(c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[m >> 2] | 0);
	                    c[h >> 2] = 0;
	                    w = c[h >> 2] | 0;
	                    i = g;
	                    return w | 0
	                } else if ((v | 0) == 63) {
	                    ng(c[j >> 2] | 0, 66, 72504, d[r >> 0] | 0);
	                    if ((c[o >> 2] | 0) != 0 ? (c[o >> 2] | 0) != (c[m >> 2] | 0) : 0)lm(c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[o >> 2] | 0);
	                    if (c[m >> 2] | 0)lm(c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[m >> 2] | 0);
	                    c[h >> 2] = 0;
	                    w = c[h >> 2] | 0;
	                    i = g;
	                    return w | 0
	                } else if ((v | 0) == 70) {
	                    if ((y | 0) != 0 ? (c[o >> 2] | 0) != (c[m >> 2] | 0) : 0)lm(c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[o >> 2] | 0);
	                    if (c[m >> 2] | 0)lm(c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[m >> 2] | 0);
	                    c[h >> 2] = 0;
	                    w = c[h >> 2] | 0;
	                    i = g;
	                    return w | 0
	                } else if ((v | 0) == 85) {
	                    og(c[j >> 2] | 0, 55, 0);
	                    if ((c[o >> 2] | 0) != 0 ? (c[o >> 2] | 0) != (c[m >> 2] | 0) : 0)lm(c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[o >> 2] | 0);
	                    if (c[m >> 2] | 0)lm(c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[m >> 2] | 0);
	                    c[h >> 2] = 0;
	                    w = c[h >> 2] | 0;
	                    i = g;
	                    return w | 0
	                } else if ((v | 0) == 100) {
	                    og(z, 54, 0);
	                    if (c[m >> 2] | 0)lm(c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[m >> 2] | 0);
	                    c[h >> 2] = 0;
	                    w = c[h >> 2] | 0;
	                    i = g;
	                    return w | 0
	                } else if ((v | 0) == 104) {
	                    if (c[m >> 2] | 0)lm(c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[m >> 2] | 0);
	                    c[h >> 2] = 0;
	                    w = c[h >> 2] | 0;
	                    i = g;
	                    return w | 0
	                } else if ((v | 0) == 117) {
	                    if ((c[n >> 2] | 0) != 0 & (c[o >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 16 >> 2] = c[o >> 2], (c[o >> 2] | 0) != 0) : 0)c[(c[o >> 2] | 0) + 20 >> 2] = c[n >> 2];
	                    if ((c[(c[j >> 2] | 0) + 104 >> 2] | 0) != 0 ? (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 56 >> 2] | 0) != (c[k >> 2] | 0) : 0)qg(c[j >> 2] | 0, 90, 67976, 0, 0);
	                    me(c[j >> 2] | 0);
	                    do if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 63) {
	                        if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 42) {
	                            b:do if (c[m >> 2] | 0) {
	                                c[(c[m >> 2] | 0) + 4 >> 2] = 3;
	                                c[n >> 2] = c[m >> 2];
	                                while (1) {
	                                    if (!(c[n >> 2] | 0))break b;
	                                    if ((c[c[n >> 2] >> 2] | 0) != 4)break b;
	                                    do if (c[(c[n >> 2] | 0) + 12 >> 2] | 0) {
	                                        if ((c[(c[(c[n >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) != 2 ? (c[(c[(c[n >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) != 3 : 0)break;
	                                        c[(c[(c[n >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 1
	                                    } while (0);
	                                    do if (c[(c[n >> 2] | 0) + 16 >> 2] | 0) {
	                                        if ((c[(c[(c[n >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) != 2 ? (c[(c[(c[n >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) != 3 : 0)break;
	                                        c[(c[(c[n >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] = 1
	                                    } while (0);
	                                    c[n >> 2] = c[(c[n >> 2] | 0) + 16 >> 2]
	                                }
	                            } while (0);
	                            me(c[j >> 2] | 0);
	                            break
	                        }
	                        if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 43) {
	                            if (c[m >> 2] | 0) {
	                                c[u >> 2] = 0;
	                                if ((c[(c[m >> 2] | 0) + 4 >> 2] | 0) != 2 ? (c[(c[m >> 2] | 0) + 4 >> 2] | 0) != 3 : 0)c[(c[m >> 2] | 0) + 4 >> 2] = 4; else c[(c[m >> 2] | 0) + 4 >> 2] = 3;
	                                while (1) {
	                                    if (!(c[n >> 2] | 0))break;
	                                    if ((c[c[n >> 2] >> 2] | 0) != 4)break;
	                                    do if (c[(c[n >> 2] | 0) + 12 >> 2] | 0) {
	                                        if ((c[(c[(c[n >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) != 2 ? (c[(c[(c[n >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) != 3 : 0)break;
	                                        c[(c[(c[n >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] = 1;
	                                        c[u >> 2] = 1
	                                    } while (0);
	                                    do if (c[(c[n >> 2] | 0) + 16 >> 2] | 0) {
	                                        if ((c[(c[(c[n >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) != 2 ? (c[(c[(c[n >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) != 3 : 0)break;
	                                        c[(c[(c[n >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] = 1;
	                                        c[u >> 2] = 1
	                                    } while (0);
	                                    c[n >> 2] = c[(c[n >> 2] | 0) + 16 >> 2]
	                                }
	                                if (c[u >> 2] | 0)c[(c[m >> 2] | 0) + 4 >> 2] = 3
	                            }
	                            me(c[j >> 2] | 0)
	                        }
	                    } else {
	                        do if (c[m >> 2] | 0) {
	                            if ((c[(c[m >> 2] | 0) + 4 >> 2] | 0) != 4 ? (c[(c[m >> 2] | 0) + 4 >> 2] | 0) != 3 : 0) {
	                                c[(c[m >> 2] | 0) + 4 >> 2] = 2;
	                                break
	                            }
	                            c[(c[m >> 2] | 0) + 4 >> 2] = 3
	                        } while (0);
	                        me(c[j >> 2] | 0)
	                    } while (0);
	                    c[h >> 2] = c[m >> 2];
	                    w = c[h >> 2] | 0;
	                    i = g;
	                    return w | 0
	                }
	                return 0
	            }

	            function Qg(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                b = i;
	                i = i + 48 | 0;
	                e = b;
	                f = b + 32 | 0;
	                g = b + 28 | 0;
	                h = b + 24 | 0;
	                j = b + 20 | 0;
	                k = b + 16 | 0;
	                l = b + 12 | 0;
	                m = b + 8 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 56 >> 2];
	                a = (c[f >> 2] | 0) + 200 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + 3;
	                a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + 3;
	                a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + 3;
	                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[f >> 2] | 0) | 0;
	                Ue(c[f >> 2] | 0) | 0;
	                if (((((((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 73 ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 78 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 67 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 76 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) == 85 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) == 68 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 6 >> 0] | 0 | 0) == 69 : 0) {
	                    a = (c[f >> 2] | 0) + 200 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 7;
	                    a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 7;
	                    a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 7;
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[f >> 2] | 0) | 0;
	                    Ue(c[f >> 2] | 0) | 0;
	                    a = c[f >> 2] | 0;
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 91)og(a, 83, 0); else {
	                        if ((c[(c[a + 36 >> 2] | 0) + 56 >> 2] | 0) != (c[g >> 2] | 0))qg(c[f >> 2] | 0, 90, 72192, 0, 0);
	                        me(c[f >> 2] | 0)
	                    }
	                    if (c[33952] | 0) {
	                        if ((c[(c[f >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                            a = c[33976] | 0;
	                            n = c[33980] | 0;
	                            o = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2] | 0;
	                            c[e >> 2] = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2];
	                            c[e + 4 >> 2] = o;
	                            Db[a & 511](n, 65312, e)
	                        }
	                        Db[c[135904 >> 2] & 511](c[33980] | 0, 72264, e)
	                    }
	                    while (1) {
	                        if (!(d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0))break;
	                        if (((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 93 ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 93 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 62 : 0)break;
	                        if ((c[(c[f >> 2] | 0) + 172 >> 2] | 0) == -1)break;
	                        c[h >> 2] = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                        c[j >> 2] = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 36 >> 2];
	                        do if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60) {
	                            if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) != 33) {
	                                p = 37;
	                                break
	                            }
	                            if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) != 91) {
	                                p = 37;
	                                break
	                            }
	                            Qg(c[f >> 2] | 0)
	                        } else p = 37; while (0);
	                        a:do if ((p | 0) == 37) {
	                            p = 0;
	                            do if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32) {
	                                if (9 <= (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 13)break;
	                                n = c[f >> 2] | 0;
	                                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37) {
	                                    zf(n);
	                                    break a
	                                } else {
	                                    yf(n);
	                                    break a
	                                }
	                            } while (0);
	                            me(c[f >> 2] | 0)
	                        } while (0);
	                        while (1) {
	                            if (!(d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0))q = (c[(c[f >> 2] | 0) + 40 >> 2] | 0) > 1; else q = 0;
	                            r = c[f >> 2] | 0;
	                            if (!q)break;
	                            Ve(r) | 0
	                        }
	                        if ((c[(c[r + 36 >> 2] | 0) + 16 >> 2] | 0) != (c[h >> 2] | 0))continue;
	                        if ((c[j >> 2] | 0) == (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 36 >> 2] | 0)) {
	                            p = 51;
	                            break
	                        }
	                    }
	                    if ((p | 0) == 51)og(c[f >> 2] | 0, 60, 0);
	                    if (c[33952] | 0) {
	                        if ((c[(c[f >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                            j = c[33976] | 0;
	                            h = c[33980] | 0;
	                            r = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2] | 0;
	                            c[e >> 2] = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2];
	                            c[e + 4 >> 2] = r;
	                            Db[j & 511](h, 65312, e)
	                        }
	                        Db[c[135904 >> 2] & 511](c[33980] | 0, 72304, e)
	                    }
	                } else p = 57;
	                do if ((p | 0) == 57) {
	                    if ((((((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 73 ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 71 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 78 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 79 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) == 82 : 0) ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) == 69 : 0) {
	                        c[m >> 2] = 0;
	                        h = (c[f >> 2] | 0) + 200 | 0;
	                        c[h >> 2] = (c[h >> 2] | 0) + 6;
	                        h = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                        c[h >> 2] = (c[h >> 2] | 0) + 6;
	                        h = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                        c[h >> 2] = (c[h >> 2] | 0) + 6;
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[f >> 2] | 0) | 0;
	                        Ue(c[f >> 2] | 0) | 0;
	                        h = c[f >> 2] | 0;
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 91)og(h, 83, 0); else {
	                            if ((c[(c[h + 36 >> 2] | 0) + 56 >> 2] | 0) != (c[g >> 2] | 0))qg(c[f >> 2] | 0, 90, 72192, 0, 0);
	                            me(c[f >> 2] | 0)
	                        }
	                        if (c[33952] | 0) {
	                            if ((c[(c[f >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                                h = c[33976] | 0;
	                                j = c[33980] | 0;
	                                r = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2] | 0;
	                                c[e >> 2] = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2];
	                                c[e + 4 >> 2] = r;
	                                Db[h & 511](j, 65312, e)
	                            }
	                            Db[c[135904 >> 2] & 511](c[33980] | 0, 72344, e)
	                        }
	                        c[k >> 2] = c[(c[f >> 2] | 0) + 212 >> 2];
	                        c[l >> 2] = c[(c[f >> 2] | 0) + 172 >> 2];
	                        if (!(c[(c[f >> 2] | 0) + 288 >> 2] | 0))c[(c[f >> 2] | 0) + 212 >> 2] = 1;
	                        c[(c[f >> 2] | 0) + 172 >> 2] = 15;
	                        b:while (1) {
	                            if ((c[m >> 2] | 0) < 0)break;
	                            if (!(d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0))break;
	                            if ((c[(c[f >> 2] | 0) + 172 >> 2] | 0) == -1)break;
	                            do if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60) {
	                                if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) != 33)break;
	                                if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) != 91)break;
	                                c[m >> 2] = (c[m >> 2] | 0) + 1;
	                                j = (c[f >> 2] | 0) + 200 | 0;
	                                c[j >> 2] = (c[j >> 2] | 0) + 3;
	                                j = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                                c[j >> 2] = (c[j >> 2] | 0) + 3;
	                                j = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                                c[j >> 2] = (c[j >> 2] | 0) + 3;
	                                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                                if (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0)continue b;
	                                if ((ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0) > 0)continue b;
	                                Ve(c[f >> 2] | 0) | 0;
	                                continue b
	                            } while (0);
	                            do if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 93) {
	                                if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) != 93)break;
	                                if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) != 62)break;
	                                j = (c[m >> 2] | 0) + -1 | 0;
	                                c[m >> 2] = j;
	                                if ((j | 0) < 0)continue b;
	                                j = (c[f >> 2] | 0) + 200 | 0;
	                                c[j >> 2] = (c[j >> 2] | 0) + 3;
	                                j = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                                c[j >> 2] = (c[j >> 2] | 0) + 3;
	                                j = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                                c[j >> 2] = (c[j >> 2] | 0) + 3;
	                                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                                if (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0)continue b;
	                                if ((ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0) > 0)continue b;
	                                Ve(c[f >> 2] | 0) | 0;
	                                continue b
	                            } while (0);
	                            me(c[f >> 2] | 0)
	                        }
	                        c[(c[f >> 2] | 0) + 212 >> 2] = c[k >> 2];
	                        c[(c[f >> 2] | 0) + 172 >> 2] = c[l >> 2];
	                        if (!(c[33952] | 0))break;
	                        if ((c[(c[f >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                            j = c[33976] | 0;
	                            h = c[33980] | 0;
	                            r = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2] | 0;
	                            c[e >> 2] = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2];
	                            c[e + 4 >> 2] = r;
	                            Db[j & 511](h, 65312, e)
	                        }
	                        Db[c[135904 >> 2] & 511](c[33980] | 0, 72384, e);
	                        break
	                    }
	                    og(c[f >> 2] | 0, 95, 0)
	                } while (0);
	                if ((((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 : 0) ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 : 0) ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)Fg(c[f >> 2] | 0);
	                e = c[f >> 2] | 0;
	                if (!(d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0)) {
	                    og(e, 59, 0);
	                    i = b;
	                    return
	                }
	                if ((c[(c[e + 36 >> 2] | 0) + 56 >> 2] | 0) != (c[g >> 2] | 0))qg(c[f >> 2] | 0, 90, 72192, 0, 0);
	                g = (c[f >> 2] | 0) + 200 | 0;
	                c[g >> 2] = (c[g >> 2] | 0) + 3;
	                g = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                c[g >> 2] = (c[g >> 2] | 0) + 3;
	                g = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                c[g >> 2] = (c[g >> 2] | 0) + 3;
	                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                if (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) {
	                    i = b;
	                    return
	                }
	                if ((ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0) > 0) {
	                    i = b;
	                    return
	                }
	                Ve(c[f >> 2] | 0) | 0;
	                i = b;
	                return
	            }

	            function Rg(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                do if ((c[c[d >> 2] >> 2] | 0) != 0 ? (c[(c[c[d >> 2] >> 2] | 0) + 108 >> 2] | 0) == -554844497 : 0) {
	                    if ((c[(c[c[d >> 2] >> 2] | 0) + 116 >> 2] | 0) == 0 ? (c[(c[c[d >> 2] >> 2] | 0) + 120 >> 2] | 0) == 0 : 0)break;
	                    c[(c[d >> 2] | 0) + 324 >> 2] = 1
	                } while (0);
	                a = AP(c[(c[d >> 2] | 0) + 296 >> 2] | 0, 70032, 3) | 0;
	                c[(c[d >> 2] | 0) + 312 >> 2] = a;
	                a = AP(c[(c[d >> 2] | 0) + 296 >> 2] | 0, 70040, 5) | 0;
	                c[(c[d >> 2] | 0) + 316 >> 2] = a;
	                a = AP(c[(c[d >> 2] | 0) + 296 >> 2] | 0, 70048, 36) | 0;
	                c[(c[d >> 2] | 0) + 320 >> 2] = a;
	                if (((c[(c[d >> 2] | 0) + 312 >> 2] | 0) != 0 ? (c[(c[d >> 2] | 0) + 316 >> 2] | 0) != 0 : 0) ? (c[(c[d >> 2] | 0) + 320 >> 2] | 0) != 0 : 0) {
	                    i = b;
	                    return
	                }
	                ie(c[d >> 2] | 0, 0);
	                i = b;
	                return
	            }

	            function Sg(a, b, e, f) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0;
	                g = i;
	                i = i + 64 | 0;
	                h = g + 56 | 0;
	                j = g + 52 | 0;
	                k = g + 48 | 0;
	                l = g + 44 | 0;
	                m = g + 40 | 0;
	                n = g + 36 | 0;
	                o = g + 32 | 0;
	                p = g + 28 | 0;
	                q = g + 24 | 0;
	                r = g + 20 | 0;
	                s = g + 16 | 0;
	                t = g + 12 | 0;
	                u = g + 8 | 0;
	                v = g + 4 | 0;
	                w = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                c[o >> 2] = 0;
	                c[q >> 2] = 0;
	                c[r >> 2] = 0;
	                c[s >> 2] = 0;
	                c[u >> 2] = 0;
	                if (!((c[(c[j >> 2] | 0) + 248 >> 2] | 0) > 40 ? (c[(c[j >> 2] | 0) + 360 >> 2] & 524288 | 0) == 0 : 0))x = 3;
	                if ((x | 0) == 3 ? (c[(c[j >> 2] | 0) + 248 >> 2] | 0) <= 1024 : 0) {
	                    if (c[m >> 2] | 0)c[c[m >> 2] >> 2] = 0;
	                    if (!(c[k >> 2] | 0)) {
	                        c[h >> 2] = 1;
	                        y = c[h >> 2] | 0;
	                        i = g;
	                        return y | 0
	                    }
	                    c[t >> 2] = xy(c[k >> 2] | 0) | 0;
	                    c[n >> 2] = Zf(c[k >> 2] | 0, c[t >> 2] | 0) | 0;
	                    if (!(c[n >> 2] | 0)) {
	                        c[h >> 2] = 27;
	                        y = c[h >> 2] | 0;
	                        i = g;
	                        return y | 0
	                    }
	                    if (c[l >> 2] | 0)c[(c[n >> 2] | 0) + 4 >> 2] = c[l >> 2]; else c[(c[n >> 2] | 0) + 4 >> 2] = c[n >> 2];
	                    if (c[(c[n >> 2] | 0) + 296 >> 2] | 0)zP(c[(c[n >> 2] | 0) + 296 >> 2] | 0);
	                    c[(c[n >> 2] | 0) + 296 >> 2] = c[(c[j >> 2] | 0) + 296 >> 2];
	                    l = AP(c[(c[n >> 2] | 0) + 296 >> 2] | 0, 70032, 3) | 0;
	                    c[(c[n >> 2] | 0) + 312 >> 2] = l;
	                    l = AP(c[(c[n >> 2] | 0) + 296 >> 2] | 0, 70040, 5) | 0;
	                    c[(c[n >> 2] | 0) + 316 >> 2] = l;
	                    l = AP(c[(c[n >> 2] | 0) + 296 >> 2] | 0, 70048, 36) | 0;
	                    c[(c[n >> 2] | 0) + 320 >> 2] = l;
	                    c[v >> 2] = 0;
	                    while (1) {
	                        z = c[n >> 2] | 0;
	                        if ((c[v >> 2] | 0) >= (c[(c[j >> 2] | 0) + 328 >> 2] | 0))break;
	                        ih(z, c[(c[(c[j >> 2] | 0) + 336 >> 2] | 0) + (c[v >> 2] << 2) >> 2] | 0, c[(c[(c[j >> 2] | 0) + 336 >> 2] | 0) + ((c[v >> 2] | 0) + 1 << 2) >> 2] | 0) | 0;
	                        c[v >> 2] = (c[v >> 2] | 0) + 2
	                    }
	                    c[q >> 2] = c[z >> 2];
	                    c[c[n >> 2] >> 2] = c[c[j >> 2] >> 2];
	                    Rg(c[n >> 2] | 0);
	                    c[(c[n >> 2] | 0) + 16 >> 2] = c[(c[j >> 2] | 0) + 16 >> 2];
	                    c[(c[n >> 2] | 0) + 360 >> 2] = c[(c[j >> 2] | 0) + 360 >> 2];
	                    c[(c[n >> 2] | 0) + 272 >> 2] = c[(c[j >> 2] | 0) + 272 >> 2];
	                    do if (!(c[(c[j >> 2] | 0) + 8 >> 2] | 0)) {
	                        c[o >> 2] = Sh(68488) | 0;
	                        if (c[o >> 2] | 0) {
	                            c[(c[o >> 2] | 0) + 92 >> 2] = 64;
	                            c[(c[o >> 2] | 0) + 80 >> 2] = c[(c[n >> 2] | 0) + 296 >> 2];
	                            yP(c[(c[o >> 2] | 0) + 80 >> 2] | 0) | 0;
	                            c[(c[n >> 2] | 0) + 8 >> 2] = c[o >> 2];
	                            break
	                        }
	                        c[c[n >> 2] >> 2] = c[q >> 2];
	                        c[(c[n >> 2] | 0) + 296 >> 2] = 0;
	                        Ae(c[n >> 2] | 0);
	                        c[h >> 2] = 1;
	                        y = c[h >> 2] | 0;
	                        i = g;
	                        return y | 0
	                    } else {
	                        c[(c[n >> 2] | 0) + 8 >> 2] = c[(c[j >> 2] | 0) + 8 >> 2];
	                        c[r >> 2] = c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + 12 >> 2];
	                        c[s >> 2] = c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + 16 >> 2]
	                    } while (0);
	                    c[p >> 2] = ji(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 0, 69968, 0) | 0;
	                    if (!(c[p >> 2] | 0)) {
	                        c[c[n >> 2] >> 2] = c[q >> 2];
	                        c[(c[n >> 2] | 0) + 296 >> 2] = 0;
	                        Ae(c[n >> 2] | 0);
	                        if (c[o >> 2] | 0)Th(c[o >> 2] | 0);
	                        c[h >> 2] = 1;
	                        y = c[h >> 2] | 0;
	                        i = g;
	                        return y | 0
	                    }
	                    c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + 12 >> 2] = 0;
	                    c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + 16 >> 2] = 0;
	                    zi(c[(c[n >> 2] | 0) + 8 >> 2] | 0, c[p >> 2] | 0) | 0;
	                    Qe(c[n >> 2] | 0, c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + 12 >> 2] | 0) | 0;
	                    c[(c[n >> 2] | 0) + 172 >> 2] = 7;
	                    c[(c[n >> 2] | 0) + 248 >> 2] = (c[(c[j >> 2] | 0) + 248 >> 2] | 0) + 1;
	                    c[(c[n >> 2] | 0) + 104 >> 2] = 0;
	                    c[(c[n >> 2] | 0) + 276 >> 2] = c[(c[j >> 2] | 0) + 276 >> 2];
	                    if (!((c[(c[j >> 2] | 0) + 104 >> 2] | 0) == 0 ? (c[(c[j >> 2] | 0) + 16 >> 2] | 0) == 0 : 0)) {
	                        p = (c[n >> 2] | 0) + 276 | 0;
	                        c[p >> 2] = c[p >> 2] | 8
	                    }
	                    c[(c[n >> 2] | 0) + 364 >> 2] = c[(c[j >> 2] | 0) + 364 >> 2];
	                    c[(c[n >> 2] | 0) + 348 >> 2] = c[(c[j >> 2] | 0) + 348 >> 2];
	                    c[(c[n >> 2] | 0) + 352 >> 2] = c[(c[j >> 2] | 0) + 352 >> 2];
	                    Jf(c[n >> 2] | 0);
	                    if ((d[c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 47 : 0)og(c[n >> 2] | 0, 85, 0); else x = 34;
	                    if ((x | 0) == 34 ? (d[c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 0 : 0)og(c[n >> 2] | 0, 86, 0);
	                    if ((c[(c[n >> 2] | 0) + 52 >> 2] | 0) != (c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + 12 >> 2] | 0))og(c[n >> 2] | 0, 85, 0);
	                    do if (!(c[(c[n >> 2] | 0) + 12 >> 2] | 0))if (!(c[(c[n >> 2] | 0) + 84 >> 2] | 0)) {
	                        c[u >> 2] = 1;
	                        break
	                    } else {
	                        c[u >> 2] = c[(c[n >> 2] | 0) + 84 >> 2];
	                        break
	                    } else c[u >> 2] = 0; while (0);
	                    if ((c[m >> 2] | 0) != 0 & (c[u >> 2] | 0) == 0) {
	                        c[w >> 2] = c[(c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2];
	                        c[c[m >> 2] >> 2] = c[w >> 2];
	                        while (1) {
	                            if (!(c[w >> 2] | 0))break;
	                            do if (c[(c[j >> 2] | 0) + 104 >> 2] | 0) {
	                                if (!(c[(c[j >> 2] | 0) + 12 >> 2] | 0))break;
	                                if (!(c[(c[j >> 2] | 0) + 8 >> 2] | 0))break;
	                                if (!(c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0))break;
	                                if ((c[(c[w >> 2] | 0) + 4 >> 2] | 0) != 1)break;
	                                m = bn((c[j >> 2] | 0) + 108 | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[w >> 2] | 0) | 0;
	                                x = (c[j >> 2] | 0) + 100 | 0;
	                                c[x >> 2] = c[x >> 2] & m
	                            } while (0);
	                            c[(c[w >> 2] | 0) + 20 >> 2] = 0;
	                            c[w >> 2] = c[(c[w >> 2] | 0) + 24 >> 2]
	                        }
	                        c[(c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2] = 0
	                    }
	                    if (c[(c[n >> 2] | 0) + 8 >> 2] | 0) {
	                        Rh(c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + 12 >> 2] | 0);
	                        c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + 12 >> 2] = c[r >> 2];
	                        c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + 16 >> 2] = c[s >> 2]
	                    }
	                    if (c[j >> 2] | 0) {
	                        s = (c[j >> 2] | 0) + 440 | 0;
	                        c[s >> 2] = (c[s >> 2] | 0) + (c[(c[n >> 2] | 0) + 440 >> 2] | 0)
	                    }
	                    if (c[(c[n >> 2] | 0) + 388 >> 2] | 0)Zd((c[n >> 2] | 0) + 384 | 0, (c[j >> 2] | 0) + 384 | 0) | 0;
	                    c[c[n >> 2] >> 2] = c[q >> 2];
	                    c[(c[n >> 2] | 0) + 296 >> 2] = 0;
	                    c[(c[n >> 2] | 0) + 348 >> 2] = 0;
	                    c[(c[n >> 2] | 0) + 352 >> 2] = 0;
	                    Ae(c[n >> 2] | 0);
	                    if (c[o >> 2] | 0)Th(c[o >> 2] | 0);
	                    c[h >> 2] = c[u >> 2];
	                    y = c[h >> 2] | 0;
	                    i = g;
	                    return y | 0
	                }
	                c[h >> 2] = 89;
	                y = c[h >> 2] | 0;
	                i = g;
	                return y | 0
	            }

	            function Tg(b, e, f, g, h, j, k, l) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                k = k | 0;
	                l = l | 0;
	                var m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0;
	                m = i;
	                i = i + 80 | 0;
	                n = m + 60 | 0;
	                o = m + 56 | 0;
	                p = m + 52 | 0;
	                q = m + 48 | 0;
	                r = m + 44 | 0;
	                s = m + 40 | 0;
	                t = m + 36 | 0;
	                u = m + 32 | 0;
	                v = m + 28 | 0;
	                w = m + 24 | 0;
	                x = m + 20 | 0;
	                y = m + 16 | 0;
	                z = m + 12 | 0;
	                A = m + 8 | 0;
	                B = m + 64 | 0;
	                C = m + 4 | 0;
	                D = m;
	                c[o >> 2] = b;
	                c[p >> 2] = e;
	                c[q >> 2] = f;
	                c[r >> 2] = g;
	                c[s >> 2] = h;
	                c[t >> 2] = j;
	                c[u >> 2] = k;
	                c[v >> 2] = l;
	                c[z >> 2] = 0;
	                c[A >> 2] = 0;
	                if ((c[s >> 2] | 0) > 40) {
	                    if (!((c[p >> 2] | 0) != 0 ? !((c[s >> 2] | 0) > 1024 ? 1 : (c[(c[p >> 2] | 0) + 360 >> 2] & 524288 | 0) == 0) : 0))E = 5
	                } else if ((c[s >> 2] | 0) > 1024)E = 5;
	                if ((E | 0) == 5) {
	                    c[n >> 2] = 89;
	                    F = c[n >> 2] | 0;
	                    i = m;
	                    return F | 0
	                }
	                if (c[v >> 2] | 0)c[c[v >> 2] >> 2] = 0;
	                if ((c[t >> 2] | 0) == 0 & (c[u >> 2] | 0) == 0) {
	                    c[n >> 2] = 1;
	                    F = c[n >> 2] | 0;
	                    i = m;
	                    return F | 0
	                }
	                if (!(c[o >> 2] | 0)) {
	                    c[n >> 2] = 1;
	                    F = c[n >> 2] | 0;
	                    i = m;
	                    return F | 0
	                }
	                c[w >> 2] = fh(c[t >> 2] | 0, c[u >> 2] | 0, 0, c[p >> 2] | 0) | 0;
	                if (!(c[w >> 2] | 0)) {
	                    c[n >> 2] = 27;
	                    F = c[n >> 2] | 0;
	                    i = m;
	                    return F | 0
	                }
	                c[(c[w >> 2] | 0) + 4 >> 2] = c[w >> 2];
	                if (c[p >> 2] | 0) {
	                    c[(c[w >> 2] | 0) + 272 >> 2] = c[(c[p >> 2] | 0) + 272 >> 2];
	                    c[(c[w >> 2] | 0) + 276 >> 2] = c[(c[p >> 2] | 0) + 276 >> 2];
	                    c[(c[w >> 2] | 0) + 104 >> 2] = c[(c[p >> 2] | 0) + 104 >> 2];
	                    c[(c[w >> 2] | 0) + 96 >> 2] = c[(c[p >> 2] | 0) + 96 >> 2];
	                    c[(c[w >> 2] | 0) + 68 >> 2] = c[(c[p >> 2] | 0) + 68 >> 2];
	                    c[(c[w >> 2] | 0) + 72 >> 2] = c[(c[p >> 2] | 0) + 72 >> 2];
	                    c[(c[w >> 2] | 0) + 76 >> 2] = c[(c[p >> 2] | 0) + 76 >> 2];
	                    c[(c[w >> 2] | 0) + 80 >> 2] = c[(c[p >> 2] | 0) + 80 >> 2]
	                } else {
	                    c[(c[w >> 2] | 0) + 272 >> 2] = 0;
	                    c[(c[w >> 2] | 0) + 104 >> 2] = 0;
	                    c[(c[w >> 2] | 0) + 96 >> 2] = 2;
	                    c[(c[w >> 2] | 0) + 276 >> 2] = 0
	                }
	                if ((c[q >> 2] | 0) != 0 ? (c[z >> 2] = c[c[w >> 2] >> 2], c[c[w >> 2] >> 2] = c[q >> 2], (c[r >> 2] | 0) != 0) : 0)c[(c[w >> 2] | 0) + 4 >> 2] = c[r >> 2];
	                Rg(c[w >> 2] | 0);
	                c[x >> 2] = Sh(68488) | 0;
	                if (!(c[x >> 2] | 0)) {
	                    c[(c[w >> 2] | 0) + 72 >> 2] = 0;
	                    c[(c[w >> 2] | 0) + 76 >> 2] = 0;
	                    c[(c[w >> 2] | 0) + 80 >> 2] = 0;
	                    Ae(c[w >> 2] | 0);
	                    c[n >> 2] = 1;
	                    F = c[n >> 2] | 0;
	                    i = m;
	                    return F | 0
	                }
	                c[(c[x >> 2] | 0) + 92 >> 2] = 64;
	                c[(c[x >> 2] | 0) + 44 >> 2] = c[(c[o >> 2] | 0) + 44 >> 2];
	                c[(c[x >> 2] | 0) + 48 >> 2] = c[(c[o >> 2] | 0) + 48 >> 2];
	                c[(c[x >> 2] | 0) + 80 >> 2] = c[(c[o >> 2] | 0) + 80 >> 2];
	                yP(c[(c[x >> 2] | 0) + 80 >> 2] | 0) | 0;
	                if (c[(c[o >> 2] | 0) + 72 >> 2] | 0) {
	                    r = my(c[(c[o >> 2] | 0) + 72 >> 2] | 0) | 0;
	                    c[(c[x >> 2] | 0) + 72 >> 2] = r
	                }
	                c[y >> 2] = ji(c[x >> 2] | 0, 0, 69968, 0) | 0;
	                if (!(c[y >> 2] | 0)) {
	                    if (c[q >> 2] | 0)c[c[w >> 2] >> 2] = c[z >> 2];
	                    c[(c[w >> 2] | 0) + 72 >> 2] = 0;
	                    c[(c[w >> 2] | 0) + 76 >> 2] = 0;
	                    c[(c[w >> 2] | 0) + 80 >> 2] = 0;
	                    Ae(c[w >> 2] | 0);
	                    c[(c[x >> 2] | 0) + 44 >> 2] = 0;
	                    c[(c[x >> 2] | 0) + 48 >> 2] = 0;
	                    Th(c[x >> 2] | 0);
	                    c[n >> 2] = 1;
	                    F = c[n >> 2] | 0;
	                    i = m;
	                    return F | 0
	                }
	                zi(c[x >> 2] | 0, c[y >> 2] | 0) | 0;
	                Qe(c[w >> 2] | 0, c[(c[x >> 2] | 0) + 12 >> 2] | 0) | 0;
	                c[(c[w >> 2] | 0) + 8 >> 2] = c[o >> 2];
	                c[(c[y >> 2] | 0) + 32 >> 2] = c[o >> 2];
	                if ((c[(c[w >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[w >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[w >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[w >> 2] | 0);
	                if (((c[(c[(c[w >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[w >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) >= 4 ? (a[B >> 0] = a[c[(c[(c[w >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0, a[B + 1 >> 0] = a[(c[(c[(c[w >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0, a[B + 2 >> 0] = a[(c[(c[(c[w >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0, a[B + 3 >> 0] = a[(c[(c[(c[w >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0, c[C >> 2] = sd(B, 4) | 0, (c[C >> 2] | 0) != 0) : 0)re(c[w >> 2] | 0, c[C >> 2] | 0) | 0;
	                a:do if (((((d[c[(c[(c[w >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[w >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 63 : 0) ? (d[(c[(c[(c[w >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 120 : 0) ? (d[(c[(c[(c[w >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 109 : 0) ? (d[(c[(c[(c[w >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) == 108 : 0) {
	                    do if ((d[(c[(c[(c[w >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[(c[(c[(c[w >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) ? (d[(c[(c[(c[w >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[(c[(c[(c[w >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    _e(c[w >> 2] | 0)
	                } while (0);
	                c[(c[w >> 2] | 0) + 172 >> 2] = 7;
	                c[(c[w >> 2] | 0) + 248 >> 2] = c[s >> 2];
	                Jf(c[w >> 2] | 0);
	                if ((d[c[(c[(c[w >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[w >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 47 : 0)og(c[w >> 2] | 0, 85, 0); else E = 47;
	                if ((E | 0) == 47 ? (d[c[(c[(c[w >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 0 : 0)og(c[w >> 2] | 0, 86, 0);
	                if ((c[(c[w >> 2] | 0) + 52 >> 2] | 0) != (c[(c[x >> 2] | 0) + 12 >> 2] | 0))og(c[w >> 2] | 0, 85, 0);
	                do if (!(c[(c[w >> 2] | 0) + 12 >> 2] | 0))if (!(c[(c[w >> 2] | 0) + 84 >> 2] | 0)) {
	                    c[A >> 2] = 1;
	                    break
	                } else {
	                    c[A >> 2] = c[(c[w >> 2] | 0) + 84 >> 2];
	                    break
	                } else {
	                    if (c[v >> 2] | 0) {
	                        c[D >> 2] = c[(c[(c[x >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2];
	                        c[c[v >> 2] >> 2] = c[D >> 2];
	                        while (1) {
	                            if (!(c[D >> 2] | 0))break;
	                            c[(c[D >> 2] | 0) + 20 >> 2] = 0;
	                            c[D >> 2] = c[(c[D >> 2] | 0) + 24 >> 2]
	                        }
	                        c[(c[(c[x >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2] = 0
	                    }
	                    c[A >> 2] = 0
	                } while (0);
	                if (c[p >> 2] | 0) {
	                    D = (c[p >> 2] | 0) + 440 | 0;
	                    c[D >> 2] = (c[D >> 2] | 0) + (c[(c[w >> 2] | 0) + 440 >> 2] | 0)
	                }
	                if (c[(c[w >> 2] | 0) + 36 >> 2] | 0) {
	                    D = (c[p >> 2] | 0) + 444 | 0;
	                    c[D >> 2] = (c[D >> 2] | 0) + (c[(c[(c[w >> 2] | 0) + 36 >> 2] | 0) + 36 >> 2] | 0);
	                    D = (c[p >> 2] | 0) + 444 | 0;
	                    c[D >> 2] = (c[D >> 2] | 0) + ((c[(c[(c[w >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[w >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0))
	                }
	                if (c[(c[w >> 2] | 0) + 388 >> 2] | 0)Zd((c[w >> 2] | 0) + 384 | 0, (c[p >> 2] | 0) + 384 | 0) | 0;
	                if (c[q >> 2] | 0)c[c[w >> 2] >> 2] = c[z >> 2];
	                c[(c[p >> 2] | 0) + 72 >> 2] = c[(c[w >> 2] | 0) + 72 >> 2];
	                c[(c[p >> 2] | 0) + 76 >> 2] = c[(c[w >> 2] | 0) + 76 >> 2];
	                c[(c[p >> 2] | 0) + 80 >> 2] = c[(c[w >> 2] | 0) + 80 >> 2];
	                c[(c[w >> 2] | 0) + 72 >> 2] = 0;
	                c[(c[w >> 2] | 0) + 76 >> 2] = 0;
	                c[(c[w >> 2] | 0) + 80 >> 2] = 0;
	                Ae(c[w >> 2] | 0);
	                c[(c[x >> 2] | 0) + 44 >> 2] = 0;
	                c[(c[x >> 2] | 0) + 48 >> 2] = 0;
	                Th(c[x >> 2] | 0);
	                c[n >> 2] = c[A >> 2];
	                F = c[n >> 2] | 0;
	                i = m;
	                return F | 0
	            }

	            function Ug(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if (!(c[17530] | 0)) {
	                    i = e;
	                    return
	                }
	                Db[c[70120 >> 2] & 511](c[f >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0);
	                i = e;
	                return
	            }

	            function Vg(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 212 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 172 >> 2] | 0) == -1 : 0) {
	                    i = e;
	                    return
	                }
	                if (c[g >> 2] | 0)c[(c[g >> 2] | 0) + 84 >> 2] = 42;
	                d = c[g >> 2] | 0;
	                if (!(c[h >> 2] | 0)) {
	                    b = c[j >> 2] | 0;
	                    c[f >> 2] = c[j >> 2];
	                    Xd(0, 0, 0, d, 0, 1, 42, 3, 0, 0, b, 0, 0, 0, 0, 71848, f)
	                } else {
	                    b = c[h >> 2] | 0;
	                    a = c[j >> 2] | 0;
	                    k = c[j >> 2] | 0;
	                    c[f >> 2] = c[h >> 2];
	                    c[f + 4 >> 2] = k;
	                    Xd(0, 0, 0, d, 0, 1, 42, 3, 0, 0, b, a, 0, 0, 0, 71872, f)
	                }
	                if (!(c[g >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                c[(c[g >> 2] | 0) + 12 >> 2] = 0;
	                if (c[(c[g >> 2] | 0) + 288 >> 2] | 0) {
	                    i = e;
	                    return
	                }
	                c[(c[g >> 2] | 0) + 212 >> 2] = 1;
	                i = e;
	                return
	            }

	            function Wg(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[f >> 2] | 0);
	                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 47 : 0) {
	                    b = (c[f >> 2] | 0) + 200 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 2;
	                    b = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 2;
	                    b = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 2;
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[f >> 2] | 0) | 0;
	                    c[h >> 2] = mh(c[f >> 2] | 0, c[(c[f >> 2] | 0) + 184 >> 2] | 0) | 0;
	                    if ((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[f >> 2] | 0);
	                    Ue(c[f >> 2] | 0) | 0;
	                    if (9 <= (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)j = 19; else if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13 ? 32 > (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) : 0)j = 20; else j = 19;
	                    if ((j | 0) == 19)if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 62) {
	                        b = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                        c[b >> 2] = (c[b >> 2] | 0) + 1;
	                        b = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                        c[b >> 2] = (c[b >> 2] | 0) + 1;
	                        b = (c[f >> 2] | 0) + 200 | 0;
	                        c[b >> 2] = (c[b >> 2] | 0) + 1;
	                        if (!(d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0))ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0
	                    } else j = 20;
	                    if ((j | 0) == 20)og(c[f >> 2] | 0, 73, 0);
	                    if ((c[h >> 2] | 0) != 1) {
	                        if (!(c[h >> 2] | 0))c[h >> 2] = 70752;
	                        $g(c[f >> 2] | 0, 76, 70768, c[(c[f >> 2] | 0) + 184 >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0)
	                    }
	                    if (((c[c[f >> 2] >> 2] | 0) != 0 ? (c[(c[c[f >> 2] >> 2] | 0) + 60 >> 2] | 0) != 0 : 0) ? (c[(c[f >> 2] | 0) + 212 >> 2] | 0) == 0 : 0)Ab[c[(c[c[f >> 2] >> 2] | 0) + 60 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0, c[(c[f >> 2] | 0) + 184 >> 2] | 0);
	                    Te(c[f >> 2] | 0) | 0;
	                    Zg(c[f >> 2] | 0) | 0;
	                    i = e;
	                    return
	                }
	                xg(c[f >> 2] | 0, 74, 71816);
	                i = e;
	                return
	            }

	            function Xg(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                do if ((c[(c[f >> 2] | 0) + 236 >> 2] | 0) >= (c[(c[f >> 2] | 0) + 240 >> 2] | 0)) {
	                    b = (c[f >> 2] | 0) + 240 | 0;
	                    c[b >> 2] = c[b >> 2] << 1;
	                    c[h >> 2] = Hb[c[135760 >> 2] & 511](c[(c[f >> 2] | 0) + 244 >> 2] | 0, c[(c[f >> 2] | 0) + 240 >> 2] << 2) | 0;
	                    if (c[h >> 2] | 0) {
	                        c[(c[f >> 2] | 0) + 244 >> 2] = c[h >> 2];
	                        break
	                    }
	                    ie(c[f >> 2] | 0, 0);
	                    b = (c[f >> 2] | 0) + 240 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) / 2 | 0;
	                    c[e >> 2] = -1;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } while (0);
	                c[(c[(c[f >> 2] | 0) + 244 >> 2] | 0) + (c[(c[f >> 2] | 0) + 236 >> 2] << 2) >> 2] = c[g >> 2];
	                c[(c[f >> 2] | 0) + 232 >> 2] = (c[(c[f >> 2] | 0) + 244 >> 2] | 0) + (c[(c[f >> 2] | 0) + 236 >> 2] << 2);
	                g = (c[f >> 2] | 0) + 236 | 0;
	                f = c[g >> 2] | 0;
	                c[g >> 2] = f + 1;
	                c[e >> 2] = f;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function Yg(a, b, e, f) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0, J = 0, K = 0, L = 0, M = 0, N = 0, O = 0, P = 0, Q = 0, R = 0, S = 0;
	                g = i;
	                i = i + 144 | 0;
	                h = g + 132 | 0;
	                j = g + 128 | 0;
	                k = g + 124 | 0;
	                l = g + 120 | 0;
	                m = g + 116 | 0;
	                n = g + 112 | 0;
	                o = g + 108 | 0;
	                p = g + 104 | 0;
	                q = g + 100 | 0;
	                r = g + 96 | 0;
	                s = g + 92 | 0;
	                t = g + 88 | 0;
	                u = g + 84 | 0;
	                v = g + 80 | 0;
	                w = g + 76 | 0;
	                x = g + 72 | 0;
	                y = g + 68 | 0;
	                z = g + 64 | 0;
	                A = g + 60 | 0;
	                B = g + 56 | 0;
	                C = g + 52 | 0;
	                D = g + 48 | 0;
	                E = g + 44 | 0;
	                F = g + 40 | 0;
	                G = g + 36 | 0;
	                H = g + 32 | 0;
	                I = g + 28 | 0;
	                J = g + 24 | 0;
	                K = g + 20 | 0;
	                L = g + 16 | 0;
	                M = g + 12 | 0;
	                N = g + 8 | 0;
	                O = g + 4 | 0;
	                P = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                c[t >> 2] = c[(c[j >> 2] | 0) + 300 >> 2];
	                c[u >> 2] = c[(c[j >> 2] | 0) + 304 >> 2];
	                c[G >> 2] = c[(c[j >> 2] | 0) + 328 >> 2];
	                if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 60) {
	                    c[h >> 2] = 0;
	                    Q = c[h >> 2] | 0;
	                    i = g;
	                    return Q | 0
	                }
	                f = (c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                c[f >> 2] = (c[f >> 2] | 0) + 1;
	                f = (c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                c[f >> 2] = (c[f >> 2] | 0) + 1;
	                f = (c[j >> 2] | 0) + 200 | 0;
	                c[f >> 2] = (c[f >> 2] | 0) + 1;
	                if (!(d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0))ke(c[(c[j >> 2] | 0) + 36 >> 2] | 0, 250) | 0;
	                a:while (1) {
	                    if (((c[(c[j >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 : 0) ? ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)Fg(c[j >> 2] | 0);
	                    c[E >> 2] = c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2];
	                    c[F >> 2] = (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0);
	                    c[C >> 2] = c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2];
	                    c[D >> 2] = c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2];
	                    c[w >> 2] = 0;
	                    c[v >> 2] = 0;
	                    c[x >> 2] = 0;
	                    c[A >> 2] = 0;
	                    c[B >> 2] = 0;
	                    c[(c[j >> 2] | 0) + 328 >> 2] = c[G >> 2];
	                    c[n >> 2] = nh(c[j >> 2] | 0, o) | 0;
	                    R = c[j >> 2] | 0;
	                    if (!(c[n >> 2] | 0)) {
	                        S = 10;
	                        break
	                    }
	                    c[c[m >> 2] >> 2] = (c[(c[R + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) - (c[F >> 2] | 0);
	                    Ue(c[j >> 2] | 0) | 0;
	                    if ((c[(c[j >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[j >> 2] | 0);
	                    b:do if ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) == (c[E >> 2] | 0)) {
	                        c:while (1) {
	                            if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 62)break a;
	                            if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 47 ? (d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 62 : 0)break a;
	                            if (!(9 <= (d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0))S = 20;
	                            if (((S | 0) == 20 ? (S = 0, (d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13) : 0) ? 32 > (d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) : 0)break a;
	                            if ((c[(c[j >> 2] | 0) + 172 >> 2] | 0) == -1)break a;
	                            c[H >> 2] = c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                            c[I >> 2] = c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 36 >> 2];
	                            c[J >> 2] = -1;
	                            c[K >> 2] = 0;
	                            c[p >> 2] = oh(c[j >> 2] | 0, c[o >> 2] | 0, c[n >> 2] | 0, q, s, J, K) | 0;
	                            if ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != (c[E >> 2] | 0))break;
	                            d:do if ((c[p >> 2] | 0) != 0 & (c[s >> 2] | 0) != 0) {
	                                if ((c[J >> 2] | 0) < 0)c[J >> 2] = xy(c[s >> 2] | 0) | 0;
	                                if ((c[q >> 2] | 0) == 0 ? (c[p >> 2] | 0) == (c[(c[j >> 2] | 0) + 316 >> 2] | 0) : 0) {
	                                    c[L >> 2] = AP(c[(c[j >> 2] | 0) + 296 >> 2] | 0, c[s >> 2] | 0, c[J >> 2] | 0) | 0;
	                                    if (!(c[L >> 2] | 0)) {
	                                        S = 32;
	                                        break a
	                                    }
	                                    do if (d[c[L >> 2] >> 0] | 0) {
	                                        c[M >> 2] = yl(c[L >> 2] | 0) | 0;
	                                        if (!(c[M >> 2] | 0))Jg(c[j >> 2] | 0, 99, 71016, c[L >> 2] | 0, 0, 0); else {
	                                            if (!(c[c[M >> 2] >> 2] | 0))ph(c[j >> 2] | 0, 100, 71048, c[L >> 2] | 0, 0, 0);
	                                            Al(c[M >> 2] | 0)
	                                        }
	                                        if ((c[L >> 2] | 0) == (c[(c[j >> 2] | 0) + 320 >> 2] | 0)) {
	                                            if ((c[p >> 2] | 0) == (c[(c[j >> 2] | 0) + 312 >> 2] | 0))break;
	                                            Jg(c[j >> 2] | 0, 200, 71080, 0, 0, 0);
	                                            break
	                                        }
	                                        if ((c[J >> 2] | 0) != 29) {
	                                            S = 47;
	                                            break
	                                        }
	                                        if (!(qy(c[L >> 2] | 0, 71136) | 0)) {
	                                            S = 47;
	                                            break
	                                        }
	                                        Jg(c[j >> 2] | 0, 200, 71168, 0, 0, 0)
	                                    } else S = 47; while (0);
	                                    do if ((S | 0) == 47) {
	                                        S = 0;
	                                        c[z >> 2] = 1;
	                                        while (1) {
	                                            if ((c[z >> 2] | 0) > (c[A >> 2] | 0))break;
	                                            if (!(c[(c[(c[j >> 2] | 0) + 336 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 328 >> 2] | 0) - (c[z >> 2] << 1) << 2) >> 2] | 0))break;
	                                            c[z >> 2] = (c[z >> 2] | 0) + 1
	                                        }
	                                        f = c[j >> 2] | 0;
	                                        if ((c[z >> 2] | 0) <= (c[A >> 2] | 0)) {
	                                            Vg(f, 0, c[p >> 2] | 0);
	                                            break
	                                        }
	                                        if ((ih(f, 0, c[L >> 2] | 0) | 0) <= 0)break;
	                                        c[A >> 2] = (c[A >> 2] | 0) + 1
	                                    } while (0);
	                                    if (c[K >> 2] | 0)zb[c[135736 >> 2] & 511](c[s >> 2] | 0);
	                                    if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 62)break a;
	                                    if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 47 ? (d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 62 : 0)break a;
	                                    do if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32) {
	                                        if (9 <= (d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                                        if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13) {
	                                            S = 64;
	                                            break a
	                                        }
	                                    } while (0);
	                                    Ue(c[j >> 2] | 0) | 0;
	                                    continue c
	                                }
	                                if ((c[q >> 2] | 0) != (c[(c[j >> 2] | 0) + 316 >> 2] | 0)) {
	                                    if (!((c[t >> 2] | 0) != 0 ? ((c[w >> 2] | 0) + 5 | 0) <= (c[u >> 2] | 0) : 0))S = 108;
	                                    do if ((S | 0) == 108) {
	                                        S = 0;
	                                        if ((qh(c[j >> 2] | 0, (c[w >> 2] | 0) + 5 | 0) | 0) >= 0) {
	                                            c[u >> 2] = c[(c[j >> 2] | 0) + 304 >> 2];
	                                            c[t >> 2] = c[(c[j >> 2] | 0) + 300 >> 2];
	                                            break
	                                        }
	                                        if (d[(c[s >> 2] | 0) + (c[J >> 2] | 0) >> 0] | 0)break d;
	                                        zb[c[135736 >> 2] & 511](c[s >> 2] | 0);
	                                        break d
	                                    } while (0);
	                                    f = c[K >> 2] | 0;
	                                    e = c[v >> 2] | 0;
	                                    c[v >> 2] = e + 1;
	                                    c[(c[(c[j >> 2] | 0) + 340 >> 2] | 0) + (e << 2) >> 2] = f;
	                                    f = c[p >> 2] | 0;
	                                    e = c[w >> 2] | 0;
	                                    c[w >> 2] = e + 1;
	                                    c[(c[t >> 2] | 0) + (e << 2) >> 2] = f;
	                                    f = c[q >> 2] | 0;
	                                    e = c[w >> 2] | 0;
	                                    c[w >> 2] = e + 1;
	                                    c[(c[t >> 2] | 0) + (e << 2) >> 2] = f;
	                                    f = c[w >> 2] | 0;
	                                    c[w >> 2] = f + 1;
	                                    c[(c[t >> 2] | 0) + (f << 2) >> 2] = 0;
	                                    f = c[s >> 2] | 0;
	                                    e = c[w >> 2] | 0;
	                                    c[w >> 2] = e + 1;
	                                    c[(c[t >> 2] | 0) + (e << 2) >> 2] = f;
	                                    c[s >> 2] = (c[s >> 2] | 0) + (c[J >> 2] | 0);
	                                    f = c[s >> 2] | 0;
	                                    e = c[w >> 2] | 0;
	                                    c[w >> 2] = e + 1;
	                                    c[(c[t >> 2] | 0) + (e << 2) >> 2] = f;
	                                    if (!(c[K >> 2] | 0))break;
	                                    c[B >> 2] = 1;
	                                    break
	                                }
	                                c[N >> 2] = AP(c[(c[j >> 2] | 0) + 296 >> 2] | 0, c[s >> 2] | 0, c[J >> 2] | 0) | 0;
	                                f = c[N >> 2] | 0;
	                                e = c[(c[j >> 2] | 0) + 320 >> 2] | 0;
	                                e:do if ((c[p >> 2] | 0) == (c[(c[j >> 2] | 0) + 312 >> 2] | 0)) {
	                                    if ((f | 0) == (e | 0))break;
	                                    Jg(c[j >> 2] | 0, 200, 71216, 0, 0, 0)
	                                } else {
	                                    b = c[p >> 2] | 0;
	                                    a = c[j >> 2] | 0;
	                                    if ((f | 0) == (e | 0)) {
	                                        if ((b | 0) == (c[a + 312 >> 2] | 0))break;
	                                        Jg(c[j >> 2] | 0, 200, 71264, 0, 0, 0);
	                                        break
	                                    }
	                                    if ((b | 0) == (c[a + 316 >> 2] | 0)) {
	                                        Jg(c[j >> 2] | 0, 200, 71312, 0, 0, 0);
	                                        break
	                                    }
	                                    do if ((c[J >> 2] | 0) == 29) {
	                                        if (!(qy(c[N >> 2] | 0, 71136) | 0))break;
	                                        Jg(c[j >> 2] | 0, 200, 71168, 0, 0, 0);
	                                        break e
	                                    } while (0);
	                                    do if (c[N >> 2] | 0) {
	                                        if (!(d[c[N >> 2] >> 0] | 0))break;
	                                        c[O >> 2] = yl(c[N >> 2] | 0) | 0;
	                                        a = c[j >> 2] | 0;
	                                        if (!(c[O >> 2] | 0))Jg(a, 99, 71408, c[p >> 2] | 0, c[N >> 2] | 0, 0); else {
	                                            do if (c[a + 268 >> 2] | 0) {
	                                                if (c[c[O >> 2] >> 2] | 0)break;
	                                                ph(c[j >> 2] | 0, 100, 71448, c[p >> 2] | 0, c[N >> 2] | 0, 0)
	                                            } while (0);
	                                            Al(c[O >> 2] | 0)
	                                        }
	                                        c[z >> 2] = 1;
	                                        while (1) {
	                                            if ((c[z >> 2] | 0) > (c[A >> 2] | 0))break;
	                                            if ((c[(c[(c[j >> 2] | 0) + 336 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 328 >> 2] | 0) - (c[z >> 2] << 1) << 2) >> 2] | 0) == (c[p >> 2] | 0))break;
	                                            c[z >> 2] = (c[z >> 2] | 0) + 1
	                                        }
	                                        a = c[j >> 2] | 0;
	                                        if ((c[z >> 2] | 0) <= (c[A >> 2] | 0)) {
	                                            Vg(a, c[q >> 2] | 0, c[p >> 2] | 0);
	                                            break e
	                                        }
	                                        if ((ih(a, c[p >> 2] | 0, c[N >> 2] | 0) | 0) <= 0)break e;
	                                        c[A >> 2] = (c[A >> 2] | 0) + 1;
	                                        break e
	                                    } while (0);
	                                    Jg(c[j >> 2] | 0, 200, 71360, c[p >> 2] | 0, 0, 0)
	                                } while (0);
	                                if (c[K >> 2] | 0)zb[c[135736 >> 2] & 511](c[s >> 2] | 0);
	                                if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 62)break a;
	                                if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 47 ? (d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 62 : 0)break a;
	                                do if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32) {
	                                    if (9 <= (d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                                    if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13) {
	                                        S = 104;
	                                        break a
	                                    }
	                                } while (0);
	                                Ue(c[j >> 2] | 0) | 0;
	                                if ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != (c[E >> 2] | 0))break b; else continue c
	                            } else if ((c[s >> 2] | 0) != 0 ? (d[(c[s >> 2] | 0) + (c[J >> 2] | 0) >> 0] | 0 | 0) == 0 : 0)zb[c[135736 >> 2] & 511](c[s >> 2] | 0); while (0);
	                            if ((c[(c[j >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[j >> 2] | 0);
	                            if ((c[(c[j >> 2] | 0) + 172 >> 2] | 0) == -1)break a;
	                            if ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != (c[E >> 2] | 0))break b;
	                            if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 62)break a;
	                            if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 47 ? (d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 62 : 0)break a;
	                            do if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32) {
	                                if (9 <= (d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                                if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13) {
	                                    S = 129;
	                                    break a
	                                }
	                            } while (0);
	                            Ue(c[j >> 2] | 0) | 0;
	                            if ((c[I >> 2] | 0) == (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 36 >> 2] | 0) ? ((c[p >> 2] | 0) == 0 ? (c[H >> 2] | 0) == (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) : 0) & (c[s >> 2] | 0) == 0 : 0) {
	                                S = 132;
	                                break a
	                            }
	                            do if (!(c[(c[j >> 2] | 0) + 292 >> 2] | 0)) {
	                                if (((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) >= 250)break;
	                                vg(c[j >> 2] | 0)
	                            } while (0);
	                            if ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != (c[E >> 2] | 0))break b
	                        }
	                        if ((c[s >> 2] | 0) != 0 & (c[K >> 2] | 0) != 0)zb[c[135736 >> 2] & 511](c[s >> 2] | 0);
	                        c[s >> 2] = 0
	                    } while (0);
	                    f:do if (c[B >> 2] | 0) {
	                        c[y >> 2] = 3;
	                        c[z >> 2] = 0;
	                        while (1) {
	                            if ((c[z >> 2] | 0) >= (c[v >> 2] | 0))break f;
	                            if ((c[(c[(c[j >> 2] | 0) + 340 >> 2] | 0) + (c[z >> 2] << 2) >> 2] | 0) != 0 ? (c[(c[t >> 2] | 0) + (c[y >> 2] << 2) >> 2] | 0) != 0 : 0)zb[c[135736 >> 2] & 511](c[(c[t >> 2] | 0) + (c[y >> 2] << 2) >> 2] | 0);
	                            c[y >> 2] = (c[y >> 2] | 0) + 5;
	                            c[z >> 2] = (c[z >> 2] | 0) + 1
	                        }
	                    } while (0);
	                    c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] = (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) + (c[F >> 2] | 0);
	                    c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2] = c[C >> 2];
	                    c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = c[D >> 2];
	                    if ((c[(c[j >> 2] | 0) + 12 >> 2] | 0) != 1) {
	                        S = 219;
	                        break
	                    }
	                }
	                if ((S | 0) == 10) {
	                    xg(R, 68, 70952);
	                    c[h >> 2] = 0;
	                    Q = c[h >> 2] | 0;
	                    i = g;
	                    return Q | 0
	                } else if ((S | 0) == 32) {
	                    ie(c[j >> 2] | 0, 70984);
	                    if ((c[s >> 2] | 0) != 0 & (c[K >> 2] | 0) != 0)zb[c[135736 >> 2] & 511](c[s >> 2] | 0);
	                    c[h >> 2] = 0;
	                    Q = c[h >> 2] | 0;
	                    i = g;
	                    return Q | 0
	                } else if ((S | 0) == 64)xg(c[j >> 2] | 0, 65, 69320); else if ((S | 0) == 104)xg(c[j >> 2] | 0, 65, 69320); else if ((S | 0) == 129)xg(c[j >> 2] | 0, 65, 69320); else if ((S | 0) == 132)og(c[j >> 2] | 0, 1, 69352); else if ((S | 0) == 219) {
	                    c[h >> 2] = 0;
	                    Q = c[h >> 2] | 0;
	                    i = g;
	                    return Q | 0
	                }
	                g:do if ((c[(c[j >> 2] | 0) + 348 >> 2] | 0) != 0 ? (c[P >> 2] = Tj(c[(c[j >> 2] | 0) + 348 >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0) | 0, (c[P >> 2] | 0) != 0) : 0) {
	                    c[y >> 2] = 0;
	                    h:while (1) {
	                        if ((c[y >> 2] | 0) >= (c[c[P >> 2] >> 2] | 0))break g;
	                        c[p >> 2] = c[(c[P >> 2] | 0) + 8 + ((c[y >> 2] | 0) * 5 << 2) >> 2];
	                        c[q >> 2] = c[(c[P >> 2] | 0) + 8 + (((c[y >> 2] | 0) * 5 | 0) + 1 << 2) >> 2];
	                        do if ((c[q >> 2] | 0) == 0 ? (c[p >> 2] | 0) == (c[(c[j >> 2] | 0) + 316 >> 2] | 0) : 0) {
	                            c[z >> 2] = 1;
	                            while (1) {
	                                if ((c[z >> 2] | 0) > (c[A >> 2] | 0))break;
	                                if (!(c[(c[(c[j >> 2] | 0) + 336 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 328 >> 2] | 0) - (c[z >> 2] << 1) << 2) >> 2] | 0))break;
	                                c[z >> 2] = (c[z >> 2] | 0) + 1
	                            }
	                            if (((c[z >> 2] | 0) > (c[A >> 2] | 0) ? (c[r >> 2] = hh(c[j >> 2] | 0, 0) | 0, (c[r >> 2] | 0) != (c[(c[P >> 2] | 0) + 8 + (((c[y >> 2] | 0) * 5 | 0) + 2 << 2) >> 2] | 0)) : 0) ? (ih(c[j >> 2] | 0, 0, c[(c[P >> 2] | 0) + 8 + (((c[y >> 2] | 0) * 5 | 0) + 2 << 2) >> 2] | 0) | 0) > 0 : 0)c[A >> 2] = (c[A >> 2] | 0) + 1
	                        } else {
	                            if ((c[q >> 2] | 0) == (c[(c[j >> 2] | 0) + 316 >> 2] | 0)) {
	                                c[z >> 2] = 1;
	                                while (1) {
	                                    if ((c[z >> 2] | 0) > (c[A >> 2] | 0))break;
	                                    if ((c[(c[(c[j >> 2] | 0) + 336 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 328 >> 2] | 0) - (c[z >> 2] << 1) << 2) >> 2] | 0) == (c[p >> 2] | 0))break;
	                                    c[z >> 2] = (c[z >> 2] | 0) + 1
	                                }
	                                if ((c[z >> 2] | 0) <= (c[A >> 2] | 0))break;
	                                c[r >> 2] = hh(c[j >> 2] | 0, c[p >> 2] | 0) | 0;
	                                if ((c[r >> 2] | 0) == (c[(c[P >> 2] | 0) + 16 >> 2] | 0))break;
	                                if ((ih(c[j >> 2] | 0, c[p >> 2] | 0, c[(c[P >> 2] | 0) + 8 + (((c[y >> 2] | 0) * 5 | 0) + 2 << 2) >> 2] | 0) | 0) <= 0)break;
	                                c[A >> 2] = (c[A >> 2] | 0) + 1;
	                                break
	                            }
	                            c[z >> 2] = 0;
	                            while (1) {
	                                if ((c[z >> 2] | 0) >= (c[w >> 2] | 0))break;
	                                if ((c[p >> 2] | 0) == (c[(c[t >> 2] | 0) + (c[z >> 2] << 2) >> 2] | 0) ? (c[q >> 2] | 0) == (c[(c[t >> 2] | 0) + ((c[z >> 2] | 0) + 1 << 2) >> 2] | 0) : 0)break;
	                                c[z >> 2] = (c[z >> 2] | 0) + 5
	                            }
	                            if ((c[z >> 2] | 0) >= (c[w >> 2] | 0)) {
	                                if (!((c[t >> 2] | 0) != 0 ? ((c[w >> 2] | 0) + 5 | 0) <= (c[u >> 2] | 0) : 0)) {
	                                    if ((qh(c[j >> 2] | 0, (c[w >> 2] | 0) + 5 | 0) | 0) < 0)break h;
	                                    c[u >> 2] = c[(c[j >> 2] | 0) + 304 >> 2];
	                                    c[t >> 2] = c[(c[j >> 2] | 0) + 300 >> 2]
	                                }
	                                s = c[p >> 2] | 0;
	                                K = c[w >> 2] | 0;
	                                c[w >> 2] = K + 1;
	                                c[(c[t >> 2] | 0) + (K << 2) >> 2] = s;
	                                s = c[q >> 2] | 0;
	                                K = c[w >> 2] | 0;
	                                c[w >> 2] = K + 1;
	                                c[(c[t >> 2] | 0) + (K << 2) >> 2] = s;
	                                if (!(c[q >> 2] | 0)) {
	                                    s = c[w >> 2] | 0;
	                                    c[w >> 2] = s + 1;
	                                    c[(c[t >> 2] | 0) + (s << 2) >> 2] = 0
	                                } else {
	                                    s = hh(c[j >> 2] | 0, c[q >> 2] | 0) | 0;
	                                    K = c[w >> 2] | 0;
	                                    c[w >> 2] = K + 1;
	                                    c[(c[t >> 2] | 0) + (K << 2) >> 2] = s
	                                }
	                                s = c[(c[P >> 2] | 0) + 8 + (((c[y >> 2] | 0) * 5 | 0) + 2 << 2) >> 2] | 0;
	                                K = c[w >> 2] | 0;
	                                c[w >> 2] = K + 1;
	                                c[(c[t >> 2] | 0) + (K << 2) >> 2] = s;
	                                s = c[(c[P >> 2] | 0) + 8 + (((c[y >> 2] | 0) * 5 | 0) + 3 << 2) >> 2] | 0;
	                                K = c[w >> 2] | 0;
	                                c[w >> 2] = K + 1;
	                                c[(c[t >> 2] | 0) + (K << 2) >> 2] = s;
	                                if ((c[(c[j >> 2] | 0) + 28 >> 2] | 0) == 1 ? (c[(c[P >> 2] | 0) + 8 + (((c[y >> 2] | 0) * 5 | 0) + 4 << 2) >> 2] | 0) != 0 : 0)qg(c[j >> 2] | 0, 538, 71488, c[p >> 2] | 0, c[n >> 2] | 0);
	                                c[x >> 2] = (c[x >> 2] | 0) + 1
	                            }
	                        } while (0);
	                        c[y >> 2] = (c[y >> 2] | 0) + 1
	                    }
	                    c[h >> 2] = 0;
	                    Q = c[h >> 2] | 0;
	                    i = g;
	                    return Q | 0
	                } while (0);
	                c[y >> 2] = 0;
	                while (1) {
	                    if ((c[y >> 2] | 0) >= (c[w >> 2] | 0))break;
	                    if (c[(c[t >> 2] | 0) + ((c[y >> 2] | 0) + 1 << 2) >> 2] | 0) {
	                        c[r >> 2] = hh(c[j >> 2] | 0, c[(c[t >> 2] | 0) + ((c[y >> 2] | 0) + 1 << 2) >> 2] | 0) | 0;
	                        if (!(c[r >> 2] | 0))Jg(c[j >> 2] | 0, 201, 71552, c[(c[t >> 2] | 0) + ((c[y >> 2] | 0) + 1 << 2) >> 2] | 0, c[(c[t >> 2] | 0) + (c[y >> 2] << 2) >> 2] | 0, c[n >> 2] | 0);
	                        c[(c[t >> 2] | 0) + ((c[y >> 2] | 0) + 2 << 2) >> 2] = c[r >> 2]
	                    } else c[r >> 2] = 0;
	                    c[z >> 2] = 0;
	                    while (1) {
	                        if ((c[z >> 2] | 0) >= (c[y >> 2] | 0))break;
	                        if ((c[(c[t >> 2] | 0) + (c[y >> 2] << 2) >> 2] | 0) == (c[(c[t >> 2] | 0) + (c[z >> 2] << 2) >> 2] | 0)) {
	                            if ((c[(c[t >> 2] | 0) + ((c[y >> 2] | 0) + 1 << 2) >> 2] | 0) == (c[(c[t >> 2] | 0) + ((c[z >> 2] | 0) + 1 << 2) >> 2] | 0)) {
	                                S = 189;
	                                break
	                            }
	                            if ((c[r >> 2] | 0) != 0 ? (c[(c[t >> 2] | 0) + ((c[z >> 2] | 0) + 2 << 2) >> 2] | 0) == (c[r >> 2] | 0) : 0) {
	                                S = 192;
	                                break
	                            }
	                        }
	                        c[z >> 2] = (c[z >> 2] | 0) + 5
	                    }
	                    if ((S | 0) == 189) {
	                        S = 0;
	                        Vg(c[j >> 2] | 0, c[(c[t >> 2] | 0) + ((c[y >> 2] | 0) + 1 << 2) >> 2] | 0, c[(c[t >> 2] | 0) + (c[y >> 2] << 2) >> 2] | 0)
	                    } else if ((S | 0) == 192) {
	                        S = 0;
	                        Jg(c[j >> 2] | 0, 203, 71608, c[(c[t >> 2] | 0) + (c[y >> 2] << 2) >> 2] | 0, c[r >> 2] | 0, 0)
	                    }
	                    c[y >> 2] = (c[y >> 2] | 0) + 5
	                }
	                c[r >> 2] = hh(c[j >> 2] | 0, c[o >> 2] | 0) | 0;
	                if ((c[o >> 2] | 0) != 0 & (c[r >> 2] | 0) == 0)Jg(c[j >> 2] | 0, 201, 71656, c[o >> 2] | 0, c[n >> 2] | 0, 0);
	                c[c[k >> 2] >> 2] = c[o >> 2];
	                c[c[l >> 2] >> 2] = c[r >> 2];
	                do if (((c[c[j >> 2] >> 2] | 0) != 0 ? (c[(c[c[j >> 2] >> 2] | 0) + 116 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 212 >> 2] | 0) == 0 : 0) {
	                    l = c[(c[c[j >> 2] >> 2] | 0) + 116 >> 2] | 0;
	                    k = c[(c[j >> 2] | 0) + 4 >> 2] | 0;
	                    S = c[n >> 2] | 0;
	                    p = c[o >> 2] | 0;
	                    P = c[r >> 2] | 0;
	                    if ((c[A >> 2] | 0) > 0) {
	                        Eb[l & 511](k, S, p, P, c[A >> 2] | 0, (c[(c[j >> 2] | 0) + 336 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 328 >> 2] | 0) - (c[A >> 2] << 1) << 2) | 0, (c[w >> 2] | 0) / 5 | 0, c[x >> 2] | 0, c[t >> 2] | 0);
	                        break
	                    } else {
	                        Eb[l & 511](k, S, p, P, 0, 0, (c[w >> 2] | 0) / 5 | 0, c[x >> 2] | 0, c[t >> 2] | 0);
	                        break
	                    }
	                } while (0);
	                i:do if (c[B >> 2] | 0) {
	                    c[y >> 2] = 3;
	                    c[z >> 2] = 0;
	                    while (1) {
	                        if ((c[z >> 2] | 0) >= (c[v >> 2] | 0))break i;
	                        if ((c[(c[(c[j >> 2] | 0) + 340 >> 2] | 0) + (c[z >> 2] << 2) >> 2] | 0) != 0 ? (c[(c[t >> 2] | 0) + (c[y >> 2] << 2) >> 2] | 0) != 0 : 0)zb[c[135736 >> 2] & 511](c[(c[t >> 2] | 0) + (c[y >> 2] << 2) >> 2] | 0);
	                        c[y >> 2] = (c[y >> 2] | 0) + 5;
	                        c[z >> 2] = (c[z >> 2] | 0) + 1
	                    }
	                } while (0);
	                c[h >> 2] = c[n >> 2];
	                Q = c[h >> 2] | 0;
	                i = g;
	                return Q | 0
	            }

	            function Zg(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if ((c[(c[e >> 2] | 0) + 236 >> 2] | 0) <= 0) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = (c[e >> 2] | 0) + 236 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + -1;
	                a = c[e >> 2] | 0;
	                if ((c[(c[e >> 2] | 0) + 236 >> 2] | 0) > 0)c[(c[e >> 2] | 0) + 232 >> 2] = (c[(c[e >> 2] | 0) + 244 >> 2] | 0) + ((c[a + 236 >> 2] | 0) - 1 << 2); else c[(c[e >> 2] | 0) + 232 >> 2] = c[a + 244 >> 2];
	                c[f >> 2] = c[(c[(c[e >> 2] | 0) + 244 >> 2] | 0) + (c[(c[e >> 2] | 0) + 236 >> 2] << 2) >> 2];
	                c[(c[(c[e >> 2] | 0) + 244 >> 2] | 0) + (c[(c[e >> 2] | 0) + 236 >> 2] << 2) >> 2] = -1;
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function _g(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                if (!(c[(c[g >> 2] | 0) + 336 >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                if ((c[(c[g >> 2] | 0) + 328 >> 2] | 0) < (c[h >> 2] | 0)) {
	                    b = c[33976] | 0;
	                    a = c[33980] | 0;
	                    c[e >> 2] = c[h >> 2];
	                    Db[b & 511](a, 70928, e);
	                    c[h >> 2] = c[(c[g >> 2] | 0) + 328 >> 2]
	                }
	                if ((c[(c[g >> 2] | 0) + 328 >> 2] | 0) <= 0) {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                c[j >> 2] = 0;
	                while (1) {
	                    if ((c[j >> 2] | 0) >= (c[h >> 2] | 0))break;
	                    e = (c[g >> 2] | 0) + 328 | 0;
	                    c[e >> 2] = (c[e >> 2] | 0) + -1;
	                    c[(c[(c[g >> 2] | 0) + 336 >> 2] | 0) + (c[(c[g >> 2] | 0) + 328 >> 2] << 2) >> 2] = 0;
	                    c[j >> 2] = (c[j >> 2] | 0) + 1
	                }
	                c[f >> 2] = c[h >> 2];
	                k = c[f >> 2] | 0;
	                i = d;
	                return k | 0
	            }

	            function $g(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h;
	                k = h + 32 | 0;
	                l = h + 28 | 0;
	                m = h + 24 | 0;
	                n = h + 20 | 0;
	                o = h + 16 | 0;
	                p = h + 12 | 0;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                if (((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 212 >> 2] | 0) != 0 : 0) ? (c[(c[k >> 2] | 0) + 172 >> 2] | 0) == -1 : 0) {
	                    i = h;
	                    return
	                }
	                if (c[k >> 2] | 0)c[(c[k >> 2] | 0) + 84 >> 2] = c[l >> 2];
	                g = c[k >> 2] | 0;
	                f = c[l >> 2] | 0;
	                l = c[n >> 2] | 0;
	                e = c[p >> 2] | 0;
	                d = c[o >> 2] | 0;
	                b = c[m >> 2] | 0;
	                m = c[o >> 2] | 0;
	                o = c[p >> 2] | 0;
	                c[j >> 2] = c[n >> 2];
	                c[j + 4 >> 2] = m;
	                c[j + 8 >> 2] = o;
	                Xd(0, 0, 0, g, 0, 1, f, 3, 0, 0, l, e, 0, d, 0, b, j);
	                if (!(c[k >> 2] | 0)) {
	                    i = h;
	                    return
	                }
	                c[(c[k >> 2] | 0) + 12 >> 2] = 0;
	                if (c[(c[k >> 2] | 0) + 288 >> 2] | 0) {
	                    i = h;
	                    return
	                }
	                c[(c[k >> 2] | 0) + 212 >> 2] = 1;
	                i = h;
	                return
	            }

	            function ah(a, b, f, g, h, j) {
	                a = a | 0;
	                b = b | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                var k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                k = i;
	                i = i + 32 | 0;
	                l = k + 24 | 0;
	                m = k + 20 | 0;
	                n = k + 16 | 0;
	                o = k + 12 | 0;
	                p = k + 8 | 0;
	                q = k + 4 | 0;
	                r = k;
	                c[l >> 2] = a;
	                c[m >> 2] = b;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                c[p >> 2] = h;
	                c[q >> 2] = j;
	                if ((c[(c[l >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[l >> 2] | 0);
	                if ((d[c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 47 : 0) {
	                    j = (c[l >> 2] | 0) + 200 | 0;
	                    c[j >> 2] = (c[j >> 2] | 0) + 2;
	                    j = (c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[j >> 2] = (c[j >> 2] | 0) + 2;
	                    j = (c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[j >> 2] = (c[j >> 2] | 0) + 2;
	                    if ((d[c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[l >> 2] | 0);
	                    if ((d[c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[l >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[l >> 2] | 0) | 0;
	                    do if ((c[q >> 2] | 0) > 0 ? (sy(c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0, c[(c[l >> 2] | 0) + 184 >> 2] | 0, c[q >> 2] | 0) | 0) == 0 : 0) {
	                        j = c[q >> 2] | 0;
	                        if ((d[(c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + (c[q >> 2] | 0) >> 0] | 0 | 0) == 62) {
	                            h = (c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                            c[h >> 2] = (c[h >> 2] | 0) + (j + 1);
	                            h = (c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                            c[h >> 2] = (c[h >> 2] | 0) + ((c[q >> 2] | 0) + 1);
	                            break
	                        } else {
	                            h = (c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                            c[h >> 2] = (c[h >> 2] | 0) + j;
	                            j = (c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                            c[j >> 2] = (c[j >> 2] | 0) + (c[q >> 2] | 0);
	                            c[r >> 2] = 1;
	                            s = 20;
	                            break
	                        }
	                    } else s = 17; while (0);
	                    do if ((s | 0) == 17) {
	                        q = c[l >> 2] | 0;
	                        j = c[(c[l >> 2] | 0) + 184 >> 2] | 0;
	                        if (!(c[m >> 2] | 0)) {
	                            c[r >> 2] = mh(q, j) | 0;
	                            s = 20;
	                            break
	                        } else {
	                            c[r >> 2] = rh(q, j, c[m >> 2] | 0) | 0;
	                            s = 20;
	                            break
	                        }
	                    } while (0);
	                    if ((s | 0) == 20) {
	                        if ((c[(c[l >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[l >> 2] | 0);
	                        if ((c[(c[l >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                            i = k;
	                            return
	                        }
	                        Ue(c[l >> 2] | 0) | 0;
	                        if (9 <= (d[c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)s = 28; else if ((d[c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13 ? 32 > (d[c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) : 0)s = 29; else s = 28;
	                        if ((s | 0) == 28)if ((d[c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 62) {
	                            j = (c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                            c[j >> 2] = (c[j >> 2] | 0) + 1;
	                            j = (c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                            c[j >> 2] = (c[j >> 2] | 0) + 1;
	                            j = (c[l >> 2] | 0) + 200 | 0;
	                            c[j >> 2] = (c[j >> 2] | 0) + 1;
	                            if (!(d[c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0))ke(c[(c[l >> 2] | 0) + 36 >> 2] | 0, 250) | 0
	                        } else s = 29;
	                        if ((s | 0) == 29)og(c[l >> 2] | 0, 73, 0);
	                        if ((c[r >> 2] | 0) != 1) {
	                            if (!(c[r >> 2] | 0))c[r >> 2] = 70752;
	                            if ((c[o >> 2] | 0) == 0 ? (c[(c[l >> 2] | 0) + 52 >> 2] | 0) != 0 : 0)c[o >> 2] = e[(c[(c[l >> 2] | 0) + 52 >> 2] | 0) + 56 >> 1];
	                            $g(c[l >> 2] | 0, 76, 70768, c[(c[l >> 2] | 0) + 184 >> 2] | 0, c[o >> 2] | 0, c[r >> 2] | 0)
	                        }
	                    }
	                    if (((c[c[l >> 2] >> 2] | 0) != 0 ? (c[(c[c[l >> 2] >> 2] | 0) + 120 >> 2] | 0) != 0 : 0) ? (c[(c[l >> 2] | 0) + 212 >> 2] | 0) == 0 : 0)Jb[c[(c[c[l >> 2] >> 2] | 0) + 120 >> 2] & 511](c[(c[l >> 2] | 0) + 4 >> 2] | 0, c[(c[l >> 2] | 0) + 184 >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0);
	                    Zg(c[l >> 2] | 0) | 0;
	                    if (!(c[p >> 2] | 0)) {
	                        i = k;
	                        return
	                    }
	                    _g(c[l >> 2] | 0, c[p >> 2] | 0) | 0;
	                    i = k;
	                    return
	                }
	                og(c[l >> 2] | 0, 74, 0);
	                i = k;
	                return
	            }

	            function bh(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 91) {
	                    c[(c[e >> 2] | 0) + 172 >> 2] = 3;
	                    me(c[e >> 2] | 0);
	                    while (1) {
	                        if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 93)break;
	                        if ((c[(c[e >> 2] | 0) + 172 >> 2] | 0) == -1)break;
	                        c[f >> 2] = c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                        c[g >> 2] = c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 36 >> 2];
	                        Ue(c[e >> 2] | 0) | 0;
	                        yf(c[e >> 2] | 0);
	                        zf(c[e >> 2] | 0);
	                        while (1) {
	                            if (!(d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0))h = (c[(c[e >> 2] | 0) + 40 >> 2] | 0) > 1; else h = 0;
	                            j = c[e >> 2] | 0;
	                            if (!h)break;
	                            Ve(j) | 0
	                        }
	                        if ((c[(c[j + 36 >> 2] | 0) + 16 >> 2] | 0) != (c[f >> 2] | 0))continue;
	                        if ((c[g >> 2] | 0) == (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 36 >> 2] | 0)) {
	                            k = 12;
	                            break
	                        }
	                    }
	                    if ((k | 0) == 12)og(c[e >> 2] | 0, 1, 70688);
	                    if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 93) {
	                        me(c[e >> 2] | 0);
	                        Ue(c[e >> 2] | 0) | 0
	                    }
	                }
	                if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 62) {
	                    l = c[e >> 2] | 0;
	                    me(l);
	                    i = b;
	                    return
	                }
	                og(c[e >> 2] | 0, 61, 0);
	                l = c[e >> 2] | 0;
	                me(l);
	                i = b;
	                return
	            }

	            function ch(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[(c[d >> 2] | 0) + 352 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                Xj(c[(c[d >> 2] | 0) + 352 >> 2] | 0, 228, c[d >> 2] | 0);
	                if ($j(c[(c[d >> 2] | 0) + 352 >> 2] | 0) | 0) {
	                    i = b;
	                    return
	                }
	                Kj(c[(c[d >> 2] | 0) + 352 >> 2] | 0, 0);
	                c[(c[d >> 2] | 0) + 352 >> 2] = 0;
	                i = b;
	                return
	            }

	            function dh(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0, J = 0, K = 0, L = 0, M = 0, N = 0, O = 0, P = 0, Q = 0, R = 0, S = 0, T = 0, U = 0, V = 0, W = 0, X = 0;
	                f = i;
	                i = i + 288 | 0;
	                g = f;
	                h = f + 124 | 0;
	                j = f + 120 | 0;
	                k = f + 116 | 0;
	                l = f + 112 | 0;
	                m = f + 108 | 0;
	                n = f + 104 | 0;
	                o = f + 285 | 0;
	                p = f + 284 | 0;
	                q = f + 100 | 0;
	                r = f + 96 | 0;
	                s = f + 92 | 0;
	                t = f + 88 | 0;
	                u = f + 280 | 0;
	                v = f + 84 | 0;
	                w = f + 80 | 0;
	                x = f + 76 | 0;
	                y = f + 72 | 0;
	                z = f + 68 | 0;
	                A = f + 64 | 0;
	                B = f + 60 | 0;
	                C = f + 56 | 0;
	                D = f + 52 | 0;
	                E = f + 48 | 0;
	                F = f + 44 | 0;
	                G = f + 40 | 0;
	                H = f + 36 | 0;
	                I = f + 32 | 0;
	                J = f + 28 | 0;
	                K = f + 24 | 0;
	                L = f + 278 | 0;
	                M = f + 20 | 0;
	                N = f + 16 | 0;
	                O = f + 128 | 0;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[l >> 2] = 0;
	                if (!(c[(c[j >> 2] | 0) + 36 >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    P = c[h >> 2] | 0;
	                    i = f;
	                    return P | 0
	                }
	                if ((c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 ? ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 4096 : 0) {
	                    Fg(c[j >> 2] | 0);
	                    c[(c[j >> 2] | 0) + 204 >> 2] = 0
	                }
	                th(c[j >> 2] | 0, q, r);
	                a:while (1) {
	                    if ((c[(c[j >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                        Q = 407;
	                        break
	                    }
	                    if ((c[(c[j >> 2] | 0) + 84 >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 212 >> 2] | 0) == 1 : 0) {
	                        Q = 10;
	                        break
	                    }
	                    while (1) {
	                        if (!(d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0))R = (c[(c[j >> 2] | 0) + 40 >> 2] | 0) > 1; else R = 0;
	                        S = c[j >> 2] | 0;
	                        if (!R)break;
	                        Ve(S) | 0
	                    }
	                    if (!(c[S + 36 >> 2] | 0)) {
	                        Q = 407;
	                        break
	                    }
	                    e = c[j >> 2] | 0;
	                    if (!(c[c[(c[j >> 2] | 0) + 36 >> 2] >> 2] | 0))c[m >> 2] = (c[(c[e + 36 >> 2] | 0) + 24 >> 2] | 0) - ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0)); else {
	                        if (((c[e + 172 >> 2] | 0) != 0 ? (c[(c[c[(c[j >> 2] | 0) + 36 >> 2] >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) ? (az(c[(c[c[(c[j >> 2] | 0) + 36 >> 2] >> 2] | 0) + 20 >> 2] | 0) | 0) == 0 : 0) {
	                            c[s >> 2] = jz(c[(c[c[(c[j >> 2] | 0) + 36 >> 2] >> 2] | 0) + 16 >> 2] | 0, c[(c[j >> 2] | 0) + 36 >> 2] | 0) | 0;
	                            c[t >> 2] = (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0);
	                            Lk(c[c[(c[j >> 2] | 0) + 36 >> 2] >> 2] | 0, 0, 65640) | 0;
	                            kz(c[(c[c[(c[j >> 2] | 0) + 36 >> 2] >> 2] | 0) + 16 >> 2] | 0, c[(c[j >> 2] | 0) + 36 >> 2] | 0, c[s >> 2] | 0, c[t >> 2] | 0) | 0
	                        }
	                        e = _y(c[(c[c[(c[j >> 2] | 0) + 36 >> 2] >> 2] | 0) + 16 >> 2] | 0) | 0;
	                        c[m >> 2] = e - ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0))
	                    }
	                    if ((c[m >> 2] | 0) < 1) {
	                        Q = 407;
	                        break
	                    }
	                    do switch (c[(c[j >> 2] | 0) + 172 >> 2] | 0) {
	                        case 1:
	                        {
	                            Ue(c[j >> 2] | 0) | 0;
	                            e = c[(c[j >> 2] | 0) + 36 >> 2] | 0;
	                            if (!(c[c[(c[j >> 2] | 0) + 36 >> 2] >> 2] | 0))c[m >> 2] = (c[e + 24 >> 2] | 0) - ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0)); else {
	                                b = _y(c[(c[e >> 2] | 0) + 16 >> 2] | 0) | 0;
	                                c[m >> 2] = b - ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0))
	                            }
	                            if ((c[m >> 2] | 0) < 2) {
	                                Q = 407;
	                                break a
	                            }
	                            a[o >> 0] = a[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                            a[p >> 0] = a[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0;
	                            if ((d[o >> 0] | 0 | 0) == 60 ? (d[p >> 0] | 0 | 0) == 63 : 0) {
	                                if ((c[k >> 2] | 0) == 0 ? (uh(c[j >> 2] | 0, 63, 62, 0) | 0) < 0 : 0) {
	                                    Q = 265;
	                                    break a
	                                }
	                                mf(c[j >> 2] | 0);
	                                if ((c[(c[j >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                                    Q = 407;
	                                    break a
	                                }
	                                c[(c[j >> 2] | 0) + 172 >> 2] = 1;
	                                c[(c[j >> 2] | 0) + 292 >> 2] = 1;
	                                c[(c[j >> 2] | 0) + 204 >> 2] = 0;
	                                continue a
	                            }
	                            if ((((d[o >> 0] | 0 | 0) == 60 ? (d[p >> 0] | 0 | 0) == 33 : 0) ? (d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 45 : 0) ? (d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 45 : 0) {
	                                if ((c[k >> 2] | 0) == 0 ? (uh(c[j >> 2] | 0, 45, 45, 62) | 0) < 0 : 0) {
	                                    Q = 274;
	                                    break a
	                                }
	                                kf(c[j >> 2] | 0);
	                                if ((c[(c[j >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                                    Q = 407;
	                                    break a
	                                }
	                                c[(c[j >> 2] | 0) + 172 >> 2] = 1;
	                                c[(c[j >> 2] | 0) + 292 >> 2] = 1;
	                                c[(c[j >> 2] | 0) + 204 >> 2] = 0;
	                                continue a
	                            }
	                            do if ((((((d[o >> 0] | 0 | 0) == 60 ? (d[p >> 0] | 0 | 0) == 33 : 0) ? (d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 68 : 0) ? (d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 79 : 0) ? (d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) == 67 : 0) ? (d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) == 84 : 0) {
	                                if ((d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 6 >> 0] | 0 | 0) != 89)break;
	                                if ((d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 7 >> 0] | 0 | 0) != 80)break;
	                                if ((d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 8 >> 0] | 0 | 0) != 69)break;
	                                if ((c[k >> 2] | 0) == 0 ? (uh(c[j >> 2] | 0, 62, 0, 0) | 0) < 0 : 0) {
	                                    Q = 288;
	                                    break a
	                                }
	                                c[(c[j >> 2] | 0) + 216 >> 2] = 1;
	                                c[(c[j >> 2] | 0) + 292 >> 2] = 0;
	                                c[(c[j >> 2] | 0) + 204 >> 2] = 0;
	                                Ff(c[j >> 2] | 0);
	                                if ((c[(c[j >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                                    Q = 407;
	                                    break a
	                                }
	                                b = c[j >> 2] | 0;
	                                if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 91) {
	                                    c[b + 172 >> 2] = 3;
	                                    continue a
	                                }
	                                c[b + 216 >> 2] = 2;
	                                do if (c[c[j >> 2] >> 2] | 0) {
	                                    if (c[(c[j >> 2] | 0) + 212 >> 2] | 0)break;
	                                    if (!(c[(c[c[j >> 2] >> 2] | 0) + 104 >> 2] | 0))break;
	                                    Jb[c[(c[c[j >> 2] >> 2] | 0) + 104 >> 2] & 511](c[(c[j >> 2] | 0) + 4 >> 2] | 0, c[(c[j >> 2] | 0) + 220 >> 2] | 0, c[(c[j >> 2] | 0) + 228 >> 2] | 0, c[(c[j >> 2] | 0) + 224 >> 2] | 0)
	                                } while (0);
	                                c[(c[j >> 2] | 0) + 216 >> 2] = 0;
	                                ch(c[j >> 2] | 0);
	                                c[(c[j >> 2] | 0) + 172 >> 2] = 4;
	                                continue a
	                            } while (0);
	                            if ((d[o >> 0] | 0 | 0) == 60 ? (d[p >> 0] | 0 | 0) == 33 & (c[m >> 2] | 0) < 9 : 0) {
	                                Q = 407;
	                                break a
	                            }
	                            c[(c[j >> 2] | 0) + 172 >> 2] = 6;
	                            c[(c[j >> 2] | 0) + 292 >> 2] = 6;
	                            th(c[j >> 2] | 0, q, r);
	                            continue a;
	                            break
	                        }
	                        case 9:
	                        {
	                            if ((c[m >> 2] | 0) < 2) {
	                                Q = 407;
	                                break a
	                            }
	                            do if (!(c[k >> 2] | 0)) {
	                                if (!(c[(c[j >> 2] | 0) + 292 >> 2] | 0))if ((uh(c[j >> 2] | 0, 62, 0, 0) | 0) < 0) {
	                                    Q = 407;
	                                    break a
	                                } else break;
	                                if (!(c[r >> 2] | 0)) {
	                                    Q = 407;
	                                    break a
	                                }
	                                if ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) >>> 0 >= (c[r >> 2] | 0) >>> 0) {
	                                    Q = 407;
	                                    break a
	                                }
	                            } while (0);
	                            b = c[j >> 2] | 0;
	                            if (c[(c[j >> 2] | 0) + 324 >> 2] | 0) {
	                                ah(b, c[(c[(c[j >> 2] | 0) + 344 >> 2] | 0) + (((c[(c[j >> 2] | 0) + 188 >> 2] | 0) * 3 | 0) - 3 << 2) >> 2] | 0, c[(c[(c[j >> 2] | 0) + 344 >> 2] | 0) + (((c[(c[j >> 2] | 0) + 188 >> 2] | 0) * 3 | 0) - 2 << 2) >> 2] | 0, 0, c[(c[(c[j >> 2] | 0) + 344 >> 2] | 0) + (((c[(c[j >> 2] | 0) + 188 >> 2] | 0) * 3 | 0) - 1 << 2) >> 2] | 0, 0);
	                                wh(c[j >> 2] | 0) | 0
	                            } else Wg(b, 0);
	                            if ((c[(c[j >> 2] | 0) + 172 >> 2] | 0) == -1)continue a;
	                            b = (c[j >> 2] | 0) + 172 | 0;
	                            if (!(c[(c[j >> 2] | 0) + 188 >> 2] | 0)) {
	                                c[b >> 2] = 14;
	                                continue a
	                            } else {
	                                c[b >> 2] = 7;
	                                continue a
	                            }
	                            break
	                        }
	                        case 8:
	                        {
	                            c[D >> 2] = uh(c[j >> 2] | 0, 93, 93, 62) | 0;
	                            if ((c[D >> 2] | 0) < 0) {
	                                Q = 207;
	                                break a
	                            }
	                            c[G >> 2] = xh(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0, c[D >> 2] | 0) | 0;
	                            if ((c[G >> 2] | 0) < 0) {
	                                Q = 231;
	                                break a
	                            }
	                            if ((c[G >> 2] | 0) != (c[D >> 2] | 0)) {
	                                Q = 231;
	                                break a
	                            }
	                            if ((((c[D >> 2] | 0) == 0 ? (c[c[j >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[c[j >> 2] >> 2] | 0) + 100 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 212 >> 2] | 0) == 0 : 0) {
	                                if (((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) >= 9 ? (QT((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + -9 | 0, 70176, 9) | 0) == 0 : 0)Db[c[(c[c[j >> 2] >> 2] | 0) + 100 >> 2] & 511](c[(c[j >> 2] | 0) + 4 >> 2] | 0, 65640, 0)
	                            } else Q = 238;
	                            do if (((Q | 0) == 238 ? (Q = 0, (c[D >> 2] | 0) > 0 ? (c[c[j >> 2] >> 2] | 0) != 0 : 0) : 0) ? (c[(c[j >> 2] | 0) + 212 >> 2] | 0) == 0 : 0) {
	                                b = c[c[j >> 2] >> 2] | 0;
	                                if (c[(c[c[j >> 2] >> 2] | 0) + 100 >> 2] | 0) {
	                                    Db[c[b + 100 >> 2] & 511](c[(c[j >> 2] | 0) + 4 >> 2] | 0, c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0, c[D >> 2] | 0);
	                                    break
	                                }
	                                if (c[b + 68 >> 2] | 0)Db[c[(c[c[j >> 2] >> 2] | 0) + 68 >> 2] & 511](c[(c[j >> 2] | 0) + 4 >> 2] | 0, c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0, c[D >> 2] | 0)
	                            } while (0);
	                            if ((c[(c[j >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                                Q = 407;
	                                break a
	                            }
	                            c[H >> 2] = 0;
	                            while (1) {
	                                T = d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                                if ((c[H >> 2] | 0) >= ((c[D >> 2] | 0) + 3 | 0))break;
	                                b = c[(c[j >> 2] | 0) + 36 >> 2] | 0;
	                                if ((T | 0) == 10) {
	                                    e = b + 28 | 0;
	                                    c[e >> 2] = (c[e >> 2] | 0) + 1;
	                                    c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                                } else {
	                                    e = b + 32 | 0;
	                                    c[e >> 2] = (c[e >> 2] | 0) + 1
	                                }
	                                e = (c[j >> 2] | 0) + 200 | 0;
	                                c[e >> 2] = (c[e >> 2] | 0) + 1;
	                                e = (c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                                c[e >> 2] = (c[e >> 2] | 0) + 1;
	                                c[H >> 2] = (c[H >> 2] | 0) + 1
	                            }
	                            if ((T | 0) == 37)We(c[j >> 2] | 0);
	                            if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[j >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[j >> 2] | 0) | 0;
	                            c[(c[j >> 2] | 0) + 204 >> 2] = 0;
	                            c[(c[j >> 2] | 0) + 172 >> 2] = 7;
	                            continue a;
	                            break
	                        }
	                        case 0:
	                        {
	                            e = c[m >> 2] | 0;
	                            if (!(c[(c[j >> 2] | 0) + 256 >> 2] | 0)) {
	                                if ((e | 0) < 4) {
	                                    Q = 407;
	                                    break a
	                                }
	                                a[u >> 0] = a[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                                a[u + 1 >> 0] = a[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0;
	                                a[u + 2 >> 0] = a[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0;
	                                a[u + 3 >> 0] = a[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0;
	                                c[v >> 2] = sd(u, 4) | 0;
	                                re(c[j >> 2] | 0, c[v >> 2] | 0) | 0;
	                                continue a
	                            }
	                            if ((e | 0) < 2) {
	                                Q = 407;
	                                break a
	                            }
	                            a[o >> 0] = a[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                            a[p >> 0] = a[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0;
	                            if (!(d[o >> 0] | 0)) {
	                                Q = 30;
	                                break a
	                            }
	                            if ((d[o >> 0] | 0 | 0) == 60 ? (d[p >> 0] | 0 | 0) == 63 : 0) {
	                                if ((c[m >> 2] | 0) < 5) {
	                                    Q = 39;
	                                    break a
	                                }
	                                if ((c[k >> 2] | 0) == 0 ? (uh(c[j >> 2] | 0, 63, 62, 0) | 0) < 0 : 0) {
	                                    Q = 42;
	                                    break a
	                                }
	                                if ((c[c[j >> 2] >> 2] | 0) != 0 ? (c[(c[c[j >> 2] >> 2] | 0) + 44 >> 2] | 0) != 0 : 0)Ab[c[(c[c[j >> 2] >> 2] | 0) + 44 >> 2] & 511](c[(c[j >> 2] | 0) + 4 >> 2] | 0, 136080);
	                                b:do if ((d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 120) {
	                                    if ((d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) != 109)break;
	                                    if ((d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) != 108)break;
	                                    do if ((d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) != 32) {
	                                        if (9 <= (d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) ? (d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) <= 10 : 0)break;
	                                        if ((d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) != 13)break b
	                                    } while (0);
	                                    c[l >> 2] = (c[l >> 2] | 0) + 5;
	                                    Of(c[j >> 2] | 0);
	                                    U = c[j >> 2] | 0;
	                                    if ((c[(c[j >> 2] | 0) + 84 >> 2] | 0) == 32) {
	                                        Q = 54;
	                                        break a
	                                    }
	                                    c[(c[j >> 2] | 0) + 28 >> 2] = c[(c[U + 36 >> 2] | 0) + 52 >> 2];
	                                    do if (!(c[(c[j >> 2] | 0) + 24 >> 2] | 0)) {
	                                        if (!(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 44 >> 2] | 0))break;
	                                        e = my(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 44 >> 2] | 0) | 0;
	                                        c[(c[j >> 2] | 0) + 24 >> 2] = e
	                                    } while (0);
	                                    do if (c[c[j >> 2] >> 2] | 0) {
	                                        if (!(c[(c[c[j >> 2] >> 2] | 0) + 48 >> 2] | 0))break;
	                                        if (c[(c[j >> 2] | 0) + 212 >> 2] | 0)break;
	                                        zb[c[(c[c[j >> 2] >> 2] | 0) + 48 >> 2] & 511](c[(c[j >> 2] | 0) + 4 >> 2] | 0)
	                                    } while (0);
	                                    c[(c[j >> 2] | 0) + 172 >> 2] = 1;
	                                    continue a
	                                } while (0);
	                                e = oy(68488) | 0;
	                                c[(c[j >> 2] | 0) + 20 >> 2] = e;
	                                do if (c[c[j >> 2] >> 2] | 0) {
	                                    if (!(c[(c[c[j >> 2] >> 2] | 0) + 48 >> 2] | 0))break;
	                                    if (c[(c[j >> 2] | 0) + 212 >> 2] | 0)break;
	                                    zb[c[(c[c[j >> 2] >> 2] | 0) + 48 >> 2] & 511](c[(c[j >> 2] | 0) + 4 >> 2] | 0)
	                                } while (0);
	                                c[(c[j >> 2] | 0) + 172 >> 2] = 1;
	                                continue a
	                            }
	                            if ((c[c[j >> 2] >> 2] | 0) != 0 ? (c[(c[c[j >> 2] >> 2] | 0) + 44 >> 2] | 0) != 0 : 0)Ab[c[(c[c[j >> 2] >> 2] | 0) + 44 >> 2] & 511](c[(c[j >> 2] | 0) + 4 >> 2] | 0, 136080);
	                            e = oy(68488) | 0;
	                            c[(c[j >> 2] | 0) + 20 >> 2] = e;
	                            e = c[j >> 2] | 0;
	                            if (!(c[(c[j >> 2] | 0) + 20 >> 2] | 0)) {
	                                ie(e, 0);
	                                continue a
	                            }
	                            if (((c[e >> 2] | 0) != 0 ? (c[(c[c[j >> 2] >> 2] | 0) + 48 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 212 >> 2] | 0) == 0 : 0)zb[c[(c[c[j >> 2] >> 2] | 0) + 48 >> 2] & 511](c[(c[j >> 2] | 0) + 4 >> 2] | 0);
	                            c[(c[j >> 2] | 0) + 172 >> 2] = 1;
	                            continue a;
	                            break
	                        }
	                        case 7:
	                        {
	                            if ((c[m >> 2] | 0) < 2 ? (c[(c[j >> 2] | 0) + 40 >> 2] | 0) == 1 : 0) {
	                                Q = 407;
	                                break a
	                            }
	                            a[o >> 0] = a[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                            a[p >> 0] = a[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0;
	                            c[A >> 2] = c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                            c[B >> 2] = c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 36 >> 2];
	                            if ((d[o >> 0] | 0 | 0) == 60 ? (d[p >> 0] | 0 | 0) == 47 : 0) {
	                                c[(c[j >> 2] | 0) + 172 >> 2] = 9;
	                                continue a
	                            }
	                            if ((d[o >> 0] | 0 | 0) == 60 ? (d[p >> 0] | 0 | 0) == 63 : 0) {
	                                if ((c[k >> 2] | 0) == 0 ? (uh(c[j >> 2] | 0, 63, 62, 0) | 0) < 0 : 0) {
	                                    Q = 147;
	                                    break a
	                                }
	                                mf(c[j >> 2] | 0);
	                                c[(c[j >> 2] | 0) + 172 >> 2] = 7;
	                                c[(c[j >> 2] | 0) + 292 >> 2] = 1
	                            } else Q = 149;
	                            do if ((Q | 0) == 149) {
	                                Q = 0;
	                                if ((d[o >> 0] | 0 | 0) == 60 ? (d[p >> 0] | 0 | 0) != 33 : 0) {
	                                    c[(c[j >> 2] | 0) + 172 >> 2] = 6;
	                                    continue a
	                                }
	                                if ((((d[o >> 0] | 0 | 0) == 60 ? (d[p >> 0] | 0 | 0) == 33 : 0) ? (d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 45 : 0) ? (d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 45 : 0) {
	                                    if ((c[m >> 2] | 0) < 4) {
	                                        Q = 407;
	                                        break a
	                                    }
	                                    e = (c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                                    c[e >> 2] = (c[e >> 2] | 0) + 4;
	                                    c[C >> 2] = uh(c[j >> 2] | 0, 45, 45, 62) | 0;
	                                    e = (c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                                    c[e >> 2] = (c[e >> 2] | 0) + -4;
	                                    V = c[j >> 2] | 0;
	                                    if ((c[k >> 2] | 0) == 0 & (c[C >> 2] | 0) < 0) {
	                                        Q = 158;
	                                        break a
	                                    }
	                                    kf(V);
	                                    c[(c[j >> 2] | 0) + 172 >> 2] = 7;
	                                    c[(c[j >> 2] | 0) + 292 >> 2] = 1;
	                                    break
	                                }
	                                do if ((((d[o >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 33 : 0) ? (d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 91 : 0) ? (d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 67 : 0) {
	                                    if ((d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0 | 0) != 68)break;
	                                    if ((d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0 | 0) != 65)break;
	                                    if ((d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 6 >> 0] | 0 | 0) != 84)break;
	                                    if ((d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 7 >> 0] | 0 | 0) != 65)break;
	                                    if ((d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 8 >> 0] | 0 | 0) != 91)break;
	                                    e = (c[j >> 2] | 0) + 200 | 0;
	                                    c[e >> 2] = (c[e >> 2] | 0) + 9;
	                                    e = (c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                                    c[e >> 2] = (c[e >> 2] | 0) + 9;
	                                    e = (c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                                    c[e >> 2] = (c[e >> 2] | 0) + 9;
	                                    if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[j >> 2] | 0);
	                                    do if (!(d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0)) {
	                                        if ((ke(c[(c[j >> 2] | 0) + 36 >> 2] | 0, 250) | 0) > 0)break;
	                                        Ve(c[j >> 2] | 0) | 0
	                                    } while (0);
	                                    c[(c[j >> 2] | 0) + 172 >> 2] = 8;
	                                    continue a
	                                } while (0);
	                                if ((d[o >> 0] | 0 | 0) == 60 ? (d[p >> 0] | 0 | 0) == 33 & (c[m >> 2] | 0) < 9 : 0) {
	                                    Q = 407;
	                                    break a
	                                }
	                                if ((d[o >> 0] | 0 | 0) == 38) {
	                                    if ((c[k >> 2] | 0) == 0 ? (uh(c[j >> 2] | 0, 59, 0, 0) | 0) < 0 : 0) {
	                                        Q = 407;
	                                        break a
	                                    }
	                                    Df(c[j >> 2] | 0);
	                                    break
	                                }
	                                do if (!(((c[m >> 2] | 0) < 300 ? (c[(c[j >> 2] | 0) + 40 >> 2] | 0) == 1 : 0) ^ 1 | (c[k >> 2] | 0) != 0)) {
	                                    if (!(c[(c[j >> 2] | 0) + 292 >> 2] | 0))if ((uh(c[j >> 2] | 0, 60, 0, 0) | 0) < 0) {
	                                        Q = 407;
	                                        break a
	                                    } else break;
	                                    if (!(c[q >> 2] | 0)) {
	                                        Q = 407;
	                                        break a
	                                    }
	                                    if ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) >>> 0 > (c[q >> 2] | 0) >>> 0) {
	                                        Q = 407;
	                                        break a
	                                    }
	                                } while (0);
	                                c[(c[j >> 2] | 0) + 204 >> 2] = 0;
	                                hf(c[j >> 2] | 0, 0)
	                            } while (0);
	                            while (1) {
	                                if (d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0)break;
	                                if ((c[(c[j >> 2] | 0) + 40 >> 2] | 0) <= 1)break;
	                                Ve(c[j >> 2] | 0) | 0
	                            }
	                            if ((c[B >> 2] | 0) != (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 36 >> 2] | 0))continue a;
	                            if ((c[A >> 2] | 0) != (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0))continue a;
	                            og(c[j >> 2] | 0, 1, 69472);
	                            c[(c[j >> 2] | 0) + 172 >> 2] = -1;
	                            continue a;
	                            break
	                        }
	                        case 6:
	                        {
	                            c[x >> 2] = 0;
	                            c[y >> 2] = 0;
	                            c[z >> 2] = c[(c[j >> 2] | 0) + 328 >> 2];
	                            if ((c[m >> 2] | 0) < 2 ? (c[(c[j >> 2] | 0) + 40 >> 2] | 0) == 1 : 0) {
	                                Q = 407;
	                                break a
	                            }
	                            a[o >> 0] = a[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                            if ((d[o >> 0] | 0 | 0) != 60) {
	                                Q = 81;
	                                break a
	                            }
	                            do if (!(c[k >> 2] | 0)) {
	                                if (!(c[(c[j >> 2] | 0) + 292 >> 2] | 0))if ((uh(c[j >> 2] | 0, 62, 0, 0) | 0) < 0) {
	                                    Q = 407;
	                                    break a
	                                } else break;
	                                if (!(c[r >> 2] | 0)) {
	                                    Q = 407;
	                                    break a
	                                }
	                                if ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) >>> 0 >= (c[r >> 2] | 0) >>> 0) {
	                                    Q = 407;
	                                    break a
	                                }
	                            } while (0);
	                            e = c[j >> 2] | 0;
	                            do if (c[(c[j >> 2] | 0) + 236 >> 2] | 0) {
	                                b = c[j >> 2] | 0;
	                                if ((c[c[e + 232 >> 2] >> 2] | 0) == -2) {
	                                    Xg(b, -1) | 0;
	                                    break
	                                } else {
	                                    Xg(b, c[c[(c[j >> 2] | 0) + 232 >> 2] >> 2] | 0) | 0;
	                                    break
	                                }
	                            } else Xg(e, -1) | 0; while (0);
	                            e = c[j >> 2] | 0;
	                            if (c[(c[j >> 2] | 0) + 324 >> 2] | 0)c[w >> 2] = Yg(e, x, y, n) | 0; else c[w >> 2] = Hf(e) | 0;
	                            if ((c[(c[j >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                                Q = 407;
	                                break a
	                            }
	                            W = c[j >> 2] | 0;
	                            if (!(c[w >> 2] | 0)) {
	                                Q = 99;
	                                break a
	                            }
	                            do if (((c[W + 104 >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                                if (!(c[(c[j >> 2] | 0) + 52 >> 2] | 0))break;
	                                if ((c[(c[j >> 2] | 0) + 52 >> 2] | 0) != (c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + 12 >> 2] | 0))break;
	                                e = an((c[j >> 2] | 0) + 108 | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0) | 0;
	                                b = (c[j >> 2] | 0) + 100 | 0;
	                                c[b >> 2] = c[b >> 2] & e
	                            } while (0);
	                            if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 47 ? (d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 62 : 0) {
	                                e = (c[j >> 2] | 0) + 200 | 0;
	                                c[e >> 2] = (c[e >> 2] | 0) + 2;
	                                e = (c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                                c[e >> 2] = (c[e >> 2] | 0) + 2;
	                                e = (c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                                c[e >> 2] = (c[e >> 2] | 0) + 2;
	                                if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[j >> 2] | 0);
	                                do if (!(d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0)) {
	                                    if ((ke(c[(c[j >> 2] | 0) + 36 >> 2] | 0, 250) | 0) > 0)break;
	                                    Ve(c[j >> 2] | 0) | 0
	                                } while (0);
	                                e = (c[c[j >> 2] >> 2] | 0) != 0;
	                                do if (c[(c[j >> 2] | 0) + 324 >> 2] | 0) {
	                                    do if (e) {
	                                        if (!(c[(c[c[j >> 2] >> 2] | 0) + 120 >> 2] | 0))break;
	                                        if (c[(c[j >> 2] | 0) + 212 >> 2] | 0)break;
	                                        Jb[c[(c[c[j >> 2] >> 2] | 0) + 120 >> 2] & 511](c[(c[j >> 2] | 0) + 4 >> 2] | 0, c[w >> 2] | 0, c[x >> 2] | 0, c[y >> 2] | 0)
	                                    } while (0);
	                                    if (((c[(c[j >> 2] | 0) + 328 >> 2] | 0) - (c[z >> 2] | 0) | 0) <= 0)break;
	                                    _g(c[j >> 2] | 0, (c[(c[j >> 2] | 0) + 328 >> 2] | 0) - (c[z >> 2] | 0) | 0) | 0
	                                } else {
	                                    if (!e)break;
	                                    if (!(c[(c[c[j >> 2] >> 2] | 0) + 60 >> 2] | 0))break;
	                                    if (c[(c[j >> 2] | 0) + 212 >> 2] | 0)break;
	                                    Ab[c[(c[c[j >> 2] >> 2] | 0) + 60 >> 2] & 511](c[(c[j >> 2] | 0) + 4 >> 2] | 0, c[w >> 2] | 0)
	                                } while (0);
	                                if ((c[(c[j >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                                    Q = 407;
	                                    break a
	                                }
	                                Zg(c[j >> 2] | 0) | 0;
	                                e = (c[j >> 2] | 0) + 172 | 0;
	                                if (!(c[(c[j >> 2] | 0) + 188 >> 2] | 0))c[e >> 2] = 14; else c[e >> 2] = 7;
	                                c[(c[j >> 2] | 0) + 292 >> 2] = 1;
	                                continue a
	                            }
	                            e = c[j >> 2] | 0;
	                            if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 62)me(e); else {
	                                pg(e, 73, 70136, c[w >> 2] | 0);
	                                Re(c[j >> 2] | 0) | 0;
	                                Zg(c[j >> 2] | 0) | 0
	                            }
	                            e = c[j >> 2] | 0;
	                            b = c[w >> 2] | 0;
	                            if (c[(c[j >> 2] | 0) + 324 >> 2] | 0)vh(e, b, c[x >> 2] | 0, c[y >> 2] | 0, (c[(c[j >> 2] | 0) + 328 >> 2] | 0) - (c[z >> 2] | 0) | 0) | 0; else Se(e, b) | 0;
	                            c[(c[j >> 2] | 0) + 172 >> 2] = 7;
	                            c[(c[j >> 2] | 0) + 292 >> 2] = 1;
	                            continue a;
	                            break
	                        }
	                        case 4:
	                        {
	                            Ue(c[j >> 2] | 0) | 0;
	                            b = c[(c[j >> 2] | 0) + 36 >> 2] | 0;
	                            if (!(c[c[(c[j >> 2] | 0) + 36 >> 2] >> 2] | 0))c[m >> 2] = (c[b + 24 >> 2] | 0) - ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0)); else {
	                                e = _y(c[(c[b >> 2] | 0) + 16 >> 2] | 0) | 0;
	                                c[m >> 2] = e - ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0))
	                            }
	                            if ((c[m >> 2] | 0) < 2) {
	                                Q = 407;
	                                break a
	                            }
	                            a[o >> 0] = a[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                            a[p >> 0] = a[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0;
	                            if ((d[o >> 0] | 0 | 0) == 60 ? (d[p >> 0] | 0 | 0) == 63 : 0) {
	                                if ((c[k >> 2] | 0) == 0 ? (uh(c[j >> 2] | 0, 63, 62, 0) | 0) < 0 : 0) {
	                                    Q = 308;
	                                    break a
	                                }
	                                mf(c[j >> 2] | 0);
	                                if ((c[(c[j >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                                    Q = 407;
	                                    break a
	                                }
	                                c[(c[j >> 2] | 0) + 172 >> 2] = 4;
	                                c[(c[j >> 2] | 0) + 292 >> 2] = 1;
	                                continue a
	                            }
	                            if ((((d[o >> 0] | 0 | 0) == 60 ? (d[p >> 0] | 0 | 0) == 33 : 0) ? (d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 45 : 0) ? (d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 45 : 0) {
	                                if ((c[k >> 2] | 0) == 0 ? (uh(c[j >> 2] | 0, 45, 45, 62) | 0) < 0 : 0) {
	                                    Q = 317;
	                                    break a
	                                }
	                                kf(c[j >> 2] | 0);
	                                if ((c[(c[j >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                                    Q = 407;
	                                    break a
	                                }
	                                c[(c[j >> 2] | 0) + 172 >> 2] = 4;
	                                c[(c[j >> 2] | 0) + 292 >> 2] = 1;
	                                continue a
	                            }
	                            if ((d[o >> 0] | 0 | 0) == 60 ? (d[p >> 0] | 0 | 0) == 33 & (c[m >> 2] | 0) < 4 : 0) {
	                                Q = 407;
	                                break a
	                            }
	                            c[(c[j >> 2] | 0) + 172 >> 2] = 6;
	                            if (!(c[(c[j >> 2] | 0) + 292 >> 2] | 0))c[(c[j >> 2] | 0) + 292 >> 2] = 6;
	                            th(c[j >> 2] | 0, q, r);
	                            continue a;
	                            break
	                        }
	                        case 14:
	                        {
	                            Ue(c[j >> 2] | 0) | 0;
	                            e = c[(c[j >> 2] | 0) + 36 >> 2] | 0;
	                            if (!(c[c[(c[j >> 2] | 0) + 36 >> 2] >> 2] | 0))c[m >> 2] = (c[e + 24 >> 2] | 0) - ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0)); else {
	                                b = _y(c[(c[e >> 2] | 0) + 16 >> 2] | 0) | 0;
	                                c[m >> 2] = b - ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0))
	                            }
	                            if ((c[m >> 2] | 0) < 2) {
	                                Q = 407;
	                                break a
	                            }
	                            a[o >> 0] = a[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                            a[p >> 0] = a[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0;
	                            if ((d[o >> 0] | 0 | 0) == 60 ? (d[p >> 0] | 0 | 0) == 63 : 0) {
	                                if ((c[k >> 2] | 0) == 0 ? (uh(c[j >> 2] | 0, 63, 62, 0) | 0) < 0 : 0) {
	                                    Q = 333;
	                                    break a
	                                }
	                                mf(c[j >> 2] | 0);
	                                if ((c[(c[j >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                                    Q = 407;
	                                    break a
	                                }
	                                c[(c[j >> 2] | 0) + 172 >> 2] = 14;
	                                c[(c[j >> 2] | 0) + 292 >> 2] = 1;
	                                continue a
	                            }
	                            if ((d[o >> 0] | 0 | 0) != 60) {
	                                Q = 345;
	                                break a
	                            }
	                            if ((d[p >> 0] | 0 | 0) != 33) {
	                                Q = 345;
	                                break a
	                            }
	                            if ((d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) != 45) {
	                                Q = 345;
	                                break a
	                            }
	                            if ((d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) != 45) {
	                                Q = 345;
	                                break a
	                            }
	                            if ((c[k >> 2] | 0) == 0 ? (uh(c[j >> 2] | 0, 45, 45, 62) | 0) < 0 : 0) {
	                                Q = 342;
	                                break a
	                            }
	                            kf(c[j >> 2] | 0);
	                            if ((c[(c[j >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                                Q = 407;
	                                break a
	                            }
	                            c[(c[j >> 2] | 0) + 172 >> 2] = 14;
	                            c[(c[j >> 2] | 0) + 292 >> 2] = 1;
	                            continue a;
	                            break
	                        }
	                        case 3:
	                        {
	                            a[L >> 0] = 0;
	                            c[I >> 2] = (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0);
	                            if ((c[I >> 2] | 0) < 0) {
	                                Q = 351;
	                                break a
	                            }
	                            if ((c[(c[j >> 2] | 0) + 204 >> 2] | 0) > (c[I >> 2] | 0))c[I >> 2] = c[(c[j >> 2] | 0) + 204 >> 2];
	                            c[K >> 2] = Vy(c[(c[c[(c[j >> 2] | 0) + 36 >> 2] >> 2] | 0) + 16 >> 2] | 0) | 0;
	                            c[M >> 2] = _y(c[(c[c[(c[j >> 2] | 0) + 36 >> 2] >> 2] | 0) + 16 >> 2] | 0) | 0;
	                            c:while (1) {
	                                if ((c[I >> 2] | 0) >>> 0 >= (c[M >> 2] | 0) >>> 0) {
	                                    Q = 389;
	                                    break a
	                                }
	                                d:do if (d[L >> 0] | 0) {
	                                    if ((d[(c[K >> 2] | 0) + (c[I >> 2] | 0) >> 0] | 0 | 0) == (d[L >> 0] | 0 | 0))a[L >> 0] = 0
	                                } else {
	                                    do if ((((d[L >> 0] | 0 | 0) == 0 ? (d[(c[K >> 2] | 0) + (c[I >> 2] | 0) >> 0] | 0 | 0) == 60 : 0) ? (c[N >> 2] = 0, ((c[I >> 2] | 0) + 4 | 0) >>> 0 < (c[M >> 2] | 0) >>> 0) : 0) ? (d[(c[K >> 2] | 0) + ((c[I >> 2] | 0) + 1) >> 0] | 0 | 0) == 33 : 0) {
	                                        if ((d[(c[K >> 2] | 0) + ((c[I >> 2] | 0) + 2) >> 0] | 0 | 0) != 45)break;
	                                        if ((d[(c[K >> 2] | 0) + ((c[I >> 2] | 0) + 3) >> 0] | 0 | 0) != 45)break;
	                                        e:while (1) {
	                                            if (((c[I >> 2] | 0) + 3 | 0) >>> 0 >= (c[M >> 2] | 0) >>> 0)break;
	                                            do if ((d[(c[K >> 2] | 0) + (c[I >> 2] | 0) >> 0] | 0 | 0) == 45) {
	                                                if ((d[(c[K >> 2] | 0) + ((c[I >> 2] | 0) + 1) >> 0] | 0 | 0) != 45)break;
	                                                if ((d[(c[K >> 2] | 0) + ((c[I >> 2] | 0) + 2) >> 0] | 0 | 0) == 62) {
	                                                    Q = 369;
	                                                    break e
	                                                }
	                                            } while (0);
	                                            c[I >> 2] = (c[I >> 2] | 0) + 1
	                                        }
	                                        if ((Q | 0) == 369) {
	                                            Q = 0;
	                                            c[N >> 2] = 1;
	                                            c[I >> 2] = (c[I >> 2] | 0) + 2
	                                        }
	                                        if (c[N >> 2] | 0)break d; else {
	                                            Q = 389;
	                                            break a
	                                        }
	                                    } while (0);
	                                    if ((d[(c[K >> 2] | 0) + (c[I >> 2] | 0) >> 0] | 0 | 0) == 34) {
	                                        a[L >> 0] = 34;
	                                        break
	                                    }
	                                    if ((d[(c[K >> 2] | 0) + (c[I >> 2] | 0) >> 0] | 0 | 0) == 39) {
	                                        a[L >> 0] = 39;
	                                        break
	                                    }
	                                    if ((d[(c[K >> 2] | 0) + (c[I >> 2] | 0) >> 0] | 0 | 0) == 93) {
	                                        if (((c[I >> 2] | 0) + 1 | 0) >>> 0 >= (c[M >> 2] | 0) >>> 0) {
	                                            Q = 389;
	                                            break a
	                                        }
	                                        if ((d[(c[K >> 2] | 0) + ((c[I >> 2] | 0) + 1) >> 0] | 0 | 0) == 93) {
	                                            c[I >> 2] = (c[I >> 2] | 0) + 1;
	                                            break
	                                        }
	                                        c[J >> 2] = 1;
	                                        while (1) {
	                                            if (((c[I >> 2] | 0) + (c[J >> 2] | 0) | 0) >>> 0 >= (c[M >> 2] | 0) >>> 0) {
	                                                Q = 389;
	                                                break a
	                                            }
	                                            if ((d[(c[K >> 2] | 0) + ((c[I >> 2] | 0) + (c[J >> 2] | 0)) >> 0] | 0 | 0) == 62)break c;
	                                            do if ((d[(c[K >> 2] | 0) + ((c[I >> 2] | 0) + (c[J >> 2] | 0)) >> 0] | 0 | 0) != 32) {
	                                                if (9 <= (d[(c[K >> 2] | 0) + ((c[I >> 2] | 0) + (c[J >> 2] | 0)) >> 0] | 0 | 0) ? (d[(c[K >> 2] | 0) + ((c[I >> 2] | 0) + (c[J >> 2] | 0)) >> 0] | 0 | 0) <= 10 : 0)break;
	                                                if ((d[(c[K >> 2] | 0) + ((c[I >> 2] | 0) + (c[J >> 2] | 0)) >> 0] | 0 | 0) != 13)break d
	                                            } while (0);
	                                            c[J >> 2] = (c[J >> 2] | 0) + 1
	                                        }
	                                    }
	                                } while (0);
	                                c[I >> 2] = (c[I >> 2] | 0) + 1
	                            }
	                            c[(c[j >> 2] | 0) + 204 >> 2] = 0;
	                            bh(c[j >> 2] | 0);
	                            if ((c[(c[j >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                                Q = 407;
	                                break a
	                            }
	                            c[(c[j >> 2] | 0) + 216 >> 2] = 2;
	                            if (((c[c[j >> 2] >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 212 >> 2] | 0) == 0 : 0) ? (c[(c[c[j >> 2] >> 2] | 0) + 104 >> 2] | 0) != 0 : 0)Jb[c[(c[c[j >> 2] >> 2] | 0) + 104 >> 2] & 511](c[(c[j >> 2] | 0) + 4 >> 2] | 0, c[(c[j >> 2] | 0) + 220 >> 2] | 0, c[(c[j >> 2] | 0) + 228 >> 2] | 0, c[(c[j >> 2] | 0) + 224 >> 2] | 0);
	                            c[(c[j >> 2] | 0) + 216 >> 2] = 0;
	                            ch(c[j >> 2] | 0);
	                            if ((c[(c[j >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                                Q = 407;
	                                break a
	                            }
	                            c[(c[j >> 2] | 0) + 172 >> 2] = 4;
	                            c[(c[j >> 2] | 0) + 204 >> 2] = 0;
	                            continue a;
	                            break
	                        }
	                        case 5:
	                        {
	                            Db[c[135904 >> 2] & 511](c[33980] | 0, 70192, g);
	                            c[(c[j >> 2] | 0) + 172 >> 2] = 7;
	                            continue a;
	                            break
	                        }
	                        case 15:
	                        {
	                            Db[c[135904 >> 2] & 511](c[33980] | 0, 70232, g);
	                            c[(c[j >> 2] | 0) + 172 >> 2] = 3;
	                            continue a;
	                            break
	                        }
	                        case 2:
	                        {
	                            Db[c[135904 >> 2] & 511](c[33980] | 0, 70272, g);
	                            c[(c[j >> 2] | 0) + 172 >> 2] = 7;
	                            continue a;
	                            break
	                        }
	                        case 10:
	                        {
	                            Db[c[135904 >> 2] & 511](c[33980] | 0, 70312, g);
	                            c[(c[j >> 2] | 0) + 172 >> 2] = 3;
	                            continue a;
	                            break
	                        }
	                        case 11:
	                        {
	                            Db[c[135904 >> 2] & 511](c[33980] | 0, 70360, g);
	                            c[(c[j >> 2] | 0) + 172 >> 2] = 7;
	                            continue a;
	                            break
	                        }
	                        case 12:
	                        {
	                            Db[c[135904 >> 2] & 511](c[33980] | 0, 70408, g);
	                            c[(c[j >> 2] | 0) + 172 >> 2] = 6;
	                            continue a;
	                            break
	                        }
	                        case 13:
	                        {
	                            Db[c[135904 >> 2] & 511](c[33980] | 0, 70456, g);
	                            c[(c[j >> 2] | 0) + 172 >> 2] = 6;
	                            continue a;
	                            break
	                        }
	                        case 16:
	                        {
	                            Db[c[135904 >> 2] & 511](c[33980] | 0, 70504, g);
	                            c[(c[j >> 2] | 0) + 172 >> 2] = 6;
	                            continue a;
	                            break
	                        }
	                        case -1:
	                        {
	                            Q = 407;
	                            break a;
	                            break
	                        }
	                        default:
	                            continue a
	                    } while (0)
	                }
	                switch (Q | 0) {
	                    case 10:
	                    {
	                        c[h >> 2] = 0;
	                        P = c[h >> 2] | 0;
	                        i = f;
	                        return P | 0
	                    }
	                    case 30:
	                    {
	                        if ((c[c[j >> 2] >> 2] | 0) != 0 ? (c[(c[c[j >> 2] >> 2] | 0) + 44 >> 2] | 0) != 0 : 0)Ab[c[(c[c[j >> 2] >> 2] | 0) + 44 >> 2] & 511](c[(c[j >> 2] | 0) + 4 >> 2] | 0, 136080);
	                        og(c[j >> 2] | 0, 4, 0);
	                        c[(c[j >> 2] | 0) + 172 >> 2] = -1;
	                        if ((c[c[j >> 2] >> 2] | 0) != 0 ? (c[(c[c[j >> 2] >> 2] | 0) + 52 >> 2] | 0) != 0 : 0) {
	                            zb[c[(c[c[j >> 2] >> 2] | 0) + 52 >> 2] & 511](c[(c[j >> 2] | 0) + 4 >> 2] | 0);
	                            Q = 407
	                        } else Q = 407;
	                        break
	                    }
	                    case 39:
	                    {
	                        c[h >> 2] = c[l >> 2];
	                        P = c[h >> 2] | 0;
	                        i = f;
	                        return P | 0
	                    }
	                    case 42:
	                    {
	                        c[h >> 2] = c[l >> 2];
	                        P = c[h >> 2] | 0;
	                        i = f;
	                        return P | 0
	                    }
	                    case 54:
	                    {
	                        c[U + 172 >> 2] = -1;
	                        c[h >> 2] = 0;
	                        P = c[h >> 2] | 0;
	                        i = f;
	                        return P | 0
	                    }
	                    case 81:
	                    {
	                        og(c[j >> 2] | 0, 4, 0);
	                        c[(c[j >> 2] | 0) + 172 >> 2] = -1;
	                        if ((c[c[j >> 2] >> 2] | 0) != 0 ? (c[(c[c[j >> 2] >> 2] | 0) + 52 >> 2] | 0) != 0 : 0) {
	                            zb[c[(c[c[j >> 2] >> 2] | 0) + 52 >> 2] & 511](c[(c[j >> 2] | 0) + 4 >> 2] | 0);
	                            Q = 407
	                        } else Q = 407;
	                        break
	                    }
	                    case 99:
	                    {
	                        Zg(W) | 0;
	                        c[(c[j >> 2] | 0) + 172 >> 2] = -1;
	                        if ((c[c[j >> 2] >> 2] | 0) != 0 ? (c[(c[c[j >> 2] >> 2] | 0) + 52 >> 2] | 0) != 0 : 0) {
	                            zb[c[(c[c[j >> 2] >> 2] | 0) + 52 >> 2] & 511](c[(c[j >> 2] | 0) + 4 >> 2] | 0);
	                            Q = 407
	                        } else Q = 407;
	                        break
	                    }
	                    case 147:
	                    {
	                        c[(c[j >> 2] | 0) + 292 >> 2] = 2;
	                        Q = 407;
	                        break
	                    }
	                    case 158:
	                    {
	                        c[V + 292 >> 2] = 5;
	                        Q = 407;
	                        break
	                    }
	                    case 207:
	                    {
	                        if ((c[m >> 2] | 0) >= 302) {
	                            c[E >> 2] = xh(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0, 300) | 0;
	                            if ((c[E >> 2] | 0) < 0) {
	                                c[E >> 2] = 0 - (c[E >> 2] | 0);
	                                V = (c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                                c[V >> 2] = (c[V >> 2] | 0) + (c[E >> 2] | 0);
	                                Q = 408;
	                                break
	                            }
	                            do if ((c[c[j >> 2] >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 212 >> 2] | 0) == 0 : 0) {
	                                V = c[c[j >> 2] >> 2] | 0;
	                                if (c[(c[c[j >> 2] >> 2] | 0) + 100 >> 2] | 0) {
	                                    Db[c[V + 100 >> 2] & 511](c[(c[j >> 2] | 0) + 4 >> 2] | 0, c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0, c[E >> 2] | 0);
	                                    break
	                                }
	                                if (c[V + 68 >> 2] | 0)Db[c[(c[c[j >> 2] >> 2] | 0) + 68 >> 2] & 511](c[(c[j >> 2] | 0) + 4 >> 2] | 0, c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0, c[E >> 2] | 0)
	                            } while (0);
	                            if ((c[(c[j >> 2] | 0) + 172 >> 2] | 0) != -1) {
	                                c[F >> 2] = 0;
	                                while (1) {
	                                    X = d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                                    if ((c[F >> 2] | 0) >= (c[E >> 2] | 0))break;
	                                    V = c[(c[j >> 2] | 0) + 36 >> 2] | 0;
	                                    if ((X | 0) == 10) {
	                                        W = V + 28 | 0;
	                                        c[W >> 2] = (c[W >> 2] | 0) + 1;
	                                        c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                                    } else {
	                                        W = V + 32 | 0;
	                                        c[W >> 2] = (c[W >> 2] | 0) + 1
	                                    }
	                                    W = (c[j >> 2] | 0) + 200 | 0;
	                                    c[W >> 2] = (c[W >> 2] | 0) + 1;
	                                    W = (c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                                    c[W >> 2] = (c[W >> 2] | 0) + 1;
	                                    c[F >> 2] = (c[F >> 2] | 0) + 1
	                                }
	                                if ((X | 0) == 37)We(c[j >> 2] | 0);
	                                if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[j >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[j >> 2] | 0) | 0;
	                                c[(c[j >> 2] | 0) + 204 >> 2] = 0;
	                                Q = 407
	                            } else Q = 407
	                        } else Q = 407;
	                        break
	                    }
	                    case 231:
	                    {
	                        c[G >> 2] = 0 - (c[G >> 2] | 0);
	                        X = (c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                        c[X >> 2] = (c[X >> 2] | 0) + (c[G >> 2] | 0);
	                        Q = 408;
	                        break
	                    }
	                    case 265:
	                    {
	                        c[(c[j >> 2] | 0) + 292 >> 2] = 2;
	                        Q = 407;
	                        break
	                    }
	                    case 274:
	                    {
	                        c[(c[j >> 2] | 0) + 292 >> 2] = 5;
	                        Q = 407;
	                        break
	                    }
	                    case 288:
	                    {
	                        c[(c[j >> 2] | 0) + 292 >> 2] = 3;
	                        Q = 407;
	                        break
	                    }
	                    case 308:
	                    {
	                        c[(c[j >> 2] | 0) + 292 >> 2] = 2;
	                        Q = 407;
	                        break
	                    }
	                    case 317:
	                    {
	                        c[(c[j >> 2] | 0) + 292 >> 2] = 5;
	                        Q = 407;
	                        break
	                    }
	                    case 333:
	                    {
	                        c[(c[j >> 2] | 0) + 292 >> 2] = 2;
	                        Q = 407;
	                        break
	                    }
	                    case 342:
	                    {
	                        c[(c[j >> 2] | 0) + 292 >> 2] = 5;
	                        Q = 407;
	                        break
	                    }
	                    case 345:
	                    {
	                        if ((d[o >> 0] | 0 | 0) == 60 ? (d[p >> 0] | 0 | 0) == 33 & (c[m >> 2] | 0) < 4 : 0) {
	                            Q = 407;
	                            break
	                        }
	                        og(c[j >> 2] | 0, 5, 0);
	                        c[(c[j >> 2] | 0) + 172 >> 2] = -1;
	                        if ((c[c[j >> 2] >> 2] | 0) != 0 ? (c[(c[c[j >> 2] >> 2] | 0) + 52 >> 2] | 0) != 0 : 0) {
	                            zb[c[(c[c[j >> 2] >> 2] | 0) + 52 >> 2] & 511](c[(c[j >> 2] | 0) + 4 >> 2] | 0);
	                            Q = 407
	                        } else Q = 407;
	                        break
	                    }
	                    case 351:
	                    {
	                        c[h >> 2] = 0;
	                        P = c[h >> 2] | 0;
	                        i = f;
	                        return P | 0
	                    }
	                    case 389:
	                    {
	                        if (!(d[L >> 0] | 0)) {
	                            c[(c[j >> 2] | 0) + 204 >> 2] = c[I >> 2];
	                            Q = 407;
	                            break
	                        } else {
	                            c[(c[j >> 2] | 0) + 204 >> 2] = 0;
	                            Q = 407;
	                            break
	                        }
	                        break
	                    }
	                }
	                if ((Q | 0) == 407) {
	                    c[h >> 2] = c[l >> 2];
	                    P = c[h >> 2] | 0;
	                    i = f;
	                    return P | 0
	                } else if ((Q | 0) == 408) {
	                    Q = d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0;
	                    l = d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0;
	                    I = d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0;
	                    c[g >> 2] = d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0];
	                    c[g + 4 >> 2] = Q;
	                    c[g + 8 >> 2] = l;
	                    c[g + 12 >> 2] = I;
	                    JT(O, 149, 70552, g) | 0;
	                    je(c[j >> 2] | 0, 9, 70592, O, 0);
	                    c[h >> 2] = 0;
	                    P = c[h >> 2] | 0;
	                    i = f;
	                    return P | 0
	                }
	                return 0
	            }

	            function eh(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                do if (!((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) < 0)) {
	                    if ((c[(c[g >> 2] | 0) + 172 >> 2] | 0) == 6)if (NT(c[h >> 2] | 0, 62, c[j >> 2] | 0) | 0) {
	                        c[f >> 2] = 1;
	                        break
	                    } else {
	                        c[f >> 2] = 0;
	                        break
	                    }
	                    if ((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 5)if (NT(c[h >> 2] | 0, 62, c[j >> 2] | 0) | 0) {
	                        c[f >> 2] = 1;
	                        break
	                    } else {
	                        c[f >> 2] = 0;
	                        break
	                    }
	                    if ((c[(c[g >> 2] | 0) + 172 >> 2] | 0) == 8)if (NT(c[h >> 2] | 0, 62, c[j >> 2] | 0) | 0) {
	                        c[f >> 2] = 1;
	                        break
	                    } else {
	                        c[f >> 2] = 0;
	                        break
	                    }
	                    if ((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 2)if (NT(c[h >> 2] | 0, 62, c[j >> 2] | 0) | 0) {
	                        c[f >> 2] = 1;
	                        break
	                    } else {
	                        c[f >> 2] = 0;
	                        break
	                    }
	                    if ((c[(c[g >> 2] | 0) + 172 >> 2] | 0) == 9)if (NT(c[h >> 2] | 0, 62, c[j >> 2] | 0) | 0) {
	                        c[f >> 2] = 1;
	                        break
	                    } else {
	                        c[f >> 2] = 0;
	                        break
	                    }
	                    if ((c[(c[g >> 2] | 0) + 292 >> 2] | 0) != 3 ? (c[(c[g >> 2] | 0) + 172 >> 2] | 0) != 3 : 0) {
	                        c[f >> 2] = 1;
	                        break
	                    }
	                    if (NT(c[h >> 2] | 0, 62, c[j >> 2] | 0) | 0) {
	                        c[f >> 2] = 1;
	                        break
	                    } else {
	                        c[f >> 2] = 0;
	                        break
	                    }
	                } else c[f >> 2] = -1; while (0);
	                i = e;
	                return c[f >> 2] | 0
	            }

	            function fh(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f + 32 | 0;
	                h = f + 28 | 0;
	                j = f + 24 | 0;
	                k = f + 20 | 0;
	                l = f + 16 | 0;
	                m = f + 12 | 0;
	                n = f + 8 | 0;
	                o = f + 4 | 0;
	                p = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[o >> 2] = 0;
	                c[m >> 2] = Be() | 0;
	                if (!(c[m >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                if (c[l >> 2] | 0) {
	                    c[(c[m >> 2] | 0) + 360 >> 2] = c[(c[l >> 2] | 0) + 360 >> 2];
	                    c[(c[m >> 2] | 0) + 272 >> 2] = c[(c[l >> 2] | 0) + 272 >> 2]
	                }
	                c[p >> 2] = Hl(c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                if (!(c[p >> 2] | 0)) {
	                    c[n >> 2] = Vk(c[h >> 2] | 0, c[j >> 2] | 0, c[m >> 2] | 0) | 0;
	                    k = c[m >> 2] | 0;
	                    if (!(c[n >> 2] | 0)) {
	                        Ae(k);
	                        c[g >> 2] = 0;
	                        q = c[g >> 2] | 0;
	                        i = f;
	                        return q | 0
	                    }
	                    Oe(k, c[n >> 2] | 0) | 0;
	                    if ((c[o >> 2] | 0) == 0 ? (c[(c[m >> 2] | 0) + 180 >> 2] | 0) == 0 : 0)c[o >> 2] = Rk(c[h >> 2] | 0) | 0;
	                    if ((c[o >> 2] | 0) != 0 ? (c[(c[m >> 2] | 0) + 180 >> 2] | 0) == 0 : 0)c[(c[m >> 2] | 0) + 180 >> 2] = c[o >> 2]
	                } else {
	                    c[n >> 2] = Vk(c[p >> 2] | 0, c[j >> 2] | 0, c[m >> 2] | 0) | 0;
	                    if (!(c[n >> 2] | 0)) {
	                        zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                        Ae(c[m >> 2] | 0);
	                        c[g >> 2] = 0;
	                        q = c[g >> 2] | 0;
	                        i = f;
	                        return q | 0
	                    }
	                    Oe(c[m >> 2] | 0, c[n >> 2] | 0) | 0;
	                    if ((c[o >> 2] | 0) == 0 ? (c[(c[m >> 2] | 0) + 180 >> 2] | 0) == 0 : 0)c[o >> 2] = Rk(c[p >> 2] | 0) | 0;
	                    if ((c[o >> 2] | 0) != 0 ? (c[(c[m >> 2] | 0) + 180 >> 2] | 0) == 0 : 0)c[(c[m >> 2] | 0) + 180 >> 2] = c[o >> 2];
	                    zb[c[135736 >> 2] & 511](c[p >> 2] | 0)
	                }
	                c[g >> 2] = c[m >> 2];
	                q = c[g >> 2] | 0;
	                i = f;
	                return q | 0
	            }

	            function gh(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = -1;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                if (c[j >> 2] | 0) {
	                    if (c[(c[g >> 2] | 0) + 24 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[g >> 2] | 0) + 24 >> 2] | 0);
	                    d = my(c[j >> 2] | 0) | 0;
	                    c[(c[g >> 2] | 0) + 24 >> 2] = d
	                }
	                d = (c[g >> 2] | 0) + 288 | 0;
	                if (c[h >> 2] & 1) {
	                    c[d >> 2] = 1;
	                    c[h >> 2] = (c[h >> 2] | 0) - 1;
	                    j = (c[g >> 2] | 0) + 360 | 0;
	                    c[j >> 2] = c[j >> 2] | 1
	                } else c[d >> 2] = 0;
	                d = (c[g >> 2] | 0) + 276 | 0;
	                if (c[h >> 2] & 4) {
	                    c[d >> 2] = 2;
	                    c[h >> 2] = (c[h >> 2] | 0) - 4;
	                    j = (c[g >> 2] | 0) + 360 | 0;
	                    c[j >> 2] = c[j >> 2] | 4
	                } else c[d >> 2] = 0;
	                if (c[h >> 2] & 8) {
	                    d = (c[g >> 2] | 0) + 276 | 0;
	                    c[d >> 2] = c[d >> 2] | 4;
	                    c[h >> 2] = (c[h >> 2] | 0) - 8;
	                    d = (c[g >> 2] | 0) + 360 | 0;
	                    c[d >> 2] = c[d >> 2] | 8
	                }
	                d = (c[g >> 2] | 0) + 16 | 0;
	                if (c[h >> 2] & 2) {
	                    c[d >> 2] = 1;
	                    c[h >> 2] = (c[h >> 2] | 0) - 2;
	                    j = (c[g >> 2] | 0) + 360 | 0;
	                    c[j >> 2] = c[j >> 2] | 2
	                } else c[d >> 2] = 0;
	                d = (c[g >> 2] | 0) + 268 | 0;
	                if (c[h >> 2] & 128) {
	                    c[d >> 2] = 1;
	                    c[h >> 2] = (c[h >> 2] | 0) - 128;
	                    j = (c[g >> 2] | 0) + 360 | 0;
	                    c[j >> 2] = c[j >> 2] | 128
	                } else c[d >> 2] = 0;
	                d = (c[g >> 2] | 0) + 208 | 0;
	                if (c[h >> 2] & 256) {
	                    c[d >> 2] = 0;
	                    c[(c[c[g >> 2] >> 2] | 0) + 72 >> 2] = 65;
	                    c[h >> 2] = (c[h >> 2] | 0) - 256;
	                    j = (c[g >> 2] | 0) + 360 | 0;
	                    c[j >> 2] = c[j >> 2] | 256
	                } else c[d >> 2] = 1;
	                d = (c[g >> 2] | 0) + 104 | 0;
	                if (c[h >> 2] & 16) {
	                    c[d >> 2] = 1;
	                    if (c[h >> 2] & 64)c[(c[g >> 2] | 0) + 116 >> 2] = 0;
	                    if (c[h >> 2] & 32)c[(c[g >> 2] | 0) + 112 >> 2] = 0;
	                    c[h >> 2] = (c[h >> 2] | 0) - 16;
	                    j = (c[g >> 2] | 0) + 360 | 0;
	                    c[j >> 2] = c[j >> 2] | 16
	                } else c[d >> 2] = 0;
	                if (c[h >> 2] & 64) {
	                    c[(c[c[g >> 2] >> 2] | 0) + 84 >> 2] = 0;
	                    c[h >> 2] = (c[h >> 2] | 0) - 64
	                }
	                if (c[h >> 2] & 32) {
	                    c[(c[c[g >> 2] >> 2] | 0) + 88 >> 2] = 0;
	                    c[(c[c[g >> 2] >> 2] | 0) + 92 >> 2] = 0;
	                    c[h >> 2] = (c[h >> 2] | 0) - 32
	                }
	                if (c[h >> 2] & 512) {
	                    c[(c[c[g >> 2] >> 2] | 0) + 56 >> 2] = 50;
	                    c[(c[c[g >> 2] >> 2] | 0) + 60 >> 2] = 51;
	                    c[(c[c[g >> 2] >> 2] | 0) + 116 >> 2] = 0;
	                    c[(c[c[g >> 2] >> 2] | 0) + 120 >> 2] = 0;
	                    c[(c[c[g >> 2] >> 2] | 0) + 108 >> 2] = 1;
	                    c[h >> 2] = (c[h >> 2] | 0) - 512;
	                    d = (c[g >> 2] | 0) + 360 | 0;
	                    c[d >> 2] = c[d >> 2] | 512
	                }
	                d = (c[g >> 2] | 0) + 364 | 0;
	                if (c[h >> 2] & 4096) {
	                    c[d >> 2] = 0;
	                    c[h >> 2] = (c[h >> 2] | 0) - 4096;
	                    j = (c[g >> 2] | 0) + 360 | 0;
	                    c[j >> 2] = c[j >> 2] | 4096
	                } else c[d >> 2] = 1;
	                if (c[h >> 2] & 16384) {
	                    c[(c[c[g >> 2] >> 2] | 0) + 100 >> 2] = 0;
	                    c[h >> 2] = (c[h >> 2] | 0) - 16384;
	                    d = (c[g >> 2] | 0) + 360 | 0;
	                    c[d >> 2] = c[d >> 2] | 16384
	                }
	                if (c[h >> 2] & 8192) {
	                    d = (c[g >> 2] | 0) + 360 | 0;
	                    c[d >> 2] = c[d >> 2] | 8192;
	                    c[h >> 2] = (c[h >> 2] | 0) - 8192
	                }
	                if (c[h >> 2] & 2048) {
	                    d = (c[g >> 2] | 0) + 360 | 0;
	                    c[d >> 2] = c[d >> 2] | 2048;
	                    c[h >> 2] = (c[h >> 2] | 0) - 2048
	                }
	                if (c[h >> 2] & 65536) {
	                    d = (c[g >> 2] | 0) + 360 | 0;
	                    c[d >> 2] = c[d >> 2] | 65536;
	                    c[h >> 2] = (c[h >> 2] | 0) - 65536
	                }
	                if (c[h >> 2] & 131072) {
	                    d = (c[g >> 2] | 0) + 360 | 0;
	                    c[d >> 2] = c[d >> 2] | 131072;
	                    c[h >> 2] = (c[h >> 2] | 0) - 131072
	                }
	                if (c[h >> 2] & 262144) {
	                    d = (c[g >> 2] | 0) + 360 | 0;
	                    c[d >> 2] = c[d >> 2] | 262144;
	                    c[h >> 2] = (c[h >> 2] | 0) - 262144
	                }
	                do if (c[h >> 2] & 524288) {
	                    d = (c[g >> 2] | 0) + 360 | 0;
	                    c[d >> 2] = c[d >> 2] | 524288;
	                    c[h >> 2] = (c[h >> 2] | 0) - 524288;
	                    if (!(c[(c[g >> 2] | 0) + 296 >> 2] | 0))break;
	                    DP(c[(c[g >> 2] | 0) + 296 >> 2] | 0, 0) | 0
	                } while (0);
	                if (c[h >> 2] & 1048576) {
	                    d = (c[g >> 2] | 0) + 360 | 0;
	                    c[d >> 2] = c[d >> 2] | 1048576;
	                    c[h >> 2] = (c[h >> 2] | 0) - 1048576
	                }
	                if (c[h >> 2] & 2097152) {
	                    d = (c[g >> 2] | 0) + 360 | 0;
	                    c[d >> 2] = c[d >> 2] | 2097152;
	                    c[h >> 2] = (c[h >> 2] | 0) - 2097152
	                }
	                if (c[h >> 2] & 4194304) {
	                    d = (c[g >> 2] | 0) + 360 | 0;
	                    c[d >> 2] = c[d >> 2] | 4194304;
	                    c[h >> 2] = (c[h >> 2] | 0) - 4194304
	                }
	                c[(c[g >> 2] | 0) + 280 >> 2] = 1;
	                c[f >> 2] = c[h >> 2];
	                k = c[f >> 2] | 0;
	                i = e;
	                return k | 0
	            }

	            function hh(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                b = c[g >> 2] | 0;
	                if ((c[h >> 2] | 0) == (c[(c[g >> 2] | 0) + 312 >> 2] | 0)) {
	                    c[f >> 2] = c[b + 320 >> 2];
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                c[j >> 2] = (c[b + 328 >> 2] | 0) - 2;
	                while (1) {
	                    if ((c[j >> 2] | 0) < 0) {
	                        l = 11;
	                        break
	                    }
	                    if ((c[(c[(c[g >> 2] | 0) + 336 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) == (c[h >> 2] | 0))break;
	                    c[j >> 2] = (c[j >> 2] | 0) - 2
	                }
	                if ((l | 0) == 11) {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                if ((c[h >> 2] | 0) == 0 ? (d[c[(c[(c[g >> 2] | 0) + 336 >> 2] | 0) + ((c[j >> 2] | 0) + 1 << 2) >> 2] >> 0] | 0 | 0) == 0 : 0) {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                c[f >> 2] = c[(c[(c[g >> 2] | 0) + 336 >> 2] | 0) + ((c[j >> 2] | 0) + 1 << 2) >> 2];
	                k = c[f >> 2] | 0;
	                i = e;
	                return k | 0
	            }

	            function ih(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                a:do if (c[(c[g >> 2] | 0) + 360 >> 2] & 8192) {
	                    c[k >> 2] = (c[(c[g >> 2] | 0) + 328 >> 2] | 0) - 2;
	                    while (1) {
	                        if ((c[k >> 2] | 0) < 0)break a;
	                        m = c[k >> 2] | 0;
	                        if ((c[(c[(c[g >> 2] | 0) + 336 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) == (c[h >> 2] | 0))break;
	                        c[k >> 2] = m - 2
	                    }
	                    if ((c[(c[(c[g >> 2] | 0) + 336 >> 2] | 0) + (m + 1 << 2) >> 2] | 0) == (c[j >> 2] | 0)) {
	                        c[f >> 2] = -2;
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    }
	                } while (0);
	                do if ((c[(c[g >> 2] | 0) + 332 >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 336 >> 2] | 0) != 0 : 0) {
	                    if ((c[(c[g >> 2] | 0) + 328 >> 2] | 0) >= (c[(c[g >> 2] | 0) + 332 >> 2] | 0)) {
	                        m = (c[g >> 2] | 0) + 332 | 0;
	                        c[m >> 2] = c[m >> 2] << 1;
	                        c[l >> 2] = Hb[c[135760 >> 2] & 511](c[(c[g >> 2] | 0) + 336 >> 2] | 0, c[(c[g >> 2] | 0) + 332 >> 2] << 2) | 0;
	                        if (c[l >> 2] | 0) {
	                            c[(c[g >> 2] | 0) + 336 >> 2] = c[l >> 2];
	                            break
	                        }
	                        ie(c[g >> 2] | 0, 0);
	                        m = (c[g >> 2] | 0) + 332 | 0;
	                        c[m >> 2] = (c[m >> 2] | 0) / 2 | 0;
	                        c[f >> 2] = -1;
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    }
	                } else o = 10; while (0);
	                if ((o | 0) == 10 ? (c[(c[g >> 2] | 0) + 332 >> 2] = 10, c[(c[g >> 2] | 0) + 328 >> 2] = 0, o = Cb[c[135744 >> 2] & 511](c[(c[g >> 2] | 0) + 332 >> 2] << 2) | 0, c[(c[g >> 2] | 0) + 336 >> 2] = o, (c[(c[g >> 2] | 0) + 336 >> 2] | 0) == 0) : 0) {
	                    ie(c[g >> 2] | 0, 0);
	                    c[(c[g >> 2] | 0) + 332 >> 2] = 0;
	                    c[f >> 2] = -1;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                o = c[h >> 2] | 0;
	                h = (c[g >> 2] | 0) + 328 | 0;
	                l = c[h >> 2] | 0;
	                c[h >> 2] = l + 1;
	                c[(c[(c[g >> 2] | 0) + 336 >> 2] | 0) + (l << 2) >> 2] = o;
	                o = c[j >> 2] | 0;
	                j = (c[g >> 2] | 0) + 328 | 0;
	                l = c[j >> 2] | 0;
	                c[j >> 2] = l + 1;
	                c[(c[(c[g >> 2] | 0) + 336 >> 2] | 0) + (l << 2) >> 2] = o;
	                c[f >> 2] = c[(c[g >> 2] | 0) + 328 >> 2];
	                n = c[f >> 2] | 0;
	                i = e;
	                return n | 0
	            }

	            function jh(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 24 | 0;
	                j = g + 20 | 0;
	                k = g + 16 | 0;
	                l = g + 12 | 0;
	                m = g + 8 | 0;
	                n = g + 4 | 0;
	                o = g;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                gh(c[h >> 2] | 0, c[l >> 2] | 0, c[k >> 2] | 0) | 0;
	                if ((c[k >> 2] | 0) != 0 ? (c[o >> 2] = Dd(c[k >> 2] | 0) | 0, (c[o >> 2] | 0) != 0) : 0)se(c[h >> 2] | 0, c[o >> 2] | 0) | 0;
	                if (((c[j >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) == 0 : 0) {
	                    o = my(c[j >> 2] | 0) | 0;
	                    c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] = o
	                }
	                Qf(c[h >> 2] | 0) | 0;
	                if ((c[(c[h >> 2] | 0) + 12 >> 2] | 0) == 0 ? (c[(c[h >> 2] | 0) + 288 >> 2] | 0) == 0 : 0) {
	                    c[n >> 2] = 0;
	                    if (c[(c[h >> 2] | 0) + 8 >> 2] | 0)Th(c[(c[h >> 2] | 0) + 8 >> 2] | 0)
	                } else c[n >> 2] = c[(c[h >> 2] | 0) + 8 >> 2];
	                c[(c[h >> 2] | 0) + 8 >> 2] = 0;
	                if (c[m >> 2] | 0) {
	                    p = c[n >> 2] | 0;
	                    i = g;
	                    return p | 0
	                }
	                Ae(c[h >> 2] | 0);
	                p = c[n >> 2] | 0;
	                i = g;
	                return p | 0
	            }

	            function kh(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                b = c[g >> 2] | 0;
	                a:do if (!(c[(c[f >> 2] | 0) + 360 >> 2] & 131072)) {
	                    if ((b | 0) != 32 & (c[g >> 2] | 0) != 62 & (c[g >> 2] | 0) != 47) {
	                        if (((((((((((((!((c[g >> 2] | 0) >= 97 & (c[g >> 2] | 0) <= 122) ? !((c[g >> 2] | 0) >= 65 & (c[g >> 2] | 0) <= 90 | (c[g >> 2] | 0) == 95 | (c[g >> 2] | 0) == 58) : 0) ? !((c[g >> 2] | 0) >= 192 & (c[g >> 2] | 0) <= 214) : 0) ? !((c[g >> 2] | 0) >= 216 & (c[g >> 2] | 0) <= 246) : 0) ? !((c[g >> 2] | 0) >= 248 & (c[g >> 2] | 0) <= 767) : 0) ? !((c[g >> 2] | 0) >= 880 & (c[g >> 2] | 0) <= 893) : 0) ? !((c[g >> 2] | 0) >= 895 & (c[g >> 2] | 0) <= 8191) : 0) ? !((c[g >> 2] | 0) >= 8204 & (c[g >> 2] | 0) <= 8205) : 0) ? !((c[g >> 2] | 0) >= 8304 & (c[g >> 2] | 0) <= 8591) : 0) ? !((c[g >> 2] | 0) >= 11264 & (c[g >> 2] | 0) <= 12271) : 0) ? !((c[g >> 2] | 0) >= 12289 & (c[g >> 2] | 0) <= 55295) : 0) ? !((c[g >> 2] | 0) >= 63744 & (c[g >> 2] | 0) <= 64975) : 0) ? !((c[g >> 2] | 0) >= 65008 & (c[g >> 2] | 0) <= 65533) : 0) ? !((c[g >> 2] | 0) >= 65536 & (c[g >> 2] | 0) <= 983039) : 0)break;
	                        c[e >> 2] = 1;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                } else {
	                    a = c[g >> 2] | 0;
	                    if ((b | 0) < 256) {
	                        if (((!(65 <= (a | 0) & (c[g >> 2] | 0) <= 90) ? !(97 <= (c[g >> 2] | 0) & (c[g >> 2] | 0) <= 122) : 0) ? !(192 <= (c[g >> 2] | 0) & (c[g >> 2] | 0) <= 214) : 0) ? !(216 <= (c[g >> 2] | 0) & (c[g >> 2] | 0) <= 246 | 248 <= (c[g >> 2] | 0)) : 0)j = 24
	                    } else if (!(DQ(a, 199744) | 0))j = 24;
	                    do if ((j | 0) == 24) {
	                        a = c[g >> 2] | 0;
	                        if ((c[g >> 2] | 0) < 256)if ((a | 0) == 95 | (c[g >> 2] | 0) == 58)break; else break a;
	                        if (!(19968 <= (a | 0) & (c[g >> 2] | 0) <= 40869 | (c[g >> 2] | 0) == 12295) ? !(12321 <= (c[g >> 2] | 0) & (c[g >> 2] | 0) <= 12329 | (c[g >> 2] | 0) == 95 | (c[g >> 2] | 0) == 58) : 0)break a
	                    } while (0);
	                    c[e >> 2] = 1;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                } while (0);
	                c[e >> 2] = 0;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function lh(b, e, f) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0, J = 0, K = 0, L = 0, M = 0, N = 0, O = 0, P = 0, Q = 0, R = 0, S = 0, T = 0;
	                g = i;
	                i = i + 144 | 0;
	                h = g + 136 | 0;
	                j = g + 132 | 0;
	                k = g + 128 | 0;
	                l = g + 124 | 0;
	                m = g + 140 | 0;
	                n = g + 120 | 0;
	                o = g + 116 | 0;
	                p = g + 112 | 0;
	                q = g + 108 | 0;
	                r = g + 104 | 0;
	                s = g + 100 | 0;
	                t = g + 96 | 0;
	                u = g + 92 | 0;
	                v = g + 88 | 0;
	                w = g + 84 | 0;
	                x = g + 80 | 0;
	                y = g + 76 | 0;
	                z = g + 72 | 0;
	                A = g + 68 | 0;
	                B = g + 64 | 0;
	                C = g + 60 | 0;
	                D = g + 56 | 0;
	                E = g + 52 | 0;
	                F = g + 48 | 0;
	                G = g + 44 | 0;
	                H = g + 40 | 0;
	                I = g + 36 | 0;
	                J = g + 32 | 0;
	                K = g + 28 | 0;
	                L = g + 24 | 0;
	                M = g + 20 | 0;
	                N = g + 16 | 0;
	                O = g + 12 | 0;
	                P = g + 8 | 0;
	                Q = g + 4 | 0;
	                R = g;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[l >> 2] = f;
	                a[m >> 0] = 0;
	                c[n >> 2] = 0;
	                c[o >> 2] = 0;
	                c[p >> 2] = 0;
	                c[q >> 2] = 0;
	                c[t >> 2] = 0;
	                c[u >> 2] = 0;
	                f = c[j >> 2] | 0;
	                do if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 34) {
	                    c[f + 172 >> 2] = 12;
	                    a[m >> 0] = 34;
	                    me(c[j >> 2] | 0)
	                } else {
	                    if ((d[c[(c[f + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 39) {
	                        a[m >> 0] = 39;
	                        c[(c[j >> 2] | 0) + 172 >> 2] = 12;
	                        me(c[j >> 2] | 0);
	                        break
	                    }
	                    og(c[j >> 2] | 0, 39, 0);
	                    c[h >> 2] = 0;
	                    S = c[h >> 2] | 0;
	                    i = g;
	                    return S | 0
	                } while (0);
	                c[q >> 2] = 100;
	                c[n >> 2] = Cb[c[135752 >> 2] & 511](c[q >> 2] | 0) | 0;
	                a:do if (c[n >> 2] | 0) {
	                    c[r >> 2] = ne(c[j >> 2] | 0, s) | 0;
	                    b:while (1) {
	                        if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == (d[m >> 0] | 0 | 0))break;
	                        f = c[r >> 2] | 0;
	                        do if ((c[r >> 2] | 0) < 256) {
	                            if (!((9 <= (f | 0) & (c[r >> 2] | 0) <= 10 | (c[r >> 2] | 0) == 13 | 32 <= (c[r >> 2] | 0)) & (c[r >> 2] | 0) != 60))break b
	                        } else {
	                            if (!(256 <= (f | 0) & (c[r >> 2] | 0) <= 55295) ? !(57344 <= (c[r >> 2] | 0) & (c[r >> 2] | 0) <= 65533) : 0)if (65536 <= (c[r >> 2] | 0) & (c[r >> 2] | 0) <= 1114111 & (c[r >> 2] | 0) != 60)break; else break b;
	                            if ((c[r >> 2] | 0) == 60)break b
	                        } while (0);
	                        if ((c[(c[j >> 2] | 0) + 172 >> 2] | 0) == -1)break;
	                        if ((c[p >> 2] | 0) >>> 0 > 1e7 ? (c[(c[j >> 2] | 0) + 360 >> 2] & 524288 | 0) == 0 : 0) {
	                            T = 18;
	                            break
	                        }
	                        if (!(c[r >> 2] | 0))break;
	                        do if ((c[r >> 2] | 0) == 38) {
	                            c[t >> 2] = 0;
	                            f = c[j >> 2] | 0;
	                            if ((d[(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 35) {
	                                c[w >> 2] = Ye(f) | 0;
	                                if ((c[w >> 2] | 0) != 38) {
	                                    if (!(c[w >> 2] | 0))break;
	                                    if (((c[p >> 2] | 0) + 10 | 0) >>> 0 > (c[q >> 2] | 0) >>> 0) {
	                                        c[C >> 2] = (c[q >> 2] << 1) + 10;
	                                        if ((c[C >> 2] | 0) >>> 0 < (c[q >> 2] | 0) >>> 0) {
	                                            T = 138;
	                                            break a
	                                        }
	                                        c[B >> 2] = Hb[c[135760 >> 2] & 511](c[n >> 2] | 0, c[C >> 2] | 0) | 0;
	                                        if (!(c[B >> 2] | 0)) {
	                                            T = 138;
	                                            break a
	                                        }
	                                        c[n >> 2] = c[B >> 2];
	                                        c[q >> 2] = c[C >> 2]
	                                    }
	                                    e = qe(0, (c[n >> 2] | 0) + (c[p >> 2] | 0) | 0, c[w >> 2] | 0) | 0;
	                                    c[p >> 2] = (c[p >> 2] | 0) + e;
	                                    break
	                                }
	                                e = ((c[p >> 2] | 0) + 10 | 0) >>> 0 > (c[q >> 2] | 0) >>> 0;
	                                if (c[(c[j >> 2] | 0) + 16 >> 2] | 0) {
	                                    if (e) {
	                                        c[y >> 2] = (c[q >> 2] << 1) + 10;
	                                        if ((c[y >> 2] | 0) >>> 0 < (c[q >> 2] | 0) >>> 0) {
	                                            T = 138;
	                                            break a
	                                        }
	                                        c[x >> 2] = Hb[c[135760 >> 2] & 511](c[n >> 2] | 0, c[y >> 2] | 0) | 0;
	                                        if (!(c[x >> 2] | 0)) {
	                                            T = 138;
	                                            break a
	                                        }
	                                        c[n >> 2] = c[x >> 2];
	                                        c[q >> 2] = c[y >> 2]
	                                    }
	                                    b = c[p >> 2] | 0;
	                                    c[p >> 2] = b + 1;
	                                    a[(c[n >> 2] | 0) + b >> 0] = 38;
	                                    break
	                                } else {
	                                    if (e) {
	                                        c[A >> 2] = (c[q >> 2] << 1) + 10;
	                                        if ((c[A >> 2] | 0) >>> 0 < (c[q >> 2] | 0) >>> 0) {
	                                            T = 138;
	                                            break a
	                                        }
	                                        c[z >> 2] = Hb[c[135760 >> 2] & 511](c[n >> 2] | 0, c[A >> 2] | 0) | 0;
	                                        if (!(c[z >> 2] | 0)) {
	                                            T = 138;
	                                            break a
	                                        }
	                                        c[n >> 2] = c[z >> 2];
	                                        c[q >> 2] = c[A >> 2]
	                                    }
	                                    e = c[p >> 2] | 0;
	                                    c[p >> 2] = e + 1;
	                                    a[(c[n >> 2] | 0) + e >> 0] = 38;
	                                    e = c[p >> 2] | 0;
	                                    c[p >> 2] = e + 1;
	                                    a[(c[n >> 2] | 0) + e >> 0] = 35;
	                                    e = c[p >> 2] | 0;
	                                    c[p >> 2] = e + 1;
	                                    a[(c[n >> 2] | 0) + e >> 0] = 51;
	                                    e = c[p >> 2] | 0;
	                                    c[p >> 2] = e + 1;
	                                    a[(c[n >> 2] | 0) + e >> 0] = 56;
	                                    e = c[p >> 2] | 0;
	                                    c[p >> 2] = e + 1;
	                                    a[(c[n >> 2] | 0) + e >> 0] = 59;
	                                    break
	                                }
	                            }
	                            c[v >> 2] = Ef(f) | 0;
	                            f = (c[j >> 2] | 0) + 440 | 0;
	                            c[f >> 2] = (c[f >> 2] | 0) + 1;
	                            if (c[v >> 2] | 0) {
	                                f = (c[j >> 2] | 0) + 440 | 0;
	                                c[f >> 2] = (c[f >> 2] | 0) + (c[(c[v >> 2] | 0) + 68 >> 2] | 0)
	                            }
	                            if ((c[v >> 2] | 0) != 0 ? (c[(c[v >> 2] | 0) + 48 >> 2] | 0) == 6 : 0) {
	                                if (((c[p >> 2] | 0) + 10 | 0) >>> 0 > (c[q >> 2] | 0) >>> 0) {
	                                    c[E >> 2] = (c[q >> 2] << 1) + 10;
	                                    if ((c[E >> 2] | 0) >>> 0 < (c[q >> 2] | 0) >>> 0) {
	                                        T = 138;
	                                        break a
	                                    }
	                                    c[D >> 2] = Hb[c[135760 >> 2] & 511](c[n >> 2] | 0, c[E >> 2] | 0) | 0;
	                                    if (!(c[D >> 2] | 0)) {
	                                        T = 138;
	                                        break a
	                                    }
	                                    c[n >> 2] = c[D >> 2];
	                                    c[q >> 2] = c[E >> 2]
	                                }
	                                if ((c[(c[j >> 2] | 0) + 16 >> 2] | 0) == 0 ? (d[c[(c[v >> 2] | 0) + 40 >> 2] >> 0] | 0 | 0) == 38 : 0) {
	                                    f = c[p >> 2] | 0;
	                                    c[p >> 2] = f + 1;
	                                    a[(c[n >> 2] | 0) + f >> 0] = 38;
	                                    f = c[p >> 2] | 0;
	                                    c[p >> 2] = f + 1;
	                                    a[(c[n >> 2] | 0) + f >> 0] = 35;
	                                    f = c[p >> 2] | 0;
	                                    c[p >> 2] = f + 1;
	                                    a[(c[n >> 2] | 0) + f >> 0] = 51;
	                                    f = c[p >> 2] | 0;
	                                    c[p >> 2] = f + 1;
	                                    a[(c[n >> 2] | 0) + f >> 0] = 56;
	                                    f = c[p >> 2] | 0;
	                                    c[p >> 2] = f + 1;
	                                    a[(c[n >> 2] | 0) + f >> 0] = 59;
	                                    break
	                                }
	                                f = a[c[(c[v >> 2] | 0) + 40 >> 2] >> 0] | 0;
	                                e = c[p >> 2] | 0;
	                                c[p >> 2] = e + 1;
	                                a[(c[n >> 2] | 0) + e >> 0] = f;
	                                break
	                            }
	                            if ((c[v >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 16 >> 2] | 0) != 0 : 0) {
	                                if ((c[(c[v >> 2] | 0) + 48 >> 2] | 0) == 6) {
	                                    if (((c[p >> 2] | 0) + 10 | 0) >>> 0 > (c[q >> 2] | 0) >>> 0) {
	                                        c[I >> 2] = (c[q >> 2] << 1) + 10;
	                                        if ((c[I >> 2] | 0) >>> 0 < (c[q >> 2] | 0) >>> 0) {
	                                            T = 138;
	                                            break a
	                                        }
	                                        c[H >> 2] = Hb[c[135760 >> 2] & 511](c[n >> 2] | 0, c[I >> 2] | 0) | 0;
	                                        if (!(c[H >> 2] | 0)) {
	                                            T = 138;
	                                            break a
	                                        }
	                                        c[n >> 2] = c[H >> 2];
	                                        c[q >> 2] = c[I >> 2]
	                                    }
	                                    if (!(c[(c[v >> 2] | 0) + 40 >> 2] | 0))break;
	                                    f = a[c[(c[v >> 2] | 0) + 40 >> 2] >> 0] | 0;
	                                    e = c[p >> 2] | 0;
	                                    c[p >> 2] = e + 1;
	                                    a[(c[n >> 2] | 0) + e >> 0] = f;
	                                    break
	                                }
	                                c[o >> 2] = af(c[j >> 2] | 0, c[(c[v >> 2] | 0) + 40 >> 2] | 0, 1, 0, 0, 0) | 0;
	                                if (!(c[o >> 2] | 0))break;
	                                c[u >> 2] = c[o >> 2];
	                                while (1) {
	                                    if (!(d[c[u >> 2] >> 0] | 0))break;
	                                    do if ((d[c[u >> 2] >> 0] | 0 | 0) == 13)T = 61; else {
	                                        if ((d[c[u >> 2] >> 0] | 0 | 0) == 10) {
	                                            T = 61;
	                                            break
	                                        }
	                                        if ((d[c[u >> 2] >> 0] | 0 | 0) == 9) {
	                                            T = 61;
	                                            break
	                                        }
	                                        f = c[u >> 2] | 0;
	                                        c[u >> 2] = f + 1;
	                                        e = a[f >> 0] | 0;
	                                        f = c[p >> 2] | 0;
	                                        c[p >> 2] = f + 1;
	                                        a[(c[n >> 2] | 0) + f >> 0] = e
	                                    } while (0);
	                                    if ((T | 0) == 61) {
	                                        T = 0;
	                                        e = c[p >> 2] | 0;
	                                        c[p >> 2] = e + 1;
	                                        a[(c[n >> 2] | 0) + e >> 0] = 32;
	                                        c[u >> 2] = (c[u >> 2] | 0) + 1
	                                    }
	                                    if (((c[p >> 2] | 0) + 10 | 0) >>> 0 <= (c[q >> 2] | 0) >>> 0)continue;
	                                    c[G >> 2] = (c[q >> 2] << 1) + 10;
	                                    if ((c[G >> 2] | 0) >>> 0 < (c[q >> 2] | 0) >>> 0) {
	                                        T = 138;
	                                        break a
	                                    }
	                                    c[F >> 2] = Hb[c[135760 >> 2] & 511](c[n >> 2] | 0, c[G >> 2] | 0) | 0;
	                                    if (!(c[F >> 2] | 0)) {
	                                        T = 138;
	                                        break a
	                                    }
	                                    c[n >> 2] = c[F >> 2];
	                                    c[q >> 2] = c[G >> 2]
	                                }
	                                zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                                c[o >> 2] = 0;
	                                break
	                            }
	                            if (c[v >> 2] | 0) {
	                                c[J >> 2] = xy(c[(c[v >> 2] | 0) + 8 >> 2] | 0) | 0;
	                                c[K >> 2] = c[(c[v >> 2] | 0) + 8 >> 2];
	                                do if (((c[(c[v >> 2] | 0) + 48 >> 2] | 0) != 6 ? (c[(c[v >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) ? (c[(c[v >> 2] | 0) + 72 >> 2] | 0) == 0 : 0) {
	                                    c[L >> 2] = c[(c[j >> 2] | 0) + 440 >> 2];
	                                    c[o >> 2] = af(c[j >> 2] | 0, c[(c[v >> 2] | 0) + 40 >> 2] | 0, 1, 0, 0, 0) | 0;
	                                    c[(c[v >> 2] | 0) + 72 >> 2] = (c[(c[j >> 2] | 0) + 440 >> 2] | 0) - (c[L >> 2] | 0) + 1 << 1;
	                                    if (!(c[o >> 2] | 0))break;
	                                    if (vy(c[o >> 2] | 0, 60) | 0) {
	                                        e = (c[v >> 2] | 0) + 72 | 0;
	                                        c[e >> 2] = c[e >> 2] | 1
	                                    }
	                                    zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                                    c[o >> 2] = 0
	                                } while (0);
	                                e = c[p >> 2] | 0;
	                                c[p >> 2] = e + 1;
	                                a[(c[n >> 2] | 0) + e >> 0] = 38;
	                                while (1) {
	                                    if (((c[p >> 2] | 0) + (c[J >> 2] | 0) + 10 | 0) >>> 0 <= (c[q >> 2] | 0) >>> 0)break;
	                                    c[N >> 2] = (c[q >> 2] << 1) + (c[J >> 2] | 0) + 10;
	                                    if ((c[N >> 2] | 0) >>> 0 < (c[q >> 2] | 0) >>> 0) {
	                                        T = 138;
	                                        break a
	                                    }
	                                    c[M >> 2] = Hb[c[135760 >> 2] & 511](c[n >> 2] | 0, c[N >> 2] | 0) | 0;
	                                    if (!(c[M >> 2] | 0)) {
	                                        T = 138;
	                                        break a
	                                    }
	                                    c[n >> 2] = c[M >> 2];
	                                    c[q >> 2] = c[N >> 2]
	                                }
	                                while (1) {
	                                    if ((c[J >> 2] | 0) <= 0)break;
	                                    e = c[K >> 2] | 0;
	                                    c[K >> 2] = e + 1;
	                                    f = a[e >> 0] | 0;
	                                    e = c[p >> 2] | 0;
	                                    c[p >> 2] = e + 1;
	                                    a[(c[n >> 2] | 0) + e >> 0] = f;
	                                    c[J >> 2] = (c[J >> 2] | 0) + -1
	                                }
	                                f = c[p >> 2] | 0;
	                                c[p >> 2] = f + 1;
	                                a[(c[n >> 2] | 0) + f >> 0] = 59
	                            }
	                        } else {
	                            if ((c[r >> 2] | 0) == 32 | (c[r >> 2] | 0) == 13 | (c[r >> 2] | 0) == 10 | (c[r >> 2] | 0) == 9) {
	                                if (!((c[p >> 2] | 0) == 0 & (c[l >> 2] | 0) != 0)) {
	                                    c:do if (!((c[l >> 2] | 0) != 0 & (c[t >> 2] | 0) != 0)) {
	                                        f = c[p >> 2] | 0;
	                                        if ((c[s >> 2] | 0) == 1) {
	                                            c[p >> 2] = f + 1;
	                                            a[(c[n >> 2] | 0) + f >> 0] = 32
	                                        } else {
	                                            e = pe((c[n >> 2] | 0) + f | 0, 32) | 0;
	                                            c[p >> 2] = (c[p >> 2] | 0) + e
	                                        }
	                                        while (1) {
	                                            if (((c[p >> 2] | 0) + 10 | 0) >>> 0 <= (c[q >> 2] | 0) >>> 0)break c;
	                                            c[P >> 2] = (c[q >> 2] << 1) + 10;
	                                            if ((c[P >> 2] | 0) >>> 0 < (c[q >> 2] | 0) >>> 0) {
	                                                T = 138;
	                                                break a
	                                            }
	                                            c[O >> 2] = Hb[c[135760 >> 2] & 511](c[n >> 2] | 0, c[P >> 2] | 0) | 0;
	                                            if (!(c[O >> 2] | 0)) {
	                                                T = 138;
	                                                break a
	                                            }
	                                            c[n >> 2] = c[O >> 2];
	                                            c[q >> 2] = c[P >> 2]
	                                        }
	                                    } while (0);
	                                    c[t >> 2] = 1
	                                }
	                            } else {
	                                c[t >> 2] = 0;
	                                if ((c[s >> 2] | 0) == 1) {
	                                    e = c[r >> 2] & 255;
	                                    f = c[p >> 2] | 0;
	                                    c[p >> 2] = f + 1;
	                                    a[(c[n >> 2] | 0) + f >> 0] = e
	                                } else {
	                                    e = pe((c[n >> 2] | 0) + (c[p >> 2] | 0) | 0, c[r >> 2] | 0) | 0;
	                                    c[p >> 2] = (c[p >> 2] | 0) + e
	                                }
	                                if (((c[p >> 2] | 0) + 10 | 0) >>> 0 > (c[q >> 2] | 0) >>> 0) {
	                                    c[R >> 2] = (c[q >> 2] << 1) + 10;
	                                    if ((c[R >> 2] | 0) >>> 0 < (c[q >> 2] | 0) >>> 0) {
	                                        T = 138;
	                                        break a
	                                    }
	                                    c[Q >> 2] = Hb[c[135760 >> 2] & 511](c[n >> 2] | 0, c[R >> 2] | 0) | 0;
	                                    if (!(c[Q >> 2] | 0)) {
	                                        T = 138;
	                                        break a
	                                    }
	                                    c[n >> 2] = c[Q >> 2];
	                                    c[q >> 2] = c[R >> 2]
	                                }
	                            }
	                            e = c[(c[j >> 2] | 0) + 36 >> 2] | 0;
	                            if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                                f = e + 28 | 0;
	                                c[f >> 2] = (c[f >> 2] | 0) + 1;
	                                c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                            } else {
	                                f = e + 32 | 0;
	                                c[f >> 2] = (c[f >> 2] | 0) + 1
	                            }
	                            f = (c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                            c[f >> 2] = (c[f >> 2] | 0) + (c[s >> 2] | 0);
	                            if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[j >> 2] | 0)
	                        } while (0);
	                        if ((c[(c[j >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[j >> 2] | 0);
	                        c[r >> 2] = ne(c[j >> 2] | 0, s) | 0
	                    }
	                    if ((T | 0) == 18) {
	                        xg(c[j >> 2] | 0, 40, 71720);
	                        T = 138;
	                        break
	                    }
	                    if ((c[(c[j >> 2] | 0) + 172 >> 2] | 0) != -1) {
	                        d:do if ((c[t >> 2] | 0) != 0 & (c[l >> 2] | 0) != 0 & (c[p >> 2] | 0) >>> 0 > 0)do {
	                            if ((d[(c[n >> 2] | 0) + ((c[p >> 2] | 0) - 1) >> 0] | 0 | 0) != 32)break d;
	                            c[p >> 2] = (c[p >> 2] | 0) + -1
	                        } while ((c[p >> 2] | 0) >>> 0 > 0); while (0);
	                        a[(c[n >> 2] | 0) + (c[p >> 2] | 0) >> 0] = 0;
	                        f = c[j >> 2] | 0;
	                        e:do if ((d[c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60)og(f, 38, 0); else {
	                            if ((d[c[(c[f + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == (d[m >> 0] | 0 | 0)) {
	                                me(c[j >> 2] | 0);
	                                break
	                            }
	                            do if (c[r >> 2] | 0) {
	                                e = c[r >> 2] | 0;
	                                if ((c[r >> 2] | 0) < 256) {
	                                    if (9 <= (e | 0) & (c[r >> 2] | 0) <= 10 | (c[r >> 2] | 0) == 13 | 32 <= (c[r >> 2] | 0))break
	                                } else {
	                                    if (256 <= (e | 0) & (c[r >> 2] | 0) <= 55295)break;
	                                    if (57344 <= (c[r >> 2] | 0) & (c[r >> 2] | 0) <= 65533)break;
	                                    if (65536 <= (c[r >> 2] | 0) & (c[r >> 2] | 0) <= 1114111)break
	                                }
	                                xg(c[j >> 2] | 0, 9, 71752);
	                                break e
	                            } while (0);
	                            xg(c[j >> 2] | 0, 40, 71792)
	                        } while (0);
	                        if ((c[p >> 2] | 0) >>> 0 >= 2147483647) {
	                            xg(c[j >> 2] | 0, 40, 71720);
	                            T = 138;
	                            break
	                        }
	                        if (c[k >> 2] | 0)c[c[k >> 2] >> 2] = c[p >> 2];
	                        c[h >> 2] = c[n >> 2];
	                        S = c[h >> 2] | 0;
	                        i = g;
	                        return S | 0
	                    }
	                } else T = 138; while (0);
	                if ((T | 0) == 138)ie(c[j >> 2] | 0, 0);
	                if (c[n >> 2] | 0)zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                if (c[o >> 2] | 0)zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                c[h >> 2] = 0;
	                S = c[h >> 2] | 0;
	                i = g;
	                return S | 0
	            }

	            function mh(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = c[h >> 2];
	                if ((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[g >> 2] | 0);
	                if ((c[(c[g >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                c[k >> 2] = c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                while (1) {
	                    if (!(d[c[k >> 2] >> 0] | 0))break;
	                    if ((d[c[k >> 2] >> 0] | 0 | 0) != (d[c[j >> 2] >> 0] | 0 | 0))break;
	                    c[k >> 2] = (c[k >> 2] | 0) + 1;
	                    c[j >> 2] = (c[j >> 2] | 0) + 1;
	                    b = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 1
	                }
	                a:do if (!(d[c[j >> 2] >> 0] | 0)) {
	                    do if ((d[c[k >> 2] >> 0] | 0 | 0) != 62 ? (d[c[k >> 2] >> 0] | 0 | 0) != 32 : 0) {
	                        if (9 <= (d[c[k >> 2] >> 0] | 0 | 0) ? (d[c[k >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[k >> 2] >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] = c[k >> 2];
	                    c[f >> 2] = 1;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                } while (0);
	                c[l >> 2] = Ze(c[g >> 2] | 0) | 0;
	                if ((c[l >> 2] | 0) == (c[h >> 2] | 0)) {
	                    c[f >> 2] = 1;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                } else {
	                    c[f >> 2] = c[l >> 2];
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                return 0
	            }

	            function nh(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 20 | 0;
	                h = e + 16 | 0;
	                j = e + 12 | 0;
	                k = e + 8 | 0;
	                l = e + 4 | 0;
	                m = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                if ((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[g >> 2] | 0);
	                c[j >> 2] = yh(c[g >> 2] | 0) | 0;
	                b = (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 58;
	                if (!(c[j >> 2] | 0)) {
	                    if (b ? (c[j >> 2] = Ze(c[g >> 2] | 0) | 0, (c[j >> 2] | 0) != 0) : 0) {
	                        Jg(c[g >> 2] | 0, 202, 70824, c[j >> 2] | 0, 0, 0);
	                        c[c[h >> 2] >> 2] = 0;
	                        c[f >> 2] = c[j >> 2];
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    }
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                do if (b) {
	                    me(c[g >> 2] | 0);
	                    c[k >> 2] = c[j >> 2];
	                    c[j >> 2] = yh(c[g >> 2] | 0) | 0;
	                    a = c[g >> 2] | 0;
	                    if (!(c[j >> 2] | 0)) {
	                        Jg(a, 202, 70856, c[k >> 2] | 0, 0, 0);
	                        c[j >> 2] = cf(c[g >> 2] | 0) | 0;
	                        if (!(c[j >> 2] | 0))c[l >> 2] = Bh(65640, c[k >> 2] | 0, 0, 0) | 0; else {
	                            c[l >> 2] = Bh(c[j >> 2] | 0, c[k >> 2] | 0, 0, 0) | 0;
	                            zb[c[135736 >> 2] & 511](c[j >> 2] | 0)
	                        }
	                        c[k >> 2] = AP(c[(c[g >> 2] | 0) + 296 >> 2] | 0, c[l >> 2] | 0, -1) | 0;
	                        if (c[l >> 2] | 0)zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                        c[c[h >> 2] >> 2] = 0;
	                        c[f >> 2] = c[k >> 2];
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    }
	                    if ((d[c[(c[a + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 58) {
	                        c[c[h >> 2] >> 2] = c[k >> 2];
	                        break
	                    }
	                    Jg(c[g >> 2] | 0, 202, 70888, c[k >> 2] | 0, c[j >> 2] | 0, 0);
	                    me(c[g >> 2] | 0);
	                    c[m >> 2] = Ze(c[g >> 2] | 0) | 0;
	                    if (c[m >> 2] | 0) {
	                        c[m >> 2] = Bh(c[m >> 2] | 0, c[j >> 2] | 0, 0, 0) | 0;
	                        c[j >> 2] = AP(c[(c[g >> 2] | 0) + 296 >> 2] | 0, c[m >> 2] | 0, -1) | 0;
	                        if (c[m >> 2] | 0)zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                        c[c[h >> 2] >> 2] = c[k >> 2];
	                        c[f >> 2] = c[j >> 2];
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    } else {
	                        c[m >> 2] = Bh(65640, c[j >> 2] | 0, 0, 0) | 0;
	                        c[j >> 2] = AP(c[(c[g >> 2] | 0) + 296 >> 2] | 0, c[m >> 2] | 0, -1) | 0;
	                        if (c[m >> 2] | 0)zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                        c[c[h >> 2] >> 2] = c[k >> 2];
	                        c[f >> 2] = c[j >> 2];
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    }
	                } else c[c[h >> 2] >> 2] = 0; while (0);
	                c[f >> 2] = c[j >> 2];
	                n = c[f >> 2] | 0;
	                i = e;
	                return n | 0
	            }

	            function oh(a, b, e, f, g, h, j) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                var k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0;
	                k = i;
	                i = i + 64 | 0;
	                l = k + 52 | 0;
	                m = k + 48 | 0;
	                n = k + 44 | 0;
	                o = k + 40 | 0;
	                p = k + 36 | 0;
	                q = k + 32 | 0;
	                r = k + 28 | 0;
	                s = k + 24 | 0;
	                t = k + 20 | 0;
	                u = k + 16 | 0;
	                v = k + 12 | 0;
	                w = k + 8 | 0;
	                x = k + 4 | 0;
	                y = k;
	                c[m >> 2] = a;
	                c[n >> 2] = b;
	                c[o >> 2] = e;
	                c[p >> 2] = f;
	                c[q >> 2] = g;
	                c[r >> 2] = h;
	                c[s >> 2] = j;
	                c[v >> 2] = 0;
	                c[w >> 2] = 0;
	                c[c[q >> 2] >> 2] = 0;
	                if ((c[(c[m >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[m >> 2] | 0);
	                c[t >> 2] = nh(c[m >> 2] | 0, c[p >> 2] | 0) | 0;
	                j = c[m >> 2] | 0;
	                if (!(c[t >> 2] | 0)) {
	                    xg(j, 68, 69032);
	                    c[l >> 2] = 0;
	                    z = c[l >> 2] | 0;
	                    i = k;
	                    return z | 0
	                }
	                if ((c[j + 352 >> 2] | 0) != 0 ? (c[x >> 2] = Vj(c[(c[m >> 2] | 0) + 352 >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, c[c[p >> 2] >> 2] | 0, c[t >> 2] | 0) | 0, (c[x >> 2] | 0) != 0) : 0)c[w >> 2] = 1;
	                Ue(c[m >> 2] | 0) | 0;
	                x = c[m >> 2] | 0;
	                if ((d[c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 61) {
	                    pg(x, 41, 69064, c[t >> 2] | 0);
	                    c[l >> 2] = 0;
	                    z = c[l >> 2] | 0;
	                    i = k;
	                    return z | 0
	                }
	                me(x);
	                Ue(c[m >> 2] | 0) | 0;
	                c[u >> 2] = Eg(c[m >> 2] | 0, c[r >> 2] | 0, c[s >> 2] | 0, c[w >> 2] | 0) | 0;
	                if ((((c[w >> 2] | 0) != 0 ? (c[c[s >> 2] >> 2] | 0) != 0 : 0) ? (c[y >> 2] = zh(c[m >> 2] | 0, c[u >> 2] | 0, c[r >> 2] | 0) | 0, (c[y >> 2] | 0) != 0) : 0) ? (c[y >> 2] | 0) != (c[u >> 2] | 0) : 0) {
	                    zb[c[135736 >> 2] & 511](c[u >> 2] | 0);
	                    c[u >> 2] = c[y >> 2]
	                }
	                c[(c[m >> 2] | 0) + 172 >> 2] = 7;
	                if ((c[c[p >> 2] >> 2] | 0) == (c[(c[m >> 2] | 0) + 312 >> 2] | 0)) {
	                    if (((c[(c[m >> 2] | 0) + 268 >> 2] | 0) != 0 ? (qy(c[t >> 2] | 0, 71704) | 0) != 0 : 0) ? (c[v >> 2] = ly(c[u >> 2] | 0, c[c[r >> 2] >> 2] | 0) | 0, (Ne(c[v >> 2] | 0) | 0) == 0) : 0)rg(c[m >> 2] | 0, 98, 69128, c[v >> 2] | 0, 0);
	                    do if (qy(c[t >> 2] | 0, 71712) | 0) {
	                        c[v >> 2] = ly(c[u >> 2] | 0, c[c[r >> 2] >> 2] | 0) | 0;
	                        if (qy(c[v >> 2] | 0, 69184) | 0) {
	                            c[c[(c[m >> 2] | 0) + 232 >> 2] >> 2] = 0;
	                            break
	                        }
	                        p = (qy(c[v >> 2] | 0, 69192) | 0) != 0;
	                        y = c[m >> 2] | 0;
	                        if (p) {
	                            c[c[y + 232 >> 2] >> 2] = 1;
	                            break
	                        } else {
	                            rg(y, 102, 69208, c[v >> 2] | 0, 0);
	                            break
	                        }
	                    } while (0);
	                    if (c[v >> 2] | 0)zb[c[135736 >> 2] & 511](c[v >> 2] | 0)
	                }
	                c[c[q >> 2] >> 2] = c[u >> 2];
	                c[l >> 2] = c[t >> 2];
	                z = c[l >> 2] | 0;
	                i = k;
	                return z | 0
	            }

	            function ph(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h;
	                k = h + 32 | 0;
	                l = h + 28 | 0;
	                m = h + 24 | 0;
	                n = h + 20 | 0;
	                o = h + 16 | 0;
	                p = h + 12 | 0;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                if (((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 212 >> 2] | 0) != 0 : 0) ? (c[(c[k >> 2] | 0) + 172 >> 2] | 0) == -1 : 0) {
	                    i = h;
	                    return
	                }
	                g = c[k >> 2] | 0;
	                k = c[l >> 2] | 0;
	                l = c[n >> 2] | 0;
	                f = c[o >> 2] | 0;
	                e = c[p >> 2] | 0;
	                d = c[m >> 2] | 0;
	                m = c[o >> 2] | 0;
	                o = c[p >> 2] | 0;
	                c[j >> 2] = c[n >> 2];
	                c[j + 4 >> 2] = m;
	                c[j + 8 >> 2] = o;
	                Xd(0, 0, 0, g, 0, 3, k, 1, 0, 0, l, f, e, 0, 0, d, j);
	                i = h;
	                return
	            }

	            function qh(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[(c[f >> 2] | 0) + 300 >> 2] | 0)) {
	                    c[k >> 2] = 55;
	                    c[h >> 2] = Cb[c[135744 >> 2] & 511](c[k >> 2] << 2) | 0;
	                    if ((c[h >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 300 >> 2] = c[h >> 2], c[j >> 2] = Cb[c[135744 >> 2] & 511](((c[k >> 2] | 0) / 5 | 0) << 2) | 0, (c[j >> 2] | 0) != 0) : 0) {
	                        c[(c[f >> 2] | 0) + 340 >> 2] = c[j >> 2];
	                        c[(c[f >> 2] | 0) + 304 >> 2] = c[k >> 2];
	                        l = 9
	                    } else l = 10
	                } else if (((c[g >> 2] | 0) + 5 | 0) > (c[(c[f >> 2] | 0) + 304 >> 2] | 0)) {
	                    c[k >> 2] = (c[g >> 2] | 0) + 5 << 1;
	                    c[h >> 2] = Hb[c[135760 >> 2] & 511](c[(c[f >> 2] | 0) + 300 >> 2] | 0, c[k >> 2] << 2) | 0;
	                    if ((c[h >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 300 >> 2] = c[h >> 2], c[j >> 2] = Hb[c[135760 >> 2] & 511](c[(c[f >> 2] | 0) + 340 >> 2] | 0, ((c[k >> 2] | 0) / 5 | 0) << 2) | 0, (c[j >> 2] | 0) != 0) : 0) {
	                        c[(c[f >> 2] | 0) + 340 >> 2] = c[j >> 2];
	                        c[(c[f >> 2] | 0) + 304 >> 2] = c[k >> 2];
	                        l = 9
	                    } else l = 10
	                } else l = 9;
	                if ((l | 0) == 9) {
	                    c[e >> 2] = c[(c[f >> 2] | 0) + 304 >> 2];
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                } else if ((l | 0) == 10) {
	                    ie(c[f >> 2] | 0, 0);
	                    c[e >> 2] = -1;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                return 0
	            }

	            function rh(a, b, e) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 28 | 0;
	                h = f + 24 | 0;
	                j = f + 20 | 0;
	                k = f + 16 | 0;
	                l = f + 12 | 0;
	                m = f + 8 | 0;
	                n = f + 4 | 0;
	                o = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                e = c[h >> 2] | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[g >> 2] = mh(e, c[j >> 2] | 0) | 0;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                if ((c[e + 292 >> 2] | 0) == 0 ? ((c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[h >> 2] | 0);
	                c[m >> 2] = c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                c[l >> 2] = c[k >> 2];
	                while (1) {
	                    if (!(d[c[m >> 2] >> 0] | 0))break;
	                    if ((d[c[m >> 2] >> 0] | 0 | 0) != (d[c[l >> 2] >> 0] | 0 | 0))break;
	                    c[m >> 2] = (c[m >> 2] | 0) + 1;
	                    c[l >> 2] = (c[l >> 2] | 0) + 1
	                }
	                a:do if ((d[c[l >> 2] >> 0] | 0 | 0) == 0 ? (d[c[m >> 2] >> 0] | 0 | 0) == 58 : 0) {
	                    c[m >> 2] = (c[m >> 2] | 0) + 1;
	                    c[l >> 2] = c[j >> 2];
	                    while (1) {
	                        if (!(d[c[m >> 2] >> 0] | 0))break;
	                        if ((d[c[m >> 2] >> 0] | 0 | 0) != (d[c[l >> 2] >> 0] | 0 | 0))break;
	                        c[m >> 2] = (c[m >> 2] | 0) + 1;
	                        c[l >> 2] = (c[l >> 2] | 0) + 1
	                    }
	                    if (!(d[c[l >> 2] >> 0] | 0)) {
	                        do if ((d[c[m >> 2] >> 0] | 0 | 0) != 62 ? (d[c[m >> 2] >> 0] | 0 | 0) != 32 : 0) {
	                            if (9 <= (d[c[m >> 2] >> 0] | 0 | 0) ? (d[c[m >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[m >> 2] >> 0] | 0 | 0) != 13)break a
	                        } while (0);
	                        c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] = c[m >> 2];
	                        c[g >> 2] = 1;
	                        p = c[g >> 2] | 0;
	                        i = f;
	                        return p | 0
	                    }
	                } while (0);
	                c[n >> 2] = nh(c[h >> 2] | 0, o) | 0;
	                if ((c[n >> 2] | 0) == (c[j >> 2] | 0) ? (c[k >> 2] | 0) == (c[o >> 2] | 0) : 0) {
	                    c[g >> 2] = 1;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                c[g >> 2] = c[n >> 2];
	                p = c[g >> 2] | 0;
	                i = f;
	                return p | 0
	            }

	            function sh(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 20 | 0;
	                j = g + 16 | 0;
	                k = g + 12 | 0;
	                l = g + 8 | 0;
	                m = g;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[g + 4 >> 2] = f;
	                c[m >> 2] = c[j >> 2];
	                if ((c[h >> 2] | 0) != 1) {
	                    i = g;
	                    return
	                }
	                ck(c[(c[m >> 2] | 0) + 352 >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, 0) | 0;
	                i = g;
	                return
	            }

	            function th(a, b, e) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = e;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    Db[c[135904 >> 2] & 511](c[33980] | 0, 70648, f);
	                    i = f;
	                    return
	                }
	                if ((c[(c[g >> 2] | 0) + 292 >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 40 >> 2] | 0) == 1 : 0) {
	                    c[k >> 2] = c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2];
	                    c[k >> 2] = (c[k >> 2] | 0) + -1;
	                    while (1) {
	                        if ((c[k >> 2] | 0) >>> 0 >= (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) >>> 0)l = (d[c[k >> 2] >> 0] | 0 | 0) != 60; else l = 0;
	                        m = c[k >> 2] | 0;
	                        if (!l)break;
	                        c[k >> 2] = m + -1
	                    }
	                    if (m >>> 0 < (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) >>> 0) {
	                        c[c[h >> 2] >> 2] = 0;
	                        c[c[j >> 2] >> 2] = 0;
	                        i = f;
	                        return
	                    }
	                    c[c[h >> 2] >> 2] = c[k >> 2];
	                    c[k >> 2] = (c[k >> 2] | 0) + 1;
	                    while (1) {
	                        if ((c[k >> 2] | 0) >>> 0 < (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) >>> 0)n = (d[c[k >> 2] >> 0] | 0 | 0) != 62; else n = 0;
	                        o = c[k >> 2] | 0;
	                        if (!n)break;
	                        m = c[k >> 2] | 0;
	                        if ((d[o >> 0] | 0 | 0) == 39) {
	                            c[k >> 2] = m + 1;
	                            while (1) {
	                                if ((c[k >> 2] | 0) >>> 0 < (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) >>> 0)p = (d[c[k >> 2] >> 0] | 0 | 0) != 39; else p = 0;
	                                q = c[k >> 2] | 0;
	                                if (!p)break;
	                                c[k >> 2] = q + 1
	                            }
	                            if (q >>> 0 >= (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) >>> 0)continue;
	                            c[k >> 2] = (c[k >> 2] | 0) + 1;
	                            continue
	                        } else {
	                            l = (d[m >> 0] | 0 | 0) == 34;
	                            c[k >> 2] = (c[k >> 2] | 0) + 1;
	                            if (!l)continue;
	                            while (1) {
	                                if ((c[k >> 2] | 0) >>> 0 < (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) >>> 0)r = (d[c[k >> 2] >> 0] | 0 | 0) != 34; else r = 0;
	                                s = c[k >> 2] | 0;
	                                if (!r)break;
	                                c[k >> 2] = s + 1
	                            }
	                            if (s >>> 0 >= (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) >>> 0)continue;
	                            c[k >> 2] = (c[k >> 2] | 0) + 1;
	                            continue
	                        }
	                    }
	                    if (o >>> 0 < (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) >>> 0) {
	                        c[c[j >> 2] >> 2] = c[k >> 2];
	                        i = f;
	                        return
	                    }
	                    c[k >> 2] = c[c[h >> 2] >> 2];
	                    c[k >> 2] = (c[k >> 2] | 0) + -1;
	                    while (1) {
	                        if ((c[k >> 2] | 0) >>> 0 >= (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) >>> 0)t = (d[c[k >> 2] >> 0] | 0 | 0) != 62; else t = 0;
	                        u = c[k >> 2] | 0;
	                        if (!t)break;
	                        c[k >> 2] = u + -1
	                    }
	                    if (u >>> 0 >= (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) >>> 0) {
	                        c[c[j >> 2] >> 2] = c[k >> 2];
	                        i = f;
	                        return
	                    } else {
	                        c[c[j >> 2] >> 2] = 0;
	                        i = f;
	                        return
	                    }
	                }
	                c[c[h >> 2] >> 2] = 0;
	                c[c[j >> 2] >> 2] = 0;
	                i = f;
	                return
	            }

	            function uh(b, e, f, g) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                h = i;
	                i = i + 32 | 0;
	                j = h + 20 | 0;
	                k = h + 16 | 0;
	                l = h + 26 | 0;
	                m = h + 25 | 0;
	                n = h + 24 | 0;
	                o = h + 12 | 0;
	                p = h + 8 | 0;
	                q = h + 4 | 0;
	                r = h;
	                c[k >> 2] = b;
	                a[l >> 0] = e;
	                a[m >> 0] = f;
	                a[n >> 0] = g;
	                c[q >> 2] = c[(c[k >> 2] | 0) + 36 >> 2];
	                if (!(c[q >> 2] | 0)) {
	                    c[j >> 2] = -1;
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                }
	                c[o >> 2] = (c[(c[q >> 2] | 0) + 16 >> 2] | 0) - (c[(c[q >> 2] | 0) + 12 >> 2] | 0);
	                if ((c[o >> 2] | 0) < 0) {
	                    c[j >> 2] = -1;
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                }
	                if ((c[(c[k >> 2] | 0) + 204 >> 2] | 0) > (c[o >> 2] | 0))c[o >> 2] = c[(c[k >> 2] | 0) + 204 >> 2];
	                g = c[q >> 2] | 0;
	                if (!(c[c[q >> 2] >> 2] | 0)) {
	                    c[r >> 2] = c[g + 12 >> 2];
	                    c[p >> 2] = c[(c[q >> 2] | 0) + 24 >> 2]
	                } else {
	                    c[r >> 2] = Vy(c[(c[g >> 2] | 0) + 16 >> 2] | 0) | 0;
	                    c[p >> 2] = _y(c[(c[c[q >> 2] >> 2] | 0) + 16 >> 2] | 0) | 0
	                }
	                if (!(a[n >> 0] | 0)) {
	                    if (a[m >> 0] | 0)c[p >> 2] = (c[p >> 2] | 0) + -1
	                } else c[p >> 2] = (c[p >> 2] | 0) - 2;
	                a:while (1) {
	                    t = c[o >> 2] | 0;
	                    if ((c[o >> 2] | 0) >= (c[p >> 2] | 0)) {
	                        u = 23;
	                        break
	                    }
	                    do if ((d[(c[r >> 2] | 0) + t >> 0] | 0) == (d[l >> 0] | 0))if (d[n >> 0] | 0) {
	                        if ((d[(c[r >> 2] | 0) + ((c[o >> 2] | 0) + 1) >> 0] | 0) != (d[m >> 0] | 0))break;
	                        if ((d[(c[r >> 2] | 0) + ((c[o >> 2] | 0) + 2) >> 0] | 0) != (d[n >> 0] | 0))break; else {
	                            u = 21;
	                            break a
	                        }
	                    } else {
	                        if (!(d[m >> 0] | 0)) {
	                            u = 21;
	                            break a
	                        }
	                        if ((d[(c[r >> 2] | 0) + ((c[o >> 2] | 0) + 1) >> 0] | 0) != (d[m >> 0] | 0))break; else {
	                            u = 21;
	                            break a
	                        }
	                    } while (0);
	                    c[o >> 2] = (c[o >> 2] | 0) + 1
	                }
	                if ((u | 0) == 21) {
	                    c[(c[k >> 2] | 0) + 204 >> 2] = 0;
	                    c[j >> 2] = (c[o >> 2] | 0) - ((c[(c[q >> 2] | 0) + 16 >> 2] | 0) - (c[(c[q >> 2] | 0) + 12 >> 2] | 0));
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                } else if ((u | 0) == 23) {
	                    c[(c[k >> 2] | 0) + 204 >> 2] = t;
	                    c[j >> 2] = -1;
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                }
	                return 0
	            }

	            function vh(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 28 | 0;
	                j = g + 24 | 0;
	                k = g + 20 | 0;
	                l = g + 16 | 0;
	                m = g + 12 | 0;
	                n = g + 8 | 0;
	                o = g + 4 | 0;
	                p = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                a:do if ((c[(c[j >> 2] | 0) + 188 >> 2] | 0) >= (c[(c[j >> 2] | 0) + 192 >> 2] | 0)) {
	                    f = (c[j >> 2] | 0) + 192 | 0;
	                    c[f >> 2] = c[f >> 2] << 1;
	                    c[o >> 2] = Hb[c[135760 >> 2] & 511](c[(c[j >> 2] | 0) + 196 >> 2] | 0, c[(c[j >> 2] | 0) + 192 >> 2] << 2) | 0;
	                    do if (c[o >> 2] | 0) {
	                        c[(c[j >> 2] | 0) + 196 >> 2] = c[o >> 2];
	                        c[p >> 2] = Hb[c[135760 >> 2] & 511](c[(c[j >> 2] | 0) + 344 >> 2] | 0, (c[(c[j >> 2] | 0) + 192 >> 2] | 0) * 3 << 2) | 0;
	                        if (!(c[p >> 2] | 0)) {
	                            f = (c[j >> 2] | 0) + 192 | 0;
	                            c[f >> 2] = (c[f >> 2] | 0) / 2 | 0;
	                            break
	                        } else {
	                            c[(c[j >> 2] | 0) + 344 >> 2] = c[p >> 2];
	                            break a
	                        }
	                    } else {
	                        f = (c[j >> 2] | 0) + 192 | 0;
	                        c[f >> 2] = (c[f >> 2] | 0) / 2 | 0
	                    } while (0);
	                    ie(c[j >> 2] | 0, 0);
	                    c[h >> 2] = -1;
	                    q = c[h >> 2] | 0;
	                    i = g;
	                    return q | 0
	                } while (0);
	                c[(c[(c[j >> 2] | 0) + 196 >> 2] | 0) + (c[(c[j >> 2] | 0) + 188 >> 2] << 2) >> 2] = c[k >> 2];
	                c[(c[j >> 2] | 0) + 184 >> 2] = c[k >> 2];
	                c[(c[(c[j >> 2] | 0) + 344 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 188 >> 2] | 0) * 3 << 2) >> 2] = c[l >> 2];
	                c[(c[(c[j >> 2] | 0) + 344 >> 2] | 0) + (((c[(c[j >> 2] | 0) + 188 >> 2] | 0) * 3 | 0) + 1 << 2) >> 2] = c[m >> 2];
	                c[(c[(c[j >> 2] | 0) + 344 >> 2] | 0) + (((c[(c[j >> 2] | 0) + 188 >> 2] | 0) * 3 | 0) + 2 << 2) >> 2] = c[n >> 2];
	                n = (c[j >> 2] | 0) + 188 | 0;
	                j = c[n >> 2] | 0;
	                c[n >> 2] = j + 1;
	                c[h >> 2] = j;
	                q = c[h >> 2] | 0;
	                i = g;
	                return q | 0
	            }

	            function wh(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if ((c[(c[e >> 2] | 0) + 188 >> 2] | 0) <= 0) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = (c[e >> 2] | 0) + 188 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + -1;
	                a = c[e >> 2] | 0;
	                if ((c[(c[e >> 2] | 0) + 188 >> 2] | 0) > 0)c[(c[e >> 2] | 0) + 184 >> 2] = c[(c[(c[e >> 2] | 0) + 196 >> 2] | 0) + ((c[a + 188 >> 2] | 0) - 1 << 2) >> 2]; else c[a + 184 >> 2] = 0;
	                c[f >> 2] = c[(c[(c[e >> 2] | 0) + 196 >> 2] | 0) + (c[(c[e >> 2] | 0) + 188 >> 2] << 2) >> 2];
	                c[(c[(c[e >> 2] | 0) + 196 >> 2] | 0) + (c[(c[e >> 2] | 0) + 188 >> 2] << 2) >> 2] = 0;
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function xh(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f + 20 | 0;
	                m = f;
	                c[h >> 2] = b;
	                c[j >> 2] = e;
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) <= 0) {
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                c[k >> 2] = 0;
	                while (1) {
	                    o = c[k >> 2] | 0;
	                    if ((c[k >> 2] | 0) >= (c[j >> 2] | 0)) {
	                        p = 53;
	                        break
	                    }
	                    a[l >> 0] = a[(c[h >> 2] | 0) + o >> 0] | 0;
	                    e = d[l >> 0] | 0;
	                    if (!((d[l >> 0] | 0) & 128)) {
	                        if ((e | 0) >= 32) {
	                            c[k >> 2] = (c[k >> 2] | 0) + 1;
	                            continue
	                        }
	                        if (((d[l >> 0] | 0 | 0) != 10 ? (d[l >> 0] | 0 | 0) != 13 : 0) ? (d[l >> 0] | 0 | 0) != 9 : 0) {
	                            p = 12;
	                            break
	                        }
	                        c[k >> 2] = (c[k >> 2] | 0) + 1;
	                        continue
	                    }
	                    if ((e & 224 | 0) == 192) {
	                        q = c[k >> 2] | 0;
	                        if (((c[k >> 2] | 0) + 2 | 0) > (c[j >> 2] | 0)) {
	                            p = 15;
	                            break
	                        }
	                        r = c[k >> 2] | 0;
	                        if (((d[(c[h >> 2] | 0) + (q + 1) >> 0] | 0) & 192 | 0) != 128) {
	                            p = 17;
	                            break
	                        }
	                        c[m >> 2] = ((d[(c[h >> 2] | 0) + r >> 0] | 0) & 31) << 6;
	                        c[m >> 2] = c[m >> 2] | (d[(c[h >> 2] | 0) + ((c[k >> 2] | 0) + 1) >> 0] | 0) & 63;
	                        e = c[m >> 2] | 0;
	                        if ((c[m >> 2] | 0) < 256) {
	                            if (!(9 <= (e | 0) & (c[m >> 2] | 0) <= 10 | (c[m >> 2] | 0) == 13 | 32 <= (c[m >> 2] | 0))) {
	                                p = 23;
	                                break
	                            }
	                        } else if ((!(256 <= (e | 0) & (c[m >> 2] | 0) <= 55295) ? !(57344 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 65533) : 0) ? !(65536 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 1114111) : 0) {
	                            p = 23;
	                            break
	                        }
	                        c[k >> 2] = (c[k >> 2] | 0) + 2;
	                        continue
	                    }
	                    if (((d[l >> 0] | 0) & 240 | 0) == 224) {
	                        s = c[k >> 2] | 0;
	                        if (((c[k >> 2] | 0) + 3 | 0) > (c[j >> 2] | 0)) {
	                            p = 27;
	                            break
	                        }
	                        if (((d[(c[h >> 2] | 0) + (s + 1) >> 0] | 0) & 192 | 0) != 128) {
	                            p = 30;
	                            break
	                        }
	                        if (((d[(c[h >> 2] | 0) + ((c[k >> 2] | 0) + 2) >> 0] | 0) & 192 | 0) != 128) {
	                            p = 30;
	                            break
	                        }
	                        c[m >> 2] = ((d[(c[h >> 2] | 0) + (c[k >> 2] | 0) >> 0] | 0) & 15) << 12;
	                        c[m >> 2] = c[m >> 2] | ((d[(c[h >> 2] | 0) + ((c[k >> 2] | 0) + 1) >> 0] | 0) & 63) << 6;
	                        c[m >> 2] = c[m >> 2] | (d[(c[h >> 2] | 0) + ((c[k >> 2] | 0) + 2) >> 0] | 0) & 63;
	                        e = c[m >> 2] | 0;
	                        if ((c[m >> 2] | 0) < 256) {
	                            if (!(9 <= (e | 0) & (c[m >> 2] | 0) <= 10 | (c[m >> 2] | 0) == 13 | 32 <= (c[m >> 2] | 0))) {
	                                p = 36;
	                                break
	                            }
	                        } else if ((!(256 <= (e | 0) & (c[m >> 2] | 0) <= 55295) ? !(57344 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 65533) : 0) ? !(65536 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 1114111) : 0) {
	                            p = 36;
	                            break
	                        }
	                        c[k >> 2] = (c[k >> 2] | 0) + 3;
	                        continue
	                    }
	                    t = c[k >> 2] | 0;
	                    if (((d[l >> 0] | 0) & 248 | 0) != 240) {
	                        p = 52;
	                        break
	                    }
	                    u = c[k >> 2] | 0;
	                    if ((t + 4 | 0) > (c[j >> 2] | 0)) {
	                        p = 40;
	                        break
	                    }
	                    if (((d[(c[h >> 2] | 0) + (u + 1) >> 0] | 0) & 192 | 0) != 128) {
	                        p = 44;
	                        break
	                    }
	                    if (((d[(c[h >> 2] | 0) + ((c[k >> 2] | 0) + 2) >> 0] | 0) & 192 | 0) != 128) {
	                        p = 44;
	                        break
	                    }
	                    if (((d[(c[h >> 2] | 0) + ((c[k >> 2] | 0) + 3) >> 0] | 0) & 192 | 0) != 128) {
	                        p = 44;
	                        break
	                    }
	                    c[m >> 2] = ((d[(c[h >> 2] | 0) + (c[k >> 2] | 0) >> 0] | 0) & 7) << 18;
	                    c[m >> 2] = c[m >> 2] | ((d[(c[h >> 2] | 0) + ((c[k >> 2] | 0) + 1) >> 0] | 0) & 63) << 12;
	                    c[m >> 2] = c[m >> 2] | ((d[(c[h >> 2] | 0) + ((c[k >> 2] | 0) + 2) >> 0] | 0) & 63) << 6;
	                    c[m >> 2] = c[m >> 2] | (d[(c[h >> 2] | 0) + ((c[k >> 2] | 0) + 3) >> 0] | 0) & 63;
	                    e = c[m >> 2] | 0;
	                    if ((c[m >> 2] | 0) < 256) {
	                        if (!(9 <= (e | 0) & (c[m >> 2] | 0) <= 10 | (c[m >> 2] | 0) == 13 | 32 <= (c[m >> 2] | 0))) {
	                            p = 50;
	                            break
	                        }
	                    } else if ((!(256 <= (e | 0) & (c[m >> 2] | 0) <= 55295) ? !(57344 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 65533) : 0) ? !(65536 <= (c[m >> 2] | 0) & (c[m >> 2] | 0) <= 1114111) : 0) {
	                        p = 50;
	                        break
	                    }
	                    c[k >> 2] = (c[k >> 2] | 0) + 4
	                }
	                switch (p | 0) {
	                    case 12:
	                    {
	                        c[g >> 2] = 0 - (c[k >> 2] | 0);
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    case 15:
	                    {
	                        c[g >> 2] = q;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    case 17:
	                    {
	                        c[g >> 2] = 0 - r;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    case 23:
	                    {
	                        c[g >> 2] = 0 - (c[k >> 2] | 0);
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    case 27:
	                    {
	                        c[g >> 2] = s;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    case 30:
	                    {
	                        c[g >> 2] = 0 - (c[k >> 2] | 0);
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    case 36:
	                    {
	                        c[g >> 2] = 0 - (c[k >> 2] | 0);
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    case 40:
	                    {
	                        c[g >> 2] = u;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    case 44:
	                    {
	                        c[g >> 2] = 0 - (c[k >> 2] | 0);
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    case 50:
	                    {
	                        c[g >> 2] = 0 - (c[k >> 2] | 0);
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    case 52:
	                    {
	                        c[g >> 2] = 0 - t;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    case 53:
	                    {
	                        c[g >> 2] = o;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                }
	                return 0
	            }

	            function yh(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                b = i;
	                i = i + 32 | 0;
	                e = b + 16 | 0;
	                f = b + 12 | 0;
	                g = b + 8 | 0;
	                h = b + 4 | 0;
	                j = b;
	                c[f >> 2] = a;
	                c[j >> 2] = 0;
	                c[g >> 2] = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                if ((d[c[g >> 2] >> 0] | 0 | 0) >= 97 ? (d[c[g >> 2] >> 0] | 0 | 0) <= 122 : 0)k = 6; else k = 3;
	                do if ((k | 0) == 3) {
	                    if ((d[c[g >> 2] >> 0] | 0 | 0) >= 65 ? (d[c[g >> 2] >> 0] | 0 | 0) <= 90 : 0) {
	                        k = 6;
	                        break
	                    }
	                    if ((d[c[g >> 2] >> 0] | 0 | 0) == 95)k = 6
	                } while (0);
	                if ((k | 0) == 6) {
	                    c[g >> 2] = (c[g >> 2] | 0) + 1;
	                    while (1) {
	                        if ((d[c[g >> 2] >> 0] | 0 | 0) >= 97 ? (d[c[g >> 2] >> 0] | 0 | 0) <= 122 : 0)l = 1; else k = 9;
	                        do if ((k | 0) == 9) {
	                            k = 0;
	                            if ((d[c[g >> 2] >> 0] | 0 | 0) >= 65 ? (d[c[g >> 2] >> 0] | 0 | 0) <= 90 : 0) {
	                                l = 1;
	                                break
	                            }
	                            if ((d[c[g >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[g >> 2] >> 0] | 0 | 0) <= 57 : 0) {
	                                l = 1;
	                                break
	                            }
	                            if ((d[c[g >> 2] >> 0] | 0 | 0) != 95 ? (d[c[g >> 2] >> 0] | 0 | 0) != 45 : 0)l = (d[c[g >> 2] >> 0] | 0 | 0) == 46; else l = 1
	                        } while (0);
	                        m = c[g >> 2] | 0;
	                        if (!l)break;
	                        c[g >> 2] = m + 1
	                    }
	                    if ((d[m >> 0] | 0 | 0) > 0 ? (d[c[g >> 2] >> 0] | 0 | 0) < 128 : 0) {
	                        c[j >> 2] = (c[g >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0);
	                        if ((c[j >> 2] | 0) > 5e4 ? (c[(c[f >> 2] | 0) + 360 >> 2] & 524288 | 0) == 0 : 0) {
	                            og(c[f >> 2] | 0, 110, 70920);
	                            c[e >> 2] = 0;
	                            n = c[e >> 2] | 0;
	                            i = b;
	                            return n | 0
	                        }
	                        c[h >> 2] = AP(c[(c[f >> 2] | 0) + 296 >> 2] | 0, c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0, c[j >> 2] | 0) | 0;
	                        c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] = c[g >> 2];
	                        g = (c[f >> 2] | 0) + 200 | 0;
	                        c[g >> 2] = (c[g >> 2] | 0) + (c[j >> 2] | 0);
	                        g = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                        c[g >> 2] = (c[g >> 2] | 0) + (c[j >> 2] | 0);
	                        if (!(c[h >> 2] | 0))ie(c[f >> 2] | 0, 0);
	                        c[e >> 2] = c[h >> 2];
	                        n = c[e >> 2] | 0;
	                        i = b;
	                        return n | 0
	                    }
	                }
	                c[e >> 2] = Ah(c[f >> 2] | 0) | 0;
	                n = c[e >> 2] | 0;
	                i = b;
	                return n | 0
	            }

	            function zh(a, b, e) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f + 32 | 0;
	                h = f + 28 | 0;
	                j = f + 24 | 0;
	                k = f + 20 | 0;
	                l = f + 16 | 0;
	                m = f + 12 | 0;
	                n = f + 8 | 0;
	                o = f + 4 | 0;
	                p = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[m >> 2] = 0;
	                c[n >> 2] = 0;
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0) {
	                    c[g >> 2] = 0;
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                c[l >> 2] = c[c[k >> 2] >> 2];
	                if ((c[l >> 2] | 0) <= 0) {
	                    c[g >> 2] = 0;
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                c[o >> 2] = c[j >> 2];
	                while (1) {
	                    if ((d[c[o >> 2] >> 0] | 0 | 0) != 32)break;
	                    c[o >> 2] = (c[o >> 2] | 0) + 1;
	                    c[m >> 2] = (c[m >> 2] | 0) + 1
	                }
	                while (1) {
	                    if (!(d[c[o >> 2] >> 0] | 0))break;
	                    e = (d[c[o >> 2] >> 0] | 0 | 0) == 32;
	                    c[o >> 2] = (c[o >> 2] | 0) + 1;
	                    if (!e)continue;
	                    if ((d[c[o >> 2] >> 0] | 0 | 0) == 32) {
	                        r = 12;
	                        break
	                    }
	                    if (!(d[c[o >> 2] >> 0] | 0)) {
	                        r = 12;
	                        break
	                    }
	                }
	                if ((r | 0) == 12)c[n >> 2] = 1;
	                if (c[n >> 2] | 0) {
	                    c[p >> 2] = ly((c[j >> 2] | 0) + (c[m >> 2] | 0) | 0, (c[l >> 2] | 0) - (c[m >> 2] | 0) + 1 | 0) | 0;
	                    if (!(c[p >> 2] | 0)) {
	                        ie(c[h >> 2] | 0, 0);
	                        c[g >> 2] = 0;
	                        q = c[g >> 2] | 0;
	                        i = f;
	                        return q | 0
	                    } else {
	                        Mg(c[p >> 2] | 0, c[p >> 2] | 0) | 0;
	                        h = ZT(c[p >> 2] | 0) | 0;
	                        c[c[k >> 2] >> 2] = h;
	                        c[g >> 2] = c[p >> 2];
	                        q = c[g >> 2] | 0;
	                        i = f;
	                        return q | 0
	                    }
	                } else if (c[m >> 2] | 0) {
	                    p = c[k >> 2] | 0;
	                    c[p >> 2] = (c[p >> 2] | 0) - (c[m >> 2] | 0);
	                    fU(c[j >> 2] | 0, (c[j >> 2] | 0) + (c[m >> 2] | 0) | 0, 1 + (c[c[k >> 2] >> 2] | 0) | 0) | 0;
	                    c[g >> 2] = c[j >> 2];
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                } else {
	                    c[g >> 2] = 0;
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                return 0
	            }

	            function Ah(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                b = i;
	                i = i + 32 | 0;
	                e = b + 24 | 0;
	                f = b + 20 | 0;
	                g = b + 16 | 0;
	                h = b + 12 | 0;
	                j = b + 8 | 0;
	                k = b + 4 | 0;
	                l = b;
	                c[f >> 2] = a;
	                c[g >> 2] = 0;
	                c[k >> 2] = 0;
	                if ((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[f >> 2] | 0);
	                c[l >> 2] = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                c[j >> 2] = ne(c[f >> 2] | 0, h) | 0;
	                if (!((c[j >> 2] | 0) == 32 | (c[j >> 2] | 0) == 62 | (c[j >> 2] | 0) == 47) ? (a = (kh(c[f >> 2] | 0, c[j >> 2] | 0) | 0) == 0, !(a | (c[j >> 2] | 0) == 58)) : 0) {
	                    while (1) {
	                        if (!((c[j >> 2] | 0) != 32 & (c[j >> 2] | 0) != 62 & (c[j >> 2] | 0) != 47)) {
	                            m = 30;
	                            break
	                        }
	                        a = (Cg(c[f >> 2] | 0, c[j >> 2] | 0) | 0) != 0;
	                        if (!(a & (c[j >> 2] | 0) != 58)) {
	                            m = 30;
	                            break
	                        }
	                        a = c[k >> 2] | 0;
	                        c[k >> 2] = a + 1;
	                        if ((a | 0) > 100) {
	                            if ((c[g >> 2] | 0) > 5e4 ? (c[(c[f >> 2] | 0) + 360 >> 2] & 524288 | 0) == 0 : 0) {
	                                m = 12;
	                                break
	                            }
	                            c[k >> 2] = 0;
	                            if ((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[f >> 2] | 0);
	                            if ((c[(c[f >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                                m = 17;
	                                break
	                            }
	                        }
	                        c[g >> 2] = (c[g >> 2] | 0) + (c[h >> 2] | 0);
	                        a = c[(c[f >> 2] | 0) + 36 >> 2] | 0;
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                            n = a + 28 | 0;
	                            c[n >> 2] = (c[n >> 2] | 0) + 1;
	                            c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                        } else {
	                            n = a + 32 | 0;
	                            c[n >> 2] = (c[n >> 2] | 0) + 1
	                        }
	                        n = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                        c[n >> 2] = (c[n >> 2] | 0) + (c[h >> 2] | 0);
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 37)We(c[f >> 2] | 0);
	                        c[l >> 2] = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                        c[j >> 2] = ne(c[f >> 2] | 0, h) | 0;
	                        if (c[j >> 2] | 0)continue;
	                        c[k >> 2] = 0;
	                        if ((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)vg(c[f >> 2] | 0);
	                        if ((c[(c[f >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                            m = 28;
	                            break
	                        }
	                        c[l >> 2] = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                        c[j >> 2] = ne(c[f >> 2] | 0, h) | 0
	                    }
	                    if ((m | 0) == 12) {
	                        og(c[f >> 2] | 0, 110, 70920);
	                        c[e >> 2] = 0;
	                        o = c[e >> 2] | 0;
	                        i = b;
	                        return o | 0
	                    } else if ((m | 0) == 17) {
	                        c[e >> 2] = 0;
	                        o = c[e >> 2] | 0;
	                        i = b;
	                        return o | 0
	                    } else if ((m | 0) == 28) {
	                        c[e >> 2] = 0;
	                        o = c[e >> 2] | 0;
	                        i = b;
	                        return o | 0
	                    } else if ((m | 0) == 30) {
	                        if ((c[g >> 2] | 0) > 5e4 ? (c[(c[f >> 2] | 0) + 360 >> 2] & 524288 | 0) == 0 : 0) {
	                            og(c[f >> 2] | 0, 110, 70920);
	                            c[e >> 2] = 0;
	                            o = c[e >> 2] | 0;
	                            i = b;
	                            return o | 0
	                        }
	                        c[e >> 2] = AP(c[(c[f >> 2] | 0) + 296 >> 2] | 0, (c[l >> 2] | 0) + (0 - (c[g >> 2] | 0)) | 0, c[g >> 2] | 0) | 0;
	                        o = c[e >> 2] | 0;
	                        i = b;
	                        return o | 0
	                    }
	                }
	                c[e >> 2] = 0;
	                o = c[e >> 2] | 0;
	                i = b;
	                return o | 0
	            }

	            function Bh(b, d, e, f) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 28 | 0;
	                j = g + 24 | 0;
	                k = g + 20 | 0;
	                l = g + 16 | 0;
	                m = g + 12 | 0;
	                n = g + 8 | 0;
	                o = g + 4 | 0;
	                p = g;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                if (!(c[j >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    q = c[h >> 2] | 0;
	                    i = g;
	                    return q | 0
	                }
	                f = c[j >> 2] | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[h >> 2] = f;
	                    q = c[h >> 2] | 0;
	                    i = g;
	                    return q | 0
	                }
	                c[n >> 2] = ZT(f | 0) | 0;
	                c[o >> 2] = ZT(c[k >> 2] | 0) | 0;
	                if ((c[l >> 2] | 0) != 0 ? (c[m >> 2] | 0) >= ((c[n >> 2] | 0) + (c[o >> 2] | 0) + 2 | 0) : 0)c[p >> 2] = c[l >> 2]; else r = 7;
	                if ((r | 0) == 7 ? (c[p >> 2] = Cb[c[135752 >> 2] & 511]((c[n >> 2] | 0) + (c[o >> 2] | 0) + 2 | 0) | 0, (c[p >> 2] | 0) == 0) : 0) {
	                    tj(75136);
	                    c[h >> 2] = 0;
	                    q = c[h >> 2] | 0;
	                    i = g;
	                    return q | 0
	                }
	                eU(c[p >> 2] | 0, c[k >> 2] | 0, c[o >> 2] | 0) | 0;
	                a[(c[p >> 2] | 0) + (c[o >> 2] | 0) >> 0] = 58;
	                eU((c[p >> 2] | 0) + ((c[o >> 2] | 0) + 1) | 0, c[j >> 2] | 0, c[n >> 2] | 0) | 0;
	                a[(c[p >> 2] | 0) + ((c[n >> 2] | 0) + (c[o >> 2] | 0) + 1) >> 0] = 0;
	                c[h >> 2] = c[p >> 2];
	                q = c[h >> 2] | 0;
	                i = g;
	                return q | 0
	            }

	            function Ch(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = 0;
	                c[k >> 2] = 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[c[h >> 2] >> 2] = 0;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                if ((d[c[g >> 2] >> 0] | 0 | 0) == 58) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                while (1) {
	                    if (d[(c[g >> 2] | 0) + (c[j >> 2] | 0) >> 0] | 0)m = (d[(c[g >> 2] | 0) + (c[j >> 2] | 0) >> 0] | 0 | 0) != 58; else m = 0;
	                    n = c[j >> 2] | 0;
	                    if (!m)break;
	                    c[j >> 2] = n + 1
	                }
	                if (!(d[(c[g >> 2] | 0) + n >> 0] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                n = ly(c[g >> 2] | 0, c[j >> 2] | 0) | 0;
	                c[c[h >> 2] >> 2] = n;
	                if (!(c[c[h >> 2] >> 2] | 0)) {
	                    tj(75152);
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[k >> 2] = my((c[g >> 2] | 0) + ((c[j >> 2] | 0) + 1) | 0) | 0;
	                if (c[k >> 2] | 0) {
	                    c[f >> 2] = c[k >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                tj(75152);
	                if (c[c[h >> 2] >> 2] | 0) {
	                    zb[c[135736 >> 2] & 511](c[c[h >> 2] >> 2] | 0);
	                    c[c[h >> 2] >> 2] = 0
	                }
	                c[f >> 2] = 0;
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function Dh(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = 0;
	                do if (c[g >> 2] | 0) {
	                    if (!(c[h >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        break
	                    }
	                    if ((d[c[g >> 2] >> 0] | 0 | 0) == 58) {
	                        c[f >> 2] = 0;
	                        break
	                    }
	                    while (1) {
	                        if (d[(c[g >> 2] | 0) + (c[j >> 2] | 0) >> 0] | 0)k = (d[(c[g >> 2] | 0) + (c[j >> 2] | 0) >> 0] | 0 | 0) != 58; else k = 0;
	                        l = c[j >> 2] | 0;
	                        if (!k)break;
	                        c[j >> 2] = l + 1
	                    }
	                    if (!(d[(c[g >> 2] | 0) + l >> 0] | 0)) {
	                        c[f >> 2] = 0;
	                        break
	                    } else {
	                        c[c[h >> 2] >> 2] = c[j >> 2];
	                        c[f >> 2] = (c[g >> 2] | 0) + ((c[j >> 2] | 0) + 1);
	                        break
	                    }
	                } else c[f >> 2] = 0; while (0);
	                i = e;
	                return c[f >> 2] | 0
	            }

	            function Eh(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = c[g >> 2];
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = -1;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                a:do if (c[h >> 2] | 0)while (1) {
	                    do if ((d[c[j >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[j >> 2] >> 0] | 0 | 0) ? (d[c[j >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[j >> 2] >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    c[j >> 2] = (c[j >> 2] | 0) + 1
	                } while (0);
	                if ((d[c[j >> 2] >> 0] | 0 | 0) >= 97 ? (d[c[j >> 2] >> 0] | 0 | 0) <= 122 : 0)n = 14; else n = 11;
	                do if ((n | 0) == 11) {
	                    if ((d[c[j >> 2] >> 0] | 0 | 0) >= 65 ? (d[c[j >> 2] >> 0] | 0 | 0) <= 90 : 0) {
	                        n = 14;
	                        break
	                    }
	                    if ((d[c[j >> 2] >> 0] | 0 | 0) == 95)n = 14
	                } while (0);
	                if ((n | 0) == 14) {
	                    c[j >> 2] = (c[j >> 2] | 0) + 1;
	                    b:while (1) {
	                        if (!((d[c[j >> 2] >> 0] | 0 | 0) >= 97 ? (d[c[j >> 2] >> 0] | 0 | 0) <= 122 : 0))n = 17;
	                        do if ((n | 0) == 17) {
	                            n = 0;
	                            if ((d[c[j >> 2] >> 0] | 0 | 0) >= 65 ? (d[c[j >> 2] >> 0] | 0 | 0) <= 90 : 0)break;
	                            if ((d[c[j >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[j >> 2] >> 0] | 0 | 0) <= 57 : 0)break;
	                            if (((d[c[j >> 2] >> 0] | 0 | 0) != 95 ? (d[c[j >> 2] >> 0] | 0 | 0) != 45 : 0) ? (d[c[j >> 2] >> 0] | 0 | 0) != 46 : 0)break b
	                        } while (0);
	                        c[j >> 2] = (c[j >> 2] | 0) + 1
	                    }
	                    c:do if (c[h >> 2] | 0)while (1) {
	                        do if ((d[c[j >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[j >> 2] >> 0] | 0 | 0) ? (d[c[j >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[j >> 2] >> 0] | 0 | 0) != 13)break c
	                        } while (0);
	                        c[j >> 2] = (c[j >> 2] | 0) + 1
	                    } while (0);
	                    if (!(d[c[j >> 2] >> 0] | 0)) {
	                        c[f >> 2] = 0;
	                        m = c[f >> 2] | 0;
	                        i = e;
	                        return m | 0
	                    }
	                }
	                c[j >> 2] = c[g >> 2];
	                c[k >> 2] = oe(0, c[j >> 2] | 0, l) | 0;
	                d:do if (c[h >> 2] | 0)while (1) {
	                    if ((c[k >> 2] | 0) < 256) {
	                        if ((c[k >> 2] | 0) != 32 ? !(9 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 10) : 0)o = (c[k >> 2] | 0) == 13; else o = 1;
	                        p = o & 1
	                    } else p = 0;
	                    if (!p)break d;
	                    c[j >> 2] = (c[j >> 2] | 0) + (c[l >> 2] | 0);
	                    c[k >> 2] = oe(0, c[j >> 2] | 0, l) | 0
	                } while (0);
	                p = c[k >> 2] | 0;
	                if ((c[k >> 2] | 0) < 256) {
	                    if (((!(65 <= (p | 0) & (c[k >> 2] | 0) <= 90) ? !(97 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 122) : 0) ? !(192 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 214) : 0) ? !(216 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 246 | 248 <= (c[k >> 2] | 0)) : 0)n = 47
	                } else if (!(DQ(p, 199744) | 0))n = 47;
	                do if ((n | 0) == 47) {
	                    p = c[k >> 2] | 0;
	                    if ((c[k >> 2] | 0) < 256) {
	                        if ((p | 0) == 95)break
	                    } else {
	                        if (19968 <= (p | 0) & (c[k >> 2] | 0) <= 40869 | (c[k >> 2] | 0) == 12295)break;
	                        if (!((12321 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 12329 ^ 1) & (c[k >> 2] | 0) != 95))break
	                    }
	                    c[f >> 2] = 1;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                } while (0);
	                c[j >> 2] = (c[j >> 2] | 0) + (c[l >> 2] | 0);
	                c[k >> 2] = oe(0, c[j >> 2] | 0, l) | 0;
	                e:while (1) {
	                    p = c[k >> 2] | 0;
	                    if ((c[k >> 2] | 0) < 256) {
	                        if (((!(65 <= (p | 0) & (c[k >> 2] | 0) <= 90) ? !(97 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 122) : 0) ? !(192 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 214) : 0) ? !(216 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 246 | 248 <= (c[k >> 2] | 0)) : 0)n = 59
	                    } else if (!(DQ(p, 199744) | 0))n = 59;
	                    do if ((n | 0) == 59) {
	                        n = 0;
	                        if ((c[k >> 2] | 0) >= 256) {
	                            if (19968 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 40869 | (c[k >> 2] | 0) == 12295)break;
	                            if (12321 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 12329)break
	                        }
	                        p = c[k >> 2] | 0;
	                        if ((c[k >> 2] | 0) < 256) {
	                            if (48 <= (p | 0) & (c[k >> 2] | 0) <= 57 | (c[k >> 2] | 0) == 46 | (c[k >> 2] | 0) == 45 | (c[k >> 2] | 0) == 95)break
	                        } else {
	                            o = (DQ(p, 200216) | 0) != 0;
	                            if (o | (c[k >> 2] | 0) == 46 | (c[k >> 2] | 0) == 45 | (c[k >> 2] | 0) == 95)break
	                        }
	                        if ((c[k >> 2] | 0) >= 256 ? (DQ(c[k >> 2] | 0, 200144) | 0) != 0 : 0)break;
	                        o = c[k >> 2] | 0;
	                        if ((c[k >> 2] | 0) < 256)q = (o | 0) == 183 & 1; else q = DQ(o, 200272) | 0;
	                        if (!q)break e
	                    } while (0);
	                    c[j >> 2] = (c[j >> 2] | 0) + (c[l >> 2] | 0);
	                    c[k >> 2] = oe(0, c[j >> 2] | 0, l) | 0
	                }
	                f:do if (c[h >> 2] | 0)while (1) {
	                    if ((c[k >> 2] | 0) < 256) {
	                        if ((c[k >> 2] | 0) != 32 ? !(9 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 10) : 0)r = (c[k >> 2] | 0) == 13; else r = 1;
	                        s = r & 1
	                    } else s = 0;
	                    if (!s)break f;
	                    c[j >> 2] = (c[j >> 2] | 0) + (c[l >> 2] | 0);
	                    c[k >> 2] = oe(0, c[j >> 2] | 0, l) | 0
	                } while (0);
	                if (c[k >> 2] | 0) {
	                    c[f >> 2] = 1;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                } else {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                return 0
	            }

	            function Fh(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = c[g >> 2];
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = -1;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                a:do if (c[h >> 2] | 0)while (1) {
	                    do if ((d[c[j >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[j >> 2] >> 0] | 0 | 0) ? (d[c[j >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[j >> 2] >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    c[j >> 2] = (c[j >> 2] | 0) + 1
	                } while (0);
	                if ((d[c[j >> 2] >> 0] | 0 | 0) >= 97 ? (d[c[j >> 2] >> 0] | 0 | 0) <= 122 : 0)n = 14; else n = 11;
	                do if ((n | 0) == 11) {
	                    if ((d[c[j >> 2] >> 0] | 0 | 0) >= 65 ? (d[c[j >> 2] >> 0] | 0 | 0) <= 90 : 0) {
	                        n = 14;
	                        break
	                    }
	                    if ((d[c[j >> 2] >> 0] | 0 | 0) == 95)n = 14
	                } while (0);
	                b:do if ((n | 0) == 14) {
	                    c[j >> 2] = (c[j >> 2] | 0) + 1;
	                    while (1) {
	                        if ((d[c[j >> 2] >> 0] | 0 | 0) >= 97 ? (d[c[j >> 2] >> 0] | 0 | 0) <= 122 : 0)o = 1; else n = 17;
	                        do if ((n | 0) == 17) {
	                            n = 0;
	                            if ((d[c[j >> 2] >> 0] | 0 | 0) >= 65 ? (d[c[j >> 2] >> 0] | 0 | 0) <= 90 : 0) {
	                                o = 1;
	                                break
	                            }
	                            if ((d[c[j >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[j >> 2] >> 0] | 0 | 0) <= 57 : 0) {
	                                o = 1;
	                                break
	                            }
	                            if ((d[c[j >> 2] >> 0] | 0 | 0) != 95 ? (d[c[j >> 2] >> 0] | 0 | 0) != 45 : 0)o = (d[c[j >> 2] >> 0] | 0 | 0) == 46; else o = 1
	                        } while (0);
	                        p = c[j >> 2] | 0;
	                        if (!o)break;
	                        c[j >> 2] = p + 1
	                    }
	                    c:do if ((d[p >> 0] | 0 | 0) == 58) {
	                        c[j >> 2] = (c[j >> 2] | 0) + 1;
	                        if (!((d[c[j >> 2] >> 0] | 0 | 0) >= 97 ? (d[c[j >> 2] >> 0] | 0 | 0) <= 122 : 0))n = 29;
	                        do if ((n | 0) == 29) {
	                            if ((d[c[j >> 2] >> 0] | 0 | 0) >= 65 ? (d[c[j >> 2] >> 0] | 0 | 0) <= 90 : 0)break;
	                            if ((d[c[j >> 2] >> 0] | 0 | 0) != 95)break b
	                        } while (0);
	                        c[j >> 2] = (c[j >> 2] | 0) + 1;
	                        while (1) {
	                            if (!((d[c[j >> 2] >> 0] | 0 | 0) >= 97 ? (d[c[j >> 2] >> 0] | 0 | 0) <= 122 : 0))n = 35;
	                            do if ((n | 0) == 35) {
	                                n = 0;
	                                if ((d[c[j >> 2] >> 0] | 0 | 0) >= 65 ? (d[c[j >> 2] >> 0] | 0 | 0) <= 90 : 0)break;
	                                if ((d[c[j >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[j >> 2] >> 0] | 0 | 0) <= 57 : 0)break;
	                                if (((d[c[j >> 2] >> 0] | 0 | 0) != 95 ? (d[c[j >> 2] >> 0] | 0 | 0) != 45 : 0) ? (d[c[j >> 2] >> 0] | 0 | 0) != 46 : 0)break c
	                            } while (0);
	                            c[j >> 2] = (c[j >> 2] | 0) + 1
	                        }
	                    } while (0);
	                    d:do if (c[h >> 2] | 0)while (1) {
	                        do if ((d[c[j >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[j >> 2] >> 0] | 0 | 0) ? (d[c[j >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[j >> 2] >> 0] | 0 | 0) != 13)break d
	                        } while (0);
	                        c[j >> 2] = (c[j >> 2] | 0) + 1
	                    } while (0);
	                    if (!(d[c[j >> 2] >> 0] | 0)) {
	                        c[f >> 2] = 0;
	                        m = c[f >> 2] | 0;
	                        i = e;
	                        return m | 0
	                    }
	                } while (0);
	                c[j >> 2] = c[g >> 2];
	                c[k >> 2] = oe(0, c[j >> 2] | 0, l) | 0;
	                e:do if (c[h >> 2] | 0)while (1) {
	                    if ((c[k >> 2] | 0) < 256) {
	                        if ((c[k >> 2] | 0) != 32 ? !(9 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 10) : 0)q = (c[k >> 2] | 0) == 13; else q = 1;
	                        r = q & 1
	                    } else r = 0;
	                    if (!r)break e;
	                    c[j >> 2] = (c[j >> 2] | 0) + (c[l >> 2] | 0);
	                    c[k >> 2] = oe(0, c[j >> 2] | 0, l) | 0
	                } while (0);
	                r = c[k >> 2] | 0;
	                if ((c[k >> 2] | 0) < 256) {
	                    if (((!(65 <= (r | 0) & (c[k >> 2] | 0) <= 90) ? !(97 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 122) : 0) ? !(192 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 214) : 0) ? !(216 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 246 | 248 <= (c[k >> 2] | 0)) : 0)n = 65
	                } else if (!(DQ(r, 199744) | 0))n = 65;
	                do if ((n | 0) == 65) {
	                    r = c[k >> 2] | 0;
	                    if ((c[k >> 2] | 0) < 256) {
	                        if ((r | 0) == 95)break
	                    } else {
	                        if (19968 <= (r | 0) & (c[k >> 2] | 0) <= 40869 | (c[k >> 2] | 0) == 12295)break;
	                        if (!((12321 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 12329 ^ 1) & (c[k >> 2] | 0) != 95))break
	                    }
	                    c[f >> 2] = 1;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                } while (0);
	                c[j >> 2] = (c[j >> 2] | 0) + (c[l >> 2] | 0);
	                c[k >> 2] = oe(0, c[j >> 2] | 0, l) | 0;
	                f:while (1) {
	                    r = c[k >> 2] | 0;
	                    if ((c[k >> 2] | 0) < 256) {
	                        if (((!(65 <= (r | 0) & (c[k >> 2] | 0) <= 90) ? !(97 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 122) : 0) ? !(192 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 214) : 0) ? !(216 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 246 | 248 <= (c[k >> 2] | 0)) : 0)n = 77
	                    } else if (!(DQ(r, 199744) | 0))n = 77;
	                    do if ((n | 0) == 77) {
	                        n = 0;
	                        if ((c[k >> 2] | 0) >= 256) {
	                            if (19968 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 40869 | (c[k >> 2] | 0) == 12295)break;
	                            if (12321 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 12329)break
	                        }
	                        r = c[k >> 2] | 0;
	                        if ((c[k >> 2] | 0) < 256) {
	                            if (48 <= (r | 0) & (c[k >> 2] | 0) <= 57 | (c[k >> 2] | 0) == 46 | (c[k >> 2] | 0) == 45 | (c[k >> 2] | 0) == 95)break
	                        } else {
	                            q = (DQ(r, 200216) | 0) != 0;
	                            if (q | (c[k >> 2] | 0) == 46 | (c[k >> 2] | 0) == 45 | (c[k >> 2] | 0) == 95)break
	                        }
	                        if ((c[k >> 2] | 0) >= 256 ? (DQ(c[k >> 2] | 0, 200144) | 0) != 0 : 0)break;
	                        q = c[k >> 2] | 0;
	                        if ((c[k >> 2] | 0) < 256)s = (q | 0) == 183 & 1; else s = DQ(q, 200272) | 0;
	                        if (!s)break f
	                    } while (0);
	                    c[j >> 2] = (c[j >> 2] | 0) + (c[l >> 2] | 0);
	                    c[k >> 2] = oe(0, c[j >> 2] | 0, l) | 0
	                }
	                g:do if ((c[k >> 2] | 0) == 58) {
	                    c[j >> 2] = (c[j >> 2] | 0) + (c[l >> 2] | 0);
	                    c[k >> 2] = oe(0, c[j >> 2] | 0, l) | 0;
	                    s = c[k >> 2] | 0;
	                    if ((c[k >> 2] | 0) < 256) {
	                        if (((!(65 <= (s | 0) & (c[k >> 2] | 0) <= 90) ? !(97 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 122) : 0) ? !(192 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 214) : 0) ? !(216 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 246 | 248 <= (c[k >> 2] | 0)) : 0)n = 97
	                    } else if (!(DQ(s, 199744) | 0))n = 97;
	                    do if ((n | 0) == 97) {
	                        s = c[k >> 2] | 0;
	                        if ((c[k >> 2] | 0) < 256) {
	                            if ((s | 0) == 95)break
	                        } else {
	                            if (19968 <= (s | 0) & (c[k >> 2] | 0) <= 40869 | (c[k >> 2] | 0) == 12295)break;
	                            if (!((12321 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 12329 ^ 1) & (c[k >> 2] | 0) != 95))break
	                        }
	                        c[f >> 2] = 1;
	                        m = c[f >> 2] | 0;
	                        i = e;
	                        return m | 0
	                    } while (0);
	                    c[j >> 2] = (c[j >> 2] | 0) + (c[l >> 2] | 0);
	                    c[k >> 2] = oe(0, c[j >> 2] | 0, l) | 0;
	                    while (1) {
	                        s = c[k >> 2] | 0;
	                        if ((c[k >> 2] | 0) < 256) {
	                            if (((!(65 <= (s | 0) & (c[k >> 2] | 0) <= 90) ? !(97 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 122) : 0) ? !(192 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 214) : 0) ? !(216 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 246 | 248 <= (c[k >> 2] | 0)) : 0)n = 109
	                        } else if (!(DQ(s, 199744) | 0))n = 109;
	                        do if ((n | 0) == 109) {
	                            n = 0;
	                            if ((c[k >> 2] | 0) >= 256) {
	                                if (19968 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 40869 | (c[k >> 2] | 0) == 12295)break;
	                                if (12321 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 12329)break
	                            }
	                            s = c[k >> 2] | 0;
	                            if ((c[k >> 2] | 0) < 256) {
	                                if (48 <= (s | 0) & (c[k >> 2] | 0) <= 57 | (c[k >> 2] | 0) == 46 | (c[k >> 2] | 0) == 45 | (c[k >> 2] | 0) == 95)break
	                            } else {
	                                q = (DQ(s, 200216) | 0) != 0;
	                                if (q | (c[k >> 2] | 0) == 46 | (c[k >> 2] | 0) == 45 | (c[k >> 2] | 0) == 95)break
	                            }
	                            if ((c[k >> 2] | 0) >= 256 ? (DQ(c[k >> 2] | 0, 200144) | 0) != 0 : 0)break;
	                            q = c[k >> 2] | 0;
	                            if ((c[k >> 2] | 0) < 256)t = (q | 0) == 183 & 1; else t = DQ(q, 200272) | 0;
	                            if (!t)break g
	                        } while (0);
	                        c[j >> 2] = (c[j >> 2] | 0) + (c[l >> 2] | 0);
	                        c[k >> 2] = oe(0, c[j >> 2] | 0, l) | 0
	                    }
	                } while (0);
	                h:do if (c[h >> 2] | 0)while (1) {
	                    if ((c[k >> 2] | 0) < 256) {
	                        if ((c[k >> 2] | 0) != 32 ? !(9 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 10) : 0)u = (c[k >> 2] | 0) == 13; else u = 1;
	                        v = u & 1
	                    } else v = 0;
	                    if (!v)break h;
	                    c[j >> 2] = (c[j >> 2] | 0) + (c[l >> 2] | 0);
	                    c[k >> 2] = oe(0, c[j >> 2] | 0, l) | 0
	                } while (0);
	                if (c[k >> 2] | 0) {
	                    c[f >> 2] = 1;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                } else {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                return 0
	            }

	            function Gh(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = c[g >> 2];
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = -1;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                a:do if (c[h >> 2] | 0)while (1) {
	                    do if ((d[c[j >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[j >> 2] >> 0] | 0 | 0) ? (d[c[j >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[j >> 2] >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    c[j >> 2] = (c[j >> 2] | 0) + 1
	                } while (0);
	                if ((d[c[j >> 2] >> 0] | 0 | 0) >= 97 ? (d[c[j >> 2] >> 0] | 0 | 0) <= 122 : 0)n = 15; else n = 11;
	                do if ((n | 0) == 11) {
	                    if ((d[c[j >> 2] >> 0] | 0 | 0) >= 65 ? (d[c[j >> 2] >> 0] | 0 | 0) <= 90 : 0) {
	                        n = 15;
	                        break
	                    }
	                    if (!((d[c[j >> 2] >> 0] | 0 | 0) != 95 ? (d[c[j >> 2] >> 0] | 0 | 0) != 58 : 0))n = 15
	                } while (0);
	                if ((n | 0) == 15) {
	                    c[j >> 2] = (c[j >> 2] | 0) + 1;
	                    b:while (1) {
	                        if (!((d[c[j >> 2] >> 0] | 0 | 0) >= 97 ? (d[c[j >> 2] >> 0] | 0 | 0) <= 122 : 0))n = 18;
	                        do if ((n | 0) == 18) {
	                            n = 0;
	                            if ((d[c[j >> 2] >> 0] | 0 | 0) >= 65 ? (d[c[j >> 2] >> 0] | 0 | 0) <= 90 : 0)break;
	                            if ((d[c[j >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[j >> 2] >> 0] | 0 | 0) <= 57 : 0)break;
	                            if ((((d[c[j >> 2] >> 0] | 0 | 0) != 95 ? (d[c[j >> 2] >> 0] | 0 | 0) != 45 : 0) ? (d[c[j >> 2] >> 0] | 0 | 0) != 46 : 0) ? (d[c[j >> 2] >> 0] | 0 | 0) != 58 : 0)break b
	                        } while (0);
	                        c[j >> 2] = (c[j >> 2] | 0) + 1
	                    }
	                    c:do if (c[h >> 2] | 0)while (1) {
	                        do if ((d[c[j >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[j >> 2] >> 0] | 0 | 0) ? (d[c[j >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[j >> 2] >> 0] | 0 | 0) != 13)break c
	                        } while (0);
	                        c[j >> 2] = (c[j >> 2] | 0) + 1
	                    } while (0);
	                    if (!(d[c[j >> 2] >> 0] | 0)) {
	                        c[f >> 2] = 0;
	                        m = c[f >> 2] | 0;
	                        i = e;
	                        return m | 0
	                    }
	                }
	                c[j >> 2] = c[g >> 2];
	                c[k >> 2] = oe(0, c[j >> 2] | 0, l) | 0;
	                d:do if (c[h >> 2] | 0)while (1) {
	                    if ((c[k >> 2] | 0) < 256) {
	                        if ((c[k >> 2] | 0) != 32 ? !(9 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 10) : 0)o = (c[k >> 2] | 0) == 13; else o = 1;
	                        p = o & 1
	                    } else p = 0;
	                    if (!p)break d;
	                    c[j >> 2] = (c[j >> 2] | 0) + (c[l >> 2] | 0);
	                    c[k >> 2] = oe(0, c[j >> 2] | 0, l) | 0
	                } while (0);
	                p = c[k >> 2] | 0;
	                if ((c[k >> 2] | 0) < 256) {
	                    if (((!(65 <= (p | 0) & (c[k >> 2] | 0) <= 90) ? !(97 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 122) : 0) ? !(192 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 214) : 0) ? !(216 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 246 | 248 <= (c[k >> 2] | 0)) : 0)n = 49
	                } else if (!(DQ(p, 199744) | 0))n = 49;
	                do if ((n | 0) == 49) {
	                    p = c[k >> 2] | 0;
	                    if ((c[k >> 2] | 0) < 256) {
	                        if (!((p | 0) != 95 & (c[k >> 2] | 0) != 58))break
	                    } else {
	                        if (19968 <= (p | 0) & (c[k >> 2] | 0) <= 40869 | (c[k >> 2] | 0) == 12295)break;
	                        if (!((12321 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 12329 ^ 1) & (c[k >> 2] | 0) != 95 & (c[k >> 2] | 0) != 58))break
	                    }
	                    c[f >> 2] = 1;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                } while (0);
	                c[j >> 2] = (c[j >> 2] | 0) + (c[l >> 2] | 0);
	                c[k >> 2] = oe(0, c[j >> 2] | 0, l) | 0;
	                e:while (1) {
	                    p = c[k >> 2] | 0;
	                    if ((c[k >> 2] | 0) < 256) {
	                        if (((!(65 <= (p | 0) & (c[k >> 2] | 0) <= 90) ? !(97 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 122) : 0) ? !(192 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 214) : 0) ? !(216 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 246 | 248 <= (c[k >> 2] | 0)) : 0)n = 61
	                    } else if (!(DQ(p, 199744) | 0))n = 61;
	                    do if ((n | 0) == 61) {
	                        n = 0;
	                        if ((c[k >> 2] | 0) >= 256) {
	                            if (19968 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 40869 | (c[k >> 2] | 0) == 12295)break;
	                            if (12321 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 12329)break
	                        }
	                        p = c[k >> 2] | 0;
	                        if ((c[k >> 2] | 0) < 256) {
	                            if (48 <= (p | 0) & (c[k >> 2] | 0) <= 57 | (c[k >> 2] | 0) == 46 | (c[k >> 2] | 0) == 58 | (c[k >> 2] | 0) == 45 | (c[k >> 2] | 0) == 95)break
	                        } else {
	                            o = (DQ(p, 200216) | 0) != 0;
	                            if (o | (c[k >> 2] | 0) == 46 | (c[k >> 2] | 0) == 58 | (c[k >> 2] | 0) == 45 | (c[k >> 2] | 0) == 95)break
	                        }
	                        if ((c[k >> 2] | 0) >= 256 ? (DQ(c[k >> 2] | 0, 200144) | 0) != 0 : 0)break;
	                        o = c[k >> 2] | 0;
	                        if ((c[k >> 2] | 0) < 256)q = (o | 0) == 183 & 1; else q = DQ(o, 200272) | 0;
	                        if (!q)break e
	                    } while (0);
	                    c[j >> 2] = (c[j >> 2] | 0) + (c[l >> 2] | 0);
	                    c[k >> 2] = oe(0, c[j >> 2] | 0, l) | 0
	                }
	                f:do if (c[h >> 2] | 0)while (1) {
	                    if ((c[k >> 2] | 0) < 256) {
	                        if ((c[k >> 2] | 0) != 32 ? !(9 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 10) : 0)r = (c[k >> 2] | 0) == 13; else r = 1;
	                        s = r & 1
	                    } else s = 0;
	                    if (!s)break f;
	                    c[j >> 2] = (c[j >> 2] | 0) + (c[l >> 2] | 0);
	                    c[k >> 2] = oe(0, c[j >> 2] | 0, l) | 0
	                } while (0);
	                if (c[k >> 2] | 0) {
	                    c[f >> 2] = 1;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                } else {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                return 0
	            }

	            function Hh(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = c[g >> 2];
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = -1;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                a:do if (c[h >> 2] | 0)while (1) {
	                    do if ((d[c[j >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[j >> 2] >> 0] | 0 | 0) ? (d[c[j >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[j >> 2] >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    c[j >> 2] = (c[j >> 2] | 0) + 1
	                } while (0);
	                if ((d[c[j >> 2] >> 0] | 0 | 0) >= 97 ? (d[c[j >> 2] >> 0] | 0 | 0) <= 122 : 0)n = 19; else n = 11;
	                do if ((n | 0) == 11) {
	                    if ((d[c[j >> 2] >> 0] | 0 | 0) >= 65 ? (d[c[j >> 2] >> 0] | 0 | 0) <= 90 : 0) {
	                        n = 19;
	                        break
	                    }
	                    if ((d[c[j >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[j >> 2] >> 0] | 0 | 0) <= 57 : 0) {
	                        n = 19;
	                        break
	                    }
	                    if (!((((d[c[j >> 2] >> 0] | 0 | 0) != 95 ? (d[c[j >> 2] >> 0] | 0 | 0) != 45 : 0) ? (d[c[j >> 2] >> 0] | 0 | 0) != 46 : 0) ? (d[c[j >> 2] >> 0] | 0 | 0) != 58 : 0))n = 19
	                } while (0);
	                if ((n | 0) == 19) {
	                    c[j >> 2] = (c[j >> 2] | 0) + 1;
	                    b:while (1) {
	                        if (!((d[c[j >> 2] >> 0] | 0 | 0) >= 97 ? (d[c[j >> 2] >> 0] | 0 | 0) <= 122 : 0))n = 22;
	                        do if ((n | 0) == 22) {
	                            n = 0;
	                            if ((d[c[j >> 2] >> 0] | 0 | 0) >= 65 ? (d[c[j >> 2] >> 0] | 0 | 0) <= 90 : 0)break;
	                            if ((d[c[j >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[j >> 2] >> 0] | 0 | 0) <= 57 : 0)break;
	                            if ((((d[c[j >> 2] >> 0] | 0 | 0) != 95 ? (d[c[j >> 2] >> 0] | 0 | 0) != 45 : 0) ? (d[c[j >> 2] >> 0] | 0 | 0) != 46 : 0) ? (d[c[j >> 2] >> 0] | 0 | 0) != 58 : 0)break b
	                        } while (0);
	                        c[j >> 2] = (c[j >> 2] | 0) + 1
	                    }
	                    c:do if (c[h >> 2] | 0)while (1) {
	                        do if ((d[c[j >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[j >> 2] >> 0] | 0 | 0) ? (d[c[j >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[j >> 2] >> 0] | 0 | 0) != 13)break c
	                        } while (0);
	                        c[j >> 2] = (c[j >> 2] | 0) + 1
	                    } while (0);
	                    if (!(d[c[j >> 2] >> 0] | 0)) {
	                        c[f >> 2] = 0;
	                        m = c[f >> 2] | 0;
	                        i = e;
	                        return m | 0
	                    }
	                }
	                c[j >> 2] = c[g >> 2];
	                c[k >> 2] = oe(0, c[j >> 2] | 0, l) | 0;
	                d:do if (c[h >> 2] | 0)while (1) {
	                    if ((c[k >> 2] | 0) < 256) {
	                        if ((c[k >> 2] | 0) != 32 ? !(9 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 10) : 0)o = (c[k >> 2] | 0) == 13; else o = 1;
	                        p = o & 1
	                    } else p = 0;
	                    if (!p)break d;
	                    c[j >> 2] = (c[j >> 2] | 0) + (c[l >> 2] | 0);
	                    c[k >> 2] = oe(0, c[j >> 2] | 0, l) | 0
	                } while (0);
	                p = c[k >> 2] | 0;
	                if ((c[k >> 2] | 0) < 256) {
	                    if (((!(65 <= (p | 0) & (c[k >> 2] | 0) <= 90) ? !(97 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 122) : 0) ? !(192 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 214) : 0) ? !(216 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 246 | 248 <= (c[k >> 2] | 0)) : 0)n = 53
	                } else if (!(DQ(p, 199744) | 0))n = 53;
	                do if ((n | 0) == 53) {
	                    if ((c[k >> 2] | 0) >= 256) {
	                        if (19968 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 40869 | (c[k >> 2] | 0) == 12295)break;
	                        if (12321 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 12329)break
	                    }
	                    p = c[k >> 2] | 0;
	                    if ((c[k >> 2] | 0) < 256) {
	                        if (48 <= (p | 0) & (c[k >> 2] | 0) <= 57 | (c[k >> 2] | 0) == 46 | (c[k >> 2] | 0) == 58 | (c[k >> 2] | 0) == 45 | (c[k >> 2] | 0) == 95)break
	                    } else {
	                        o = (DQ(p, 200216) | 0) != 0;
	                        if (o | (c[k >> 2] | 0) == 46 | (c[k >> 2] | 0) == 58 | (c[k >> 2] | 0) == 45 | (c[k >> 2] | 0) == 95)break
	                    }
	                    if ((c[k >> 2] | 0) >= 256 ? (DQ(c[k >> 2] | 0, 200144) | 0) != 0 : 0)break;
	                    o = c[k >> 2] | 0;
	                    if ((c[k >> 2] | 0) < 256) {
	                        if ((o | 0) == 183)break
	                    } else if (DQ(o, 200272) | 0)break;
	                    c[f >> 2] = 1;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                } while (0);
	                c[j >> 2] = (c[j >> 2] | 0) + (c[l >> 2] | 0);
	                c[k >> 2] = oe(0, c[j >> 2] | 0, l) | 0;
	                e:while (1) {
	                    o = c[k >> 2] | 0;
	                    if ((c[k >> 2] | 0) < 256) {
	                        if (((!(65 <= (o | 0) & (c[k >> 2] | 0) <= 90) ? !(97 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 122) : 0) ? !(192 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 214) : 0) ? !(216 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 246 | 248 <= (c[k >> 2] | 0)) : 0)n = 72
	                    } else if (!(DQ(o, 199744) | 0))n = 72;
	                    do if ((n | 0) == 72) {
	                        n = 0;
	                        if ((c[k >> 2] | 0) >= 256) {
	                            if (19968 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 40869 | (c[k >> 2] | 0) == 12295)break;
	                            if (12321 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 12329)break
	                        }
	                        o = c[k >> 2] | 0;
	                        if ((c[k >> 2] | 0) < 256) {
	                            if (48 <= (o | 0) & (c[k >> 2] | 0) <= 57 | (c[k >> 2] | 0) == 46 | (c[k >> 2] | 0) == 58 | (c[k >> 2] | 0) == 45 | (c[k >> 2] | 0) == 95)break
	                        } else {
	                            p = (DQ(o, 200216) | 0) != 0;
	                            if (p | (c[k >> 2] | 0) == 46 | (c[k >> 2] | 0) == 58 | (c[k >> 2] | 0) == 45 | (c[k >> 2] | 0) == 95)break
	                        }
	                        if ((c[k >> 2] | 0) >= 256 ? (DQ(c[k >> 2] | 0, 200144) | 0) != 0 : 0)break;
	                        p = c[k >> 2] | 0;
	                        if ((c[k >> 2] | 0) < 256)q = (p | 0) == 183 & 1; else q = DQ(p, 200272) | 0;
	                        if (!q)break e
	                    } while (0);
	                    c[j >> 2] = (c[j >> 2] | 0) + (c[l >> 2] | 0);
	                    c[k >> 2] = oe(0, c[j >> 2] | 0, l) | 0
	                }
	                f:do if (c[h >> 2] | 0)while (1) {
	                    if ((c[k >> 2] | 0) < 256) {
	                        if ((c[k >> 2] | 0) != 32 ? !(9 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 10) : 0)r = (c[k >> 2] | 0) == 13; else r = 1;
	                        s = r & 1
	                    } else s = 0;
	                    if (!s)break f;
	                    c[j >> 2] = (c[j >> 2] | 0) + (c[l >> 2] | 0);
	                    c[k >> 2] = oe(0, c[j >> 2] | 0, l) | 0
	                } while (0);
	                if (c[k >> 2] | 0) {
	                    c[f >> 2] = 1;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                } else {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                return 0
	            }

	            function Ih(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 1 : 0) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                if (((c[j >> 2] | 0) != 0 ? (qy(c[j >> 2] | 0, 75168) | 0) != 0 : 0) ? (qy(c[h >> 2] | 0, 75176) | 0) != 0 : 0) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                c[k >> 2] = Cb[c[135744 >> 2] & 511](24) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    tj(75216);
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                d = c[k >> 2] | 0;
	                c[d + 0 >> 2] = 0;
	                c[d + 4 >> 2] = 0;
	                c[d + 8 >> 2] = 0;
	                c[d + 12 >> 2] = 0;
	                c[d + 16 >> 2] = 0;
	                c[d + 20 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 4 >> 2] = 18;
	                if (c[h >> 2] | 0) {
	                    d = my(c[h >> 2] | 0) | 0;
	                    c[(c[k >> 2] | 0) + 8 >> 2] = d
	                }
	                if (c[j >> 2] | 0) {
	                    d = my(c[j >> 2] | 0) | 0;
	                    c[(c[k >> 2] | 0) + 12 >> 2] = d
	                }
	                do if (c[g >> 2] | 0) {
	                    if (!(c[(c[g >> 2] | 0) + 48 >> 2] | 0)) {
	                        c[(c[g >> 2] | 0) + 48 >> 2] = c[k >> 2];
	                        break
	                    }
	                    c[l >> 2] = c[(c[g >> 2] | 0) + 48 >> 2];
	                    if (!((c[(c[l >> 2] | 0) + 12 >> 2] | 0) == 0 ? (c[(c[k >> 2] | 0) + 12 >> 2] | 0) == 0 : 0))n = 19;
	                    if ((n | 0) == 19 ? (qy(c[(c[l >> 2] | 0) + 12 >> 2] | 0, c[(c[k >> 2] | 0) + 12 >> 2] | 0) | 0) == 0 : 0) {
	                        do {
	                            if (!(c[c[l >> 2] >> 2] | 0)) {
	                                n = 26;
	                                break
	                            }
	                            c[l >> 2] = c[c[l >> 2] >> 2];
	                            if ((c[(c[l >> 2] | 0) + 12 >> 2] | 0) == 0 ? (c[(c[k >> 2] | 0) + 12 >> 2] | 0) == 0 : 0)break
	                        } while ((qy(c[(c[l >> 2] | 0) + 12 >> 2] | 0, c[(c[k >> 2] | 0) + 12 >> 2] | 0) | 0) == 0);
	                        if ((n | 0) == 26) {
	                            c[c[l >> 2] >> 2] = c[k >> 2];
	                            break
	                        }
	                        Jh(c[k >> 2] | 0);
	                        c[f >> 2] = 0;
	                        m = c[f >> 2] | 0;
	                        i = e;
	                        return m | 0
	                    }
	                    Jh(c[k >> 2] | 0);
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                } while (0);
	                c[f >> 2] = c[k >> 2];
	                m = c[f >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function Jh(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 8 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 12 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 12 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function Kh(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if ((c[(c[e >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[e >> 2] | 0) + 4 >> 2] | 0) != 2 : 0) {
	                    i = d;
	                    return
	                }
	                c[(c[e >> 2] | 0) + 36 >> 2] = c[f >> 2];
	                i = d;
	                return
	            }

	            function Lh(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                if (!((c[d >> 2] | 0) != 0 & (c[d >> 2] | 0) != 0)) {
	                    i = b;
	                    return
	                }
	                do {
	                    c[e >> 2] = c[c[d >> 2] >> 2];
	                    Jh(c[d >> 2] | 0);
	                    c[d >> 2] = c[e >> 2]
	                } while ((c[d >> 2] | 0) != 0);
	                i = b;
	                return
	            }

	            function Mh(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if ((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 48 >> 2] | 0) != 0 : 0) {
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                c[m >> 2] = Cb[c[135744 >> 2] & 511](64) | 0;
	                if (!(c[m >> 2] | 0)) {
	                    tj(75240);
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                e = (c[m >> 2] | 0) + 0 | 0;
	                d = e + 64 | 0;
	                do {
	                    c[e >> 2] = 0;
	                    e = e + 4 | 0
	                } while ((e | 0) < (d | 0));
	                c[(c[m >> 2] | 0) + 4 >> 2] = 14;
	                if (c[j >> 2] | 0) {
	                    e = my(c[j >> 2] | 0) | 0;
	                    c[(c[m >> 2] | 0) + 8 >> 2] = e
	                }
	                if (c[k >> 2] | 0) {
	                    e = my(c[k >> 2] | 0) | 0;
	                    c[(c[m >> 2] | 0) + 52 >> 2] = e
	                }
	                if (c[l >> 2] | 0) {
	                    e = my(c[l >> 2] | 0) | 0;
	                    c[(c[m >> 2] | 0) + 56 >> 2] = e
	                }
	                if (c[h >> 2] | 0)c[(c[h >> 2] | 0) + 48 >> 2] = c[m >> 2];
	                c[(c[m >> 2] | 0) + 32 >> 2] = c[h >> 2];
	                if ((c[18774] | 0) != 0 & (c[33968] | 0) != 0)zb[c[135872 >> 2] & 511](c[m >> 2] | 0);
	                c[g >> 2] = c[m >> 2];
	                n = c[g >> 2] | 0;
	                i = f;
	                return n | 0
	            }

	            function Nh(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[f >> 2] = c[(c[e >> 2] | 0) + 12 >> 2];
	                while (1) {
	                    if (!(c[f >> 2] | 0)) {
	                        h = 8;
	                        break
	                    }
	                    j = c[f >> 2] | 0;
	                    if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 14) {
	                        h = 6;
	                        break
	                    }
	                    c[f >> 2] = c[j + 24 >> 2]
	                }
	                if ((h | 0) == 6) {
	                    c[d >> 2] = j;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else if ((h | 0) == 8) {
	                    c[d >> 2] = c[(c[e >> 2] | 0) + 44 >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function Oh(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 28 | 0;
	                h = f + 24 | 0;
	                j = f + 20 | 0;
	                k = f + 16 | 0;
	                l = f + 12 | 0;
	                m = f + 8 | 0;
	                n = f + 4 | 0;
	                o = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if ((c[h >> 2] | 0) != 0 ? (Nh(c[h >> 2] | 0) | 0) != 0 : 0) {
	                    c[g >> 2] = 0;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                c[m >> 2] = Cb[c[135744 >> 2] & 511](64) | 0;
	                if (!(c[m >> 2] | 0)) {
	                    tj(75256);
	                    c[g >> 2] = 0;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                e = (c[m >> 2] | 0) + 0 | 0;
	                d = e + 64 | 0;
	                do {
	                    c[e >> 2] = 0;
	                    e = e + 4 | 0
	                } while ((e | 0) < (d | 0));
	                c[(c[m >> 2] | 0) + 4 >> 2] = 14;
	                if ((c[j >> 2] | 0) != 0 ? (e = my(c[j >> 2] | 0) | 0, c[(c[m >> 2] | 0) + 8 >> 2] = e, (c[(c[m >> 2] | 0) + 8 >> 2] | 0) == 0) : 0) {
	                    tj(75256);
	                    zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                    c[g >> 2] = 0;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                if ((c[k >> 2] | 0) != 0 ? (e = my(c[k >> 2] | 0) | 0, c[(c[m >> 2] | 0) + 52 >> 2] = e, (c[(c[m >> 2] | 0) + 52 >> 2] | 0) == 0) : 0) {
	                    tj(75256);
	                    if (c[(c[m >> 2] | 0) + 8 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[m >> 2] | 0) + 8 >> 2] | 0);
	                    zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                    c[g >> 2] = 0;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                if ((c[l >> 2] | 0) != 0 ? (e = my(c[l >> 2] | 0) | 0, c[(c[m >> 2] | 0) + 56 >> 2] = e, (c[(c[m >> 2] | 0) + 56 >> 2] | 0) == 0) : 0) {
	                    tj(75256);
	                    if (c[(c[m >> 2] | 0) + 8 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[m >> 2] | 0) + 8 >> 2] | 0);
	                    if (c[(c[m >> 2] | 0) + 52 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[m >> 2] | 0) + 52 >> 2] | 0);
	                    zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                    c[g >> 2] = 0;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                do if (c[h >> 2] | 0) {
	                    c[(c[h >> 2] | 0) + 44 >> 2] = c[m >> 2];
	                    c[(c[m >> 2] | 0) + 20 >> 2] = c[h >> 2];
	                    c[(c[m >> 2] | 0) + 32 >> 2] = c[h >> 2];
	                    if (!(c[(c[h >> 2] | 0) + 12 >> 2] | 0)) {
	                        c[(c[h >> 2] | 0) + 12 >> 2] = c[m >> 2];
	                        c[(c[h >> 2] | 0) + 16 >> 2] = c[m >> 2];
	                        break
	                    }
	                    e = c[(c[h >> 2] | 0) + 12 >> 2] | 0;
	                    if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 13) {
	                        c[n >> 2] = e;
	                        c[(c[n >> 2] | 0) + 28 >> 2] = c[m >> 2];
	                        c[(c[m >> 2] | 0) + 24 >> 2] = c[n >> 2];
	                        c[(c[h >> 2] | 0) + 12 >> 2] = c[m >> 2];
	                        break
	                    }
	                    c[o >> 2] = e;
	                    while (1) {
	                        if (c[o >> 2] | 0)q = (c[(c[o >> 2] | 0) + 4 >> 2] | 0) != 1; else q = 0;
	                        r = c[o >> 2] | 0;
	                        if (!q)break;
	                        c[o >> 2] = c[r + 24 >> 2]
	                    }
	                    if (!r) {
	                        c[(c[m >> 2] | 0) + 28 >> 2] = c[(c[h >> 2] | 0) + 16 >> 2];
	                        c[(c[(c[m >> 2] | 0) + 28 >> 2] | 0) + 24 >> 2] = c[m >> 2];
	                        c[(c[m >> 2] | 0) + 24 >> 2] = 0;
	                        c[(c[h >> 2] | 0) + 16 >> 2] = c[m >> 2];
	                        break
	                    }
	                    c[(c[m >> 2] | 0) + 24 >> 2] = c[o >> 2];
	                    c[(c[m >> 2] | 0) + 28 >> 2] = c[(c[o >> 2] | 0) + 28 >> 2];
	                    e = c[m >> 2] | 0;
	                    if (!(c[(c[m >> 2] | 0) + 28 >> 2] | 0))c[(c[h >> 2] | 0) + 12 >> 2] = e; else c[(c[(c[m >> 2] | 0) + 28 >> 2] | 0) + 24 >> 2] = e;
	                    c[(c[o >> 2] | 0) + 28 >> 2] = c[m >> 2]
	                } while (0);
	                if ((c[18774] | 0) != 0 & (c[33968] | 0) != 0)zb[c[135872 >> 2] & 511](c[m >> 2] | 0);
	                c[g >> 2] = c[m >> 2];
	                p = c[g >> 2] | 0;
	                i = f;
	                return p | 0
	            }

	            function Ph(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[d >> 2] = a;
	                c[e >> 2] = 0;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 32 >> 2] | 0)c[e >> 2] = c[(c[(c[d >> 2] | 0) + 32 >> 2] | 0) + 80 >> 2];
	                if ((c[18774] | 0) != 0 & (c[33970] | 0) != 0)zb[c[135880 >> 2] & 511](c[d >> 2] | 0);
	                a:do if (c[(c[d >> 2] | 0) + 12 >> 2] | 0) {
	                    c[g >> 2] = c[(c[d >> 2] | 0) + 12 >> 2];
	                    while (1) {
	                        if (!(c[g >> 2] | 0))break a;
	                        c[f >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                        if ((((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 12 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 15 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 16 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 17 : 0) {
	                            Qh(c[g >> 2] | 0);
	                            Rh(c[g >> 2] | 0)
	                        }
	                        c[g >> 2] = c[f >> 2]
	                    }
	                } while (0);
	                do if (c[(c[d >> 2] | 0) + 8 >> 2] | 0) {
	                    if ((c[e >> 2] | 0) != 0 ? (CP(c[e >> 2] | 0, c[(c[d >> 2] | 0) + 8 >> 2] | 0) | 0) != 0 : 0)break;
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 8 >> 2] | 0)
	                } while (0);
	                do if (c[(c[d >> 2] | 0) + 56 >> 2] | 0) {
	                    if ((c[e >> 2] | 0) != 0 ? (CP(c[e >> 2] | 0, c[(c[d >> 2] | 0) + 56 >> 2] | 0) | 0) != 0 : 0)break;
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 56 >> 2] | 0)
	                } while (0);
	                do if (c[(c[d >> 2] | 0) + 52 >> 2] | 0) {
	                    if ((c[e >> 2] | 0) != 0 ? (CP(c[e >> 2] | 0, c[(c[d >> 2] | 0) + 52 >> 2] | 0) | 0) != 0 : 0)break;
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 52 >> 2] | 0)
	                } while (0);
	                if (c[(c[d >> 2] | 0) + 36 >> 2] | 0)ym(c[(c[d >> 2] | 0) + 36 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 40 >> 2] | 0)nm(c[(c[d >> 2] | 0) + 40 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 44 >> 2] | 0)um(c[(c[d >> 2] | 0) + 44 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 48 >> 2] | 0)dd(c[(c[d >> 2] | 0) + 48 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 60 >> 2] | 0)dd(c[(c[d >> 2] | 0) + 60 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function Qh(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if ((c[(c[d >> 2] | 0) + 4 >> 2] | 0) == 18) {
	                    i = b;
	                    return
	                }
	                if ((c[(c[d >> 2] | 0) + 4 >> 2] | 0) == 14 ? (c[e >> 2] = c[(c[d >> 2] | 0) + 32 >> 2], (c[e >> 2] | 0) != 0) : 0) {
	                    if ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) == (c[d >> 2] | 0))c[(c[e >> 2] | 0) + 44 >> 2] = 0;
	                    if ((c[(c[e >> 2] | 0) + 48 >> 2] | 0) == (c[d >> 2] | 0))c[(c[e >> 2] | 0) + 48 >> 2] = 0
	                }
	                if ((c[(c[d >> 2] | 0) + 4 >> 2] | 0) == 17 ? (c[f >> 2] = c[(c[d >> 2] | 0) + 32 >> 2], (c[f >> 2] | 0) != 0) : 0) {
	                    if (c[(c[f >> 2] | 0) + 44 >> 2] | 0) {
	                        e = Rj(c[(c[(c[f >> 2] | 0) + 44 >> 2] | 0) + 48 >> 2] | 0, c[(c[d >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        if ((e | 0) == (c[d >> 2] | 0))ak(c[(c[(c[f >> 2] | 0) + 44 >> 2] | 0) + 48 >> 2] | 0, c[(c[d >> 2] | 0) + 8 >> 2] | 0, 0) | 0;
	                        e = Rj(c[(c[(c[f >> 2] | 0) + 44 >> 2] | 0) + 60 >> 2] | 0, c[(c[d >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        if ((e | 0) == (c[d >> 2] | 0))ak(c[(c[(c[f >> 2] | 0) + 44 >> 2] | 0) + 60 >> 2] | 0, c[(c[d >> 2] | 0) + 8 >> 2] | 0, 0) | 0
	                    }
	                    if (c[(c[f >> 2] | 0) + 48 >> 2] | 0) {
	                        e = Rj(c[(c[(c[f >> 2] | 0) + 48 >> 2] | 0) + 48 >> 2] | 0, c[(c[d >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        if ((e | 0) == (c[d >> 2] | 0))ak(c[(c[(c[f >> 2] | 0) + 48 >> 2] | 0) + 48 >> 2] | 0, c[(c[d >> 2] | 0) + 8 >> 2] | 0, 0) | 0;
	                        e = Rj(c[(c[(c[f >> 2] | 0) + 48 >> 2] | 0) + 60 >> 2] | 0, c[(c[d >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        if ((e | 0) == (c[d >> 2] | 0))ak(c[(c[(c[f >> 2] | 0) + 48 >> 2] | 0) + 60 >> 2] | 0, c[(c[d >> 2] | 0) + 8 >> 2] | 0, 0) | 0
	                    }
	                }
	                if (c[(c[d >> 2] | 0) + 20 >> 2] | 0) {
	                    c[g >> 2] = c[(c[d >> 2] | 0) + 20 >> 2];
	                    f = c[g >> 2] | 0;
	                    if ((c[(c[d >> 2] | 0) + 4 >> 2] | 0) == 2) {
	                        if ((c[f + 44 >> 2] | 0) == (c[d >> 2] | 0))c[(c[g >> 2] | 0) + 44 >> 2] = c[(c[d >> 2] | 0) + 24 >> 2]
	                    } else {
	                        if ((c[f + 12 >> 2] | 0) == (c[d >> 2] | 0))c[(c[g >> 2] | 0) + 12 >> 2] = c[(c[d >> 2] | 0) + 24 >> 2];
	                        if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) == (c[d >> 2] | 0))c[(c[g >> 2] | 0) + 16 >> 2] = c[(c[d >> 2] | 0) + 28 >> 2]
	                    }
	                    c[(c[d >> 2] | 0) + 20 >> 2] = 0
	                }
	                if (c[(c[d >> 2] | 0) + 24 >> 2] | 0)c[(c[(c[d >> 2] | 0) + 24 >> 2] | 0) + 28 >> 2] = c[(c[d >> 2] | 0) + 28 >> 2];
	                if (c[(c[d >> 2] | 0) + 28 >> 2] | 0)c[(c[(c[d >> 2] | 0) + 28 >> 2] | 0) + 24 >> 2] = c[(c[d >> 2] | 0) + 24 >> 2];
	                c[(c[d >> 2] | 0) + 28 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 24 >> 2] = 0;
	                i = b;
	                return
	            }

	            function Rh(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[d >> 2] = a;
	                c[e >> 2] = 0;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                a = c[d >> 2] | 0;
	                if ((c[(c[d >> 2] | 0) + 4 >> 2] | 0) == 14) {
	                    Ph(a);
	                    i = b;
	                    return
	                }
	                g = c[d >> 2] | 0;
	                if ((c[a + 4 >> 2] | 0) == 18) {
	                    Jh(g);
	                    i = b;
	                    return
	                }
	                if ((c[g + 4 >> 2] | 0) == 2) {
	                    ei(c[d >> 2] | 0);
	                    i = b;
	                    return
	                }
	                if ((c[18774] | 0) != 0 & (c[33970] | 0) != 0)zb[c[135880 >> 2] & 511](c[d >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 32 >> 2] | 0)c[e >> 2] = c[(c[(c[d >> 2] | 0) + 32 >> 2] | 0) + 80 >> 2];
	                do if ((c[(c[d >> 2] | 0) + 4 >> 2] | 0) == 17) {
	                    c[f >> 2] = c[d >> 2];
	                    do if (c[(c[f >> 2] | 0) + 56 >> 2] | 0) {
	                        if ((c[e >> 2] | 0) != 0 ? (CP(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 56 >> 2] | 0) | 0) != 0 : 0)break;
	                        zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 56 >> 2] | 0)
	                    } while (0);
	                    if (c[(c[f >> 2] | 0) + 52 >> 2] | 0) {
	                        if ((c[e >> 2] | 0) != 0 ? (CP(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 52 >> 2] | 0) | 0) != 0 : 0)break;
	                        zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 52 >> 2] | 0)
	                    }
	                } while (0);
	                if ((c[(c[d >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 5 : 0)Uh(c[(c[d >> 2] | 0) + 12 >> 2] | 0);
	                if (!(((c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 19 : 0) ? (c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 20 : 0))h = 27;
	                if ((h | 0) == 27 ? (c[(c[d >> 2] | 0) + 44 >> 2] | 0) != 0 : 0)di(c[(c[d >> 2] | 0) + 44 >> 2] | 0);
	                do if (((((((c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[d >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) ? (c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 5 : 0) ? (c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 20 : 0) ? (c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 19 : 0) ? (c[(c[d >> 2] | 0) + 40 >> 2] | 0) != ((c[d >> 2] | 0) + 44 | 0) : 0) ? (c[(c[d >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) {
	                    if ((c[e >> 2] | 0) != 0 ? (CP(c[e >> 2] | 0, c[(c[d >> 2] | 0) + 40 >> 2] | 0) | 0) != 0 : 0)break;
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 40 >> 2] | 0)
	                } while (0);
	                do if ((((c[(c[d >> 2] | 0) + 8 >> 2] | 0) != 0 ? (c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 3 : 0) ? (c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 8 : 0) ? (c[(c[d >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                    if ((c[e >> 2] | 0) != 0 ? (CP(c[e >> 2] | 0, c[(c[d >> 2] | 0) + 8 >> 2] | 0) | 0) != 0 : 0)break;
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 8 >> 2] | 0)
	                } while (0);
	                if (!(((c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 19 : 0) ? (c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 20 : 0))h = 49;
	                if ((h | 0) == 49 ? (c[(c[d >> 2] | 0) + 48 >> 2] | 0) != 0 : 0)Lh(c[(c[d >> 2] | 0) + 48 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function Sh(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[e >> 2] = (c[e >> 2] | 0) == 0 ? 75288 : a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](96) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    tj(75296);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = (c[f >> 2] | 0) + 0 | 0;
	                h = a + 96 | 0;
	                do {
	                    c[a >> 2] = 0;
	                    a = a + 4 | 0
	                } while ((a | 0) < (h | 0));
	                c[(c[f >> 2] | 0) + 4 >> 2] = 9;
	                a = my(c[e >> 2] | 0) | 0;
	                c[(c[f >> 2] | 0) + 56 >> 2] = a;
	                if (!(c[(c[f >> 2] | 0) + 56 >> 2] | 0)) {
	                    tj(75296);
	                    zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[(c[f >> 2] | 0) + 40 >> 2] = -1;
	                c[(c[f >> 2] | 0) + 36 >> 2] = -1;
	                c[(c[f >> 2] | 0) + 32 >> 2] = c[f >> 2];
	                c[(c[f >> 2] | 0) + 88 >> 2] = 0;
	                c[(c[f >> 2] | 0) + 92 >> 2] = 32;
	                c[(c[f >> 2] | 0) + 76 >> 2] = 1;
	                if ((c[18774] | 0) != 0 & (c[33968] | 0) != 0)zb[c[135872 >> 2] & 511](c[f >> 2] | 0);
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function Th(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[d >> 2] = a;
	                c[g >> 2] = 0;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[d >> 2] | 0)c[g >> 2] = c[(c[d >> 2] | 0) + 80 >> 2];
	                if ((c[18774] | 0) != 0 & (c[33970] | 0) != 0)zb[c[135880 >> 2] & 511](c[d >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 64 >> 2] | 0)Dm(c[(c[d >> 2] | 0) + 64 >> 2] | 0);
	                c[(c[d >> 2] | 0) + 64 >> 2] = 0;
	                if (c[(c[d >> 2] | 0) + 68 >> 2] | 0)Jm(c[(c[d >> 2] | 0) + 68 >> 2] | 0);
	                c[(c[d >> 2] | 0) + 68 >> 2] = 0;
	                c[e >> 2] = c[(c[d >> 2] | 0) + 48 >> 2];
	                c[f >> 2] = c[(c[d >> 2] | 0) + 44 >> 2];
	                if ((c[f >> 2] | 0) == (c[e >> 2] | 0))c[e >> 2] = 0;
	                if (c[e >> 2] | 0) {
	                    Qh(c[(c[d >> 2] | 0) + 48 >> 2] | 0);
	                    c[(c[d >> 2] | 0) + 48 >> 2] = 0;
	                    Ph(c[e >> 2] | 0)
	                }
	                if (c[f >> 2] | 0) {
	                    Qh(c[(c[d >> 2] | 0) + 44 >> 2] | 0);
	                    c[(c[d >> 2] | 0) + 44 >> 2] = 0;
	                    Ph(c[f >> 2] | 0)
	                }
	                if (c[(c[d >> 2] | 0) + 12 >> 2] | 0)Uh(c[(c[d >> 2] | 0) + 12 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 52 >> 2] | 0)Lh(c[(c[d >> 2] | 0) + 52 >> 2] | 0);
	                do if (c[(c[d >> 2] | 0) + 56 >> 2] | 0) {
	                    if ((c[g >> 2] | 0) != 0 ? (CP(c[g >> 2] | 0, c[(c[d >> 2] | 0) + 56 >> 2] | 0) | 0) != 0 : 0)break;
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 56 >> 2] | 0)
	                } while (0);
	                do if (c[(c[d >> 2] | 0) + 8 >> 2] | 0) {
	                    if ((c[g >> 2] | 0) != 0 ? (CP(c[g >> 2] | 0, c[(c[d >> 2] | 0) + 8 >> 2] | 0) | 0) != 0 : 0)break;
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 8 >> 2] | 0)
	                } while (0);
	                do if (c[(c[d >> 2] | 0) + 60 >> 2] | 0) {
	                    if ((c[g >> 2] | 0) != 0 ? (CP(c[g >> 2] | 0, c[(c[d >> 2] | 0) + 60 >> 2] | 0) | 0) != 0 : 0)break;
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 60 >> 2] | 0)
	                } while (0);
	                do if (c[(c[d >> 2] | 0) + 72 >> 2] | 0) {
	                    if ((c[g >> 2] | 0) != 0 ? (CP(c[g >> 2] | 0, c[(c[d >> 2] | 0) + 72 >> 2] | 0) | 0) != 0 : 0)break;
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 72 >> 2] | 0)
	                } while (0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                if (!(c[g >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                zP(c[g >> 2] | 0);
	                i = b;
	                return
	            }

	            function Uh(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[d >> 2] = a;
	                c[f >> 2] = 0;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                a = c[d >> 2] | 0;
	                if ((c[(c[d >> 2] | 0) + 4 >> 2] | 0) == 18) {
	                    Lh(a);
	                    i = b;
	                    return
	                }
	                if (((c[a + 4 >> 2] | 0) != 9 ? (c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 21 : 0) ? (c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 13 : 0) {
	                    if (c[(c[d >> 2] | 0) + 32 >> 2] | 0)c[f >> 2] = c[(c[(c[d >> 2] | 0) + 32 >> 2] | 0) + 80 >> 2];
	                    while (1) {
	                        if (!(c[d >> 2] | 0))break;
	                        c[e >> 2] = c[(c[d >> 2] | 0) + 24 >> 2];
	                        if ((c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 14) {
	                            if ((c[18774] | 0) != 0 & (c[33970] | 0) != 0)zb[c[135880 >> 2] & 511](c[d >> 2] | 0);
	                            if ((c[(c[d >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 5 : 0)Uh(c[(c[d >> 2] | 0) + 12 >> 2] | 0);
	                            if (!(((c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 19 : 0) ? (c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 20 : 0))g = 20;
	                            if ((g | 0) == 20 ? (g = 0, (c[(c[d >> 2] | 0) + 44 >> 2] | 0) != 0) : 0)di(c[(c[d >> 2] | 0) + 44 >> 2] | 0);
	                            do if (((((c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 19 : 0) ? (c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 20 : 0) ? (c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 5 : 0) ? (c[(c[d >> 2] | 0) + 40 >> 2] | 0) != ((c[d >> 2] | 0) + 44 | 0) : 0) {
	                                if (!(c[(c[d >> 2] | 0) + 40 >> 2] | 0))break;
	                                if ((c[f >> 2] | 0) != 0 ? (CP(c[f >> 2] | 0, c[(c[d >> 2] | 0) + 40 >> 2] | 0) | 0) != 0 : 0)break;
	                                zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 40 >> 2] | 0)
	                            } while (0);
	                            if (!(((c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 19 : 0) ? (c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 20 : 0))g = 34;
	                            if ((g | 0) == 34 ? (g = 0, (c[(c[d >> 2] | 0) + 48 >> 2] | 0) != 0) : 0)Lh(c[(c[d >> 2] | 0) + 48 >> 2] | 0);
	                            do if (((c[(c[d >> 2] | 0) + 8 >> 2] | 0) != 0 ? (c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 3 : 0) ? (c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 8 : 0) {
	                                if (!(c[(c[d >> 2] | 0) + 8 >> 2] | 0))break;
	                                if ((c[f >> 2] | 0) != 0 ? (CP(c[f >> 2] | 0, c[(c[d >> 2] | 0) + 8 >> 2] | 0) | 0) != 0 : 0)break;
	                                zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 8 >> 2] | 0)
	                            } while (0);
	                            zb[c[135736 >> 2] & 511](c[d >> 2] | 0)
	                        }
	                        c[d >> 2] = c[e >> 2]
	                    }
	                    i = b;
	                    return
	                }
	                Th(c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function Vh(b, e, f) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0;
	                g = i;
	                i = i + 80 | 0;
	                h = g + 60 | 0;
	                j = g + 56 | 0;
	                k = g + 52 | 0;
	                l = g + 48 | 0;
	                m = g + 44 | 0;
	                n = g + 40 | 0;
	                o = g + 36 | 0;
	                p = g + 32 | 0;
	                q = g + 28 | 0;
	                r = g + 24 | 0;
	                s = g + 20 | 0;
	                t = g + 16 | 0;
	                u = g + 12 | 0;
	                v = g + 8 | 0;
	                w = g + 74 | 0;
	                x = g + 4 | 0;
	                y = g + 64 | 0;
	                z = g;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[l >> 2] = f;
	                c[m >> 2] = 0;
	                c[n >> 2] = 0;
	                c[q >> 2] = c[k >> 2];
	                c[r >> 2] = (c[q >> 2] | 0) + (c[l >> 2] | 0);
	                if (!(c[k >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    A = c[h >> 2] | 0;
	                    i = g;
	                    return A | 0
	                }
	                c[u >> 2] = My(0) | 0;
	                if (!(c[u >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    A = c[h >> 2] | 0;
	                    i = g;
	                    return A | 0
	                }
	                Qy(c[u >> 2] | 0, 4) | 0;
	                c[s >> 2] = c[q >> 2];
	                a:while (1) {
	                    if ((c[q >> 2] | 0) >>> 0 < (c[r >> 2] | 0) >>> 0)B = (d[c[q >> 2] >> 0] | 0 | 0) != 0; else B = 0;
	                    C = c[q >> 2] | 0;
	                    if (!B) {
	                        D = 87;
	                        break
	                    }
	                    if ((d[C >> 0] | 0 | 0) != 38) {
	                        c[q >> 2] = (c[q >> 2] | 0) + 1;
	                        continue
	                    }
	                    c[v >> 2] = 0;
	                    if ((c[q >> 2] | 0) != (c[s >> 2] | 0) ? (cz(c[u >> 2] | 0, c[s >> 2] | 0, (c[q >> 2] | 0) - (c[s >> 2] | 0) | 0) | 0) != 0 : 0)break;
	                    c[s >> 2] = c[q >> 2];
	                    if ((((c[q >> 2] | 0) + 2 | 0) >>> 0 < (c[r >> 2] | 0) >>> 0 ? (d[(c[q >> 2] | 0) + 1 >> 0] | 0 | 0) == 35 : 0) ? (d[(c[q >> 2] | 0) + 2 >> 0] | 0 | 0) == 120 : 0) {
	                        c[q >> 2] = (c[q >> 2] | 0) + 3;
	                        if ((c[q >> 2] | 0) >>> 0 < (c[r >> 2] | 0) >>> 0)a[w >> 0] = a[c[q >> 2] >> 0] | 0; else a[w >> 0] = 0;
	                        b:while (1) {
	                            if ((d[w >> 0] | 0 | 0) == 59)break;
	                            if ((d[w >> 0] | 0 | 0) >= 48 ? (d[w >> 0] | 0 | 0) <= 57 : 0)c[v >> 2] = (c[v >> 2] << 4) + ((d[w >> 0] | 0) - 48); else D = 22;
	                            do if ((D | 0) == 22) {
	                                D = 0;
	                                if ((d[w >> 0] | 0 | 0) >= 97 ? (d[w >> 0] | 0 | 0) <= 102 : 0) {
	                                    c[v >> 2] = (c[v >> 2] << 4) + ((d[w >> 0] | 0) - 97) + 10;
	                                    break
	                                }
	                                if ((d[w >> 0] | 0 | 0) < 65) {
	                                    D = 28;
	                                    break b
	                                }
	                                if ((d[w >> 0] | 0 | 0) > 70) {
	                                    D = 28;
	                                    break b
	                                }
	                                c[v >> 2] = (c[v >> 2] << 4) + ((d[w >> 0] | 0) - 65) + 10
	                            } while (0);
	                            c[q >> 2] = (c[q >> 2] | 0) + 1;
	                            if ((c[q >> 2] | 0) >>> 0 < (c[r >> 2] | 0) >>> 0) {
	                                a[w >> 0] = a[c[q >> 2] >> 0] | 0;
	                                continue
	                            } else {
	                                a[w >> 0] = 0;
	                                continue
	                            }
	                        }
	                        if ((D | 0) == 28) {
	                            D = 0;
	                            uj(1300, c[j >> 2] | 0, 0);
	                            c[v >> 2] = 0
	                        }
	                        if ((d[w >> 0] | 0 | 0) == 59)c[q >> 2] = (c[q >> 2] | 0) + 1;
	                        c[s >> 2] = c[q >> 2]
	                    } else D = 35;
	                    do if ((D | 0) == 35) {
	                        D = 0;
	                        if (((c[q >> 2] | 0) + 1 | 0) >>> 0 < (c[r >> 2] | 0) >>> 0 ? (d[(c[q >> 2] | 0) + 1 >> 0] | 0 | 0) == 35 : 0) {
	                            c[q >> 2] = (c[q >> 2] | 0) + 2;
	                            if ((c[q >> 2] | 0) >>> 0 < (c[r >> 2] | 0) >>> 0)a[w >> 0] = a[c[q >> 2] >> 0] | 0; else a[w >> 0] = 0;
	                            while (1) {
	                                if ((d[w >> 0] | 0 | 0) == 59)break;
	                                if ((d[w >> 0] | 0 | 0) < 48) {
	                                    D = 44;
	                                    break
	                                }
	                                if ((d[w >> 0] | 0 | 0) > 57) {
	                                    D = 44;
	                                    break
	                                }
	                                c[v >> 2] = ((c[v >> 2] | 0) * 10 | 0) + ((d[w >> 0] | 0) - 48);
	                                c[q >> 2] = (c[q >> 2] | 0) + 1;
	                                if ((c[q >> 2] | 0) >>> 0 < (c[r >> 2] | 0) >>> 0) {
	                                    a[w >> 0] = a[c[q >> 2] >> 0] | 0;
	                                    continue
	                                } else {
	                                    a[w >> 0] = 0;
	                                    continue
	                                }
	                            }
	                            if ((D | 0) == 44) {
	                                D = 0;
	                                uj(1301, c[j >> 2] | 0, 0);
	                                c[v >> 2] = 0
	                            }
	                            if ((d[w >> 0] | 0 | 0) == 59)c[q >> 2] = (c[q >> 2] | 0) + 1;
	                            c[s >> 2] = c[q >> 2];
	                            break
	                        }
	                        c[q >> 2] = (c[q >> 2] | 0) + 1;
	                        c[s >> 2] = c[q >> 2];
	                        while (1) {
	                            if ((c[q >> 2] | 0) >>> 0 < (c[r >> 2] | 0) >>> 0 ? (d[c[q >> 2] >> 0] | 0 | 0) != 0 : 0)E = (d[c[q >> 2] >> 0] | 0 | 0) != 59; else E = 0;
	                            F = c[q >> 2] | 0;
	                            if (!E)break;
	                            c[q >> 2] = F + 1
	                        }
	                        if (F >>> 0 >= (c[r >> 2] | 0) >>> 0) {
	                            D = 58;
	                            break a
	                        }
	                        if (!(d[c[q >> 2] >> 0] | 0)) {
	                            D = 58;
	                            break a
	                        }
	                        if ((c[q >> 2] | 0) != (c[s >> 2] | 0)) {
	                            c[p >> 2] = ly(c[s >> 2] | 0, (c[q >> 2] | 0) - (c[s >> 2] | 0) | 0) | 0;
	                            c[t >> 2] = ad(c[j >> 2] | 0, c[p >> 2] | 0) | 0;
	                            if ((c[t >> 2] | 0) != 0 ? (c[(c[t >> 2] | 0) + 48 >> 2] | 0) == 6 : 0) {
	                                if (ez(c[u >> 2] | 0, c[(c[t >> 2] | 0) + 40 >> 2] | 0) | 0)break a
	                            } else D = 63;
	                            do if ((D | 0) == 63) {
	                                D = 0;
	                                do if (!(az(c[u >> 2] | 0) | 0)) {
	                                    c[o >> 2] = Wh(c[j >> 2] | 0, 0) | 0;
	                                    if (!(c[o >> 2] | 0)) {
	                                        D = 65;
	                                        break a
	                                    }
	                                    k = Ny(c[u >> 2] | 0) | 0;
	                                    c[(c[o >> 2] | 0) + 40 >> 2] = k;
	                                    if (!(c[n >> 2] | 0)) {
	                                        k = c[o >> 2] | 0;
	                                        c[m >> 2] = k;
	                                        c[n >> 2] = k;
	                                        break
	                                    } else {
	                                        c[n >> 2] = Xh(c[n >> 2] | 0, c[o >> 2] | 0) | 0;
	                                        break
	                                    }
	                                } while (0);
	                                c[o >> 2] = Yh(c[j >> 2] | 0, c[p >> 2] | 0) | 0;
	                                if (!(c[o >> 2] | 0)) {
	                                    D = 71;
	                                    break a
	                                }
	                                c:do if (c[t >> 2] | 0) {
	                                    if (c[(c[t >> 2] | 0) + 12 >> 2] | 0)break;
	                                    k = Zh(c[j >> 2] | 0, c[(c[o >> 2] | 0) + 40 >> 2] | 0) | 0;
	                                    c[(c[t >> 2] | 0) + 12 >> 2] = k;
	                                    c[(c[t >> 2] | 0) + 68 >> 2] = 1;
	                                    c[x >> 2] = c[(c[t >> 2] | 0) + 12 >> 2];
	                                    while (1) {
	                                        if (!(c[x >> 2] | 0))break c;
	                                        c[(c[x >> 2] | 0) + 20 >> 2] = c[t >> 2];
	                                        c[(c[t >> 2] | 0) + 16 >> 2] = c[x >> 2];
	                                        c[x >> 2] = c[(c[x >> 2] | 0) + 24 >> 2]
	                                    }
	                                } while (0);
	                                if (!(c[n >> 2] | 0)) {
	                                    k = c[o >> 2] | 0;
	                                    c[m >> 2] = k;
	                                    c[n >> 2] = k;
	                                    break
	                                } else {
	                                    c[n >> 2] = Xh(c[n >> 2] | 0, c[o >> 2] | 0) | 0;
	                                    break
	                                }
	                            } while (0);
	                            zb[c[135736 >> 2] & 511](c[p >> 2] | 0)
	                        }
	                        c[q >> 2] = (c[q >> 2] | 0) + 1;
	                        c[s >> 2] = c[q >> 2]
	                    } while (0);
	                    if (!(c[v >> 2] | 0))continue;
	                    c[z >> 2] = pe(y, c[v >> 2] | 0) | 0;
	                    a[y + (c[z >> 2] | 0) >> 0] = 0;
	                    if (ez(c[u >> 2] | 0, y) | 0)break;
	                    c[v >> 2] = 0
	                }
	                do if ((D | 0) == 58)uj(1302, c[j >> 2] | 0, c[s >> 2] | 0); else if ((D | 0) == 65) {
	                    if (c[p >> 2] | 0)zb[c[135736 >> 2] & 511](c[p >> 2] | 0)
	                } else if ((D | 0) == 71) {
	                    if (c[p >> 2] | 0)zb[c[135736 >> 2] & 511](c[p >> 2] | 0)
	                } else if ((D | 0) == 87) {
	                    if ((C | 0) != (c[s >> 2] | 0) ? (cz(c[u >> 2] | 0, c[s >> 2] | 0, (c[q >> 2] | 0) - (c[s >> 2] | 0) | 0) | 0) != 0 : 0)break;
	                    if (az(c[u >> 2] | 0) | 0) {
	                        if (c[m >> 2] | 0)break;
	                        c[m >> 2] = Wh(c[j >> 2] | 0, 75312) | 0;
	                        break
	                    }
	                    c[o >> 2] = Wh(c[j >> 2] | 0, 0) | 0;
	                    if (c[o >> 2] | 0) {
	                        v = Ny(c[u >> 2] | 0) | 0;
	                        c[(c[o >> 2] | 0) + 40 >> 2] = v;
	                        if (!(c[n >> 2] | 0)) {
	                            v = c[o >> 2] | 0;
	                            c[m >> 2] = v;
	                            c[n >> 2] = v;
	                            break
	                        } else {
	                            c[n >> 2] = Xh(c[n >> 2] | 0, c[o >> 2] | 0) | 0;
	                            break
	                        }
	                    }
	                } while (0);
	                Ry(c[u >> 2] | 0);
	                c[h >> 2] = c[m >> 2];
	                A = c[h >> 2] | 0;
	                i = g;
	                return A | 0
	            }

	            function Wh(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[g >> 2] = li(c[f >> 2] | 0) | 0;
	                if (!(c[g >> 2] | 0)) {
	                    h = c[g >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                c[(c[g >> 2] | 0) + 32 >> 2] = c[e >> 2];
	                h = c[g >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function Xh(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                    if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                        if ((c[f >> 2] | 0) == (c[g >> 2] | 0)) {
	                            c[e >> 2] = 0;
	                            j = c[e >> 2] | 0;
	                            i = d;
	                            return j | 0
	                        }
	                        Qh(c[g >> 2] | 0);
	                        if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 3) {
	                            b = c[f >> 2] | 0;
	                            if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 3) {
	                                ui(b, c[(c[g >> 2] | 0) + 40 >> 2] | 0);
	                                Rh(c[g >> 2] | 0);
	                                c[e >> 2] = c[f >> 2];
	                                j = c[e >> 2] | 0;
	                                i = d;
	                                return j | 0
	                            }
	                            if (((c[b + 24 >> 2] | 0) != 0 ? (c[(c[(c[f >> 2] | 0) + 24 >> 2] | 0) + 4 >> 2] | 0) == 3 : 0) ? (c[(c[f >> 2] | 0) + 8 >> 2] | 0) == (c[(c[(c[f >> 2] | 0) + 24 >> 2] | 0) + 8 >> 2] | 0) : 0) {
	                                c[h >> 2] = my(c[(c[g >> 2] | 0) + 40 >> 2] | 0) | 0;
	                                c[h >> 2] = By(c[h >> 2] | 0, c[(c[(c[f >> 2] | 0) + 24 >> 2] | 0) + 40 >> 2] | 0) | 0;
	                                vi(c[(c[f >> 2] | 0) + 24 >> 2] | 0, c[h >> 2] | 0);
	                                zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                                Rh(c[g >> 2] | 0);
	                                c[e >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                                j = c[e >> 2] | 0;
	                                i = d;
	                                return j | 0
	                            }
	                        } else if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 2) {
	                            c[e >> 2] = vj(c[f >> 2] | 0, c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                            j = c[e >> 2] | 0;
	                            i = d;
	                            return j | 0
	                        }
	                        if ((c[(c[g >> 2] | 0) + 32 >> 2] | 0) != (c[(c[f >> 2] | 0) + 32 >> 2] | 0))ri(c[g >> 2] | 0, c[(c[f >> 2] | 0) + 32 >> 2] | 0);
	                        c[(c[g >> 2] | 0) + 20 >> 2] = c[(c[f >> 2] | 0) + 20 >> 2];
	                        c[(c[g >> 2] | 0) + 28 >> 2] = c[f >> 2];
	                        c[(c[g >> 2] | 0) + 24 >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                        c[(c[f >> 2] | 0) + 24 >> 2] = c[g >> 2];
	                        if (c[(c[g >> 2] | 0) + 24 >> 2] | 0)c[(c[(c[g >> 2] | 0) + 24 >> 2] | 0) + 28 >> 2] = c[g >> 2];
	                        if ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 16 >> 2] | 0) == (c[f >> 2] | 0) : 0)c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 16 >> 2] = c[g >> 2];
	                        c[e >> 2] = c[g >> 2];
	                        j = c[e >> 2] | 0;
	                        i = d;
	                        return j | 0
	                    }
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[e >> 2] = 0;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function Yh(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                c[j >> 2] = Cb[c[135744 >> 2] & 511](60) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    tj(75424);
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                b = (c[j >> 2] | 0) + 0 | 0;
	                a = b + 60 | 0;
	                do {
	                    c[b >> 2] = 0;
	                    b = b + 4 | 0
	                } while ((b | 0) < (a | 0));
	                c[(c[j >> 2] | 0) + 4 >> 2] = 5;
	                c[(c[j >> 2] | 0) + 32 >> 2] = c[g >> 2];
	                b = c[h >> 2] | 0;
	                do if ((d[c[h >> 2] >> 0] | 0 | 0) == 38) {
	                    c[h >> 2] = b + 1;
	                    c[l >> 2] = xy(c[h >> 2] | 0) | 0;
	                    a = c[h >> 2] | 0;
	                    n = c[l >> 2] | 0;
	                    if ((d[(c[h >> 2] | 0) + ((c[l >> 2] | 0) - 1) >> 0] | 0 | 0) == 59) {
	                        o = ly(a, n - 1 | 0) | 0;
	                        c[(c[j >> 2] | 0) + 8 >> 2] = o;
	                        break
	                    } else {
	                        o = ly(a, n) | 0;
	                        c[(c[j >> 2] | 0) + 8 >> 2] = o;
	                        break
	                    }
	                } else {
	                    o = my(b) | 0;
	                    c[(c[j >> 2] | 0) + 8 >> 2] = o
	                } while (0);
	                c[k >> 2] = ad(c[g >> 2] | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0) | 0;
	                if (c[k >> 2] | 0) {
	                    c[(c[j >> 2] | 0) + 40 >> 2] = c[(c[k >> 2] | 0) + 40 >> 2];
	                    c[(c[j >> 2] | 0) + 12 >> 2] = c[k >> 2];
	                    c[(c[j >> 2] | 0) + 16 >> 2] = c[k >> 2]
	                }
	                if ((c[18774] | 0) != 0 & (c[33968] | 0) != 0)zb[c[135872 >> 2] & 511](c[j >> 2] | 0);
	                c[f >> 2] = c[j >> 2];
	                m = c[f >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function Zh(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0;
	                f = i;
	                i = i + 80 | 0;
	                g = f + 52 | 0;
	                h = f + 48 | 0;
	                j = f + 44 | 0;
	                k = f + 40 | 0;
	                l = f + 36 | 0;
	                m = f + 32 | 0;
	                n = f + 28 | 0;
	                o = f + 24 | 0;
	                p = f + 20 | 0;
	                q = f + 16 | 0;
	                r = f + 12 | 0;
	                s = f + 8 | 0;
	                t = f + 66 | 0;
	                u = f + 4 | 0;
	                v = f + 56 | 0;
	                w = f;
	                c[h >> 2] = b;
	                c[j >> 2] = e;
	                c[k >> 2] = 0;
	                c[l >> 2] = 0;
	                c[o >> 2] = c[j >> 2];
	                if (!(c[j >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    x = c[g >> 2] | 0;
	                    i = f;
	                    return x | 0
	                }
	                c[r >> 2] = My(0) | 0;
	                if (!(c[r >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    x = c[g >> 2] | 0;
	                    i = f;
	                    return x | 0
	                }
	                Qy(c[r >> 2] | 0, 4) | 0;
	                c[p >> 2] = c[o >> 2];
	                a:while (1) {
	                    y = c[o >> 2] | 0;
	                    if (!(d[c[o >> 2] >> 0] | 0)) {
	                        z = 70;
	                        break
	                    }
	                    if ((d[y >> 0] | 0 | 0) != 38) {
	                        c[o >> 2] = (c[o >> 2] | 0) + 1;
	                        continue
	                    }
	                    c[s >> 2] = 0;
	                    if ((c[o >> 2] | 0) != (c[p >> 2] | 0) ? (cz(c[r >> 2] | 0, c[p >> 2] | 0, (c[o >> 2] | 0) - (c[p >> 2] | 0) | 0) | 0) != 0 : 0)break;
	                    c[p >> 2] = c[o >> 2];
	                    if ((d[(c[o >> 2] | 0) + 1 >> 0] | 0 | 0) == 35 ? (d[(c[o >> 2] | 0) + 2 >> 0] | 0 | 0) == 120 : 0) {
	                        c[o >> 2] = (c[o >> 2] | 0) + 3;
	                        a[t >> 0] = a[c[o >> 2] >> 0] | 0;
	                        b:while (1) {
	                            if ((d[t >> 0] | 0 | 0) == 59)break;
	                            if ((d[t >> 0] | 0 | 0) >= 48 ? (d[t >> 0] | 0 | 0) <= 57 : 0)c[s >> 2] = (c[s >> 2] << 4) + ((d[t >> 0] | 0) - 48); else z = 17;
	                            do if ((z | 0) == 17) {
	                                z = 0;
	                                if ((d[t >> 0] | 0 | 0) >= 97 ? (d[t >> 0] | 0 | 0) <= 102 : 0) {
	                                    c[s >> 2] = (c[s >> 2] << 4) + ((d[t >> 0] | 0) - 97) + 10;
	                                    break
	                                }
	                                if ((d[t >> 0] | 0 | 0) < 65) {
	                                    z = 23;
	                                    break b
	                                }
	                                if ((d[t >> 0] | 0 | 0) > 70) {
	                                    z = 23;
	                                    break b
	                                }
	                                c[s >> 2] = (c[s >> 2] << 4) + ((d[t >> 0] | 0) - 65) + 10
	                            } while (0);
	                            c[o >> 2] = (c[o >> 2] | 0) + 1;
	                            a[t >> 0] = a[c[o >> 2] >> 0] | 0
	                        }
	                        if ((z | 0) == 23) {
	                            z = 0;
	                            uj(1300, c[h >> 2] | 0, 0);
	                            c[s >> 2] = 0
	                        }
	                        if ((d[t >> 0] | 0 | 0) == 59)c[o >> 2] = (c[o >> 2] | 0) + 1;
	                        c[p >> 2] = c[o >> 2]
	                    } else z = 28;
	                    do if ((z | 0) == 28) {
	                        z = 0;
	                        j = c[o >> 2] | 0;
	                        if ((d[(c[o >> 2] | 0) + 1 >> 0] | 0 | 0) == 35) {
	                            c[o >> 2] = j + 2;
	                            a[t >> 0] = a[c[o >> 2] >> 0] | 0;
	                            while (1) {
	                                if ((d[t >> 0] | 0 | 0) == 59)break;
	                                if ((d[t >> 0] | 0 | 0) < 48) {
	                                    z = 34;
	                                    break
	                                }
	                                if ((d[t >> 0] | 0 | 0) > 57) {
	                                    z = 34;
	                                    break
	                                }
	                                c[s >> 2] = ((c[s >> 2] | 0) * 10 | 0) + ((d[t >> 0] | 0) - 48);
	                                c[o >> 2] = (c[o >> 2] | 0) + 1;
	                                a[t >> 0] = a[c[o >> 2] >> 0] | 0
	                            }
	                            if ((z | 0) == 34) {
	                                z = 0;
	                                uj(1301, c[h >> 2] | 0, 0);
	                                c[s >> 2] = 0
	                            }
	                            if ((d[t >> 0] | 0 | 0) == 59)c[o >> 2] = (c[o >> 2] | 0) + 1;
	                            c[p >> 2] = c[o >> 2];
	                            break
	                        }
	                        c[o >> 2] = j + 1;
	                        c[p >> 2] = c[o >> 2];
	                        while (1) {
	                            if (d[c[o >> 2] >> 0] | 0)A = (d[c[o >> 2] >> 0] | 0 | 0) != 59; else A = 0;
	                            B = c[o >> 2] | 0;
	                            if (!A)break;
	                            c[o >> 2] = B + 1
	                        }
	                        if (!(d[B >> 0] | 0)) {
	                            z = 44;
	                            break a
	                        }
	                        if ((c[o >> 2] | 0) != (c[p >> 2] | 0)) {
	                            c[n >> 2] = ly(c[p >> 2] | 0, (c[o >> 2] | 0) - (c[p >> 2] | 0) | 0) | 0;
	                            c[q >> 2] = ad(c[h >> 2] | 0, c[n >> 2] | 0) | 0;
	                            if ((c[q >> 2] | 0) != 0 ? (c[(c[q >> 2] | 0) + 48 >> 2] | 0) == 6 : 0) {
	                                if (ez(c[r >> 2] | 0, c[(c[q >> 2] | 0) + 40 >> 2] | 0) | 0)break a
	                            } else z = 49;
	                            do if ((z | 0) == 49) {
	                                z = 0;
	                                do if (!(az(c[r >> 2] | 0) | 0)) {
	                                    c[m >> 2] = Wh(c[h >> 2] | 0, 0) | 0;
	                                    j = Ny(c[r >> 2] | 0) | 0;
	                                    c[(c[m >> 2] | 0) + 40 >> 2] = j;
	                                    if (!(c[l >> 2] | 0)) {
	                                        j = c[m >> 2] | 0;
	                                        c[k >> 2] = j;
	                                        c[l >> 2] = j;
	                                        break
	                                    } else {
	                                        c[l >> 2] = Xh(c[l >> 2] | 0, c[m >> 2] | 0) | 0;
	                                        break
	                                    }
	                                } while (0);
	                                c[m >> 2] = Yh(c[h >> 2] | 0, c[n >> 2] | 0) | 0;
	                                if (!(c[m >> 2] | 0)) {
	                                    z = 54;
	                                    break a
	                                }
	                                c:do if ((c[q >> 2] | 0) != 0 ? (c[(c[q >> 2] | 0) + 12 >> 2] | 0) == 0 : 0) {
	                                    j = Zh(c[h >> 2] | 0, c[(c[m >> 2] | 0) + 40 >> 2] | 0) | 0;
	                                    c[(c[q >> 2] | 0) + 12 >> 2] = j;
	                                    c[(c[q >> 2] | 0) + 68 >> 2] = 1;
	                                    c[u >> 2] = c[(c[q >> 2] | 0) + 12 >> 2];
	                                    while (1) {
	                                        if (!(c[u >> 2] | 0))break c;
	                                        c[(c[u >> 2] | 0) + 20 >> 2] = c[q >> 2];
	                                        c[u >> 2] = c[(c[u >> 2] | 0) + 24 >> 2]
	                                    }
	                                } while (0);
	                                if (!(c[l >> 2] | 0)) {
	                                    j = c[m >> 2] | 0;
	                                    c[k >> 2] = j;
	                                    c[l >> 2] = j;
	                                    break
	                                } else {
	                                    c[l >> 2] = Xh(c[l >> 2] | 0, c[m >> 2] | 0) | 0;
	                                    break
	                                }
	                            } while (0);
	                            zb[c[135736 >> 2] & 511](c[n >> 2] | 0)
	                        }
	                        c[o >> 2] = (c[o >> 2] | 0) + 1;
	                        c[p >> 2] = c[o >> 2]
	                    } while (0);
	                    if (!(c[s >> 2] | 0))continue;
	                    c[w >> 2] = pe(v, c[s >> 2] | 0) | 0;
	                    a[v + (c[w >> 2] | 0) >> 0] = 0;
	                    if (ez(c[r >> 2] | 0, v) | 0)break;
	                    c[s >> 2] = 0
	                }
	                do if ((z | 0) == 44)uj(1302, c[h >> 2] | 0, c[p >> 2] | 0); else if ((z | 0) == 54) {
	                    if (c[n >> 2] | 0)zb[c[135736 >> 2] & 511](c[n >> 2] | 0)
	                } else if ((z | 0) == 70) {
	                    if ((c[k >> 2] | 0) == 0 ? 1 : (y | 0) != (c[p >> 2] | 0))cz(c[r >> 2] | 0, c[p >> 2] | 0, (c[o >> 2] | 0) - (c[p >> 2] | 0) | 0) | 0;
	                    if (!(az(c[r >> 2] | 0) | 0)) {
	                        c[m >> 2] = Wh(c[h >> 2] | 0, 0) | 0;
	                        s = Ny(c[r >> 2] | 0) | 0;
	                        c[(c[m >> 2] | 0) + 40 >> 2] = s;
	                        if (!(c[l >> 2] | 0)) {
	                            s = c[m >> 2] | 0;
	                            c[k >> 2] = s;
	                            c[l >> 2] = s;
	                            break
	                        } else {
	                            c[l >> 2] = Xh(c[l >> 2] | 0, c[m >> 2] | 0) | 0;
	                            break
	                        }
	                    }
	                } while (0);
	                Ry(c[r >> 2] | 0);
	                c[g >> 2] = c[k >> 2];
	                x = c[g >> 2] | 0;
	                i = f;
	                return x | 0
	            }

	            function _h(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f + 36 | 0;
	                h = f + 32 | 0;
	                j = f + 28 | 0;
	                k = f + 24 | 0;
	                l = f + 20 | 0;
	                m = f + 16 | 0;
	                n = f + 12 | 0;
	                o = f + 8 | 0;
	                p = f + 4 | 0;
	                q = f;
	                r = f + 40 | 0;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[l >> 2] = c[j >> 2];
	                c[m >> 2] = 0;
	                if (!(c[j >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    s = c[g >> 2] | 0;
	                    i = f;
	                    return s | 0
	                }
	                if ((c[(c[j >> 2] | 0) + 20 >> 2] | 0) != 0 ? (c[(c[(c[j >> 2] | 0) + 20 >> 2] | 0) + 4 >> 2] | 0) == 2 : 0)c[o >> 2] = 1; else c[o >> 2] = 0;
	                while (1) {
	                    if (!(c[l >> 2] | 0))break;
	                    do if ((c[(c[l >> 2] | 0) + 4 >> 2] | 0) != 3 ? (c[(c[l >> 2] | 0) + 4 >> 2] | 0) != 4 : 0) {
	                        if ((c[(c[l >> 2] | 0) + 4 >> 2] | 0) == 5) {
	                            if (!(c[k >> 2] | 0)) {
	                                a[r >> 0] = 38;
	                                a[r + 1 >> 0] = 0;
	                                c[m >> 2] = zy(c[m >> 2] | 0, r, 1) | 0;
	                                c[m >> 2] = By(c[m >> 2] | 0, c[(c[l >> 2] | 0) + 8 >> 2] | 0) | 0;
	                                a[r >> 0] = 59;
	                                a[r + 1 >> 0] = 0;
	                                c[m >> 2] = zy(c[m >> 2] | 0, r, 1) | 0;
	                                break
	                            }
	                            c[n >> 2] = ad(c[h >> 2] | 0, c[(c[l >> 2] | 0) + 8 >> 2] | 0) | 0;
	                            if (!(c[n >> 2] | 0)) {
	                                c[m >> 2] = By(c[m >> 2] | 0, c[(c[l >> 2] | 0) + 40 >> 2] | 0) | 0;
	                                break
	                            }
	                            c[q >> 2] = _h(c[h >> 2] | 0, c[(c[n >> 2] | 0) + 12 >> 2] | 0, 1) | 0;
	                            if (c[q >> 2] | 0) {
	                                c[m >> 2] = By(c[m >> 2] | 0, c[q >> 2] | 0) | 0;
	                                zb[c[135736 >> 2] & 511](c[q >> 2] | 0)
	                            }
	                        }
	                    } else t = 10; while (0);
	                    do if ((t | 0) == 10) {
	                        t = 0;
	                        if (c[k >> 2] | 0) {
	                            c[m >> 2] = By(c[m >> 2] | 0, c[(c[l >> 2] | 0) + 40 >> 2] | 0) | 0;
	                            break
	                        }
	                        j = c[h >> 2] | 0;
	                        e = c[(c[l >> 2] | 0) + 40 >> 2] | 0;
	                        if (c[o >> 2] | 0)c[p >> 2] = bd(j, e) | 0; else c[p >> 2] = cd(j, e) | 0;
	                        if (c[p >> 2] | 0) {
	                            c[m >> 2] = By(c[m >> 2] | 0, c[p >> 2] | 0) | 0;
	                            zb[c[135736 >> 2] & 511](c[p >> 2] | 0)
	                        }
	                    } while (0);
	                    c[l >> 2] = c[(c[l >> 2] | 0) + 24 >> 2]
	                }
	                c[g >> 2] = c[m >> 2];
	                s = c[g >> 2] | 0;
	                i = f;
	                return s | 0
	            }

	            function $h(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                } else {
	                    c[f >> 2] = wj(c[g >> 2] | 0, 0, c[h >> 2] | 0, c[j >> 2] | 0, 0) | 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                return 0
	            }

	            function ai(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if (!(c[k >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                } else {
	                    c[g >> 2] = wj(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, 0) | 0;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                return 0
	            }

	            function bi(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if (!(c[k >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                } else {
	                    c[g >> 2] = wj(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, 1) | 0;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                return 0
	            }

	            function ci(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                c[k >> 2] = Cb[c[135744 >> 2] & 511](48) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    tj(75320);
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                d = (c[k >> 2] | 0) + 0 | 0;
	                b = d + 48 | 0;
	                do {
	                    c[d >> 2] = 0;
	                    d = d + 4 | 0
	                } while ((d | 0) < (b | 0));
	                c[(c[k >> 2] | 0) + 4 >> 2] = 2;
	                if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 80 >> 2] | 0) != 0 : 0) {
	                    d = AP(c[(c[g >> 2] | 0) + 80 >> 2] | 0, c[h >> 2] | 0, -1) | 0;
	                    c[(c[k >> 2] | 0) + 8 >> 2] = d
	                } else {
	                    d = my(c[h >> 2] | 0) | 0;
	                    c[(c[k >> 2] | 0) + 8 >> 2] = d
	                }
	                c[(c[k >> 2] | 0) + 32 >> 2] = c[g >> 2];
	                a:do if (c[j >> 2] | 0) {
	                    d = Zh(c[g >> 2] | 0, c[j >> 2] | 0) | 0;
	                    c[(c[k >> 2] | 0) + 12 >> 2] = d;
	                    c[(c[k >> 2] | 0) + 16 >> 2] = 0;
	                    c[l >> 2] = c[(c[k >> 2] | 0) + 12 >> 2];
	                    while (1) {
	                        if (!(c[l >> 2] | 0))break a;
	                        c[(c[l >> 2] | 0) + 20 >> 2] = c[k >> 2];
	                        if (!(c[(c[l >> 2] | 0) + 24 >> 2] | 0))c[(c[k >> 2] | 0) + 16 >> 2] = c[l >> 2];
	                        c[l >> 2] = c[(c[l >> 2] | 0) + 24 >> 2]
	                    }
	                } while (0);
	                if ((c[18774] | 0) != 0 & (c[33968] | 0) != 0)zb[c[135872 >> 2] & 511](c[k >> 2] | 0);
	                c[f >> 2] = c[k >> 2];
	                m = c[f >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function di(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                if (!((c[d >> 2] | 0) != 0 & (c[d >> 2] | 0) != 0)) {
	                    i = b;
	                    return
	                }
	                do {
	                    c[e >> 2] = c[(c[d >> 2] | 0) + 24 >> 2];
	                    ei(c[d >> 2] | 0);
	                    c[d >> 2] = c[e >> 2]
	                } while ((c[d >> 2] | 0) != 0);
	                i = b;
	                return
	            }

	            function ei(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                c[e >> 2] = 0;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 32 >> 2] | 0)c[e >> 2] = c[(c[(c[d >> 2] | 0) + 32 >> 2] | 0) + 80 >> 2];
	                if ((c[18774] | 0) != 0 & (c[33970] | 0) != 0)zb[c[135880 >> 2] & 511](c[d >> 2] | 0);
	                if ((c[(c[d >> 2] | 0) + 32 >> 2] | 0) != 0 ? (c[(c[d >> 2] | 0) + 40 >> 2] | 0) == 2 : 0)Gm(c[(c[d >> 2] | 0) + 32 >> 2] | 0, c[d >> 2] | 0) | 0;
	                if (c[(c[d >> 2] | 0) + 12 >> 2] | 0)Uh(c[(c[d >> 2] | 0) + 12 >> 2] | 0);
	                do if (c[(c[d >> 2] | 0) + 8 >> 2] | 0) {
	                    if ((c[e >> 2] | 0) != 0 ? (CP(c[e >> 2] | 0, c[(c[d >> 2] | 0) + 8 >> 2] | 0) | 0) != 0 : 0)break;
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 8 >> 2] | 0)
	                } while (0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function fi(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = -1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                if (!(c[(c[e >> 2] | 0) + 20 >> 2] | 0)) {
	                    c[d >> 2] = -1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[f >> 2] = c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 44 >> 2];
	                if ((c[f >> 2] | 0) == (c[e >> 2] | 0)) {
	                    c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 44 >> 2] = c[(c[e >> 2] | 0) + 24 >> 2];
	                    if (c[(c[e >> 2] | 0) + 24 >> 2] | 0)c[(c[(c[e >> 2] | 0) + 24 >> 2] | 0) + 28 >> 2] = 0;
	                    ei(c[e >> 2] | 0);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                while (1) {
	                    if (!(c[f >> 2] | 0)) {
	                        h = 15;
	                        break
	                    }
	                    if ((c[(c[f >> 2] | 0) + 24 >> 2] | 0) == (c[e >> 2] | 0))break;
	                    c[f >> 2] = c[(c[f >> 2] | 0) + 24 >> 2]
	                }
	                if ((h | 0) == 15) {
	                    c[d >> 2] = -1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[(c[f >> 2] | 0) + 24 >> 2] = c[(c[e >> 2] | 0) + 24 >> 2];
	                if (c[(c[f >> 2] | 0) + 24 >> 2] | 0)c[(c[(c[f >> 2] | 0) + 24 >> 2] | 0) + 28 >> 2] = c[f >> 2];
	                ei(c[e >> 2] | 0);
	                c[d >> 2] = 0;
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function gi(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[k >> 2] = Cb[c[135744 >> 2] & 511](60) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    tj(75344);
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                d = (c[k >> 2] | 0) + 0 | 0;
	                b = d + 60 | 0;
	                do {
	                    c[d >> 2] = 0;
	                    d = d + 4 | 0
	                } while ((d | 0) < (b | 0));
	                c[(c[k >> 2] | 0) + 4 >> 2] = 7;
	                if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 80 >> 2] | 0) != 0 : 0) {
	                    d = AP(c[(c[g >> 2] | 0) + 80 >> 2] | 0, c[h >> 2] | 0, -1) | 0;
	                    c[(c[k >> 2] | 0) + 8 >> 2] = d
	                } else {
	                    d = my(c[h >> 2] | 0) | 0;
	                    c[(c[k >> 2] | 0) + 8 >> 2] = d
	                }
	                if (c[j >> 2] | 0) {
	                    d = my(c[j >> 2] | 0) | 0;
	                    c[(c[k >> 2] | 0) + 40 >> 2] = d
	                }
	                c[(c[k >> 2] | 0) + 32 >> 2] = c[g >> 2];
	                if ((c[18774] | 0) != 0 & (c[33968] | 0) != 0)zb[c[135872 >> 2] & 511](c[k >> 2] | 0);
	                c[f >> 2] = c[k >> 2];
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function hi(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[h >> 2] = Cb[c[135744 >> 2] & 511](60) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    tj(75360);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                b = (c[h >> 2] | 0) + 0 | 0;
	                a = b + 60 | 0;
	                do {
	                    c[b >> 2] = 0;
	                    b = b + 4 | 0
	                } while ((b | 0) < (a | 0));
	                c[(c[h >> 2] | 0) + 4 >> 2] = 1;
	                b = my(c[g >> 2] | 0) | 0;
	                c[(c[h >> 2] | 0) + 8 >> 2] = b;
	                c[(c[h >> 2] | 0) + 36 >> 2] = c[f >> 2];
	                if ((c[18774] | 0) != 0 & (c[33968] | 0) != 0)zb[c[135872 >> 2] & 511](c[h >> 2] | 0);
	                c[e >> 2] = c[h >> 2];
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function ii(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[h >> 2] = Cb[c[135744 >> 2] & 511](60) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    tj(75360);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                b = (c[h >> 2] | 0) + 0 | 0;
	                a = b + 60 | 0;
	                do {
	                    c[b >> 2] = 0;
	                    b = b + 4 | 0
	                } while ((b | 0) < (a | 0));
	                c[(c[h >> 2] | 0) + 4 >> 2] = 1;
	                c[(c[h >> 2] | 0) + 8 >> 2] = c[g >> 2];
	                c[(c[h >> 2] | 0) + 36 >> 2] = c[f >> 2];
	                if ((c[18774] | 0) != 0 & (c[33968] | 0) != 0)zb[c[135872 >> 2] & 511](c[h >> 2] | 0);
	                c[e >> 2] = c[h >> 2];
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function ji(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 80 >> 2] | 0) != 0 : 0) {
	                    e = c[h >> 2] | 0;
	                    c[l >> 2] = ii(e, AP(c[(c[g >> 2] | 0) + 80 >> 2] | 0, c[j >> 2] | 0, -1) | 0) | 0
	                } else c[l >> 2] = hi(c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                if (!(c[l >> 2] | 0)) {
	                    n = c[l >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                c[(c[l >> 2] | 0) + 32 >> 2] = c[g >> 2];
	                if (!(c[k >> 2] | 0)) {
	                    n = c[l >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                j = Zh(c[g >> 2] | 0, c[k >> 2] | 0) | 0;
	                c[(c[l >> 2] | 0) + 12 >> 2] = j;
	                if (!(c[l >> 2] | 0)) {
	                    n = c[l >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                c[m >> 2] = c[(c[l >> 2] | 0) + 12 >> 2];
	                if (!(c[m >> 2] | 0)) {
	                    c[(c[l >> 2] | 0) + 16 >> 2] = 0;
	                    n = c[l >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                while (1) {
	                    j = (c[(c[m >> 2] | 0) + 24 >> 2] | 0) != 0;
	                    c[(c[m >> 2] | 0) + 20 >> 2] = c[l >> 2];
	                    o = c[m >> 2] | 0;
	                    if (!j)break;
	                    c[m >> 2] = c[o + 24 >> 2]
	                }
	                c[(c[l >> 2] | 0) + 16 >> 2] = o;
	                n = c[l >> 2] | 0;
	                i = f;
	                return n | 0
	            }

	            function ki(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[l >> 2] = ii(c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                do if (c[l >> 2] | 0) {
	                    c[(c[l >> 2] | 0) + 32 >> 2] = c[g >> 2];
	                    if ((c[k >> 2] | 0) != 0 ? (h = Zh(c[g >> 2] | 0, c[k >> 2] | 0) | 0, c[(c[l >> 2] | 0) + 12 >> 2] = h, (c[l >> 2] | 0) != 0) : 0) {
	                        c[m >> 2] = c[(c[l >> 2] | 0) + 12 >> 2];
	                        if (!(c[m >> 2] | 0)) {
	                            c[(c[l >> 2] | 0) + 16 >> 2] = 0;
	                            break
	                        }
	                        while (1) {
	                            h = (c[(c[m >> 2] | 0) + 24 >> 2] | 0) != 0;
	                            c[(c[m >> 2] | 0) + 20 >> 2] = c[l >> 2];
	                            n = c[m >> 2] | 0;
	                            if (!h)break;
	                            c[m >> 2] = c[n + 24 >> 2]
	                        }
	                        c[(c[l >> 2] | 0) + 16 >> 2] = n
	                    }
	                } else if ((c[j >> 2] | 0) != 0 & (c[g >> 2] | 0) != 0 ? (CP(c[(c[g >> 2] | 0) + 80 >> 2] | 0, c[j >> 2] | 0) | 0) == 0 : 0)zb[c[135736 >> 2] & 511](c[j >> 2] | 0); while (0);
	                i = f;
	                return c[l >> 2] | 0
	            }

	            function li(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](60) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    tj(75376);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = (c[f >> 2] | 0) + 0 | 0;
	                h = a + 60 | 0;
	                do {
	                    c[a >> 2] = 0;
	                    a = a + 4 | 0
	                } while ((a | 0) < (h | 0));
	                c[(c[f >> 2] | 0) + 4 >> 2] = 3;
	                c[(c[f >> 2] | 0) + 8 >> 2] = 75104;
	                if (c[e >> 2] | 0) {
	                    a = my(c[e >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 40 >> 2] = a
	                }
	                if ((c[18774] | 0) != 0 & (c[33968] | 0) != 0)zb[c[135872 >> 2] & 511](c[f >> 2] | 0);
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function mi(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[j >> 2] = Cb[c[135744 >> 2] & 511](60) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    tj(75392);
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                b = (c[j >> 2] | 0) + 0 | 0;
	                a = b + 60 | 0;
	                do {
	                    c[b >> 2] = 0;
	                    b = b + 4 | 0
	                } while ((b | 0) < (a | 0));
	                c[(c[j >> 2] | 0) + 4 >> 2] = 5;
	                c[(c[j >> 2] | 0) + 32 >> 2] = c[g >> 2];
	                g = c[h >> 2] | 0;
	                do if ((d[c[h >> 2] >> 0] | 0 | 0) == 38) {
	                    c[h >> 2] = g + 1;
	                    c[k >> 2] = xy(c[h >> 2] | 0) | 0;
	                    b = c[h >> 2] | 0;
	                    a = c[k >> 2] | 0;
	                    if ((d[(c[h >> 2] | 0) + ((c[k >> 2] | 0) - 1) >> 0] | 0 | 0) == 59) {
	                        m = ly(b, a - 1 | 0) | 0;
	                        c[(c[j >> 2] | 0) + 8 >> 2] = m;
	                        break
	                    } else {
	                        m = ly(b, a) | 0;
	                        c[(c[j >> 2] | 0) + 8 >> 2] = m;
	                        break
	                    }
	                } else {
	                    m = my(g) | 0;
	                    c[(c[j >> 2] | 0) + 8 >> 2] = m
	                } while (0);
	                if ((c[18774] | 0) != 0 & (c[33968] | 0) != 0)zb[c[135872 >> 2] & 511](c[j >> 2] | 0);
	                c[f >> 2] = c[j >> 2];
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function ni(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = Cb[c[135744 >> 2] & 511](60) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    tj(75376);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                b = (c[h >> 2] | 0) + 0 | 0;
	                a = b + 60 | 0;
	                do {
	                    c[b >> 2] = 0;
	                    b = b + 4 | 0
	                } while ((b | 0) < (a | 0));
	                c[(c[h >> 2] | 0) + 4 >> 2] = 3;
	                c[(c[h >> 2] | 0) + 8 >> 2] = 75104;
	                if (c[f >> 2] | 0) {
	                    b = ly(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                    c[(c[h >> 2] | 0) + 40 >> 2] = b
	                }
	                if ((c[18774] | 0) != 0 & (c[33968] | 0) != 0)zb[c[135872 >> 2] & 511](c[h >> 2] | 0);
	                c[e >> 2] = c[h >> 2];
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function oi(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](60) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    tj(75448);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = (c[f >> 2] | 0) + 0 | 0;
	                h = a + 60 | 0;
	                do {
	                    c[a >> 2] = 0;
	                    a = a + 4 | 0
	                } while ((a | 0) < (h | 0));
	                c[(c[f >> 2] | 0) + 4 >> 2] = 8;
	                c[(c[f >> 2] | 0) + 8 >> 2] = 75128;
	                if (c[e >> 2] | 0) {
	                    a = my(c[e >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 40 >> 2] = a
	                }
	                if ((c[18774] | 0) != 0 & (c[33968] | 0) != 0)zb[c[135872 >> 2] & 511](c[f >> 2] | 0);
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function pi(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = Cb[c[135744 >> 2] & 511](60) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    tj(75472);
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                d = (c[k >> 2] | 0) + 0 | 0;
	                b = d + 60 | 0;
	                do {
	                    c[d >> 2] = 0;
	                    d = d + 4 | 0
	                } while ((d | 0) < (b | 0));
	                c[(c[k >> 2] | 0) + 4 >> 2] = 4;
	                c[(c[k >> 2] | 0) + 32 >> 2] = c[g >> 2];
	                if (c[h >> 2] | 0) {
	                    g = ly(c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                    c[(c[k >> 2] | 0) + 40 >> 2] = g
	                }
	                if ((c[18774] | 0) != 0 & (c[33968] | 0) != 0)zb[c[135872 >> 2] & 511](c[k >> 2] | 0);
	                c[f >> 2] = c[k >> 2];
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function qi(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[g >> 2] = oi(c[f >> 2] | 0) | 0;
	                if (!(c[g >> 2] | 0)) {
	                    h = c[g >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                c[(c[g >> 2] | 0) + 32 >> 2] = c[e >> 2];
	                h = c[g >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function ri(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if ((c[(c[e >> 2] | 0) + 4 >> 2] | 0) == 18) {
	                    i = d;
	                    return
	                }
	                if ((c[(c[e >> 2] | 0) + 32 >> 2] | 0) == (c[f >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                a:do if ((c[(c[e >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                    c[g >> 2] = c[(c[e >> 2] | 0) + 44 >> 2];
	                    while (1) {
	                        if (!(c[g >> 2] | 0))break a;
	                        c[(c[g >> 2] | 0) + 32 >> 2] = c[f >> 2];
	                        si(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[f >> 2] | 0);
	                        c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2]
	                    }
	                } while (0);
	                if (c[(c[e >> 2] | 0) + 12 >> 2] | 0)si(c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[f >> 2] | 0);
	                c[(c[e >> 2] | 0) + 32 >> 2] = c[f >> 2];
	                i = d;
	                return
	            }

	            function si(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if ((c[(c[e >> 2] | 0) + 4 >> 2] | 0) == 18) {
	                    i = d;
	                    return
	                }
	                c[g >> 2] = c[e >> 2];
	                while (1) {
	                    if (!(c[g >> 2] | 0))break;
	                    if ((c[(c[g >> 2] | 0) + 32 >> 2] | 0) != (c[f >> 2] | 0))ri(c[g >> 2] | 0, c[f >> 2] | 0);
	                    c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2]
	                }
	                i = d;
	                return
	            }

	            function ti(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 24 | 0;
	                h = f + 20 | 0;
	                j = f + 16 | 0;
	                k = f + 12 | 0;
	                l = f + 8 | 0;
	                m = f + 4 | 0;
	                n = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if (!(c[h >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                if (!(c[k >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                do if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                    e = c[(c[h >> 2] | 0) + 32 >> 2] | 0;
	                    if (!(c[j >> 2] | 0)) {
	                        c[m >> 2] = ji(e, c[(c[h >> 2] | 0) + 36 >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0;
	                        break
	                    } else {
	                        c[m >> 2] = ji(e, c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0;
	                        break
	                    }
	                } else {
	                    if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 9 ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 13 : 0) {
	                        if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 11) {
	                            c[m >> 2] = ji(c[(c[h >> 2] | 0) + 32 >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0;
	                            break
	                        }
	                        c[g >> 2] = 0;
	                        o = c[g >> 2] | 0;
	                        i = f;
	                        return o | 0
	                    }
	                    e = c[h >> 2] | 0;
	                    if (!(c[j >> 2] | 0)) {
	                        c[m >> 2] = ji(e, 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0;
	                        break
	                    } else {
	                        c[m >> 2] = ji(e, c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0;
	                        break
	                    }
	                } while (0);
	                if (!(c[m >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                c[(c[m >> 2] | 0) + 4 >> 2] = 1;
	                c[(c[m >> 2] | 0) + 20 >> 2] = c[h >> 2];
	                c[(c[m >> 2] | 0) + 32 >> 2] = c[(c[h >> 2] | 0) + 32 >> 2];
	                if (!(c[(c[h >> 2] | 0) + 12 >> 2] | 0)) {
	                    c[(c[h >> 2] | 0) + 12 >> 2] = c[m >> 2];
	                    c[(c[h >> 2] | 0) + 16 >> 2] = c[m >> 2]
	                } else {
	                    c[n >> 2] = c[(c[h >> 2] | 0) + 16 >> 2];
	                    c[(c[n >> 2] | 0) + 24 >> 2] = c[m >> 2];
	                    c[(c[m >> 2] | 0) + 28 >> 2] = c[n >> 2];
	                    c[(c[h >> 2] | 0) + 16 >> 2] = c[m >> 2]
	                }
	                c[g >> 2] = c[m >> 2];
	                o = c[g >> 2] | 0;
	                i = f;
	                return o | 0
	            }

	            function ui(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if ((c[e >> 2] | 0) == 0 | (c[f >> 2] | 0) == 0) {
	                    i = d;
	                    return
	                }
	                c[g >> 2] = xy(c[f >> 2] | 0) | 0;
	                $i(c[e >> 2] | 0, c[f >> 2] | 0, c[g >> 2] | 0);
	                i = d;
	                return
	            }

	            function vi(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                switch (c[(c[e >> 2] | 0) + 4 >> 2] | 0) {
	                    case 8:
	                    case 7:
	                    case 6:
	                    case 5:
	                    case 4:
	                    case 3:
	                    {
	                        do if ((c[(c[e >> 2] | 0) + 40 >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 40 >> 2] | 0) != ((c[e >> 2] | 0) + 44 | 0) : 0) {
	                            if (((c[(c[e >> 2] | 0) + 32 >> 2] | 0) != 0 ? (c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 80 >> 2] | 0) != 0 : 0) ? (CP(c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 80 >> 2] | 0, c[(c[e >> 2] | 0) + 40 >> 2] | 0) | 0) != 0 : 0)break;
	                            zb[c[135736 >> 2] & 511](c[(c[e >> 2] | 0) + 40 >> 2] | 0)
	                        } while (0);
	                        if (c[(c[e >> 2] | 0) + 12 >> 2] | 0)Uh(c[(c[e >> 2] | 0) + 12 >> 2] | 0);
	                        c[(c[e >> 2] | 0) + 12 >> 2] = 0;
	                        c[(c[e >> 2] | 0) + 16 >> 2] = 0;
	                        if (c[f >> 2] | 0) {
	                            b = my(c[f >> 2] | 0) | 0;
	                            c[(c[e >> 2] | 0) + 40 >> 2] = b
	                        } else c[(c[e >> 2] | 0) + 40 >> 2] = 0;
	                        c[(c[e >> 2] | 0) + 44 >> 2] = 0;
	                        c[(c[e >> 2] | 0) + 48 >> 2] = 0;
	                        i = d;
	                        return
	                    }
	                    case 2:
	                    case 1:
	                    case 11:
	                    {
	                        if (c[(c[e >> 2] | 0) + 12 >> 2] | 0)Uh(c[(c[e >> 2] | 0) + 12 >> 2] | 0);
	                        b = Zh(c[(c[e >> 2] | 0) + 32 >> 2] | 0, c[f >> 2] | 0) | 0;
	                        c[(c[e >> 2] | 0) + 12 >> 2] = b;
	                        if (!(c[e >> 2] | 0)) {
	                            i = d;
	                            return
	                        }
	                        c[g >> 2] = c[(c[e >> 2] | 0) + 12 >> 2];
	                        if (!(c[g >> 2] | 0)) {
	                            c[(c[e >> 2] | 0) + 16 >> 2] = 0;
	                            i = d;
	                            return
	                        }
	                        while (1) {
	                            b = (c[(c[g >> 2] | 0) + 24 >> 2] | 0) != 0;
	                            c[(c[g >> 2] | 0) + 20 >> 2] = c[e >> 2];
	                            h = c[g >> 2] | 0;
	                            if (!b)break;
	                            c[g >> 2] = c[h + 24 >> 2]
	                        }
	                        c[(c[e >> 2] | 0) + 16 >> 2] = h;
	                        i = d;
	                        return
	                    }
	                    default:
	                    {
	                        i = d;
	                        return
	                    }
	                }
	            }

	            function wi(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                    if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                        if ((c[f >> 2] | 0) == (c[g >> 2] | 0)) {
	                            c[e >> 2] = 0;
	                            j = c[e >> 2] | 0;
	                            i = d;
	                            return j | 0
	                        }
	                        Qh(c[g >> 2] | 0);
	                        if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 3) {
	                            if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 3) {
	                                c[h >> 2] = my(c[(c[g >> 2] | 0) + 40 >> 2] | 0) | 0;
	                                c[h >> 2] = By(c[h >> 2] | 0, c[(c[f >> 2] | 0) + 40 >> 2] | 0) | 0;
	                                vi(c[f >> 2] | 0, c[h >> 2] | 0);
	                                zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                                Rh(c[g >> 2] | 0);
	                                c[e >> 2] = c[f >> 2];
	                                j = c[e >> 2] | 0;
	                                i = d;
	                                return j | 0
	                            }
	                            if (((c[(c[f >> 2] | 0) + 28 >> 2] | 0) != 0 ? (c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 4 >> 2] | 0) == 3 : 0) ? (c[(c[f >> 2] | 0) + 8 >> 2] | 0) == (c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 8 >> 2] | 0) : 0) {
	                                ui(c[(c[f >> 2] | 0) + 28 >> 2] | 0, c[(c[g >> 2] | 0) + 40 >> 2] | 0);
	                                Rh(c[g >> 2] | 0);
	                                c[e >> 2] = c[(c[f >> 2] | 0) + 28 >> 2];
	                                j = c[e >> 2] | 0;
	                                i = d;
	                                return j | 0
	                            }
	                        } else if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 2) {
	                            c[e >> 2] = vj(c[(c[f >> 2] | 0) + 28 >> 2] | 0, c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                            j = c[e >> 2] | 0;
	                            i = d;
	                            return j | 0
	                        }
	                        if ((c[(c[g >> 2] | 0) + 32 >> 2] | 0) != (c[(c[f >> 2] | 0) + 32 >> 2] | 0))ri(c[g >> 2] | 0, c[(c[f >> 2] | 0) + 32 >> 2] | 0);
	                        c[(c[g >> 2] | 0) + 20 >> 2] = c[(c[f >> 2] | 0) + 20 >> 2];
	                        c[(c[g >> 2] | 0) + 24 >> 2] = c[f >> 2];
	                        c[(c[g >> 2] | 0) + 28 >> 2] = c[(c[f >> 2] | 0) + 28 >> 2];
	                        c[(c[f >> 2] | 0) + 28 >> 2] = c[g >> 2];
	                        if (c[(c[g >> 2] | 0) + 28 >> 2] | 0)c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 24 >> 2] = c[g >> 2];
	                        if ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 12 >> 2] | 0) == (c[f >> 2] | 0) : 0)c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 12 >> 2] = c[g >> 2];
	                        c[e >> 2] = c[g >> 2];
	                        j = c[e >> 2] | 0;
	                        i = d;
	                        return j | 0
	                    }
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[e >> 2] = 0;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function xi(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                    if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                        if ((c[f >> 2] | 0) == (c[g >> 2] | 0)) {
	                            c[e >> 2] = 0;
	                            j = c[e >> 2] | 0;
	                            i = d;
	                            return j | 0
	                        }
	                        if (((((c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 2 ? (c[(c[f >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) ? (c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 16 >> 2] | 0) != 0 : 0) ? (c[(c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 16 >> 2] | 0) + 24 >> 2] | 0) == 0 : 0)c[f >> 2] = c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 16 >> 2]; else k = 15;
	                        a:do if ((k | 0) == 15)while (1) {
	                            k = 0;
	                            if (!(c[(c[f >> 2] | 0) + 24 >> 2] | 0))break a;
	                            c[f >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                            k = 15
	                        } while (0);
	                        Qh(c[g >> 2] | 0);
	                        if (((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 3 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 3 : 0) ? (c[(c[f >> 2] | 0) + 8 >> 2] | 0) == (c[(c[g >> 2] | 0) + 8 >> 2] | 0) : 0) {
	                            ui(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 40 >> 2] | 0);
	                            Rh(c[g >> 2] | 0);
	                            c[e >> 2] = c[f >> 2];
	                            j = c[e >> 2] | 0;
	                            i = d;
	                            return j | 0
	                        }
	                        if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 2) {
	                            c[e >> 2] = vj(c[f >> 2] | 0, c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                            j = c[e >> 2] | 0;
	                            i = d;
	                            return j | 0
	                        }
	                        if ((c[(c[g >> 2] | 0) + 32 >> 2] | 0) != (c[(c[f >> 2] | 0) + 32 >> 2] | 0))ri(c[g >> 2] | 0, c[(c[f >> 2] | 0) + 32 >> 2] | 0);
	                        c[h >> 2] = c[(c[f >> 2] | 0) + 20 >> 2];
	                        c[(c[g >> 2] | 0) + 28 >> 2] = c[f >> 2];
	                        c[(c[g >> 2] | 0) + 24 >> 2] = 0;
	                        c[(c[g >> 2] | 0) + 20 >> 2] = c[h >> 2];
	                        c[(c[f >> 2] | 0) + 24 >> 2] = c[g >> 2];
	                        if (c[h >> 2] | 0)c[(c[h >> 2] | 0) + 16 >> 2] = c[g >> 2];
	                        c[e >> 2] = c[g >> 2];
	                        j = c[e >> 2] | 0;
	                        i = d;
	                        return j | 0
	                    }
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[e >> 2] = 0;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function yi(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                    if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                        b = c[g >> 2] | 0;
	                        if (!(c[(c[f >> 2] | 0) + 12 >> 2] | 0))c[(c[f >> 2] | 0) + 12 >> 2] = b; else {
	                            do if (((c[b + 4 >> 2] | 0) == 3 ? (c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) == 3 : 0) ? (c[(c[g >> 2] | 0) + 8 >> 2] | 0) == (c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + 8 >> 2] | 0) : 0) {
	                                ui(c[(c[f >> 2] | 0) + 16 >> 2] | 0, c[(c[g >> 2] | 0) + 40 >> 2] | 0);
	                                a = c[g >> 2] | 0;
	                                if (c[(c[g >> 2] | 0) + 24 >> 2] | 0) {
	                                    c[h >> 2] = a;
	                                    c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                                    Rh(c[h >> 2] | 0);
	                                    break
	                                }
	                                Rh(a);
	                                c[e >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                                j = c[e >> 2] | 0;
	                                i = d;
	                                return j | 0
	                            } while (0);
	                            c[h >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                            c[(c[h >> 2] | 0) + 24 >> 2] = c[g >> 2];
	                            c[(c[g >> 2] | 0) + 28 >> 2] = c[h >> 2]
	                        }
	                        while (1) {
	                            h = (c[(c[g >> 2] | 0) + 24 >> 2] | 0) != 0;
	                            c[(c[g >> 2] | 0) + 20 >> 2] = c[f >> 2];
	                            k = (c[(c[g >> 2] | 0) + 32 >> 2] | 0) != (c[(c[f >> 2] | 0) + 32 >> 2] | 0);
	                            if (!h)break;
	                            if (k)ri(c[g >> 2] | 0, c[(c[f >> 2] | 0) + 32 >> 2] | 0);
	                            c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2]
	                        }
	                        if (k)ri(c[g >> 2] | 0, c[(c[f >> 2] | 0) + 32 >> 2] | 0);
	                        c[(c[f >> 2] | 0) + 16 >> 2] = c[g >> 2];
	                        c[e >> 2] = c[g >> 2];
	                        j = c[e >> 2] | 0;
	                        i = d;
	                        return j | 0
	                    }
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[e >> 2] = 0;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function zi(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                    if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                        if ((c[f >> 2] | 0) == (c[g >> 2] | 0)) {
	                            c[e >> 2] = 0;
	                            l = c[e >> 2] | 0;
	                            i = d;
	                            return l | 0
	                        }
	                        if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 3) {
	                            if (((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 3 ? (c[(c[f >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) ? (c[(c[f >> 2] | 0) + 8 >> 2] | 0) == (c[(c[g >> 2] | 0) + 8 >> 2] | 0) : 0) {
	                                ui(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 40 >> 2] | 0);
	                                Rh(c[g >> 2] | 0);
	                                c[e >> 2] = c[f >> 2];
	                                l = c[e >> 2] | 0;
	                                i = d;
	                                return l | 0
	                            }
	                            if ((((c[(c[f >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) == 3 : 0) ? (c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + 8 >> 2] | 0) == (c[(c[g >> 2] | 0) + 8 >> 2] | 0) : 0) ? (c[(c[f >> 2] | 0) + 16 >> 2] | 0) != (c[g >> 2] | 0) : 0) {
	                                ui(c[(c[f >> 2] | 0) + 16 >> 2] | 0, c[(c[g >> 2] | 0) + 40 >> 2] | 0);
	                                Rh(c[g >> 2] | 0);
	                                c[e >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                                l = c[e >> 2] | 0;
	                                i = d;
	                                return l | 0
	                            }
	                        }
	                        c[h >> 2] = c[(c[g >> 2] | 0) + 20 >> 2];
	                        c[(c[g >> 2] | 0) + 20 >> 2] = c[f >> 2];
	                        if ((c[(c[g >> 2] | 0) + 32 >> 2] | 0) != (c[(c[f >> 2] | 0) + 32 >> 2] | 0))ri(c[g >> 2] | 0, c[(c[f >> 2] | 0) + 32 >> 2] | 0);
	                        if ((c[h >> 2] | 0) == (c[f >> 2] | 0)) {
	                            c[e >> 2] = c[g >> 2];
	                            l = c[e >> 2] | 0;
	                            i = d;
	                            return l | 0
	                        }
	                        if (((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 3 ? (c[(c[f >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) ? (c[f >> 2] | 0) != (c[g >> 2] | 0) : 0) {
	                            ui(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 40 >> 2] | 0);
	                            Rh(c[g >> 2] | 0);
	                            c[e >> 2] = c[f >> 2];
	                            l = c[e >> 2] | 0;
	                            i = d;
	                            return l | 0
	                        }
	                        b = c[f >> 2] | 0;
	                        do if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 2)if (!(c[b + 12 >> 2] | 0)) {
	                            c[(c[f >> 2] | 0) + 12 >> 2] = c[g >> 2];
	                            c[(c[f >> 2] | 0) + 16 >> 2] = c[g >> 2];
	                            break
	                        } else {
	                            c[h >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                            c[(c[h >> 2] | 0) + 24 >> 2] = c[g >> 2];
	                            c[(c[g >> 2] | 0) + 28 >> 2] = c[h >> 2];
	                            c[(c[f >> 2] | 0) + 16 >> 2] = c[g >> 2];
	                            break
	                        } else {
	                            if ((c[b + 4 >> 2] | 0) != 1) {
	                                c[e >> 2] = 0;
	                                l = c[e >> 2] | 0;
	                                i = d;
	                                return l | 0
	                            }
	                            if (c[(c[f >> 2] | 0) + 44 >> 2] | 0) {
	                                a = c[f >> 2] | 0;
	                                m = c[(c[g >> 2] | 0) + 8 >> 2] | 0;
	                                if (!(c[(c[g >> 2] | 0) + 36 >> 2] | 0))c[j >> 2] = Ai(a, m, 0) | 0; else c[j >> 2] = Ai(a, m, c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) | 0;
	                                do if ((c[j >> 2] | 0) != 0 ? (c[j >> 2] | 0) != (c[g >> 2] | 0) : 0) {
	                                    if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) == 16)break;
	                                    Qh(c[j >> 2] | 0);
	                                    ei(c[j >> 2] | 0)
	                                } while (0);
	                                if ((c[j >> 2] | 0) == (c[g >> 2] | 0)) {
	                                    c[e >> 2] = c[g >> 2];
	                                    l = c[e >> 2] | 0;
	                                    i = d;
	                                    return l | 0
	                                }
	                            }
	                            if (!(c[(c[f >> 2] | 0) + 44 >> 2] | 0)) {
	                                c[(c[f >> 2] | 0) + 44 >> 2] = c[g >> 2];
	                                break
	                            }
	                            c[k >> 2] = c[(c[f >> 2] | 0) + 44 >> 2];
	                            while (1) {
	                                if (!(c[(c[k >> 2] | 0) + 24 >> 2] | 0))break;
	                                c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                            }
	                            c[(c[k >> 2] | 0) + 24 >> 2] = c[g >> 2];
	                            c[(c[g >> 2] | 0) + 28 >> 2] = c[k >> 2]
	                        } while (0);
	                        c[e >> 2] = c[g >> 2];
	                        l = c[e >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    }
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                c[e >> 2] = 0;
	                l = c[e >> 2] | 0;
	                i = d;
	                return l | 0
	            }

	            function Ai(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                d = xj(c[f >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0, c[18946] | 0) | 0;
	                i = e;
	                return d | 0
	            }

	            function Bi(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                    c[d >> 2] = c[(c[e >> 2] | 0) + 16 >> 2];
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                }
	                c[d >> 2] = 0;
	                f = c[d >> 2] | 0;
	                i = b;
	                return f | 0
	            }

	            function Ci(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) == (c[g >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                if (((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) ? (c[(c[f >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) {
	                    if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                        b = c[f >> 2] | 0;
	                        if ((c[g >> 2] | 0) == (c[f >> 2] | 0)) {
	                            c[e >> 2] = b;
	                            h = c[e >> 2] | 0;
	                            i = d;
	                            return h | 0
	                        }
	                        if ((c[b + 4 >> 2] | 0) == 2 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 2 : 0) {
	                            c[e >> 2] = c[f >> 2];
	                            h = c[e >> 2] | 0;
	                            i = d;
	                            return h | 0
	                        }
	                        if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 2 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 2 : 0) {
	                            c[e >> 2] = c[f >> 2];
	                            h = c[e >> 2] | 0;
	                            i = d;
	                            return h | 0
	                        }
	                        Qh(c[g >> 2] | 0);
	                        ri(c[g >> 2] | 0, c[(c[f >> 2] | 0) + 32 >> 2] | 0);
	                        c[(c[g >> 2] | 0) + 20 >> 2] = c[(c[f >> 2] | 0) + 20 >> 2];
	                        c[(c[g >> 2] | 0) + 24 >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                        if (c[(c[g >> 2] | 0) + 24 >> 2] | 0)c[(c[(c[g >> 2] | 0) + 24 >> 2] | 0) + 28 >> 2] = c[g >> 2];
	                        c[(c[g >> 2] | 0) + 28 >> 2] = c[(c[f >> 2] | 0) + 28 >> 2];
	                        if (c[(c[g >> 2] | 0) + 28 >> 2] | 0)c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 24 >> 2] = c[g >> 2];
	                        do if (c[(c[g >> 2] | 0) + 20 >> 2] | 0) {
	                            b = c[(c[g >> 2] | 0) + 20 >> 2] | 0;
	                            if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 2) {
	                                if ((c[b + 44 >> 2] | 0) != (c[f >> 2] | 0))break;
	                                c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 44 >> 2] = c[g >> 2];
	                                break
	                            }
	                            if ((c[b + 12 >> 2] | 0) == (c[f >> 2] | 0))c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 12 >> 2] = c[g >> 2];
	                            if ((c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 16 >> 2] | 0) == (c[f >> 2] | 0))c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 16 >> 2] = c[g >> 2]
	                        } while (0);
	                        c[(c[f >> 2] | 0) + 28 >> 2] = 0;
	                        c[(c[f >> 2] | 0) + 24 >> 2] = 0;
	                        c[(c[f >> 2] | 0) + 20 >> 2] = 0;
	                        c[e >> 2] = c[f >> 2];
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                    Qh(c[f >> 2] | 0);
	                    c[e >> 2] = c[f >> 2];
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                c[e >> 2] = 0;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function Di(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                do if (c[e >> 2] | 0)if ((c[(c[e >> 2] | 0) + 4 >> 2] | 0) == 18) {
	                    c[f >> 2] = Ih(0, c[(c[e >> 2] | 0) + 8 >> 2] | 0, c[(c[e >> 2] | 0) + 12 >> 2] | 0) | 0;
	                    c[d >> 2] = c[f >> 2];
	                    break
	                } else {
	                    c[d >> 2] = 0;
	                    break
	                } else c[d >> 2] = 0; while (0);
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function Ei(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[d >> 2] = a;
	                c[e >> 2] = 0;
	                c[f >> 2] = 0;
	                while (1) {
	                    if (!(c[d >> 2] | 0))break;
	                    c[g >> 2] = Di(c[d >> 2] | 0) | 0;
	                    a = c[g >> 2] | 0;
	                    if (!(c[f >> 2] | 0)) {
	                        c[f >> 2] = a;
	                        c[e >> 2] = a
	                    } else {
	                        c[c[f >> 2] >> 2] = a;
	                        c[f >> 2] = c[g >> 2]
	                    }
	                    c[d >> 2] = c[c[d >> 2] >> 2]
	                }
	                i = b;
	                return c[e >> 2] | 0
	            }

	            function Fi(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                b = yj(0, c[e >> 2] | 0, c[f >> 2] | 0) | 0;
	                i = d;
	                return b | 0
	            }

	            function Gi(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                c[j >> 2] = 0;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 1 : 0) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                while (1) {
	                    if (!(c[g >> 2] | 0)) {
	                        m = 11;
	                        break
	                    }
	                    c[k >> 2] = Fi(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                    if (!(c[k >> 2] | 0)) {
	                        m = 6;
	                        break
	                    }
	                    b = c[k >> 2] | 0;
	                    if (!(c[j >> 2] | 0)) {
	                        c[j >> 2] = b;
	                        c[h >> 2] = b
	                    } else {
	                        c[(c[j >> 2] | 0) + 24 >> 2] = b;
	                        c[(c[k >> 2] | 0) + 28 >> 2] = c[j >> 2];
	                        c[j >> 2] = c[k >> 2]
	                    }
	                    c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2]
	                }
	                if ((m | 0) == 6) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                } else if ((m | 0) == 11) {
	                    c[e >> 2] = c[h >> 2];
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                return 0
	            }

	            function Hi(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[g >> 2] = zj(c[e >> 2] | 0, 0, 0, c[f >> 2] | 0) | 0;
	                i = d;
	                return c[g >> 2] | 0
	            }

	            function Ii(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = zj(c[f >> 2] | 0, c[g >> 2] | 0, 0, c[h >> 2] | 0) | 0;
	                i = e;
	                return c[j >> 2] | 0
	            }

	            function Ji(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[g >> 2] = Aj(c[f >> 2] | 0, c[e >> 2] | 0, 0) | 0;
	                i = d;
	                return c[g >> 2] | 0
	            }

	            function Ki(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                c[e >> 2] = Aj(c[d >> 2] | 0, 0, 0) | 0;
	                i = b;
	                return c[e >> 2] | 0
	            }

	            function Li(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                b = i;
	                i = i + 48 | 0;
	                d = b + 32 | 0;
	                e = b + 28 | 0;
	                f = b + 24 | 0;
	                g = b + 20 | 0;
	                h = b + 16 | 0;
	                j = b + 12 | 0;
	                k = b + 8 | 0;
	                l = b + 4 | 0;
	                m = b;
	                c[e >> 2] = a;
	                c[h >> 2] = 0;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    n = c[d >> 2] | 0;
	                    i = b;
	                    return n | 0
	                }
	                c[f >> 2] = Mh(0, c[(c[e >> 2] | 0) + 8 >> 2] | 0, c[(c[e >> 2] | 0) + 52 >> 2] | 0, c[(c[e >> 2] | 0) + 56 >> 2] | 0) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    n = c[d >> 2] | 0;
	                    i = b;
	                    return n | 0
	                }
	                if (c[(c[e >> 2] | 0) + 48 >> 2] | 0) {
	                    a = ed(c[(c[e >> 2] | 0) + 48 >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 48 >> 2] = a
	                }
	                if (c[(c[e >> 2] | 0) + 36 >> 2] | 0) {
	                    a = zm(c[(c[e >> 2] | 0) + 36 >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 36 >> 2] = a
	                }
	                if (c[(c[e >> 2] | 0) + 40 >> 2] | 0) {
	                    a = om(c[(c[e >> 2] | 0) + 40 >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 40 >> 2] = a
	                }
	                if (c[(c[e >> 2] | 0) + 44 >> 2] | 0) {
	                    a = vm(c[(c[e >> 2] | 0) + 44 >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 44 >> 2] = a
	                }
	                if (c[(c[e >> 2] | 0) + 60 >> 2] | 0) {
	                    a = ed(c[(c[e >> 2] | 0) + 60 >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 60 >> 2] = a
	                }
	                c[g >> 2] = c[(c[e >> 2] | 0) + 12 >> 2];
	                while (1) {
	                    if (!(c[g >> 2] | 0))break;
	                    c[j >> 2] = 0;
	                    e = c[g >> 2] | 0;
	                    a:do if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 17) {
	                        a = c[g >> 2] | 0;
	                        if ((c[e + 4 >> 2] | 0) == 15) {
	                            c[l >> 2] = a;
	                            c[j >> 2] = Mm(c[f >> 2] | 0, c[(c[l >> 2] | 0) + 8 >> 2] | 0, c[(c[l >> 2] | 0) + 48 >> 2] | 0) | 0;
	                            break
	                        }
	                        o = c[g >> 2] | 0;
	                        if ((c[a + 4 >> 2] | 0) == 16) {
	                            c[m >> 2] = o;
	                            c[j >> 2] = Nm(c[f >> 2] | 0, c[(c[m >> 2] | 0) + 60 >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0, c[(c[m >> 2] | 0) + 56 >> 2] | 0) | 0;
	                            break
	                        }
	                        if ((c[o + 4 >> 2] | 0) == 8)c[j >> 2] = Hi(c[g >> 2] | 0, 0) | 0
	                    } else {
	                        c[k >> 2] = e;
	                        switch (c[(c[k >> 2] | 0) + 48 >> 2] | 0) {
	                            case 3:
	                            case 2:
	                            case 1:
	                            {
	                                c[j >> 2] = Bj(c[f >> 2] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0) | 0;
	                                break a;
	                                break
	                            }
	                            case 5:
	                            case 4:
	                            {
	                                c[j >> 2] = Cj(c[f >> 2] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0) | 0;
	                                break a;
	                                break
	                            }
	                            default:
	                                break a
	                        }
	                    } while (0);
	                    if (!(c[j >> 2] | 0)) {
	                        c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                        continue
	                    }
	                    e = c[j >> 2] | 0;
	                    if (!(c[h >> 2] | 0))c[(c[f >> 2] | 0) + 12 >> 2] = e; else c[(c[h >> 2] | 0) + 24 >> 2] = e;
	                    c[(c[j >> 2] | 0) + 28 >> 2] = c[h >> 2];
	                    c[(c[j >> 2] | 0) + 20 >> 2] = c[f >> 2];
	                    c[(c[j >> 2] | 0) + 24 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 16 >> 2] = c[j >> 2];
	                    c[h >> 2] = c[j >> 2];
	                    c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2]
	                }
	                c[d >> 2] = c[f >> 2];
	                n = c[d >> 2] | 0;
	                i = b;
	                return n | 0
	            }

	            function Mi(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                c[h >> 2] = Sh(c[(c[f >> 2] | 0) + 56 >> 2] | 0) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                if (c[(c[f >> 2] | 0) + 8 >> 2] | 0) {
	                    b = Cb[c[135768 >> 2] & 511](c[(c[f >> 2] | 0) + 8 >> 2] | 0) | 0;
	                    c[(c[h >> 2] | 0) + 8 >> 2] = b
	                }
	                if (c[(c[f >> 2] | 0) + 60 >> 2] | 0) {
	                    b = my(c[(c[f >> 2] | 0) + 60 >> 2] | 0) | 0;
	                    c[(c[h >> 2] | 0) + 60 >> 2] = b
	                }
	                if (c[(c[f >> 2] | 0) + 72 >> 2] | 0) {
	                    b = my(c[(c[f >> 2] | 0) + 72 >> 2] | 0) | 0;
	                    c[(c[h >> 2] | 0) + 72 >> 2] = b
	                }
	                c[(c[h >> 2] | 0) + 76 >> 2] = c[(c[f >> 2] | 0) + 76 >> 2];
	                c[(c[h >> 2] | 0) + 36 >> 2] = c[(c[f >> 2] | 0) + 36 >> 2];
	                c[(c[h >> 2] | 0) + 40 >> 2] = c[(c[f >> 2] | 0) + 40 >> 2];
	                b = c[h >> 2] | 0;
	                if (!(c[g >> 2] | 0)) {
	                    c[e >> 2] = b;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                c[b + 16 >> 2] = 0;
	                c[(c[h >> 2] | 0) + 12 >> 2] = 0;
	                do if (c[(c[f >> 2] | 0) + 44 >> 2] | 0) {
	                    b = Li(c[(c[f >> 2] | 0) + 44 >> 2] | 0) | 0;
	                    c[(c[h >> 2] | 0) + 44 >> 2] = b;
	                    b = c[h >> 2] | 0;
	                    if (c[(c[h >> 2] | 0) + 44 >> 2] | 0) {
	                        ri(c[b + 44 >> 2] | 0, c[h >> 2] | 0);
	                        c[(c[(c[h >> 2] | 0) + 44 >> 2] | 0) + 20 >> 2] = c[h >> 2];
	                        break
	                    }
	                    Th(b);
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                } while (0);
	                if (c[(c[f >> 2] | 0) + 52 >> 2] | 0) {
	                    b = Ei(c[(c[f >> 2] | 0) + 52 >> 2] | 0) | 0;
	                    c[(c[h >> 2] | 0) + 52 >> 2] = b
	                }
	                a:do if (c[(c[f >> 2] | 0) + 12 >> 2] | 0) {
	                    b = Aj(c[(c[f >> 2] | 0) + 12 >> 2] | 0, c[h >> 2] | 0, c[h >> 2] | 0) | 0;
	                    c[(c[h >> 2] | 0) + 12 >> 2] = b;
	                    c[(c[h >> 2] | 0) + 16 >> 2] = 0;
	                    c[j >> 2] = c[(c[h >> 2] | 0) + 12 >> 2];
	                    while (1) {
	                        if (!(c[j >> 2] | 0))break a;
	                        if (!(c[(c[j >> 2] | 0) + 24 >> 2] | 0))c[(c[h >> 2] | 0) + 16 >> 2] = c[j >> 2];
	                        c[j >> 2] = c[(c[j >> 2] | 0) + 24 >> 2]
	                    }
	                } while (0);
	                c[e >> 2] = c[h >> 2];
	                k = c[e >> 2] | 0;
	                i = d;
	                return k | 0
	            }

	            function Ni(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = Dj(c[d >> 2] | 0, 0) | 0;
	                i = b;
	                return a | 0
	            }

	            function Oi(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0;
	                e = i;
	                i = i + 176 | 0;
	                f = e;
	                g = e + 64 | 0;
	                h = e + 60 | 0;
	                j = e + 56 | 0;
	                k = e + 52 | 0;
	                l = e + 48 | 0;
	                m = e + 44 | 0;
	                n = e + 40 | 0;
	                o = e + 36 | 0;
	                p = e + 32 | 0;
	                q = e + 28 | 0;
	                r = e + 24 | 0;
	                s = e + 68 | 0;
	                t = e + 20 | 0;
	                u = e + 16 | 0;
	                c[h >> 2] = b;
	                c[m >> 2] = 0;
	                c[t >> 2] = 0;
	                if ((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                    c[o >> 2] = 500;
	                    c[m >> 2] = Cb[c[135752 >> 2] & 511](c[o >> 2] | 0) | 0;
	                    if (!(c[m >> 2] | 0)) {
	                        tj(75488);
	                        c[g >> 2] = 0;
	                        v = c[g >> 2] | 0;
	                        i = e;
	                        return v | 0
	                    }
	                    c[p >> 2] = Cb[c[135752 >> 2] & 511](c[o >> 2] | 0) | 0;
	                    if (!(c[p >> 2] | 0)) {
	                        tj(75488);
	                        zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                        c[g >> 2] = 0;
	                        v = c[g >> 2] | 0;
	                        i = e;
	                        return v | 0
	                    }
	                    a[c[m >> 2] >> 0] = 0;
	                    c[j >> 2] = c[h >> 2];
	                    while (1) {
	                        c[r >> 2] = 75312;
	                        c[q >> 2] = 75512;
	                        c[t >> 2] = 0;
	                        a:do if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 9 ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 13 : 0) {
	                            if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                                c[u >> 2] = 0;
	                                c[q >> 2] = 75520;
	                                c[r >> 2] = c[(c[j >> 2] | 0) + 8 >> 2];
	                                do if (c[(c[j >> 2] | 0) + 36 >> 2] | 0)if (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) {
	                                    h = c[(c[j >> 2] | 0) + 8 >> 2] | 0;
	                                    c[f >> 2] = c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2];
	                                    c[f + 4 >> 2] = h;
	                                    JT(s, 99, 75528, f) | 0;
	                                    a[s + 99 >> 0] = 0;
	                                    c[r >> 2] = s;
	                                    break
	                                } else {
	                                    c[u >> 2] = 1;
	                                    c[r >> 2] = 75536;
	                                    break
	                                } while (0);
	                                c[l >> 2] = c[(c[j >> 2] | 0) + 20 >> 2];
	                                c[k >> 2] = c[(c[j >> 2] | 0) + 28 >> 2];
	                                while (1) {
	                                    if (!(c[k >> 2] | 0))break;
	                                    do if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                                        if (!(c[u >> 2] | 0)) {
	                                            if (!(qy(c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0) | 0))break;
	                                            if ((c[(c[k >> 2] | 0) + 36 >> 2] | 0) != (c[(c[j >> 2] | 0) + 36 >> 2] | 0)) {
	                                                if (!(c[(c[k >> 2] | 0) + 36 >> 2] | 0))break;
	                                                if (!(c[(c[j >> 2] | 0) + 36 >> 2] | 0))break;
	                                                if (!(qy(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0))break
	                                            }
	                                        }
	                                        c[t >> 2] = (c[t >> 2] | 0) + 1
	                                    } while (0);
	                                    c[k >> 2] = c[(c[k >> 2] | 0) + 28 >> 2]
	                                }
	                                if (c[t >> 2] | 0) {
	                                    c[t >> 2] = (c[t >> 2] | 0) + 1;
	                                    break
	                                }
	                                c[k >> 2] = c[(c[j >> 2] | 0) + 24 >> 2];
	                                while (1) {
	                                    if (!((c[k >> 2] | 0) != 0 & (c[t >> 2] | 0) == 0))break;
	                                    b:do if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                                        do if (!(c[u >> 2] | 0)) {
	                                            if (!(qy(c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0) | 0))break b;
	                                            if ((c[(c[k >> 2] | 0) + 36 >> 2] | 0) == (c[(c[j >> 2] | 0) + 36 >> 2] | 0))break;
	                                            if (!(c[(c[k >> 2] | 0) + 36 >> 2] | 0))break b;
	                                            if (!(c[(c[j >> 2] | 0) + 36 >> 2] | 0))break b;
	                                            if (!(qy(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0))break b
	                                        } while (0);
	                                        c[t >> 2] = (c[t >> 2] | 0) + 1
	                                    } while (0);
	                                    c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                                }
	                                if (!(c[t >> 2] | 0))break;
	                                c[t >> 2] = 1;
	                                break
	                            }
	                            if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) == 8) {
	                                c[q >> 2] = 75520;
	                                c[r >> 2] = 75544;
	                                c[l >> 2] = c[(c[j >> 2] | 0) + 20 >> 2];
	                                c[k >> 2] = c[(c[j >> 2] | 0) + 28 >> 2];
	                                while (1) {
	                                    if (!(c[k >> 2] | 0))break;
	                                    if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 8)c[t >> 2] = (c[t >> 2] | 0) + 1;
	                                    c[k >> 2] = c[(c[k >> 2] | 0) + 28 >> 2]
	                                }
	                                if (c[t >> 2] | 0) {
	                                    c[t >> 2] = (c[t >> 2] | 0) + 1;
	                                    break
	                                }
	                                c[k >> 2] = c[(c[j >> 2] | 0) + 24 >> 2];
	                                while (1) {
	                                    if (!((c[k >> 2] | 0) != 0 & (c[t >> 2] | 0) == 0))break;
	                                    if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 8)c[t >> 2] = (c[t >> 2] | 0) + 1;
	                                    c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                                }
	                                if (!(c[t >> 2] | 0))break;
	                                c[t >> 2] = 1;
	                                break
	                            }
	                            if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 3 ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 4 : 0) {
	                                if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 7) {
	                                    if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 2) {
	                                        c[l >> 2] = c[(c[j >> 2] | 0) + 20 >> 2];
	                                        break
	                                    }
	                                    c[q >> 2] = 75600;
	                                    c[r >> 2] = c[(c[j >> 2] | 0) + 8 >> 2];
	                                    if (c[(c[j >> 2] | 0) + 36 >> 2] | 0) {
	                                        h = c[j >> 2] | 0;
	                                        if (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) {
	                                            b = c[(c[j >> 2] | 0) + 8 >> 2] | 0;
	                                            c[f >> 2] = c[(c[h + 36 >> 2] | 0) + 12 >> 2];
	                                            c[f + 4 >> 2] = b;
	                                            JT(s, 99, 75528, f) | 0
	                                        } else {
	                                            c[f >> 2] = c[h + 8 >> 2];
	                                            JT(s, 99, 75608, f) | 0
	                                        }
	                                        a[s + 99 >> 0] = 0;
	                                        c[r >> 2] = s
	                                    }
	                                    c[l >> 2] = c[(c[j >> 2] | 0) + 20 >> 2];
	                                    break
	                                }
	                                c[q >> 2] = 75520;
	                                c[f >> 2] = c[(c[j >> 2] | 0) + 8 >> 2];
	                                JT(s, 99, 75568, f) | 0;
	                                a[s + 99 >> 0] = 0;
	                                c[r >> 2] = s;
	                                c[l >> 2] = c[(c[j >> 2] | 0) + 20 >> 2];
	                                c[k >> 2] = c[(c[j >> 2] | 0) + 28 >> 2];
	                                while (1) {
	                                    if (!(c[k >> 2] | 0))break;
	                                    if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 7 ? (qy(c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0) | 0) != 0 : 0)c[t >> 2] = (c[t >> 2] | 0) + 1;
	                                    c[k >> 2] = c[(c[k >> 2] | 0) + 28 >> 2]
	                                }
	                                if (c[t >> 2] | 0) {
	                                    c[t >> 2] = (c[t >> 2] | 0) + 1;
	                                    break
	                                }
	                                c[k >> 2] = c[(c[j >> 2] | 0) + 24 >> 2];
	                                while (1) {
	                                    if (!((c[k >> 2] | 0) != 0 & (c[t >> 2] | 0) == 0))break;
	                                    do if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 7) {
	                                        if (!(qy(c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0) | 0))break;
	                                        c[t >> 2] = (c[t >> 2] | 0) + 1
	                                    } while (0);
	                                    c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                                }
	                                if (!(c[t >> 2] | 0))break;
	                                c[t >> 2] = 1;
	                                break
	                            }
	                            c[q >> 2] = 75520;
	                            c[r >> 2] = 75560;
	                            c[l >> 2] = c[(c[j >> 2] | 0) + 20 >> 2];
	                            c[k >> 2] = c[(c[j >> 2] | 0) + 28 >> 2];
	                            while (1) {
	                                if (!(c[k >> 2] | 0))break;
	                                if (!((c[(c[k >> 2] | 0) + 4 >> 2] | 0) != 3 ? (c[(c[k >> 2] | 0) + 4 >> 2] | 0) != 4 : 0))c[t >> 2] = (c[t >> 2] | 0) + 1;
	                                c[k >> 2] = c[(c[k >> 2] | 0) + 28 >> 2]
	                            }
	                            if (c[t >> 2] | 0) {
	                                c[t >> 2] = (c[t >> 2] | 0) + 1;
	                                break
	                            }
	                            c[k >> 2] = c[(c[j >> 2] | 0) + 24 >> 2];
	                            while (1) {
	                                if (!(c[k >> 2] | 0))break a;
	                                if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 3)break;
	                                if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 4)break;
	                                c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                            }
	                            c[t >> 2] = 1
	                        } else w = 11; while (0);
	                        if ((w | 0) == 11) {
	                            w = 0;
	                            if ((d[c[m >> 2] >> 0] | 0 | 0) == 47) {
	                                w = 110;
	                                break
	                            }
	                            c[q >> 2] = 75520;
	                            c[l >> 2] = 0
	                        }
	                        h = (xy(c[m >> 2] | 0) | 0) + 120 | 0;
	                        if (h >>> 0 > (c[o >> 2] | 0) >>> 0) {
	                            h = c[o >> 2] << 1;
	                            c[o >> 2] = h + (xy(c[m >> 2] | 0) | 0) + 120;
	                            c[n >> 2] = Hb[c[135760 >> 2] & 511](c[m >> 2] | 0, c[o >> 2] | 0) | 0;
	                            if (!(c[n >> 2] | 0)) {
	                                w = 102;
	                                break
	                            }
	                            c[m >> 2] = c[n >> 2];
	                            c[n >> 2] = Hb[c[135760 >> 2] & 511](c[p >> 2] | 0, c[o >> 2] | 0) | 0;
	                            if (!(c[n >> 2] | 0)) {
	                                w = 104;
	                                break
	                            }
	                            c[p >> 2] = c[n >> 2]
	                        }
	                        h = c[p >> 2] | 0;
	                        b = c[o >> 2] | 0;
	                        x = c[q >> 2] | 0;
	                        y = c[r >> 2] | 0;
	                        if (!(c[t >> 2] | 0)) {
	                            z = c[m >> 2] | 0;
	                            c[f >> 2] = x;
	                            c[f + 4 >> 2] = y;
	                            c[f + 8 >> 2] = z;
	                            JT(h, b, 75616, f) | 0
	                        } else {
	                            z = c[t >> 2] | 0;
	                            A = c[m >> 2] | 0;
	                            c[f >> 2] = x;
	                            c[f + 4 >> 2] = y;
	                            c[f + 8 >> 2] = z;
	                            c[f + 12 >> 2] = A;
	                            JT(h, b, 75624, f) | 0
	                        }
	                        b = c[m >> 2] | 0;
	                        h = c[o >> 2] | 0;
	                        c[f >> 2] = c[p >> 2];
	                        JT(b, h, 75608, f) | 0;
	                        c[j >> 2] = c[l >> 2];
	                        if (!(c[j >> 2] | 0)) {
	                            w = 110;
	                            break
	                        }
	                    }
	                    if ((w | 0) == 102) {
	                        tj(75488);
	                        zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                        c[g >> 2] = 0;
	                        v = c[g >> 2] | 0;
	                        i = e;
	                        return v | 0
	                    } else if ((w | 0) == 104) {
	                        tj(75488);
	                        zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                        c[g >> 2] = 0;
	                        v = c[g >> 2] | 0;
	                        i = e;
	                        return v | 0
	                    } else if ((w | 0) == 110) {
	                        zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                        c[g >> 2] = c[m >> 2];
	                        v = c[g >> 2] | 0;
	                        i = e;
	                        return v | 0
	                    }
	                }
	                c[g >> 2] = 0;
	                v = c[g >> 2] | 0;
	                i = e;
	                return v | 0
	            }

	            function Pi(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[f >> 2] = c[(c[e >> 2] | 0) + 12 >> 2];
	                while (1) {
	                    h = c[f >> 2] | 0;
	                    if (!(c[f >> 2] | 0)) {
	                        j = 8;
	                        break
	                    }
	                    k = c[f >> 2] | 0;
	                    if ((c[h + 4 >> 2] | 0) == 1) {
	                        j = 6;
	                        break
	                    }
	                    c[f >> 2] = c[k + 24 >> 2]
	                }
	                if ((j | 0) == 6) {
	                    c[d >> 2] = k;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else if ((j | 0) == 8) {
	                    c[d >> 2] = h;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function Qi(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                    Qh(c[g >> 2] | 0);
	                    ri(c[g >> 2] | 0, c[f >> 2] | 0);
	                    c[(c[g >> 2] | 0) + 20 >> 2] = c[f >> 2];
	                    c[h >> 2] = c[(c[f >> 2] | 0) + 12 >> 2];
	                    while (1) {
	                        if (!(c[h >> 2] | 0))break;
	                        if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 1)break;
	                        c[h >> 2] = c[(c[h >> 2] | 0) + 24 >> 2]
	                    }
	                    do if (!(c[h >> 2] | 0))if (!(c[(c[f >> 2] | 0) + 12 >> 2] | 0)) {
	                        c[(c[f >> 2] | 0) + 12 >> 2] = c[g >> 2];
	                        c[(c[f >> 2] | 0) + 16 >> 2] = c[g >> 2];
	                        break
	                    } else {
	                        xi(c[(c[f >> 2] | 0) + 12 >> 2] | 0, c[g >> 2] | 0) | 0;
	                        break
	                    } else Ci(c[h >> 2] | 0, c[g >> 2] | 0) | 0; while (0);
	                    c[e >> 2] = c[h >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[e >> 2] = 0;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function Ri(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 20 | 0;
	                h = e + 16 | 0;
	                j = e + 12 | 0;
	                k = e + 8 | 0;
	                l = e + 4 | 0;
	                m = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[l >> 2] = c[h >> 2];
	                if ((c[h >> 2] | 0) != 0 ? !((c[j >> 2] | 0) == 0 ? 1 : (c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 18) : 0) {
	                    if (qy(c[j >> 2] | 0, 75176) | 0) {
	                        if ((c[g >> 2] | 0) == 0 ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) {
	                            c[k >> 2] = Cb[c[135744 >> 2] & 511](24) | 0;
	                            if (!(c[k >> 2] | 0)) {
	                                tj(75760);
	                                c[f >> 2] = 0;
	                                n = c[f >> 2] | 0;
	                                i = e;
	                                return n | 0
	                            } else {
	                                d = c[k >> 2] | 0;
	                                c[d + 0 >> 2] = 0;
	                                c[d + 4 >> 2] = 0;
	                                c[d + 8 >> 2] = 0;
	                                c[d + 12 >> 2] = 0;
	                                c[d + 16 >> 2] = 0;
	                                c[d + 20 >> 2] = 0;
	                                c[(c[k >> 2] | 0) + 4 >> 2] = 18;
	                                d = my(75176) | 0;
	                                c[(c[k >> 2] | 0) + 8 >> 2] = d;
	                                d = my(75168) | 0;
	                                c[(c[k >> 2] | 0) + 12 >> 2] = d;
	                                c[c[k >> 2] >> 2] = c[(c[h >> 2] | 0) + 48 >> 2];
	                                c[(c[h >> 2] | 0) + 48 >> 2] = c[k >> 2];
	                                c[f >> 2] = c[k >> 2];
	                                n = c[f >> 2] | 0;
	                                i = e;
	                                return n | 0
	                            }
	                        }
	                        if ((c[g >> 2] | 0) == 0 ? (c[g >> 2] = c[(c[h >> 2] | 0) + 32 >> 2], (c[g >> 2] | 0) == 0) : 0) {
	                            c[f >> 2] = 0;
	                            n = c[f >> 2] | 0;
	                            i = e;
	                            return n | 0
	                        }
	                        d = c[g >> 2] | 0;
	                        if (!(c[(c[g >> 2] | 0) + 52 >> 2] | 0)) {
	                            c[f >> 2] = Ej(d) | 0;
	                            n = c[f >> 2] | 0;
	                            i = e;
	                            return n | 0
	                        } else {
	                            c[f >> 2] = c[d + 52 >> 2];
	                            n = c[f >> 2] | 0;
	                            i = e;
	                            return n | 0
	                        }
	                    }
	                    c[m >> 2] = (c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 2 & 1;
	                    a:while (1) {
	                        if (!(c[h >> 2] | 0)) {
	                            o = 41;
	                            break
	                        }
	                        if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 5) {
	                            o = 21;
	                            break
	                        }
	                        if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 6) {
	                            o = 21;
	                            break
	                        }
	                        if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 17) {
	                            o = 21;
	                            break
	                        }
	                        do if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                            c[k >> 2] = c[(c[h >> 2] | 0) + 48 >> 2];
	                            while (1) {
	                                if (!(c[k >> 2] | 0))break;
	                                do if (((c[j >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, c[j >> 2] | 0) | 0) != 0 : 0) {
	                                    if ((c[m >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 12 >> 2] | 0) == 0 : 0)break;
	                                    if ((Fj(c[g >> 2] | 0, c[l >> 2] | 0, c[h >> 2] | 0, c[(c[k >> 2] | 0) + 12 >> 2] | 0) | 0) == 1) {
	                                        o = 30;
	                                        break a
	                                    }
	                                } while (0);
	                                c[k >> 2] = c[c[k >> 2] >> 2]
	                            }
	                            if ((((c[l >> 2] | 0) != (c[h >> 2] | 0) ? (c[k >> 2] = c[(c[h >> 2] | 0) + 36 >> 2], (c[k >> 2] | 0) != 0) : 0) ? ((c[j >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) : 0) ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, c[j >> 2] | 0) | 0) != 0 : 0) {
	                                if ((c[m >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 12 >> 2] | 0) == 0 : 0)break;
	                                if ((Fj(c[g >> 2] | 0, c[l >> 2] | 0, c[h >> 2] | 0, c[(c[k >> 2] | 0) + 12 >> 2] | 0) | 0) == 1) {
	                                    o = 39;
	                                    break a
	                                }
	                            }
	                        } while (0);
	                        c[h >> 2] = c[(c[h >> 2] | 0) + 20 >> 2]
	                    }
	                    if ((o | 0) == 21) {
	                        c[f >> 2] = 0;
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    } else if ((o | 0) == 30) {
	                        c[f >> 2] = c[k >> 2];
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    } else if ((o | 0) == 39) {
	                        c[f >> 2] = c[k >> 2];
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    } else if ((o | 0) == 41) {
	                        c[f >> 2] = 0;
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    }
	                }
	                c[f >> 2] = 0;
	                n = c[f >> 2] | 0;
	                i = e;
	                return n | 0
	            }

	            function Si(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 24 | 0;
	                h = f + 20 | 0;
	                j = f + 16 | 0;
	                k = f + 12 | 0;
	                l = f + 8 | 0;
	                m = f + 4 | 0;
	                n = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if ((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 8 >> 2] | 0) == 0 : 0) {
	                    c[g >> 2] = 0;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                if (c[j >> 2] | 0)p = c[(c[j >> 2] | 0) + 8 >> 2] | 0; else p = 0;
	                c[m >> 2] = xj(c[h >> 2] | 0, c[k >> 2] | 0, p, 0) | 0;
	                if (!(c[m >> 2] | 0)) {
	                    c[g >> 2] = wj(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, 0) | 0;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                if ((c[(c[m >> 2] | 0) + 40 >> 2] | 0) == 2) {
	                    Gm(c[(c[h >> 2] | 0) + 32 >> 2] | 0, c[m >> 2] | 0) | 0;
	                    c[(c[m >> 2] | 0) + 40 >> 2] = 2
	                }
	                if (c[(c[m >> 2] | 0) + 12 >> 2] | 0)Uh(c[(c[m >> 2] | 0) + 12 >> 2] | 0);
	                c[(c[m >> 2] | 0) + 12 >> 2] = 0;
	                c[(c[m >> 2] | 0) + 16 >> 2] = 0;
	                c[(c[m >> 2] | 0) + 36 >> 2] = c[j >> 2];
	                a:do if (c[l >> 2] | 0) {
	                    if ((Fy(c[l >> 2] | 0) | 0) == 0 ? (uj(1303, c[(c[h >> 2] | 0) + 32 >> 2] | 0, 0), (c[(c[h >> 2] | 0) + 32 >> 2] | 0) != 0) : 0) {
	                        j = my(75792) | 0;
	                        c[(c[(c[h >> 2] | 0) + 32 >> 2] | 0) + 60 >> 2] = j
	                    }
	                    j = Wh(c[(c[h >> 2] | 0) + 32 >> 2] | 0, c[l >> 2] | 0) | 0;
	                    c[(c[m >> 2] | 0) + 12 >> 2] = j;
	                    c[(c[m >> 2] | 0) + 16 >> 2] = 0;
	                    c[n >> 2] = c[(c[m >> 2] | 0) + 12 >> 2];
	                    while (1) {
	                        if (!(c[n >> 2] | 0))break a;
	                        c[(c[n >> 2] | 0) + 20 >> 2] = c[m >> 2];
	                        if (!(c[(c[n >> 2] | 0) + 24 >> 2] | 0))c[(c[m >> 2] | 0) + 16 >> 2] = c[n >> 2];
	                        c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2]
	                    }
	                } while (0);
	                if ((c[(c[m >> 2] | 0) + 40 >> 2] | 0) == 2)Cm(0, c[(c[h >> 2] | 0) + 32 >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0) | 0;
	                c[g >> 2] = c[m >> 2];
	                o = c[g >> 2] | 0;
	                i = f;
	                return o | 0
	            }

	            function Ti(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                    while (1) {
	                        if (!(c[e >> 2] | 0)) {
	                            g = 8;
	                            break
	                        }
	                        c[f >> 2] = Ui(c[e >> 2] | 0, 75640, 75176) | 0;
	                        if (c[f >> 2] | 0) {
	                            g = 6;
	                            break
	                        }
	                        c[e >> 2] = c[(c[e >> 2] | 0) + 20 >> 2]
	                    }
	                    if ((g | 0) == 6) {
	                        c[d >> 2] = c[f >> 2];
	                        h = c[d >> 2] | 0;
	                        i = b;
	                        return h | 0
	                    } else if ((g | 0) == 8) {
	                        c[d >> 2] = 0;
	                        h = c[d >> 2] | 0;
	                        i = b;
	                        return h | 0
	                    }
	                }
	                c[d >> 2] = 0;
	                h = c[d >> 2] | 0;
	                i = b;
	                return h | 0
	            }

	            function Ui(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = xj(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[18946] | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } else {
	                    c[f >> 2] = Gj(c[k >> 2] | 0) | 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                return 0
	            }

	            function Vi(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) {
	                    while (1) {
	                        if (!(c[e >> 2] | 0)) {
	                            g = 11;
	                            break
	                        }
	                        c[f >> 2] = Ui(c[e >> 2] | 0, 75648, 75176) | 0;
	                        if (c[f >> 2] | 0) {
	                            if (qy(c[f >> 2] | 0, 75664) | 0) {
	                                g = 7;
	                                break
	                            }
	                            a = (qy(c[f >> 2] | 0, 75656) | 0) != 0;
	                            zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                            if (a) {
	                                g = 9;
	                                break
	                            }
	                        }
	                        c[e >> 2] = c[(c[e >> 2] | 0) + 20 >> 2]
	                    }
	                    if ((g | 0) == 7) {
	                        zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                        c[d >> 2] = 1;
	                        h = c[d >> 2] | 0;
	                        i = b;
	                        return h | 0
	                    } else if ((g | 0) == 9) {
	                        c[d >> 2] = 0;
	                        h = c[d >> 2] | 0;
	                        i = b;
	                        return h | 0
	                    } else if ((g | 0) == 11) {
	                        c[d >> 2] = -1;
	                        h = c[d >> 2] | 0;
	                        i = b;
	                        return h | 0
	                    }
	                }
	                c[d >> 2] = -1;
	                h = c[d >> 2] | 0;
	                i = b;
	                return h | 0
	            }

	            function Wi(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                switch (c[(c[e >> 2] | 0) + 4 >> 2] | 0) {
	                    case 9:
	                    case 21:
	                    case 13:
	                    {
	                        c[j >> 2] = c[e >> 2];
	                        if (c[(c[j >> 2] | 0) + 72 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[j >> 2] | 0) + 72 >> 2] | 0);
	                        if (!(c[f >> 2] | 0)) {
	                            c[(c[j >> 2] | 0) + 72 >> 2] = 0;
	                            i = d;
	                            return
	                        } else {
	                            b = Kl(c[f >> 2] | 0) | 0;
	                            c[(c[j >> 2] | 0) + 72 >> 2] = b;
	                            i = d;
	                            return
	                        }
	                        break
	                    }
	                    case 20:
	                    case 19:
	                    case 18:
	                    case 6:
	                    case 5:
	                    case 7:
	                    case 17:
	                    case 16:
	                    case 15:
	                    case 14:
	                    case 12:
	                    case 11:
	                    case 10:
	                    case 8:
	                    case 4:
	                    case 3:
	                    {
	                        i = d;
	                        return
	                    }
	                    default:
	                    {
	                        c[g >> 2] = Ri(c[(c[e >> 2] | 0) + 32 >> 2] | 0, c[e >> 2] | 0, 75176) | 0;
	                        if (!(c[g >> 2] | 0)) {
	                            i = d;
	                            return
	                        }
	                        c[h >> 2] = Kl(c[f >> 2] | 0) | 0;
	                        b = c[e >> 2] | 0;
	                        e = c[g >> 2] | 0;
	                        if (c[h >> 2] | 0) {
	                            Si(b, e, 75680, c[h >> 2] | 0) | 0;
	                            zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                            i = d;
	                            return
	                        } else {
	                            Si(b, e, 75680, c[f >> 2] | 0) | 0;
	                            i = d;
	                            return
	                        }
	                    }
	                }
	            }

	            function Xi(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 24 | 0;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                l = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                if ((c[g >> 2] | 0) == 0 & (c[f >> 2] | 0) == 0) {
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 18 : 0) {
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                if (!(c[f >> 2] | 0))c[f >> 2] = c[(c[g >> 2] | 0) + 32 >> 2];
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 13 : 0) {
	                    c[g >> 2] = c[(c[f >> 2] | 0) + 12 >> 2];
	                    while (1) {
	                        if (!(c[g >> 2] | 0)) {
	                            n = 22;
	                            break
	                        }
	                        if (!(c[(c[g >> 2] | 0) + 8 >> 2] | 0)) {
	                            n = 22;
	                            break
	                        }
	                        b = c[g >> 2] | 0;
	                        if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 1) {
	                            c[g >> 2] = c[b + 24 >> 2];
	                            continue
	                        }
	                        a = (ty(c[b + 8 >> 2] | 0, 75688) | 0) != 0;
	                        b = c[g >> 2] | 0;
	                        if (!a) {
	                            c[g >> 2] = c[b + 12 >> 2];
	                            continue
	                        }
	                        a = (ty(c[b + 8 >> 2] | 0, 75696) | 0) != 0;
	                        b = c[g >> 2] | 0;
	                        if (!a) {
	                            c[g >> 2] = c[b + 12 >> 2];
	                            continue
	                        }
	                        a = (ty(c[b + 8 >> 2] | 0, 75680) | 0) != 0;
	                        o = c[g >> 2] | 0;
	                        if (!a) {
	                            n = 20;
	                            break
	                        }
	                        c[g >> 2] = c[o + 24 >> 2]
	                    }
	                    if ((n | 0) == 20) {
	                        c[e >> 2] = Yi(o, 75704) | 0;
	                        m = c[e >> 2] | 0;
	                        i = d;
	                        return m | 0
	                    } else if ((n | 0) == 22) {
	                        c[e >> 2] = 0;
	                        m = c[e >> 2] | 0;
	                        i = d;
	                        return m | 0
	                    }
	                }
	                while (1) {
	                    if (!(c[g >> 2] | 0)) {
	                        n = 38;
	                        break
	                    }
	                    p = c[g >> 2] | 0;
	                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 17) {
	                        n = 25;
	                        break
	                    }
	                    if ((c[p + 4 >> 2] | 0) == 1 ? (c[j >> 2] = Ui(c[g >> 2] | 0, 75680, 75176) | 0, (c[j >> 2] | 0) != 0) : 0) {
	                        if (c[h >> 2] | 0) {
	                            c[k >> 2] = Hl(c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                            o = (c[k >> 2] | 0) != 0;
	                            zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                            zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                            if (!o) {
	                                n = 31;
	                                break
	                            }
	                            c[h >> 2] = c[k >> 2]
	                        } else c[h >> 2] = c[j >> 2];
	                        if (!(sy(c[h >> 2] | 0, 75712, 7) | 0)) {
	                            n = 36;
	                            break
	                        }
	                        if (!(sy(c[h >> 2] | 0, 75720, 6) | 0)) {
	                            n = 36;
	                            break
	                        }
	                        if (!(sy(c[h >> 2] | 0, 75728, 4) | 0)) {
	                            n = 36;
	                            break
	                        }
	                    }
	                    c[g >> 2] = c[(c[g >> 2] | 0) + 20 >> 2]
	                }
	                if ((n | 0) == 25) {
	                    c[l >> 2] = p;
	                    c[e >> 2] = my(c[(c[l >> 2] | 0) + 64 >> 2] | 0) | 0;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                } else if ((n | 0) == 31) {
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                } else if ((n | 0) == 36) {
	                    c[e >> 2] = c[h >> 2];
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                } else if ((n | 0) == 38) {
	                    if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 72 >> 2] | 0) != 0 : 0)if (!(c[h >> 2] | 0)) {
	                        c[e >> 2] = my(c[(c[f >> 2] | 0) + 72 >> 2] | 0) | 0;
	                        m = c[e >> 2] | 0;
	                        i = d;
	                        return m | 0
	                    } else {
	                        c[k >> 2] = Hl(c[h >> 2] | 0, c[(c[f >> 2] | 0) + 72 >> 2] | 0) | 0;
	                        zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                        c[e >> 2] = c[k >> 2];
	                        m = c[e >> 2] | 0;
	                        i = d;
	                        return m | 0
	                    }
	                    c[e >> 2] = c[h >> 2];
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                return 0
	            }

	            function Yi(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = dj(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } else {
	                    c[e >> 2] = Gj(c[h >> 2] | 0) | 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                return 0
	            }

	            function Zi(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 28 | 0;
	                f = d + 24 | 0;
	                g = d + 20 | 0;
	                h = d + 16 | 0;
	                j = d + 12 | 0;
	                k = d + 8 | 0;
	                l = d + 4 | 0;
	                m = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[g >> 2] | 0) == 0 | (c[f >> 2] | 0) == 0) {
	                    c[e >> 2] = -1;
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                a:do switch (c[(c[g >> 2] | 0) + 4 >> 2] | 0) {
	                    case 1:
	                    case 11:
	                    {
	                        c[h >> 2] = c[g >> 2];
	                        b:while (1) {
	                            if (!(c[h >> 2] | 0))break a;
	                            b = c[(c[h >> 2] | 0) + 4 >> 2] | 0;
	                            if ((b | 0) == 5)Zi(c[f >> 2] | 0, c[h >> 2] | 0) | 0; else if ((b | 0) == 3 | (b | 0) == 4 ? (c[(c[h >> 2] | 0) + 40 >> 2] | 0) != 0 : 0)ez(c[f >> 2] | 0, c[(c[h >> 2] | 0) + 40 >> 2] | 0) | 0;
	                            if ((c[(c[h >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[(c[(c[h >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) != 17 : 0) {
	                                c[h >> 2] = c[(c[h >> 2] | 0) + 12 >> 2];
	                                continue
	                            }
	                            if ((c[h >> 2] | 0) == (c[g >> 2] | 0))break a;
	                            if (c[(c[h >> 2] | 0) + 24 >> 2] | 0) {
	                                c[h >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                                continue
	                            }
	                            while (1) {
	                                c[h >> 2] = c[(c[h >> 2] | 0) + 20 >> 2];
	                                if (!(c[h >> 2] | 0))continue b;
	                                if ((c[h >> 2] | 0) == (c[g >> 2] | 0)) {
	                                    o = 19;
	                                    break
	                                }
	                                p = c[h >> 2] | 0;
	                                if (c[(c[h >> 2] | 0) + 24 >> 2] | 0) {
	                                    o = 21;
	                                    break
	                                }
	                                if (!p)continue b
	                            }
	                            if ((o | 0) == 19) {
	                                o = 0;
	                                c[h >> 2] = 0;
	                                continue
	                            } else if ((o | 0) == 21) {
	                                o = 0;
	                                c[h >> 2] = c[p + 24 >> 2];
	                                continue
	                            }
	                        }
	                        break
	                    }
	                    case 3:
	                    case 4:
	                    {
	                        ez(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 40 >> 2] | 0) | 0;
	                        break
	                    }
	                    case 9:
	                    case 21:
	                    case 13:
	                    {
	                        c[g >> 2] = c[(c[g >> 2] | 0) + 12 >> 2];
	                        while (1) {
	                            if (!(c[g >> 2] | 0))break a;
	                            if (!(((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 3 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 4 : 0))Zi(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                            c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2]
	                        }
	                        break
	                    }
	                    case 18:
	                    {
	                        ez(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        break
	                    }
	                    case 2:
	                    {
	                        c[j >> 2] = c[g >> 2];
	                        c[k >> 2] = c[(c[j >> 2] | 0) + 12 >> 2];
	                        while (1) {
	                            if (!(c[k >> 2] | 0))break a;
	                            b = c[f >> 2] | 0;
	                            a = c[k >> 2] | 0;
	                            if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 3)ez(b, c[a + 40 >> 2] | 0) | 0; else Zi(b, a) | 0;
	                            c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                        }
	                        break
	                    }
	                    case 7:
	                    case 8:
	                    {
	                        ez(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 40 >> 2] | 0) | 0;
	                        break
	                    }
	                    case 5:
	                    {
	                        c[l >> 2] = ad(c[(c[g >> 2] | 0) + 32 >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        if (!(c[l >> 2] | 0)) {
	                            c[e >> 2] = -1;
	                            n = c[e >> 2] | 0;
	                            i = d;
	                            return n | 0
	                        }
	                        c[m >> 2] = c[(c[l >> 2] | 0) + 12 >> 2];
	                        while (1) {
	                            if (!(c[m >> 2] | 0))break a;
	                            Zi(c[f >> 2] | 0, c[m >> 2] | 0) | 0;
	                            c[m >> 2] = c[(c[m >> 2] | 0) + 24 >> 2]
	                        }
	                        break
	                    }
	                    default:
	                    {
	                    }
	                } while (0);
	                c[e >> 2] = 0;
	                n = c[e >> 2] | 0;
	                i = d;
	                return n | 0
	            }

	            function _i(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                b = i;
	                i = i + 48 | 0;
	                d = b + 36 | 0;
	                e = b + 32 | 0;
	                f = b + 28 | 0;
	                g = b + 24 | 0;
	                h = b + 20 | 0;
	                j = b + 16 | 0;
	                k = b + 12 | 0;
	                l = b + 8 | 0;
	                m = b + 4 | 0;
	                n = b;
	                c[e >> 2] = a;
	                a:do if (!(c[e >> 2] | 0))c[d >> 2] = 0; else do switch (c[(c[e >> 2] | 0) + 4 >> 2] | 0) {
	                    case 13:
	                    case 21:
	                    case 9:
	                    {
	                        c[l >> 2] = Ly() | 0;
	                        if (!(c[l >> 2] | 0)) {
	                            c[d >> 2] = 0;
	                            break a
	                        } else {
	                            Zi(c[l >> 2] | 0, c[e >> 2] | 0) | 0;
	                            c[m >> 2] = Ny(c[l >> 2] | 0) | 0;
	                            Ry(c[l >> 2] | 0);
	                            c[d >> 2] = c[m >> 2];
	                            break a
	                        }
	                        break
	                    }
	                    case 2:
	                    {
	                        c[d >> 2] = Gj(c[e >> 2] | 0) | 0;
	                        break a;
	                        break
	                    }
	                    case 5:
	                    {
	                        c[h >> 2] = ad(c[(c[e >> 2] | 0) + 32 >> 2] | 0, c[(c[e >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        if (!(c[h >> 2] | 0)) {
	                            c[d >> 2] = 0;
	                            break a
	                        }
	                        c[j >> 2] = Ly() | 0;
	                        if (!(c[j >> 2] | 0)) {
	                            c[d >> 2] = 0;
	                            break a
	                        } else {
	                            Zi(c[j >> 2] | 0, c[e >> 2] | 0) | 0;
	                            c[k >> 2] = Ny(c[j >> 2] | 0) | 0;
	                            Ry(c[j >> 2] | 0);
	                            c[d >> 2] = c[k >> 2];
	                            break a
	                        }
	                        break
	                    }
	                    case 1:
	                    case 11:
	                    {
	                        c[f >> 2] = My(64) | 0;
	                        if (!(c[f >> 2] | 0)) {
	                            c[d >> 2] = 0;
	                            break a
	                        } else {
	                            Zi(c[f >> 2] | 0, c[e >> 2] | 0) | 0;
	                            c[g >> 2] = Ny(c[f >> 2] | 0) | 0;
	                            Ry(c[f >> 2] | 0);
	                            c[d >> 2] = c[g >> 2];
	                            break a
	                        }
	                        break
	                    }
	                    case 15:
	                    {
	                        c[d >> 2] = 0;
	                        break a;
	                        break
	                    }
	                    case 3:
	                    case 4:
	                    {
	                        if (c[(c[e >> 2] | 0) + 40 >> 2] | 0) {
	                            c[d >> 2] = my(c[(c[e >> 2] | 0) + 40 >> 2] | 0) | 0;
	                            break a
	                        } else {
	                            c[d >> 2] = 0;
	                            break a
	                        }
	                        break
	                    }
	                    case 18:
	                    {
	                        c[n >> 2] = my(c[(c[e >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        c[d >> 2] = c[n >> 2];
	                        break a;
	                        break
	                    }
	                    case 17:
	                    {
	                        c[d >> 2] = 0;
	                        break a;
	                        break
	                    }
	                    case 20:
	                    case 19:
	                    case 14:
	                    case 12:
	                    case 10:
	                    case 6:
	                    {
	                        c[d >> 2] = 0;
	                        break a;
	                        break
	                    }
	                    case 16:
	                    {
	                        c[d >> 2] = 0;
	                        break a;
	                        break
	                    }
	                    case 7:
	                    case 8:
	                    {
	                        if (c[(c[e >> 2] | 0) + 40 >> 2] | 0) {
	                            c[d >> 2] = my(c[(c[e >> 2] | 0) + 40 >> 2] | 0) | 0;
	                            break a
	                        } else {
	                            c[d >> 2] = 0;
	                            break a
	                        }
	                        break
	                    }
	                    default:
	                    {
	                        c[d >> 2] = 0;
	                        break a
	                    }
	                } while (0); while (0);
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function $i(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if ((c[f >> 2] | 0) == 0 | (c[h >> 2] | 0) <= 0) {
	                    i = e;
	                    return
	                }
	                switch (c[(c[f >> 2] | 0) + 4 >> 2] | 0) {
	                    case 8:
	                    case 7:
	                    case 6:
	                    case 5:
	                    case 4:
	                    case 3:
	                    case 12:
	                    {
	                        if (!(c[g >> 2] | 0)) {
	                            i = e;
	                            return
	                        }
	                        do if ((c[(c[f >> 2] | 0) + 40 >> 2] | 0) != ((c[f >> 2] | 0) + 44 | 0)) {
	                            if (((c[(c[f >> 2] | 0) + 32 >> 2] | 0) != 0 ? (c[(c[(c[f >> 2] | 0) + 32 >> 2] | 0) + 80 >> 2] | 0) != 0 : 0) ? (CP(c[(c[(c[f >> 2] | 0) + 32 >> 2] | 0) + 80 >> 2] | 0, c[(c[f >> 2] | 0) + 40 >> 2] | 0) | 0) != 0 : 0)break;
	                            d = zy(c[(c[f >> 2] | 0) + 40 >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                            c[(c[f >> 2] | 0) + 40 >> 2] = d;
	                            i = e;
	                            return
	                        } while (0);
	                        d = Ay(c[(c[f >> 2] | 0) + 40 >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                        c[(c[f >> 2] | 0) + 40 >> 2] = d;
	                        c[(c[f >> 2] | 0) + 44 >> 2] = 0;
	                        c[(c[f >> 2] | 0) + 48 >> 2] = 0;
	                        i = e;
	                        return
	                    }
	                    case 1:
	                    case 11:
	                    {
	                        c[j >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                        c[k >> 2] = ni(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                        if (!(c[k >> 2] | 0)) {
	                            i = e;
	                            return
	                        }
	                        c[l >> 2] = zi(c[f >> 2] | 0, c[k >> 2] | 0) | 0;
	                        if (!((c[j >> 2] | 0) != 0 ? (c[l >> 2] | 0) == (c[k >> 2] | 0) : 0)) {
	                            i = e;
	                            return
	                        }
	                        if ((c[(c[j >> 2] | 0) + 24 >> 2] | 0) != (c[k >> 2] | 0)) {
	                            i = e;
	                            return
	                        }
	                        aj(c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                        i = e;
	                        return
	                    }
	                    default:
	                    {
	                        i = e;
	                        return
	                    }
	                }
	            }

	            function aj(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                b = c[g >> 2] | 0;
	                do if (c[f >> 2] | 0) {
	                    a = c[f >> 2] | 0;
	                    if (!b) {
	                        c[e >> 2] = a;
	                        break
	                    }
	                    if ((c[a + 4 >> 2] | 0) != 3) {
	                        c[e >> 2] = c[f >> 2];
	                        break
	                    }
	                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 3) {
	                        c[e >> 2] = c[f >> 2];
	                        break
	                    }
	                    a = c[f >> 2] | 0;
	                    if ((c[(c[g >> 2] | 0) + 8 >> 2] | 0) != (c[(c[f >> 2] | 0) + 8 >> 2] | 0)) {
	                        c[e >> 2] = a;
	                        break
	                    } else {
	                        ui(a, c[(c[g >> 2] | 0) + 40 >> 2] | 0);
	                        Qh(c[g >> 2] | 0);
	                        Rh(c[g >> 2] | 0);
	                        c[e >> 2] = c[f >> 2];
	                        break
	                    }
	                } else c[e >> 2] = b; while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function bj(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 28 | 0;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                l = d;
	                c[d + 24 >> 2] = a;
	                c[f >> 2] = b;
	                c[h >> 2] = 0;
	                c[j >> 2] = 0;
	                c[k >> 2] = 10;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                    a:while (1) {
	                        if (!(c[f >> 2] | 0)) {
	                            m = 24;
	                            break
	                        }
	                        b:do if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                            c[g >> 2] = c[(c[f >> 2] | 0) + 48 >> 2];
	                            while (1) {
	                                if (!(c[g >> 2] | 0))break b;
	                                if (!(c[h >> 2] | 0)) {
	                                    c[h >> 2] = Cb[c[135744 >> 2] & 511]((c[k >> 2] | 0) + 1 << 2) | 0;
	                                    if (!(c[h >> 2] | 0)) {
	                                        m = 10;
	                                        break a
	                                    }
	                                    c[(c[h >> 2] | 0) + (c[j >> 2] << 2) >> 2] = 0
	                                }
	                                c[l >> 2] = 0;
	                                while (1) {
	                                    if ((c[l >> 2] | 0) >= (c[j >> 2] | 0))break;
	                                    if ((c[(c[g >> 2] | 0) + 12 >> 2] | 0) == (c[(c[(c[h >> 2] | 0) + (c[l >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0))break;
	                                    if (qy(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[h >> 2] | 0) + (c[l >> 2] << 2) >> 2] | 0) + 12 >> 2] | 0) | 0)break;
	                                    c[l >> 2] = (c[l >> 2] | 0) + 1
	                                }
	                                if ((c[l >> 2] | 0) >= (c[j >> 2] | 0)) {
	                                    if ((c[j >> 2] | 0) >= (c[k >> 2] | 0) ? (c[k >> 2] = c[k >> 2] << 1, c[h >> 2] = Hb[c[135760 >> 2] & 511](c[h >> 2] | 0, (c[k >> 2] | 0) + 1 << 2) | 0, (c[h >> 2] | 0) == 0) : 0) {
	                                        m = 20;
	                                        break a
	                                    }
	                                    b = c[g >> 2] | 0;
	                                    a = c[j >> 2] | 0;
	                                    c[j >> 2] = a + 1;
	                                    c[(c[h >> 2] | 0) + (a << 2) >> 2] = b;
	                                    c[(c[h >> 2] | 0) + (c[j >> 2] << 2) >> 2] = 0
	                                }
	                                c[g >> 2] = c[c[g >> 2] >> 2]
	                            }
	                        } while (0);
	                        c[f >> 2] = c[(c[f >> 2] | 0) + 20 >> 2]
	                    }
	                    if ((m | 0) == 10) {
	                        tj(75736);
	                        c[e >> 2] = 0;
	                        n = c[e >> 2] | 0;
	                        i = d;
	                        return n | 0
	                    } else if ((m | 0) == 20) {
	                        tj(75736);
	                        c[e >> 2] = 0;
	                        n = c[e >> 2] | 0;
	                        i = d;
	                        return n | 0
	                    } else if ((m | 0) == 24) {
	                        c[e >> 2] = c[h >> 2];
	                        n = c[e >> 2] | 0;
	                        i = d;
	                        return n | 0
	                    }
	                }
	                c[e >> 2] = 0;
	                n = c[e >> 2] | 0;
	                i = d;
	                return n | 0
	            }

	            function cj(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[l >> 2] = c[h >> 2];
	                if ((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                    if ((c[j >> 2] | 0) != 0 ? (qy(c[j >> 2] | 0, 75168) | 0) != 0 : 0) {
	                        if ((c[g >> 2] | 0) == 0 ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) {
	                            c[k >> 2] = Cb[c[135744 >> 2] & 511](24) | 0;
	                            if (!(c[k >> 2] | 0)) {
	                                tj(75760);
	                                c[f >> 2] = 0;
	                                m = c[f >> 2] | 0;
	                                i = e;
	                                return m | 0
	                            } else {
	                                d = c[k >> 2] | 0;
	                                c[d + 0 >> 2] = 0;
	                                c[d + 4 >> 2] = 0;
	                                c[d + 8 >> 2] = 0;
	                                c[d + 12 >> 2] = 0;
	                                c[d + 16 >> 2] = 0;
	                                c[d + 20 >> 2] = 0;
	                                c[(c[k >> 2] | 0) + 4 >> 2] = 18;
	                                d = my(75176) | 0;
	                                c[(c[k >> 2] | 0) + 8 >> 2] = d;
	                                d = my(75168) | 0;
	                                c[(c[k >> 2] | 0) + 12 >> 2] = d;
	                                c[c[k >> 2] >> 2] = c[(c[h >> 2] | 0) + 48 >> 2];
	                                c[(c[h >> 2] | 0) + 48 >> 2] = c[k >> 2];
	                                c[f >> 2] = c[k >> 2];
	                                m = c[f >> 2] | 0;
	                                i = e;
	                                return m | 0
	                            }
	                        }
	                        if ((c[g >> 2] | 0) == 0 ? (c[g >> 2] = c[(c[h >> 2] | 0) + 32 >> 2], (c[g >> 2] | 0) == 0) : 0) {
	                            c[f >> 2] = 0;
	                            m = c[f >> 2] | 0;
	                            i = e;
	                            return m | 0
	                        }
	                        d = c[g >> 2] | 0;
	                        if (!(c[(c[g >> 2] | 0) + 52 >> 2] | 0)) {
	                            c[f >> 2] = Ej(d) | 0;
	                            m = c[f >> 2] | 0;
	                            i = e;
	                            return m | 0
	                        } else {
	                            c[f >> 2] = c[d + 52 >> 2];
	                            m = c[f >> 2] | 0;
	                            i = e;
	                            return m | 0
	                        }
	                    }
	                    a:while (1) {
	                        if (!(c[h >> 2] | 0)) {
	                            n = 43;
	                            break
	                        }
	                        if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 5) {
	                            n = 21;
	                            break
	                        }
	                        if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 6) {
	                            n = 21;
	                            break
	                        }
	                        if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 17) {
	                            n = 21;
	                            break
	                        }
	                        if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                            c[k >> 2] = c[(c[h >> 2] | 0) + 48 >> 2];
	                            while (1) {
	                                if (!(c[k >> 2] | 0))break;
	                                if (((c[j >> 2] | 0) == 0 ? (c[(c[k >> 2] | 0) + 12 >> 2] | 0) == 0 : 0) ? (c[(c[k >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                                    n = 27;
	                                    break a
	                                }
	                                if ((((c[j >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[(c[k >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (qy(c[(c[k >> 2] | 0) + 12 >> 2] | 0, c[j >> 2] | 0) | 0) != 0 : 0) {
	                                    n = 31;
	                                    break a
	                                }
	                                c[k >> 2] = c[c[k >> 2] >> 2]
	                            }
	                            if ((c[l >> 2] | 0) != (c[h >> 2] | 0) ? (c[k >> 2] = c[(c[h >> 2] | 0) + 36 >> 2], (c[k >> 2] | 0) != 0) : 0) {
	                                if (((c[j >> 2] | 0) == 0 ? (c[(c[k >> 2] | 0) + 12 >> 2] | 0) == 0 : 0) ? (c[(c[k >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                                    n = 37;
	                                    break
	                                }
	                                if ((((c[j >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[(c[k >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (qy(c[(c[k >> 2] | 0) + 12 >> 2] | 0, c[j >> 2] | 0) | 0) != 0 : 0) {
	                                    n = 41;
	                                    break
	                                }
	                            }
	                        }
	                        c[h >> 2] = c[(c[h >> 2] | 0) + 20 >> 2]
	                    }
	                    if ((n | 0) == 21) {
	                        c[f >> 2] = 0;
	                        m = c[f >> 2] | 0;
	                        i = e;
	                        return m | 0
	                    } else if ((n | 0) == 27) {
	                        c[f >> 2] = c[k >> 2];
	                        m = c[f >> 2] | 0;
	                        i = e;
	                        return m | 0
	                    } else if ((n | 0) == 31) {
	                        c[f >> 2] = c[k >> 2];
	                        m = c[f >> 2] | 0;
	                        i = e;
	                        return m | 0
	                    } else if ((n | 0) == 37) {
	                        c[f >> 2] = c[k >> 2];
	                        m = c[f >> 2] | 0;
	                        i = e;
	                        return m | 0
	                    } else if ((n | 0) == 41) {
	                        c[f >> 2] = c[k >> 2];
	                        m = c[f >> 2] | 0;
	                        i = e;
	                        return m | 0
	                    } else if ((n | 0) == 43) {
	                        c[f >> 2] = 0;
	                        m = c[f >> 2] | 0;
	                        i = e;
	                        return m | 0
	                    }
	                }
	                c[f >> 2] = 0;
	                m = c[f >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function dj(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) != 0 ? !((c[g >> 2] | 0) == 0 ? 1 : (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 1) : 0) {
	                    c[h >> 2] = c[(c[f >> 2] | 0) + 44 >> 2];
	                    while (1) {
	                        if (!(c[h >> 2] | 0))break;
	                        b = (qy(c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[g >> 2] | 0) | 0) != 0;
	                        l = c[h >> 2] | 0;
	                        if (b) {
	                            m = 7;
	                            break
	                        }
	                        c[h >> 2] = c[l + 24 >> 2]
	                    }
	                    if ((m | 0) == 7) {
	                        c[e >> 2] = l;
	                        n = c[e >> 2] | 0;
	                        i = d;
	                        return n | 0
	                    }
	                    if (!(c[18946] | 0)) {
	                        c[e >> 2] = 0;
	                        n = c[e >> 2] | 0;
	                        i = d;
	                        return n | 0
	                    }
	                    c[j >> 2] = c[(c[f >> 2] | 0) + 32 >> 2];
	                    if ((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 44 >> 2] | 0) != 0 : 0) {
	                        c[k >> 2] = Fm(c[(c[j >> 2] | 0) + 44 >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0, c[g >> 2] | 0) | 0;
	                        if ((c[k >> 2] | 0) == 0 ? (c[(c[j >> 2] | 0) + 48 >> 2] | 0) != 0 : 0)c[k >> 2] = Fm(c[(c[j >> 2] | 0) + 48 >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0, c[g >> 2] | 0) | 0;
	                        if ((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 48 >> 2] | 0) != 0 : 0) {
	                            c[e >> 2] = c[k >> 2];
	                            n = c[e >> 2] | 0;
	                            i = d;
	                            return n | 0
	                        }
	                    }
	                    c[e >> 2] = 0;
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                c[e >> 2] = 0;
	                n = c[e >> 2] | 0;
	                i = d;
	                return n | 0
	            }

	            function ej(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = xj(c[f >> 2] | 0, c[g >> 2] | 0, 0, c[18946] | 0) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } else {
	                    c[e >> 2] = Gj(c[h >> 2] | 0) | 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                return 0
	            }

	            function fj(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = xj(c[f >> 2] | 0, c[g >> 2] | 0, 0, 0) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } else {
	                    Qh(c[h >> 2] | 0);
	                    ei(c[h >> 2] | 0);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                return 0
	            }

	            function gj(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 28 | 0;
	                g = e + 24 | 0;
	                h = e + 20 | 0;
	                j = e + 16 | 0;
	                k = e + 12 | 0;
	                l = e + 8 | 0;
	                m = e + 4 | 0;
	                n = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (!((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) {
	                    c[l >> 2] = Dh(c[h >> 2] | 0, k) | 0;
	                    if (c[l >> 2] | 0) {
	                        c[n >> 2] = ly(c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                        c[m >> 2] = cj(c[(c[g >> 2] | 0) + 32 >> 2] | 0, c[g >> 2] | 0, c[n >> 2] | 0) | 0;
	                        if (c[n >> 2] | 0)zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                        if (c[m >> 2] | 0) {
	                            c[f >> 2] = Si(c[g >> 2] | 0, c[m >> 2] | 0, c[l >> 2] | 0, c[j >> 2] | 0) | 0;
	                            o = c[f >> 2] | 0;
	                            i = e;
	                            return o | 0
	                        }
	                    }
	                    c[f >> 2] = Si(c[g >> 2] | 0, 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                c[f >> 2] = 0;
	                o = c[f >> 2] | 0;
	                i = e;
	                return o | 0
	            }

	            function hj(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                do if (c[e >> 2] | 0)if ((c[(c[e >> 2] | 0) + 4 >> 2] | 0) == 3) {
	                    c[d >> 2] = 1;
	                    break
	                } else {
	                    c[d >> 2] = 0;
	                    break
	                } else c[d >> 2] = 0; while (0);
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function ij(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[f >> 2] = a;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 3 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 4 : 0) {
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                if (!(c[(c[f >> 2] | 0) + 40 >> 2] | 0)) {
	                    c[e >> 2] = 1;
	                    h = c[e >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                c[g >> 2] = c[(c[f >> 2] | 0) + 40 >> 2];
	                a:while (1) {
	                    if (!(d[c[g >> 2] >> 0] | 0)) {
	                        j = 16;
	                        break
	                    }
	                    do if ((d[c[g >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[g >> 2] >> 0] | 0 | 0) ? (d[c[g >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[g >> 2] >> 0] | 0 | 0) != 13) {
	                            j = 14;
	                            break a
	                        }
	                    } while (0);
	                    c[g >> 2] = (c[g >> 2] | 0) + 1
	                }
	                if ((j | 0) == 14) {
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = b;
	                    return h | 0
	                } else if ((j | 0) == 16) {
	                    c[e >> 2] = 1;
	                    h = c[e >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                return 0
	            }

	            function jj(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = -1;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                if ((((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 3 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 4 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 8 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 7 : 0) {
	                    c[f >> 2] = -1;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                do if ((c[(c[g >> 2] | 0) + 40 >> 2] | 0) == ((c[g >> 2] | 0) + 44 | 0))l = 12; else {
	                    if (((c[(c[g >> 2] | 0) + 32 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 32 >> 2] | 0) + 80 >> 2] | 0) != 0 : 0) ? (CP(c[(c[(c[g >> 2] | 0) + 32 >> 2] | 0) + 80 >> 2] | 0, c[(c[g >> 2] | 0) + 40 >> 2] | 0) | 0) != 0 : 0) {
	                        l = 12;
	                        break
	                    }
	                    d = zy(c[(c[g >> 2] | 0) + 40 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                    c[(c[g >> 2] | 0) + 40 >> 2] = d
	                } while (0);
	                if ((l | 0) == 12) {
	                    l = Ay(c[(c[g >> 2] | 0) + 40 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                    c[(c[g >> 2] | 0) + 40 >> 2] = l
	                }
	                c[(c[g >> 2] | 0) + 44 >> 2] = 0;
	                if (!(c[(c[g >> 2] | 0) + 40 >> 2] | 0)) {
	                    c[f >> 2] = -1;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                } else {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                return 0
	            }

	            function kj() {
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = Cb[c[135744 >> 2] & 511](20) | 0;
	                if (!(c[e >> 2] | 0)) {
	                    tj(75808);
	                    c[d >> 2] = 0;
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                }
	                c[(c[e >> 2] | 0) + 4 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 8 >> 2] = c[33950];
	                c[(c[e >> 2] | 0) + 12 >> 2] = c[33948];
	                g = Cb[c[135752 >> 2] & 511](c[(c[e >> 2] | 0) + 8 >> 2] | 0) | 0;
	                c[c[e >> 2] >> 2] = g;
	                if (!(c[c[e >> 2] >> 2] | 0)) {
	                    tj(75808);
	                    zb[c[135736 >> 2] & 511](c[e >> 2] | 0);
	                    c[d >> 2] = 0;
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                } else {
	                    a[c[c[e >> 2] >> 2] >> 0] = 0;
	                    c[(c[e >> 2] | 0) + 16 >> 2] = 0;
	                    c[d >> 2] = c[e >> 2];
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                }
	                return 0
	            }

	            function lj(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if ((c[(c[d >> 2] | 0) + 12 >> 2] | 0) == 3 ? (c[(c[d >> 2] | 0) + 16 >> 2] | 0) != 0 : 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 16 >> 2] | 0); else e = 5;
	                if (((e | 0) == 5 ? (c[c[d >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[d >> 2] | 0) + 12 >> 2] | 0) != 2 : 0)zb[c[135736 >> 2] & 511](c[c[d >> 2] >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function mj(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[k >> 2] = 0;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                if ((c[(c[g >> 2] | 0) + 12 >> 2] | 0) == 2) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                if ((c[h >> 2] | 0) >>> 0 < (c[(c[g >> 2] | 0) + 8 >> 2] | 0) >>> 0) {
	                    c[f >> 2] = 1;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                d = c[(c[g >> 2] | 0) + 12 >> 2] | 0;
	                a:do if ((d | 0) == 4) {
	                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) >>> 0 < 4096) {
	                        c[j >> 2] = c[h >> 2];
	                        break
	                    }
	                    c[j >> 2] = c[(c[g >> 2] | 0) + 8 >> 2] << 1;
	                    while (1) {
	                        if ((c[h >> 2] | 0) >>> 0 <= (c[j >> 2] | 0) >>> 0)break a;
	                        if ((c[j >> 2] | 0) >>> 0 > 2147483647)break;
	                        c[j >> 2] = c[j >> 2] << 1
	                    }
	                    tj(75824);
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                } else if ((d | 0) == 1)c[j >> 2] = (c[h >> 2] | 0) + 10; else if ((d | 0) == 0 | (d | 0) == 3) {
	                    if (c[(c[g >> 2] | 0) + 8 >> 2] | 0)n = c[(c[g >> 2] | 0) + 8 >> 2] << 1; else n = (c[h >> 2] | 0) + 10 | 0;
	                    c[j >> 2] = n;
	                    while (1) {
	                        if ((c[h >> 2] | 0) >>> 0 <= (c[j >> 2] | 0) >>> 0)break a;
	                        if ((c[j >> 2] | 0) >>> 0 > 2147483647)break;
	                        c[j >> 2] = c[j >> 2] << 1
	                    }
	                    tj(75824);
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                } else c[j >> 2] = (c[h >> 2] | 0) + 10; while (0);
	                do if ((c[(c[g >> 2] | 0) + 12 >> 2] | 0) == 3 ? (c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 : 0) {
	                    c[l >> 2] = (c[c[g >> 2] >> 2] | 0) - (c[(c[g >> 2] | 0) + 16 >> 2] | 0);
	                    if ((c[l >> 2] | 0) >>> 0 > (c[j >> 2] | 0) >>> 0) {
	                        fU(c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[c[g >> 2] >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] | 0) | 0;
	                        c[c[g >> 2] >> 2] = c[(c[g >> 2] | 0) + 16 >> 2];
	                        a[(c[c[g >> 2] >> 2] | 0) + (c[(c[g >> 2] | 0) + 4 >> 2] | 0) >> 0] = 0;
	                        h = (c[g >> 2] | 0) + 8 | 0;
	                        c[h >> 2] = (c[h >> 2] | 0) + (c[l >> 2] | 0);
	                        break
	                    }
	                    c[k >> 2] = Hb[c[135760 >> 2] & 511](c[(c[g >> 2] | 0) + 16 >> 2] | 0, (c[l >> 2] | 0) + (c[j >> 2] | 0) | 0) | 0;
	                    if (c[k >> 2] | 0) {
	                        c[(c[g >> 2] | 0) + 16 >> 2] = c[k >> 2];
	                        c[c[g >> 2] >> 2] = (c[k >> 2] | 0) + (c[l >> 2] | 0);
	                        break
	                    }
	                    tj(75824);
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                } else o = 32; while (0);
	                do if ((o | 0) == 32) {
	                    do if (c[c[g >> 2] >> 2] | 0) {
	                        if (((c[(c[g >> 2] | 0) + 8 >> 2] | 0) - (c[(c[g >> 2] | 0) + 4 >> 2] | 0) | 0) >>> 0 < 100) {
	                            c[k >> 2] = Hb[c[135760 >> 2] & 511](c[c[g >> 2] >> 2] | 0, c[j >> 2] | 0) | 0;
	                            break
	                        }
	                        c[k >> 2] = Cb[c[135752 >> 2] & 511](c[j >> 2] | 0) | 0;
	                        if (c[k >> 2] | 0) {
	                            eU(c[k >> 2] | 0, c[c[g >> 2] >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] | 0) | 0;
	                            zb[c[135736 >> 2] & 511](c[c[g >> 2] >> 2] | 0);
	                            a[(c[k >> 2] | 0) + (c[(c[g >> 2] | 0) + 4 >> 2] | 0) >> 0] = 0
	                        }
	                    } else c[k >> 2] = Cb[c[135752 >> 2] & 511](c[j >> 2] | 0) | 0; while (0);
	                    if (c[k >> 2] | 0) {
	                        c[c[g >> 2] >> 2] = c[k >> 2];
	                        break
	                    }
	                    tj(75824);
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                } while (0);
	                c[(c[g >> 2] | 0) + 8 >> 2] = c[j >> 2];
	                c[f >> 2] = 1;
	                m = c[f >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function nj(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                do if ((c[j >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0)c[g >> 2] = -1; else {
	                    if ((c[(c[h >> 2] | 0) + 12 >> 2] | 0) == 2) {
	                        c[g >> 2] = -1;
	                        break
	                    }
	                    if ((c[k >> 2] | 0) < -1) {
	                        c[g >> 2] = -1;
	                        break
	                    }
	                    if (!(c[k >> 2] | 0)) {
	                        c[g >> 2] = 0;
	                        break
	                    }
	                    if ((c[k >> 2] | 0) < 0)c[k >> 2] = xy(c[j >> 2] | 0) | 0;
	                    if ((c[k >> 2] | 0) < 0) {
	                        c[g >> 2] = -1;
	                        break
	                    }
	                    if (!(c[k >> 2] | 0)) {
	                        c[g >> 2] = 0;
	                        break
	                    }
	                    c[l >> 2] = (c[(c[h >> 2] | 0) + 4 >> 2] | 0) + (c[k >> 2] | 0) + 2;
	                    if ((c[l >> 2] | 0) >>> 0 > (c[(c[h >> 2] | 0) + 8 >> 2] | 0) >>> 0 ? (mj(c[h >> 2] | 0, c[l >> 2] | 0) | 0) == 0 : 0) {
	                        tj(75824);
	                        c[g >> 2] = 2;
	                        break
	                    }
	                    fU((c[c[h >> 2] >> 2] | 0) + (c[(c[h >> 2] | 0) + 4 >> 2] | 0) | 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                    e = (c[h >> 2] | 0) + 4 | 0;
	                    c[e >> 2] = (c[e >> 2] | 0) + (c[k >> 2] | 0);
	                    a[(c[c[h >> 2] >> 2] | 0) + (c[(c[h >> 2] | 0) + 4 >> 2] | 0) >> 0] = 0;
	                    c[g >> 2] = 0
	                } while (0);
	                i = f;
	                return c[g >> 2] | 0
	            }

	            function oj(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                do if (c[f >> 2] | 0) {
	                    if ((c[(c[f >> 2] | 0) + 12 >> 2] | 0) == 2) {
	                        c[e >> 2] = -1;
	                        break
	                    }
	                    if (!(c[g >> 2] | 0)) {
	                        c[e >> 2] = -1;
	                        break
	                    } else {
	                        c[e >> 2] = nj(c[f >> 2] | 0, c[g >> 2] | 0, -1) | 0;
	                        break
	                    }
	                } else c[e >> 2] = -1; while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function pj(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = -1;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                if ((c[(c[g >> 2] | 0) + 12 >> 2] | 0) == 2) {
	                    c[f >> 2] = -1;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = -1;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                c[j >> 2] = c[h >> 2];
	                while (1) {
	                    l = c[(c[g >> 2] | 0) + 4 >> 2] | 0;
	                    if (!(a[c[j >> 2] >> 0] | 0)) {
	                        m = 13;
	                        break
	                    }
	                    if ((l + 10 | 0) >>> 0 >= (c[(c[g >> 2] | 0) + 8 >> 2] | 0) >>> 0 ? (mj(c[g >> 2] | 0, (c[(c[g >> 2] | 0) + 4 >> 2] | 0) + 10 | 0) | 0) == 0 : 0) {
	                        m = 11;
	                        break
	                    }
	                    h = a[c[j >> 2] >> 0] | 0;
	                    d = (c[g >> 2] | 0) + 4 | 0;
	                    b = c[d >> 2] | 0;
	                    c[d >> 2] = b + 1;
	                    a[(c[c[g >> 2] >> 2] | 0) + b >> 0] = h;
	                    c[j >> 2] = (c[j >> 2] | 0) + 1
	                }
	                if ((m | 0) == 11) {
	                    tj(75824);
	                    c[f >> 2] = 2;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                } else if ((m | 0) == 13) {
	                    a[(c[c[g >> 2] >> 2] | 0) + l >> 0] = 0;
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                return 0
	            }

	            function qj(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if ((c[(c[e >> 2] | 0) + 12 >> 2] | 0) == 2) {
	                    i = d;
	                    return
	                }
	                oj(c[e >> 2] | 0, c[f >> 2] | 0) | 0;
	                i = d;
	                return
	            }

	            function rj(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if ((c[(c[e >> 2] | 0) + 12 >> 2] | 0) == 2) {
	                    i = d;
	                    return
	                }
	                pj(c[e >> 2] | 0, c[f >> 2] | 0) | 0;
	                i = d;
	                return
	            }

	            function sj(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                if ((c[(c[f >> 2] | 0) + 12 >> 2] | 0) == 2) {
	                    i = e;
	                    return
	                }
	                if (!(vy(c[g >> 2] | 0, 34) | 0)) {
	                    pj(c[f >> 2] | 0, 75840) | 0;
	                    oj(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                    pj(c[f >> 2] | 0, 75840) | 0;
	                    i = e;
	                    return
	                }
	                b = (vy(c[g >> 2] | 0, 39) | 0) != 0;
	                a = c[f >> 2] | 0;
	                if (!b) {
	                    pj(a, 75856) | 0;
	                    oj(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                    pj(c[f >> 2] | 0, 75856) | 0;
	                    i = e;
	                    return
	                }
	                pj(a, 75840) | 0;
	                a = c[g >> 2] | 0;
	                c[h >> 2] = a;
	                c[j >> 2] = a;
	                while (1) {
	                    if (!(d[c[h >> 2] >> 0] | 0))break;
	                    if ((d[c[h >> 2] >> 0] | 0 | 0) != 34) {
	                        c[h >> 2] = (c[h >> 2] | 0) + 1;
	                        continue
	                    }
	                    if ((c[j >> 2] | 0) != (c[h >> 2] | 0))nj(c[f >> 2] | 0, c[j >> 2] | 0, (c[h >> 2] | 0) - (c[j >> 2] | 0) | 0) | 0;
	                    nj(c[f >> 2] | 0, 75848, 6) | 0;
	                    c[h >> 2] = (c[h >> 2] | 0) + 1;
	                    c[j >> 2] = c[h >> 2]
	                }
	                if ((c[j >> 2] | 0) != (c[h >> 2] | 0))nj(c[f >> 2] | 0, c[j >> 2] | 0, (c[h >> 2] | 0) - (c[j >> 2] | 0) | 0) | 0;
	                pj(c[f >> 2] | 0, 75840) | 0;
	                i = e;
	                return
	            }

	            function tj(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                ce(2, 2, 0, 0, c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function uj(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = 0;
	                d = c[f >> 2] | 0;
	                if ((d | 0) == 1302)c[j >> 2] = 76032; else if ((d | 0) == 1300)c[j >> 2] = 75952; else if ((d | 0) == 1301)c[j >> 2] = 75992; else if ((d | 0) == 1303)c[j >> 2] = 76072; else c[j >> 2] = 76096;
	                ce(2, c[f >> 2] | 0, c[g >> 2] | 0, c[j >> 2] | 0, c[h >> 2] | 0);
	                i = e;
	                return
	            }

	            function vj(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                do if (((c[h >> 2] | 0) != 0 ? !((c[j >> 2] | 0) == 0 ? 1 : (c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 2) : 0) ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) == 2 : 0) {
	                    if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 2 : 0)break;
	                    d = c[(c[h >> 2] | 0) + 20 >> 2] | 0;
	                    b = c[(c[j >> 2] | 0) + 8 >> 2] | 0;
	                    if (!(c[(c[j >> 2] | 0) + 36 >> 2] | 0))c[k >> 2] = Ai(d, b, 0) | 0; else c[k >> 2] = Ai(d, b, c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) | 0;
	                    if ((c[(c[j >> 2] | 0) + 32 >> 2] | 0) != (c[(c[h >> 2] | 0) + 32 >> 2] | 0))ri(c[j >> 2] | 0, c[(c[h >> 2] | 0) + 32 >> 2] | 0);
	                    c[(c[j >> 2] | 0) + 20 >> 2] = c[(c[h >> 2] | 0) + 20 >> 2];
	                    c[(c[j >> 2] | 0) + 28 >> 2] = c[g >> 2];
	                    if (c[g >> 2] | 0) {
	                        c[(c[j >> 2] | 0) + 24 >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                        c[(c[g >> 2] | 0) + 24 >> 2] = c[j >> 2];
	                        if (c[(c[j >> 2] | 0) + 24 >> 2] | 0)c[(c[(c[j >> 2] | 0) + 24 >> 2] | 0) + 28 >> 2] = c[j >> 2]
	                    } else {
	                        c[(c[j >> 2] | 0) + 24 >> 2] = c[h >> 2];
	                        c[(c[h >> 2] | 0) + 28 >> 2] = c[j >> 2]
	                    }
	                    if ((c[(c[j >> 2] | 0) + 28 >> 2] | 0) == 0 ? (c[(c[j >> 2] | 0) + 20 >> 2] | 0) != 0 : 0)c[(c[(c[j >> 2] | 0) + 20 >> 2] | 0) + 44 >> 2] = c[j >> 2];
	                    if ((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 4 >> 2] | 0) != 16 : 0)fi(c[k >> 2] | 0) | 0;
	                    c[f >> 2] = c[j >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } while (0);
	                c[f >> 2] = 0;
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function wj(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                g = i;
	                i = i + 48 | 0;
	                h = g + 36 | 0;
	                j = g + 32 | 0;
	                k = g + 28 | 0;
	                l = g + 24 | 0;
	                m = g + 20 | 0;
	                n = g + 16 | 0;
	                o = g + 12 | 0;
	                p = g + 8 | 0;
	                q = g + 4 | 0;
	                r = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[p >> 2] = 0;
	                if ((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 1 : 0) {
	                    do if ((c[n >> 2] | 0) == 1) {
	                        if ((c[(c[j >> 2] | 0) + 32 >> 2] | 0) != 0 ? (CP(c[(c[(c[j >> 2] | 0) + 32 >> 2] | 0) + 80 >> 2] | 0, c[l >> 2] | 0) | 0) != 0 : 0)break;
	                        zb[c[135736 >> 2] & 511](c[l >> 2] | 0)
	                    } while (0);
	                    c[h >> 2] = 0;
	                    s = c[h >> 2] | 0;
	                    i = g;
	                    return s | 0
	                }
	                c[o >> 2] = Cb[c[135744 >> 2] & 511](48) | 0;
	                if (!(c[o >> 2] | 0)) {
	                    do if ((c[n >> 2] | 0) == 1) {
	                        if (((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 32 >> 2] | 0) != 0 : 0) ? (CP(c[(c[(c[j >> 2] | 0) + 32 >> 2] | 0) + 80 >> 2] | 0, c[l >> 2] | 0) | 0) != 0 : 0)break;
	                        zb[c[135736 >> 2] & 511](c[l >> 2] | 0)
	                    } while (0);
	                    tj(75320);
	                    c[h >> 2] = 0;
	                    s = c[h >> 2] | 0;
	                    i = g;
	                    return s | 0
	                }
	                f = (c[o >> 2] | 0) + 0 | 0;
	                e = f + 48 | 0;
	                do {
	                    c[f >> 2] = 0;
	                    f = f + 4 | 0
	                } while ((f | 0) < (e | 0));
	                c[(c[o >> 2] | 0) + 4 >> 2] = 2;
	                c[(c[o >> 2] | 0) + 20 >> 2] = c[j >> 2];
	                if (c[j >> 2] | 0) {
	                    c[p >> 2] = c[(c[j >> 2] | 0) + 32 >> 2];
	                    c[(c[o >> 2] | 0) + 32 >> 2] = c[p >> 2]
	                }
	                c[(c[o >> 2] | 0) + 36 >> 2] = c[k >> 2];
	                do if (!(c[n >> 2] | 0)) {
	                    if ((c[p >> 2] | 0) != 0 ? (c[(c[p >> 2] | 0) + 80 >> 2] | 0) != 0 : 0) {
	                        k = AP(c[(c[p >> 2] | 0) + 80 >> 2] | 0, c[l >> 2] | 0, -1) | 0;
	                        c[(c[o >> 2] | 0) + 8 >> 2] = k;
	                        break
	                    }
	                    k = my(c[l >> 2] | 0) | 0;
	                    c[(c[o >> 2] | 0) + 8 >> 2] = k
	                } else c[(c[o >> 2] | 0) + 8 >> 2] = c[l >> 2]; while (0);
	                a:do if (c[m >> 2] | 0) {
	                    if ((Fy(c[m >> 2] | 0) | 0) == 0 ? (uj(1303, c[p >> 2] | 0, 0), (c[p >> 2] | 0) != 0) : 0) {
	                        l = my(75792) | 0;
	                        c[(c[p >> 2] | 0) + 60 >> 2] = l
	                    }
	                    l = Wh(c[p >> 2] | 0, c[m >> 2] | 0) | 0;
	                    c[(c[o >> 2] | 0) + 12 >> 2] = l;
	                    c[(c[o >> 2] | 0) + 16 >> 2] = 0;
	                    c[q >> 2] = c[(c[o >> 2] | 0) + 12 >> 2];
	                    while (1) {
	                        if (!(c[q >> 2] | 0))break a;
	                        c[(c[q >> 2] | 0) + 20 >> 2] = c[o >> 2];
	                        if (!(c[(c[q >> 2] | 0) + 24 >> 2] | 0))c[(c[o >> 2] | 0) + 16 >> 2] = c[q >> 2];
	                        c[q >> 2] = c[(c[q >> 2] | 0) + 24 >> 2]
	                    }
	                } while (0);
	                do if (c[j >> 2] | 0) {
	                    if (!(c[(c[j >> 2] | 0) + 44 >> 2] | 0)) {
	                        c[(c[j >> 2] | 0) + 44 >> 2] = c[o >> 2];
	                        break
	                    }
	                    c[r >> 2] = c[(c[j >> 2] | 0) + 44 >> 2];
	                    while (1) {
	                        if (!(c[(c[r >> 2] | 0) + 24 >> 2] | 0))break;
	                        c[r >> 2] = c[(c[r >> 2] | 0) + 24 >> 2]
	                    }
	                    c[(c[r >> 2] | 0) + 24 >> 2] = c[o >> 2];
	                    c[(c[o >> 2] | 0) + 28 >> 2] = c[r >> 2]
	                } while (0);
	                if ((c[m >> 2] | 0) != 0 & (c[j >> 2] | 0) != 0 ? (Em(c[(c[j >> 2] | 0) + 32 >> 2] | 0, c[j >> 2] | 0, c[o >> 2] | 0) | 0) == 1 : 0)Cm(0, c[(c[j >> 2] | 0) + 32 >> 2] | 0, c[m >> 2] | 0, c[o >> 2] | 0) | 0;
	                if ((c[18774] | 0) != 0 & (c[33968] | 0) != 0)zb[c[135872 >> 2] & 511](c[o >> 2] | 0);
	                c[h >> 2] = c[o >> 2];
	                s = c[h >> 2] | 0;
	                i = g;
	                return s | 0
	            }

	            function xj(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f + 44 | 0;
	                h = f + 40 | 0;
	                j = f + 36 | 0;
	                k = f + 32 | 0;
	                l = f + 28 | 0;
	                m = f + 24 | 0;
	                n = f + 20 | 0;
	                o = f + 16 | 0;
	                p = f + 12 | 0;
	                q = f + 8 | 0;
	                r = f + 4 | 0;
	                s = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if ((c[h >> 2] | 0) != 0 ? !((c[j >> 2] | 0) == 0 ? 1 : (c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 1) : 0) {
	                    a:do if (c[(c[h >> 2] | 0) + 44 >> 2] | 0) {
	                        c[m >> 2] = c[(c[h >> 2] | 0) + 44 >> 2];
	                        if (!(c[k >> 2] | 0)) {
	                            while (1) {
	                                if ((c[(c[m >> 2] | 0) + 36 >> 2] | 0) == 0 ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, c[j >> 2] | 0) | 0) != 0 : 0)break;
	                                c[m >> 2] = c[(c[m >> 2] | 0) + 24 >> 2];
	                                if (!(c[m >> 2] | 0))break a
	                            }
	                            c[g >> 2] = c[m >> 2];
	                            t = c[g >> 2] | 0;
	                            i = f;
	                            return t | 0
	                        }
	                        while (1) {
	                            if ((c[(c[m >> 2] | 0) + 36 >> 2] | 0) != 0 ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, c[j >> 2] | 0) | 0) != 0 : 0) {
	                                if ((c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) == (c[k >> 2] | 0))break;
	                                if (qy(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[k >> 2] | 0) | 0)break
	                            }
	                            c[m >> 2] = c[(c[m >> 2] | 0) + 24 >> 2];
	                            if (!(c[m >> 2] | 0))break a
	                        }
	                        c[g >> 2] = c[m >> 2];
	                        t = c[g >> 2] | 0;
	                        i = f;
	                        return t | 0
	                    } while (0);
	                    if (!(c[l >> 2] | 0)) {
	                        c[g >> 2] = 0;
	                        t = c[g >> 2] | 0;
	                        i = f;
	                        return t | 0
	                    }
	                    if ((c[(c[h >> 2] | 0) + 32 >> 2] | 0) != 0 ? (c[(c[(c[h >> 2] | 0) + 32 >> 2] | 0) + 44 >> 2] | 0) != 0 : 0) {
	                        c[n >> 2] = c[(c[h >> 2] | 0) + 32 >> 2];
	                        c[o >> 2] = 0;
	                        c[q >> 2] = 0;
	                        do if ((c[(c[h >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                            c[q >> 2] = my(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0;
	                            c[q >> 2] = By(c[q >> 2] | 0, 75864) | 0;
	                            c[q >> 2] = By(c[q >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0) | 0;
	                            if (c[q >> 2] | 0) {
	                                c[p >> 2] = c[q >> 2];
	                                break
	                            }
	                            c[g >> 2] = 0;
	                            t = c[g >> 2] | 0;
	                            i = f;
	                            return t | 0
	                        } else u = 25; while (0);
	                        if ((u | 0) == 25)c[p >> 2] = c[(c[h >> 2] | 0) + 8 >> 2];
	                        if (!(c[k >> 2] | 0)) {
	                            c[o >> 2] = Nm(c[(c[n >> 2] | 0) + 44 >> 2] | 0, c[p >> 2] | 0, c[j >> 2] | 0, 0) | 0;
	                            if ((c[o >> 2] | 0) == 0 ? (c[(c[n >> 2] | 0) + 48 >> 2] | 0) != 0 : 0)c[o >> 2] = Nm(c[(c[n >> 2] | 0) + 48 >> 2] | 0, c[p >> 2] | 0, c[j >> 2] | 0, 0) | 0
	                        } else {
	                            c[r >> 2] = bj(c[(c[h >> 2] | 0) + 32 >> 2] | 0, c[h >> 2] | 0) | 0;
	                            if (!(c[r >> 2] | 0)) {
	                                if (c[q >> 2] | 0)zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                                c[g >> 2] = 0;
	                                t = c[g >> 2] | 0;
	                                i = f;
	                                return t | 0
	                            }
	                            c[s >> 2] = c[r >> 2];
	                            while (1) {
	                                if (!(c[c[s >> 2] >> 2] | 0))break;
	                                if (qy(c[(c[c[s >> 2] >> 2] | 0) + 8 >> 2] | 0, c[k >> 2] | 0) | 0) {
	                                    c[o >> 2] = Nm(c[(c[n >> 2] | 0) + 44 >> 2] | 0, c[p >> 2] | 0, c[j >> 2] | 0, c[(c[c[s >> 2] >> 2] | 0) + 12 >> 2] | 0) | 0;
	                                    if (c[o >> 2] | 0)break;
	                                    if ((c[(c[n >> 2] | 0) + 48 >> 2] | 0) != 0 ? (c[o >> 2] = Nm(c[(c[n >> 2] | 0) + 48 >> 2] | 0, c[p >> 2] | 0, c[j >> 2] | 0, c[(c[c[s >> 2] >> 2] | 0) + 12 >> 2] | 0) | 0, (c[o >> 2] | 0) != 0) : 0)break
	                                }
	                                c[s >> 2] = (c[s >> 2] | 0) + 4
	                            }
	                            zb[c[135736 >> 2] & 511](c[r >> 2] | 0)
	                        }
	                        if (c[q >> 2] | 0)zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                        if ((c[o >> 2] | 0) != 0 ? (c[(c[o >> 2] | 0) + 48 >> 2] | 0) != 0 : 0) {
	                            c[g >> 2] = c[o >> 2];
	                            t = c[g >> 2] | 0;
	                            i = f;
	                            return t | 0
	                        }
	                    }
	                    c[g >> 2] = 0;
	                    t = c[g >> 2] | 0;
	                    i = f;
	                    return t | 0
	                }
	                c[g >> 2] = 0;
	                t = c[g >> 2] | 0;
	                i = f;
	                return t | 0
	            }

	            function yj(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 36 | 0;
	                g = e + 32 | 0;
	                h = e + 28 | 0;
	                j = e + 24 | 0;
	                k = e + 20 | 0;
	                l = e + 16 | 0;
	                m = e + 12 | 0;
	                n = e + 8 | 0;
	                o = e + 4 | 0;
	                p = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (!(c[j >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    q = c[f >> 2] | 0;
	                    i = e;
	                    return q | 0
	                }
	                if ((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 1 : 0) {
	                    c[f >> 2] = 0;
	                    q = c[f >> 2] | 0;
	                    i = e;
	                    return q | 0
	                }
	                do if (!(c[h >> 2] | 0)) {
	                    if (c[g >> 2] | 0) {
	                        c[k >> 2] = ci(c[g >> 2] | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0, 0) | 0;
	                        break
	                    }
	                    d = c[j >> 2] | 0;
	                    if (c[(c[j >> 2] | 0) + 20 >> 2] | 0) {
	                        c[k >> 2] = ci(c[(c[d + 20 >> 2] | 0) + 32 >> 2] | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0, 0) | 0;
	                        break
	                    }
	                    b = c[j >> 2] | 0;
	                    if (c[d + 12 >> 2] | 0) {
	                        c[k >> 2] = ci(c[(c[b + 12 >> 2] | 0) + 32 >> 2] | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0, 0) | 0;
	                        break
	                    } else {
	                        c[k >> 2] = ci(0, c[b + 8 >> 2] | 0, 0) | 0;
	                        break
	                    }
	                } else c[k >> 2] = ci(c[(c[h >> 2] | 0) + 32 >> 2] | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0, 0) | 0; while (0);
	                if (!(c[k >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    q = c[f >> 2] | 0;
	                    i = e;
	                    return q | 0
	                }
	                c[(c[k >> 2] | 0) + 20 >> 2] = c[h >> 2];
	                do if ((c[h >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) {
	                    c[l >> 2] = cj(c[(c[h >> 2] | 0) + 32 >> 2] | 0, c[h >> 2] | 0, c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0;
	                    if (c[l >> 2] | 0)if (qy(c[(c[l >> 2] | 0) + 8 >> 2] | 0, c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) | 0) {
	                        c[(c[k >> 2] | 0) + 36 >> 2] = c[l >> 2];
	                        break
	                    } else {
	                        g = Hj(c[(c[h >> 2] | 0) + 32 >> 2] | 0, c[h >> 2] | 0, c[(c[j >> 2] | 0) + 36 >> 2] | 0) | 0;
	                        c[(c[k >> 2] | 0) + 36 >> 2] = g;
	                        break
	                    }
	                    c[l >> 2] = cj(c[(c[j >> 2] | 0) + 32 >> 2] | 0, c[(c[j >> 2] | 0) + 20 >> 2] | 0, c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0;
	                    if (c[l >> 2] | 0) {
	                        c[m >> 2] = c[h >> 2];
	                        c[n >> 2] = 0;
	                        while (1) {
	                            r = c[m >> 2] | 0;
	                            if (!(c[(c[m >> 2] | 0) + 20 >> 2] | 0))break;
	                            c[n >> 2] = r;
	                            c[m >> 2] = c[(c[m >> 2] | 0) + 20 >> 2]
	                        }
	                        if ((r | 0) == (c[(c[h >> 2] | 0) + 32 >> 2] | 0))c[m >> 2] = c[n >> 2];
	                        g = Ih(c[m >> 2] | 0, c[(c[l >> 2] | 0) + 8 >> 2] | 0, c[(c[l >> 2] | 0) + 12 >> 2] | 0) | 0;
	                        c[(c[k >> 2] | 0) + 36 >> 2] = g
	                    }
	                } else c[(c[k >> 2] | 0) + 36 >> 2] = 0; while (0);
	                a:do if (c[(c[j >> 2] | 0) + 12 >> 2] | 0) {
	                    l = Aj(c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[(c[k >> 2] | 0) + 32 >> 2] | 0, c[k >> 2] | 0) | 0;
	                    c[(c[k >> 2] | 0) + 12 >> 2] = l;
	                    c[(c[k >> 2] | 0) + 16 >> 2] = 0;
	                    c[o >> 2] = c[(c[k >> 2] | 0) + 12 >> 2];
	                    while (1) {
	                        if (!(c[o >> 2] | 0))break a;
	                        if (!(c[(c[o >> 2] | 0) + 24 >> 2] | 0))c[(c[k >> 2] | 0) + 16 >> 2] = c[o >> 2];
	                        c[o >> 2] = c[(c[o >> 2] | 0) + 24 >> 2]
	                    }
	                } while (0);
	                if (((((((c[h >> 2] | 0) != 0 & (c[j >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 32 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 32 >> 2] | 0) != 0 : 0) ? (c[(c[(c[j >> 2] | 0) + 32 >> 2] | 0) + 64 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) ? (Em(c[(c[j >> 2] | 0) + 32 >> 2] | 0, c[(c[j >> 2] | 0) + 20 >> 2] | 0, c[j >> 2] | 0) | 0) != 0 : 0) ? (c[p >> 2] = _h(c[(c[j >> 2] | 0) + 32 >> 2] | 0, c[(c[j >> 2] | 0) + 12 >> 2] | 0, 1) | 0, (c[p >> 2] | 0) != 0) : 0) {
	                    Cm(0, c[(c[h >> 2] | 0) + 32 >> 2] | 0, c[p >> 2] | 0, c[k >> 2] | 0) | 0;
	                    zb[c[135736 >> 2] & 511](c[p >> 2] | 0)
	                }
	                c[f >> 2] = c[k >> 2];
	                q = c[f >> 2] | 0;
	                i = e;
	                return q | 0
	            }

	            function zj(a, d, e, f) {
	                a = a | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                g = i;
	                i = i + 48 | 0;
	                h = g + 36 | 0;
	                j = g + 32 | 0;
	                k = g + 28 | 0;
	                l = g + 24 | 0;
	                m = g + 20 | 0;
	                n = g + 16 | 0;
	                o = g + 12 | 0;
	                p = g + 8 | 0;
	                q = g + 4 | 0;
	                r = g;
	                c[j >> 2] = a;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                if (!(c[j >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    s = c[h >> 2] | 0;
	                    i = g;
	                    return s | 0
	                }
	                switch (c[(c[j >> 2] | 0) + 4 >> 2] | 0) {
	                    case 18:
	                    {
	                        c[h >> 2] = Ei(c[j >> 2] | 0) | 0;
	                        s = c[h >> 2] | 0;
	                        i = g;
	                        return s | 0
	                    }
	                    case 10:
	                    case 12:
	                    case 14:
	                    case 15:
	                    case 16:
	                    case 17:
	                    {
	                        c[h >> 2] = 0;
	                        s = c[h >> 2] | 0;
	                        i = g;
	                        return s | 0
	                    }
	                    case 2:
	                    {
	                        c[h >> 2] = yj(c[k >> 2] | 0, c[l >> 2] | 0, c[j >> 2] | 0) | 0;
	                        s = c[h >> 2] | 0;
	                        i = g;
	                        return s | 0
	                    }
	                    case 9:
	                    case 13:
	                    case 21:
	                    {
	                        c[h >> 2] = Mi(c[j >> 2] | 0, c[m >> 2] | 0) | 0;
	                        s = c[h >> 2] | 0;
	                        i = g;
	                        return s | 0
	                    }
	                    default:
	                    {
	                        c[n >> 2] = Cb[c[135744 >> 2] & 511](60) | 0;
	                        if (!(c[n >> 2] | 0)) {
	                            tj(75936);
	                            c[h >> 2] = 0;
	                            s = c[h >> 2] | 0;
	                            i = g;
	                            return s | 0
	                        }
	                        f = (c[n >> 2] | 0) + 0 | 0;
	                        e = f + 60 | 0;
	                        do {
	                            c[f >> 2] = 0;
	                            f = f + 4 | 0
	                        } while ((f | 0) < (e | 0));
	                        c[(c[n >> 2] | 0) + 4 >> 2] = c[(c[j >> 2] | 0) + 4 >> 2];
	                        c[(c[n >> 2] | 0) + 32 >> 2] = c[k >> 2];
	                        c[(c[n >> 2] | 0) + 20 >> 2] = c[l >> 2];
	                        do if ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) != 75104) {
	                            if ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) == 75112) {
	                                c[(c[n >> 2] | 0) + 8 >> 2] = 75112;
	                                break
	                            }
	                            if ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) == 75128) {
	                                c[(c[n >> 2] | 0) + 8 >> 2] = 75128;
	                                break
	                            }
	                            if (c[(c[j >> 2] | 0) + 8 >> 2] | 0) {
	                                if ((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 80 >> 2] | 0) != 0 : 0) {
	                                    f = AP(c[(c[k >> 2] | 0) + 80 >> 2] | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0, -1) | 0;
	                                    c[(c[n >> 2] | 0) + 8 >> 2] = f;
	                                    break
	                                }
	                                f = my(c[(c[j >> 2] | 0) + 8 >> 2] | 0) | 0;
	                                c[(c[n >> 2] | 0) + 8 >> 2] = f
	                            }
	                        } else c[(c[n >> 2] | 0) + 8 >> 2] = 75104; while (0);
	                        if (((((c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[j >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 5 : 0) ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 20 : 0) ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 19 : 0) {
	                            f = my(c[(c[j >> 2] | 0) + 40 >> 2] | 0) | 0;
	                            c[(c[n >> 2] | 0) + 40 >> 2] = f
	                        } else t = 27;
	                        if ((t | 0) == 27 ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) == 1 : 0)b[(c[n >> 2] | 0) + 56 >> 1] = b[(c[j >> 2] | 0) + 56 >> 1] | 0;
	                        if (c[l >> 2] | 0) {
	                            if ((c[18774] | 0) != 0 & (c[33968] | 0) != 0)zb[c[135872 >> 2] & 511](c[n >> 2] | 0);
	                            c[o >> 2] = zi(c[l >> 2] | 0, c[n >> 2] | 0) | 0;
	                            if ((c[o >> 2] | 0) != (c[n >> 2] | 0)) {
	                                c[h >> 2] = c[o >> 2];
	                                s = c[h >> 2] | 0;
	                                i = g;
	                                return s | 0
	                            }
	                        }
	                        do if (c[m >> 2] | 0) {
	                            if (!((c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 19 : 0))t = 37;
	                            if ((t | 0) == 37 ? (c[(c[j >> 2] | 0) + 48 >> 2] | 0) != 0 : 0) {
	                                o = Ei(c[(c[j >> 2] | 0) + 48 >> 2] | 0) | 0;
	                                c[(c[n >> 2] | 0) + 48 >> 2] = o
	                            }
	                            do if (c[(c[j >> 2] | 0) + 36 >> 2] | 0) {
	                                c[p >> 2] = cj(c[k >> 2] | 0, c[n >> 2] | 0, c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0;
	                                if (c[p >> 2] | 0) {
	                                    c[(c[n >> 2] | 0) + 36 >> 2] = c[p >> 2];
	                                    break
	                                }
	                                c[p >> 2] = cj(c[(c[j >> 2] | 0) + 32 >> 2] | 0, c[j >> 2] | 0, c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0;
	                                if (!(c[p >> 2] | 0)) {
	                                    o = Hj(c[k >> 2] | 0, c[n >> 2] | 0, c[(c[j >> 2] | 0) + 36 >> 2] | 0) | 0;
	                                    c[(c[n >> 2] | 0) + 36 >> 2] = o;
	                                    break
	                                }
	                                c[q >> 2] = c[n >> 2];
	                                while (1) {
	                                    u = c[q >> 2] | 0;
	                                    if (!(c[(c[q >> 2] | 0) + 20 >> 2] | 0))break;
	                                    c[q >> 2] = c[u + 20 >> 2]
	                                }
	                                o = Ih(u, c[(c[p >> 2] | 0) + 8 >> 2] | 0, c[(c[p >> 2] | 0) + 12 >> 2] | 0) | 0;
	                                c[(c[n >> 2] | 0) + 36 >> 2] = o
	                            } while (0);
	                            if (!((c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 19 : 0))t = 50;
	                            if ((t | 0) == 50 ? (c[(c[j >> 2] | 0) + 44 >> 2] | 0) != 0 : 0) {
	                                o = Gi(c[n >> 2] | 0, c[(c[j >> 2] | 0) + 44 >> 2] | 0) | 0;
	                                c[(c[n >> 2] | 0) + 44 >> 2] = o
	                            }
	                            if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) == 5) {
	                                if ((c[k >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 32 >> 2] | 0) == (c[k >> 2] | 0) : 0)c[(c[n >> 2] | 0) + 12 >> 2] = c[(c[j >> 2] | 0) + 12 >> 2]; else {
	                                    o = ad(c[k >> 2] | 0, c[(c[n >> 2] | 0) + 8 >> 2] | 0) | 0;
	                                    c[(c[n >> 2] | 0) + 12 >> 2] = o
	                                }
	                                c[(c[n >> 2] | 0) + 16 >> 2] = c[(c[n >> 2] | 0) + 12 >> 2];
	                                break
	                            }
	                            if (((c[m >> 2] | 0) != 2 ? (c[(c[j >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (o = Aj(c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[k >> 2] | 0, c[n >> 2] | 0) | 0, c[(c[n >> 2] | 0) + 12 >> 2] = o, (c[n >> 2] | 0) != 0) : 0) {
	                                c[r >> 2] = c[(c[n >> 2] | 0) + 12 >> 2];
	                                if (!(c[r >> 2] | 0)) {
	                                    c[(c[n >> 2] | 0) + 16 >> 2] = 0;
	                                    break
	                                }
	                                while (1) {
	                                    o = (c[(c[r >> 2] | 0) + 24 >> 2] | 0) != 0;
	                                    c[(c[r >> 2] | 0) + 20 >> 2] = c[n >> 2];
	                                    v = c[r >> 2] | 0;
	                                    if (!o)break;
	                                    c[r >> 2] = c[v + 24 >> 2]
	                                }
	                                c[(c[n >> 2] | 0) + 16 >> 2] = v
	                            }
	                        } while (0);
	                        if ((c[l >> 2] | 0) == 0 & (c[18774] | 0) != 0 & (c[33968] | 0) != 0)zb[c[135872 >> 2] & 511](c[n >> 2] | 0);
	                        c[h >> 2] = c[n >> 2];
	                        s = c[h >> 2] | 0;
	                        i = g;
	                        return s | 0
	                    }
	                }
	                return 0
	            }

	            function Aj(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 20 | 0;
	                h = e + 16 | 0;
	                j = e + 12 | 0;
	                k = e + 8 | 0;
	                l = e + 4 | 0;
	                m = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 0;
	                c[l >> 2] = 0;
	                a:while (1) {
	                    if (!(c[g >> 2] | 0)) {
	                        n = 19;
	                        break
	                    }
	                    do if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 14) {
	                        if (!(c[h >> 2] | 0)) {
	                            c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                            continue a
	                        }
	                        if (c[(c[h >> 2] | 0) + 44 >> 2] | 0) {
	                            c[m >> 2] = c[(c[h >> 2] | 0) + 44 >> 2];
	                            zi(c[j >> 2] | 0, c[m >> 2] | 0) | 0;
	                            break
	                        }
	                        c[m >> 2] = Li(c[g >> 2] | 0) | 0;
	                        if (!(c[m >> 2] | 0)) {
	                            n = 8;
	                            break a
	                        }
	                        c[(c[m >> 2] | 0) + 32 >> 2] = c[h >> 2];
	                        c[(c[m >> 2] | 0) + 20 >> 2] = c[j >> 2];
	                        c[(c[h >> 2] | 0) + 44 >> 2] = c[m >> 2];
	                        zi(c[j >> 2] | 0, c[m >> 2] | 0) | 0
	                    } else c[m >> 2] = zj(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, 1) | 0; while (0);
	                    if (!(c[m >> 2] | 0)) {
	                        n = 13;
	                        break
	                    }
	                    if (c[k >> 2] | 0) {
	                        if ((c[l >> 2] | 0) != (c[m >> 2] | 0)) {
	                            c[(c[l >> 2] | 0) + 24 >> 2] = c[m >> 2];
	                            c[(c[m >> 2] | 0) + 28 >> 2] = c[l >> 2];
	                            c[l >> 2] = c[m >> 2]
	                        }
	                    } else {
	                        c[(c[m >> 2] | 0) + 28 >> 2] = 0;
	                        d = c[m >> 2] | 0;
	                        c[l >> 2] = d;
	                        c[k >> 2] = d
	                    }
	                    c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2]
	                }
	                if ((n | 0) == 8) {
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                } else if ((n | 0) == 13) {
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                } else if ((n | 0) == 19) {
	                    c[f >> 2] = c[k >> 2];
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                return 0
	            }

	            function Bj(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 48 >> 2] | 0) != 0 : 0) {
	                    c[h >> 2] = c[(c[f >> 2] | 0) + 48 >> 2];
	                    c[e >> 2] = Rj(c[h >> 2] | 0, c[g >> 2] | 0) | 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[e >> 2] = 0;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function Cj(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 60 >> 2] | 0) != 0 : 0) {
	                    c[h >> 2] = c[(c[f >> 2] | 0) + 60 >> 2];
	                    c[e >> 2] = Rj(c[h >> 2] | 0, c[g >> 2] | 0) | 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[e >> 2] = 0;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function Dj(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = -1;
	                if ((c[h >> 2] | 0) >= 5) {
	                    c[f >> 2] = -1;
	                    k = c[f >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = c[j >> 2];
	                    k = c[f >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                a:do if ((((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 3 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 8 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 7 : 0) {
	                    do if (c[(c[g >> 2] | 0) + 28 >> 2] | 0) {
	                        if ((((c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 4 >> 2] | 0) != 3 : 0) ? (c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 4 >> 2] | 0) != 8 : 0) ? (c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 4 >> 2] | 0) != 7 : 0)break;
	                        c[j >> 2] = Dj(c[(c[g >> 2] | 0) + 28 >> 2] | 0, (c[h >> 2] | 0) + 1 | 0) | 0;
	                        break a
	                    } while (0);
	                    if ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 4 >> 2] | 0) == 1 : 0)c[j >> 2] = Dj(c[(c[g >> 2] | 0) + 20 >> 2] | 0, (c[h >> 2] | 0) + 1 | 0) | 0
	                } else l = 9; while (0);
	                if ((l | 0) == 9) {
	                    do if ((e[(c[g >> 2] | 0) + 56 >> 1] | 0 | 0) == 65535) {
	                        if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 3 ? (c[(c[g >> 2] | 0) + 52 >> 2] | 0) != 0 : 0) {
	                            c[j >> 2] = c[(c[g >> 2] | 0) + 52 >> 2];
	                            break
	                        }
	                        if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 ? (c[(c[g >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                            c[j >> 2] = Dj(c[(c[g >> 2] | 0) + 12 >> 2] | 0, (c[h >> 2] | 0) + 1 | 0) | 0;
	                            break
	                        }
	                        l = c[g >> 2] | 0;
	                        if (c[(c[g >> 2] | 0) + 24 >> 2] | 0) {
	                            c[j >> 2] = Dj(c[l + 24 >> 2] | 0, (c[h >> 2] | 0) + 1 | 0) | 0;
	                            break
	                        }
	                        if (c[l + 28 >> 2] | 0)c[j >> 2] = Dj(c[(c[g >> 2] | 0) + 28 >> 2] | 0, (c[h >> 2] | 0) + 1 | 0) | 0
	                    } while (0);
	                    if ((c[j >> 2] | 0) == -1 | (c[j >> 2] | 0) == 65535)c[j >> 2] = e[(c[g >> 2] | 0) + 56 >> 1]
	                }
	                c[f >> 2] = c[j >> 2];
	                k = c[f >> 2] | 0;
	                i = d;
	                return k | 0
	            }

	            function Ej(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                if (c[(c[e >> 2] | 0) + 52 >> 2] | 0) {
	                    c[d >> 2] = c[(c[e >> 2] | 0) + 52 >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](24) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    tj(75904);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    a = c[f >> 2] | 0;
	                    c[a + 0 >> 2] = 0;
	                    c[a + 4 >> 2] = 0;
	                    c[a + 8 >> 2] = 0;
	                    c[a + 12 >> 2] = 0;
	                    c[a + 16 >> 2] = 0;
	                    c[a + 20 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 4 >> 2] = 18;
	                    a = my(75176) | 0;
	                    c[(c[f >> 2] | 0) + 8 >> 2] = a;
	                    a = my(75168) | 0;
	                    c[(c[f >> 2] | 0) + 12 >> 2] = a;
	                    c[(c[e >> 2] | 0) + 52 >> 2] = c[f >> 2];
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function Fj(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[f + 16 >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                a:while (1) {
	                    if (c[h >> 2] | 0)m = (c[h >> 2] | 0) != (c[j >> 2] | 0); else m = 0;
	                    n = c[h >> 2] | 0;
	                    if (!m) {
	                        o = 19;
	                        break
	                    }
	                    if ((c[n + 4 >> 2] | 0) == 5) {
	                        o = 8;
	                        break
	                    }
	                    if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 6) {
	                        o = 8;
	                        break
	                    }
	                    if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 17) {
	                        o = 8;
	                        break
	                    }
	                    b:do if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                        c[l >> 2] = c[(c[h >> 2] | 0) + 48 >> 2];
	                        while (1) {
	                            if (!(c[l >> 2] | 0))break b;
	                            if ((c[k >> 2] | 0) == 0 ? (c[(c[l >> 2] | 0) + 12 >> 2] | 0) == 0 : 0) {
	                                o = 13;
	                                break a
	                            }
	                            if (((c[k >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (qy(c[(c[l >> 2] | 0) + 12 >> 2] | 0, c[k >> 2] | 0) | 0) != 0 : 0) {
	                                o = 16;
	                                break a
	                            }
	                            c[l >> 2] = c[c[l >> 2] >> 2]
	                        }
	                    } while (0);
	                    c[h >> 2] = c[(c[h >> 2] | 0) + 20 >> 2]
	                }
	                if ((o | 0) == 8) {
	                    c[g >> 2] = -1;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                } else if ((o | 0) == 13) {
	                    c[g >> 2] = 0;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                } else if ((o | 0) == 16) {
	                    c[g >> 2] = 0;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                } else if ((o | 0) == 19)if ((n | 0) != (c[j >> 2] | 0)) {
	                    c[g >> 2] = -1;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                } else {
	                    c[g >> 2] = 1;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                return 0
	            }

	            function Gj(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = c[e >> 2] | 0;
	                if ((c[(c[e >> 2] | 0) + 4 >> 2] | 0) != 2)if ((c[a + 4 >> 2] | 0) == 16) {
	                    c[d >> 2] = my(c[(c[e >> 2] | 0) + 48 >> 2] | 0) | 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                if (c[a + 12 >> 2] | 0) {
	                    do if (!(c[(c[(c[e >> 2] | 0) + 12 >> 2] | 0) + 24 >> 2] | 0)) {
	                        if ((c[(c[(c[e >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) != 3 ? (c[(c[(c[e >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) != 4 : 0)break;
	                        c[d >> 2] = my(c[(c[(c[e >> 2] | 0) + 12 >> 2] | 0) + 40 >> 2] | 0) | 0;
	                        g = c[d >> 2] | 0;
	                        i = b;
	                        return g | 0
	                    } while (0);
	                    c[f >> 2] = _h(c[(c[e >> 2] | 0) + 32 >> 2] | 0, c[(c[e >> 2] | 0) + 12 >> 2] | 0, 1) | 0;
	                    if (c[f >> 2] | 0) {
	                        c[d >> 2] = c[f >> 2];
	                        g = c[d >> 2] | 0;
	                        i = b;
	                        return g | 0
	                    }
	                }
	                c[d >> 2] = my(75312) | 0;
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function Hj(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                e = i;
	                i = i + 96 | 0;
	                f = e;
	                g = e + 28 | 0;
	                h = e + 24 | 0;
	                j = e + 20 | 0;
	                k = e + 16 | 0;
	                l = e + 12 | 0;
	                m = e + 32 | 0;
	                n = e + 8 | 0;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[n >> 2] = 1;
	                if ((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) {
	                    if ((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 18 : 0) {
	                        c[l >> 2] = Ri(c[h >> 2] | 0, c[j >> 2] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        if (c[l >> 2] | 0) {
	                            c[g >> 2] = c[l >> 2];
	                            o = c[g >> 2] | 0;
	                            i = e;
	                            return o | 0
	                        }
	                        if (!(c[(c[k >> 2] | 0) + 12 >> 2] | 0))JT(m, 50, 75656, f) | 0; else {
	                            c[f >> 2] = c[(c[k >> 2] | 0) + 12 >> 2];
	                            JT(m, 50, 75872, f) | 0
	                        }
	                        c[l >> 2] = cj(c[h >> 2] | 0, c[j >> 2] | 0, m) | 0;
	                        while (1) {
	                            if (!(c[l >> 2] | 0)) {
	                                p = 20;
	                                break
	                            }
	                            if ((c[n >> 2] | 0) > 1e3) {
	                                p = 15;
	                                break
	                            }
	                            if (!(c[(c[k >> 2] | 0) + 12 >> 2] | 0)) {
	                                d = c[n >> 2] | 0;
	                                c[n >> 2] = d + 1;
	                                c[f >> 2] = d;
	                                JT(m, 50, 75880, f) | 0
	                            } else {
	                                d = c[(c[k >> 2] | 0) + 12 >> 2] | 0;
	                                b = c[n >> 2] | 0;
	                                c[n >> 2] = b + 1;
	                                c[f >> 2] = d;
	                                c[f + 4 >> 2] = b;
	                                JT(m, 50, 75896, f) | 0
	                            }
	                            c[l >> 2] = cj(c[h >> 2] | 0, c[j >> 2] | 0, m) | 0
	                        }
	                        if ((p | 0) == 15) {
	                            c[g >> 2] = 0;
	                            o = c[g >> 2] | 0;
	                            i = e;
	                            return o | 0
	                        } else if ((p | 0) == 20) {
	                            c[l >> 2] = Ih(c[j >> 2] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0, m) | 0;
	                            c[g >> 2] = c[l >> 2];
	                            o = c[g >> 2] | 0;
	                            i = e;
	                            return o | 0
	                        }
	                    }
	                    c[g >> 2] = 0;
	                    o = c[g >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                c[g >> 2] = 0;
	                o = c[g >> 2] | 0;
	                i = e;
	                return o | 0
	            }

	            function Ij(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[e >> 2] = (c[e >> 2] | 0) <= 0 ? 256 : a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](20) | 0;
	                do if (c[f >> 2] | 0) {
	                    c[(c[f >> 2] | 0) + 12 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 4 >> 2] = c[e >> 2];
	                    c[(c[f >> 2] | 0) + 8 >> 2] = 0;
	                    a = Cb[c[135744 >> 2] & 511]((c[e >> 2] | 0) * 24 | 0) | 0;
	                    c[c[f >> 2] >> 2] = a;
	                    if (!(c[c[f >> 2] >> 2] | 0)) {
	                        zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                        break
	                    }
	                    cU(c[c[f >> 2] >> 2] | 0, 0, (c[e >> 2] | 0) * 24 | 0) | 0;
	                    a = vP() | 0;
	                    c[(c[f >> 2] | 0) + 16 >> 2] = a;
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } while (0);
	                c[d >> 2] = 0;
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function Jj(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[g >> 2] = Ij(c[e >> 2] | 0) | 0;
	                if (!(c[g >> 2] | 0)) {
	                    h = c[g >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                c[(c[g >> 2] | 0) + 12 >> 2] = c[f >> 2];
	                yP(c[f >> 2] | 0) | 0;
	                h = c[g >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function Kj(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 24 | 0;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                l = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[k >> 2] = 0;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if (c[c[e >> 2] >> 2] | 0) {
	                    c[l >> 2] = c[(c[e >> 2] | 0) + 8 >> 2];
	                    c[g >> 2] = 0;
	                    while (1) {
	                        if (!((c[l >> 2] | 0) > 0 ? (c[g >> 2] | 0) < (c[(c[e >> 2] | 0) + 4 >> 2] | 0) : 0))break;
	                        c[h >> 2] = (c[c[e >> 2] >> 2] | 0) + ((c[g >> 2] | 0) * 24 | 0);
	                        a:do if (c[(c[h >> 2] | 0) + 20 >> 2] | 0) {
	                            c[k >> 2] = 1;
	                            while (1) {
	                                if (!(c[h >> 2] | 0))break a;
	                                c[j >> 2] = c[c[h >> 2] >> 2];
	                                if ((c[f >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 16 >> 2] | 0) != 0 : 0)Ab[c[f >> 2] & 511](c[(c[h >> 2] | 0) + 16 >> 2] | 0, c[(c[h >> 2] | 0) + 4 >> 2] | 0);
	                                if (!(c[(c[e >> 2] | 0) + 12 >> 2] | 0)) {
	                                    if (c[(c[h >> 2] | 0) + 4 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[h >> 2] | 0) + 4 >> 2] | 0);
	                                    if (c[(c[h >> 2] | 0) + 8 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[h >> 2] | 0) + 8 >> 2] | 0);
	                                    if (c[(c[h >> 2] | 0) + 12 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[h >> 2] | 0) + 12 >> 2] | 0)
	                                }
	                                c[(c[h >> 2] | 0) + 16 >> 2] = 0;
	                                if (!(c[k >> 2] | 0))zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                                c[l >> 2] = (c[l >> 2] | 0) + -1;
	                                c[k >> 2] = 0;
	                                c[h >> 2] = c[j >> 2]
	                            }
	                        } while (0);
	                        c[g >> 2] = (c[g >> 2] | 0) + 1
	                    }
	                    zb[c[135736 >> 2] & 511](c[c[e >> 2] >> 2] | 0)
	                }
	                if (c[(c[e >> 2] | 0) + 12 >> 2] | 0)zP(c[(c[e >> 2] | 0) + 12 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[e >> 2] | 0);
	                i = d;
	                return
	            }

	            function Lj(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                d = Mj(c[f >> 2] | 0, c[g >> 2] | 0, 0, 0, c[h >> 2] | 0) | 0;
	                i = e;
	                return d | 0
	            }

	            function Mj(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                g = i;
	                i = i + 48 | 0;
	                h = g + 36 | 0;
	                j = g + 32 | 0;
	                k = g + 28 | 0;
	                l = g + 24 | 0;
	                m = g + 20 | 0;
	                n = g + 16 | 0;
	                o = g + 12 | 0;
	                p = g + 8 | 0;
	                q = g + 4 | 0;
	                r = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[p >> 2] = 0;
	                if ((c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0) {
	                    c[h >> 2] = -1;
	                    s = c[h >> 2] | 0;
	                    i = g;
	                    return s | 0
	                }
	                if (c[(c[j >> 2] | 0) + 12 >> 2] | 0) {
	                    if ((CP(c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[k >> 2] | 0) | 0) == 0 ? (c[k >> 2] = AP(c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[k >> 2] | 0, -1) | 0, (c[k >> 2] | 0) == 0) : 0) {
	                        c[h >> 2] = -1;
	                        s = c[h >> 2] | 0;
	                        i = g;
	                        return s | 0
	                    }
	                    if (((c[l >> 2] | 0) != 0 ? (CP(c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[l >> 2] | 0) | 0) == 0 : 0) ? (c[l >> 2] = AP(c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[l >> 2] | 0, -1) | 0, (c[l >> 2] | 0) == 0) : 0) {
	                        c[h >> 2] = -1;
	                        s = c[h >> 2] | 0;
	                        i = g;
	                        return s | 0
	                    }
	                    if (((c[m >> 2] | 0) != 0 ? (CP(c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[m >> 2] | 0) | 0) == 0 : 0) ? (c[m >> 2] = AP(c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[m >> 2] | 0, -1) | 0, (c[m >> 2] | 0) == 0) : 0) {
	                        c[h >> 2] = -1;
	                        s = c[h >> 2] | 0;
	                        i = g;
	                        return s | 0
	                    }
	                }
	                c[o >> 2] = dk(c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0) | 0;
	                do if (c[(c[c[j >> 2] >> 2] | 0) + ((c[o >> 2] | 0) * 24 | 0) + 20 >> 2] | 0) {
	                    f = (c[(c[j >> 2] | 0) + 12 >> 2] | 0) != 0;
	                    c[r >> 2] = (c[c[j >> 2] >> 2] | 0) + ((c[o >> 2] | 0) * 24 | 0);
	                    if (f) {
	                        while (1) {
	                            t = (c[(c[r >> 2] | 0) + 4 >> 2] | 0) == (c[k >> 2] | 0);
	                            if (!(c[c[r >> 2] >> 2] | 0))break;
	                            if ((t ? (c[(c[r >> 2] | 0) + 8 >> 2] | 0) == (c[l >> 2] | 0) : 0) ? (c[(c[r >> 2] | 0) + 12 >> 2] | 0) == (c[m >> 2] | 0) : 0) {
	                                u = 22;
	                                break
	                            }
	                            c[p >> 2] = (c[p >> 2] | 0) + 1;
	                            c[r >> 2] = c[c[r >> 2] >> 2]
	                        }
	                        if ((u | 0) == 22) {
	                            c[h >> 2] = -1;
	                            s = c[h >> 2] | 0;
	                            i = g;
	                            return s | 0
	                        }
	                        if (!t)break;
	                        if ((c[(c[r >> 2] | 0) + 8 >> 2] | 0) != (c[l >> 2] | 0))break;
	                        if ((c[(c[r >> 2] | 0) + 12 >> 2] | 0) != (c[m >> 2] | 0))break;
	                        c[h >> 2] = -1;
	                        s = c[h >> 2] | 0;
	                        i = g;
	                        return s | 0
	                    } else {
	                        while (1) {
	                            f = (c[c[r >> 2] >> 2] | 0) != 0;
	                            v = (qy(c[(c[r >> 2] | 0) + 4 >> 2] | 0, c[k >> 2] | 0) | 0) != 0;
	                            if (!f)break;
	                            if ((v ? (qy(c[(c[r >> 2] | 0) + 8 >> 2] | 0, c[l >> 2] | 0) | 0) != 0 : 0) ? (qy(c[(c[r >> 2] | 0) + 12 >> 2] | 0, c[m >> 2] | 0) | 0) != 0 : 0) {
	                                u = 32;
	                                break
	                            }
	                            c[p >> 2] = (c[p >> 2] | 0) + 1;
	                            c[r >> 2] = c[c[r >> 2] >> 2]
	                        }
	                        if ((u | 0) == 32) {
	                            c[h >> 2] = -1;
	                            s = c[h >> 2] | 0;
	                            i = g;
	                            return s | 0
	                        }
	                        if (!v)break;
	                        if (!(qy(c[(c[r >> 2] | 0) + 8 >> 2] | 0, c[l >> 2] | 0) | 0))break;
	                        if (!(qy(c[(c[r >> 2] | 0) + 12 >> 2] | 0, c[m >> 2] | 0) | 0))break;
	                        c[h >> 2] = -1;
	                        s = c[h >> 2] | 0;
	                        i = g;
	                        return s | 0
	                    }
	                } else c[r >> 2] = 0; while (0);
	                if (c[r >> 2] | 0) {
	                    c[q >> 2] = Cb[c[135744 >> 2] & 511](24) | 0;
	                    if (!(c[q >> 2] | 0)) {
	                        c[h >> 2] = -1;
	                        s = c[h >> 2] | 0;
	                        i = g;
	                        return s | 0
	                    }
	                } else c[q >> 2] = (c[c[j >> 2] >> 2] | 0) + ((c[o >> 2] | 0) * 24 | 0);
	                o = c[k >> 2] | 0;
	                if (c[(c[j >> 2] | 0) + 12 >> 2] | 0) {
	                    c[(c[q >> 2] | 0) + 4 >> 2] = o;
	                    c[(c[q >> 2] | 0) + 8 >> 2] = c[l >> 2];
	                    c[(c[q >> 2] | 0) + 12 >> 2] = c[m >> 2]
	                } else {
	                    k = my(o) | 0;
	                    c[(c[q >> 2] | 0) + 4 >> 2] = k;
	                    k = my(c[l >> 2] | 0) | 0;
	                    c[(c[q >> 2] | 0) + 8 >> 2] = k;
	                    k = my(c[m >> 2] | 0) | 0;
	                    c[(c[q >> 2] | 0) + 12 >> 2] = k
	                }
	                c[(c[q >> 2] | 0) + 16 >> 2] = c[n >> 2];
	                c[c[q >> 2] >> 2] = 0;
	                c[(c[q >> 2] | 0) + 20 >> 2] = 1;
	                if (c[r >> 2] | 0)c[c[r >> 2] >> 2] = c[q >> 2];
	                q = (c[j >> 2] | 0) + 8 | 0;
	                c[q >> 2] = (c[q >> 2] | 0) + 1;
	                if ((c[p >> 2] | 0) >>> 0 > 8)ek(c[j >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] << 3) | 0;
	                c[h >> 2] = 0;
	                s = c[h >> 2] | 0;
	                i = g;
	                return s | 0
	            }

	            function Nj(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 12 | 0;
	                h = f + 8 | 0;
	                j = f + 4 | 0;
	                k = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                e = Mj(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, 0, c[k >> 2] | 0) | 0;
	                i = f;
	                return e | 0
	            }

	            function Oj(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 12 | 0;
	                h = f + 8 | 0;
	                j = f + 4 | 0;
	                k = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                e = Pj(c[g >> 2] | 0, c[h >> 2] | 0, 0, 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                i = f;
	                return e | 0
	            }

	            function Pj(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h + 36 | 0;
	                k = h + 32 | 0;
	                l = h + 28 | 0;
	                m = h + 24 | 0;
	                n = h + 20 | 0;
	                o = h + 16 | 0;
	                p = h + 12 | 0;
	                q = h + 8 | 0;
	                r = h + 4 | 0;
	                s = h;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                if ((c[k >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0) {
	                    c[j >> 2] = -1;
	                    t = c[j >> 2] | 0;
	                    i = h;
	                    return t | 0
	                }
	                if (c[(c[k >> 2] | 0) + 12 >> 2] | 0) {
	                    if ((CP(c[(c[k >> 2] | 0) + 12 >> 2] | 0, c[l >> 2] | 0) | 0) == 0 ? (c[l >> 2] = AP(c[(c[k >> 2] | 0) + 12 >> 2] | 0, c[l >> 2] | 0, -1) | 0, (c[l >> 2] | 0) == 0) : 0) {
	                        c[j >> 2] = -1;
	                        t = c[j >> 2] | 0;
	                        i = h;
	                        return t | 0
	                    }
	                    if (((c[m >> 2] | 0) != 0 ? (CP(c[(c[k >> 2] | 0) + 12 >> 2] | 0, c[m >> 2] | 0) | 0) == 0 : 0) ? (c[m >> 2] = AP(c[(c[k >> 2] | 0) + 12 >> 2] | 0, c[m >> 2] | 0, -1) | 0, (c[m >> 2] | 0) == 0) : 0) {
	                        c[j >> 2] = -1;
	                        t = c[j >> 2] | 0;
	                        i = h;
	                        return t | 0
	                    }
	                    if (((c[n >> 2] | 0) != 0 ? (CP(c[(c[k >> 2] | 0) + 12 >> 2] | 0, c[n >> 2] | 0) | 0) == 0 : 0) ? (c[n >> 2] = AP(c[(c[k >> 2] | 0) + 12 >> 2] | 0, c[n >> 2] | 0, -1) | 0, (c[n >> 2] | 0) == 0) : 0) {
	                        c[j >> 2] = -1;
	                        t = c[j >> 2] | 0;
	                        i = h;
	                        return t | 0
	                    }
	                }
	                c[q >> 2] = dk(c[k >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0) | 0;
	                do if (c[(c[c[k >> 2] >> 2] | 0) + ((c[q >> 2] | 0) * 24 | 0) + 20 >> 2] | 0) {
	                    g = (c[(c[k >> 2] | 0) + 12 >> 2] | 0) != 0;
	                    c[s >> 2] = (c[c[k >> 2] >> 2] | 0) + ((c[q >> 2] | 0) * 24 | 0);
	                    if (g) {
	                        while (1) {
	                            u = (c[(c[s >> 2] | 0) + 4 >> 2] | 0) == (c[l >> 2] | 0);
	                            if (!(c[c[s >> 2] >> 2] | 0))break;
	                            if ((u ? (c[(c[s >> 2] | 0) + 8 >> 2] | 0) == (c[m >> 2] | 0) : 0) ? (c[(c[s >> 2] | 0) + 12 >> 2] | 0) == (c[n >> 2] | 0) : 0) {
	                                v = 22;
	                                break
	                            }
	                            c[s >> 2] = c[c[s >> 2] >> 2]
	                        }
	                        if ((v | 0) == 22) {
	                            if (c[p >> 2] | 0)Ab[c[p >> 2] & 511](c[(c[s >> 2] | 0) + 16 >> 2] | 0, c[(c[s >> 2] | 0) + 4 >> 2] | 0);
	                            c[(c[s >> 2] | 0) + 16 >> 2] = c[o >> 2];
	                            c[j >> 2] = 0;
	                            t = c[j >> 2] | 0;
	                            i = h;
	                            return t | 0
	                        }
	                        if (!u)break;
	                        if ((c[(c[s >> 2] | 0) + 8 >> 2] | 0) != (c[m >> 2] | 0))break;
	                        if ((c[(c[s >> 2] | 0) + 12 >> 2] | 0) != (c[n >> 2] | 0))break;
	                        if (c[p >> 2] | 0)Ab[c[p >> 2] & 511](c[(c[s >> 2] | 0) + 16 >> 2] | 0, c[(c[s >> 2] | 0) + 4 >> 2] | 0);
	                        c[(c[s >> 2] | 0) + 16 >> 2] = c[o >> 2];
	                        c[j >> 2] = 0;
	                        t = c[j >> 2] | 0;
	                        i = h;
	                        return t | 0
	                    } else {
	                        while (1) {
	                            g = (c[c[s >> 2] >> 2] | 0) != 0;
	                            w = (qy(c[(c[s >> 2] | 0) + 4 >> 2] | 0, c[l >> 2] | 0) | 0) != 0;
	                            if (!g)break;
	                            if ((w ? (qy(c[(c[s >> 2] | 0) + 8 >> 2] | 0, c[m >> 2] | 0) | 0) != 0 : 0) ? (qy(c[(c[s >> 2] | 0) + 12 >> 2] | 0, c[n >> 2] | 0) | 0) != 0 : 0) {
	                                v = 36;
	                                break
	                            }
	                            c[s >> 2] = c[c[s >> 2] >> 2]
	                        }
	                        if ((v | 0) == 36) {
	                            if (c[p >> 2] | 0)Ab[c[p >> 2] & 511](c[(c[s >> 2] | 0) + 16 >> 2] | 0, c[(c[s >> 2] | 0) + 4 >> 2] | 0);
	                            c[(c[s >> 2] | 0) + 16 >> 2] = c[o >> 2];
	                            c[j >> 2] = 0;
	                            t = c[j >> 2] | 0;
	                            i = h;
	                            return t | 0
	                        }
	                        if (!w)break;
	                        if (!(qy(c[(c[s >> 2] | 0) + 8 >> 2] | 0, c[m >> 2] | 0) | 0))break;
	                        if (!(qy(c[(c[s >> 2] | 0) + 12 >> 2] | 0, c[n >> 2] | 0) | 0))break;
	                        if (c[p >> 2] | 0)Ab[c[p >> 2] & 511](c[(c[s >> 2] | 0) + 16 >> 2] | 0, c[(c[s >> 2] | 0) + 4 >> 2] | 0);
	                        c[(c[s >> 2] | 0) + 16 >> 2] = c[o >> 2];
	                        c[j >> 2] = 0;
	                        t = c[j >> 2] | 0;
	                        i = h;
	                        return t | 0
	                    }
	                } else c[s >> 2] = 0; while (0);
	                if (c[s >> 2] | 0) {
	                    c[r >> 2] = Cb[c[135744 >> 2] & 511](24) | 0;
	                    if (!(c[r >> 2] | 0)) {
	                        c[j >> 2] = -1;
	                        t = c[j >> 2] | 0;
	                        i = h;
	                        return t | 0
	                    }
	                } else c[r >> 2] = (c[c[k >> 2] >> 2] | 0) + ((c[q >> 2] | 0) * 24 | 0);
	                q = c[l >> 2] | 0;
	                if (c[(c[k >> 2] | 0) + 12 >> 2] | 0) {
	                    c[(c[r >> 2] | 0) + 4 >> 2] = q;
	                    c[(c[r >> 2] | 0) + 8 >> 2] = c[m >> 2];
	                    c[(c[r >> 2] | 0) + 12 >> 2] = c[n >> 2]
	                } else {
	                    l = my(q) | 0;
	                    c[(c[r >> 2] | 0) + 4 >> 2] = l;
	                    l = my(c[m >> 2] | 0) | 0;
	                    c[(c[r >> 2] | 0) + 8 >> 2] = l;
	                    l = my(c[n >> 2] | 0) | 0;
	                    c[(c[r >> 2] | 0) + 12 >> 2] = l
	                }
	                c[(c[r >> 2] | 0) + 16 >> 2] = c[o >> 2];
	                c[c[r >> 2] >> 2] = 0;
	                c[(c[r >> 2] | 0) + 20 >> 2] = 1;
	                o = (c[k >> 2] | 0) + 8 | 0;
	                c[o >> 2] = (c[o >> 2] | 0) + 1;
	                if (c[s >> 2] | 0)c[c[s >> 2] >> 2] = c[r >> 2];
	                c[j >> 2] = 0;
	                t = c[j >> 2] | 0;
	                i = h;
	                return t | 0
	            }

	            function Qj(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 16 | 0;
	                j = g + 12 | 0;
	                k = g + 8 | 0;
	                l = g + 4 | 0;
	                m = g;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                f = Pj(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, 0, c[l >> 2] | 0, c[m >> 2] | 0) | 0;
	                i = g;
	                return f | 0
	            }

	            function Rj(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                b = Sj(c[e >> 2] | 0, c[f >> 2] | 0, 0, 0) | 0;
	                i = d;
	                return b | 0
	            }

	            function Sj(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 24 | 0;
	                h = f + 20 | 0;
	                j = f + 16 | 0;
	                k = f + 12 | 0;
	                l = f + 8 | 0;
	                m = f + 4 | 0;
	                n = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if (!(c[h >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                if (!(c[j >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                c[m >> 2] = dk(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0;
	                if (!(c[(c[c[h >> 2] >> 2] | 0) + ((c[m >> 2] | 0) * 24 | 0) + 20 >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                a:do if (c[(c[h >> 2] | 0) + 12 >> 2] | 0) {
	                    c[n >> 2] = (c[c[h >> 2] >> 2] | 0) + ((c[m >> 2] | 0) * 24 | 0);
	                    while (1) {
	                        if (!(c[n >> 2] | 0))break a;
	                        if (((c[(c[n >> 2] | 0) + 4 >> 2] | 0) == (c[j >> 2] | 0) ? (c[(c[n >> 2] | 0) + 8 >> 2] | 0) == (c[k >> 2] | 0) : 0) ? (c[(c[n >> 2] | 0) + 12 >> 2] | 0) == (c[l >> 2] | 0) : 0)break;
	                        c[n >> 2] = c[c[n >> 2] >> 2]
	                    }
	                    c[g >> 2] = c[(c[n >> 2] | 0) + 16 >> 2];
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                } while (0);
	                c[n >> 2] = (c[c[h >> 2] >> 2] | 0) + ((c[m >> 2] | 0) * 24 | 0);
	                while (1) {
	                    if (!(c[n >> 2] | 0)) {
	                        p = 22;
	                        break
	                    }
	                    if (((qy(c[(c[n >> 2] | 0) + 4 >> 2] | 0, c[j >> 2] | 0) | 0) != 0 ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, c[k >> 2] | 0) | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 12 >> 2] | 0, c[l >> 2] | 0) | 0) != 0 : 0) {
	                        p = 20;
	                        break
	                    }
	                    c[n >> 2] = c[c[n >> 2] >> 2]
	                }
	                if ((p | 0) == 20) {
	                    c[g >> 2] = c[(c[n >> 2] | 0) + 16 >> 2];
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                } else if ((p | 0) == 22) {
	                    c[g >> 2] = 0;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                return 0
	            }

	            function Tj(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                d = Sj(c[f >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0, 0) | 0;
	                i = e;
	                return d | 0
	            }

	            function Uj(a, b, d, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                j = i;
	                i = i + 48 | 0;
	                k = j + 36 | 0;
	                l = j + 32 | 0;
	                m = j + 28 | 0;
	                n = j + 24 | 0;
	                o = j + 20 | 0;
	                p = j + 16 | 0;
	                q = j + 12 | 0;
	                r = j + 8 | 0;
	                s = j + 4 | 0;
	                t = j;
	                c[l >> 2] = a;
	                c[m >> 2] = b;
	                c[n >> 2] = d;
	                c[o >> 2] = e;
	                c[p >> 2] = f;
	                c[q >> 2] = g;
	                c[r >> 2] = h;
	                if (!(c[l >> 2] | 0)) {
	                    c[k >> 2] = 0;
	                    u = c[k >> 2] | 0;
	                    i = j;
	                    return u | 0
	                }
	                if (!(c[n >> 2] | 0)) {
	                    c[k >> 2] = 0;
	                    u = c[k >> 2] | 0;
	                    i = j;
	                    return u | 0
	                }
	                c[s >> 2] = fk(c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0, c[r >> 2] | 0) | 0;
	                if (!(c[(c[c[l >> 2] >> 2] | 0) + ((c[s >> 2] | 0) * 24 | 0) + 20 >> 2] | 0)) {
	                    c[k >> 2] = 0;
	                    u = c[k >> 2] | 0;
	                    i = j;
	                    return u | 0
	                }
	                c[t >> 2] = (c[c[l >> 2] >> 2] | 0) + ((c[s >> 2] | 0) * 24 | 0);
	                while (1) {
	                    if (!(c[t >> 2] | 0)) {
	                        v = 14;
	                        break
	                    }
	                    if (((ry(c[m >> 2] | 0, c[n >> 2] | 0, c[(c[t >> 2] | 0) + 4 >> 2] | 0) | 0) != 0 ? (ry(c[o >> 2] | 0, c[p >> 2] | 0, c[(c[t >> 2] | 0) + 8 >> 2] | 0) | 0) != 0 : 0) ? (ry(c[q >> 2] | 0, c[r >> 2] | 0, c[(c[t >> 2] | 0) + 12 >> 2] | 0) | 0) != 0 : 0) {
	                        v = 12;
	                        break
	                    }
	                    c[t >> 2] = c[c[t >> 2] >> 2]
	                }
	                if ((v | 0) == 12) {
	                    c[k >> 2] = c[(c[t >> 2] | 0) + 16 >> 2];
	                    u = c[k >> 2] | 0;
	                    i = j;
	                    return u | 0
	                } else if ((v | 0) == 14) {
	                    c[k >> 2] = 0;
	                    u = c[k >> 2] | 0;
	                    i = j;
	                    return u | 0
	                }
	                return 0
	            }

	            function Vj(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 16 | 0;
	                j = g + 12 | 0;
	                k = g + 8 | 0;
	                l = g + 4 | 0;
	                m = g;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                f = Uj(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0, 0, 0) | 0;
	                i = g;
	                return f | 0
	            }

	            function Wj(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j + 4 >> 2] = c[h >> 2];
	                c[j >> 2] = c[g >> 2];
	                Xj(c[f >> 2] | 0, 229, j);
	                i = e;
	                return
	            }

	            function Xj(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 20 | 0;
	                h = e + 16 | 0;
	                j = e + 12 | 0;
	                k = e + 8 | 0;
	                l = e + 4 | 0;
	                m = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    i = e;
	                    return
	                }
	                if (!(c[c[f >> 2] >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                c[j >> 2] = 0;
	                while (1) {
	                    if ((c[j >> 2] | 0) >= (c[(c[f >> 2] | 0) + 4 >> 2] | 0))break;
	                    a:do if (c[(c[c[f >> 2] >> 2] | 0) + ((c[j >> 2] | 0) * 24 | 0) + 20 >> 2] | 0) {
	                        c[l >> 2] = (c[c[f >> 2] >> 2] | 0) + ((c[j >> 2] | 0) * 24 | 0);
	                        while (1) {
	                            if (!(c[l >> 2] | 0))break a;
	                            c[m >> 2] = c[c[l >> 2] >> 2];
	                            c[k >> 2] = c[(c[f >> 2] | 0) + 8 >> 2];
	                            if ((c[g >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 16 >> 2] | 0) != 0 : 0)xb[c[g >> 2] & 511](c[(c[l >> 2] | 0) + 16 >> 2] | 0, c[h >> 2] | 0, c[(c[l >> 2] | 0) + 4 >> 2] | 0, c[(c[l >> 2] | 0) + 8 >> 2] | 0, c[(c[l >> 2] | 0) + 12 >> 2] | 0);
	                            if ((c[k >> 2] | 0) == (c[(c[f >> 2] | 0) + 8 >> 2] | 0)) {
	                                c[l >> 2] = c[m >> 2];
	                                continue
	                            }
	                            if ((c[l >> 2] | 0) != ((c[c[f >> 2] >> 2] | 0) + ((c[j >> 2] | 0) * 24 | 0) | 0)) {
	                                c[l >> 2] = c[m >> 2];
	                                continue
	                            }
	                            if (!(c[(c[c[f >> 2] >> 2] | 0) + ((c[j >> 2] | 0) * 24 | 0) + 20 >> 2] | 0))c[l >> 2] = 0;
	                            if ((c[(c[c[f >> 2] >> 2] | 0) + ((c[j >> 2] | 0) * 24 | 0) >> 2] | 0) == (c[m >> 2] | 0))continue;
	                            c[l >> 2] = (c[c[f >> 2] >> 2] | 0) + ((c[j >> 2] | 0) * 24 | 0)
	                        }
	                    } while (0);
	                    c[j >> 2] = (c[j >> 2] | 0) + 1
	                }
	                i = e;
	                return
	            }

	            function Yj(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                h = i;
	                i = i + 32 | 0;
	                j = h + 20 | 0;
	                k = h + 16 | 0;
	                l = h + 12 | 0;
	                m = h + 8 | 0;
	                n = h + 4 | 0;
	                o = h;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                Zj(c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0);
	                i = h;
	                return
	            }

	            function Zj(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h + 32 | 0;
	                k = h + 28 | 0;
	                l = h + 24 | 0;
	                m = h + 20 | 0;
	                n = h + 16 | 0;
	                o = h + 12 | 0;
	                p = h + 8 | 0;
	                q = h + 4 | 0;
	                r = h;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                if ((c[j >> 2] | 0) == 0 | (c[n >> 2] | 0) == 0) {
	                    i = h;
	                    return
	                }
	                if (!(c[c[j >> 2] >> 2] | 0)) {
	                    i = h;
	                    return
	                }
	                c[p >> 2] = 0;
	                while (1) {
	                    if ((c[p >> 2] | 0) >= (c[(c[j >> 2] | 0) + 4 >> 2] | 0))break;
	                    a:do if (c[(c[c[j >> 2] >> 2] | 0) + ((c[p >> 2] | 0) * 24 | 0) + 20 >> 2] | 0) {
	                        c[q >> 2] = (c[c[j >> 2] >> 2] | 0) + ((c[p >> 2] | 0) * 24 | 0);
	                        while (1) {
	                            if (!(c[q >> 2] | 0))break a;
	                            c[r >> 2] = c[c[q >> 2] >> 2];
	                            if (!((c[k >> 2] | 0) != 0 ? (qy(c[k >> 2] | 0, c[(c[q >> 2] | 0) + 4 >> 2] | 0) | 0) == 0 : 0))s = 10;
	                            do if ((s | 0) == 10) {
	                                s = 0;
	                                if ((c[l >> 2] | 0) != 0 ? (qy(c[l >> 2] | 0, c[(c[q >> 2] | 0) + 8 >> 2] | 0) | 0) == 0 : 0)break;
	                                if ((c[m >> 2] | 0) != 0 ? (qy(c[m >> 2] | 0, c[(c[q >> 2] | 0) + 12 >> 2] | 0) | 0) == 0 : 0)break;
	                                if (c[(c[q >> 2] | 0) + 16 >> 2] | 0)xb[c[n >> 2] & 511](c[(c[q >> 2] | 0) + 16 >> 2] | 0, c[o >> 2] | 0, c[(c[q >> 2] | 0) + 4 >> 2] | 0, c[(c[q >> 2] | 0) + 8 >> 2] | 0, c[(c[q >> 2] | 0) + 12 >> 2] | 0)
	                            } while (0);
	                            c[q >> 2] = c[r >> 2]
	                        }
	                    } while (0);
	                    c[p >> 2] = (c[p >> 2] | 0) + 1
	                }
	                i = h;
	                return
	            }

	            function _j(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 24 | 0;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                l = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                if (!(c[g >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                c[l >> 2] = Ij(c[(c[f >> 2] | 0) + 4 >> 2] | 0) | 0;
	                if (!(c[l >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                a:do if (c[c[f >> 2] >> 2] | 0) {
	                    c[h >> 2] = 0;
	                    while (1) {
	                        if ((c[h >> 2] | 0) >= (c[(c[f >> 2] | 0) + 4 >> 2] | 0))break a;
	                        b:do if (c[(c[c[f >> 2] >> 2] | 0) + ((c[h >> 2] | 0) * 24 | 0) + 20 >> 2] | 0) {
	                            c[j >> 2] = (c[c[f >> 2] >> 2] | 0) + ((c[h >> 2] | 0) * 24 | 0);
	                            while (1) {
	                                if (!(c[j >> 2] | 0))break b;
	                                c[k >> 2] = c[c[j >> 2] >> 2];
	                                b = c[l >> 2] | 0;
	                                a = c[(c[j >> 2] | 0) + 4 >> 2] | 0;
	                                n = c[(c[j >> 2] | 0) + 8 >> 2] | 0;
	                                o = c[(c[j >> 2] | 0) + 12 >> 2] | 0;
	                                Mj(b, a, n, o, Hb[c[g >> 2] & 511](c[(c[j >> 2] | 0) + 16 >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0) | 0) | 0;
	                                c[j >> 2] = c[k >> 2]
	                            }
	                        } while (0);
	                        c[h >> 2] = (c[h >> 2] | 0) + 1
	                    }
	                } while (0);
	                c[(c[l >> 2] | 0) + 8 >> 2] = c[(c[f >> 2] | 0) + 8 >> 2];
	                c[e >> 2] = c[l >> 2];
	                m = c[e >> 2] | 0;
	                i = d;
	                return m | 0
	            }

	            function $j(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0))c[d >> 2] = -1; else c[d >> 2] = c[(c[e >> 2] | 0) + 8 >> 2];
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function ak(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                d = bk(c[f >> 2] | 0, c[g >> 2] | 0, 0, 0, c[h >> 2] | 0) | 0;
	                i = e;
	                return d | 0
	            }

	            function bk(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                g = i;
	                i = i + 48 | 0;
	                h = g + 32 | 0;
	                j = g + 28 | 0;
	                k = g + 24 | 0;
	                l = g + 20 | 0;
	                m = g + 16 | 0;
	                n = g + 12 | 0;
	                o = g + 8 | 0;
	                p = g + 4 | 0;
	                q = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[q >> 2] = 0;
	                if ((c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0) {
	                    c[h >> 2] = -1;
	                    r = c[h >> 2] | 0;
	                    i = g;
	                    return r | 0
	                }
	                c[o >> 2] = dk(c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0) | 0;
	                if (!(c[(c[c[j >> 2] >> 2] | 0) + ((c[o >> 2] | 0) * 24 | 0) + 20 >> 2] | 0)) {
	                    c[h >> 2] = -1;
	                    r = c[h >> 2] | 0;
	                    i = g;
	                    return r | 0
	                }
	                c[p >> 2] = (c[c[j >> 2] >> 2] | 0) + ((c[o >> 2] | 0) * 24 | 0);
	                while (1) {
	                    if (!(c[p >> 2] | 0)) {
	                        s = 27;
	                        break
	                    }
	                    if (((qy(c[(c[p >> 2] | 0) + 4 >> 2] | 0, c[k >> 2] | 0) | 0) != 0 ? (qy(c[(c[p >> 2] | 0) + 8 >> 2] | 0, c[l >> 2] | 0) | 0) != 0 : 0) ? (qy(c[(c[p >> 2] | 0) + 12 >> 2] | 0, c[m >> 2] | 0) | 0) != 0 : 0)break;
	                    c[q >> 2] = c[p >> 2];
	                    c[p >> 2] = c[c[p >> 2] >> 2]
	                }
	                if ((s | 0) == 27) {
	                    c[h >> 2] = -1;
	                    r = c[h >> 2] | 0;
	                    i = g;
	                    return r | 0
	                }
	                if ((c[n >> 2] | 0) != 0 ? (c[(c[p >> 2] | 0) + 16 >> 2] | 0) != 0 : 0)Ab[c[n >> 2] & 511](c[(c[p >> 2] | 0) + 16 >> 2] | 0, c[(c[p >> 2] | 0) + 4 >> 2] | 0);
	                c[(c[p >> 2] | 0) + 16 >> 2] = 0;
	                if (!(c[(c[j >> 2] | 0) + 12 >> 2] | 0)) {
	                    if (c[(c[p >> 2] | 0) + 4 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[p >> 2] | 0) + 4 >> 2] | 0);
	                    if (c[(c[p >> 2] | 0) + 8 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[p >> 2] | 0) + 8 >> 2] | 0);
	                    if (c[(c[p >> 2] | 0) + 12 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[p >> 2] | 0) + 12 >> 2] | 0)
	                }
	                n = c[c[p >> 2] >> 2] | 0;
	                do if (!(c[q >> 2] | 0)) {
	                    s = c[p >> 2] | 0;
	                    if (!n) {
	                        c[s + 20 >> 2] = 0;
	                        break
	                    } else {
	                        c[p >> 2] = c[s >> 2];
	                        s = (c[c[j >> 2] >> 2] | 0) + ((c[o >> 2] | 0) * 24 | 0) | 0;
	                        m = c[p >> 2] | 0;
	                        c[s + 0 >> 2] = c[m + 0 >> 2];
	                        c[s + 4 >> 2] = c[m + 4 >> 2];
	                        c[s + 8 >> 2] = c[m + 8 >> 2];
	                        c[s + 12 >> 2] = c[m + 12 >> 2];
	                        c[s + 16 >> 2] = c[m + 16 >> 2];
	                        c[s + 20 >> 2] = c[m + 20 >> 2];
	                        zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                        break
	                    }
	                } else {
	                    c[c[q >> 2] >> 2] = n;
	                    zb[c[135736 >> 2] & 511](c[p >> 2] | 0)
	                } while (0);
	                p = (c[j >> 2] | 0) + 8 | 0;
	                c[p >> 2] = (c[p >> 2] | 0) + -1;
	                c[h >> 2] = 0;
	                r = c[h >> 2] | 0;
	                i = g;
	                return r | 0
	            }

	            function ck(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 12 | 0;
	                h = f + 8 | 0;
	                j = f + 4 | 0;
	                k = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                e = bk(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, 0, c[k >> 2] | 0) | 0;
	                i = f;
	                return e | 0
	            }

	            function dk(b, e, f, g) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                h = i;
	                i = i + 32 | 0;
	                j = h + 16 | 0;
	                k = h + 12 | 0;
	                l = h + 8 | 0;
	                m = h + 4 | 0;
	                n = h;
	                o = h + 20 | 0;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[l >> 2] = f;
	                c[m >> 2] = g;
	                c[n >> 2] = 0;
	                c[n >> 2] = c[(c[j >> 2] | 0) + 16 >> 2];
	                a:do if (c[k >> 2] | 0) {
	                    c[n >> 2] = (c[n >> 2] | 0) + ((d[c[k >> 2] >> 0] | 0) * 30 | 0);
	                    while (1) {
	                        g = c[k >> 2] | 0;
	                        c[k >> 2] = g + 1;
	                        f = a[g >> 0] | 0;
	                        a[o >> 0] = f;
	                        if (!(f << 24 >> 24))break a;
	                        c[n >> 2] = c[n >> 2] ^ (c[n >> 2] << 5) + ((c[n >> 2] | 0) >>> 3) + (a[o >> 0] | 0)
	                    }
	                } while (0);
	                c[n >> 2] = c[n >> 2] ^ (c[n >> 2] << 5) + ((c[n >> 2] | 0) >>> 3);
	                b:do if (c[l >> 2] | 0)while (1) {
	                    k = c[l >> 2] | 0;
	                    c[l >> 2] = k + 1;
	                    f = a[k >> 0] | 0;
	                    a[o >> 0] = f;
	                    if (!(f << 24 >> 24))break b;
	                    c[n >> 2] = c[n >> 2] ^ (c[n >> 2] << 5) + ((c[n >> 2] | 0) >>> 3) + (a[o >> 0] | 0)
	                } while (0);
	                c[n >> 2] = c[n >> 2] ^ (c[n >> 2] << 5) + ((c[n >> 2] | 0) >>> 3);
	                if (!(c[m >> 2] | 0)) {
	                    p = c[n >> 2] | 0;
	                    q = c[j >> 2] | 0;
	                    r = q + 4 | 0;
	                    s = c[r >> 2] | 0;
	                    t = (p >>> 0) % (s >>> 0) | 0;
	                    i = h;
	                    return t | 0
	                }
	                while (1) {
	                    l = c[m >> 2] | 0;
	                    c[m >> 2] = l + 1;
	                    f = a[l >> 0] | 0;
	                    a[o >> 0] = f;
	                    if (!(f << 24 >> 24))break;
	                    c[n >> 2] = c[n >> 2] ^ (c[n >> 2] << 5) + ((c[n >> 2] | 0) >>> 3) + (a[o >> 0] | 0)
	                }
	                p = c[n >> 2] | 0;
	                q = c[j >> 2] | 0;
	                r = q + 4 | 0;
	                s = c[r >> 2] | 0;
	                t = (p >>> 0) % (s >>> 0) | 0;
	                i = h;
	                return t | 0
	            }

	            function ek(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                d = i;
	                i = i + 48 | 0;
	                e = d + 32 | 0;
	                f = d + 28 | 0;
	                g = d + 24 | 0;
	                h = d + 20 | 0;
	                j = d + 16 | 0;
	                k = d + 12 | 0;
	                l = d + 8 | 0;
	                m = d + 4 | 0;
	                n = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    o = c[e >> 2] | 0;
	                    i = d;
	                    return o | 0
	                }
	                if ((c[g >> 2] | 0) < 8) {
	                    c[e >> 2] = -1;
	                    o = c[e >> 2] | 0;
	                    i = d;
	                    return o | 0
	                }
	                if ((c[g >> 2] | 0) > 16384) {
	                    c[e >> 2] = -1;
	                    o = c[e >> 2] | 0;
	                    i = d;
	                    return o | 0
	                }
	                c[j >> 2] = c[(c[f >> 2] | 0) + 4 >> 2];
	                c[n >> 2] = c[c[f >> 2] >> 2];
	                if (!(c[n >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    o = c[e >> 2] | 0;
	                    i = d;
	                    return o | 0
	                }
	                b = Cb[c[135744 >> 2] & 511]((c[g >> 2] | 0) * 24 | 0) | 0;
	                c[c[f >> 2] >> 2] = b;
	                if (!(c[c[f >> 2] >> 2] | 0)) {
	                    c[c[f >> 2] >> 2] = c[n >> 2];
	                    c[e >> 2] = -1;
	                    o = c[e >> 2] | 0;
	                    i = d;
	                    return o | 0
	                }
	                cU(c[c[f >> 2] >> 2] | 0, 0, (c[g >> 2] | 0) * 24 | 0) | 0;
	                c[(c[f >> 2] | 0) + 4 >> 2] = c[g >> 2];
	                c[k >> 2] = 0;
	                while (1) {
	                    if ((c[k >> 2] | 0) >= (c[j >> 2] | 0))break;
	                    if (c[(c[n >> 2] | 0) + ((c[k >> 2] | 0) * 24 | 0) + 20 >> 2] | 0) {
	                        c[h >> 2] = dk(c[f >> 2] | 0, c[(c[n >> 2] | 0) + ((c[k >> 2] | 0) * 24 | 0) + 4 >> 2] | 0, c[(c[n >> 2] | 0) + ((c[k >> 2] | 0) * 24 | 0) + 8 >> 2] | 0, c[(c[n >> 2] | 0) + ((c[k >> 2] | 0) * 24 | 0) + 12 >> 2] | 0) | 0;
	                        g = (c[c[f >> 2] >> 2] | 0) + ((c[h >> 2] | 0) * 24 | 0) | 0;
	                        b = (c[n >> 2] | 0) + ((c[k >> 2] | 0) * 24 | 0) | 0;
	                        c[g + 0 >> 2] = c[b + 0 >> 2];
	                        c[g + 4 >> 2] = c[b + 4 >> 2];
	                        c[g + 8 >> 2] = c[b + 8 >> 2];
	                        c[g + 12 >> 2] = c[b + 12 >> 2];
	                        c[g + 16 >> 2] = c[b + 16 >> 2];
	                        c[g + 20 >> 2] = c[b + 20 >> 2];
	                        c[(c[c[f >> 2] >> 2] | 0) + ((c[h >> 2] | 0) * 24 | 0) >> 2] = 0
	                    }
	                    c[k >> 2] = (c[k >> 2] | 0) + 1
	                }
	                c[k >> 2] = 0;
	                while (1) {
	                    if ((c[k >> 2] | 0) >= (c[j >> 2] | 0))break;
	                    c[l >> 2] = c[(c[n >> 2] | 0) + ((c[k >> 2] | 0) * 24 | 0) >> 2];
	                    while (1) {
	                        if (!(c[l >> 2] | 0))break;
	                        c[m >> 2] = c[c[l >> 2] >> 2];
	                        c[h >> 2] = dk(c[f >> 2] | 0, c[(c[l >> 2] | 0) + 4 >> 2] | 0, c[(c[l >> 2] | 0) + 8 >> 2] | 0, c[(c[l >> 2] | 0) + 12 >> 2] | 0) | 0;
	                        b = (c[c[f >> 2] >> 2] | 0) + ((c[h >> 2] | 0) * 24 | 0) | 0;
	                        if (!(c[(c[c[f >> 2] >> 2] | 0) + ((c[h >> 2] | 0) * 24 | 0) + 20 >> 2] | 0)) {
	                            g = c[l >> 2] | 0;
	                            c[b + 0 >> 2] = c[g + 0 >> 2];
	                            c[b + 4 >> 2] = c[g + 4 >> 2];
	                            c[b + 8 >> 2] = c[g + 8 >> 2];
	                            c[b + 12 >> 2] = c[g + 12 >> 2];
	                            c[b + 16 >> 2] = c[g + 16 >> 2];
	                            c[b + 20 >> 2] = c[g + 20 >> 2];
	                            c[(c[c[f >> 2] >> 2] | 0) + ((c[h >> 2] | 0) * 24 | 0) >> 2] = 0;
	                            zb[c[135736 >> 2] & 511](c[l >> 2] | 0)
	                        } else {
	                            c[c[l >> 2] >> 2] = c[b >> 2];
	                            c[(c[c[f >> 2] >> 2] | 0) + ((c[h >> 2] | 0) * 24 | 0) >> 2] = c[l >> 2]
	                        }
	                        c[l >> 2] = c[m >> 2]
	                    }
	                    c[k >> 2] = (c[k >> 2] | 0) + 1
	                }
	                zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                c[e >> 2] = 0;
	                o = c[e >> 2] | 0;
	                i = d;
	                return o | 0
	            }

	            function fk(b, e, f, g, h, j, k) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                k = k | 0;
	                var l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0;
	                l = i;
	                i = i + 48 | 0;
	                m = l + 28 | 0;
	                n = l + 24 | 0;
	                o = l + 20 | 0;
	                p = l + 16 | 0;
	                q = l + 12 | 0;
	                r = l + 8 | 0;
	                s = l + 4 | 0;
	                t = l;
	                u = l + 32 | 0;
	                c[m >> 2] = b;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                c[q >> 2] = h;
	                c[r >> 2] = j;
	                c[s >> 2] = k;
	                c[t >> 2] = 0;
	                c[t >> 2] = c[(c[m >> 2] | 0) + 16 >> 2];
	                if (c[n >> 2] | 0)c[t >> 2] = (c[t >> 2] | 0) + ((d[c[n >> 2] >> 0] | 0) * 30 | 0); else c[t >> 2] = (c[t >> 2] | 0) + ((d[c[o >> 2] >> 0] | 0) * 30 | 0);
	                if (c[n >> 2] | 0) {
	                    while (1) {
	                        k = c[n >> 2] | 0;
	                        c[n >> 2] = k + 1;
	                        j = a[k >> 0] | 0;
	                        a[u >> 0] = j;
	                        v = c[t >> 2] | 0;
	                        w = (c[t >> 2] << 5) + ((c[t >> 2] | 0) >>> 3) | 0;
	                        if (!(j << 24 >> 24))break;
	                        c[t >> 2] = v ^ w + (a[u >> 0] | 0)
	                    }
	                    c[t >> 2] = v ^ w + 58
	                }
	                a:do if (c[o >> 2] | 0)while (1) {
	                    w = c[o >> 2] | 0;
	                    c[o >> 2] = w + 1;
	                    v = a[w >> 0] | 0;
	                    a[u >> 0] = v;
	                    if (!(v << 24 >> 24))break a;
	                    c[t >> 2] = c[t >> 2] ^ (c[t >> 2] << 5) + ((c[t >> 2] | 0) >>> 3) + (a[u >> 0] | 0)
	                } while (0);
	                c[t >> 2] = c[t >> 2] ^ (c[t >> 2] << 5) + ((c[t >> 2] | 0) >>> 3);
	                if (c[p >> 2] | 0) {
	                    while (1) {
	                        o = c[p >> 2] | 0;
	                        c[p >> 2] = o + 1;
	                        v = a[o >> 0] | 0;
	                        a[u >> 0] = v;
	                        x = c[t >> 2] | 0;
	                        y = (c[t >> 2] << 5) + ((c[t >> 2] | 0) >>> 3) | 0;
	                        if (!(v << 24 >> 24))break;
	                        c[t >> 2] = x ^ y + (a[u >> 0] | 0)
	                    }
	                    c[t >> 2] = x ^ y + 58
	                }
	                b:do if (c[q >> 2] | 0)while (1) {
	                    y = c[q >> 2] | 0;
	                    c[q >> 2] = y + 1;
	                    x = a[y >> 0] | 0;
	                    a[u >> 0] = x;
	                    if (!(x << 24 >> 24))break b;
	                    c[t >> 2] = c[t >> 2] ^ (c[t >> 2] << 5) + ((c[t >> 2] | 0) >>> 3) + (a[u >> 0] | 0)
	                } while (0);
	                c[t >> 2] = c[t >> 2] ^ (c[t >> 2] << 5) + ((c[t >> 2] | 0) >>> 3);
	                if (c[r >> 2] | 0) {
	                    while (1) {
	                        q = c[r >> 2] | 0;
	                        c[r >> 2] = q + 1;
	                        x = a[q >> 0] | 0;
	                        a[u >> 0] = x;
	                        z = c[t >> 2] | 0;
	                        A = (c[t >> 2] << 5) + ((c[t >> 2] | 0) >>> 3) | 0;
	                        if (!(x << 24 >> 24))break;
	                        c[t >> 2] = z ^ A + (a[u >> 0] | 0)
	                    }
	                    c[t >> 2] = z ^ A + 58
	                }
	                if (!(c[s >> 2] | 0)) {
	                    B = c[t >> 2] | 0;
	                    C = c[m >> 2] | 0;
	                    D = C + 4 | 0;
	                    E = c[D >> 2] | 0;
	                    F = (B >>> 0) % (E >>> 0) | 0;
	                    i = l;
	                    return F | 0
	                }
	                while (1) {
	                    A = c[s >> 2] | 0;
	                    c[s >> 2] = A + 1;
	                    z = a[A >> 0] | 0;
	                    a[u >> 0] = z;
	                    if (!(z << 24 >> 24))break;
	                    c[t >> 2] = c[t >> 2] ^ (c[t >> 2] << 5) + ((c[t >> 2] | 0) >>> 3) + (a[u >> 0] | 0)
	                }
	                B = c[t >> 2] | 0;
	                C = c[m >> 2] | 0;
	                D = C + 4 | 0;
	                E = c[D >> 2] | 0;
	                F = (B >>> 0) % (E >>> 0) | 0;
	                i = l;
	                return F | 0
	            }

	            function gk(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 20 | 0;
	                j = g + 16 | 0;
	                k = g + 12 | 0;
	                l = g;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[g + 8 >> 2] = e;
	                c[g + 4 >> 2] = f;
	                c[l >> 2] = c[j >> 2];
	                Db[c[c[l >> 2] >> 2] & 511](c[h >> 2] | 0, c[(c[l >> 2] | 0) + 4 >> 2] | 0, c[k >> 2] | 0);
	                i = g;
	                return
	            }

	            function hk(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                do if (!(c[g >> 2] | 0)) {
	                    if (!(c[(_a() | 0) >> 2] | 0)) {
	                        c[g >> 2] = 0;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 13) {
	                        c[g >> 2] = 1501;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 11) {
	                        c[g >> 2] = 1502;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 9) {
	                        c[g >> 2] = 1503;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 74) {
	                        c[g >> 2] = 1504;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 16) {
	                        c[g >> 2] = 1505;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 125) {
	                        c[g >> 2] = 1506;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 10) {
	                        c[g >> 2] = 1507;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 35) {
	                        c[g >> 2] = 1508;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 33) {
	                        c[g >> 2] = 1509;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 17) {
	                        c[g >> 2] = 1510;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 14) {
	                        c[g >> 2] = 1511;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 27) {
	                        c[g >> 2] = 1512;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 115) {
	                        c[g >> 2] = 1513;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 4) {
	                        c[g >> 2] = 1514;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 22) {
	                        c[g >> 2] = 1515;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 5) {
	                        c[g >> 2] = 1516;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 21) {
	                        c[g >> 2] = 1517;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 24) {
	                        c[g >> 2] = 1518;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 31) {
	                        c[g >> 2] = 1519;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 90) {
	                        c[g >> 2] = 1520;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 36) {
	                        c[g >> 2] = 1521;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 23) {
	                        c[g >> 2] = 1522;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 19) {
	                        c[g >> 2] = 1523;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 2) {
	                        c[g >> 2] = 1524;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 8) {
	                        c[g >> 2] = 1525;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 37) {
	                        c[g >> 2] = 1526;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 12) {
	                        c[g >> 2] = 1527;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 28) {
	                        c[g >> 2] = 1528;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 38) {
	                        c[g >> 2] = 1529;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 20) {
	                        c[g >> 2] = 1530;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 39) {
	                        c[g >> 2] = 1531;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 95) {
	                        c[g >> 2] = 1532;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 25) {
	                        c[g >> 2] = 1533;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 6) {
	                        c[g >> 2] = 1534;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 1) {
	                        c[g >> 2] = 1535;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 32) {
	                        c[g >> 2] = 1536;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 34) {
	                        c[g >> 2] = 1537;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 30) {
	                        c[g >> 2] = 1538;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 29) {
	                        c[g >> 2] = 1539;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 3) {
	                        c[g >> 2] = 1540;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 110) {
	                        c[g >> 2] = 1541;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 18) {
	                        c[g >> 2] = 1542;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 88) {
	                        c[g >> 2] = 1550;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 106) {
	                        c[g >> 2] = 1551;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 111) {
	                        c[g >> 2] = 1552;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 110) {
	                        c[g >> 2] = 1541;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 101) {
	                        c[g >> 2] = 1553;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 98) {
	                        c[g >> 2] = 1554;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 115) {
	                        c[g >> 2] = 1513;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 114) {
	                        c[g >> 2] = 1555;
	                        break
	                    }
	                    if ((c[(_a() | 0) >> 2] | 0) == 97) {
	                        c[g >> 2] = 1556;
	                        break
	                    } else {
	                        c[g >> 2] = 1500;
	                        break
	                    }
	                } while (0);
	                c[j >> 2] = 0;
	                if ((c[g >> 2] | 0) >= 1500)c[j >> 2] = (c[g >> 2] | 0) - 1500;
	                if ((c[j >> 2] | 0) >>> 0 < 57) {
	                    k = c[f >> 2] | 0;
	                    l = c[g >> 2] | 0;
	                    m = c[j >> 2] | 0;
	                    n = 76128 + (m << 2) | 0;
	                    o = c[n >> 2] | 0;
	                    p = c[h >> 2] | 0;
	                    ce(k, l, 0, o, p);
	                    i = e;
	                    return
	                }
	                c[j >> 2] = 0;
	                k = c[f >> 2] | 0;
	                l = c[g >> 2] | 0;
	                m = c[j >> 2] | 0;
	                n = 76128 + (m << 2) | 0;
	                o = c[n >> 2] | 0;
	                p = c[h >> 2] | 0;
	                ce(k, l, 0, o, p);
	                i = e;
	                return
	            }

	            function ik(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e;
	                g = e + 32 | 0;
	                h = e + 28 | 0;
	                j = e + 24 | 0;
	                k = e + 20 | 0;
	                l = e + 16 | 0;
	                m = e + 12 | 0;
	                n = e + 8 | 0;
	                o = e + 4 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = c[g >> 2];
	                c[l >> 2] = 0;
	                c[m >> 2] = 0;
	                c[n >> 2] = 0;
	                c[o >> 2] = 2;
	                if (((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 212 >> 2] | 0) != 0 : 0) ? (c[(c[k >> 2] | 0) + 172 >> 2] | 0) == -1 : 0) {
	                    i = e;
	                    return
	                }
	                if ((c[k >> 2] | 0) != 0 ? (c[c[k >> 2] >> 2] | 0) != 0 : 0) {
	                    g = c[c[k >> 2] >> 2] | 0;
	                    if (c[(c[k >> 2] | 0) + 104 >> 2] | 0) {
	                        c[m >> 2] = c[g + 88 >> 2];
	                        c[o >> 2] = 2
	                    } else {
	                        c[m >> 2] = c[g + 84 >> 2];
	                        c[o >> 2] = 1
	                    }
	                    if ((c[(c[c[k >> 2] >> 2] | 0) + 108 >> 2] | 0) == -554844497)c[l >> 2] = c[(c[c[k >> 2] >> 2] | 0) + 124 >> 2];
	                    c[n >> 2] = c[(c[k >> 2] | 0) + 4 >> 2]
	                }
	                g = c[l >> 2] | 0;
	                l = c[m >> 2] | 0;
	                m = c[n >> 2] | 0;
	                n = c[k >> 2] | 0;
	                k = c[o >> 2] | 0;
	                o = c[j >> 2] | 0;
	                d = c[h >> 2] | 0;
	                c[f >> 2] = c[j >> 2];
	                Xd(g, l, m, n, 0, 8, 1549, k, 0, 0, o, 0, 0, 0, 0, d, f);
	                i = e;
	                return
	            }

	            function jk() {
	                var a = 0, b = 0;
	                a = i;
	                i = i + 16 | 0;
	                b = a;
	                if (!(c[19090] | 0)) {
	                    i = a;
	                    return
	                }
	                c[b >> 2] = (c[19092] | 0) - 1;
	                while (1) {
	                    if ((c[b >> 2] | 0) < 0)break;
	                    c[76376 + (c[b >> 2] << 4) >> 2] = 0;
	                    c[76380 + (c[b >> 2] << 4) >> 2] = 0;
	                    c[76384 + (c[b >> 2] << 4) >> 2] = 0;
	                    c[76388 + (c[b >> 2] << 4) >> 2] = 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + -1
	                }
	                c[19092] = 0;
	                c[19090] = 0;
	                i = a;
	                return
	            }

	            function kk() {
	                var a = 0, b = 0;
	                a = i;
	                i = i + 16 | 0;
	                b = a;
	                if (!(c[19154] | 0)) {
	                    i = a;
	                    return
	                }
	                c[b >> 2] = (c[19156] | 0) - 1;
	                while (1) {
	                    if ((c[b >> 2] | 0) < 0)break;
	                    c[76632 + (c[b >> 2] << 4) >> 2] = 0;
	                    c[76636 + (c[b >> 2] << 4) >> 2] = 0;
	                    c[76640 + (c[b >> 2] << 4) >> 2] = 0;
	                    c[76644 + (c[b >> 2] << 4) >> 2] = 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + -1
	                }
	                c[19156] = 0;
	                c[19154] = 0;
	                i = a;
	                return
	            }

	            function lk(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 96 | 0;
	                d = b + 80 | 0;
	                e = b + 76 | 0;
	                f = b;
	                c[e >> 2] = a;
	                do if (c[e >> 2] | 0) {
	                    if (($a(c[e >> 2] | 0, f | 0) | 0) == -1) {
	                        c[d >> 2] = 0;
	                        break
	                    }
	                    if ((c[f + 12 >> 2] & 61440 | 0) == 16384) {
	                        c[d >> 2] = 2;
	                        break
	                    } else {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                } else c[d >> 2] = 0; while (0);
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function mk() {
	                return 0
	            }

	            function nk(a) {
	                a = a | 0;
	                var b = 0;
	                b = i;
	                i = i + 16 | 0;
	                c[b >> 2] = a;
	                i = b;
	                return 1
	            }

	            function ok(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[d >> 2] = a;
	                c[f >> 2] = Yk(c[d >> 2] | 0) | 0;
	                if (c[f >> 2] | 0) {
	                    g = c[f >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[e >> 2] = El(c[d >> 2] | 0, 0, 0) | 0;
	                if (!(c[e >> 2] | 0)) {
	                    g = c[f >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[f >> 2] = Yk(c[e >> 2] | 0) | 0;
	                zb[c[135736 >> 2] & 511](c[e >> 2] | 0);
	                g = c[f >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function pk(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) {
	                    c[f >> 2] = -1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[k >> 2] = Aa(c[h >> 2] | 0, 1, c[j >> 2] | 0, c[g >> 2] | 0) | 0;
	                if ((c[k >> 2] | 0) < 0)Zk(0, 76872);
	                c[f >> 2] = c[k >> 2];
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function qk(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = -1;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                c[f >> 2] = c[e >> 2];
	                if ((c[f >> 2] | 0) != (c[q >> 2] | 0) ? (c[f >> 2] | 0) != (c[o >> 2] | 0) : 0) {
	                    if ((c[f >> 2] | 0) == (c[p >> 2] | 0)) {
	                        c[d >> 2] = 0;
	                        h = c[d >> 2] | 0;
	                        i = b;
	                        return h | 0
	                    }
	                    a = (Xa(c[e >> 2] | 0) | 0) == -1;
	                    c[g >> 2] = a ? -1 : 0;
	                    if ((c[g >> 2] | 0) < 0)Zk(0, 76896);
	                    c[d >> 2] = c[g >> 2];
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                c[g >> 2] = Ga(c[f >> 2] | 0) | 0;
	                if ((c[g >> 2] | 0) < 0)Zk(0, 76880);
	                c[d >> 2] = 0;
	                h = c[d >> 2] | 0;
	                i = b;
	                return h | 0
	            }

	            function rk(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if ((c[19092] | 0) >= 15) {
	                    c[g >> 2] = -1;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                } else {
	                    c[76376 + (c[19092] << 4) >> 2] = c[h >> 2];
	                    c[76380 + (c[19092] << 4) >> 2] = c[j >> 2];
	                    c[76384 + (c[19092] << 4) >> 2] = c[k >> 2];
	                    c[76388 + (c[19092] << 4) >> 2] = c[l >> 2];
	                    c[19090] = 1;
	                    l = c[19092] | 0;
	                    c[19092] = l + 1;
	                    c[g >> 2] = l;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                return 0
	            }

	            function sk(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if ((c[19156] | 0) >= 15) {
	                    c[g >> 2] = -1;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                } else {
	                    c[76632 + (c[19156] << 4) >> 2] = c[h >> 2];
	                    c[76636 + (c[19156] << 4) >> 2] = c[j >> 2];
	                    c[76640 + (c[19156] << 4) >> 2] = c[k >> 2];
	                    c[76644 + (c[19156] << 4) >> 2] = c[l >> 2];
	                    c[19154] = 1;
	                    l = c[19156] | 0;
	                    c[19156] = l + 1;
	                    c[g >> 2] = l;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                return 0
	            }

	            function tk() {
	                var a = 0;
	                a = i;
	                if (c[19090] | 0) {
	                    i = a;
	                    return
	                }
	                rk(230, 231, 232, 233) | 0;
	                c[19090] = 1;
	                i = a;
	                return
	            }

	            function uk() {
	                var a = 0;
	                a = i;
	                if (c[19154] | 0) {
	                    i = a;
	                    return
	                }
	                sk(230, 234, 235, 233) | 0;
	                c[19154] = 1;
	                i = a;
	                return
	            }

	            function vk(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](36) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    al(76912);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = (c[f >> 2] | 0) + 0 | 0;
	                h = a + 36 | 0;
	                do {
	                    c[a >> 2] = 0;
	                    a = a + 4 | 0
	                } while ((a | 0) < (h | 0));
	                a = My(c[33950] << 1) | 0;
	                c[(c[f >> 2] | 0) + 16 >> 2] = a;
	                if (!(c[(c[f >> 2] | 0) + 16 >> 2] | 0)) {
	                    zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                Qy(c[(c[f >> 2] | 0) + 16 >> 2] | 0, 0) | 0;
	                a = Cd(c[e >> 2] | 0) | 0;
	                c[(c[f >> 2] | 0) + 12 >> 2] = a;
	                if (c[(c[f >> 2] | 0) + 12 >> 2] | 0) {
	                    a = My(c[33950] << 1) | 0;
	                    c[(c[f >> 2] | 0) + 20 >> 2] = a
	                } else c[(c[f >> 2] | 0) + 20 >> 2] = 0;
	                c[(c[f >> 2] | 0) + 4 >> 2] = 0;
	                c[(c[f >> 2] | 0) + 8 >> 2] = 0;
	                c[c[f >> 2] >> 2] = 0;
	                c[(c[f >> 2] | 0) + 24 >> 2] = -1;
	                c[(c[f >> 2] | 0) + 32 >> 2] = 0;
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function wk(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](32) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    al(76936);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = c[f >> 2] | 0;
	                c[a + 0 >> 2] = 0;
	                c[a + 4 >> 2] = 0;
	                c[a + 8 >> 2] = 0;
	                c[a + 12 >> 2] = 0;
	                c[a + 16 >> 2] = 0;
	                c[a + 20 >> 2] = 0;
	                c[a + 24 >> 2] = 0;
	                c[a + 28 >> 2] = 0;
	                a = Ly() | 0;
	                c[(c[f >> 2] | 0) + 16 >> 2] = a;
	                if (!(c[(c[f >> 2] | 0) + 16 >> 2] | 0)) {
	                    zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                if ((Py(c[(c[f >> 2] | 0) + 16 >> 2] | 0) | 0) == 1)Qy(c[(c[f >> 2] | 0) + 16 >> 2] | 0, 0) | 0;
	                c[(c[f >> 2] | 0) + 12 >> 2] = c[e >> 2];
	                do if (c[e >> 2] | 0) {
	                    a = My(4e3) | 0;
	                    c[(c[f >> 2] | 0) + 20 >> 2] = a;
	                    if (c[(c[f >> 2] | 0) + 20 >> 2] | 0) {
	                        Gd(c[f >> 2] | 0, 1) | 0;
	                        break
	                    }
	                    zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else c[(c[f >> 2] | 0) + 20 >> 2] = 0; while (0);
	                c[(c[f >> 2] | 0) + 4 >> 2] = 0;
	                c[(c[f >> 2] | 0) + 8 >> 2] = 0;
	                c[c[f >> 2] >> 2] = 0;
	                c[(c[f >> 2] | 0) + 24 >> 2] = 0;
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function xk(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](32) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    al(76936);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = c[f >> 2] | 0;
	                c[a + 0 >> 2] = 0;
	                c[a + 4 >> 2] = 0;
	                c[a + 8 >> 2] = 0;
	                c[a + 12 >> 2] = 0;
	                c[a + 16 >> 2] = 0;
	                c[a + 20 >> 2] = 0;
	                c[a + 24 >> 2] = 0;
	                c[a + 28 >> 2] = 0;
	                a = Ly() | 0;
	                c[(c[f >> 2] | 0) + 16 >> 2] = a;
	                if (!(c[(c[f >> 2] | 0) + 16 >> 2] | 0)) {
	                    zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                Qy(c[(c[f >> 2] | 0) + 16 >> 2] | 0, 3) | 0;
	                c[(c[f >> 2] | 0) + 12 >> 2] = c[e >> 2];
	                do if (c[e >> 2] | 0) {
	                    a = My(4e3) | 0;
	                    c[(c[f >> 2] | 0) + 20 >> 2] = a;
	                    if (c[(c[f >> 2] | 0) + 20 >> 2] | 0) {
	                        Gd(c[f >> 2] | 0, 1) | 0;
	                        break
	                    }
	                    zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else c[(c[f >> 2] | 0) + 20 >> 2] = 0; while (0);
	                c[(c[f >> 2] | 0) + 4 >> 2] = 0;
	                c[(c[f >> 2] | 0) + 8 >> 2] = 0;
	                c[c[f >> 2] >> 2] = 0;
	                c[(c[f >> 2] | 0) + 24 >> 2] = 0;
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function yk(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 20 >> 2] | 0) {
	                    Ry(c[(c[d >> 2] | 0) + 20 >> 2] | 0);
	                    c[(c[d >> 2] | 0) + 20 >> 2] = 0
	                }
	                if (c[(c[d >> 2] | 0) + 12 >> 2] | 0)Hd(c[(c[d >> 2] | 0) + 12 >> 2] | 0) | 0;
	                if (c[(c[d >> 2] | 0) + 8 >> 2] | 0)Cb[c[(c[d >> 2] | 0) + 8 >> 2] & 511](c[c[d >> 2] >> 2] | 0) | 0;
	                if (c[(c[d >> 2] | 0) + 16 >> 2] | 0) {
	                    Ry(c[(c[d >> 2] | 0) + 16 >> 2] | 0);
	                    c[(c[d >> 2] | 0) + 16 >> 2] = 0
	                }
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function zk(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                c[g >> 2] = 0;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = -1;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                if (c[(c[e >> 2] | 0) + 4 >> 2] | 0)Ak(c[e >> 2] | 0) | 0;
	                if (c[(c[e >> 2] | 0) + 8 >> 2] | 0)c[g >> 2] = Cb[c[(c[e >> 2] | 0) + 8 >> 2] & 511](c[c[e >> 2] >> 2] | 0) | 0;
	                c[f >> 2] = c[(c[e >> 2] | 0) + 24 >> 2];
	                if (c[(c[e >> 2] | 0) + 20 >> 2] | 0) {
	                    Ry(c[(c[e >> 2] | 0) + 20 >> 2] | 0);
	                    c[(c[e >> 2] | 0) + 20 >> 2] = 0
	                }
	                if (c[(c[e >> 2] | 0) + 12 >> 2] | 0)Hd(c[(c[e >> 2] | 0) + 12 >> 2] | 0) | 0;
	                if (c[(c[e >> 2] | 0) + 16 >> 2] | 0) {
	                    Ry(c[(c[e >> 2] | 0) + 16 >> 2] | 0);
	                    c[(c[e >> 2] | 0) + 16 >> 2] = 0
	                }
	                if (c[(c[e >> 2] | 0) + 28 >> 2] | 0)c[g >> 2] = -1;
	                zb[c[135736 >> 2] & 511](c[e >> 2] | 0);
	                c[d >> 2] = (c[g >> 2] | 0) == 0 ? c[f >> 2] | 0 : c[g >> 2] | 0;
	                h = c[d >> 2] | 0;
	                i = b;
	                return h | 0
	            }

	            function Ak(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                c[g >> 2] = 0;
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 28 >> 2] | 0) == 0 : 0) {
	                    a:do if ((c[(c[e >> 2] | 0) + 20 >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                        while (1) {
	                            c[f >> 2] = Gd(c[e >> 2] | 0, 0) | 0;
	                            if ((c[f >> 2] | 0) < 0)break;
	                            if (!(c[f >> 2] | 0))break a
	                        }
	                        Zk(1544, 0);
	                        c[(c[e >> 2] | 0) + 28 >> 2] = 1544;
	                        c[d >> 2] = -1;
	                        h = c[d >> 2] | 0;
	                        i = b;
	                        return h | 0
	                    } while (0);
	                    if (((c[(c[e >> 2] | 0) + 20 >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[(c[e >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                        f = c[(c[e >> 2] | 0) + 4 >> 2] | 0;
	                        a = c[c[e >> 2] >> 2] | 0;
	                        j = Vy(c[(c[e >> 2] | 0) + 20 >> 2] | 0) | 0;
	                        k = _y(c[(c[e >> 2] | 0) + 20 >> 2] | 0) | 0;
	                        c[g >> 2] = vb[f & 511](a, j, k) | 0;
	                        if ((c[g >> 2] | 0) >= 0)Ty(c[(c[e >> 2] | 0) + 20 >> 2] | 0, c[g >> 2] | 0) | 0
	                    } else l = 14;
	                    if (((l | 0) == 14 ? (c[(c[e >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) ? (l = c[(c[e >> 2] | 0) + 4 >> 2] | 0, k = c[c[e >> 2] >> 2] | 0, j = Vy(c[(c[e >> 2] | 0) + 16 >> 2] | 0) | 0, a = _y(c[(c[e >> 2] | 0) + 16 >> 2] | 0) | 0, c[g >> 2] = vb[l & 511](k, j, a) | 0, (c[g >> 2] | 0) >= 0) : 0)Ty(c[(c[e >> 2] | 0) + 16 >> 2] | 0, c[g >> 2] | 0) | 0;
	                    if ((c[g >> 2] | 0) < 0) {
	                        Zk(1545, 0);
	                        c[(c[e >> 2] | 0) + 28 >> 2] = 1545;
	                        c[d >> 2] = c[g >> 2];
	                        h = c[d >> 2] | 0;
	                        i = b;
	                        return h | 0
	                    } else {
	                        a = (c[e >> 2] | 0) + 24 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + (c[g >> 2] | 0);
	                        c[d >> 2] = c[g >> 2];
	                        h = c[d >> 2] | 0;
	                        i = b;
	                        return h | 0
	                    }
	                }
	                c[d >> 2] = -1;
	                h = c[d >> 2] | 0;
	                i = b;
	                return h | 0
	            }

	            function Bk(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[j >> 2] = 0;
	                c[k >> 2] = 0;
	                if (!(c[19090] | 0))tk();
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                a:do if (!(c[k >> 2] | 0)) {
	                    c[j >> 2] = (c[19092] | 0) - 1;
	                    while (1) {
	                        if ((c[j >> 2] | 0) < 0)break a;
	                        if (((c[76376 + (c[j >> 2] << 4) >> 2] | 0) != 0 ? (Cb[c[76376 + (c[j >> 2] << 4) >> 2] & 511](c[f >> 2] | 0) | 0) != 0 : 0) ? (c[k >> 2] = Cb[c[76376 + (c[j >> 2] << 4) + 4 >> 2] & 511](c[f >> 2] | 0) | 0, (c[k >> 2] | 0) != 0) : 0)break a;
	                        c[j >> 2] = (c[j >> 2] | 0) + -1
	                    }
	                } while (0);
	                if (!(c[k >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                c[h >> 2] = vk(c[g >> 2] | 0) | 0;
	                if (c[h >> 2] | 0) {
	                    c[c[h >> 2] >> 2] = c[k >> 2];
	                    c[(c[h >> 2] | 0) + 4 >> 2] = c[76384 + (c[j >> 2] << 4) >> 2];
	                    c[(c[h >> 2] | 0) + 8 >> 2] = c[76388 + (c[j >> 2] << 4) >> 2]
	                } else Cb[c[76376 + (c[j >> 2] << 4) + 12 >> 2] & 511](c[k >> 2] | 0) | 0;
	                c[e >> 2] = c[h >> 2];
	                l = c[e >> 2] | 0;
	                i = d;
	                return l | 0
	            }

	            function Ck(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (c[33972] | 0) {
	                    c[e >> 2] = Hb[c[135888 >> 2] & 511](c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                } else {
	                    c[e >> 2] = Bk(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                return 0
	            }

	            function Dk(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 32 | 0;
	                g = e + 28 | 0;
	                h = e + 24 | 0;
	                j = e + 16 | 0;
	                k = e + 12 | 0;
	                l = e + 8 | 0;
	                m = e + 4 | 0;
	                n = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[e + 20 >> 2] = d;
	                c[l >> 2] = 0;
	                c[m >> 2] = 0;
	                c[n >> 2] = 0;
	                if (!(c[19154] | 0))uk();
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                c[k >> 2] = yl(c[g >> 2] | 0) | 0;
	                if (c[k >> 2] | 0) {
	                    if (!((c[c[k >> 2] >> 2] | 0) != 0 ? (qy(c[c[k >> 2] >> 2] | 0, 76960) | 0) == 0 : 0))c[n >> 2] = El(c[g >> 2] | 0, 0, 0) | 0;
	                    Al(c[k >> 2] | 0)
	                }
	                if (c[n >> 2] | 0) {
	                    c[l >> 2] = (c[19156] | 0) - 1;
	                    while (1) {
	                        if ((c[l >> 2] | 0) < 0)break;
	                        if (((c[76632 + (c[l >> 2] << 4) >> 2] | 0) != 0 ? (Cb[c[76632 + (c[l >> 2] << 4) >> 2] & 511](c[n >> 2] | 0) | 0) != 0 : 0) ? (c[m >> 2] = Cb[c[76632 + (c[l >> 2] << 4) + 4 >> 2] & 511](c[n >> 2] | 0) | 0, (c[m >> 2] | 0) != 0) : 0)break;
	                        c[l >> 2] = (c[l >> 2] | 0) + -1
	                    }
	                    zb[c[135736 >> 2] & 511](c[n >> 2] | 0)
	                }
	                a:do if (!(c[m >> 2] | 0)) {
	                    c[l >> 2] = (c[19156] | 0) - 1;
	                    while (1) {
	                        if ((c[l >> 2] | 0) < 0)break a;
	                        if (((c[76632 + (c[l >> 2] << 4) >> 2] | 0) != 0 ? (Cb[c[76632 + (c[l >> 2] << 4) >> 2] & 511](c[g >> 2] | 0) | 0) != 0 : 0) ? (c[m >> 2] = Cb[c[76632 + (c[l >> 2] << 4) + 4 >> 2] & 511](c[g >> 2] | 0) | 0, (c[m >> 2] | 0) != 0) : 0)break a;
	                        c[l >> 2] = (c[l >> 2] | 0) + -1
	                    }
	                } while (0);
	                if (!(c[m >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                c[j >> 2] = xk(c[h >> 2] | 0) | 0;
	                if (c[j >> 2] | 0) {
	                    c[c[j >> 2] >> 2] = c[m >> 2];
	                    c[(c[j >> 2] | 0) + 4 >> 2] = c[76640 + (c[l >> 2] << 4) >> 2];
	                    c[(c[j >> 2] | 0) + 8 >> 2] = c[76644 + (c[l >> 2] << 4) >> 2]
	                }
	                c[f >> 2] = c[j >> 2];
	                o = c[f >> 2] | 0;
	                i = e;
	                return o | 0
	            }

	            function Ek(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (c[33974] | 0) {
	                    c[f >> 2] = vb[c[135896 >> 2] & 511](c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                } else {
	                    c[f >> 2] = Dk(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                return 0
	            }

	            function Fk(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[19154] | 0))uk();
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[h >> 2] = xk(c[g >> 2] | 0) | 0;
	                if (c[h >> 2] | 0) {
	                    c[c[h >> 2] >> 2] = c[f >> 2];
	                    c[(c[h >> 2] | 0) + 4 >> 2] = 235;
	                    c[(c[h >> 2] | 0) + 8 >> 2] = 236
	                }
	                c[e >> 2] = c[h >> 2];
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function Gk(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) < 0) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[h >> 2] = vk(c[g >> 2] | 0) | 0;
	                if (c[h >> 2] | 0) {
	                    c[c[h >> 2] >> 2] = c[f >> 2];
	                    c[(c[h >> 2] | 0) + 4 >> 2] = 237;
	                    c[(c[h >> 2] | 0) + 8 >> 2] = 238
	                }
	                c[e >> 2] = c[h >> 2];
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function Hk(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if ((c[h >> 2] | 0) <= 0) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                c[k >> 2] = vk(c[j >> 2] | 0) | 0;
	                if ((c[k >> 2] | 0) != 0 ? (c[c[k >> 2] >> 2] = c[g >> 2], c[(c[k >> 2] | 0) + 4 >> 2] = 227, c[(c[k >> 2] | 0) + 8 >> 2] = 0, c[l >> 2] = cz(c[(c[k >> 2] | 0) + 16 >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0) | 0, (c[l >> 2] | 0) != 0) : 0) {
	                    zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                c[f >> 2] = c[k >> 2];
	                m = c[f >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function Ik(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if ((c[h >> 2] | 0) <= 0) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[k >> 2] = Cb[c[135744 >> 2] & 511](36) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    al(76912);
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                d = (c[k >> 2] | 0) + 0 | 0;
	                b = d + 36 | 0;
	                do {
	                    c[d >> 2] = 0;
	                    d = d + 4 | 0
	                } while ((d | 0) < (b | 0));
	                d = Oy(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                c[(c[k >> 2] | 0) + 16 >> 2] = d;
	                if (!(c[(c[k >> 2] | 0) + 16 >> 2] | 0)) {
	                    zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                d = Cd(c[j >> 2] | 0) | 0;
	                c[(c[k >> 2] | 0) + 12 >> 2] = d;
	                if (c[(c[k >> 2] | 0) + 12 >> 2] | 0) {
	                    d = My(c[33950] << 1) | 0;
	                    c[(c[k >> 2] | 0) + 20 >> 2] = d
	                } else c[(c[k >> 2] | 0) + 20 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 24 >> 2] = -1;
	                c[c[k >> 2] >> 2] = c[g >> 2];
	                c[(c[k >> 2] | 0) + 4 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 8 >> 2] = 0;
	                c[f >> 2] = c[k >> 2];
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function Jk(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) < 0) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[h >> 2] = xk(c[g >> 2] | 0) | 0;
	                if (c[h >> 2] | 0) {
	                    c[c[h >> 2] >> 2] = c[f >> 2];
	                    c[(c[h >> 2] | 0) + 4 >> 2] = 239;
	                    c[(c[h >> 2] | 0) + 8 >> 2] = 0
	                }
	                c[e >> 2] = c[h >> 2];
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function Kk(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if (!(c[h >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                c[m >> 2] = vk(c[l >> 2] | 0) | 0;
	                if (c[m >> 2] | 0) {
	                    c[c[m >> 2] >> 2] = c[k >> 2];
	                    c[(c[m >> 2] | 0) + 4 >> 2] = c[h >> 2];
	                    c[(c[m >> 2] | 0) + 8 >> 2] = c[j >> 2]
	                }
	                c[g >> 2] = c[m >> 2];
	                n = c[g >> 2] | 0;
	                i = f;
	                return n | 0
	            }

	            function Lk(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 20 | 0;
	                h = e + 16 | 0;
	                j = e + 12 | 0;
	                k = e + 8 | 0;
	                l = e + 4 | 0;
	                m = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 0;
	                if ((c[h >> 2] | 0) < 0) {
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 28 >> 2] | 0) == 0 : 0) {
	                    do if (!(c[(c[g >> 2] | 0) + 12 >> 2] | 0)) {
	                        c[k >> 2] = c[h >> 2];
	                        c[l >> 2] = cz(c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                        if (c[l >> 2] | 0) {
	                            c[f >> 2] = -1;
	                            n = c[f >> 2] | 0;
	                            i = e;
	                            return n | 0
	                        }
	                    } else {
	                        if (!(c[(c[g >> 2] | 0) + 20 >> 2] | 0)) {
	                            d = Ly() | 0;
	                            c[(c[g >> 2] | 0) + 20 >> 2] = d
	                        }
	                        c[l >> 2] = cz(c[(c[g >> 2] | 0) + 20 >> 2] | 0, c[j >> 2] | 0, c[h >> 2] | 0) | 0;
	                        if (c[l >> 2] | 0) {
	                            c[f >> 2] = -1;
	                            n = c[f >> 2] | 0;
	                            i = e;
	                            return n | 0
	                        }
	                        c[m >> 2] = _y(c[(c[g >> 2] | 0) + 20 >> 2] | 0) | 0;
	                        c[k >> 2] = Fd(c[g >> 2] | 0, 1) | 0;
	                        if ((c[k >> 2] | 0) >= 0) {
	                            d = c[m >> 2] | 0;
	                            b = d - (_y(c[(c[g >> 2] | 0) + 20 >> 2] | 0) | 0) | 0;
	                            d = (c[g >> 2] | 0) + 32 | 0;
	                            c[d >> 2] = (c[d >> 2] | 0) + b;
	                            break
	                        }
	                        Zk(1544, 0);
	                        c[(c[g >> 2] | 0) + 28 >> 2] = 1544;
	                        c[f >> 2] = -1;
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    } while (0);
	                    c[f >> 2] = c[k >> 2];
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                c[f >> 2] = -1;
	                n = c[f >> 2] | 0;
	                i = e;
	                return n | 0
	            }

	            function Mk(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 24 | 0;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                l = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                c[j >> 2] = 0;
	                c[k >> 2] = 0;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 28 >> 2] | 0) == 0 : 0) {
	                    if ((c[g >> 2] | 0) <= 4e3 & (c[g >> 2] | 0) != 4)c[g >> 2] = 4e3;
	                    if (($y(c[(c[f >> 2] | 0) + 16 >> 2] | 0) | 0) >>> 0 <= 0) {
	                        Zk(1548, 0);
	                        c[(c[f >> 2] | 0) + 28 >> 2] = 1548;
	                        c[e >> 2] = -1;
	                        m = c[e >> 2] | 0;
	                        i = d;
	                        return m | 0
	                    }
	                    if ((Uy(c[(c[f >> 2] | 0) + 16 >> 2] | 0, (c[g >> 2] | 0) + 1 | 0) | 0) < 0) {
	                        al(76968);
	                        c[(c[f >> 2] | 0) + 28 >> 2] = 2;
	                        c[e >> 2] = -1;
	                        m = c[e >> 2] | 0;
	                        i = d;
	                        return m | 0
	                    }
	                    c[h >> 2] = Wy(c[(c[f >> 2] | 0) + 16 >> 2] | 0) | 0;
	                    if (!(c[(c[f >> 2] | 0) + 4 >> 2] | 0)) {
	                        Zk(1547, 0);
	                        c[(c[f >> 2] | 0) + 28 >> 2] = 1547;
	                        c[e >> 2] = -1;
	                        m = c[e >> 2] | 0;
	                        i = d;
	                        return m | 0
	                    }
	                    c[j >> 2] = vb[c[(c[f >> 2] | 0) + 4 >> 2] & 511](c[c[f >> 2] >> 2] | 0, c[h >> 2] | 0, c[g >> 2] | 0) | 0;
	                    if ((c[j >> 2] | 0) <= 0)c[(c[f >> 2] | 0) + 4 >> 2] = 240;
	                    if ((c[j >> 2] | 0) < 0) {
	                        c[e >> 2] = -1;
	                        m = c[e >> 2] | 0;
	                        i = d;
	                        return m | 0
	                    }
	                    c[g >> 2] = c[j >> 2];
	                    do if (c[(c[f >> 2] | 0) + 12 >> 2] | 0) {
	                        if (!(c[(c[f >> 2] | 0) + 20 >> 2] | 0)) {
	                            b = Ly() | 0;
	                            c[(c[f >> 2] | 0) + 20 >> 2] = b
	                        }
	                        c[j >> 2] = cz(c[(c[f >> 2] | 0) + 20 >> 2] | 0, c[h >> 2] | 0, c[g >> 2] | 0) | 0;
	                        if (c[j >> 2] | 0) {
	                            c[e >> 2] = -1;
	                            m = c[e >> 2] | 0;
	                            i = d;
	                            return m | 0
	                        }
	                        c[l >> 2] = _y(c[(c[f >> 2] | 0) + 20 >> 2] | 0) | 0;
	                        c[k >> 2] = Fd(c[f >> 2] | 0, 1) | 0;
	                        if ((c[k >> 2] | 0) >= 0) {
	                            b = c[l >> 2] | 0;
	                            a = b - (_y(c[(c[f >> 2] | 0) + 20 >> 2] | 0) | 0) | 0;
	                            b = (c[f >> 2] | 0) + 32 | 0;
	                            c[b >> 2] = (c[b >> 2] | 0) + a;
	                            break
	                        }
	                        Zk(1544, 0);
	                        c[(c[f >> 2] | 0) + 28 >> 2] = 1544;
	                        c[e >> 2] = -1;
	                        m = c[e >> 2] | 0;
	                        i = d;
	                        return m | 0
	                    } else {
	                        c[k >> 2] = c[g >> 2];
	                        Xy(c[(c[f >> 2] | 0) + 16 >> 2] | 0, c[k >> 2] | 0) | 0
	                    } while (0);
	                    c[e >> 2] = c[k >> 2];
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                c[e >> 2] = -1;
	                m = c[e >> 2] | 0;
	                i = d;
	                return m | 0
	            }

	            function Nk(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                do if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 28 >> 2] | 0) == 0 : 0) {
	                    b = c[f >> 2] | 0;
	                    if (c[(c[f >> 2] | 0) + 4 >> 2] | 0) {
	                        c[e >> 2] = Mk(b, c[g >> 2] | 0) | 0;
	                        break
	                    }
	                    if ((Py(c[b + 16 >> 2] | 0) | 0) == 2) {
	                        c[e >> 2] = 0;
	                        break
	                    } else {
	                        c[e >> 2] = -1;
	                        break
	                    }
	                } else h = 3; while (0);
	                if ((h | 0) == 3)c[e >> 2] = -1;
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function Ok(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 28 | 0;
	                g = e + 24 | 0;
	                h = e + 20 | 0;
	                j = e + 16 | 0;
	                k = e + 12 | 0;
	                l = e + 8 | 0;
	                m = e + 4 | 0;
	                n = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 0;
	                c[m >> 2] = 0;
	                if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 28 >> 2] | 0) == 0 : 0) {
	                    if ((c[h >> 2] | 0) < 0) {
	                        c[f >> 2] = 0;
	                        o = c[f >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    }
	                    if (c[(c[g >> 2] | 0) + 28 >> 2] | 0) {
	                        c[f >> 2] = -1;
	                        o = c[f >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    }
	                    while (1) {
	                        d = c[h >> 2] | 0;
	                        c[n >> 2] = d;
	                        c[n >> 2] = (c[n >> 2] | 0) > 16e3 ? 16e3 : d;
	                        d = c[g >> 2] | 0;
	                        if (c[(c[g >> 2] | 0) + 12 >> 2] | 0) {
	                            if (!(c[d + 20 >> 2] | 0)) {
	                                b = Ly() | 0;
	                                c[(c[g >> 2] | 0) + 20 >> 2] = b
	                            }
	                            c[l >> 2] = cz(c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[j >> 2] | 0, c[n >> 2] | 0) | 0;
	                            if (c[l >> 2] | 0) {
	                                p = 12;
	                                break
	                            }
	                            if ((_y(c[(c[g >> 2] | 0) + 16 >> 2] | 0) | 0) >>> 0 < 4e3 ? (c[n >> 2] | 0) == (c[h >> 2] | 0) : 0) {
	                                p = 32;
	                                break
	                            }
	                            c[l >> 2] = Gd(c[g >> 2] | 0, 0) | 0;
	                            if ((c[l >> 2] | 0) < 0 & (c[l >> 2] | 0) != -3) {
	                                p = 16;
	                                break
	                            }
	                            c[k >> 2] = _y(c[(c[g >> 2] | 0) + 20 >> 2] | 0) | 0
	                        } else {
	                            c[l >> 2] = cz(c[d + 16 >> 2] | 0, c[j >> 2] | 0, c[n >> 2] | 0) | 0;
	                            if (c[l >> 2] | 0) {
	                                p = 19;
	                                break
	                            }
	                            c[k >> 2] = _y(c[(c[g >> 2] | 0) + 16 >> 2] | 0) | 0
	                        }
	                        c[j >> 2] = (c[j >> 2] | 0) + (c[n >> 2] | 0);
	                        c[h >> 2] = (c[h >> 2] | 0) - (c[n >> 2] | 0);
	                        if ((c[k >> 2] | 0) < 4e3 & (c[h >> 2] | 0) <= 0) {
	                            p = 32;
	                            break
	                        }
	                        if (c[(c[g >> 2] | 0) + 4 >> 2] | 0) {
	                            d = c[(c[g >> 2] | 0) + 4 >> 2] | 0;
	                            b = c[c[g >> 2] >> 2] | 0;
	                            a = c[g >> 2] | 0;
	                            if (c[(c[g >> 2] | 0) + 12 >> 2] | 0) {
	                                q = Vy(c[a + 20 >> 2] | 0) | 0;
	                                c[l >> 2] = vb[d & 511](b, q, c[k >> 2] | 0) | 0;
	                                if ((c[l >> 2] | 0) >= 0)Ty(c[(c[g >> 2] | 0) + 20 >> 2] | 0, c[l >> 2] | 0) | 0
	                            } else {
	                                q = Vy(c[a + 16 >> 2] | 0) | 0;
	                                c[l >> 2] = vb[d & 511](b, q, c[k >> 2] | 0) | 0;
	                                if ((c[l >> 2] | 0) >= 0)Ty(c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[l >> 2] | 0) | 0
	                            }
	                            if ((c[l >> 2] | 0) < 0) {
	                                p = 29;
	                                break
	                            }
	                            q = (c[g >> 2] | 0) + 24 | 0;
	                            c[q >> 2] = (c[q >> 2] | 0) + (c[l >> 2] | 0)
	                        }
	                        c[m >> 2] = (c[m >> 2] | 0) + (c[k >> 2] | 0);
	                        if ((c[h >> 2] | 0) <= 0) {
	                            p = 32;
	                            break
	                        }
	                    }
	                    if ((p | 0) == 12) {
	                        c[f >> 2] = -1;
	                        o = c[f >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    } else if ((p | 0) == 16) {
	                        Zk(1544, 0);
	                        c[(c[g >> 2] | 0) + 28 >> 2] = 1544;
	                        c[f >> 2] = -1;
	                        o = c[f >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    } else if ((p | 0) == 19) {
	                        c[f >> 2] = -1;
	                        o = c[f >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    } else if ((p | 0) == 29) {
	                        Zk(1546, 0);
	                        c[(c[g >> 2] | 0) + 28 >> 2] = 1546;
	                        c[f >> 2] = c[l >> 2];
	                        o = c[f >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    } else if ((p | 0) == 32) {
	                        c[f >> 2] = c[m >> 2];
	                        o = c[f >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    }
	                }
	                c[f >> 2] = -1;
	                o = c[f >> 2] | 0;
	                i = e;
	                return o | 0
	            }

	            function Pk(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 40 | 0;
	                g = e + 36 | 0;
	                h = e + 32 | 0;
	                j = e + 28 | 0;
	                k = e + 24 | 0;
	                l = e + 20 | 0;
	                m = e + 16 | 0;
	                n = e + 12 | 0;
	                o = e + 8 | 0;
	                p = e + 4 | 0;
	                q = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 0;
	                c[m >> 2] = 0;
	                c[n >> 2] = 0;
	                if ((((c[g >> 2] | 0) != 0 ? !((c[h >> 2] | 0) == 0 ? 1 : (c[(c[g >> 2] | 0) + 28 >> 2] | 0) != 0) : 0) ? (c[(c[g >> 2] | 0) + 16 >> 2] | 0) != 0 : 0) ? (Py(c[(c[g >> 2] | 0) + 16 >> 2] | 0) | 0) != 2 : 0) {
	                    c[p >> 2] = ZT(c[h >> 2] | 0) | 0;
	                    if ((c[p >> 2] | 0) < 0) {
	                        c[f >> 2] = 0;
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    }
	                    if (c[(c[g >> 2] | 0) + 28 >> 2] | 0) {
	                        c[f >> 2] = -1;
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    }
	                    if (!(c[j >> 2] | 0))c[j >> 2] = 241;
	                    while (1) {
	                        c[n >> 2] = c[m >> 2];
	                        c[q >> 2] = c[p >> 2];
	                        c[o >> 2] = ($y(c[(c[g >> 2] | 0) + 16 >> 2] | 0) | 0) - 1;
	                        d = c[g >> 2] | 0;
	                        if ((c[o >> 2] | 0) < 40) {
	                            if ((Uy(c[d + 16 >> 2] | 0, 100) | 0) < 0) {
	                                s = 14;
	                                break
	                            }
	                            c[n >> 2] = -1
	                        } else {
	                            if (c[d + 12 >> 2] | 0) {
	                                if (!(c[(c[g >> 2] | 0) + 20 >> 2] | 0)) {
	                                    d = Ly() | 0;
	                                    c[(c[g >> 2] | 0) + 20 >> 2] = d
	                                }
	                                d = c[j >> 2] | 0;
	                                b = Wy(c[(c[g >> 2] | 0) + 16 >> 2] | 0) | 0;
	                                c[l >> 2] = Fb[d & 511](b, o, c[h >> 2] | 0, q) | 0;
	                                if ((c[l >> 2] | 0) < 0 | (c[o >> 2] | 0) == 0) {
	                                    s = 20;
	                                    break
	                                }
	                                Xy(c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[o >> 2] | 0) | 0;
	                                if ((_y(c[(c[g >> 2] | 0) + 16 >> 2] | 0) | 0) >>> 0 < 4e3 ? (c[q >> 2] | 0) == (c[p >> 2] | 0) : 0) {
	                                    s = 44;
	                                    break
	                                }
	                                c[l >> 2] = Gd(c[g >> 2] | 0, 0) | 0;
	                                if ((c[l >> 2] | 0) < 0 & (c[l >> 2] | 0) != -3) {
	                                    s = 24;
	                                    break
	                                }
	                                c[k >> 2] = _y(c[(c[g >> 2] | 0) + 20 >> 2] | 0) | 0
	                            } else {
	                                b = c[j >> 2] | 0;
	                                d = Wy(c[(c[g >> 2] | 0) + 16 >> 2] | 0) | 0;
	                                c[l >> 2] = Fb[b & 511](d, o, c[h >> 2] | 0, q) | 0;
	                                if ((c[l >> 2] | 0) < 0 | (c[o >> 2] | 0) == 0) {
	                                    s = 27;
	                                    break
	                                }
	                                Xy(c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[o >> 2] | 0) | 0;
	                                c[k >> 2] = _y(c[(c[g >> 2] | 0) + 16 >> 2] | 0) | 0
	                            }
	                            c[h >> 2] = (c[h >> 2] | 0) + (c[q >> 2] | 0);
	                            c[p >> 2] = (c[p >> 2] | 0) - (c[q >> 2] | 0);
	                            if ((c[k >> 2] | 0) < 4e3 & (c[p >> 2] | 0) <= 0) {
	                                s = 44;
	                                break
	                            }
	                            d = c[g >> 2] | 0;
	                            if (!(c[(c[g >> 2] | 0) + 4 >> 2] | 0)) {
	                                if (($y(c[d + 16 >> 2] | 0) | 0) >>> 0 < 4e3)Uy(c[(c[g >> 2] | 0) + 16 >> 2] | 0, 4e3) | 0
	                            } else {
	                                b = c[(c[g >> 2] | 0) + 4 >> 2] | 0;
	                                a = c[c[g >> 2] >> 2] | 0;
	                                t = c[g >> 2] | 0;
	                                if (c[d + 12 >> 2] | 0) {
	                                    d = Vy(c[t + 20 >> 2] | 0) | 0;
	                                    c[l >> 2] = vb[b & 511](a, d, c[k >> 2] | 0) | 0;
	                                    if ((c[l >> 2] | 0) >= 0)Ty(c[(c[g >> 2] | 0) + 20 >> 2] | 0, c[l >> 2] | 0) | 0
	                                } else {
	                                    d = Vy(c[t + 16 >> 2] | 0) | 0;
	                                    c[l >> 2] = vb[b & 511](a, d, c[k >> 2] | 0) | 0;
	                                    if ((c[l >> 2] | 0) >= 0)Ty(c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[l >> 2] | 0) | 0
	                                }
	                                if ((c[l >> 2] | 0) < 0) {
	                                    s = 37;
	                                    break
	                                }
	                                d = (c[g >> 2] | 0) + 24 | 0;
	                                c[d >> 2] = (c[d >> 2] | 0) + (c[l >> 2] | 0)
	                            }
	                            c[m >> 2] = (c[m >> 2] | 0) + (c[k >> 2] | 0)
	                        }
	                        if ((c[p >> 2] | 0) <= 0) {
	                            s = 44;
	                            break
	                        }
	                        if ((c[n >> 2] | 0) == (c[m >> 2] | 0)) {
	                            s = 44;
	                            break
	                        }
	                    }
	                    if ((s | 0) == 14) {
	                        c[f >> 2] = -1;
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    } else if ((s | 0) == 20) {
	                        c[f >> 2] = -1;
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    } else if ((s | 0) == 24) {
	                        Zk(1544, 0);
	                        c[(c[g >> 2] | 0) + 28 >> 2] = 1544;
	                        c[f >> 2] = -1;
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    } else if ((s | 0) == 27) {
	                        c[f >> 2] = -1;
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    } else if ((s | 0) == 37) {
	                        Zk(1546, 0);
	                        c[(c[g >> 2] | 0) + 28 >> 2] = 1546;
	                        c[f >> 2] = c[l >> 2];
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    } else if ((s | 0) == 44) {
	                        c[f >> 2] = c[m >> 2];
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    }
	                }
	                c[f >> 2] = -1;
	                r = c[f >> 2] | 0;
	                i = e;
	                return r | 0
	            }

	            function Qk(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                do if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 28 >> 2] | 0) == 0 : 0) {
	                    if (!(c[g >> 2] | 0)) {
	                        c[e >> 2] = -1;
	                        break
	                    }
	                    c[h >> 2] = ZT(c[g >> 2] | 0) | 0;
	                    if ((c[h >> 2] | 0) > 0) {
	                        c[e >> 2] = Ok(c[f >> 2] | 0, c[h >> 2] | 0, c[g >> 2] | 0) | 0;
	                        break
	                    } else {
	                        c[e >> 2] = c[h >> 2];
	                        break
	                    }
	                } else j = 3; while (0);
	                if ((j | 0) == 3)c[e >> 2] = -1;
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function Rk(b) {
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 1040 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d + 16 | 0;
	                j = d;
	                c[f >> 2] = b;
	                c[g >> 2] = 0;
	                if (!(c[19090] | 0))tk();
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                aU(h | 0, c[f >> 2] | 0, 1023) | 0;
	                a[h + 1023 >> 0] = 0;
	                c[j >> 2] = h + (ZT(h | 0) | 0);
	                while (1) {
	                    if ((c[j >> 2] | 0) >>> 0 <= h >>> 0)break;
	                    if ((a[c[j >> 2] >> 0] | 0) == 47)break;
	                    c[j >> 2] = (c[j >> 2] | 0) + -1
	                }
	                if ((a[c[j >> 2] >> 0] | 0) != 47) {
	                    if (za(h | 0, 1024) | 0) {
	                        a[h + 1023 >> 0] = 0;
	                        c[g >> 2] = Cb[c[135768 >> 2] & 511](h) | 0
	                    }
	                } else {
	                    if ((c[j >> 2] | 0) == (h | 0))a[h + 1 >> 0] = 0; else a[c[j >> 2] >> 0] = 0;
	                    c[g >> 2] = Cb[c[135768 >> 2] & 511](h) | 0
	                }
	                c[e >> 2] = c[g >> 2];
	                k = c[e >> 2] | 0;
	                i = d;
	                return k | 0
	            }

	            function Sk(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                c[d + 4 >> 2] = a;
	                c[e >> 2] = b;
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function Tk(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                c[19248] = c[d >> 2];
	                i = b;
	                return
	            }

	            function Uk() {
	                return c[19248] | 0
	            }

	            function Vk(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if ((c[g >> 2] | 0) != 0 ? (hl(c[g >> 2] | 0) | 0) == 0 : 0) {
	                    c[k >> 2] = Jl(c[g >> 2] | 0) | 0;
	                    if (!(c[k >> 2] | 0)) {
	                        al(77e3);
	                        c[f >> 2] = 0;
	                        m = c[f >> 2] | 0;
	                        i = e;
	                        return m | 0
	                    } else {
	                        c[l >> 2] = vb[c[76992 >> 2] & 511](c[k >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                        zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                        c[f >> 2] = c[l >> 2];
	                        m = c[f >> 2] | 0;
	                        i = e;
	                        return m | 0
	                    }
	                }
	                c[f >> 2] = vb[c[76992 >> 2] & 511](c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                m = c[f >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function Wk(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 0;
	                c[l >> 2] = 0;
	                c[l >> 2] = il(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                if (!(c[l >> 2] | 0))c[l >> 2] = c[g >> 2];
	                do if (c[l >> 2] | 0) {
	                    if ((uy(c[l >> 2] | 0, 77032, 6) | 0) != 0 ? (uy(c[l >> 2] | 0, 77040, 7) | 0) != 0 : 0)break;
	                    Zk(1543, c[l >> 2] | 0);
	                    if ((c[l >> 2] | 0) != (c[g >> 2] | 0))zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                } while (0);
	                c[k >> 2] = Xk(c[l >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                if ((c[l >> 2] | 0) != (c[g >> 2] | 0))zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                c[f >> 2] = c[k >> 2];
	                m = c[f >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function Xk(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 20 | 0;
	                h = e + 16 | 0;
	                j = e + 12 | 0;
	                k = e + 8 | 0;
	                l = e + 4 | 0;
	                m = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 0;
	                c[l >> 2] = 0;
	                if ((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 360 >> 2] & 2048 | 0) != 0 : 0) {
	                    c[m >> 2] = c[(c[j >> 2] | 0) + 360 >> 2];
	                    d = (c[j >> 2] | 0) + 360 | 0;
	                    c[d >> 2] = (c[d >> 2] | 0) - 2048;
	                    c[k >> 2] = Wk(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                    c[(c[j >> 2] | 0) + 360 >> 2] = c[m >> 2];
	                    c[f >> 2] = c[k >> 2];
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                c[l >> 2] = il(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                if (!(c[l >> 2] | 0))c[l >> 2] = c[g >> 2];
	                if (!(c[l >> 2] | 0)) {
	                    if (!(c[h >> 2] | 0))c[h >> 2] = 77048;
	                    ik(c[j >> 2] | 0, 77056, c[h >> 2] | 0);
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                c[k >> 2] = xe(c[j >> 2] | 0, c[l >> 2] | 0) | 0;
	                if ((c[l >> 2] | 0) != 0 ? (c[l >> 2] | 0) != (c[g >> 2] | 0) : 0)zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                c[f >> 2] = c[k >> 2];
	                n = c[f >> 2] | 0;
	                i = e;
	                return n | 0
	            }

	            function Yk(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                c[f >> 2] = c[e >> 2];
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                if (!(PT(c[e >> 2] | 0, 77176) | 0)) {
	                    c[g >> 2] = c[p >> 2];
	                    c[d >> 2] = c[g >> 2];
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                a = (uy(c[e >> 2] | 0, 77096, 17) | 0) != 0;
	                j = c[e >> 2] | 0;
	                do if (a) {
	                    k = (uy(j, 77120, 8) | 0) != 0;
	                    l = c[e >> 2] | 0;
	                    if (!k) {
	                        c[f >> 2] = l + 7;
	                        break
	                    }
	                    if (!(uy(l, 77192, 6) | 0))c[f >> 2] = (c[e >> 2] | 0) + 5
	                } else c[f >> 2] = j + 16; while (0);
	                if (!(lk(c[f >> 2] | 0) | 0)) {
	                    c[d >> 2] = 0;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                c[g >> 2] = pb(c[f >> 2] | 0, 77200) | 0;
	                if (!(c[g >> 2] | 0))Zk(0, c[f >> 2] | 0);
	                c[d >> 2] = c[g >> 2];
	                h = c[d >> 2] | 0;
	                i = b;
	                return h | 0
	            }

	            function Zk(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                hk(8, c[e >> 2] | 0, c[f >> 2] | 0);
	                i = d;
	                return
	            }

	            function _k(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                if (!(PT(c[e >> 2] | 0, 77176) | 0)) {
	                    c[g >> 2] = c[q >> 2];
	                    c[d >> 2] = c[g >> 2];
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                a = (uy(c[e >> 2] | 0, 77096, 17) | 0) != 0;
	                j = c[e >> 2] | 0;
	                do if (a) {
	                    k = (uy(j, 77120, 8) | 0) != 0;
	                    l = c[e >> 2] | 0;
	                    if (k) {
	                        c[f >> 2] = l;
	                        break
	                    } else {
	                        c[f >> 2] = l + 7;
	                        break
	                    }
	                } else c[f >> 2] = j + 16; while (0);
	                if (!(c[f >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                c[g >> 2] = pb(c[f >> 2] | 0, 77184) | 0;
	                if (!(c[g >> 2] | 0))Zk(0, c[f >> 2] | 0);
	                c[d >> 2] = c[g >> 2];
	                h = c[d >> 2] | 0;
	                i = b;
	                return h | 0
	            }

	            function $k(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) {
	                    c[f >> 2] = -1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[k >> 2] = ib(c[h >> 2] | 0, c[j >> 2] | 0, 1, c[g >> 2] | 0) | 0;
	                if ((c[k >> 2] | 0) == 0 ? (Sa(c[g >> 2] | 0) | 0) != 0 : 0) {
	                    Zk(0, 77160);
	                    c[f >> 2] = -1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[f >> 2] = ca(c[k >> 2] | 0, c[j >> 2] | 0) | 0;
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function al(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                ce(8, 2, 0, 0, c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function bl(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = -1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = (Ga(c[e >> 2] | 0) | 0) == -1;
	                c[f >> 2] = a ? -1 : 0;
	                if ((c[f >> 2] | 0) < 0)Zk(0, 76880);
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function cl(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = eb(c[f >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                if ((c[j >> 2] | 0) >= 0) {
	                    k = c[j >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                Zk(0, 77152);
	                k = c[j >> 2] | 0;
	                i = e;
	                return k | 0
	            }

	            function dl(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                c[e >> 2] = Ra(c[d >> 2] | 0) | 0;
	                if ((c[e >> 2] | 0) < 0)Zk(0, 77144);
	                i = b;
	                return c[e >> 2] | 0
	            }

	            function el(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = 0;
	                if ((c[h >> 2] | 0) > 0 ? (c[j >> 2] = Ya(c[f >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0) | 0, (c[j >> 2] | 0) < 0) : 0)Zk(0, 77136);
	                i = e;
	                return c[j >> 2] | 0
	            }

	            function fl(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0;
	                e = i;
	                i = i + 16 | 0;
	                c[e + 8 >> 2] = a;
	                c[e + 4 >> 2] = b;
	                c[e >> 2] = d;
	                i = e;
	                return 0
	            }

	            function gl(b, e, f, g) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                h = i;
	                i = i + 32 | 0;
	                j = h + 28 | 0;
	                k = h + 24 | 0;
	                l = h + 20 | 0;
	                m = h + 16 | 0;
	                n = h + 12 | 0;
	                o = h + 8 | 0;
	                p = h + 4 | 0;
	                q = h;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[l >> 2] = f;
	                c[m >> 2] = g;
	                c[n >> 2] = c[j >> 2];
	                c[o >> 2] = c[l >> 2];
	                c[p >> 2] = (c[j >> 2] | 0) + (c[c[k >> 2] >> 2] | 0);
	                c[q >> 2] = (c[l >> 2] | 0) + (c[c[m >> 2] >> 2] | 0);
	                a:while (1) {
	                    if ((c[l >> 2] | 0) >>> 0 >= (c[q >> 2] | 0) >>> 0)break;
	                    if ((c[j >> 2] | 0) >>> 0 >= (c[p >> 2] | 0) >>> 0)break;
	                    do if ((d[c[l >> 2] >> 0] | 0 | 0) == 60) {
	                        if (((c[p >> 2] | 0) - (c[j >> 2] | 0) | 0) < 4)break a;
	                        g = c[j >> 2] | 0;
	                        c[j >> 2] = g + 1;
	                        a[g >> 0] = 38;
	                        g = c[j >> 2] | 0;
	                        c[j >> 2] = g + 1;
	                        a[g >> 0] = 108;
	                        g = c[j >> 2] | 0;
	                        c[j >> 2] = g + 1;
	                        a[g >> 0] = 116;
	                        g = c[j >> 2] | 0;
	                        c[j >> 2] = g + 1;
	                        a[g >> 0] = 59
	                    } else {
	                        if ((d[c[l >> 2] >> 0] | 0 | 0) == 62) {
	                            if (((c[p >> 2] | 0) - (c[j >> 2] | 0) | 0) < 4)break a;
	                            g = c[j >> 2] | 0;
	                            c[j >> 2] = g + 1;
	                            a[g >> 0] = 38;
	                            g = c[j >> 2] | 0;
	                            c[j >> 2] = g + 1;
	                            a[g >> 0] = 103;
	                            g = c[j >> 2] | 0;
	                            c[j >> 2] = g + 1;
	                            a[g >> 0] = 116;
	                            g = c[j >> 2] | 0;
	                            c[j >> 2] = g + 1;
	                            a[g >> 0] = 59;
	                            break
	                        }
	                        if ((d[c[l >> 2] >> 0] | 0 | 0) == 38) {
	                            if (((c[p >> 2] | 0) - (c[j >> 2] | 0) | 0) < 5)break a;
	                            g = c[j >> 2] | 0;
	                            c[j >> 2] = g + 1;
	                            a[g >> 0] = 38;
	                            g = c[j >> 2] | 0;
	                            c[j >> 2] = g + 1;
	                            a[g >> 0] = 97;
	                            g = c[j >> 2] | 0;
	                            c[j >> 2] = g + 1;
	                            a[g >> 0] = 109;
	                            g = c[j >> 2] | 0;
	                            c[j >> 2] = g + 1;
	                            a[g >> 0] = 112;
	                            g = c[j >> 2] | 0;
	                            c[j >> 2] = g + 1;
	                            a[g >> 0] = 59;
	                            break
	                        }
	                        if ((d[c[l >> 2] >> 0] | 0 | 0) != 13) {
	                            g = a[c[l >> 2] >> 0] | 0;
	                            f = c[j >> 2] | 0;
	                            c[j >> 2] = f + 1;
	                            a[f >> 0] = g;
	                            break
	                        }
	                        if (((c[p >> 2] | 0) - (c[j >> 2] | 0) | 0) < 5)break a;
	                        g = c[j >> 2] | 0;
	                        c[j >> 2] = g + 1;
	                        a[g >> 0] = 38;
	                        g = c[j >> 2] | 0;
	                        c[j >> 2] = g + 1;
	                        a[g >> 0] = 35;
	                        g = c[j >> 2] | 0;
	                        c[j >> 2] = g + 1;
	                        a[g >> 0] = 49;
	                        g = c[j >> 2] | 0;
	                        c[j >> 2] = g + 1;
	                        a[g >> 0] = 51;
	                        g = c[j >> 2] | 0;
	                        c[j >> 2] = g + 1;
	                        a[g >> 0] = 59
	                    } while (0);
	                    c[l >> 2] = (c[l >> 2] | 0) + 1
	                }
	                c[c[k >> 2] >> 2] = (c[j >> 2] | 0) - (c[n >> 2] | 0);
	                c[c[m >> 2] >> 2] = (c[l >> 2] | 0) - (c[o >> 2] | 0);
	                i = h;
	                return 0
	            }

	            function hl(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = (uy(c[e >> 2] | 0, 77096, 17) | 0) != 0;
	                h = c[e >> 2] | 0;
	                do if (a) {
	                    j = (uy(h, 77120, 8) | 0) != 0;
	                    k = c[e >> 2] | 0;
	                    if (j) {
	                        c[f >> 2] = k;
	                        break
	                    } else {
	                        c[f >> 2] = k + 7;
	                        break
	                    }
	                } else c[f >> 2] = h + 16; while (0);
	                c[d >> 2] = lk(c[f >> 2] | 0) | 0;
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function il(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = 0;
	                c[k >> 2] = Gw() | 0;
	                if (!(c[k >> 2] | 0)) {
	                    m = c[j >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                if (hl(c[f >> 2] | 0) | 0) {
	                    m = c[j >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                if (((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 284 >> 2] | 0) != 0 : 0) ? (c[k >> 2] | 0) == 3 | (c[k >> 2] | 0) == 2 : 0)c[j >> 2] = Jw(c[(c[h >> 2] | 0) + 284 >> 2] | 0, c[g >> 2] | 0, c[f >> 2] | 0) | 0;
	                if ((c[j >> 2] | 0) == 0 ? (c[k >> 2] | 0) == 3 | (c[k >> 2] | 0) == 1 : 0)c[j >> 2] = Ew(c[g >> 2] | 0, c[f >> 2] | 0) | 0;
	                if ((c[j >> 2] | 0) == 0 & (c[f >> 2] | 0) != 0)c[j >> 2] = my(c[f >> 2] | 0) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    m = c[j >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                if (hl(c[j >> 2] | 0) | 0) {
	                    m = c[j >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                c[l >> 2] = 0;
	                if (((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 284 >> 2] | 0) != 0 : 0) ? (c[k >> 2] | 0) == 3 | (c[k >> 2] | 0) == 2 : 0)c[l >> 2] = Kw(c[(c[h >> 2] | 0) + 284 >> 2] | 0, c[j >> 2] | 0) | 0;
	                if ((c[l >> 2] | 0) == 0 ? (c[k >> 2] | 0) == 3 | (c[k >> 2] | 0) == 1 : 0)c[l >> 2] = Fw(c[j >> 2] | 0) | 0;
	                if (!(c[l >> 2] | 0)) {
	                    m = c[j >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                c[j >> 2] = c[l >> 2];
	                m = c[j >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function jl() {
	                var a = 0, b = 0, d = 0, e = 0;
	                a = i;
	                i = i + 16 | 0;
	                b = a;
	                d = c[33976] | 0;
	                e = c[33980] | 0;
	                c[b >> 2] = c[19636];
	                Db[d & 511](e, 78496, b);
	                i = a;
	                return
	            }

	            function kl(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e;
	                g = e + 28 | 0;
	                h = e + 24 | 0;
	                j = e + 20 | 0;
	                k = e + 16 | 0;
	                l = e + 12 | 0;
	                m = e + 8 | 0;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                if (!(c[19638] | 0))ll() | 0;
	                c[l >> 2] = iT(24 + (c[h >> 2] | 0) | 0) | 0;
	                if (!(c[l >> 2] | 0)) {
	                    Db[c[135904 >> 2] & 511](c[33980] | 0, 78560, f);
	                    ml();
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                c[c[l >> 2] >> 2] = 23205;
	                c[(c[l >> 2] | 0) + 12 >> 2] = c[h >> 2];
	                c[(c[l >> 2] | 0) + 4 >> 2] = 1;
	                c[(c[l >> 2] | 0) + 16 >> 2] = c[j >> 2];
	                c[(c[l >> 2] | 0) + 20 >> 2] = c[k >> 2];
	                rx(c[19650] | 0);
	                k = (c[19652] | 0) + 1 | 0;
	                c[19652] = k;
	                c[(c[l >> 2] | 0) + 8 >> 2] = k;
	                c[19654] = (c[19654] | 0) + (c[h >> 2] | 0);
	                c[19656] = (c[19656] | 0) + 1;
	                if ((c[19654] | 0) >>> 0 > (c[19658] | 0) >>> 0)c[19658] = c[19654];
	                sx(c[19650] | 0);
	                if ((c[19636] | 0) == (c[(c[l >> 2] | 0) + 8 >> 2] | 0))jl();
	                c[m >> 2] = (c[l >> 2] | 0) + 24;
	                if ((c[19660] | 0) == (c[m >> 2] | 0)) {
	                    l = c[33976] | 0;
	                    k = c[33980] | 0;
	                    j = c[h >> 2] | 0;
	                    c[f >> 2] = c[19660];
	                    c[f + 4 >> 2] = j;
	                    Db[l & 511](k, 78648, f);
	                    jl()
	                }
	                c[g >> 2] = c[m >> 2];
	                n = c[g >> 2] | 0;
	                i = e;
	                return n | 0
	            }

	            function ll() {
	                var a = 0, b = 0, d = 0, e = 0, f = 0, g = 0;
	                a = i;
	                i = i + 16 | 0;
	                b = a;
	                d = a + 8 | 0;
	                e = a + 4 | 0;
	                if (c[19638] | 0) {
	                    c[d >> 2] = -1;
	                    f = c[d >> 2] | 0;
	                    i = a;
	                    return f | 0
	                }
	                c[19638] = 1;
	                c[19650] = px() | 0;
	                c[e >> 2] = cb(78864) | 0;
	                if (c[e >> 2] | 0) {
	                    g = c[e >> 2] | 0;
	                    c[b >> 2] = 78544;
	                    bT(g, 78888, b) | 0
	                }
	                c[e >> 2] = cb(78896) | 0;
	                if (c[e >> 2] | 0) {
	                    g = c[e >> 2] | 0;
	                    c[b >> 2] = 78640;
	                    bT(g, 78912, b) | 0
	                }
	                c[d >> 2] = 0;
	                f = c[d >> 2] | 0;
	                i = a;
	                return f | 0
	            }

	            function ml() {
	                return
	            }

	            function nl(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = kl(c[d >> 2] | 0, 78672, 0) | 0;
	                i = b;
	                return a | 0
	            }

	            function ol(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f;
	                h = f + 40 | 0;
	                j = f + 36 | 0;
	                k = f + 32 | 0;
	                l = f + 28 | 0;
	                m = f + 24 | 0;
	                n = f + 20 | 0;
	                o = f + 16 | 0;
	                p = f + 12 | 0;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                if (!(c[j >> 2] | 0)) {
	                    c[h >> 2] = kl(c[k >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0) | 0;
	                    q = c[h >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                if (!(c[19638] | 0))ll() | 0;
	                c[n >> 2] = (c[j >> 2] | 0) + -24;
	                c[p >> 2] = c[(c[n >> 2] | 0) + 8 >> 2];
	                if ((c[19636] | 0) == (c[p >> 2] | 0))jl();
	                e = c[n >> 2] | 0;
	                do if ((c[c[n >> 2] >> 2] | 0) != 23205)xl(e); else {
	                    c[e >> 2] = -23206;
	                    rx(c[19650] | 0);
	                    c[19654] = (c[19654] | 0) - (c[(c[n >> 2] | 0) + 12 >> 2] | 0);
	                    c[19656] = (c[19656] | 0) + -1;
	                    sx(c[19650] | 0);
	                    c[o >> 2] = kT(c[n >> 2] | 0, 24 + (c[k >> 2] | 0) | 0) | 0;
	                    if (!(c[o >> 2] | 0)) {
	                        jT(c[n >> 2] | 0);
	                        break
	                    }
	                    c[n >> 2] = c[o >> 2];
	                    if ((c[19660] | 0) == (c[j >> 2] | 0)) {
	                        d = c[33976] | 0;
	                        b = c[33980] | 0;
	                        a = c[(c[n >> 2] | 0) + 12 >> 2] | 0;
	                        r = c[k >> 2] | 0;
	                        c[g >> 2] = c[19660];
	                        c[g + 4 >> 2] = a;
	                        c[g + 8 >> 2] = r;
	                        Db[d & 511](b, 78680, g);
	                        jl()
	                    }
	                    c[c[n >> 2] >> 2] = 23205;
	                    c[(c[n >> 2] | 0) + 8 >> 2] = c[p >> 2];
	                    c[(c[n >> 2] | 0) + 4 >> 2] = 2;
	                    c[(c[n >> 2] | 0) + 12 >> 2] = c[k >> 2];
	                    c[(c[n >> 2] | 0) + 16 >> 2] = c[l >> 2];
	                    c[(c[n >> 2] | 0) + 20 >> 2] = c[m >> 2];
	                    rx(c[19650] | 0);
	                    c[19654] = (c[19654] | 0) + (c[k >> 2] | 0);
	                    c[19656] = (c[19656] | 0) + 1;
	                    if ((c[19654] | 0) >>> 0 > (c[19658] | 0) >>> 0)c[19658] = c[19654];
	                    sx(c[19650] | 0);
	                    c[h >> 2] = (c[n >> 2] | 0) + 24;
	                    q = c[h >> 2] | 0;
	                    i = f;
	                    return q | 0
	                } while (0);
	                c[h >> 2] = 0;
	                q = c[h >> 2] | 0;
	                i = f;
	                return q | 0
	            }

	            function pl(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                b = ol(c[e >> 2] | 0, c[f >> 2] | 0, 78672, 0) | 0;
	                i = d;
	                return b | 0
	            }

	            function ql(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                g = b + 4 | 0;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                do if ((c[e >> 2] | 0) == (-1 | 0))Db[c[135904 >> 2] & 511](c[33980] | 0, 78712, d); else {
	                    if ((c[19660] | 0) == (c[e >> 2] | 0)) {
	                        a = c[33976] | 0;
	                        h = c[33980] | 0;
	                        c[d >> 2] = c[19660];
	                        Db[a & 511](h, 78752, d);
	                        jl()
	                    }
	                    c[g >> 2] = c[e >> 2];
	                    c[f >> 2] = (c[e >> 2] | 0) + -24;
	                    if ((c[c[f >> 2] >> 2] | 0) != 23205) {
	                        xl(c[f >> 2] | 0);
	                        break
	                    }
	                    if ((c[19636] | 0) == (c[(c[f >> 2] | 0) + 8 >> 2] | 0))jl();
	                    c[c[f >> 2] >> 2] = -23206;
	                    cU(c[g >> 2] | 0, -1, c[(c[f >> 2] | 0) + 12 >> 2] | 0) | 0;
	                    rx(c[19650] | 0);
	                    c[19654] = (c[19654] | 0) - (c[(c[f >> 2] | 0) + 12 >> 2] | 0);
	                    c[19656] = (c[19656] | 0) + -1;
	                    sx(c[19650] | 0);
	                    jT(c[f >> 2] | 0);
	                    i = b;
	                    return
	                } while (0);
	                f = c[33976] | 0;
	                g = c[33980] | 0;
	                c[d >> 2] = c[e >> 2];
	                Db[f & 511](g, 78768, d);
	                jl();
	                i = b;
	                return
	            }

	            function rl(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e;
	                g = e + 28 | 0;
	                h = e + 24 | 0;
	                j = e + 20 | 0;
	                k = e + 16 | 0;
	                l = e + 12 | 0;
	                m = e + 8 | 0;
	                n = e + 4 | 0;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[m >> 2] = (ZT(c[h >> 2] | 0) | 0) + 1;
	                if (!(c[19638] | 0))ll() | 0;
	                c[n >> 2] = iT(24 + (c[m >> 2] | 0) | 0) | 0;
	                if (!(c[n >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    o = c[g >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                c[c[n >> 2] >> 2] = 23205;
	                c[(c[n >> 2] | 0) + 12 >> 2] = c[m >> 2];
	                c[(c[n >> 2] | 0) + 4 >> 2] = 3;
	                c[(c[n >> 2] | 0) + 16 >> 2] = c[j >> 2];
	                c[(c[n >> 2] | 0) + 20 >> 2] = c[k >> 2];
	                rx(c[19650] | 0);
	                k = (c[19652] | 0) + 1 | 0;
	                c[19652] = k;
	                c[(c[n >> 2] | 0) + 8 >> 2] = k;
	                c[19654] = (c[19654] | 0) + (c[m >> 2] | 0);
	                c[19656] = (c[19656] | 0) + 1;
	                if ((c[19654] | 0) >>> 0 > (c[19658] | 0) >>> 0)c[19658] = c[19654];
	                sx(c[19650] | 0);
	                c[l >> 2] = (c[n >> 2] | 0) + 24;
	                if ((c[19636] | 0) == (c[(c[n >> 2] | 0) + 8 >> 2] | 0))jl();
	                gU(c[l >> 2] | 0, c[h >> 2] | 0) | 0;
	                if ((c[19660] | 0) == (c[l >> 2] | 0)) {
	                    h = c[33976] | 0;
	                    n = c[33980] | 0;
	                    c[f >> 2] = c[19660];
	                    Db[h & 511](n, 78792, f);
	                    jl()
	                }
	                c[g >> 2] = c[l >> 2];
	                o = c[g >> 2] | 0;
	                i = e;
	                return o | 0
	            }

	            function sl(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = rl(c[d >> 2] | 0, 78672, 0) | 0;
	                i = b;
	                return a | 0
	            }

	            function tl() {
	                return c[19654] | 0
	            }

	            function ul(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                f = d + 12 | 0;
	                c[f >> 2] = a;
	                c[d + 8 >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                b = c[f >> 2] | 0;
	                f = c[19658] | 0;
	                c[e >> 2] = c[19654];
	                c[e + 4 >> 2] = f;
	                Ka(b | 0, 78816, e | 0) | 0;
	                i = d;
	                return
	            }

	            function vl() {
	                var a = 0;
	                a = i;
	                if (!(c[19638] | 0)) {
	                    i = a;
	                    return
	                }
	                qx(c[19650] | 0);
	                c[19650] = 0;
	                c[19638] = 0;
	                i = a;
	                return
	            }

	            function wl(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                do if (c[h >> 2] | 0) {
	                    if (!(c[j >> 2] | 0)) {
	                        c[g >> 2] = -1;
	                        break
	                    }
	                    if (!(c[k >> 2] | 0)) {
	                        c[g >> 2] = -1;
	                        break
	                    }
	                    if (!(c[l >> 2] | 0)) {
	                        c[g >> 2] = -1;
	                        break
	                    } else {
	                        c[33934] = c[h >> 2];
	                        c[33936] = c[j >> 2];
	                        c[33938] = c[j >> 2];
	                        c[33940] = c[k >> 2];
	                        c[33942] = c[l >> 2];
	                        c[g >> 2] = 0;
	                        break
	                    }
	                } else c[g >> 2] = -1; while (0);
	                i = f;
	                return c[g >> 2] | 0
	            }

	            function xl(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                e = b + 4 | 0;
	                c[e >> 2] = a;
	                a = c[33976] | 0;
	                f = c[33980] | 0;
	                c[d >> 2] = c[e >> 2];
	                Db[a & 511](f, 78920, d);
	                i = b;
	                return
	            }

	            function yl(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                c[f >> 2] = zl() | 0;
	                if ((c[f >> 2] | 0) != 0 ? (c[g >> 2] = Ll(c[f >> 2] | 0, c[e >> 2] | 0) | 0, (c[g >> 2] | 0) != 0) : 0) {
	                    Al(c[f >> 2] | 0);
	                    c[d >> 2] = 0;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                c[d >> 2] = c[f >> 2];
	                h = c[d >> 2] | 0;
	                i = b;
	                return h | 0
	            }

	            function zl() {
	                var a = 0, b = 0, d = 0, e = 0, f = 0, g = 0;
	                a = i;
	                i = i + 16 | 0;
	                b = a + 4 | 0;
	                d = a;
	                c[d >> 2] = Cb[c[135744 >> 2] & 511](44) | 0;
	                if (!(c[d >> 2] | 0)) {
	                    Ml(78960);
	                    c[b >> 2] = 0;
	                    e = c[b >> 2] | 0;
	                    i = a;
	                    return e | 0
	                } else {
	                    f = (c[d >> 2] | 0) + 0 | 0;
	                    g = f + 44 | 0;
	                    do {
	                        c[f >> 2] = 0;
	                        f = f + 4 | 0
	                    } while ((f | 0) < (g | 0));
	                    c[b >> 2] = c[d >> 2];
	                    e = c[b >> 2] | 0;
	                    i = a;
	                    return e | 0
	                }
	                return 0
	            }

	            function Al(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[c[d >> 2] >> 2] | 0)zb[c[135736 >> 2] & 511](c[c[d >> 2] >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 12 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 12 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 16 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 16 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 24 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 24 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 32 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 32 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 4 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 4 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 8 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 28 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 28 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 40 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 40 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function Bl(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                b = Ll(c[e >> 2] | 0, c[f >> 2] | 0) | 0;
	                i = d;
	                return b | 0
	            }

	            function Cl(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0, J = 0, K = 0, L = 0;
	                e = i;
	                i = i + 112 | 0;
	                f = e;
	                g = e + 100 | 0;
	                h = e + 96 | 0;
	                j = e + 92 | 0;
	                k = e + 88 | 0;
	                l = e + 84 | 0;
	                m = e + 80 | 0;
	                n = e + 76 | 0;
	                o = e + 72 | 0;
	                p = e + 68 | 0;
	                q = e + 64 | 0;
	                r = e + 60 | 0;
	                s = e + 56 | 0;
	                t = e + 52 | 0;
	                u = e + 48 | 0;
	                v = e + 44 | 0;
	                w = e + 40 | 0;
	                x = e + 36 | 0;
	                y = e + 32 | 0;
	                z = e + 28 | 0;
	                A = e + 24 | 0;
	                B = e + 20 | 0;
	                C = e + 16 | 0;
	                D = e + 12 | 0;
	                E = e + 8 | 0;
	                F = e + 4 | 0;
	                c[h >> 2] = b;
	                c[j >> 2] = 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    G = c[g >> 2] | 0;
	                    i = e;
	                    return G | 0
	                }
	                c[n >> 2] = 80;
	                c[j >> 2] = Cb[c[135752 >> 2] & 511]((c[n >> 2] | 0) + 1 | 0) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    Ml(78984);
	                    c[g >> 2] = 0;
	                    G = c[g >> 2] | 0;
	                    i = e;
	                    return G | 0
	                }
	                c[m >> 2] = 0;
	                a:do if (c[c[h >> 2] >> 2] | 0) {
	                    c[l >> 2] = c[c[h >> 2] >> 2];
	                    while (1) {
	                        H = (c[m >> 2] | 0) >= (c[n >> 2] | 0);
	                        if (!(a[c[l >> 2] >> 0] | 0))break;
	                        if (H) {
	                            c[k >> 2] = Nl(c[j >> 2] | 0, n) | 0;
	                            if (!(c[k >> 2] | 0))break a;
	                            c[j >> 2] = c[k >> 2]
	                        }
	                        b = c[l >> 2] | 0;
	                        c[l >> 2] = b + 1;
	                        I = a[b >> 0] | 0;
	                        b = c[m >> 2] | 0;
	                        c[m >> 2] = b + 1;
	                        a[(c[j >> 2] | 0) + b >> 0] = I
	                    }
	                    if (H) {
	                        c[k >> 2] = Nl(c[j >> 2] | 0, n) | 0;
	                        if (!(c[k >> 2] | 0))break;
	                        c[j >> 2] = c[k >> 2]
	                    }
	                    I = c[m >> 2] | 0;
	                    c[m >> 2] = I + 1;
	                    a[(c[j >> 2] | 0) + I >> 0] = 58;
	                    J = 16
	                } else J = 16; while (0);
	                b:do if ((J | 0) == 16) {
	                    H = c[h >> 2] | 0;
	                    c:do if (!(c[(c[h >> 2] | 0) + 4 >> 2] | 0)) {
	                        d:do if ((c[H + 12 >> 2] | 0) == 0 ? (c[(c[h >> 2] | 0) + 20 >> 2] | 0) != -1 : 0) {
	                            if (!(c[(c[h >> 2] | 0) + 8 >> 2] | 0)) {
	                                if (!(c[c[h >> 2] >> 2] | 0))break;
	                                if (((c[m >> 2] | 0) + 3 | 0) < (c[n >> 2] | 0))break;
	                                c[k >> 2] = Nl(c[j >> 2] | 0, n) | 0;
	                                if (!(c[k >> 2] | 0))break b;
	                                c[j >> 2] = c[k >> 2];
	                                break
	                            }
	                            if (((c[m >> 2] | 0) + 3 | 0) >= (c[n >> 2] | 0)) {
	                                c[k >> 2] = Nl(c[j >> 2] | 0, n) | 0;
	                                if (!(c[k >> 2] | 0))break b;
	                                c[j >> 2] = c[k >> 2]
	                            }
	                            I = c[m >> 2] | 0;
	                            c[m >> 2] = I + 1;
	                            a[(c[j >> 2] | 0) + I >> 0] = 47;
	                            I = c[m >> 2] | 0;
	                            c[m >> 2] = I + 1;
	                            a[(c[j >> 2] | 0) + I >> 0] = 47;
	                            c[l >> 2] = c[(c[h >> 2] | 0) + 8 >> 2];
	                            e:while (1) {
	                                if (!(a[c[l >> 2] >> 0] | 0))break d;
	                                if (((c[m >> 2] | 0) + 3 | 0) >= (c[n >> 2] | 0)) {
	                                    c[k >> 2] = Nl(c[j >> 2] | 0, n) | 0;
	                                    if (!(c[k >> 2] | 0))break b;
	                                    c[j >> 2] = c[k >> 2]
	                                }
	                                if (!((a[c[l >> 2] >> 0] | 0) >= 97 ? (a[c[l >> 2] >> 0] | 0) <= 122 : 0))J = 113;
	                                do if ((J | 0) == 113) {
	                                    J = 0;
	                                    if ((a[c[l >> 2] >> 0] | 0) >= 65 ? (a[c[l >> 2] >> 0] | 0) <= 90 : 0)break;
	                                    if ((a[c[l >> 2] >> 0] | 0) >= 48 ? (a[c[l >> 2] >> 0] | 0) <= 57 : 0)break;
	                                    if ((a[c[l >> 2] >> 0] | 0) != 45 ? (a[c[l >> 2] >> 0] | 0) != 95 : 0) {
	                                        if ((a[c[l >> 2] >> 0] | 0) == 46)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 33)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 126)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 42)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 39)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 40)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 41)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 36)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 44)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 59)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 58)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 64)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 38)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 61)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 43)break;
	                                        I = c[l >> 2] | 0;
	                                        c[l >> 2] = I + 1;
	                                        c[u >> 2] = d[I >> 0];
	                                        c[v >> 2] = (c[u >> 2] | 0) / 16 | 0;
	                                        c[w >> 2] = (c[u >> 2] | 0) % 16 | 0;
	                                        I = c[m >> 2] | 0;
	                                        c[m >> 2] = I + 1;
	                                        a[(c[j >> 2] | 0) + I >> 0] = 37;
	                                        I = (c[v >> 2] | 0) + ((c[v >> 2] | 0) > 9 ? 55 : 48) & 255;
	                                        b = c[m >> 2] | 0;
	                                        c[m >> 2] = b + 1;
	                                        a[(c[j >> 2] | 0) + b >> 0] = I;
	                                        I = (c[w >> 2] | 0) + ((c[w >> 2] | 0) > 9 ? 55 : 48) & 255;
	                                        b = c[m >> 2] | 0;
	                                        c[m >> 2] = b + 1;
	                                        a[(c[j >> 2] | 0) + b >> 0] = I;
	                                        continue e
	                                    }
	                                } while (0);
	                                I = c[l >> 2] | 0;
	                                c[l >> 2] = I + 1;
	                                b = a[I >> 0] | 0;
	                                I = c[m >> 2] | 0;
	                                c[m >> 2] = I + 1;
	                                a[(c[j >> 2] | 0) + I >> 0] = b
	                            }
	                        } else J = 53; while (0);
	                        if ((J | 0) == 53) {
	                            if (((c[m >> 2] | 0) + 3 | 0) >= (c[n >> 2] | 0)) {
	                                c[k >> 2] = Nl(c[j >> 2] | 0, n) | 0;
	                                if (!(c[k >> 2] | 0))break b;
	                                c[j >> 2] = c[k >> 2]
	                            }
	                            b = c[m >> 2] | 0;
	                            c[m >> 2] = b + 1;
	                            a[(c[j >> 2] | 0) + b >> 0] = 47;
	                            b = c[m >> 2] | 0;
	                            c[m >> 2] = b + 1;
	                            a[(c[j >> 2] | 0) + b >> 0] = 47;
	                            if (c[(c[h >> 2] | 0) + 16 >> 2] | 0) {
	                                c[l >> 2] = c[(c[h >> 2] | 0) + 16 >> 2];
	                                f:while (1) {
	                                    K = ((c[m >> 2] | 0) + 3 | 0) >= (c[n >> 2] | 0);
	                                    if (!(a[c[l >> 2] >> 0] | 0))break;
	                                    if (K) {
	                                        c[k >> 2] = Nl(c[j >> 2] | 0, n) | 0;
	                                        if (!(c[k >> 2] | 0))break b;
	                                        c[j >> 2] = c[k >> 2]
	                                    }
	                                    if (!((a[c[l >> 2] >> 0] | 0) >= 97 ? (a[c[l >> 2] >> 0] | 0) <= 122 : 0))J = 64;
	                                    do if ((J | 0) == 64) {
	                                        J = 0;
	                                        if ((a[c[l >> 2] >> 0] | 0) >= 65 ? (a[c[l >> 2] >> 0] | 0) <= 90 : 0)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) >= 48 ? (a[c[l >> 2] >> 0] | 0) <= 57 : 0)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) != 45 ? (a[c[l >> 2] >> 0] | 0) != 95 : 0) {
	                                            if ((a[c[l >> 2] >> 0] | 0) == 46)break;
	                                            if ((a[c[l >> 2] >> 0] | 0) == 33)break;
	                                            if ((a[c[l >> 2] >> 0] | 0) == 126)break;
	                                            if ((a[c[l >> 2] >> 0] | 0) == 42)break;
	                                            if ((a[c[l >> 2] >> 0] | 0) == 39)break;
	                                            if ((a[c[l >> 2] >> 0] | 0) == 40)break;
	                                            if ((a[c[l >> 2] >> 0] | 0) == 41)break;
	                                            if ((a[c[l >> 2] >> 0] | 0) == 59)break;
	                                            if ((a[c[l >> 2] >> 0] | 0) == 58)break;
	                                            if ((a[c[l >> 2] >> 0] | 0) == 38)break;
	                                            if ((a[c[l >> 2] >> 0] | 0) == 61)break;
	                                            if ((a[c[l >> 2] >> 0] | 0) == 43)break;
	                                            if ((a[c[l >> 2] >> 0] | 0) == 36)break;
	                                            if ((a[c[l >> 2] >> 0] | 0) == 44)break;
	                                            b = c[l >> 2] | 0;
	                                            c[l >> 2] = b + 1;
	                                            c[r >> 2] = d[b >> 0];
	                                            c[s >> 2] = (c[r >> 2] | 0) / 16 | 0;
	                                            c[t >> 2] = (c[r >> 2] | 0) % 16 | 0;
	                                            b = c[m >> 2] | 0;
	                                            c[m >> 2] = b + 1;
	                                            a[(c[j >> 2] | 0) + b >> 0] = 37;
	                                            b = (c[s >> 2] | 0) + ((c[s >> 2] | 0) > 9 ? 55 : 48) & 255;
	                                            I = c[m >> 2] | 0;
	                                            c[m >> 2] = I + 1;
	                                            a[(c[j >> 2] | 0) + I >> 0] = b;
	                                            b = (c[t >> 2] | 0) + ((c[t >> 2] | 0) > 9 ? 55 : 48) & 255;
	                                            I = c[m >> 2] | 0;
	                                            c[m >> 2] = I + 1;
	                                            a[(c[j >> 2] | 0) + I >> 0] = b;
	                                            continue f
	                                        }
	                                    } while (0);
	                                    b = c[l >> 2] | 0;
	                                    c[l >> 2] = b + 1;
	                                    I = a[b >> 0] | 0;
	                                    b = c[m >> 2] | 0;
	                                    c[m >> 2] = b + 1;
	                                    a[(c[j >> 2] | 0) + b >> 0] = I
	                                }
	                                if (K) {
	                                    c[k >> 2] = Nl(c[j >> 2] | 0, n) | 0;
	                                    if (!(c[k >> 2] | 0))break b;
	                                    c[j >> 2] = c[k >> 2]
	                                }
	                                I = c[m >> 2] | 0;
	                                c[m >> 2] = I + 1;
	                                a[(c[j >> 2] | 0) + I >> 0] = 64
	                            }
	                            if (c[(c[h >> 2] | 0) + 12 >> 2] | 0) {
	                                c[l >> 2] = c[(c[h >> 2] | 0) + 12 >> 2];
	                                while (1) {
	                                    if (!(a[c[l >> 2] >> 0] | 0))break;
	                                    if ((c[m >> 2] | 0) >= (c[n >> 2] | 0)) {
	                                        c[k >> 2] = Nl(c[j >> 2] | 0, n) | 0;
	                                        if (!(c[k >> 2] | 0))break b;
	                                        c[j >> 2] = c[k >> 2]
	                                    }
	                                    I = c[l >> 2] | 0;
	                                    c[l >> 2] = I + 1;
	                                    b = a[I >> 0] | 0;
	                                    I = c[m >> 2] | 0;
	                                    c[m >> 2] = I + 1;
	                                    a[(c[j >> 2] | 0) + I >> 0] = b
	                                }
	                                if ((c[(c[h >> 2] | 0) + 20 >> 2] | 0) > 0) {
	                                    if (((c[m >> 2] | 0) + 10 | 0) >= (c[n >> 2] | 0)) {
	                                        c[k >> 2] = Nl(c[j >> 2] | 0, n) | 0;
	                                        if (!(c[k >> 2] | 0))break b;
	                                        c[j >> 2] = c[k >> 2]
	                                    }
	                                    b = (c[j >> 2] | 0) + (c[m >> 2] | 0) | 0;
	                                    I = (c[n >> 2] | 0) - (c[m >> 2] | 0) | 0;
	                                    c[f >> 2] = c[(c[h >> 2] | 0) + 20 >> 2];
	                                    L = JT(b, I, 79e3, f) | 0;
	                                    c[m >> 2] = (c[m >> 2] | 0) + L
	                                }
	                            }
	                        }
	                        g:do if (c[(c[h >> 2] | 0) + 24 >> 2] | 0) {
	                            c[l >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                            do if ((c[c[h >> 2] >> 2] | 0) != 0 ? (a[c[l >> 2] >> 0] | 0) == 47 : 0) {
	                                if (!((a[(c[l >> 2] | 0) + 1 >> 0] | 0) >= 97 ? (a[(c[l >> 2] | 0) + 1 >> 0] | 0) <= 122 : 0)) {
	                                    if ((a[(c[l >> 2] | 0) + 1 >> 0] | 0) < 65)break;
	                                    if ((a[(c[l >> 2] | 0) + 1 >> 0] | 0) > 90)break
	                                }
	                                if ((a[(c[l >> 2] | 0) + 2 >> 0] | 0) == 58 ? (qy(c[c[h >> 2] >> 2] | 0, 79008) | 0) != 0 : 0) {
	                                    if (((c[m >> 2] | 0) + 3 | 0) >= (c[n >> 2] | 0)) {
	                                        c[k >> 2] = Nl(c[j >> 2] | 0, n) | 0;
	                                        if (!(c[k >> 2] | 0))break b;
	                                        c[j >> 2] = c[k >> 2]
	                                    }
	                                    L = c[l >> 2] | 0;
	                                    c[l >> 2] = L + 1;
	                                    I = a[L >> 0] | 0;
	                                    L = c[m >> 2] | 0;
	                                    c[m >> 2] = L + 1;
	                                    a[(c[j >> 2] | 0) + L >> 0] = I;
	                                    I = c[l >> 2] | 0;
	                                    c[l >> 2] = I + 1;
	                                    L = a[I >> 0] | 0;
	                                    I = c[m >> 2] | 0;
	                                    c[m >> 2] = I + 1;
	                                    a[(c[j >> 2] | 0) + I >> 0] = L;
	                                    L = c[l >> 2] | 0;
	                                    c[l >> 2] = L + 1;
	                                    I = a[L >> 0] | 0;
	                                    L = c[m >> 2] | 0;
	                                    c[m >> 2] = L + 1;
	                                    a[(c[j >> 2] | 0) + L >> 0] = I
	                                }
	                            } while (0);
	                            h:while (1) {
	                                if (!(a[c[l >> 2] >> 0] | 0))break g;
	                                if (((c[m >> 2] | 0) + 3 | 0) >= (c[n >> 2] | 0)) {
	                                    c[k >> 2] = Nl(c[j >> 2] | 0, n) | 0;
	                                    if (!(c[k >> 2] | 0))break b;
	                                    c[j >> 2] = c[k >> 2]
	                                }
	                                if (!((a[c[l >> 2] >> 0] | 0) >= 97 ? (a[c[l >> 2] >> 0] | 0) <= 122 : 0))J = 159;
	                                do if ((J | 0) == 159) {
	                                    J = 0;
	                                    if ((a[c[l >> 2] >> 0] | 0) >= 65 ? (a[c[l >> 2] >> 0] | 0) <= 90 : 0)break;
	                                    if ((a[c[l >> 2] >> 0] | 0) >= 48 ? (a[c[l >> 2] >> 0] | 0) <= 57 : 0)break;
	                                    if (((a[c[l >> 2] >> 0] | 0) != 45 ? (a[c[l >> 2] >> 0] | 0) != 95 : 0) ? (a[c[l >> 2] >> 0] | 0) != 46 : 0) {
	                                        if ((a[c[l >> 2] >> 0] | 0) == 33)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 126)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 42)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 39)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 40)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 41)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 47)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 59)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 64)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 38)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 61)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 43)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 36)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 44)break;
	                                        I = c[l >> 2] | 0;
	                                        c[l >> 2] = I + 1;
	                                        c[x >> 2] = d[I >> 0];
	                                        c[y >> 2] = (c[x >> 2] | 0) / 16 | 0;
	                                        c[z >> 2] = (c[x >> 2] | 0) % 16 | 0;
	                                        I = c[m >> 2] | 0;
	                                        c[m >> 2] = I + 1;
	                                        a[(c[j >> 2] | 0) + I >> 0] = 37;
	                                        I = (c[y >> 2] | 0) + ((c[y >> 2] | 0) > 9 ? 55 : 48) & 255;
	                                        L = c[m >> 2] | 0;
	                                        c[m >> 2] = L + 1;
	                                        a[(c[j >> 2] | 0) + L >> 0] = I;
	                                        I = (c[z >> 2] | 0) + ((c[z >> 2] | 0) > 9 ? 55 : 48) & 255;
	                                        L = c[m >> 2] | 0;
	                                        c[m >> 2] = L + 1;
	                                        a[(c[j >> 2] | 0) + L >> 0] = I;
	                                        continue h
	                                    }
	                                } while (0);
	                                I = c[l >> 2] | 0;
	                                c[l >> 2] = I + 1;
	                                L = a[I >> 0] | 0;
	                                I = c[m >> 2] | 0;
	                                c[m >> 2] = I + 1;
	                                a[(c[j >> 2] | 0) + I >> 0] = L
	                            }
	                        } while (0);
	                        if (c[(c[h >> 2] | 0) + 40 >> 2] | 0) {
	                            if (((c[m >> 2] | 0) + 1 | 0) >= (c[n >> 2] | 0)) {
	                                c[k >> 2] = Nl(c[j >> 2] | 0, n) | 0;
	                                if (!(c[k >> 2] | 0))break b;
	                                c[j >> 2] = c[k >> 2]
	                            }
	                            L = c[m >> 2] | 0;
	                            c[m >> 2] = L + 1;
	                            a[(c[j >> 2] | 0) + L >> 0] = 63;
	                            c[l >> 2] = c[(c[h >> 2] | 0) + 40 >> 2];
	                            while (1) {
	                                if (!(a[c[l >> 2] >> 0] | 0))break c;
	                                if (((c[m >> 2] | 0) + 1 | 0) >= (c[n >> 2] | 0)) {
	                                    c[k >> 2] = Nl(c[j >> 2] | 0, n) | 0;
	                                    if (!(c[k >> 2] | 0))break b;
	                                    c[j >> 2] = c[k >> 2]
	                                }
	                                L = c[l >> 2] | 0;
	                                c[l >> 2] = L + 1;
	                                I = a[L >> 0] | 0;
	                                L = c[m >> 2] | 0;
	                                c[m >> 2] = L + 1;
	                                a[(c[j >> 2] | 0) + L >> 0] = I
	                            }
	                        }
	                        if (c[(c[h >> 2] | 0) + 28 >> 2] | 0) {
	                            if (((c[m >> 2] | 0) + 3 | 0) >= (c[n >> 2] | 0)) {
	                                c[k >> 2] = Nl(c[j >> 2] | 0, n) | 0;
	                                if (!(c[k >> 2] | 0))break b;
	                                c[j >> 2] = c[k >> 2]
	                            }
	                            I = c[m >> 2] | 0;
	                            c[m >> 2] = I + 1;
	                            a[(c[j >> 2] | 0) + I >> 0] = 63;
	                            c[l >> 2] = c[(c[h >> 2] | 0) + 28 >> 2];
	                            i:while (1) {
	                                if (!(a[c[l >> 2] >> 0] | 0))break c;
	                                if (((c[m >> 2] | 0) + 3 | 0) >= (c[n >> 2] | 0)) {
	                                    c[k >> 2] = Nl(c[j >> 2] | 0, n) | 0;
	                                    if (!(c[k >> 2] | 0))break b;
	                                    c[j >> 2] = c[k >> 2]
	                                }
	                                if (!((a[c[l >> 2] >> 0] | 0) >= 97 ? (a[c[l >> 2] >> 0] | 0) <= 122 : 0))J = 203;
	                                do if ((J | 0) == 203) {
	                                    J = 0;
	                                    if ((a[c[l >> 2] >> 0] | 0) >= 65 ? (a[c[l >> 2] >> 0] | 0) <= 90 : 0)break;
	                                    if ((a[c[l >> 2] >> 0] | 0) >= 48 ? (a[c[l >> 2] >> 0] | 0) <= 57 : 0)break;
	                                    if ((a[c[l >> 2] >> 0] | 0) != 45 ? (a[c[l >> 2] >> 0] | 0) != 95 : 0) {
	                                        if ((a[c[l >> 2] >> 0] | 0) == 46)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 33)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 126)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 42)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 39)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 40)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 41)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 59)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 47)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 63)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 58)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 64)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 38)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 61)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 43)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 36)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 44)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 91)break;
	                                        if ((a[c[l >> 2] >> 0] | 0) == 93)break;
	                                        I = c[l >> 2] | 0;
	                                        c[l >> 2] = I + 1;
	                                        c[A >> 2] = d[I >> 0];
	                                        c[B >> 2] = (c[A >> 2] | 0) / 16 | 0;
	                                        c[C >> 2] = (c[A >> 2] | 0) % 16 | 0;
	                                        I = c[m >> 2] | 0;
	                                        c[m >> 2] = I + 1;
	                                        a[(c[j >> 2] | 0) + I >> 0] = 37;
	                                        I = (c[B >> 2] | 0) + ((c[B >> 2] | 0) > 9 ? 55 : 48) & 255;
	                                        L = c[m >> 2] | 0;
	                                        c[m >> 2] = L + 1;
	                                        a[(c[j >> 2] | 0) + L >> 0] = I;
	                                        I = (c[C >> 2] | 0) + ((c[C >> 2] | 0) > 9 ? 55 : 48) & 255;
	                                        L = c[m >> 2] | 0;
	                                        c[m >> 2] = L + 1;
	                                        a[(c[j >> 2] | 0) + L >> 0] = I;
	                                        continue i
	                                    }
	                                } while (0);
	                                I = c[l >> 2] | 0;
	                                c[l >> 2] = I + 1;
	                                L = a[I >> 0] | 0;
	                                I = c[m >> 2] | 0;
	                                c[m >> 2] = I + 1;
	                                a[(c[j >> 2] | 0) + I >> 0] = L
	                            }
	                        }
	                    } else {
	                        c[l >> 2] = c[H + 4 >> 2];
	                        j:while (1) {
	                            if (!(a[c[l >> 2] >> 0] | 0))break c;
	                            if (((c[m >> 2] | 0) + 3 | 0) >= (c[n >> 2] | 0)) {
	                                c[k >> 2] = Nl(c[j >> 2] | 0, n) | 0;
	                                if (!(c[k >> 2] | 0))break b;
	                                c[j >> 2] = c[k >> 2]
	                            }
	                            do if ((((((((((a[c[l >> 2] >> 0] | 0) != 59 ? (a[c[l >> 2] >> 0] | 0) != 47 : 0) ? (a[c[l >> 2] >> 0] | 0) != 63 : 0) ? (a[c[l >> 2] >> 0] | 0) != 58 : 0) ? (a[c[l >> 2] >> 0] | 0) != 64 : 0) ? (a[c[l >> 2] >> 0] | 0) != 38 : 0) ? (a[c[l >> 2] >> 0] | 0) != 61 : 0) ? (a[c[l >> 2] >> 0] | 0) != 43 : 0) ? (a[c[l >> 2] >> 0] | 0) != 36 : 0) ? (a[c[l >> 2] >> 0] | 0) != 44 : 0) {
	                                if ((a[c[l >> 2] >> 0] | 0) == 91)break;
	                                if ((a[c[l >> 2] >> 0] | 0) == 93)break;
	                                if ((a[c[l >> 2] >> 0] | 0) >= 97 ? (a[c[l >> 2] >> 0] | 0) <= 122 : 0)break;
	                                if ((a[c[l >> 2] >> 0] | 0) >= 65 ? (a[c[l >> 2] >> 0] | 0) <= 90 : 0)break;
	                                if ((a[c[l >> 2] >> 0] | 0) >= 48 ? (a[c[l >> 2] >> 0] | 0) <= 57 : 0)break;
	                                if ((a[c[l >> 2] >> 0] | 0) == 45)break;
	                                if ((a[c[l >> 2] >> 0] | 0) == 95)break;
	                                if ((a[c[l >> 2] >> 0] | 0) == 46)break;
	                                if ((a[c[l >> 2] >> 0] | 0) == 33)break;
	                                if ((a[c[l >> 2] >> 0] | 0) == 126)break;
	                                if ((a[c[l >> 2] >> 0] | 0) == 42)break;
	                                if ((a[c[l >> 2] >> 0] | 0) == 39)break;
	                                if ((a[c[l >> 2] >> 0] | 0) == 40)break;
	                                if ((a[c[l >> 2] >> 0] | 0) == 41)break;
	                                L = c[l >> 2] | 0;
	                                c[l >> 2] = L + 1;
	                                c[o >> 2] = d[L >> 0];
	                                c[p >> 2] = (c[o >> 2] | 0) / 16 | 0;
	                                c[q >> 2] = (c[o >> 2] | 0) % 16 | 0;
	                                L = c[m >> 2] | 0;
	                                c[m >> 2] = L + 1;
	                                a[(c[j >> 2] | 0) + L >> 0] = 37;
	                                L = (c[p >> 2] | 0) + ((c[p >> 2] | 0) > 9 ? 55 : 48) & 255;
	                                I = c[m >> 2] | 0;
	                                c[m >> 2] = I + 1;
	                                a[(c[j >> 2] | 0) + I >> 0] = L;
	                                L = (c[q >> 2] | 0) + ((c[q >> 2] | 0) > 9 ? 55 : 48) & 255;
	                                I = c[m >> 2] | 0;
	                                c[m >> 2] = I + 1;
	                                a[(c[j >> 2] | 0) + I >> 0] = L;
	                                continue j
	                            } while (0);
	                            L = c[l >> 2] | 0;
	                            c[l >> 2] = L + 1;
	                            I = a[L >> 0] | 0;
	                            L = c[m >> 2] | 0;
	                            c[m >> 2] = L + 1;
	                            a[(c[j >> 2] | 0) + L >> 0] = I
	                        }
	                    } while (0);
	                    k:do if (c[(c[h >> 2] | 0) + 32 >> 2] | 0) {
	                        if (((c[m >> 2] | 0) + 3 | 0) >= (c[n >> 2] | 0)) {
	                            c[k >> 2] = Nl(c[j >> 2] | 0, n) | 0;
	                            if (!(c[k >> 2] | 0))break b;
	                            c[j >> 2] = c[k >> 2]
	                        }
	                        H = c[m >> 2] | 0;
	                        c[m >> 2] = H + 1;
	                        a[(c[j >> 2] | 0) + H >> 0] = 35;
	                        c[l >> 2] = c[(c[h >> 2] | 0) + 32 >> 2];
	                        l:while (1) {
	                            if (!(a[c[l >> 2] >> 0] | 0))break k;
	                            if (((c[m >> 2] | 0) + 3 | 0) >= (c[n >> 2] | 0)) {
	                                c[k >> 2] = Nl(c[j >> 2] | 0, n) | 0;
	                                if (!(c[k >> 2] | 0))break b;
	                                c[j >> 2] = c[k >> 2]
	                            }
	                            if (!((a[c[l >> 2] >> 0] | 0) >= 97 ? (a[c[l >> 2] >> 0] | 0) <= 122 : 0))J = 241;
	                            do if ((J | 0) == 241) {
	                                J = 0;
	                                if ((a[c[l >> 2] >> 0] | 0) >= 65 ? (a[c[l >> 2] >> 0] | 0) <= 90 : 0)break;
	                                if ((a[c[l >> 2] >> 0] | 0) >= 48 ? (a[c[l >> 2] >> 0] | 0) <= 57 : 0)break;
	                                if (((((a[c[l >> 2] >> 0] | 0) != 45 ? (a[c[l >> 2] >> 0] | 0) != 95 : 0) ? (a[c[l >> 2] >> 0] | 0) != 46 : 0) ? (a[c[l >> 2] >> 0] | 0) != 33 : 0) ? (a[c[l >> 2] >> 0] | 0) != 126 : 0) {
	                                    if ((a[c[l >> 2] >> 0] | 0) == 42)break;
	                                    if ((a[c[l >> 2] >> 0] | 0) == 39)break;
	                                    if ((a[c[l >> 2] >> 0] | 0) == 40)break;
	                                    if ((a[c[l >> 2] >> 0] | 0) == 41)break;
	                                    if ((a[c[l >> 2] >> 0] | 0) == 59)break;
	                                    if ((a[c[l >> 2] >> 0] | 0) == 47)break;
	                                    if ((a[c[l >> 2] >> 0] | 0) == 63)break;
	                                    if ((a[c[l >> 2] >> 0] | 0) == 58)break;
	                                    if ((a[c[l >> 2] >> 0] | 0) == 64)break;
	                                    if ((a[c[l >> 2] >> 0] | 0) == 38)break;
	                                    if ((a[c[l >> 2] >> 0] | 0) == 61)break;
	                                    if ((a[c[l >> 2] >> 0] | 0) == 43)break;
	                                    if ((a[c[l >> 2] >> 0] | 0) == 36)break;
	                                    if ((a[c[l >> 2] >> 0] | 0) == 44)break;
	                                    if ((a[c[l >> 2] >> 0] | 0) == 91)break;
	                                    if ((a[c[l >> 2] >> 0] | 0) == 93)break;
	                                    H = c[l >> 2] | 0;
	                                    c[l >> 2] = H + 1;
	                                    c[D >> 2] = d[H >> 0];
	                                    c[E >> 2] = (c[D >> 2] | 0) / 16 | 0;
	                                    c[F >> 2] = (c[D >> 2] | 0) % 16 | 0;
	                                    H = c[m >> 2] | 0;
	                                    c[m >> 2] = H + 1;
	                                    a[(c[j >> 2] | 0) + H >> 0] = 37;
	                                    H = (c[E >> 2] | 0) + ((c[E >> 2] | 0) > 9 ? 55 : 48) & 255;
	                                    I = c[m >> 2] | 0;
	                                    c[m >> 2] = I + 1;
	                                    a[(c[j >> 2] | 0) + I >> 0] = H;
	                                    H = (c[F >> 2] | 0) + ((c[F >> 2] | 0) > 9 ? 55 : 48) & 255;
	                                    I = c[m >> 2] | 0;
	                                    c[m >> 2] = I + 1;
	                                    a[(c[j >> 2] | 0) + I >> 0] = H;
	                                    continue l
	                                }
	                            } while (0);
	                            H = c[l >> 2] | 0;
	                            c[l >> 2] = H + 1;
	                            I = a[H >> 0] | 0;
	                            H = c[m >> 2] | 0;
	                            c[m >> 2] = H + 1;
	                            a[(c[j >> 2] | 0) + H >> 0] = I
	                        }
	                    } while (0);
	                    if ((c[m >> 2] | 0) >= (c[n >> 2] | 0)) {
	                        c[k >> 2] = Nl(c[j >> 2] | 0, n) | 0;
	                        if (!(c[k >> 2] | 0))break;
	                        c[j >> 2] = c[k >> 2]
	                    }
	                    a[(c[j >> 2] | 0) + (c[m >> 2] | 0) >> 0] = 0;
	                    c[g >> 2] = c[j >> 2];
	                    G = c[g >> 2] | 0;
	                    i = e;
	                    return G | 0
	                } while (0);
	                zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                c[g >> 2] = 0;
	                G = c[g >> 2] | 0;
	                i = e;
	                return G | 0
	            }

	            function Dl(b) {
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                c[g >> 2] = c[f >> 2];
	                while (1) {
	                    m = c[g >> 2] | 0;
	                    if ((a[c[g >> 2] >> 0] | 0) != 47)break;
	                    c[g >> 2] = m + 1
	                }
	                if (!(a[m >> 0] | 0)) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                c[h >> 2] = c[g >> 2];
	                a:while (1) {
	                    if (!(a[c[g >> 2] >> 0] | 0))break;
	                    if ((a[c[g >> 2] >> 0] | 0) == 46 ? (a[(c[g >> 2] | 0) + 1 >> 0] | 0) == 47 : 0) {
	                        c[g >> 2] = (c[g >> 2] | 0) + 2;
	                        while (1) {
	                            if ((a[c[g >> 2] >> 0] | 0) != 47)continue a;
	                            c[g >> 2] = (c[g >> 2] | 0) + 1
	                        }
	                    }
	                    if ((a[c[g >> 2] >> 0] | 0) == 46 ? (a[(c[g >> 2] | 0) + 1 >> 0] | 0) == 0 : 0)break;
	                    while (1) {
	                        if ((a[c[g >> 2] >> 0] | 0) == 47)break;
	                        if (!(a[c[g >> 2] >> 0] | 0))break a;
	                        m = c[g >> 2] | 0;
	                        c[g >> 2] = m + 1;
	                        b = a[m >> 0] | 0;
	                        m = c[h >> 2] | 0;
	                        c[h >> 2] = m + 1;
	                        a[m >> 0] = b
	                    }
	                    do {
	                        if ((a[c[g >> 2] >> 0] | 0) == 47)n = (a[(c[g >> 2] | 0) + 1 >> 0] | 0) == 47; else n = 0;
	                        o = c[g >> 2] | 0;
	                        c[g >> 2] = o + 1
	                    } while (n);
	                    b = a[o >> 0] | 0;
	                    m = c[h >> 2] | 0;
	                    c[h >> 2] = m + 1;
	                    a[m >> 0] = b
	                }
	                a[c[h >> 2] >> 0] = 0;
	                c[g >> 2] = c[f >> 2];
	                while (1) {
	                    p = c[g >> 2] | 0;
	                    if ((a[c[g >> 2] >> 0] | 0) != 47)break;
	                    c[g >> 2] = p + 1
	                }
	                if (!(a[p >> 0] | 0)) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                b:while (1) {
	                    c[j >> 2] = c[g >> 2];
	                    while (1) {
	                        if ((a[c[j >> 2] >> 0] | 0) != 47)q = (a[c[j >> 2] >> 0] | 0) != 0; else q = 0;
	                        r = c[j >> 2] | 0;
	                        if (!q)break;
	                        c[j >> 2] = r + 1
	                    }
	                    if (!(a[r >> 0] | 0))break;
	                    c[j >> 2] = (c[j >> 2] | 0) + 1;
	                    if (!(((a[c[g >> 2] >> 0] | 0) == 46 ? (a[(c[g >> 2] | 0) + 1 >> 0] | 0) == 46 : 0) ? (c[j >> 2] | 0) == ((c[g >> 2] | 0) + 3 | 0) : 0))s = 38;
	                    do if (((s | 0) == 38 ? (s = 0, (a[c[j >> 2] >> 0] | 0) == 46) : 0) ? (a[(c[j >> 2] | 0) + 1 >> 0] | 0) == 46 : 0) {
	                        if ((a[(c[j >> 2] | 0) + 2 >> 0] | 0) != 47 ? (a[(c[j >> 2] | 0) + 2 >> 0] | 0) != 0 : 0)break;
	                        t = c[g >> 2] | 0;
	                        if (!(a[(c[j >> 2] | 0) + 2 >> 0] | 0)) {
	                            s = 44;
	                            break b
	                        }
	                        c[k >> 2] = t;
	                        c[j >> 2] = (c[j >> 2] | 0) + 3;
	                        do {
	                            p = c[j >> 2] | 0;
	                            c[j >> 2] = p + 1;
	                            o = a[p >> 0] | 0;
	                            p = c[k >> 2] | 0;
	                            c[k >> 2] = p + 1;
	                            a[p >> 0] = o
	                        } while ((o << 24 >> 24 | 0) != 0);
	                        c[j >> 2] = c[g >> 2];
	                        do {
	                            if ((c[j >> 2] | 0) >>> 0 <= (c[f >> 2] | 0) >>> 0)break;
	                            o = (c[j >> 2] | 0) + -1 | 0;
	                            c[j >> 2] = o
	                        } while ((a[o >> 0] | 0) == 47);
	                        if ((c[j >> 2] | 0) == (c[f >> 2] | 0))continue b;
	                        c[g >> 2] = c[j >> 2];
	                        while (1) {
	                            if ((c[g >> 2] | 0) >>> 0 <= (c[f >> 2] | 0) >>> 0)continue b;
	                            if ((a[(c[g >> 2] | 0) + -1 >> 0] | 0) == 47)continue b;
	                            c[g >> 2] = (c[g >> 2] | 0) + -1
	                        }
	                    } while (0);
	                    c[g >> 2] = c[j >> 2]
	                }
	                if ((s | 0) == 44)a[t >> 0] = 0;
	                a[c[h >> 2] >> 0] = 0;
	                if ((a[c[f >> 2] >> 0] | 0) == 47) {
	                    c[g >> 2] = c[f >> 2];
	                    while (1) {
	                        if (((a[c[g >> 2] >> 0] | 0) == 47 ? (a[(c[g >> 2] | 0) + 1 >> 0] | 0) == 46 : 0) ? (a[(c[g >> 2] | 0) + 2 >> 0] | 0) == 46 : 0)if ((a[(c[g >> 2] | 0) + 3 >> 0] | 0) == 47)u = 1; else u = (a[(c[g >> 2] | 0) + 3 >> 0] | 0) == 0; else u = 0;
	                        v = c[g >> 2] | 0;
	                        if (!u)break;
	                        c[g >> 2] = v + 3
	                    }
	                    if ((v | 0) != (c[f >> 2] | 0)) {
	                        c[h >> 2] = c[f >> 2];
	                        while (1) {
	                            if (!(a[c[g >> 2] >> 0] | 0))break;
	                            f = c[g >> 2] | 0;
	                            c[g >> 2] = f + 1;
	                            v = a[f >> 0] | 0;
	                            f = c[h >> 2] | 0;
	                            c[h >> 2] = f + 1;
	                            a[f >> 0] = v
	                        }
	                        a[c[h >> 2] >> 0] = 0
	                    }
	                }
	                c[e >> 2] = 0;
	                l = c[e >> 2] | 0;
	                i = d;
	                return l | 0
	            }

	            function El(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 24 | 0;
	                h = f + 20 | 0;
	                j = f + 16 | 0;
	                k = f + 12 | 0;
	                l = f + 8 | 0;
	                m = f + 4 | 0;
	                n = f;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                if (!(c[h >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                if ((c[j >> 2] | 0) <= 0)c[j >> 2] = ZT(c[h >> 2] | 0) | 0;
	                if ((c[j >> 2] | 0) < 0) {
	                    c[g >> 2] = 0;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                if (!(c[k >> 2] | 0)) {
	                    c[l >> 2] = Cb[c[135752 >> 2] & 511]((c[j >> 2] | 0) + 1 | 0) | 0;
	                    if (!(c[l >> 2] | 0)) {
	                        Ml(79016);
	                        c[g >> 2] = 0;
	                        o = c[g >> 2] | 0;
	                        i = f;
	                        return o | 0
	                    }
	                } else c[l >> 2] = c[k >> 2];
	                c[n >> 2] = c[h >> 2];
	                c[m >> 2] = c[l >> 2];
	                while (1) {
	                    if ((c[j >> 2] | 0) <= 0)break;
	                    if ((((c[j >> 2] | 0) > 2 ? (a[c[n >> 2] >> 0] | 0) == 37 : 0) ? (Ol(a[(c[n >> 2] | 0) + 1 >> 0] | 0) | 0) != 0 : 0) ? (Ol(a[(c[n >> 2] | 0) + 2 >> 0] | 0) | 0) != 0 : 0) {
	                        c[n >> 2] = (c[n >> 2] | 0) + 1;
	                        if ((a[c[n >> 2] >> 0] | 0) >= 48 ? (a[c[n >> 2] >> 0] | 0) <= 57 : 0)a[c[m >> 2] >> 0] = (a[c[n >> 2] >> 0] | 0) - 48; else p = 20;
	                        do if ((p | 0) == 20) {
	                            p = 0;
	                            if ((a[c[n >> 2] >> 0] | 0) >= 97 ? (a[c[n >> 2] >> 0] | 0) <= 102 : 0) {
	                                a[c[m >> 2] >> 0] = (a[c[n >> 2] >> 0] | 0) - 97 + 10;
	                                break
	                            }
	                            if ((a[c[n >> 2] >> 0] | 0) >= 65 ? (a[c[n >> 2] >> 0] | 0) <= 70 : 0)a[c[m >> 2] >> 0] = (a[c[n >> 2] >> 0] | 0) - 65 + 10
	                        } while (0);
	                        c[n >> 2] = (c[n >> 2] | 0) + 1;
	                        if ((a[c[n >> 2] >> 0] | 0) >= 48 ? (a[c[n >> 2] >> 0] | 0) <= 57 : 0)a[c[m >> 2] >> 0] = (a[c[m >> 2] >> 0] << 4) + ((a[c[n >> 2] >> 0] | 0) - 48); else p = 29;
	                        do if ((p | 0) == 29) {
	                            p = 0;
	                            if ((a[c[n >> 2] >> 0] | 0) >= 97 ? (a[c[n >> 2] >> 0] | 0) <= 102 : 0) {
	                                a[c[m >> 2] >> 0] = (a[c[m >> 2] >> 0] << 4) + ((a[c[n >> 2] >> 0] | 0) - 97) + 10;
	                                break
	                            }
	                            if ((a[c[n >> 2] >> 0] | 0) >= 65 ? (a[c[n >> 2] >> 0] | 0) <= 70 : 0)a[c[m >> 2] >> 0] = (a[c[m >> 2] >> 0] << 4) + ((a[c[n >> 2] >> 0] | 0) - 65) + 10
	                        } while (0);
	                        c[n >> 2] = (c[n >> 2] | 0) + 1;
	                        c[j >> 2] = (c[j >> 2] | 0) - 3;
	                        c[m >> 2] = (c[m >> 2] | 0) + 1;
	                        continue
	                    }
	                    h = c[n >> 2] | 0;
	                    c[n >> 2] = h + 1;
	                    k = a[h >> 0] | 0;
	                    h = c[m >> 2] | 0;
	                    c[m >> 2] = h + 1;
	                    a[h >> 0] = k;
	                    c[j >> 2] = (c[j >> 2] | 0) + -1
	                }
	                a[c[m >> 2] >> 0] = 0;
	                c[g >> 2] = c[l >> 2];
	                o = c[g >> 2] | 0;
	                i = f;
	                return o | 0
	            }

	            function Fl(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f + 28 | 0;
	                h = f + 24 | 0;
	                j = f + 20 | 0;
	                k = f + 16 | 0;
	                l = f + 33 | 0;
	                m = f + 12 | 0;
	                n = f + 8 | 0;
	                o = f + 4 | 0;
	                p = f;
	                q = f + 32 | 0;
	                c[h >> 2] = b;
	                c[j >> 2] = e;
	                if (!(c[h >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    r = c[g >> 2] | 0;
	                    i = f;
	                    return r | 0
	                }
	                e = c[h >> 2] | 0;
	                if (!(d[c[h >> 2] >> 0] | 0)) {
	                    c[g >> 2] = my(e) | 0;
	                    r = c[g >> 2] | 0;
	                    i = f;
	                    return r | 0
	                }
	                c[o >> 2] = xy(e) | 0;
	                if ((c[o >> 2] | 0) <= 0) {
	                    c[g >> 2] = 0;
	                    r = c[g >> 2] | 0;
	                    i = f;
	                    return r | 0
	                }
	                c[o >> 2] = (c[o >> 2] | 0) + 20;
	                c[k >> 2] = Cb[c[135752 >> 2] & 511](c[o >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    Ml(79040);
	                    c[g >> 2] = 0;
	                    r = c[g >> 2] | 0;
	                    i = f;
	                    return r | 0
	                }
	                c[n >> 2] = c[h >> 2];
	                c[p >> 2] = 0;
	                a:while (1) {
	                    if (!(d[c[n >> 2] >> 0] | 0)) {
	                        s = 40;
	                        break
	                    }
	                    if (((c[o >> 2] | 0) - (c[p >> 2] | 0) | 0) <= 3) {
	                        c[m >> 2] = Nl(c[k >> 2] | 0, o) | 0;
	                        if (!(c[m >> 2] | 0)) {
	                            s = 13;
	                            break
	                        }
	                        c[k >> 2] = c[m >> 2]
	                    }
	                    a[l >> 0] = a[c[n >> 2] >> 0] | 0;
	                    do if ((d[l >> 0] | 0 | 0) != 64) {
	                        if ((d[l >> 0] | 0 | 0) >= 97 ? (d[l >> 0] | 0 | 0) <= 122 : 0)break;
	                        if ((d[l >> 0] | 0 | 0) >= 65 ? (d[l >> 0] | 0 | 0) <= 90 : 0)break;
	                        if ((d[l >> 0] | 0 | 0) >= 48 ? (d[l >> 0] | 0 | 0) <= 57 : 0)break;
	                        if ((((((((d[l >> 0] | 0 | 0) != 45 ? (d[l >> 0] | 0 | 0) != 95 : 0) ? (d[l >> 0] | 0 | 0) != 46 : 0) ? (d[l >> 0] | 0 | 0) != 33 : 0) ? (d[l >> 0] | 0 | 0) != 126 : 0) ? (d[l >> 0] | 0 | 0) != 42 : 0) ? (d[l >> 0] | 0 | 0) != 39 : 0) ? (d[l >> 0] | 0 | 0) != 40 : 0) {
	                            if ((d[l >> 0] | 0 | 0) == 41)break;
	                            if (vy(c[j >> 2] | 0, a[l >> 0] | 0) | 0)break;
	                            h = c[p >> 2] | 0;
	                            c[p >> 2] = h + 1;
	                            a[(c[k >> 2] | 0) + h >> 0] = 37;
	                            a[q >> 0] = (d[l >> 0] | 0) >> 4;
	                            h = d[q >> 0] | 0;
	                            if ((d[q >> 0] | 0 | 0) <= 9) {
	                                e = c[p >> 2] | 0;
	                                c[p >> 2] = e + 1;
	                                a[(c[k >> 2] | 0) + e >> 0] = 48 + h
	                            } else {
	                                e = c[p >> 2] | 0;
	                                c[p >> 2] = e + 1;
	                                a[(c[k >> 2] | 0) + e >> 0] = 65 + h - 10
	                            }
	                            a[q >> 0] = (d[l >> 0] | 0) & 15;
	                            h = d[q >> 0] | 0;
	                            if ((d[q >> 0] | 0 | 0) <= 9) {
	                                e = c[p >> 2] | 0;
	                                c[p >> 2] = e + 1;
	                                a[(c[k >> 2] | 0) + e >> 0] = 48 + h
	                            } else {
	                                e = c[p >> 2] | 0;
	                                c[p >> 2] = e + 1;
	                                a[(c[k >> 2] | 0) + e >> 0] = 65 + h - 10
	                            }
	                            c[n >> 2] = (c[n >> 2] | 0) + 1;
	                            continue a
	                        }
	                    } while (0);
	                    h = c[n >> 2] | 0;
	                    c[n >> 2] = h + 1;
	                    e = a[h >> 0] | 0;
	                    h = c[p >> 2] | 0;
	                    c[p >> 2] = h + 1;
	                    a[(c[k >> 2] | 0) + h >> 0] = e
	                }
	                if ((s | 0) == 13) {
	                    Ml(79040);
	                    zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    c[g >> 2] = 0;
	                    r = c[g >> 2] | 0;
	                    i = f;
	                    return r | 0
	                } else if ((s | 0) == 40) {
	                    a[(c[k >> 2] | 0) + (c[p >> 2] | 0) >> 0] = 0;
	                    c[g >> 2] = c[k >> 2];
	                    r = c[g >> 2] | 0;
	                    i = f;
	                    return r | 0
	                }
	                return 0
	            }

	            function Gl(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                b = i;
	                i = i + 48 | 0;
	                d = b;
	                e = b + 24 | 0;
	                f = b + 20 | 0;
	                g = b + 16 | 0;
	                h = b + 12 | 0;
	                j = b + 8 | 0;
	                k = b + 4 | 0;
	                l = b + 28 | 0;
	                c[f >> 2] = a;
	                c[h >> 2] = 0;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = b;
	                    return m | 0
	                }
	                c[j >> 2] = zl() | 0;
	                if ((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 36 >> 2] = 1, c[k >> 2] = Bl(c[j >> 2] | 0, c[f >> 2] | 0) | 0, (c[k >> 2] | 0) != 0) : 0) {
	                    Al(c[j >> 2] | 0);
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = b;
	                    return m | 0
	                }
	                if (!(c[j >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = b;
	                    return m | 0
	                }
	                c[g >> 2] = 0;
	                do if (c[c[j >> 2] >> 2] | 0) {
	                    c[h >> 2] = Fl(c[c[j >> 2] >> 2] | 0, 79064) | 0;
	                    if (c[h >> 2] | 0) {
	                        c[g >> 2] = By(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                        c[g >> 2] = By(c[g >> 2] | 0, 79072) | 0;
	                        zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                        break
	                    }
	                    Ml(79040);
	                    Al(c[j >> 2] | 0);
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = b;
	                    return m | 0
	                } while (0);
	                do if (c[(c[j >> 2] | 0) + 8 >> 2] | 0) {
	                    c[h >> 2] = Fl(c[(c[j >> 2] | 0) + 8 >> 2] | 0, 79080) | 0;
	                    if (c[h >> 2] | 0) {
	                        c[g >> 2] = By(c[g >> 2] | 0, 79088) | 0;
	                        c[g >> 2] = By(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                        zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                        break
	                    }
	                    Ml(79040);
	                    Al(c[j >> 2] | 0);
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = b;
	                    return m | 0
	                } while (0);
	                do if (c[(c[j >> 2] | 0) + 16 >> 2] | 0) {
	                    c[h >> 2] = Fl(c[(c[j >> 2] | 0) + 16 >> 2] | 0, 79096) | 0;
	                    if (c[h >> 2] | 0) {
	                        c[g >> 2] = By(c[g >> 2] | 0, 79088) | 0;
	                        c[g >> 2] = By(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                        c[g >> 2] = By(c[g >> 2] | 0, 79104) | 0;
	                        zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                        break
	                    }
	                    Ml(79040);
	                    Al(c[j >> 2] | 0);
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = b;
	                    return m | 0
	                } while (0);
	                if (c[(c[j >> 2] | 0) + 12 >> 2] | 0) {
	                    c[h >> 2] = Fl(c[(c[j >> 2] | 0) + 12 >> 2] | 0, 79080) | 0;
	                    if (!(c[h >> 2] | 0)) {
	                        Ml(79040);
	                        Al(c[j >> 2] | 0);
	                        c[e >> 2] = 0;
	                        m = c[e >> 2] | 0;
	                        i = b;
	                        return m | 0
	                    }
	                    if (!(c[(c[j >> 2] | 0) + 16 >> 2] | 0))c[g >> 2] = By(c[g >> 2] | 0, 79088) | 0;
	                    c[g >> 2] = By(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                    zb[c[135736 >> 2] & 511](c[h >> 2] | 0)
	                }
	                if (c[(c[j >> 2] | 0) + 20 >> 2] | 0) {
	                    c[d >> 2] = c[(c[j >> 2] | 0) + 20 >> 2];
	                    JT(l, 10, 79112, d) | 0;
	                    c[g >> 2] = By(c[g >> 2] | 0, 79072) | 0;
	                    c[g >> 2] = By(c[g >> 2] | 0, l) | 0
	                }
	                do if (c[(c[j >> 2] | 0) + 24 >> 2] | 0) {
	                    c[h >> 2] = Fl(c[(c[j >> 2] | 0) + 24 >> 2] | 0, 79120) | 0;
	                    if (c[h >> 2] | 0) {
	                        c[g >> 2] = By(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                        zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                        break
	                    }
	                    Ml(79040);
	                    Al(c[j >> 2] | 0);
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = b;
	                    return m | 0
	                } while (0);
	                do if (!(c[(c[j >> 2] | 0) + 40 >> 2] | 0)) {
	                    if (c[(c[j >> 2] | 0) + 28 >> 2] | 0) {
	                        c[h >> 2] = Fl(c[(c[j >> 2] | 0) + 28 >> 2] | 0, 79144) | 0;
	                        if (c[h >> 2] | 0) {
	                            c[g >> 2] = By(c[g >> 2] | 0, 79136) | 0;
	                            c[g >> 2] = By(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                            zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                            break
	                        }
	                        Ml(79040);
	                        Al(c[j >> 2] | 0);
	                        c[e >> 2] = 0;
	                        m = c[e >> 2] | 0;
	                        i = b;
	                        return m | 0
	                    }
	                } else {
	                    c[g >> 2] = By(c[g >> 2] | 0, 79136) | 0;
	                    c[g >> 2] = By(c[g >> 2] | 0, c[(c[j >> 2] | 0) + 40 >> 2] | 0) | 0
	                } while (0);
	                do if (c[(c[j >> 2] | 0) + 4 >> 2] | 0) {
	                    c[h >> 2] = Fl(c[(c[j >> 2] | 0) + 4 >> 2] | 0, 79160) | 0;
	                    if (c[h >> 2] | 0) {
	                        c[g >> 2] = By(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                        zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                        break
	                    }
	                    Ml(79040);
	                    Al(c[j >> 2] | 0);
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = b;
	                    return m | 0
	                } while (0);
	                do if (c[(c[j >> 2] | 0) + 32 >> 2] | 0) {
	                    c[h >> 2] = Fl(c[(c[j >> 2] | 0) + 32 >> 2] | 0, 79168) | 0;
	                    if (c[h >> 2] | 0) {
	                        c[g >> 2] = By(c[g >> 2] | 0, 79168) | 0;
	                        c[g >> 2] = By(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                        zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                        break
	                    }
	                    Ml(79040);
	                    Al(c[j >> 2] | 0);
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = b;
	                    return m | 0
	                } while (0);
	                Al(c[j >> 2] | 0);
	                c[e >> 2] = c[g >> 2];
	                m = c[e >> 2] | 0;
	                i = b;
	                return m | 0
	            }

	            function Hl(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 40 | 0;
	                g = e + 36 | 0;
	                h = e + 32 | 0;
	                j = e + 28 | 0;
	                k = e + 24 | 0;
	                l = e + 20 | 0;
	                m = e + 16 | 0;
	                n = e + 12 | 0;
	                o = e + 8 | 0;
	                p = e + 4 | 0;
	                q = e;
	                c[f >> 2] = b;
	                c[g >> 2] = d;
	                c[h >> 2] = 0;
	                c[o >> 2] = 0;
	                c[p >> 2] = 0;
	                c[q >> 2] = 0;
	                do if (c[f >> 2] | 0) {
	                    if (!(a[c[f >> 2] >> 0] | 0)) {
	                        c[j >> 2] = 0;
	                        r = 7;
	                        break
	                    }
	                    c[o >> 2] = zl() | 0;
	                    if (c[o >> 2] | 0) {
	                        c[j >> 2] = Bl(c[o >> 2] | 0, c[f >> 2] | 0) | 0;
	                        r = 7
	                    }
	                } else {
	                    c[j >> 2] = -1;
	                    r = 7
	                } while (0);
	                a:do if ((r | 0) == 7 ? (c[j >> 2] | 0) == 0 : 0) {
	                    if ((c[o >> 2] | 0) != 0 ? (c[c[o >> 2] >> 2] | 0) != 0 : 0) {
	                        c[h >> 2] = my(c[f >> 2] | 0) | 0;
	                        break
	                    }
	                    if (!(c[g >> 2] | 0))c[j >> 2] = -1; else {
	                        c[p >> 2] = zl() | 0;
	                        if (!(c[p >> 2] | 0))break;
	                        c[j >> 2] = Bl(c[p >> 2] | 0, c[g >> 2] | 0) | 0
	                    }
	                    d = c[o >> 2] | 0;
	                    if (c[j >> 2] | 0) {
	                        if (!d)break;
	                        c[h >> 2] = Cl(c[o >> 2] | 0) | 0;
	                        break
	                    }
	                    if (!d) {
	                        if (c[(c[p >> 2] | 0) + 32 >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[(c[p >> 2] | 0) + 32 >> 2] | 0);
	                            c[(c[p >> 2] | 0) + 32 >> 2] = 0
	                        }
	                        c[h >> 2] = Cl(c[p >> 2] | 0) | 0;
	                        break
	                    }
	                    c[q >> 2] = zl() | 0;
	                    if (c[q >> 2] | 0) {
	                        if ((((c[c[o >> 2] >> 2] | 0) == 0 ? (c[(c[o >> 2] | 0) + 24 >> 2] | 0) == 0 : 0) ? (c[(c[o >> 2] | 0) + 8 >> 2] | 0) == 0 : 0) ? (c[(c[o >> 2] | 0) + 12 >> 2] | 0) == 0 : 0) {
	                            if (c[c[p >> 2] >> 2] | 0) {
	                                d = Cb[c[135768 >> 2] & 511](c[c[p >> 2] >> 2] | 0) | 0;
	                                c[c[q >> 2] >> 2] = d
	                            }
	                            if (!(c[(c[p >> 2] | 0) + 8 >> 2] | 0)) {
	                                if (c[(c[p >> 2] | 0) + 12 >> 2] | 0) {
	                                    d = Cb[c[135768 >> 2] & 511](c[(c[p >> 2] | 0) + 12 >> 2] | 0) | 0;
	                                    c[(c[q >> 2] | 0) + 12 >> 2] = d;
	                                    if (c[(c[p >> 2] | 0) + 16 >> 2] | 0) {
	                                        d = Cb[c[135768 >> 2] & 511](c[(c[p >> 2] | 0) + 16 >> 2] | 0) | 0;
	                                        c[(c[q >> 2] | 0) + 16 >> 2] = d
	                                    }
	                                    c[(c[q >> 2] | 0) + 20 >> 2] = c[(c[p >> 2] | 0) + 20 >> 2]
	                                }
	                            } else {
	                                d = Cb[c[135768 >> 2] & 511](c[(c[p >> 2] | 0) + 8 >> 2] | 0) | 0;
	                                c[(c[q >> 2] | 0) + 8 >> 2] = d
	                            }
	                            if (c[(c[p >> 2] | 0) + 24 >> 2] | 0) {
	                                d = Cb[c[135768 >> 2] & 511](c[(c[p >> 2] | 0) + 24 >> 2] | 0) | 0;
	                                c[(c[q >> 2] | 0) + 24 >> 2] = d
	                            }
	                            do if (c[(c[o >> 2] | 0) + 40 >> 2] | 0) {
	                                d = Cb[c[135768 >> 2] & 511](c[(c[o >> 2] | 0) + 40 >> 2] | 0) | 0;
	                                c[(c[q >> 2] | 0) + 40 >> 2] = d
	                            } else {
	                                if (c[(c[o >> 2] | 0) + 28 >> 2] | 0) {
	                                    d = Cb[c[135768 >> 2] & 511](c[(c[o >> 2] | 0) + 28 >> 2] | 0) | 0;
	                                    c[(c[q >> 2] | 0) + 28 >> 2] = d;
	                                    break
	                                }
	                                if (c[(c[p >> 2] | 0) + 40 >> 2] | 0) {
	                                    d = Cb[c[135768 >> 2] & 511](c[(c[p >> 2] | 0) + 40 >> 2] | 0) | 0;
	                                    c[(c[q >> 2] | 0) + 40 >> 2] = d;
	                                    break
	                                }
	                                if (!(c[(c[p >> 2] | 0) + 28 >> 2] | 0))break;
	                                d = Cb[c[135768 >> 2] & 511](c[(c[p >> 2] | 0) + 28 >> 2] | 0) | 0;
	                                c[(c[q >> 2] | 0) + 28 >> 2] = d
	                            } while (0);
	                            if (c[(c[o >> 2] | 0) + 32 >> 2] | 0) {
	                                d = Cb[c[135768 >> 2] & 511](c[(c[o >> 2] | 0) + 32 >> 2] | 0) | 0;
	                                c[(c[q >> 2] | 0) + 32 >> 2] = d
	                            }
	                        } else r = 47;
	                        b:do if ((r | 0) == 47) {
	                            if (c[c[o >> 2] >> 2] | 0) {
	                                c[h >> 2] = Cl(c[o >> 2] | 0) | 0;
	                                break a
	                            }
	                            if (c[c[p >> 2] >> 2] | 0) {
	                                d = Cb[c[135768 >> 2] & 511](c[c[p >> 2] >> 2] | 0) | 0;
	                                c[c[q >> 2] >> 2] = d
	                            }
	                            if (!(c[(c[o >> 2] | 0) + 40 >> 2] | 0)) {
	                                if (c[(c[o >> 2] | 0) + 28 >> 2] | 0) {
	                                    d = Cb[c[135768 >> 2] & 511](c[(c[o >> 2] | 0) + 28 >> 2] | 0) | 0;
	                                    c[(c[q >> 2] | 0) + 28 >> 2] = d
	                                }
	                            } else {
	                                d = Cb[c[135768 >> 2] & 511](c[(c[o >> 2] | 0) + 40 >> 2] | 0) | 0;
	                                c[(c[q >> 2] | 0) + 40 >> 2] = d
	                            }
	                            if (c[(c[o >> 2] | 0) + 32 >> 2] | 0) {
	                                d = Cb[c[135768 >> 2] & 511](c[(c[o >> 2] | 0) + 32 >> 2] | 0) | 0;
	                                c[(c[q >> 2] | 0) + 32 >> 2] = d
	                            }
	                            if ((c[(c[o >> 2] | 0) + 8 >> 2] | 0) == 0 ? (c[(c[o >> 2] | 0) + 12 >> 2] | 0) == 0 : 0) {
	                                if (!(c[(c[p >> 2] | 0) + 8 >> 2] | 0)) {
	                                    if (c[(c[p >> 2] | 0) + 12 >> 2] | 0) {
	                                        d = Cb[c[135768 >> 2] & 511](c[(c[p >> 2] | 0) + 12 >> 2] | 0) | 0;
	                                        c[(c[q >> 2] | 0) + 12 >> 2] = d;
	                                        if (c[(c[p >> 2] | 0) + 16 >> 2] | 0) {
	                                            d = Cb[c[135768 >> 2] & 511](c[(c[p >> 2] | 0) + 16 >> 2] | 0) | 0;
	                                            c[(c[q >> 2] | 0) + 16 >> 2] = d
	                                        }
	                                        c[(c[q >> 2] | 0) + 20 >> 2] = c[(c[p >> 2] | 0) + 20 >> 2]
	                                    }
	                                } else {
	                                    d = Cb[c[135768 >> 2] & 511](c[(c[p >> 2] | 0) + 8 >> 2] | 0) | 0;
	                                    c[(c[q >> 2] | 0) + 8 >> 2] = d
	                                }
	                                do if (c[(c[o >> 2] | 0) + 24 >> 2] | 0) {
	                                    if ((a[c[(c[o >> 2] | 0) + 24 >> 2] >> 0] | 0) != 47)break;
	                                    d = Cb[c[135768 >> 2] & 511](c[(c[o >> 2] | 0) + 24 >> 2] | 0) | 0;
	                                    c[(c[q >> 2] | 0) + 24 >> 2] = d;
	                                    break b
	                                } while (0);
	                                c[k >> 2] = 2;
	                                if (c[(c[o >> 2] | 0) + 24 >> 2] | 0) {
	                                    d = ZT(c[(c[o >> 2] | 0) + 24 >> 2] | 0) | 0;
	                                    c[k >> 2] = (c[k >> 2] | 0) + d
	                                }
	                                if (c[(c[p >> 2] | 0) + 24 >> 2] | 0) {
	                                    d = ZT(c[(c[p >> 2] | 0) + 24 >> 2] | 0) | 0;
	                                    c[k >> 2] = (c[k >> 2] | 0) + d
	                                }
	                                d = Cb[c[135752 >> 2] & 511](c[k >> 2] | 0) | 0;
	                                c[(c[q >> 2] | 0) + 24 >> 2] = d;
	                                if (!(c[(c[q >> 2] | 0) + 24 >> 2] | 0)) {
	                                    Ml(79176);
	                                    break a
	                                }
	                                a[c[(c[q >> 2] | 0) + 24 >> 2] >> 0] = 0;
	                                c[m >> 2] = 0;
	                                c[n >> 2] = 0;
	                                c:do if (c[(c[p >> 2] | 0) + 24 >> 2] | 0)d:while (1) {
	                                    if (!(a[(c[(c[p >> 2] | 0) + 24 >> 2] | 0) + (c[m >> 2] | 0) >> 0] | 0))break c;
	                                    while (1) {
	                                        if (a[(c[(c[p >> 2] | 0) + 24 >> 2] | 0) + (c[m >> 2] | 0) >> 0] | 0)s = (a[(c[(c[p >> 2] | 0) + 24 >> 2] | 0) + (c[m >> 2] | 0) >> 0] | 0) != 47; else s = 0;
	                                        t = c[m >> 2] | 0;
	                                        if (!s)break;
	                                        c[m >> 2] = t + 1
	                                    }
	                                    if (!(a[(c[(c[p >> 2] | 0) + 24 >> 2] | 0) + t >> 0] | 0))break c;
	                                    c[m >> 2] = (c[m >> 2] | 0) + 1;
	                                    while (1) {
	                                        if ((c[n >> 2] | 0) >= (c[m >> 2] | 0))continue d;
	                                        a[(c[(c[q >> 2] | 0) + 24 >> 2] | 0) + (c[n >> 2] | 0) >> 0] = a[(c[(c[p >> 2] | 0) + 24 >> 2] | 0) + (c[n >> 2] | 0) >> 0] | 0;
	                                        c[n >> 2] = (c[n >> 2] | 0) + 1
	                                    }
	                                } while (0);
	                                a[(c[(c[q >> 2] | 0) + 24 >> 2] | 0) + (c[n >> 2] | 0) >> 0] = 0;
	                                e:do if (c[(c[o >> 2] | 0) + 24 >> 2] | 0) {
	                                    if (!(a[c[(c[o >> 2] | 0) + 24 >> 2] >> 0] | 0))break;
	                                    c[l >> 2] = 0;
	                                    do if (!(c[n >> 2] | 0)) {
	                                        if (!(c[(c[p >> 2] | 0) + 12 >> 2] | 0))break;
	                                        d = c[n >> 2] | 0;
	                                        c[n >> 2] = d + 1;
	                                        a[(c[(c[q >> 2] | 0) + 24 >> 2] | 0) + d >> 0] = 47
	                                    } while (0);
	                                    while (1) {
	                                        if (!(a[(c[(c[o >> 2] | 0) + 24 >> 2] | 0) + (c[l >> 2] | 0) >> 0] | 0))break e;
	                                        d = c[l >> 2] | 0;
	                                        c[l >> 2] = d + 1;
	                                        b = a[(c[(c[o >> 2] | 0) + 24 >> 2] | 0) + d >> 0] | 0;
	                                        d = c[n >> 2] | 0;
	                                        c[n >> 2] = d + 1;
	                                        a[(c[(c[q >> 2] | 0) + 24 >> 2] | 0) + d >> 0] = b
	                                    }
	                                } while (0);
	                                a[(c[(c[q >> 2] | 0) + 24 >> 2] | 0) + (c[n >> 2] | 0) >> 0] = 0;
	                                Dl(c[(c[q >> 2] | 0) + 24 >> 2] | 0) | 0;
	                                break
	                            }
	                            b = c[33942] | 0;
	                            d = c[o >> 2] | 0;
	                            if (c[(c[o >> 2] | 0) + 8 >> 2] | 0) {
	                                u = Cb[b & 511](c[d + 8 >> 2] | 0) | 0;
	                                c[(c[q >> 2] | 0) + 8 >> 2] = u
	                            } else {
	                                u = Cb[b & 511](c[d + 12 >> 2] | 0) | 0;
	                                c[(c[q >> 2] | 0) + 12 >> 2] = u;
	                                if (c[(c[o >> 2] | 0) + 16 >> 2] | 0) {
	                                    u = Cb[c[135768 >> 2] & 511](c[(c[o >> 2] | 0) + 16 >> 2] | 0) | 0;
	                                    c[(c[q >> 2] | 0) + 16 >> 2] = u
	                                }
	                                c[(c[q >> 2] | 0) + 20 >> 2] = c[(c[o >> 2] | 0) + 20 >> 2]
	                            }
	                            if (c[(c[o >> 2] | 0) + 24 >> 2] | 0) {
	                                u = Cb[c[135768 >> 2] & 511](c[(c[o >> 2] | 0) + 24 >> 2] | 0) | 0;
	                                c[(c[q >> 2] | 0) + 24 >> 2] = u
	                            }
	                        } while (0);
	                        c[h >> 2] = Cl(c[q >> 2] | 0) | 0
	                    }
	                } while (0);
	                if (c[o >> 2] | 0)Al(c[o >> 2] | 0);
	                if (c[p >> 2] | 0)Al(c[p >> 2] | 0);
	                if (!(c[q >> 2] | 0)) {
	                    v = c[h >> 2] | 0;
	                    i = e;
	                    return v | 0
	                }
	                Al(c[q >> 2] | 0);
	                v = c[h >> 2] | 0;
	                i = e;
	                return v | 0
	            }

	            function Il(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0;
	                f = i;
	                i = i + 64 | 0;
	                g = f + 56 | 0;
	                h = f + 52 | 0;
	                j = f + 48 | 0;
	                k = f + 44 | 0;
	                l = f + 40 | 0;
	                m = f + 36 | 0;
	                n = f + 32 | 0;
	                o = f + 28 | 0;
	                p = f + 24 | 0;
	                q = f + 20 | 0;
	                r = f + 16 | 0;
	                s = f + 12 | 0;
	                t = f + 8 | 0;
	                u = f + 4 | 0;
	                v = f;
	                c[h >> 2] = b;
	                c[j >> 2] = e;
	                c[k >> 2] = 0;
	                c[n >> 2] = 0;
	                c[o >> 2] = 0;
	                c[q >> 2] = 0;
	                c[r >> 2] = 0;
	                c[v >> 2] = 0;
	                if ((c[h >> 2] | 0) != 0 ? (d[c[h >> 2] >> 0] | 0) != 0 : 0) {
	                    c[q >> 2] = zl() | 0;
	                    if (!(c[q >> 2] | 0)) {
	                        c[g >> 2] = 0;
	                        w = c[g >> 2] | 0;
	                        i = f;
	                        return w | 0
	                    }
	                    if ((d[c[h >> 2] >> 0] | 0) != 46) {
	                        c[l >> 2] = Bl(c[q >> 2] | 0, c[h >> 2] | 0) | 0;
	                        if (!(c[l >> 2] | 0))x = 9
	                    } else {
	                        e = my(c[h >> 2] | 0) | 0;
	                        c[(c[q >> 2] | 0) + 24 >> 2] = e;
	                        x = 9
	                    }
	                    a:do if ((x | 0) == 9) {
	                        if ((c[j >> 2] | 0) != 0 ? (d[c[j >> 2] >> 0] | 0) != 0 : 0) {
	                            c[r >> 2] = zl() | 0;
	                            if (!(c[r >> 2] | 0))break;
	                            if ((d[c[j >> 2] >> 0] | 0) != 46) {
	                                c[l >> 2] = Bl(c[r >> 2] | 0, c[j >> 2] | 0) | 0;
	                                if (c[l >> 2] | 0)break
	                            } else {
	                                e = my(c[j >> 2] | 0) | 0;
	                                c[(c[r >> 2] | 0) + 24 >> 2] = e
	                            }
	                            do if (c[c[q >> 2] >> 2] | 0) {
	                                if (((c[c[r >> 2] >> 2] | 0) != 0 ? (py(c[c[r >> 2] >> 2] | 0, c[c[q >> 2] >> 2] | 0) | 0) == 0 : 0) ? (py(c[(c[r >> 2] | 0) + 12 >> 2] | 0, c[(c[q >> 2] | 0) + 12 >> 2] | 0) | 0) == 0 : 0)break;
	                                c[k >> 2] = my(c[h >> 2] | 0) | 0;
	                                break a
	                            } while (0);
	                            if (qy(c[(c[r >> 2] | 0) + 24 >> 2] | 0, c[(c[q >> 2] | 0) + 24 >> 2] | 0) | 0) {
	                                c[k >> 2] = my(79160) | 0;
	                                break
	                            }
	                            e = c[(c[q >> 2] | 0) + 24 >> 2] | 0;
	                            if (!(c[(c[r >> 2] | 0) + 24 >> 2] | 0)) {
	                                c[k >> 2] = my(e) | 0;
	                                break
	                            }
	                            if (!e) {
	                                c[(c[q >> 2] | 0) + 24 >> 2] = 79208;
	                                c[v >> 2] = 1
	                            }
	                            if (!(c[(c[r >> 2] | 0) + 24 >> 2] | 0)) {
	                                if (!(c[(c[q >> 2] | 0) + 24 >> 2] | 0))break;
	                                c[t >> 2] = c[(c[q >> 2] | 0) + 24 >> 2];
	                                if ((d[c[t >> 2] >> 0] | 0) == 47)c[t >> 2] = (c[t >> 2] | 0) + 1;
	                                c[k >> 2] = Fl(c[t >> 2] | 0, 79216) | 0;
	                                break
	                            }
	                            c[s >> 2] = c[(c[r >> 2] | 0) + 24 >> 2];
	                            if (!(c[(c[q >> 2] | 0) + 24 >> 2] | 0)) {
	                                c[m >> 2] = 0;
	                                while (1) {
	                                    if (!(d[(c[s >> 2] | 0) + (c[m >> 2] | 0) >> 0] | 0))break;
	                                    if ((d[(c[s >> 2] | 0) + (c[m >> 2] | 0) >> 0] | 0) == 47)c[o >> 2] = (c[o >> 2] | 0) + 1;
	                                    c[m >> 2] = (c[m >> 2] | 0) + 1
	                                }
	                                c[t >> 2] = 0;
	                                c[p >> 2] = 1
	                            } else {
	                                do if ((a[(c[(c[q >> 2] | 0) + 24 >> 2] | 0) + (c[n >> 2] | 0) >> 0] | 0) == 46) {
	                                    if ((a[(c[(c[q >> 2] | 0) + 24 >> 2] | 0) + ((c[n >> 2] | 0) + 1) >> 0] | 0) != 47)break;
	                                    c[n >> 2] = (c[n >> 2] | 0) + 2
	                                } while (0);
	                                do if ((d[c[s >> 2] >> 0] | 0) == 46) {
	                                    if ((d[(c[s >> 2] | 0) + 1 >> 0] | 0) != 47) {
	                                        x = 45;
	                                        break
	                                    }
	                                    c[s >> 2] = (c[s >> 2] | 0) + 2
	                                } else x = 45; while (0);
	                                do if ((x | 0) == 45) {
	                                    if ((d[c[s >> 2] >> 0] | 0) != 47)break;
	                                    if ((a[(c[(c[q >> 2] | 0) + 24 >> 2] | 0) + (c[n >> 2] | 0) >> 0] | 0) == 47)break;
	                                    c[s >> 2] = (c[s >> 2] | 0) + 1
	                                } while (0);
	                                while (1) {
	                                    if ((d[(c[s >> 2] | 0) + (c[n >> 2] | 0) >> 0] | 0) == (a[(c[(c[q >> 2] | 0) + 24 >> 2] | 0) + (c[n >> 2] | 0) >> 0] | 0))y = (d[(c[s >> 2] | 0) + (c[n >> 2] | 0) >> 0] | 0) != 0; else y = 0;
	                                    z = c[n >> 2] | 0;
	                                    if (!y)break;
	                                    c[n >> 2] = z + 1
	                                }
	                                if ((d[(c[s >> 2] | 0) + z >> 0] | 0) == (a[(c[(c[q >> 2] | 0) + 24 >> 2] | 0) + (c[n >> 2] | 0) >> 0] | 0)) {
	                                    c[k >> 2] = my(79160) | 0;
	                                    break
	                                }
	                                c[m >> 2] = c[n >> 2];
	                                e = c[m >> 2] | 0;
	                                do if ((c[m >> 2] | 0) > 0 ? (a[(c[(c[q >> 2] | 0) + 24 >> 2] | 0) + (c[m >> 2] | 0) >> 0] | 0) == 47 : 0)c[m >> 2] = e + -1; else {
	                                    if (!((c[m >> 2] | 0) > 1 ? (a[(c[(c[q >> 2] | 0) + 24 >> 2] | 0) + e >> 0] | 0) == 0 : 0))break;
	                                    if ((a[(c[(c[q >> 2] | 0) + 24 >> 2] | 0) + ((c[m >> 2] | 0) - 1) >> 0] | 0) != 47)break;
	                                    c[m >> 2] = (c[m >> 2] | 0) - 2
	                                } while (0);
	                                while (1) {
	                                    if ((c[m >> 2] | 0) <= 0)break;
	                                    if ((a[(c[(c[q >> 2] | 0) + 24 >> 2] | 0) + (c[m >> 2] | 0) >> 0] | 0) == 47)break;
	                                    c[m >> 2] = (c[m >> 2] | 0) + -1
	                                }
	                                if (!(c[m >> 2] | 0))c[t >> 2] = c[(c[q >> 2] | 0) + 24 >> 2]; else {
	                                    c[m >> 2] = (c[m >> 2] | 0) + 1;
	                                    c[t >> 2] = (c[(c[q >> 2] | 0) + 24 >> 2] | 0) + (c[m >> 2] | 0)
	                                }
	                                b:do if ((d[(c[s >> 2] | 0) + (c[n >> 2] | 0) >> 0] | 0) != (a[(c[(c[q >> 2] | 0) + 24 >> 2] | 0) + (c[n >> 2] | 0) >> 0] | 0))while (1) {
	                                    if (!(d[(c[s >> 2] | 0) + (c[m >> 2] | 0) >> 0] | 0))break b;
	                                    if ((d[(c[s >> 2] | 0) + (c[m >> 2] | 0) >> 0] | 0) == 47)c[o >> 2] = (c[o >> 2] | 0) + 1;
	                                    c[m >> 2] = (c[m >> 2] | 0) + 1
	                                } while (0);
	                                c[p >> 2] = (xy(c[t >> 2] | 0) | 0) + 1
	                            }
	                            if (!(c[o >> 2] | 0)) {
	                                if (!(c[t >> 2] | 0))break;
	                                c[k >> 2] = Fl(c[t >> 2] | 0, 79216) | 0;
	                                break
	                            }
	                            c[k >> 2] = Cb[c[135744 >> 2] & 511]((c[p >> 2] | 0) + ((c[o >> 2] | 0) * 3 | 0) | 0) | 0;
	                            if (!(c[k >> 2] | 0)) {
	                                Ml(79224);
	                                break
	                            }
	                            c[u >> 2] = c[k >> 2];
	                            while (1) {
	                                if ((c[o >> 2] | 0) <= 0)break;
	                                e = c[u >> 2] | 0;
	                                c[u >> 2] = e + 1;
	                                a[e >> 0] = 46;
	                                e = c[u >> 2] | 0;
	                                c[u >> 2] = e + 1;
	                                a[e >> 0] = 46;
	                                e = c[u >> 2] | 0;
	                                c[u >> 2] = e + 1;
	                                a[e >> 0] = 47;
	                                c[o >> 2] = (c[o >> 2] | 0) + -1
	                            }
	                            c:do if (c[t >> 2] | 0) {
	                                do if ((c[p >> 2] | 0) > 0 ? (c[u >> 2] | 0) >>> 0 > (c[k >> 2] | 0) >>> 0 : 0) {
	                                    if ((d[c[t >> 2] >> 0] | 0) != 47)break;
	                                    if ((d[(c[u >> 2] | 0) + -1 >> 0] | 0) != 47)break;
	                                    eU(c[u >> 2] | 0, (c[t >> 2] | 0) + 1 | 0, (c[p >> 2] | 0) - 1 | 0) | 0;
	                                    a[(c[u >> 2] | 0) + ((c[p >> 2] | 0) - 2) >> 0] = 0;
	                                    break c
	                                } while (0);
	                                eU(c[u >> 2] | 0, c[t >> 2] | 0, c[p >> 2] | 0) | 0;
	                                a[(c[u >> 2] | 0) + ((c[p >> 2] | 0) - 1) >> 0] = 0
	                            } else a[(c[u >> 2] | 0) + ((c[p >> 2] | 0) - 1) >> 0] = 0; while (0);
	                            c[u >> 2] = c[k >> 2];
	                            c[k >> 2] = Fl(c[u >> 2] | 0, 79216) | 0;
	                            zb[c[135736 >> 2] & 511](c[u >> 2] | 0);
	                            break
	                        }
	                        c[k >> 2] = my(c[h >> 2] | 0) | 0
	                    } while (0);
	                    if (c[v >> 2] | 0)c[(c[q >> 2] | 0) + 24 >> 2] = 0;
	                    if (c[q >> 2] | 0)Al(c[q >> 2] | 0);
	                    if (c[r >> 2] | 0)Al(c[r >> 2] | 0);
	                    c[g >> 2] = c[k >> 2];
	                    w = c[g >> 2] | 0;
	                    i = f;
	                    return w | 0
	                }
	                c[g >> 2] = 0;
	                w = c[g >> 2] | 0;
	                i = f;
	                return w | 0
	            }

	            function Jl(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 28 | 0;
	                g = e + 24 | 0;
	                h = e + 20 | 0;
	                j = e + 16 | 0;
	                k = e + 12 | 0;
	                l = e + 8 | 0;
	                m = e + 4 | 0;
	                n = e + 32 | 0;
	                o = e;
	                c[g >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    p = c[f >> 2] | 0;
	                    i = e;
	                    return p | 0
	                }
	                if (((d[c[g >> 2] >> 0] | 0 | 0) == 47 ? (d[(c[g >> 2] | 0) + 1 >> 0] | 0 | 0) == 47 : 0) ? (d[(c[g >> 2] | 0) + 2 >> 0] | 0 | 0) != 47 : 0)c[g >> 2] = (c[g >> 2] | 0) + 1;
	                b = yl(c[g >> 2] | 0) | 0;
	                c[h >> 2] = b;
	                if (b) {
	                    Al(c[h >> 2] | 0);
	                    c[f >> 2] = my(c[g >> 2] | 0) | 0;
	                    p = c[f >> 2] | 0;
	                    i = e;
	                    return p | 0
	                }
	                c[k >> 2] = wy(c[g >> 2] | 0, 79248) | 0;
	                a:do if ((c[k >> 2] | 0) != 0 ? (c[l >> 2] = (c[k >> 2] | 0) - (c[g >> 2] | 0), !((c[l >> 2] | 0) <= 0 | (c[l >> 2] | 0) > 20)) : 0) {
	                    c[m >> 2] = 0;
	                    while (1) {
	                        if ((c[m >> 2] | 0) >= (c[l >> 2] | 0))break;
	                        a[n >> 0] = a[(c[g >> 2] | 0) + (c[m >> 2] | 0) >> 0] | 0;
	                        if (!((d[n >> 0] | 0 | 0) >= 97 ? (d[n >> 0] | 0 | 0) <= 122 : 0)) {
	                            if ((d[n >> 0] | 0 | 0) < 65)break a;
	                            if ((d[n >> 0] | 0 | 0) > 90)break a
	                        }
	                        c[m >> 2] = (c[m >> 2] | 0) + 1
	                    }
	                    c[o >> 2] = Fl(c[g >> 2] | 0, 79256) | 0;
	                    if ((c[o >> 2] | 0) != 0 ? (c[h >> 2] = yl(c[o >> 2] | 0) | 0, (c[h >> 2] | 0) != 0) : 0) {
	                        Al(c[h >> 2] | 0);
	                        c[f >> 2] = c[o >> 2];
	                        p = c[f >> 2] | 0;
	                        i = e;
	                        return p | 0
	                    }
	                } while (0);
	                c[j >> 2] = my(c[g >> 2] | 0) | 0;
	                c[f >> 2] = c[j >> 2];
	                p = c[f >> 2] | 0;
	                i = e;
	                return p | 0
	            }

	            function Kl(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                b = i;
	                i = i + 64 | 0;
	                d = b + 60 | 0;
	                e = b + 56 | 0;
	                f = b + 52 | 0;
	                g = b + 8 | 0;
	                h = b + 4 | 0;
	                j = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    k = c[d >> 2] | 0;
	                    i = b;
	                    return k | 0
	                }
	                a = yl(c[e >> 2] | 0) | 0;
	                c[f >> 2] = a;
	                if (a) {
	                    Al(c[f >> 2] | 0);
	                    c[d >> 2] = my(c[e >> 2] | 0) | 0;
	                    k = c[d >> 2] | 0;
	                    i = b;
	                    return k | 0
	                }
	                c[j >> 2] = Jl(c[e >> 2] | 0) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    k = c[d >> 2] | 0;
	                    i = b;
	                    return k | 0
	                } else {
	                    e = g + 0 | 0;
	                    f = e + 44 | 0;
	                    do {
	                        c[e >> 2] = 0;
	                        e = e + 4 | 0
	                    } while ((e | 0) < (f | 0));
	                    c[g + 24 >> 2] = c[j >> 2];
	                    c[h >> 2] = Cl(g) | 0;
	                    zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                    c[d >> 2] = c[h >> 2];
	                    k = c[d >> 2] | 0;
	                    i = b;
	                    return k | 0
	                }
	                return 0
	            }

	            function Ll(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                Pl(c[f >> 2] | 0);
	                c[h >> 2] = Ql(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                if ((c[h >> 2] | 0) != 0 ? (Pl(c[f >> 2] | 0), c[h >> 2] = Rl(c[f >> 2] | 0, c[g >> 2] | 0) | 0, (c[h >> 2] | 0) != 0) : 0) {
	                    Pl(c[f >> 2] | 0);
	                    c[e >> 2] = c[h >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[e >> 2] = 0;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function Ml(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                e = b + 4 | 0;
	                c[e >> 2] = a;
	                if (c[e >> 2] | 0) {
	                    a = c[e >> 2] | 0;
	                    c[d >> 2] = c[e >> 2];
	                    Xd(0, 0, 0, 0, 0, 30, 2, 3, 0, 0, a, 0, 0, 0, 0, 79320, d);
	                    i = b;
	                    return
	                } else {
	                    Xd(0, 0, 0, 0, 0, 30, 2, 3, 0, 0, 0, 0, 0, 0, 0, 79352, d);
	                    i = b;
	                    return
	                }
	            }

	            function Nl(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[c[g >> 2] >> 2] | 0) > 1048576) {
	                    Ml(79272);
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                c[j >> 2] = c[c[g >> 2] >> 2] << 1;
	                c[h >> 2] = Hb[c[135760 >> 2] & 511](c[f >> 2] | 0, (c[j >> 2] | 0) + 1 | 0) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    Ml(78984);
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                } else {
	                    c[c[g >> 2] >> 2] = c[j >> 2];
	                    c[e >> 2] = c[h >> 2];
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                return 0
	            }

	            function Ol(b) {
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                f = d + 4 | 0;
	                a[f >> 0] = b;
	                if (!((a[f >> 0] | 0) >= 48 ? (a[f >> 0] | 0) <= 57 : 0))g = 3;
	                do if ((g | 0) == 3) {
	                    if ((a[f >> 0] | 0) >= 97 ? (a[f >> 0] | 0) <= 102 : 0)break;
	                    if ((a[f >> 0] | 0) >= 65 ? (a[f >> 0] | 0) <= 70 : 0)break;
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                } while (0);
	                c[e >> 2] = 1;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function Pl(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[c[d >> 2] >> 2] | 0)zb[c[135736 >> 2] & 511](c[c[d >> 2] >> 2] | 0);
	                c[c[d >> 2] >> 2] = 0;
	                if (c[(c[d >> 2] | 0) + 12 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 12 >> 2] | 0);
	                c[(c[d >> 2] | 0) + 12 >> 2] = 0;
	                if (c[(c[d >> 2] | 0) + 16 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 16 >> 2] | 0);
	                c[(c[d >> 2] | 0) + 16 >> 2] = 0;
	                if (c[(c[d >> 2] | 0) + 24 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 24 >> 2] | 0);
	                c[(c[d >> 2] | 0) + 24 >> 2] = 0;
	                if (c[(c[d >> 2] | 0) + 32 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 32 >> 2] | 0);
	                c[(c[d >> 2] | 0) + 32 >> 2] = 0;
	                if (c[(c[d >> 2] | 0) + 4 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 4 >> 2] | 0);
	                c[(c[d >> 2] | 0) + 4 >> 2] = 0;
	                if (c[(c[d >> 2] | 0) + 8 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                c[(c[d >> 2] | 0) + 8 >> 2] = 0;
	                if (c[(c[d >> 2] | 0) + 28 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 28 >> 2] | 0);
	                c[(c[d >> 2] | 0) + 28 >> 2] = 0;
	                if (c[(c[d >> 2] | 0) + 40 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 40 >> 2] | 0);
	                c[(c[d >> 2] | 0) + 40 >> 2] = 0;
	                i = b;
	                return
	            }

	            function Ql(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = Sl(c[g >> 2] | 0, h) | 0;
	                do if (!(c[j >> 2] | 0)) {
	                    if ((a[c[h >> 2] >> 0] | 0) != 58) {
	                        c[f >> 2] = 1;
	                        break
	                    }
	                    c[h >> 2] = (c[h >> 2] | 0) + 1;
	                    c[j >> 2] = Tl(c[g >> 2] | 0, h) | 0;
	                    if (c[j >> 2] | 0) {
	                        c[f >> 2] = c[j >> 2];
	                        break
	                    }
	                    if ((a[c[h >> 2] >> 0] | 0) == 63 ? (c[h >> 2] = (c[h >> 2] | 0) + 1, c[j >> 2] = Ul(c[g >> 2] | 0, h) | 0, (c[j >> 2] | 0) != 0) : 0) {
	                        c[f >> 2] = c[j >> 2];
	                        break
	                    }
	                    if ((a[c[h >> 2] >> 0] | 0) == 35 ? (c[h >> 2] = (c[h >> 2] | 0) + 1, c[j >> 2] = Vl(c[g >> 2] | 0, h) | 0, (c[j >> 2] | 0) != 0) : 0) {
	                        c[f >> 2] = c[j >> 2];
	                        break
	                    }
	                    if (a[c[h >> 2] >> 0] | 0) {
	                        Pl(c[g >> 2] | 0);
	                        c[f >> 2] = 1;
	                        break
	                    } else {
	                        c[f >> 2] = 0;
	                        break
	                    }
	                } else c[f >> 2] = c[j >> 2]; while (0);
	                i = e;
	                return c[f >> 2] | 0
	            }

	            function Rl(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if ((a[c[h >> 2] >> 0] | 0) == 47 ? (a[(c[h >> 2] | 0) + 1 >> 0] | 0) == 47 : 0) {
	                    c[h >> 2] = (c[h >> 2] | 0) + 2;
	                    c[j >> 2] = Wl(c[g >> 2] | 0, h) | 0;
	                    if (c[j >> 2] | 0) {
	                        c[f >> 2] = c[j >> 2];
	                        k = c[f >> 2] | 0;
	                        i = e;
	                        return k | 0
	                    }
	                    c[j >> 2] = Xl(c[g >> 2] | 0, h) | 0;
	                    if (c[j >> 2] | 0) {
	                        c[f >> 2] = c[j >> 2];
	                        k = c[f >> 2] | 0;
	                        i = e;
	                        return k | 0
	                    }
	                } else l = 7;
	                a:do if ((l | 0) == 7) {
	                    if ((a[c[h >> 2] >> 0] | 0) == 47) {
	                        c[j >> 2] = Yl(c[g >> 2] | 0, h) | 0;
	                        if (!(c[j >> 2] | 0))break;
	                        c[f >> 2] = c[j >> 2];
	                        k = c[f >> 2] | 0;
	                        i = e;
	                        return k | 0
	                    }
	                    if (!((a[c[h >> 2] >> 0] | 0) >= 97 ? (a[c[h >> 2] >> 0] | 0) <= 122 : 0))l = 12;
	                    b:do if ((l | 0) == 12) {
	                        if ((a[c[h >> 2] >> 0] | 0) >= 65 ? (a[c[h >> 2] >> 0] | 0) <= 90 : 0)break;
	                        if ((a[c[h >> 2] >> 0] | 0) >= 48 ? (a[c[h >> 2] >> 0] | 0) <= 57 : 0)break;
	                        if ((((a[c[h >> 2] >> 0] | 0) != 45 ? (a[c[h >> 2] >> 0] | 0) != 46 : 0) ? (a[c[h >> 2] >> 0] | 0) != 95 : 0) ? (a[c[h >> 2] >> 0] | 0) != 126 : 0) {
	                            c:do if ((a[c[h >> 2] >> 0] | 0) == 37) {
	                                if (!((a[(c[h >> 2] | 0) + 1 >> 0] | 0) >= 48 ? (a[(c[h >> 2] | 0) + 1 >> 0] | 0) <= 57 : 0))l = 23;
	                                do if ((l | 0) == 23) {
	                                    if ((a[(c[h >> 2] | 0) + 1 >> 0] | 0) >= 97 ? (a[(c[h >> 2] | 0) + 1 >> 0] | 0) <= 102 : 0)break;
	                                    if ((a[(c[h >> 2] | 0) + 1 >> 0] | 0) < 65)break c;
	                                    if ((a[(c[h >> 2] | 0) + 1 >> 0] | 0) > 70)break c
	                                } while (0);
	                                if ((a[(c[h >> 2] | 0) + 2 >> 0] | 0) >= 48 ? (a[(c[h >> 2] | 0) + 2 >> 0] | 0) <= 57 : 0)break b;
	                                if ((a[(c[h >> 2] | 0) + 2 >> 0] | 0) >= 97 ? (a[(c[h >> 2] | 0) + 2 >> 0] | 0) <= 102 : 0)break b;
	                                if ((a[(c[h >> 2] | 0) + 2 >> 0] | 0) >= 65 ? (a[(c[h >> 2] | 0) + 2 >> 0] | 0) <= 70 : 0)break b
	                            } while (0);
	                            if ((((((((a[c[h >> 2] >> 0] | 0) != 33 ? (a[c[h >> 2] >> 0] | 0) != 36 : 0) ? (a[c[h >> 2] >> 0] | 0) != 38 : 0) ? (a[c[h >> 2] >> 0] | 0) != 40 : 0) ? (a[c[h >> 2] >> 0] | 0) != 41 : 0) ? (a[c[h >> 2] >> 0] | 0) != 42 : 0) ? (a[c[h >> 2] >> 0] | 0) != 43 : 0) ? (a[c[h >> 2] >> 0] | 0) != 44 : 0) {
	                                if ((a[c[h >> 2] >> 0] | 0) == 59)break;
	                                if ((a[c[h >> 2] >> 0] | 0) == 61)break;
	                                if ((a[c[h >> 2] >> 0] | 0) == 39)break;
	                                if ((a[c[h >> 2] >> 0] | 0) == 58)break;
	                                if ((a[c[h >> 2] >> 0] | 0) == 64)break;
	                                if (!(c[g >> 2] | 0))break a;
	                                if (c[(c[g >> 2] | 0) + 24 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[g >> 2] | 0) + 24 >> 2] | 0);
	                                c[(c[g >> 2] | 0) + 24 >> 2] = 0;
	                                break a
	                            }
	                        }
	                    } while (0);
	                    c[j >> 2] = Zl(c[g >> 2] | 0, h) | 0;
	                    if (c[j >> 2] | 0) {
	                        c[f >> 2] = c[j >> 2];
	                        k = c[f >> 2] | 0;
	                        i = e;
	                        return k | 0
	                    }
	                } while (0);
	                if ((a[c[h >> 2] >> 0] | 0) == 63 ? (c[h >> 2] = (c[h >> 2] | 0) + 1, c[j >> 2] = Ul(c[g >> 2] | 0, h) | 0, (c[j >> 2] | 0) != 0) : 0) {
	                    c[f >> 2] = c[j >> 2];
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                if ((a[c[h >> 2] >> 0] | 0) == 35 ? (c[h >> 2] = (c[h >> 2] | 0) + 1, c[j >> 2] = Vl(c[g >> 2] | 0, h) | 0, (c[j >> 2] | 0) != 0) : 0) {
	                    c[f >> 2] = c[j >> 2];
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                if (a[c[h >> 2] >> 0] | 0) {
	                    Pl(c[g >> 2] | 0);
	                    c[f >> 2] = 1;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                } else {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                return 0
	            }

	            function Sl(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = -1;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                c[j >> 2] = c[c[h >> 2] >> 2];
	                if (!((a[c[j >> 2] >> 0] | 0) >= 97 ? (a[c[j >> 2] >> 0] | 0) <= 122 : 0))l = 5;
	                do if ((l | 0) == 5) {
	                    if ((a[c[j >> 2] >> 0] | 0) >= 65 ? (a[c[j >> 2] >> 0] | 0) <= 90 : 0)break;
	                    c[f >> 2] = 2;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                } while (0);
	                c[j >> 2] = (c[j >> 2] | 0) + 1;
	                a:while (1) {
	                    if (!((a[c[j >> 2] >> 0] | 0) >= 97 ? (a[c[j >> 2] >> 0] | 0) <= 122 : 0))l = 11;
	                    do if ((l | 0) == 11) {
	                        l = 0;
	                        if ((a[c[j >> 2] >> 0] | 0) >= 65 ? (a[c[j >> 2] >> 0] | 0) <= 90 : 0)break;
	                        if ((a[c[j >> 2] >> 0] | 0) >= 48 ? (a[c[j >> 2] >> 0] | 0) <= 57 : 0)break;
	                        if (((a[c[j >> 2] >> 0] | 0) != 43 ? (a[c[j >> 2] >> 0] | 0) != 45 : 0) ? (a[c[j >> 2] >> 0] | 0) != 46 : 0)break a
	                    } while (0);
	                    c[j >> 2] = (c[j >> 2] | 0) + 1
	                }
	                if (c[g >> 2] | 0) {
	                    if (c[c[g >> 2] >> 2] | 0)zb[c[135736 >> 2] & 511](c[c[g >> 2] >> 2] | 0);
	                    l = ly(c[c[h >> 2] >> 2] | 0, (c[j >> 2] | 0) - (c[c[h >> 2] >> 2] | 0) | 0) | 0;
	                    c[c[g >> 2] >> 2] = l
	                }
	                c[c[h >> 2] >> 2] = c[j >> 2];
	                c[f >> 2] = 0;
	                k = c[f >> 2] | 0;
	                i = e;
	                return k | 0
	            }

	            function Tl(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = c[c[h >> 2] >> 2];
	                if ((a[c[j >> 2] >> 0] | 0) == 47 ? (a[(c[j >> 2] | 0) + 1 >> 0] | 0) == 47 : 0) {
	                    c[j >> 2] = (c[j >> 2] | 0) + 2;
	                    c[k >> 2] = Wl(c[g >> 2] | 0, j) | 0;
	                    if (c[k >> 2] | 0) {
	                        c[f >> 2] = c[k >> 2];
	                        l = c[f >> 2] | 0;
	                        i = e;
	                        return l | 0
	                    }
	                    if (!(c[(c[g >> 2] | 0) + 12 >> 2] | 0))c[(c[g >> 2] | 0) + 20 >> 2] = -1;
	                    c[k >> 2] = Xl(c[g >> 2] | 0, j) | 0;
	                    if (c[k >> 2] | 0) {
	                        c[f >> 2] = c[k >> 2];
	                        l = c[f >> 2] | 0;
	                        i = e;
	                        return l | 0
	                    } else {
	                        c[c[h >> 2] >> 2] = c[j >> 2];
	                        c[f >> 2] = 0;
	                        l = c[f >> 2] | 0;
	                        i = e;
	                        return l | 0
	                    }
	                }
	                a:do if ((a[c[j >> 2] >> 0] | 0) == 47) {
	                    c[k >> 2] = Yl(c[g >> 2] | 0, j) | 0;
	                    if (c[k >> 2] | 0) {
	                        c[f >> 2] = c[k >> 2];
	                        l = c[f >> 2] | 0;
	                        i = e;
	                        return l | 0
	                    }
	                } else {
	                    if (!((a[c[j >> 2] >> 0] | 0) >= 97 ? (a[c[j >> 2] >> 0] | 0) <= 122 : 0))m = 15;
	                    b:do if ((m | 0) == 15) {
	                        if ((a[c[j >> 2] >> 0] | 0) >= 65 ? (a[c[j >> 2] >> 0] | 0) <= 90 : 0)break;
	                        if ((a[c[j >> 2] >> 0] | 0) >= 48 ? (a[c[j >> 2] >> 0] | 0) <= 57 : 0)break;
	                        if ((((a[c[j >> 2] >> 0] | 0) != 45 ? (a[c[j >> 2] >> 0] | 0) != 46 : 0) ? (a[c[j >> 2] >> 0] | 0) != 95 : 0) ? (a[c[j >> 2] >> 0] | 0) != 126 : 0) {
	                            c:do if ((a[c[j >> 2] >> 0] | 0) == 37) {
	                                if (!((a[(c[j >> 2] | 0) + 1 >> 0] | 0) >= 48 ? (a[(c[j >> 2] | 0) + 1 >> 0] | 0) <= 57 : 0))m = 26;
	                                do if ((m | 0) == 26) {
	                                    if ((a[(c[j >> 2] | 0) + 1 >> 0] | 0) >= 97 ? (a[(c[j >> 2] | 0) + 1 >> 0] | 0) <= 102 : 0)break;
	                                    if ((a[(c[j >> 2] | 0) + 1 >> 0] | 0) < 65)break c;
	                                    if ((a[(c[j >> 2] | 0) + 1 >> 0] | 0) > 70)break c
	                                } while (0);
	                                if ((a[(c[j >> 2] | 0) + 2 >> 0] | 0) >= 48 ? (a[(c[j >> 2] | 0) + 2 >> 0] | 0) <= 57 : 0)break b;
	                                if ((a[(c[j >> 2] | 0) + 2 >> 0] | 0) >= 97 ? (a[(c[j >> 2] | 0) + 2 >> 0] | 0) <= 102 : 0)break b;
	                                if ((a[(c[j >> 2] | 0) + 2 >> 0] | 0) >= 65 ? (a[(c[j >> 2] | 0) + 2 >> 0] | 0) <= 70 : 0)break b
	                            } while (0);
	                            if ((((((((a[c[j >> 2] >> 0] | 0) != 33 ? (a[c[j >> 2] >> 0] | 0) != 36 : 0) ? (a[c[j >> 2] >> 0] | 0) != 38 : 0) ? (a[c[j >> 2] >> 0] | 0) != 40 : 0) ? (a[c[j >> 2] >> 0] | 0) != 41 : 0) ? (a[c[j >> 2] >> 0] | 0) != 42 : 0) ? (a[c[j >> 2] >> 0] | 0) != 43 : 0) ? (a[c[j >> 2] >> 0] | 0) != 44 : 0) {
	                                if ((a[c[j >> 2] >> 0] | 0) == 59)break;
	                                if ((a[c[j >> 2] >> 0] | 0) == 61)break;
	                                if ((a[c[j >> 2] >> 0] | 0) == 39)break;
	                                if ((a[c[j >> 2] >> 0] | 0) == 58)break;
	                                if ((a[c[j >> 2] >> 0] | 0) == 64)break;
	                                if (!(c[g >> 2] | 0))break a;
	                                if (c[(c[g >> 2] | 0) + 24 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[g >> 2] | 0) + 24 >> 2] | 0);
	                                c[(c[g >> 2] | 0) + 24 >> 2] = 0;
	                                break a
	                            }
	                        }
	                    } while (0);
	                    c[k >> 2] = _l(c[g >> 2] | 0, j) | 0;
	                    if (c[k >> 2] | 0) {
	                        c[f >> 2] = c[k >> 2];
	                        l = c[f >> 2] | 0;
	                        i = e;
	                        return l | 0
	                    }
	                } while (0);
	                c[c[h >> 2] >> 2] = c[j >> 2];
	                c[f >> 2] = 0;
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function Ul(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = -1;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                c[j >> 2] = c[c[h >> 2] >> 2];
	                a:while (1) {
	                    if (!((a[c[j >> 2] >> 0] | 0) >= 97 ? (a[c[j >> 2] >> 0] | 0) <= 122 : 0))l = 6;
	                    b:do if ((l | 0) == 6) {
	                        l = 0;
	                        if ((a[c[j >> 2] >> 0] | 0) >= 65 ? (a[c[j >> 2] >> 0] | 0) <= 90 : 0)break;
	                        if ((a[c[j >> 2] >> 0] | 0) >= 48 ? (a[c[j >> 2] >> 0] | 0) <= 57 : 0)break;
	                        if ((((a[c[j >> 2] >> 0] | 0) != 45 ? (a[c[j >> 2] >> 0] | 0) != 46 : 0) ? (a[c[j >> 2] >> 0] | 0) != 95 : 0) ? (a[c[j >> 2] >> 0] | 0) != 126 : 0) {
	                            c:do if ((a[c[j >> 2] >> 0] | 0) == 37) {
	                                if (!((a[(c[j >> 2] | 0) + 1 >> 0] | 0) >= 48 ? (a[(c[j >> 2] | 0) + 1 >> 0] | 0) <= 57 : 0))l = 17;
	                                do if ((l | 0) == 17) {
	                                    l = 0;
	                                    if ((a[(c[j >> 2] | 0) + 1 >> 0] | 0) >= 97 ? (a[(c[j >> 2] | 0) + 1 >> 0] | 0) <= 102 : 0)break;
	                                    if ((a[(c[j >> 2] | 0) + 1 >> 0] | 0) < 65)break c;
	                                    if ((a[(c[j >> 2] | 0) + 1 >> 0] | 0) > 70)break c
	                                } while (0);
	                                if ((a[(c[j >> 2] | 0) + 2 >> 0] | 0) >= 48 ? (a[(c[j >> 2] | 0) + 2 >> 0] | 0) <= 57 : 0)break b;
	                                if ((a[(c[j >> 2] | 0) + 2 >> 0] | 0) >= 97 ? (a[(c[j >> 2] | 0) + 2 >> 0] | 0) <= 102 : 0)break b;
	                                if ((a[(c[j >> 2] | 0) + 2 >> 0] | 0) >= 65 ? (a[(c[j >> 2] | 0) + 2 >> 0] | 0) <= 70 : 0)break b
	                            } while (0);
	                            if (((((((((a[c[j >> 2] >> 0] | 0) != 33 ? (a[c[j >> 2] >> 0] | 0) != 36 : 0) ? (a[c[j >> 2] >> 0] | 0) != 38 : 0) ? (a[c[j >> 2] >> 0] | 0) != 40 : 0) ? (a[c[j >> 2] >> 0] | 0) != 41 : 0) ? (a[c[j >> 2] >> 0] | 0) != 42 : 0) ? (a[c[j >> 2] >> 0] | 0) != 43 : 0) ? (a[c[j >> 2] >> 0] | 0) != 44 : 0) ? (a[c[j >> 2] >> 0] | 0) != 59 : 0) {
	                                if ((a[c[j >> 2] >> 0] | 0) == 61)break;
	                                if ((a[c[j >> 2] >> 0] | 0) == 39)break;
	                                if ((a[c[j >> 2] >> 0] | 0) == 58)break;
	                                if ((a[c[j >> 2] >> 0] | 0) == 64)break;
	                                if ((a[c[j >> 2] >> 0] | 0) == 47)break;
	                                if ((a[c[j >> 2] >> 0] | 0) == 63)break;
	                                if (!(c[g >> 2] | 0))break a;
	                                if (!(c[(c[g >> 2] | 0) + 36 >> 2] & 1))break a;
	                                if ((a[c[j >> 2] >> 0] | 0) == 123)break;
	                                if ((a[c[j >> 2] >> 0] | 0) == 125)break;
	                                if ((a[c[j >> 2] >> 0] | 0) == 124)break;
	                                if ((a[c[j >> 2] >> 0] | 0) == 92)break;
	                                if ((a[c[j >> 2] >> 0] | 0) == 94)break;
	                                if ((a[c[j >> 2] >> 0] | 0) == 91)break;
	                                if ((a[c[j >> 2] >> 0] | 0) == 93)break;
	                                if ((a[c[j >> 2] >> 0] | 0) != 96)break a
	                            }
	                        }
	                    } while (0);
	                    d = c[j >> 2] | 0;
	                    if ((a[c[j >> 2] >> 0] | 0) == 37) {
	                        c[j >> 2] = d + 3;
	                        continue
	                    } else {
	                        c[j >> 2] = d + 1;
	                        continue
	                    }
	                }
	                if (c[g >> 2] | 0) {
	                    if (c[(c[g >> 2] | 0) + 28 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[g >> 2] | 0) + 28 >> 2] | 0);
	                    l = c[c[h >> 2] >> 2] | 0;
	                    d = (c[j >> 2] | 0) - (c[c[h >> 2] >> 2] | 0) | 0;
	                    if (c[(c[g >> 2] | 0) + 36 >> 2] & 2) {
	                        b = ly(l, d) | 0;
	                        c[(c[g >> 2] | 0) + 28 >> 2] = b
	                    } else {
	                        b = El(l, d, 0) | 0;
	                        c[(c[g >> 2] | 0) + 28 >> 2] = b
	                    }
	                    if (c[(c[g >> 2] | 0) + 40 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[g >> 2] | 0) + 40 >> 2] | 0);
	                    b = ly(c[c[h >> 2] >> 2] | 0, (c[j >> 2] | 0) - (c[c[h >> 2] >> 2] | 0) | 0) | 0;
	                    c[(c[g >> 2] | 0) + 40 >> 2] = b
	                }
	                c[c[h >> 2] >> 2] = c[j >> 2];
	                c[f >> 2] = 0;
	                k = c[f >> 2] | 0;
	                i = e;
	                return k | 0
	            }

	            function Vl(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = -1;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                c[j >> 2] = c[c[h >> 2] >> 2];
	                a:while (1) {
	                    if (!((a[c[j >> 2] >> 0] | 0) >= 97 ? (a[c[j >> 2] >> 0] | 0) <= 122 : 0))l = 6;
	                    b:do if ((l | 0) == 6) {
	                        l = 0;
	                        if ((a[c[j >> 2] >> 0] | 0) >= 65 ? (a[c[j >> 2] >> 0] | 0) <= 90 : 0)break;
	                        if ((a[c[j >> 2] >> 0] | 0) >= 48 ? (a[c[j >> 2] >> 0] | 0) <= 57 : 0)break;
	                        if ((((a[c[j >> 2] >> 0] | 0) != 45 ? (a[c[j >> 2] >> 0] | 0) != 46 : 0) ? (a[c[j >> 2] >> 0] | 0) != 95 : 0) ? (a[c[j >> 2] >> 0] | 0) != 126 : 0) {
	                            c:do if ((a[c[j >> 2] >> 0] | 0) == 37) {
	                                if (!((a[(c[j >> 2] | 0) + 1 >> 0] | 0) >= 48 ? (a[(c[j >> 2] | 0) + 1 >> 0] | 0) <= 57 : 0))l = 17;
	                                do if ((l | 0) == 17) {
	                                    l = 0;
	                                    if ((a[(c[j >> 2] | 0) + 1 >> 0] | 0) >= 97 ? (a[(c[j >> 2] | 0) + 1 >> 0] | 0) <= 102 : 0)break;
	                                    if ((a[(c[j >> 2] | 0) + 1 >> 0] | 0) < 65)break c;
	                                    if ((a[(c[j >> 2] | 0) + 1 >> 0] | 0) > 70)break c
	                                } while (0);
	                                if ((a[(c[j >> 2] | 0) + 2 >> 0] | 0) >= 48 ? (a[(c[j >> 2] | 0) + 2 >> 0] | 0) <= 57 : 0)break b;
	                                if ((a[(c[j >> 2] | 0) + 2 >> 0] | 0) >= 97 ? (a[(c[j >> 2] | 0) + 2 >> 0] | 0) <= 102 : 0)break b;
	                                if ((a[(c[j >> 2] | 0) + 2 >> 0] | 0) >= 65 ? (a[(c[j >> 2] | 0) + 2 >> 0] | 0) <= 70 : 0)break b
	                            } while (0);
	                            if (((((((((a[c[j >> 2] >> 0] | 0) != 33 ? (a[c[j >> 2] >> 0] | 0) != 36 : 0) ? (a[c[j >> 2] >> 0] | 0) != 38 : 0) ? (a[c[j >> 2] >> 0] | 0) != 40 : 0) ? (a[c[j >> 2] >> 0] | 0) != 41 : 0) ? (a[c[j >> 2] >> 0] | 0) != 42 : 0) ? (a[c[j >> 2] >> 0] | 0) != 43 : 0) ? (a[c[j >> 2] >> 0] | 0) != 44 : 0) ? (a[c[j >> 2] >> 0] | 0) != 59 : 0) {
	                                if ((a[c[j >> 2] >> 0] | 0) == 61)break;
	                                if ((a[c[j >> 2] >> 0] | 0) == 39)break;
	                                if ((a[c[j >> 2] >> 0] | 0) == 58)break;
	                                if ((a[c[j >> 2] >> 0] | 0) == 64)break;
	                                if ((a[c[j >> 2] >> 0] | 0) == 47)break;
	                                if ((a[c[j >> 2] >> 0] | 0) == 63)break;
	                                if ((a[c[j >> 2] >> 0] | 0) == 91)break;
	                                if ((a[c[j >> 2] >> 0] | 0) == 93)break;
	                                if (!(c[g >> 2] | 0))break a;
	                                if (!(c[(c[g >> 2] | 0) + 36 >> 2] & 1))break a;
	                                if ((a[c[j >> 2] >> 0] | 0) == 123)break;
	                                if ((a[c[j >> 2] >> 0] | 0) == 125)break;
	                                if ((a[c[j >> 2] >> 0] | 0) == 124)break;
	                                if ((a[c[j >> 2] >> 0] | 0) == 92)break;
	                                if ((a[c[j >> 2] >> 0] | 0) == 94)break;
	                                if ((a[c[j >> 2] >> 0] | 0) == 91)break;
	                                if ((a[c[j >> 2] >> 0] | 0) == 93)break;
	                                if ((a[c[j >> 2] >> 0] | 0) != 96)break a
	                            }
	                        }
	                    } while (0);
	                    d = c[j >> 2] | 0;
	                    if ((a[c[j >> 2] >> 0] | 0) == 37) {
	                        c[j >> 2] = d + 3;
	                        continue
	                    } else {
	                        c[j >> 2] = d + 1;
	                        continue
	                    }
	                }
	                do if (c[g >> 2] | 0) {
	                    if (c[(c[g >> 2] | 0) + 32 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[g >> 2] | 0) + 32 >> 2] | 0);
	                    l = c[c[h >> 2] >> 2] | 0;
	                    d = (c[j >> 2] | 0) - (c[c[h >> 2] >> 2] | 0) | 0;
	                    if (c[(c[g >> 2] | 0) + 36 >> 2] & 2) {
	                        b = ly(l, d) | 0;
	                        c[(c[g >> 2] | 0) + 32 >> 2] = b;
	                        break
	                    } else {
	                        b = El(l, d, 0) | 0;
	                        c[(c[g >> 2] | 0) + 32 >> 2] = b;
	                        break
	                    }
	                } while (0);
	                c[c[h >> 2] >> 2] = c[j >> 2];
	                c[f >> 2] = 0;
	                k = c[f >> 2] | 0;
	                i = e;
	                return k | 0
	            }

	            function Wl(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = c[c[h >> 2] >> 2];
	                c[k >> 2] = $l(c[g >> 2] | 0, j) | 0;
	                if ((c[k >> 2] | 0) == 0 ? (a[c[j >> 2] >> 0] | 0) == 64 : 0)c[j >> 2] = (c[j >> 2] | 0) + 1; else c[j >> 2] = c[c[h >> 2] >> 2];
	                c[k >> 2] = am(c[g >> 2] | 0, j) | 0;
	                if (c[k >> 2] | 0) {
	                    c[f >> 2] = c[k >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                if ((a[c[j >> 2] >> 0] | 0) == 58 ? (c[j >> 2] = (c[j >> 2] | 0) + 1, c[k >> 2] = bm(c[g >> 2] | 0, j) | 0, (c[k >> 2] | 0) != 0) : 0) {
	                    c[f >> 2] = c[k >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[c[h >> 2] >> 2] = c[j >> 2];
	                c[f >> 2] = 0;
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function Xl(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = c[c[h >> 2] >> 2];
	                while (1) {
	                    if ((a[c[j >> 2] >> 0] | 0) != 47)break;
	                    c[j >> 2] = (c[j >> 2] | 0) + 1;
	                    c[k >> 2] = cm(j, 0, 1) | 0;
	                    if (c[k >> 2] | 0) {
	                        l = 4;
	                        break
	                    }
	                }
	                if ((l | 0) == 4) {
	                    c[f >> 2] = c[k >> 2];
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                do if (c[g >> 2] | 0) {
	                    if (c[(c[g >> 2] | 0) + 24 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[g >> 2] | 0) + 24 >> 2] | 0);
	                    k = c[g >> 2] | 0;
	                    if ((c[c[h >> 2] >> 2] | 0) == (c[j >> 2] | 0)) {
	                        c[k + 24 >> 2] = 0;
	                        break
	                    }
	                    l = c[c[h >> 2] >> 2] | 0;
	                    d = (c[j >> 2] | 0) - (c[c[h >> 2] >> 2] | 0) | 0;
	                    if (c[k + 36 >> 2] & 2) {
	                        k = ly(l, d) | 0;
	                        c[(c[g >> 2] | 0) + 24 >> 2] = k;
	                        break
	                    } else {
	                        k = El(l, d, 0) | 0;
	                        c[(c[g >> 2] | 0) + 24 >> 2] = k;
	                        break
	                    }
	                } while (0);
	                c[c[h >> 2] >> 2] = c[j >> 2];
	                c[f >> 2] = 0;
	                m = c[f >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function Yl(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = c[c[h >> 2] >> 2];
	                if ((a[c[j >> 2] >> 0] | 0) != 47) {
	                    c[f >> 2] = 1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[j >> 2] = (c[j >> 2] | 0) + 1;
	                c[k >> 2] = cm(j, 0, 0) | 0;
	                a:do if (!(c[k >> 2] | 0)) {
	                    do {
	                        if ((a[c[j >> 2] >> 0] | 0) != 47)break a;
	                        c[j >> 2] = (c[j >> 2] | 0) + 1;
	                        c[k >> 2] = cm(j, 0, 1) | 0
	                    } while ((c[k >> 2] | 0) == 0);
	                    c[f >> 2] = c[k >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } while (0);
	                do if (c[g >> 2] | 0) {
	                    if (c[(c[g >> 2] | 0) + 24 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[g >> 2] | 0) + 24 >> 2] | 0);
	                    k = c[g >> 2] | 0;
	                    if ((c[j >> 2] | 0) == (c[c[h >> 2] >> 2] | 0)) {
	                        c[k + 24 >> 2] = 0;
	                        break
	                    }
	                    d = c[c[h >> 2] >> 2] | 0;
	                    b = (c[j >> 2] | 0) - (c[c[h >> 2] >> 2] | 0) | 0;
	                    if (c[k + 36 >> 2] & 2) {
	                        k = ly(d, b) | 0;
	                        c[(c[g >> 2] | 0) + 24 >> 2] = k;
	                        break
	                    } else {
	                        k = El(d, b, 0) | 0;
	                        c[(c[g >> 2] | 0) + 24 >> 2] = k;
	                        break
	                    }
	                } while (0);
	                c[c[h >> 2] >> 2] = c[j >> 2];
	                c[f >> 2] = 0;
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function Zl(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = c[c[h >> 2] >> 2];
	                c[k >> 2] = cm(j, 58, 0) | 0;
	                if (c[k >> 2] | 0) {
	                    c[f >> 2] = c[k >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                while (1) {
	                    if ((a[c[j >> 2] >> 0] | 0) != 47)break;
	                    c[j >> 2] = (c[j >> 2] | 0) + 1;
	                    c[k >> 2] = cm(j, 0, 1) | 0;
	                    if (c[k >> 2] | 0) {
	                        m = 5;
	                        break
	                    }
	                }
	                if ((m | 0) == 5) {
	                    c[f >> 2] = c[k >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                do if (c[g >> 2] | 0) {
	                    if (c[(c[g >> 2] | 0) + 24 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[g >> 2] | 0) + 24 >> 2] | 0);
	                    k = c[g >> 2] | 0;
	                    if ((c[j >> 2] | 0) == (c[c[h >> 2] >> 2] | 0)) {
	                        c[k + 24 >> 2] = 0;
	                        break
	                    }
	                    m = c[c[h >> 2] >> 2] | 0;
	                    d = (c[j >> 2] | 0) - (c[c[h >> 2] >> 2] | 0) | 0;
	                    if (c[k + 36 >> 2] & 2) {
	                        k = ly(m, d) | 0;
	                        c[(c[g >> 2] | 0) + 24 >> 2] = k;
	                        break
	                    } else {
	                        k = El(m, d, 0) | 0;
	                        c[(c[g >> 2] | 0) + 24 >> 2] = k;
	                        break
	                    }
	                } while (0);
	                c[c[h >> 2] >> 2] = c[j >> 2];
	                c[f >> 2] = 0;
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function _l(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = c[c[h >> 2] >> 2];
	                c[k >> 2] = cm(j, 0, 0) | 0;
	                if (c[k >> 2] | 0) {
	                    c[f >> 2] = c[k >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                while (1) {
	                    if ((a[c[j >> 2] >> 0] | 0) != 47)break;
	                    c[j >> 2] = (c[j >> 2] | 0) + 1;
	                    c[k >> 2] = cm(j, 0, 1) | 0;
	                    if (c[k >> 2] | 0) {
	                        m = 5;
	                        break
	                    }
	                }
	                if ((m | 0) == 5) {
	                    c[f >> 2] = c[k >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                do if (c[g >> 2] | 0) {
	                    if (c[(c[g >> 2] | 0) + 24 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[g >> 2] | 0) + 24 >> 2] | 0);
	                    k = c[g >> 2] | 0;
	                    if ((c[j >> 2] | 0) == (c[c[h >> 2] >> 2] | 0)) {
	                        c[k + 24 >> 2] = 0;
	                        break
	                    }
	                    m = c[c[h >> 2] >> 2] | 0;
	                    d = (c[j >> 2] | 0) - (c[c[h >> 2] >> 2] | 0) | 0;
	                    if (c[k + 36 >> 2] & 2) {
	                        k = ly(m, d) | 0;
	                        c[(c[g >> 2] | 0) + 24 >> 2] = k;
	                        break
	                    } else {
	                        k = El(m, d, 0) | 0;
	                        c[(c[g >> 2] | 0) + 24 >> 2] = k;
	                        break
	                    }
	                } while (0);
	                c[c[h >> 2] >> 2] = c[j >> 2];
	                c[f >> 2] = 0;
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function $l(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = c[c[h >> 2] >> 2];
	                while (1) {
	                    if ((a[c[j >> 2] >> 0] | 0) >= 97 ? (a[c[j >> 2] >> 0] | 0) <= 122 : 0)k = 1; else l = 4;
	                    a:do if ((l | 0) == 4) {
	                        l = 0;
	                        if ((a[c[j >> 2] >> 0] | 0) >= 65 ? (a[c[j >> 2] >> 0] | 0) <= 90 : 0) {
	                            k = 1;
	                            break
	                        }
	                        if ((a[c[j >> 2] >> 0] | 0) >= 48 ? (a[c[j >> 2] >> 0] | 0) <= 57 : 0) {
	                            k = 1;
	                            break
	                        }
	                        if ((((a[c[j >> 2] >> 0] | 0) != 45 ? (a[c[j >> 2] >> 0] | 0) != 46 : 0) ? (a[c[j >> 2] >> 0] | 0) != 95 : 0) ? (a[c[j >> 2] >> 0] | 0) != 126 : 0) {
	                            b:do if ((a[c[j >> 2] >> 0] | 0) == 37) {
	                                if (!((a[(c[j >> 2] | 0) + 1 >> 0] | 0) >= 48 ? (a[(c[j >> 2] | 0) + 1 >> 0] | 0) <= 57 : 0))l = 15;
	                                do if ((l | 0) == 15) {
	                                    l = 0;
	                                    if ((a[(c[j >> 2] | 0) + 1 >> 0] | 0) >= 97 ? (a[(c[j >> 2] | 0) + 1 >> 0] | 0) <= 102 : 0)break;
	                                    if ((a[(c[j >> 2] | 0) + 1 >> 0] | 0) < 65)break b;
	                                    if ((a[(c[j >> 2] | 0) + 1 >> 0] | 0) > 70)break b
	                                } while (0);
	                                if ((a[(c[j >> 2] | 0) + 2 >> 0] | 0) >= 48 ? (a[(c[j >> 2] | 0) + 2 >> 0] | 0) <= 57 : 0) {
	                                    k = 1;
	                                    break a
	                                }
	                                if ((a[(c[j >> 2] | 0) + 2 >> 0] | 0) >= 97 ? (a[(c[j >> 2] | 0) + 2 >> 0] | 0) <= 102 : 0) {
	                                    k = 1;
	                                    break a
	                                }
	                                if ((a[(c[j >> 2] | 0) + 2 >> 0] | 0) >= 65 ? (a[(c[j >> 2] | 0) + 2 >> 0] | 0) <= 70 : 0) {
	                                    k = 1;
	                                    break a
	                                }
	                            } while (0);
	                            if ((((((((((a[c[j >> 2] >> 0] | 0) != 33 ? (a[c[j >> 2] >> 0] | 0) != 36 : 0) ? (a[c[j >> 2] >> 0] | 0) != 38 : 0) ? (a[c[j >> 2] >> 0] | 0) != 40 : 0) ? (a[c[j >> 2] >> 0] | 0) != 41 : 0) ? (a[c[j >> 2] >> 0] | 0) != 42 : 0) ? (a[c[j >> 2] >> 0] | 0) != 43 : 0) ? (a[c[j >> 2] >> 0] | 0) != 44 : 0) ? (a[c[j >> 2] >> 0] | 0) != 59 : 0) ? (a[c[j >> 2] >> 0] | 0) != 61 : 0) {
	                                if ((a[c[j >> 2] >> 0] | 0) == 39) {
	                                    k = 1;
	                                    break
	                                }
	                                k = (a[c[j >> 2] >> 0] | 0) == 58
	                            } else k = 1
	                        } else k = 1
	                    } while (0);
	                    m = a[c[j >> 2] >> 0] | 0;
	                    if (!k)break;
	                    d = c[j >> 2] | 0;
	                    if ((m | 0) == 37) {
	                        c[j >> 2] = d + 3;
	                        continue
	                    } else {
	                        c[j >> 2] = d + 1;
	                        continue
	                    }
	                }
	                if ((m | 0) != 64) {
	                    c[f >> 2] = 1;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                do if (c[g >> 2] | 0) {
	                    if (c[(c[g >> 2] | 0) + 16 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[g >> 2] | 0) + 16 >> 2] | 0);
	                    m = c[c[h >> 2] >> 2] | 0;
	                    k = (c[j >> 2] | 0) - (c[c[h >> 2] >> 2] | 0) | 0;
	                    if (c[(c[g >> 2] | 0) + 36 >> 2] & 2) {
	                        l = ly(m, k) | 0;
	                        c[(c[g >> 2] | 0) + 16 >> 2] = l;
	                        break
	                    } else {
	                        l = El(m, k, 0) | 0;
	                        c[(c[g >> 2] | 0) + 16 >> 2] = l;
	                        break
	                    }
	                } while (0);
	                c[c[h >> 2] >> 2] = c[j >> 2];
	                c[f >> 2] = 0;
	                n = c[f >> 2] | 0;
	                i = e;
	                return n | 0
	            }

	            function am(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = c[c[h >> 2] >> 2];
	                c[k >> 2] = c[j >> 2];
	                d = c[j >> 2] | 0;
	                a:do if ((a[c[j >> 2] >> 0] | 0) == 91) {
	                    c[j >> 2] = d + 1;
	                    while (1) {
	                        if ((a[c[j >> 2] >> 0] | 0) != 93)l = (a[c[j >> 2] >> 0] | 0) != 0; else l = 0;
	                        m = c[j >> 2] | 0;
	                        if (!l)break;
	                        c[j >> 2] = m + 1
	                    }
	                    if ((a[m >> 0] | 0) == 93) {
	                        c[j >> 2] = (c[j >> 2] | 0) + 1;
	                        break
	                    }
	                    c[f >> 2] = 1;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                } else {
	                    if ((a[d >> 0] | 0) >= 48 ? (a[c[j >> 2] >> 0] | 0) <= 57 : 0) {
	                        if (((((((dm(j) | 0) == 0 ? (a[c[j >> 2] >> 0] | 0) == 46 : 0) ? (c[j >> 2] = (c[j >> 2] | 0) + 1, (dm(j) | 0) == 0) : 0) ? (a[c[j >> 2] >> 0] | 0) == 46 : 0) ? (dm(j) | 0) == 0 : 0) ? (a[c[j >> 2] >> 0] | 0) == 46 : 0) ? (dm(j) | 0) == 0 : 0)break;
	                        c[j >> 2] = c[c[h >> 2] >> 2]
	                    }
	                    while (1) {
	                        if (!((a[c[j >> 2] >> 0] | 0) >= 97 ? (a[c[j >> 2] >> 0] | 0) <= 122 : 0))o = 22;
	                        b:do if ((o | 0) == 22) {
	                            o = 0;
	                            if ((a[c[j >> 2] >> 0] | 0) >= 65 ? (a[c[j >> 2] >> 0] | 0) <= 90 : 0)break;
	                            if ((a[c[j >> 2] >> 0] | 0) >= 48 ? (a[c[j >> 2] >> 0] | 0) <= 57 : 0)break;
	                            if ((((a[c[j >> 2] >> 0] | 0) != 45 ? (a[c[j >> 2] >> 0] | 0) != 46 : 0) ? (a[c[j >> 2] >> 0] | 0) != 95 : 0) ? (a[c[j >> 2] >> 0] | 0) != 126 : 0) {
	                                c:do if ((a[c[j >> 2] >> 0] | 0) == 37) {
	                                    if (!((a[(c[j >> 2] | 0) + 1 >> 0] | 0) >= 48 ? (a[(c[j >> 2] | 0) + 1 >> 0] | 0) <= 57 : 0))o = 33;
	                                    do if ((o | 0) == 33) {
	                                        o = 0;
	                                        if ((a[(c[j >> 2] | 0) + 1 >> 0] | 0) >= 97 ? (a[(c[j >> 2] | 0) + 1 >> 0] | 0) <= 102 : 0)break;
	                                        if ((a[(c[j >> 2] | 0) + 1 >> 0] | 0) < 65)break c;
	                                        if ((a[(c[j >> 2] | 0) + 1 >> 0] | 0) > 70)break c
	                                    } while (0);
	                                    if ((a[(c[j >> 2] | 0) + 2 >> 0] | 0) >= 48 ? (a[(c[j >> 2] | 0) + 2 >> 0] | 0) <= 57 : 0)break b;
	                                    if ((a[(c[j >> 2] | 0) + 2 >> 0] | 0) >= 97 ? (a[(c[j >> 2] | 0) + 2 >> 0] | 0) <= 102 : 0)break b;
	                                    if ((a[(c[j >> 2] | 0) + 2 >> 0] | 0) >= 65 ? (a[(c[j >> 2] | 0) + 2 >> 0] | 0) <= 70 : 0)break b
	                                } while (0);
	                                if (((((((a[c[j >> 2] >> 0] | 0) != 33 ? (a[c[j >> 2] >> 0] | 0) != 36 : 0) ? (a[c[j >> 2] >> 0] | 0) != 38 : 0) ? (a[c[j >> 2] >> 0] | 0) != 40 : 0) ? (a[c[j >> 2] >> 0] | 0) != 41 : 0) ? (a[c[j >> 2] >> 0] | 0) != 42 : 0) ? (a[c[j >> 2] >> 0] | 0) != 43 : 0) {
	                                    if ((a[c[j >> 2] >> 0] | 0) == 44)break;
	                                    if ((a[c[j >> 2] >> 0] | 0) == 59)break;
	                                    if ((a[c[j >> 2] >> 0] | 0) == 61)break;
	                                    if ((a[c[j >> 2] >> 0] | 0) != 39)break a
	                                }
	                            }
	                        } while (0);
	                        b = c[j >> 2] | 0;
	                        if ((a[c[j >> 2] >> 0] | 0) == 37) {
	                            c[j >> 2] = b + 3;
	                            continue
	                        } else {
	                            c[j >> 2] = b + 1;
	                            continue
	                        }
	                    }
	                } while (0);
	                do if (c[g >> 2] | 0) {
	                    if (c[(c[g >> 2] | 0) + 8 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[g >> 2] | 0) + 8 >> 2] | 0);
	                    c[(c[g >> 2] | 0) + 8 >> 2] = 0;
	                    if (c[(c[g >> 2] | 0) + 12 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[g >> 2] | 0) + 12 >> 2] | 0);
	                    o = c[g >> 2] | 0;
	                    if ((c[j >> 2] | 0) == (c[k >> 2] | 0)) {
	                        c[o + 12 >> 2] = 0;
	                        break
	                    }
	                    d = c[k >> 2] | 0;
	                    m = (c[j >> 2] | 0) - (c[k >> 2] | 0) | 0;
	                    if (c[o + 36 >> 2] & 2) {
	                        o = ly(d, m) | 0;
	                        c[(c[g >> 2] | 0) + 12 >> 2] = o;
	                        break
	                    } else {
	                        o = El(d, m, 0) | 0;
	                        c[(c[g >> 2] | 0) + 12 >> 2] = o;
	                        break
	                    }
	                } while (0);
	                c[c[h >> 2] >> 2] = c[j >> 2];
	                c[f >> 2] = 0;
	                n = c[f >> 2] | 0;
	                i = e;
	                return n | 0
	            }

	            function bm(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = c[c[h >> 2] >> 2];
	                if ((a[c[j >> 2] >> 0] | 0) >= 48 ? (a[c[j >> 2] >> 0] | 0) <= 57 : 0) {
	                    if (c[g >> 2] | 0)c[(c[g >> 2] | 0) + 20 >> 2] = 0;
	                    while (1) {
	                        if ((a[c[j >> 2] >> 0] | 0) < 48)break;
	                        if ((a[c[j >> 2] >> 0] | 0) > 57)break;
	                        if (c[g >> 2] | 0)c[(c[g >> 2] | 0) + 20 >> 2] = ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) * 10 | 0) + ((a[c[j >> 2] >> 0] | 0) - 48);
	                        c[j >> 2] = (c[j >> 2] | 0) + 1
	                    }
	                    c[c[h >> 2] >> 2] = c[j >> 2];
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                c[f >> 2] = 1;
	                k = c[f >> 2] | 0;
	                i = e;
	                return k | 0
	            }

	            function cm(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 12 | 0;
	                h = f + 8 | 0;
	                j = f + 16 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[h >> 2] = b;
	                a[j >> 0] = d;
	                c[k >> 2] = e;
	                c[l >> 2] = c[c[h >> 2] >> 2];
	                if (!((a[c[l >> 2] >> 0] | 0) >= 97 ? (a[c[l >> 2] >> 0] | 0) <= 122 : 0))m = 3;
	                a:do if ((m | 0) == 3) {
	                    if ((a[c[l >> 2] >> 0] | 0) >= 65 ? (a[c[l >> 2] >> 0] | 0) <= 90 : 0)break;
	                    if ((a[c[l >> 2] >> 0] | 0) >= 48 ? (a[c[l >> 2] >> 0] | 0) <= 57 : 0)break;
	                    if ((((a[c[l >> 2] >> 0] | 0) != 45 ? (a[c[l >> 2] >> 0] | 0) != 46 : 0) ? (a[c[l >> 2] >> 0] | 0) != 95 : 0) ? (a[c[l >> 2] >> 0] | 0) != 126 : 0) {
	                        b:do if ((a[c[l >> 2] >> 0] | 0) == 37) {
	                            if (!((a[(c[l >> 2] | 0) + 1 >> 0] | 0) >= 48 ? (a[(c[l >> 2] | 0) + 1 >> 0] | 0) <= 57 : 0))m = 14;
	                            do if ((m | 0) == 14) {
	                                if ((a[(c[l >> 2] | 0) + 1 >> 0] | 0) >= 97 ? (a[(c[l >> 2] | 0) + 1 >> 0] | 0) <= 102 : 0)break;
	                                if ((a[(c[l >> 2] | 0) + 1 >> 0] | 0) < 65)break b;
	                                if ((a[(c[l >> 2] | 0) + 1 >> 0] | 0) > 70)break b
	                            } while (0);
	                            if ((a[(c[l >> 2] | 0) + 2 >> 0] | 0) >= 48 ? (a[(c[l >> 2] | 0) + 2 >> 0] | 0) <= 57 : 0)break a;
	                            if ((a[(c[l >> 2] | 0) + 2 >> 0] | 0) >= 97 ? (a[(c[l >> 2] | 0) + 2 >> 0] | 0) <= 102 : 0)break a;
	                            if ((a[(c[l >> 2] | 0) + 2 >> 0] | 0) >= 65 ? (a[(c[l >> 2] | 0) + 2 >> 0] | 0) <= 70 : 0)break a
	                        } while (0);
	                        if (((((((((((a[c[l >> 2] >> 0] | 0) != 33 ? (a[c[l >> 2] >> 0] | 0) != 36 : 0) ? (a[c[l >> 2] >> 0] | 0) != 38 : 0) ? (a[c[l >> 2] >> 0] | 0) != 40 : 0) ? (a[c[l >> 2] >> 0] | 0) != 41 : 0) ? (a[c[l >> 2] >> 0] | 0) != 42 : 0) ? (a[c[l >> 2] >> 0] | 0) != 43 : 0) ? (a[c[l >> 2] >> 0] | 0) != 44 : 0) ? (a[c[l >> 2] >> 0] | 0) != 59 : 0) ? (a[c[l >> 2] >> 0] | 0) != 61 : 0) ? (a[c[l >> 2] >> 0] | 0) != 39 : 0) {
	                            if ((a[c[l >> 2] >> 0] | 0) == 58)break;
	                            if ((a[c[l >> 2] >> 0] | 0) == 64)break;
	                            if (c[k >> 2] | 0) {
	                                c[g >> 2] = 0;
	                                n = c[g >> 2] | 0;
	                                i = f;
	                                return n | 0
	                            } else {
	                                c[g >> 2] = 1;
	                                n = c[g >> 2] | 0;
	                                i = f;
	                                return n | 0
	                            }
	                        }
	                    }
	                } while (0);
	                while (1) {
	                    if ((a[c[l >> 2] >> 0] | 0) >= 97 ? (a[c[l >> 2] >> 0] | 0) <= 122 : 0)m = 76; else m = 42;
	                    c:do if ((m | 0) == 42) {
	                        m = 0;
	                        if ((a[c[l >> 2] >> 0] | 0) >= 65 ? (a[c[l >> 2] >> 0] | 0) <= 90 : 0) {
	                            m = 76;
	                            break
	                        }
	                        if ((a[c[l >> 2] >> 0] | 0) >= 48 ? (a[c[l >> 2] >> 0] | 0) <= 57 : 0) {
	                            m = 76;
	                            break
	                        }
	                        if ((((a[c[l >> 2] >> 0] | 0) != 45 ? (a[c[l >> 2] >> 0] | 0) != 46 : 0) ? (a[c[l >> 2] >> 0] | 0) != 95 : 0) ? (a[c[l >> 2] >> 0] | 0) != 126 : 0) {
	                            d:do if ((a[c[l >> 2] >> 0] | 0) == 37) {
	                                if (!((a[(c[l >> 2] | 0) + 1 >> 0] | 0) >= 48 ? (a[(c[l >> 2] | 0) + 1 >> 0] | 0) <= 57 : 0))m = 53;
	                                do if ((m | 0) == 53) {
	                                    m = 0;
	                                    if ((a[(c[l >> 2] | 0) + 1 >> 0] | 0) >= 97 ? (a[(c[l >> 2] | 0) + 1 >> 0] | 0) <= 102 : 0)break;
	                                    if ((a[(c[l >> 2] | 0) + 1 >> 0] | 0) < 65)break d;
	                                    if ((a[(c[l >> 2] | 0) + 1 >> 0] | 0) > 70)break d
	                                } while (0);
	                                if ((a[(c[l >> 2] | 0) + 2 >> 0] | 0) >= 48 ? (a[(c[l >> 2] | 0) + 2 >> 0] | 0) <= 57 : 0) {
	                                    m = 76;
	                                    break c
	                                }
	                                if ((a[(c[l >> 2] | 0) + 2 >> 0] | 0) >= 97 ? (a[(c[l >> 2] | 0) + 2 >> 0] | 0) <= 102 : 0) {
	                                    m = 76;
	                                    break c
	                                }
	                                if ((a[(c[l >> 2] | 0) + 2 >> 0] | 0) >= 65 ? (a[(c[l >> 2] | 0) + 2 >> 0] | 0) <= 70 : 0) {
	                                    m = 76;
	                                    break c
	                                }
	                            } while (0);
	                            if (((((((((a[c[l >> 2] >> 0] | 0) != 33 ? (a[c[l >> 2] >> 0] | 0) != 36 : 0) ? (a[c[l >> 2] >> 0] | 0) != 38 : 0) ? (a[c[l >> 2] >> 0] | 0) != 40 : 0) ? (a[c[l >> 2] >> 0] | 0) != 41 : 0) ? (a[c[l >> 2] >> 0] | 0) != 42 : 0) ? (a[c[l >> 2] >> 0] | 0) != 43 : 0) ? (a[c[l >> 2] >> 0] | 0) != 44 : 0) ? (a[c[l >> 2] >> 0] | 0) != 59 : 0) {
	                                if ((a[c[l >> 2] >> 0] | 0) == 61) {
	                                    m = 76;
	                                    break
	                                }
	                                if ((a[c[l >> 2] >> 0] | 0) == 39) {
	                                    m = 76;
	                                    break
	                                }
	                                if ((a[c[l >> 2] >> 0] | 0) == 58) {
	                                    m = 76;
	                                    break
	                                }
	                                if ((a[c[l >> 2] >> 0] | 0) != 64)o = 0; else m = 76
	                            } else m = 76
	                        } else m = 76
	                    } while (0);
	                    if ((m | 0) == 76) {
	                        m = 0;
	                        o = (a[c[l >> 2] >> 0] | 0) != (a[j >> 0] | 0)
	                    }
	                    p = c[l >> 2] | 0;
	                    if (!o)break;
	                    k = c[l >> 2] | 0;
	                    if ((a[p >> 0] | 0) == 37) {
	                        c[l >> 2] = k + 3;
	                        continue
	                    } else {
	                        c[l >> 2] = k + 1;
	                        continue
	                    }
	                }
	                c[c[h >> 2] >> 2] = p;
	                c[g >> 2] = 0;
	                n = c[g >> 2] | 0;
	                i = f;
	                return n | 0
	            }

	            function dm(b) {
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = b;
	                c[g >> 2] = c[c[f >> 2] >> 2];
	                if ((a[c[g >> 2] >> 0] | 0) >= 48 ? (a[c[g >> 2] >> 0] | 0) <= 57 : 0) {
	                    a:do if ((a[(c[g >> 2] | 0) + 1 >> 0] | 0) >= 48 ? (a[(c[g >> 2] | 0) + 1 >> 0] | 0) <= 57 : 0) {
	                        do if (((a[c[g >> 2] >> 0] | 0) != 48 ? (a[(c[g >> 2] | 0) + 1 >> 0] | 0) >= 48 : 0) ? (a[(c[g >> 2] | 0) + 1 >> 0] | 0) <= 57 : 0) {
	                            if ((a[(c[g >> 2] | 0) + 2 >> 0] | 0) >= 48 ? (a[(c[g >> 2] | 0) + 2 >> 0] | 0) <= 57 : 0)break;
	                            c[g >> 2] = (c[g >> 2] | 0) + 2;
	                            break a
	                        } while (0);
	                        if (((((a[c[g >> 2] >> 0] | 0) == 49 ? (a[(c[g >> 2] | 0) + 1 >> 0] | 0) >= 48 : 0) ? (a[(c[g >> 2] | 0) + 1 >> 0] | 0) <= 57 : 0) ? (a[(c[g >> 2] | 0) + 2 >> 0] | 0) >= 48 : 0) ? (a[(c[g >> 2] | 0) + 2 >> 0] | 0) <= 57 : 0) {
	                            c[g >> 2] = (c[g >> 2] | 0) + 3;
	                            break
	                        }
	                        if (((((a[c[g >> 2] >> 0] | 0) == 50 ? (a[(c[g >> 2] | 0) + 1 >> 0] | 0) >= 48 : 0) ? (a[(c[g >> 2] | 0) + 1 >> 0] | 0) <= 52 : 0) ? (a[(c[g >> 2] | 0) + 2 >> 0] | 0) >= 48 : 0) ? (a[(c[g >> 2] | 0) + 2 >> 0] | 0) <= 57 : 0) {
	                            c[g >> 2] = (c[g >> 2] | 0) + 3;
	                            break
	                        }
	                        if ((((a[c[g >> 2] >> 0] | 0) == 50 ? (a[(c[g >> 2] | 0) + 1 >> 0] | 0) == 53 : 0) ? (a[(c[g >> 2] | 0) + 2 >> 0] | 0) >= 48 : 0) ? (a[(c[g >> 2] | 0) + 1 >> 0] | 0) <= 53 : 0) {
	                            c[g >> 2] = (c[g >> 2] | 0) + 3;
	                            break
	                        }
	                        c[e >> 2] = 1;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    } else j = 6; while (0);
	                    if ((j | 0) == 6)c[g >> 2] = (c[g >> 2] | 0) + 1;
	                    c[c[f >> 2] >> 2] = c[g >> 2];
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                c[e >> 2] = 1;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function em(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 5024 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                j = e + 16 | 0;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 15) {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                if ((c[(c[h >> 2] | 0) + 36 >> 2] | 0) != 4) {
	                    c[f >> 2] = 1;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                if (c[(c[h >> 2] | 0) + 52 >> 2] | 0)if (wz(c[(c[h >> 2] | 0) + 52 >> 2] | 0) | 0) {
	                    c[f >> 2] = 1;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                } else {
	                    c[(c[g >> 2] | 0) + 36 >> 2] = 0;
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                d = xz() | 0;
	                c[(c[g >> 2] | 0) + 56 >> 2] = d;
	                d = c[g >> 2] | 0;
	                if (!(c[(c[g >> 2] | 0) + 56 >> 2] | 0)) {
	                    jn(d, c[h >> 2] | 0, 1, 79384, c[(c[h >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                b = Bz(c[d + 56 >> 2] | 0) | 0;
	                c[(c[g >> 2] | 0) + 60 >> 2] = b;
	                kn(c[(c[h >> 2] | 0) + 40 >> 2] | 0, c[g >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0) | 0;
	                Cz(c[(c[g >> 2] | 0) + 56 >> 2] | 0, c[(c[g >> 2] | 0) + 60 >> 2] | 0) | 0;
	                b = Oz(c[(c[g >> 2] | 0) + 56 >> 2] | 0) | 0;
	                c[(c[h >> 2] | 0) + 52 >> 2] = b;
	                if ((wz(c[(c[h >> 2] | 0) + 52 >> 2] | 0) | 0) != 1) {
	                    a[j >> 0] = 0;
	                    fm(j, 5e3, c[(c[h >> 2] | 0) + 40 >> 2] | 0, 1);
	                    jn(c[g >> 2] | 0, c[h >> 2] | 0, 505, 79424, c[(c[h >> 2] | 0) + 8 >> 2] | 0, j, 0);
	                    c[(c[g >> 2] | 0) + 36 >> 2] = 0;
	                    c[(c[g >> 2] | 0) + 60 >> 2] = 0;
	                    yz(c[(c[g >> 2] | 0) + 56 >> 2] | 0);
	                    c[(c[g >> 2] | 0) + 56 >> 2] = 0;
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                } else {
	                    c[(c[g >> 2] | 0) + 60 >> 2] = 0;
	                    yz(c[(c[g >> 2] | 0) + 56 >> 2] | 0);
	                    c[(c[g >> 2] | 0) + 56 >> 2] = 0;
	                    c[f >> 2] = 1;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                return 0
	            }

	            function fm(b, d, e, f) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 16 | 0;
	                j = g + 12 | 0;
	                k = g + 8 | 0;
	                l = g + 4 | 0;
	                m = g;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[l >> 2] = f;
	                if (!(c[k >> 2] | 0)) {
	                    i = g;
	                    return
	                }
	                c[m >> 2] = ZT(c[h >> 2] | 0) | 0;
	                if (((c[j >> 2] | 0) - (c[m >> 2] | 0) | 0) < 50) {
	                    if (((c[j >> 2] | 0) - (c[m >> 2] | 0) | 0) <= 4) {
	                        i = g;
	                        return
	                    }
	                    if ((a[(c[h >> 2] | 0) + ((c[m >> 2] | 0) - 1) >> 0] | 0) == 46) {
	                        i = g;
	                        return
	                    }
	                    _T(c[h >> 2] | 0, 79624) | 0;
	                    i = g;
	                    return
	                }
	                if (c[l >> 2] | 0)_T(c[h >> 2] | 0, 79632) | 0;
	                f = c[c[k >> 2] >> 2] | 0;
	                do if ((f | 0) == 4) {
	                    if ((c[c[(c[k >> 2] | 0) + 12 >> 2] >> 2] | 0) != 4 ? (c[c[(c[k >> 2] | 0) + 12 >> 2] >> 2] | 0) != 3 : 0)fm(c[h >> 2] | 0, c[j >> 2] | 0, c[(c[k >> 2] | 0) + 12 >> 2] | 0, 0); else fm(c[h >> 2] | 0, c[j >> 2] | 0, c[(c[k >> 2] | 0) + 12 >> 2] | 0, 1);
	                    c[m >> 2] = ZT(c[h >> 2] | 0) | 0;
	                    if (((c[j >> 2] | 0) - (c[m >> 2] | 0) | 0) >= 50) {
	                        _T(c[h >> 2] | 0, 79664) | 0;
	                        if (!((c[c[(c[k >> 2] | 0) + 16 >> 2] >> 2] | 0) != 3 ? (c[(c[(c[k >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) == 1 : 0))n = 41;
	                        if ((n | 0) == 41 ? (c[c[(c[k >> 2] | 0) + 16 >> 2] >> 2] | 0) != 2 : 0) {
	                            fm(c[h >> 2] | 0, c[j >> 2] | 0, c[(c[k >> 2] | 0) + 16 >> 2] | 0, 1);
	                            break
	                        }
	                        fm(c[h >> 2] | 0, c[j >> 2] | 0, c[(c[k >> 2] | 0) + 16 >> 2] | 0, 0);
	                        break
	                    }
	                    if (((c[j >> 2] | 0) - (c[m >> 2] | 0) | 0) <= 4) {
	                        i = g;
	                        return
	                    }
	                    if ((a[(c[h >> 2] | 0) + ((c[m >> 2] | 0) - 1) >> 0] | 0) == 46) {
	                        i = g;
	                        return
	                    }
	                    _T(c[h >> 2] | 0, 79624) | 0;
	                    i = g;
	                    return
	                } else if ((f | 0) == 1)_T(c[h >> 2] | 0, 79640) | 0; else if ((f | 0) == 3) {
	                    if ((c[c[(c[k >> 2] | 0) + 12 >> 2] >> 2] | 0) != 4 ? (c[c[(c[k >> 2] | 0) + 12 >> 2] >> 2] | 0) != 3 : 0)fm(c[h >> 2] | 0, c[j >> 2] | 0, c[(c[k >> 2] | 0) + 12 >> 2] | 0, 0); else fm(c[h >> 2] | 0, c[j >> 2] | 0, c[(c[k >> 2] | 0) + 12 >> 2] | 0, 1);
	                    c[m >> 2] = ZT(c[h >> 2] | 0) | 0;
	                    if (((c[j >> 2] | 0) - (c[m >> 2] | 0) | 0) >= 50) {
	                        _T(c[h >> 2] | 0, 79656) | 0;
	                        if (!((c[c[(c[k >> 2] | 0) + 16 >> 2] >> 2] | 0) != 4 ? (c[(c[(c[k >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) == 1 : 0))n = 28;
	                        if ((n | 0) == 28 ? (c[c[(c[k >> 2] | 0) + 16 >> 2] >> 2] | 0) != 2 : 0) {
	                            fm(c[h >> 2] | 0, c[j >> 2] | 0, c[(c[k >> 2] | 0) + 16 >> 2] | 0, 1);
	                            break
	                        }
	                        fm(c[h >> 2] | 0, c[j >> 2] | 0, c[(c[k >> 2] | 0) + 16 >> 2] | 0, 0);
	                        break
	                    }
	                    if (((c[j >> 2] | 0) - (c[m >> 2] | 0) | 0) <= 4) {
	                        i = g;
	                        return
	                    }
	                    if ((a[(c[h >> 2] | 0) + ((c[m >> 2] | 0) - 1) >> 0] | 0) == 46) {
	                        i = g;
	                        return
	                    }
	                    _T(c[h >> 2] | 0, 79624) | 0;
	                    i = g;
	                    return
	                } else if ((f | 0) == 2) {
	                    do if (c[(c[k >> 2] | 0) + 24 >> 2] | 0) {
	                        e = (c[j >> 2] | 0) - (c[m >> 2] | 0) | 0;
	                        d = (e | 0) < ((xy(c[(c[k >> 2] | 0) + 24 >> 2] | 0) | 0) + 10 | 0);
	                        e = c[h >> 2] | 0;
	                        if (!d) {
	                            _T(e | 0, c[(c[k >> 2] | 0) + 24 >> 2] | 0) | 0;
	                            _T(c[h >> 2] | 0, 79648) | 0;
	                            break
	                        }
	                        _T(e | 0, 79624) | 0;
	                        i = g;
	                        return
	                    } while (0);
	                    e = (c[j >> 2] | 0) - (c[m >> 2] | 0) | 0;
	                    if ((e | 0) < ((xy(c[(c[k >> 2] | 0) + 8 >> 2] | 0) | 0) + 10 | 0)) {
	                        _T(c[h >> 2] | 0, 79624) | 0;
	                        i = g;
	                        return
	                    } else {
	                        if (!(c[(c[k >> 2] | 0) + 8 >> 2] | 0))break;
	                        _T(c[h >> 2] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        break
	                    }
	                } while (0);
	                if (c[l >> 2] | 0)_T(c[h >> 2] | 0, 79672) | 0;
	                l = c[(c[k >> 2] | 0) + 4 >> 2] | 0;
	                if ((l | 0) == 3) {
	                    _T(c[h >> 2] | 0, 79688) | 0;
	                    i = g;
	                    return
	                } else if ((l | 0) == 4) {
	                    _T(c[h >> 2] | 0, 79696) | 0;
	                    i = g;
	                    return
	                } else if ((l | 0) == 2) {
	                    _T(c[h >> 2] | 0, 79680) | 0;
	                    i = g;
	                    return
	                } else {
	                    i = g;
	                    return
	                }
	            }

	            function gm() {
	                var a = 0, b = 0, d = 0, e = 0, f = 0, g = 0;
	                a = i;
	                i = i + 16 | 0;
	                b = a + 4 | 0;
	                d = a;
	                e = Cb[c[135744 >> 2] & 511](64) | 0;
	                c[d >> 2] = e;
	                if (!e) {
	                    ln(0, 79472);
	                    c[b >> 2] = 0;
	                    f = c[b >> 2] | 0;
	                    i = a;
	                    return f | 0
	                } else {
	                    e = (c[d >> 2] | 0) + 0 | 0;
	                    g = e + 64 | 0;
	                    do {
	                        c[e >> 2] = 0;
	                        e = e + 4 | 0
	                    } while ((e | 0) < (g | 0));
	                    c[b >> 2] = c[d >> 2];
	                    f = c[b >> 2] | 0;
	                    i = a;
	                    return f | 0
	                }
	                return 0
	            }

	            function hm(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (c[(c[d >> 2] | 0) + 52 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 52 >> 2] | 0);
	                if (!(c[(c[d >> 2] | 0) + 24 >> 2] | 0)) {
	                    e = c[33934] | 0;
	                    f = c[d >> 2] | 0;
	                    zb[e & 511](f);
	                    i = b;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 24 >> 2] | 0);
	                e = c[33934] | 0;
	                f = c[d >> 2] | 0;
	                zb[e & 511](f);
	                i = b;
	                return
	            }

	            function im(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 28 | 0;
	                g = e + 24 | 0;
	                h = e + 20 | 0;
	                j = e + 16 | 0;
	                k = e + 12 | 0;
	                l = e + 8 | 0;
	                m = e + 4 | 0;
	                n = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[l >> 2] = 0;
	                if (c[g >> 2] | 0)c[l >> 2] = c[(c[g >> 2] | 0) + 80 >> 2];
	                g = c[j >> 2] | 0;
	                if ((g | 0) == 4 | (g | 0) == 3 | (g | 0) == 1) {
	                    if (c[h >> 2] | 0)mn(0, 1, 79528, 0)
	                } else if ((g | 0) == 2) {
	                    if (!(c[h >> 2] | 0))mn(0, 1, 79488, 0)
	                } else {
	                    mn(0, 1, 79568, 0);
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                c[k >> 2] = Cb[c[135744 >> 2] & 511](28) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    ln(0, 79472);
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                g = c[k >> 2] | 0;
	                c[g + 0 >> 2] = 0;
	                c[g + 4 >> 2] = 0;
	                c[g + 8 >> 2] = 0;
	                c[g + 12 >> 2] = 0;
	                c[g + 16 >> 2] = 0;
	                c[g + 20 >> 2] = 0;
	                c[g + 24 >> 2] = 0;
	                c[c[k >> 2] >> 2] = c[j >> 2];
	                c[(c[k >> 2] | 0) + 4 >> 2] = 1;
	                do if (c[h >> 2] | 0) {
	                    c[n >> 2] = Dh(c[h >> 2] | 0, m) | 0;
	                    j = (c[l >> 2] | 0) == 0;
	                    if (!(c[n >> 2] | 0))if (j) {
	                        g = my(c[h >> 2] | 0) | 0;
	                        c[(c[k >> 2] | 0) + 8 >> 2] = g;
	                        break
	                    } else {
	                        g = AP(c[l >> 2] | 0, c[h >> 2] | 0, -1) | 0;
	                        c[(c[k >> 2] | 0) + 8 >> 2] = g;
	                        break
	                    } else if (j) {
	                        j = ly(c[h >> 2] | 0, c[m >> 2] | 0) | 0;
	                        c[(c[k >> 2] | 0) + 24 >> 2] = j;
	                        j = my(c[n >> 2] | 0) | 0;
	                        c[(c[k >> 2] | 0) + 8 >> 2] = j;
	                        break
	                    } else {
	                        j = AP(c[l >> 2] | 0, c[h >> 2] | 0, c[m >> 2] | 0) | 0;
	                        c[(c[k >> 2] | 0) + 24 >> 2] = j;
	                        j = AP(c[l >> 2] | 0, c[n >> 2] | 0, -1) | 0;
	                        c[(c[k >> 2] | 0) + 8 >> 2] = j;
	                        break
	                    }
	                } while (0);
	                c[f >> 2] = c[k >> 2];
	                o = c[f >> 2] | 0;
	                i = e;
	                return o | 0
	            }

	            function jm(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 24 | 0;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                l = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                c[j >> 2] = 0;
	                c[l >> 2] = 0;
	                if (!(c[g >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                if (c[f >> 2] | 0)c[l >> 2] = c[(c[f >> 2] | 0) + 80 >> 2];
	                c[h >> 2] = Cb[c[135744 >> 2] & 511](28) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    ln(0, 79472);
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                b = c[h >> 2] | 0;
	                c[b + 0 >> 2] = 0;
	                c[b + 4 >> 2] = 0;
	                c[b + 8 >> 2] = 0;
	                c[b + 12 >> 2] = 0;
	                c[b + 16 >> 2] = 0;
	                c[b + 20 >> 2] = 0;
	                c[b + 24 >> 2] = 0;
	                c[c[h >> 2] >> 2] = c[c[g >> 2] >> 2];
	                c[(c[h >> 2] | 0) + 4 >> 2] = c[(c[g >> 2] | 0) + 4 >> 2];
	                do if (c[(c[g >> 2] | 0) + 8 >> 2] | 0)if (c[l >> 2] | 0) {
	                    b = AP(c[l >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0, -1) | 0;
	                    c[(c[h >> 2] | 0) + 8 >> 2] = b;
	                    break
	                } else {
	                    b = my(c[(c[g >> 2] | 0) + 8 >> 2] | 0) | 0;
	                    c[(c[h >> 2] | 0) + 8 >> 2] = b;
	                    break
	                } while (0);
	                do if (c[(c[g >> 2] | 0) + 24 >> 2] | 0)if (c[l >> 2] | 0) {
	                    b = AP(c[l >> 2] | 0, c[(c[g >> 2] | 0) + 24 >> 2] | 0, -1) | 0;
	                    c[(c[h >> 2] | 0) + 24 >> 2] = b;
	                    break
	                } else {
	                    b = my(c[(c[g >> 2] | 0) + 24 >> 2] | 0) | 0;
	                    c[(c[h >> 2] | 0) + 24 >> 2] = b;
	                    break
	                } while (0);
	                if (c[(c[g >> 2] | 0) + 12 >> 2] | 0) {
	                    b = jm(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] | 0) | 0;
	                    c[(c[h >> 2] | 0) + 12 >> 2] = b
	                }
	                if (c[(c[h >> 2] | 0) + 12 >> 2] | 0)c[(c[(c[h >> 2] | 0) + 12 >> 2] | 0) + 20 >> 2] = c[h >> 2];
	                a:do if (c[(c[g >> 2] | 0) + 16 >> 2] | 0) {
	                    c[j >> 2] = c[h >> 2];
	                    c[g >> 2] = c[(c[g >> 2] | 0) + 16 >> 2];
	                    while (1) {
	                        if (!(c[g >> 2] | 0))break a;
	                        c[k >> 2] = Cb[c[135744 >> 2] & 511](28) | 0;
	                        if (!(c[k >> 2] | 0))break;
	                        b = c[k >> 2] | 0;
	                        c[b + 0 >> 2] = 0;
	                        c[b + 4 >> 2] = 0;
	                        c[b + 8 >> 2] = 0;
	                        c[b + 12 >> 2] = 0;
	                        c[b + 16 >> 2] = 0;
	                        c[b + 20 >> 2] = 0;
	                        c[b + 24 >> 2] = 0;
	                        c[c[k >> 2] >> 2] = c[c[g >> 2] >> 2];
	                        c[(c[k >> 2] | 0) + 4 >> 2] = c[(c[g >> 2] | 0) + 4 >> 2];
	                        c[(c[j >> 2] | 0) + 16 >> 2] = c[k >> 2];
	                        do if (c[(c[g >> 2] | 0) + 8 >> 2] | 0)if (c[l >> 2] | 0) {
	                            b = AP(c[l >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0, -1) | 0;
	                            c[(c[k >> 2] | 0) + 8 >> 2] = b;
	                            break
	                        } else {
	                            b = my(c[(c[g >> 2] | 0) + 8 >> 2] | 0) | 0;
	                            c[(c[k >> 2] | 0) + 8 >> 2] = b;
	                            break
	                        } while (0);
	                        do if (c[(c[g >> 2] | 0) + 24 >> 2] | 0)if (c[l >> 2] | 0) {
	                            b = AP(c[l >> 2] | 0, c[(c[g >> 2] | 0) + 24 >> 2] | 0, -1) | 0;
	                            c[(c[k >> 2] | 0) + 24 >> 2] = b;
	                            break
	                        } else {
	                            b = my(c[(c[g >> 2] | 0) + 24 >> 2] | 0) | 0;
	                            c[(c[k >> 2] | 0) + 24 >> 2] = b;
	                            break
	                        } while (0);
	                        if (c[(c[g >> 2] | 0) + 12 >> 2] | 0) {
	                            b = jm(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] | 0) | 0;
	                            c[(c[k >> 2] | 0) + 12 >> 2] = b
	                        }
	                        if (c[(c[k >> 2] | 0) + 12 >> 2] | 0)c[(c[(c[k >> 2] | 0) + 12 >> 2] | 0) + 20 >> 2] = c[h >> 2];
	                        c[j >> 2] = c[k >> 2];
	                        c[g >> 2] = c[(c[g >> 2] | 0) + 16 >> 2]
	                    }
	                    ln(0, 79472);
	                    c[e >> 2] = c[h >> 2];
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                } while (0);
	                c[e >> 2] = c[h >> 2];
	                m = c[e >> 2] | 0;
	                i = d;
	                return m | 0
	            }

	            function km(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = jm(0, c[d >> 2] | 0) | 0;
	                i = b;
	                return a | 0
	            }

	            function lm(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[h >> 2] = 0;
	                if (c[e >> 2] | 0)c[h >> 2] = c[(c[e >> 2] | 0) + 80 >> 2];
	                while (1) {
	                    if (!(c[f >> 2] | 0)) {
	                        j = 20;
	                        break
	                    }
	                    c[g >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                    if (((c[c[f >> 2] >> 2] | 0) + -1 | 0) >>> 0 >= 4)break;
	                    if (c[(c[f >> 2] | 0) + 12 >> 2] | 0)lm(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 12 >> 2] | 0);
	                    b = (c[(c[f >> 2] | 0) + 8 >> 2] | 0) != 0;
	                    if (c[h >> 2] | 0) {
	                        if (b ? (CP(c[h >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0) | 0) == 0 : 0)zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 8 >> 2] | 0);
	                        if ((c[(c[f >> 2] | 0) + 24 >> 2] | 0) != 0 ? (CP(c[h >> 2] | 0, c[(c[f >> 2] | 0) + 24 >> 2] | 0) | 0) == 0 : 0)zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 24 >> 2] | 0)
	                    } else {
	                        if (b)zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 8 >> 2] | 0);
	                        if (c[(c[f >> 2] | 0) + 24 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 24 >> 2] | 0)
	                    }
	                    zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                    c[f >> 2] = c[g >> 2]
	                }
	                if ((j | 0) == 20) {
	                    i = d;
	                    return
	                }
	                mn(0, 1, 79568, 0);
	                i = d;
	                return
	            }

	            function mm(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                g = i;
	                i = i + 48 | 0;
	                h = g + 44 | 0;
	                j = g + 40 | 0;
	                k = g + 36 | 0;
	                l = g + 32 | 0;
	                m = g + 28 | 0;
	                n = g + 24 | 0;
	                o = g + 20 | 0;
	                p = g + 16 | 0;
	                q = g + 12 | 0;
	                r = g + 8 | 0;
	                s = g + 4 | 0;
	                t = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[q >> 2] = 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    u = c[h >> 2] | 0;
	                    i = g;
	                    return u | 0
	                }
	                if (!(c[l >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    u = c[h >> 2] | 0;
	                    i = g;
	                    return u | 0
	                }
	                f = c[m >> 2] | 0;
	                if ((f | 0) == 1) {
	                    if (c[n >> 2] | 0) {
	                        mn(c[j >> 2] | 0, 1, 79704, 0);
	                        c[h >> 2] = 0;
	                        u = c[h >> 2] | 0;
	                        i = g;
	                        return u | 0
	                    }
	                } else if ((f | 0) == 4) {
	                    if (!(c[n >> 2] | 0)) {
	                        mn(c[j >> 2] | 0, 1, 79848, 0);
	                        c[h >> 2] = 0;
	                        u = c[h >> 2] | 0;
	                        i = g;
	                        return u | 0
	                    }
	                } else if ((f | 0) == 3) {
	                    if (!(c[n >> 2] | 0)) {
	                        mn(c[j >> 2] | 0, 1, 79800, 0);
	                        c[h >> 2] = 0;
	                        u = c[h >> 2] | 0;
	                        i = g;
	                        return u | 0
	                    }
	                } else if ((f | 0) == 2) {
	                    if (c[n >> 2] | 0) {
	                        mn(c[j >> 2] | 0, 1, 79752, 0);
	                        c[h >> 2] = 0;
	                        u = c[h >> 2] | 0;
	                        i = g;
	                        return u | 0
	                    }
	                } else {
	                    mn(c[j >> 2] | 0, 1, 79896, 0);
	                    c[h >> 2] = 0;
	                    u = c[h >> 2] | 0;
	                    i = g;
	                    return u | 0
	                }
	                c[s >> 2] = Ch(c[l >> 2] | 0, r) | 0;
	                if (c[s >> 2] | 0)c[l >> 2] = c[s >> 2];
	                c[p >> 2] = c[(c[k >> 2] | 0) + 40 >> 2];
	                if (!(c[p >> 2] | 0)) {
	                    c[t >> 2] = 0;
	                    if (c[(c[k >> 2] | 0) + 32 >> 2] | 0)c[t >> 2] = c[(c[(c[k >> 2] | 0) + 32 >> 2] | 0) + 80 >> 2];
	                    c[p >> 2] = Jj(0, c[t >> 2] | 0) | 0;
	                    c[(c[k >> 2] | 0) + 40 >> 2] = c[p >> 2]
	                }
	                if (!(c[p >> 2] | 0)) {
	                    ln(c[j >> 2] | 0, 79944);
	                    if (c[s >> 2] | 0)zb[c[135736 >> 2] & 511](c[s >> 2] | 0);
	                    if (c[r >> 2] | 0)zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                    c[h >> 2] = 0;
	                    u = c[h >> 2] | 0;
	                    i = g;
	                    return u | 0
	                }
	                if ((((c[(c[k >> 2] | 0) + 32 >> 2] | 0) != 0 ? (c[(c[(c[k >> 2] | 0) + 32 >> 2] | 0) + 44 >> 2] | 0) != 0 : 0) ? (c[o >> 2] = Tj(c[(c[(c[(c[k >> 2] | 0) + 32 >> 2] | 0) + 44 >> 2] | 0) + 40 >> 2] | 0, c[l >> 2] | 0, c[r >> 2] | 0) | 0, (c[o >> 2] | 0) != 0) : 0) ? (c[(c[o >> 2] | 0) + 36 >> 2] | 0) == 0 : 0) {
	                    c[q >> 2] = c[(c[o >> 2] | 0) + 44 >> 2];
	                    c[(c[o >> 2] | 0) + 44 >> 2] = 0;
	                    ck(c[(c[(c[(c[k >> 2] | 0) + 32 >> 2] | 0) + 44 >> 2] | 0) + 40 >> 2] | 0, c[l >> 2] | 0, c[r >> 2] | 0, 0) | 0;
	                    nn(c[o >> 2] | 0)
	                }
	                c[o >> 2] = Tj(c[p >> 2] | 0, c[l >> 2] | 0, c[r >> 2] | 0) | 0;
	                do if (!(c[o >> 2] | 0)) {
	                    c[o >> 2] = Cb[c[135744 >> 2] & 511](56) | 0;
	                    if (!(c[o >> 2] | 0)) {
	                        ln(c[j >> 2] | 0, 79472);
	                        if (c[s >> 2] | 0)zb[c[135736 >> 2] & 511](c[s >> 2] | 0);
	                        if (c[r >> 2] | 0)zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                        c[h >> 2] = 0;
	                        u = c[h >> 2] | 0;
	                        i = g;
	                        return u | 0
	                    }
	                    t = (c[o >> 2] | 0) + 0 | 0;
	                    f = t + 56 | 0;
	                    do {
	                        c[t >> 2] = 0;
	                        t = t + 4 | 0
	                    } while ((t | 0) < (f | 0));
	                    c[(c[o >> 2] | 0) + 4 >> 2] = 15;
	                    t = my(c[l >> 2] | 0) | 0;
	                    c[(c[o >> 2] | 0) + 8 >> 2] = t;
	                    if (!(c[(c[o >> 2] | 0) + 8 >> 2] | 0)) {
	                        ln(c[j >> 2] | 0, 79472);
	                        if (c[s >> 2] | 0)zb[c[135736 >> 2] & 511](c[s >> 2] | 0);
	                        if (c[r >> 2] | 0)zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                        c[h >> 2] = 0;
	                        u = c[h >> 2] | 0;
	                        i = g;
	                        return u | 0
	                    } else {
	                        c[(c[o >> 2] | 0) + 48 >> 2] = c[r >> 2];
	                        if (!(Nj(c[p >> 2] | 0, c[l >> 2] | 0, c[r >> 2] | 0, c[o >> 2] | 0) | 0)) {
	                            c[(c[o >> 2] | 0) + 44 >> 2] = c[q >> 2];
	                            break
	                        }
	                        jn(c[j >> 2] | 0, c[k >> 2] | 0, 509, 79992, c[l >> 2] | 0, 0, 0);
	                        nn(c[o >> 2] | 0);
	                        if (c[s >> 2] | 0)zb[c[135736 >> 2] & 511](c[s >> 2] | 0);
	                        c[h >> 2] = 0;
	                        u = c[h >> 2] | 0;
	                        i = g;
	                        return u | 0
	                    }
	                } else {
	                    if (!(c[(c[o >> 2] | 0) + 36 >> 2] | 0)) {
	                        if (!(c[r >> 2] | 0))break;
	                        zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                        c[r >> 2] = 0;
	                        break
	                    }
	                    jn(c[j >> 2] | 0, c[k >> 2] | 0, 509, 79992, c[l >> 2] | 0, 0, 0);
	                    if (c[s >> 2] | 0)zb[c[135736 >> 2] & 511](c[s >> 2] | 0);
	                    if (c[r >> 2] | 0)zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                    c[h >> 2] = 0;
	                    u = c[h >> 2] | 0;
	                    i = g;
	                    return u | 0
	                } while (0);
	                c[(c[o >> 2] | 0) + 36 >> 2] = c[m >> 2];
	                do if (c[j >> 2] | 0) {
	                    if ((c[(c[j >> 2] | 0) + 28 >> 2] | 0) != -1412623820 ? (c[(c[j >> 2] | 0) + 28 >> 2] | 0) != -1412623819 : 0) {
	                        v = 63;
	                        break
	                    }
	                    c[(c[o >> 2] | 0) + 40 >> 2] = c[n >> 2];
	                    if (c[n >> 2] | 0)c[(c[n >> 2] | 0) + 20 >> 2] = 1
	                } else v = 63; while (0);
	                if ((v | 0) == 63) {
	                    v = jm(c[(c[k >> 2] | 0) + 32 >> 2] | 0, c[n >> 2] | 0) | 0;
	                    c[(c[o >> 2] | 0) + 40 >> 2] = v
	                }
	                c[(c[o >> 2] | 0) + 20 >> 2] = c[k >> 2];
	                c[(c[o >> 2] | 0) + 32 >> 2] = c[(c[k >> 2] | 0) + 32 >> 2];
	                v = c[o >> 2] | 0;
	                n = (c[k >> 2] | 0) + 16 | 0;
	                if (!(c[(c[k >> 2] | 0) + 16 >> 2] | 0)) {
	                    c[n >> 2] = v;
	                    c[(c[k >> 2] | 0) + 12 >> 2] = v
	                } else {
	                    c[(c[n >> 2] | 0) + 24 >> 2] = v;
	                    c[(c[o >> 2] | 0) + 28 >> 2] = c[(c[k >> 2] | 0) + 16 >> 2];
	                    c[(c[k >> 2] | 0) + 16 >> 2] = c[o >> 2]
	                }
	                if (c[s >> 2] | 0)zb[c[135736 >> 2] & 511](c[s >> 2] | 0);
	                c[h >> 2] = c[o >> 2];
	                u = c[h >> 2] | 0;
	                i = g;
	                return u | 0
	            }

	            function nm(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                Kj(c[d >> 2] | 0, 242);
	                i = b;
	                return
	            }

	            function om(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = _j(c[d >> 2] | 0, 243) | 0;
	                i = b;
	                return a | 0
	            }

	            function pm(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if ((c[e >> 2] | 0) == 0 | (c[f >> 2] | 0) == 0) {
	                    i = d;
	                    return
	                }
	                b = c[(c[f >> 2] | 0) + 36 >> 2] | 0;
	                if ((b | 0) == 3) {
	                    rj(c[e >> 2] | 0, 80024);
	                    if (c[(c[f >> 2] | 0) + 48 >> 2] | 0) {
	                        qj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 48 >> 2] | 0);
	                        rj(c[e >> 2] | 0, 79648)
	                    }
	                    qj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0);
	                    rj(c[e >> 2] | 0, 80064);
	                    pn(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 40 >> 2] | 0, 1);
	                    rj(c[e >> 2] | 0, 80072);
	                    i = d;
	                    return
	                } else if ((b | 0) == 4) {
	                    rj(c[e >> 2] | 0, 80024);
	                    if (c[(c[f >> 2] | 0) + 48 >> 2] | 0) {
	                        qj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 48 >> 2] | 0);
	                        rj(c[e >> 2] | 0, 79648)
	                    }
	                    qj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0);
	                    rj(c[e >> 2] | 0, 80064);
	                    pn(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 40 >> 2] | 0, 1);
	                    rj(c[e >> 2] | 0, 80072);
	                    i = d;
	                    return
	                } else if ((b | 0) == 1) {
	                    rj(c[e >> 2] | 0, 80024);
	                    if (c[(c[f >> 2] | 0) + 48 >> 2] | 0) {
	                        qj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 48 >> 2] | 0);
	                        rj(c[e >> 2] | 0, 79648)
	                    }
	                    qj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0);
	                    rj(c[e >> 2] | 0, 80040);
	                    i = d;
	                    return
	                } else if ((b | 0) == 2) {
	                    rj(c[e >> 2] | 0, 80024);
	                    if (c[(c[f >> 2] | 0) + 48 >> 2] | 0) {
	                        qj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 48 >> 2] | 0);
	                        rj(c[e >> 2] | 0, 79648)
	                    }
	                    qj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0);
	                    rj(c[e >> 2] | 0, 80056);
	                    i = d;
	                    return
	                } else {
	                    mn(0, 1, 80080, 0);
	                    i = d;
	                    return
	                }
	            }

	            function qm(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](8) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    ln(0, 79472);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = c[f >> 2] | 0;
	                c[a + 0 >> 2] = 0;
	                c[a + 4 >> 2] = 0;
	                if (c[e >> 2] | 0) {
	                    a = my(c[e >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 4 >> 2] = a
	                }
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function rm(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[c[d >> 2] >> 2] | 0)rm(c[c[d >> 2] >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 4 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 4 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function sm(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[f >> 2] = qm(c[(c[e >> 2] | 0) + 4 >> 2] | 0) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                if (c[c[e >> 2] >> 2] | 0) {
	                    a = sm(c[c[e >> 2] >> 2] | 0) | 0;
	                    c[c[f >> 2] >> 2] = a
	                } else c[c[f >> 2] >> 2] = 0;
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function tm(a, b, d, e, f, g, h, j, k) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                k = k | 0;
	                var l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0;
	                l = i;
	                i = i + 64 | 0;
	                m = l + 56 | 0;
	                n = l + 52 | 0;
	                o = l + 48 | 0;
	                p = l + 44 | 0;
	                q = l + 40 | 0;
	                r = l + 36 | 0;
	                s = l + 32 | 0;
	                t = l + 28 | 0;
	                u = l + 24 | 0;
	                v = l + 20 | 0;
	                w = l + 16 | 0;
	                x = l + 12 | 0;
	                y = l + 8 | 0;
	                z = l + 4 | 0;
	                A = l;
	                c[n >> 2] = a;
	                c[o >> 2] = b;
	                c[p >> 2] = d;
	                c[q >> 2] = e;
	                c[r >> 2] = f;
	                c[s >> 2] = g;
	                c[t >> 2] = h;
	                c[u >> 2] = j;
	                c[v >> 2] = k;
	                c[z >> 2] = 0;
	                if (!(c[o >> 2] | 0)) {
	                    rm(c[v >> 2] | 0);
	                    c[m >> 2] = 0;
	                    B = c[m >> 2] | 0;
	                    i = l;
	                    return B | 0
	                }
	                if (!(c[q >> 2] | 0)) {
	                    rm(c[v >> 2] | 0);
	                    c[m >> 2] = 0;
	                    B = c[m >> 2] | 0;
	                    i = l;
	                    return B | 0
	                }
	                if (!(c[p >> 2] | 0)) {
	                    rm(c[v >> 2] | 0);
	                    c[m >> 2] = 0;
	                    B = c[m >> 2] | 0;
	                    i = l;
	                    return B | 0
	                }
	                if (c[(c[o >> 2] | 0) + 32 >> 2] | 0)c[z >> 2] = c[(c[(c[o >> 2] | 0) + 32 >> 2] | 0) + 80 >> 2];
	                if (((c[s >> 2] | 0) + -1 | 0) >>> 0 >= 10) {
	                    mn(c[n >> 2] | 0, 1, 80136, 0);
	                    rm(c[v >> 2] | 0);
	                    c[m >> 2] = 0;
	                    B = c[m >> 2] | 0;
	                    i = l;
	                    return B | 0
	                }
	                if (((c[u >> 2] | 0) != 0 ? (qn(c[(c[o >> 2] | 0) + 32 >> 2] | 0, c[s >> 2] | 0, c[u >> 2] | 0) | 0) == 0 : 0) ? (jn(c[n >> 2] | 0, c[o >> 2] | 0, 500, 80192, c[p >> 2] | 0, c[q >> 2] | 0, c[u >> 2] | 0), c[u >> 2] = 0, (c[n >> 2] | 0) != 0) : 0)c[(c[n >> 2] | 0) + 36 >> 2] = 0;
	                if (((((c[(c[o >> 2] | 0) + 32 >> 2] | 0) != 0 ? (c[(c[(c[o >> 2] | 0) + 32 >> 2] | 0) + 48 >> 2] | 0) == (c[o >> 2] | 0) : 0) ? (c[(c[(c[o >> 2] | 0) + 32 >> 2] | 0) + 44 >> 2] | 0) != 0 : 0) ? (c[(c[(c[(c[o >> 2] | 0) + 32 >> 2] | 0) + 44 >> 2] | 0) + 44 >> 2] | 0) != 0 : 0) ? (c[w >> 2] = Sj(c[(c[(c[(c[o >> 2] | 0) + 32 >> 2] | 0) + 44 >> 2] | 0) + 44 >> 2] | 0, c[q >> 2] | 0, c[r >> 2] | 0, c[p >> 2] | 0) | 0, (c[w >> 2] | 0) != 0) : 0) {
	                    rm(c[v >> 2] | 0);
	                    c[m >> 2] = 0;
	                    B = c[m >> 2] | 0;
	                    i = l;
	                    return B | 0
	                }
	                c[x >> 2] = c[(c[o >> 2] | 0) + 44 >> 2];
	                if (!(c[x >> 2] | 0)) {
	                    c[x >> 2] = Jj(0, c[z >> 2] | 0) | 0;
	                    c[(c[o >> 2] | 0) + 44 >> 2] = c[x >> 2]
	                }
	                if (!(c[x >> 2] | 0)) {
	                    ln(c[n >> 2] | 0, 80240);
	                    rm(c[v >> 2] | 0);
	                    c[m >> 2] = 0;
	                    B = c[m >> 2] | 0;
	                    i = l;
	                    return B | 0
	                }
	                c[w >> 2] = Cb[c[135744 >> 2] & 511](64) | 0;
	                if (!(c[w >> 2] | 0)) {
	                    ln(c[n >> 2] | 0, 79472);
	                    rm(c[v >> 2] | 0);
	                    c[m >> 2] = 0;
	                    B = c[m >> 2] | 0;
	                    i = l;
	                    return B | 0
	                }
	                k = (c[w >> 2] | 0) + 0 | 0;
	                j = k + 64 | 0;
	                do {
	                    c[k >> 2] = 0;
	                    k = k + 4 | 0
	                } while ((k | 0) < (j | 0));
	                c[(c[w >> 2] | 0) + 4 >> 2] = 16;
	                c[(c[w >> 2] | 0) + 40 >> 2] = c[s >> 2];
	                c[(c[w >> 2] | 0) + 32 >> 2] = c[(c[o >> 2] | 0) + 32 >> 2];
	                if (c[z >> 2] | 0) {
	                    k = AP(c[z >> 2] | 0, c[q >> 2] | 0, -1) | 0;
	                    c[(c[w >> 2] | 0) + 8 >> 2] = k;
	                    k = AP(c[z >> 2] | 0, c[r >> 2] | 0, -1) | 0;
	                    c[(c[w >> 2] | 0) + 56 >> 2] = k;
	                    k = AP(c[z >> 2] | 0, c[p >> 2] | 0, -1) | 0;
	                    c[(c[w >> 2] | 0) + 60 >> 2] = k
	                } else {
	                    k = my(c[q >> 2] | 0) | 0;
	                    c[(c[w >> 2] | 0) + 8 >> 2] = k;
	                    k = my(c[r >> 2] | 0) | 0;
	                    c[(c[w >> 2] | 0) + 56 >> 2] = k;
	                    k = my(c[p >> 2] | 0) | 0;
	                    c[(c[w >> 2] | 0) + 60 >> 2] = k
	                }
	                c[(c[w >> 2] | 0) + 44 >> 2] = c[t >> 2];
	                c[(c[w >> 2] | 0) + 52 >> 2] = c[v >> 2];
	                do if (c[u >> 2] | 0)if (c[z >> 2] | 0) {
	                    v = AP(c[z >> 2] | 0, c[u >> 2] | 0, -1) | 0;
	                    c[(c[w >> 2] | 0) + 48 >> 2] = v;
	                    break
	                } else {
	                    v = my(c[u >> 2] | 0) | 0;
	                    c[(c[w >> 2] | 0) + 48 >> 2] = v;
	                    break
	                } while (0);
	                if ((Mj(c[x >> 2] | 0, c[(c[w >> 2] | 0) + 8 >> 2] | 0, c[(c[w >> 2] | 0) + 56 >> 2] | 0, c[(c[w >> 2] | 0) + 60 >> 2] | 0, c[w >> 2] | 0) | 0) < 0) {
	                    rn(c[n >> 2] | 0, c[o >> 2] | 0, 501, 80288, c[q >> 2] | 0, c[p >> 2] | 0, 0);
	                    sn(c[w >> 2] | 0);
	                    c[m >> 2] = 0;
	                    B = c[m >> 2] | 0;
	                    i = l;
	                    return B | 0
	                }
	                c[y >> 2] = tn(c[o >> 2] | 0, c[p >> 2] | 0, 1) | 0;
	                a:do if (c[y >> 2] | 0) {
	                    if (((c[s >> 2] | 0) == 2 ? (un(0, c[y >> 2] | 0, 1) | 0) != 0 : 0) ? (jn(c[n >> 2] | 0, c[o >> 2] | 0, 520, 80336, c[p >> 2] | 0, c[q >> 2] | 0, 0), (c[n >> 2] | 0) != 0) : 0)c[(c[n >> 2] | 0) + 36 >> 2] = 0;
	                    do if (!(qy(c[(c[w >> 2] | 0) + 8 >> 2] | 0, 80392) | 0)) {
	                        if ((c[(c[w >> 2] | 0) + 56 >> 2] | 0) != 0 ? (qy(c[(c[w >> 2] | 0) + 56 >> 2] | 0, 80392) | 0) != 0 : 0)break;
	                        c[A >> 2] = c[(c[y >> 2] | 0) + 44 >> 2];
	                        while (1) {
	                            if (!(c[A >> 2] | 0))break;
	                            if (!(qy(c[(c[A >> 2] | 0) + 8 >> 2] | 0, 80392) | 0)) {
	                                if (!(c[(c[w >> 2] | 0) + 56 >> 2] | 0))break;
	                                if (!(qy(c[(c[w >> 2] | 0) + 56 >> 2] | 0, 80392) | 0))break
	                            }
	                            if (!(c[(c[A >> 2] | 0) + 36 >> 2] | 0))break;
	                            c[A >> 2] = c[(c[A >> 2] | 0) + 36 >> 2]
	                        }
	                        if (c[A >> 2] | 0) {
	                            c[(c[w >> 2] | 0) + 36 >> 2] = c[(c[A >> 2] | 0) + 36 >> 2];
	                            c[(c[A >> 2] | 0) + 36 >> 2] = c[w >> 2];
	                            break a
	                        } else {
	                            c[(c[w >> 2] | 0) + 36 >> 2] = c[(c[y >> 2] | 0) + 44 >> 2];
	                            c[(c[y >> 2] | 0) + 44 >> 2] = c[w >> 2];
	                            break a
	                        }
	                    } while (0);
	                    c[(c[w >> 2] | 0) + 36 >> 2] = c[(c[y >> 2] | 0) + 44 >> 2];
	                    c[(c[y >> 2] | 0) + 44 >> 2] = c[w >> 2]
	                } while (0);
	                c[(c[w >> 2] | 0) + 20 >> 2] = c[o >> 2];
	                y = c[w >> 2] | 0;
	                A = (c[o >> 2] | 0) + 16 | 0;
	                if (!(c[(c[o >> 2] | 0) + 16 >> 2] | 0)) {
	                    c[A >> 2] = y;
	                    c[(c[o >> 2] | 0) + 12 >> 2] = y
	                } else {
	                    c[(c[A >> 2] | 0) + 24 >> 2] = y;
	                    c[(c[w >> 2] | 0) + 28 >> 2] = c[(c[o >> 2] | 0) + 16 >> 2];
	                    c[(c[o >> 2] | 0) + 16 >> 2] = c[w >> 2]
	                }
	                c[m >> 2] = c[w >> 2];
	                B = c[m >> 2] | 0;
	                i = l;
	                return B | 0
	            }

	            function um(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                Kj(c[d >> 2] | 0, 244);
	                i = b;
	                return
	            }

	            function vm(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = _j(c[d >> 2] | 0, 245) | 0;
	                i = b;
	                return a | 0
	            }

	            function wm(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if ((c[e >> 2] | 0) == 0 | (c[f >> 2] | 0) == 0) {
	                    i = d;
	                    return
	                }
	                rj(c[e >> 2] | 0, 80400);
	                qj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 60 >> 2] | 0);
	                rj(c[e >> 2] | 0, 80064);
	                if (c[(c[f >> 2] | 0) + 56 >> 2] | 0) {
	                    qj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 56 >> 2] | 0);
	                    rj(c[e >> 2] | 0, 79648)
	                }
	                qj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0);
	                do switch (c[(c[f >> 2] | 0) + 40 >> 2] | 0) {
	                    case 9:
	                    {
	                        rj(c[e >> 2] | 0, 80504);
	                        wn(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 52 >> 2] | 0);
	                        break
	                    }
	                    case 5:
	                    {
	                        rj(c[e >> 2] | 0, 80448);
	                        break
	                    }
	                    case 6:
	                    {
	                        rj(c[e >> 2] | 0, 80456);
	                        break
	                    }
	                    case 7:
	                    {
	                        rj(c[e >> 2] | 0, 80472);
	                        break
	                    }
	                    case 2:
	                    {
	                        rj(c[e >> 2] | 0, 80424);
	                        break
	                    }
	                    case 10:
	                    {
	                        rj(c[e >> 2] | 0, 80512);
	                        wn(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 52 >> 2] | 0);
	                        break
	                    }
	                    case 4:
	                    {
	                        rj(c[e >> 2] | 0, 80440);
	                        break
	                    }
	                    case 8:
	                    {
	                        rj(c[e >> 2] | 0, 80488);
	                        break
	                    }
	                    case 1:
	                    {
	                        rj(c[e >> 2] | 0, 80416);
	                        break
	                    }
	                    case 3:
	                    {
	                        rj(c[e >> 2] | 0, 80432);
	                        break
	                    }
	                    default:
	                        mn(0, 1, 80136, 0)
	                } while (0);
	                b = c[(c[f >> 2] | 0) + 44 >> 2] | 0;
	                if ((b | 0) == 2)rj(c[e >> 2] | 0, 80528); else if ((b | 0) == 3)rj(c[e >> 2] | 0, 80544); else if ((b | 0) == 4)rj(c[e >> 2] | 0, 80560); else if ((b | 0) != 1)mn(0, 1, 80568, 0);
	                if (c[(c[f >> 2] | 0) + 48 >> 2] | 0) {
	                    rj(c[e >> 2] | 0, 80064);
	                    sj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 48 >> 2] | 0)
	                }
	                rj(c[e >> 2] | 0, 80072);
	                i = d;
	                return
	            }

	            function xm(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                g = i;
	                i = i + 48 | 0;
	                h = g + 32 | 0;
	                j = g + 28 | 0;
	                k = g + 24 | 0;
	                l = g + 20 | 0;
	                m = g + 16 | 0;
	                n = g + 12 | 0;
	                o = g + 8 | 0;
	                p = g + 4 | 0;
	                q = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                if (!(c[k >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    r = c[h >> 2] | 0;
	                    i = g;
	                    return r | 0
	                }
	                if (!(c[l >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    r = c[h >> 2] | 0;
	                    i = g;
	                    return r | 0
	                }
	                if ((c[m >> 2] | 0) == 0 & (c[n >> 2] | 0) == 0) {
	                    c[h >> 2] = 0;
	                    r = c[h >> 2] | 0;
	                    i = g;
	                    return r | 0
	                }
	                c[p >> 2] = c[(c[k >> 2] | 0) + 36 >> 2];
	                if (!(c[p >> 2] | 0)) {
	                    c[q >> 2] = 0;
	                    if (c[(c[k >> 2] | 0) + 32 >> 2] | 0)c[q >> 2] = c[(c[(c[k >> 2] | 0) + 32 >> 2] | 0) + 80 >> 2];
	                    f = Jj(0, c[q >> 2] | 0) | 0;
	                    c[p >> 2] = f;
	                    c[(c[k >> 2] | 0) + 36 >> 2] = f
	                }
	                if (!(c[p >> 2] | 0)) {
	                    ln(c[j >> 2] | 0, 80624);
	                    c[h >> 2] = 0;
	                    r = c[h >> 2] | 0;
	                    i = g;
	                    return r | 0
	                }
	                c[o >> 2] = Cb[c[135744 >> 2] & 511](12) | 0;
	                if (!(c[o >> 2] | 0)) {
	                    ln(c[j >> 2] | 0, 79472);
	                    c[h >> 2] = 0;
	                    r = c[h >> 2] | 0;
	                    i = g;
	                    return r | 0
	                }
	                j = c[o >> 2] | 0;
	                c[j + 0 >> 2] = 0;
	                c[j + 4 >> 2] = 0;
	                c[j + 8 >> 2] = 0;
	                j = my(c[l >> 2] | 0) | 0;
	                c[c[o >> 2] >> 2] = j;
	                if (c[n >> 2] | 0) {
	                    j = my(c[n >> 2] | 0) | 0;
	                    c[(c[o >> 2] | 0) + 8 >> 2] = j
	                }
	                if (c[m >> 2] | 0) {
	                    j = my(c[m >> 2] | 0) | 0;
	                    c[(c[o >> 2] | 0) + 4 >> 2] = j
	                }
	                if (Lj(c[p >> 2] | 0, c[l >> 2] | 0, c[o >> 2] | 0) | 0) {
	                    mn(0, 526, 80672, c[l >> 2] | 0);
	                    xn(c[o >> 2] | 0);
	                    c[h >> 2] = 0;
	                    r = c[h >> 2] | 0;
	                    i = g;
	                    return r | 0
	                } else {
	                    c[h >> 2] = c[o >> 2];
	                    r = c[h >> 2] | 0;
	                    i = g;
	                    return r | 0
	                }
	                return 0
	            }

	            function ym(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                Kj(c[d >> 2] | 0, 246);
	                i = b;
	                return
	            }

	            function zm(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = _j(c[d >> 2] | 0, 247) | 0;
	                i = b;
	                return a | 0
	            }

	            function Am(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if ((c[e >> 2] | 0) == 0 | (c[f >> 2] | 0) == 0) {
	                    i = d;
	                    return
	                }
	                rj(c[e >> 2] | 0, 80712);
	                qj(c[e >> 2] | 0, c[c[f >> 2] >> 2] | 0);
	                b = c[e >> 2] | 0;
	                if (c[(c[f >> 2] | 0) + 4 >> 2] | 0) {
	                    rj(b, 80728);
	                    sj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 4 >> 2] | 0);
	                    if (c[(c[f >> 2] | 0) + 8 >> 2] | 0) {
	                        rj(c[e >> 2] | 0, 80064);
	                        sj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0)
	                    }
	                } else {
	                    rj(b, 80744);
	                    sj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0)
	                }
	                rj(c[e >> 2] | 0, 80760);
	                i = d;
	                return
	            }

	            function Bm(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if ((c[e >> 2] | 0) == 0 | (c[f >> 2] | 0) == 0) {
	                    i = d;
	                    return
	                }
	                Wj(c[f >> 2] | 0, 248, c[e >> 2] | 0);
	                i = d;
	                return
	            }

	            function Cm(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 24 | 0;
	                h = f + 20 | 0;
	                j = f + 16 | 0;
	                k = f + 12 | 0;
	                l = f + 8 | 0;
	                m = f + 4 | 0;
	                n = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if (!(c[j >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                if (!(c[k >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                if (!(c[l >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                c[n >> 2] = c[(c[j >> 2] | 0) + 64 >> 2];
	                if (!(c[n >> 2] | 0)) {
	                    e = Jj(0, c[(c[j >> 2] | 0) + 80 >> 2] | 0) | 0;
	                    c[n >> 2] = e;
	                    c[(c[j >> 2] | 0) + 64 >> 2] = e
	                }
	                if (!(c[n >> 2] | 0)) {
	                    ln(c[h >> 2] | 0, 80768);
	                    c[g >> 2] = 0;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                c[m >> 2] = Cb[c[135744 >> 2] & 511](24) | 0;
	                if (!(c[m >> 2] | 0)) {
	                    ln(c[h >> 2] | 0, 79472);
	                    c[g >> 2] = 0;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                e = my(c[k >> 2] | 0) | 0;
	                c[(c[m >> 2] | 0) + 4 >> 2] = e;
	                c[(c[m >> 2] | 0) + 20 >> 2] = c[j >> 2];
	                if ((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 44 >> 2] | 0) != 0 : 0) {
	                    if (c[(c[j >> 2] | 0) + 80 >> 2] | 0) {
	                        e = AP(c[(c[j >> 2] | 0) + 80 >> 2] | 0, c[(c[l >> 2] | 0) + 8 >> 2] | 0, -1) | 0;
	                        c[(c[m >> 2] | 0) + 12 >> 2] = e
	                    } else {
	                        e = my(c[(c[l >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        c[(c[m >> 2] | 0) + 12 >> 2] = e
	                    }
	                    c[(c[m >> 2] | 0) + 8 >> 2] = 0
	                } else {
	                    c[(c[m >> 2] | 0) + 8 >> 2] = c[l >> 2];
	                    c[(c[m >> 2] | 0) + 12 >> 2] = 0
	                }
	                e = Ni(c[(c[l >> 2] | 0) + 20 >> 2] | 0) | 0;
	                c[(c[m >> 2] | 0) + 16 >> 2] = e;
	                if ((Lj(c[n >> 2] | 0, c[k >> 2] | 0, c[m >> 2] | 0) | 0) < 0) {
	                    jn(c[h >> 2] | 0, c[(c[l >> 2] | 0) + 20 >> 2] | 0, 513, 80808, c[k >> 2] | 0, 0, 0);
	                    An(c[m >> 2] | 0);
	                    c[g >> 2] = 0;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                if (c[l >> 2] | 0)c[(c[l >> 2] | 0) + 40 >> 2] = 2;
	                c[g >> 2] = c[m >> 2];
	                o = c[g >> 2] | 0;
	                i = f;
	                return o | 0
	            }

	            function Dm(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                Kj(c[d >> 2] | 0, 249);
	                i = b;
	                return
	            }

	            function Em(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                e = i;
	                i = i + 128 | 0;
	                f = e + 24 | 0;
	                g = e + 20 | 0;
	                h = e + 16 | 0;
	                j = e + 12 | 0;
	                k = e + 8 | 0;
	                l = e + 78 | 0;
	                m = e + 28 | 0;
	                n = e + 4 | 0;
	                o = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if ((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                    if ((((c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (PT(c[(c[j >> 2] | 0) + 8 >> 2] | 0, 80832) | 0) == 0 : 0) ? (PT(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0, 80840) | 0) == 0 : 0) {
	                        c[f >> 2] = 1;
	                        p = c[f >> 2] | 0;
	                        i = e;
	                        return p | 0
	                    }
	                    if (!(c[g >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        p = c[f >> 2] | 0;
	                        i = e;
	                        return p | 0
	                    }
	                    if (((c[(c[g >> 2] | 0) + 44 >> 2] | 0) == 0 ? (c[(c[g >> 2] | 0) + 48 >> 2] | 0) == 0 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 13 : 0) {
	                        c[f >> 2] = 0;
	                        p = c[f >> 2] | 0;
	                        i = e;
	                        return p | 0
	                    }
	                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 13) {
	                        do if (!(qy(80832, c[(c[j >> 2] | 0) + 8 >> 2] | 0) | 0)) {
	                            if (qy(80848, c[(c[j >> 2] | 0) + 8 >> 2] | 0) | 0) {
	                                if (!(c[h >> 2] | 0))break;
	                                if (qy(c[(c[h >> 2] | 0) + 8 >> 2] | 0, 80856) | 0)break
	                            }
	                            c[f >> 2] = 0;
	                            p = c[f >> 2] | 0;
	                            i = e;
	                            return p | 0
	                        } while (0);
	                        c[f >> 2] = 1;
	                        p = c[f >> 2] | 0;
	                        i = e;
	                        return p | 0
	                    }
	                    if (!(c[h >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        p = c[f >> 2] | 0;
	                        i = e;
	                        return p | 0
	                    }
	                    c[k >> 2] = 0;
	                    if ((c[(c[h >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0)q = Bh(c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0, l, 50) | 0; else q = c[(c[h >> 2] | 0) + 8 >> 2] | 0;
	                    c[n >> 2] = q;
	                    if ((c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0)r = Bh(c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0, m, 50) | 0; else r = c[(c[j >> 2] | 0) + 8 >> 2] | 0;
	                    c[o >> 2] = r;
	                    if (((c[n >> 2] | 0) != 0 & (c[o >> 2] | 0) != 0 ? (c[k >> 2] = Fm(c[(c[g >> 2] | 0) + 44 >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0) | 0, (c[k >> 2] | 0) == 0) : 0) ? (c[(c[g >> 2] | 0) + 48 >> 2] | 0) != 0 : 0)c[k >> 2] = Fm(c[(c[g >> 2] | 0) + 48 >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0) | 0;
	                    if ((c[o >> 2] | 0) != (m | 0) ? (c[o >> 2] | 0) != (c[(c[j >> 2] | 0) + 8 >> 2] | 0) : 0)zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                    if ((c[n >> 2] | 0) != (l | 0) ? (c[n >> 2] | 0) != (c[(c[h >> 2] | 0) + 8 >> 2] | 0) : 0)zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                    if ((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 40 >> 2] | 0) == 2 : 0) {
	                        c[f >> 2] = 1;
	                        p = c[f >> 2] | 0;
	                        i = e;
	                        return p | 0
	                    }
	                    c[f >> 2] = 0;
	                    p = c[f >> 2] | 0;
	                    i = e;
	                    return p | 0
	                }
	                c[f >> 2] = 0;
	                p = c[f >> 2] | 0;
	                i = e;
	                return p | 0
	            }

	            function Fm(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 28 | 0;
	                g = e + 24 | 0;
	                h = e + 20 | 0;
	                j = e + 16 | 0;
	                k = e + 12 | 0;
	                l = e + 8 | 0;
	                m = e + 4 | 0;
	                n = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[m >> 2] = 0;
	                c[n >> 2] = 0;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                if (!(c[(c[g >> 2] | 0) + 44 >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                c[k >> 2] = c[(c[g >> 2] | 0) + 44 >> 2];
	                if (!(c[k >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                c[m >> 2] = Ch(c[j >> 2] | 0, n) | 0;
	                g = c[k >> 2] | 0;
	                if (c[m >> 2] | 0) {
	                    c[l >> 2] = Sj(g, c[m >> 2] | 0, c[n >> 2] | 0, c[h >> 2] | 0) | 0;
	                    if (c[n >> 2] | 0)zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                    if (c[m >> 2] | 0)zb[c[135736 >> 2] & 511](c[m >> 2] | 0)
	                } else c[l >> 2] = Sj(g, c[j >> 2] | 0, 0, c[h >> 2] | 0) | 0;
	                c[f >> 2] = c[l >> 2];
	                o = c[f >> 2] | 0;
	                i = e;
	                return o | 0
	            }

	            function Gm(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                if (!(c[g >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                c[h >> 2] = c[(c[f >> 2] | 0) + 64 >> 2];
	                if (!(c[h >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                c[k >> 2] = _h(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] | 0, 1) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                c[j >> 2] = Rj(c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                if ((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 8 >> 2] | 0) == (c[g >> 2] | 0) : 0) {
	                    ak(c[h >> 2] | 0, c[k >> 2] | 0, 249) | 0;
	                    zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    c[(c[g >> 2] | 0) + 40 >> 2] = 0;
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                c[e >> 2] = -1;
	                l = c[e >> 2] | 0;
	                i = d;
	                return l | 0
	            }

	            function Hm(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                do if (c[f >> 2] | 0) {
	                    if (!(c[g >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        break
	                    }
	                    c[h >> 2] = c[(c[f >> 2] | 0) + 64 >> 2];
	                    if (!(c[h >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        break
	                    }
	                    c[j >> 2] = Rj(c[h >> 2] | 0, c[g >> 2] | 0) | 0;
	                    if (!(c[j >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        break
	                    }
	                    if (!(c[(c[j >> 2] | 0) + 8 >> 2] | 0)) {
	                        c[e >> 2] = c[f >> 2];
	                        break
	                    } else {
	                        c[e >> 2] = c[(c[j >> 2] | 0) + 8 >> 2];
	                        break
	                    }
	                } else c[e >> 2] = 0; while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function Im(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 28 | 0;
	                h = f + 24 | 0;
	                j = f + 20 | 0;
	                k = f + 16 | 0;
	                l = f + 12 | 0;
	                m = f + 8 | 0;
	                n = f + 4 | 0;
	                o = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if (!(c[j >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                if (!(c[k >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                if (!(c[l >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                c[n >> 2] = c[(c[j >> 2] | 0) + 68 >> 2];
	                if (!(c[n >> 2] | 0)) {
	                    e = Jj(0, c[(c[j >> 2] | 0) + 80 >> 2] | 0) | 0;
	                    c[n >> 2] = e;
	                    c[(c[j >> 2] | 0) + 68 >> 2] = e
	                }
	                if (!(c[n >> 2] | 0)) {
	                    ln(c[h >> 2] | 0, 80864);
	                    c[g >> 2] = 0;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                c[m >> 2] = Cb[c[135744 >> 2] & 511](20) | 0;
	                if (!(c[m >> 2] | 0)) {
	                    ln(c[h >> 2] | 0, 79472);
	                    c[g >> 2] = 0;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                e = my(c[k >> 2] | 0) | 0;
	                c[(c[m >> 2] | 0) + 4 >> 2] = e;
	                if ((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 44 >> 2] | 0) != 0 : 0) {
	                    h = my(c[(c[l >> 2] | 0) + 8 >> 2] | 0) | 0;
	                    c[(c[m >> 2] | 0) + 12 >> 2] = h;
	                    c[(c[m >> 2] | 0) + 8 >> 2] = 0
	                } else {
	                    c[(c[m >> 2] | 0) + 12 >> 2] = 0;
	                    c[(c[m >> 2] | 0) + 8 >> 2] = c[l >> 2]
	                }
	                h = Ni(c[(c[l >> 2] | 0) + 20 >> 2] | 0) | 0;
	                c[(c[m >> 2] | 0) + 16 >> 2] = h;
	                h = Rj(c[n >> 2] | 0, c[k >> 2] | 0) | 0;
	                c[o >> 2] = h;
	                do if (!h) {
	                    l = IS(250, 251) | 0;
	                    c[o >> 2] = l;
	                    if (!l) {
	                        mn(0, 1, 80904, 0);
	                        break
	                    }
	                    if ((Lj(c[n >> 2] | 0, c[k >> 2] | 0, c[o >> 2] | 0) | 0) < 0) {
	                        MS(c[o >> 2] | 0);
	                        mn(0, 1, 80952, 0)
	                    } else q = 22
	                } else q = 22; while (0);
	                do if ((q | 0) == 22) {
	                    if (LS(c[o >> 2] | 0, c[m >> 2] | 0) | 0) {
	                        mn(0, 1, 80952, 0);
	                        break
	                    }
	                    c[g >> 2] = c[m >> 2];
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                } while (0);
	                if (c[m >> 2] | 0) {
	                    if (c[(c[m >> 2] | 0) + 4 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[m >> 2] | 0) + 4 >> 2] | 0);
	                    if (c[(c[m >> 2] | 0) + 12 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[m >> 2] | 0) + 12 >> 2] | 0);
	                    zb[c[135736 >> 2] & 511](c[m >> 2] | 0)
	                }
	                c[g >> 2] = 0;
	                p = c[g >> 2] | 0;
	                i = f;
	                return p | 0
	            }

	            function Jm(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                Kj(c[d >> 2] | 0, 252);
	                i = b;
	                return
	            }

	            function Km(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (!(c[j >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                if ((c[g >> 2] | 0) == 0 ? (c[g >> 2] = c[(c[j >> 2] | 0) + 32 >> 2], (c[g >> 2] | 0) == 0) : 0) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                if ((c[(c[g >> 2] | 0) + 44 >> 2] | 0) == 0 ? (c[(c[g >> 2] | 0) + 48 >> 2] | 0) == 0 : 0) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 13) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[k >> 2] = Fm(c[(c[g >> 2] | 0) + 44 >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0) | 0;
	                if ((c[k >> 2] | 0) == 0 ? (c[(c[g >> 2] | 0) + 48 >> 2] | 0) != 0 : 0)c[k >> 2] = Fm(c[(c[g >> 2] | 0) + 48 >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0) | 0;
	                do if (c[k >> 2] | 0) {
	                    if ((c[(c[k >> 2] | 0) + 40 >> 2] | 0) != 3 ? (c[(c[k >> 2] | 0) + 40 >> 2] | 0) != 4 : 0)break;
	                    c[f >> 2] = 1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } while (0);
	                c[f >> 2] = 0;
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function Lm(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 24 | 0;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                l = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[k >> 2] = 0;
	                c[l >> 2] = 0;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                if (!(c[(c[f >> 2] | 0) + 40 >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                c[h >> 2] = c[(c[f >> 2] | 0) + 40 >> 2];
	                c[k >> 2] = Ch(c[g >> 2] | 0, l) | 0;
	                if (c[k >> 2] | 0)c[g >> 2] = c[k >> 2];
	                c[j >> 2] = Tj(c[h >> 2] | 0, c[g >> 2] | 0, c[l >> 2] | 0) | 0;
	                if (c[l >> 2] | 0)zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                if (c[k >> 2] | 0)zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                c[e >> 2] = c[j >> 2];
	                m = c[e >> 2] | 0;
	                i = d;
	                return m | 0
	            }

	            function Mm(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                if (!(c[(c[g >> 2] | 0) + 40 >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } else {
	                    c[k >> 2] = c[(c[g >> 2] | 0) + 40 >> 2];
	                    c[f >> 2] = Tj(c[k >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                return 0
	            }

	            function Nm(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if (!(c[h >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                if (!(c[(c[h >> 2] | 0) + 44 >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                } else {
	                    c[m >> 2] = c[(c[h >> 2] | 0) + 44 >> 2];
	                    c[g >> 2] = Sj(c[m >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[j >> 2] | 0) | 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                return 0
	            }

	            function Om(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                do if (c[f >> 2] | 0)if (!(c[(c[f >> 2] | 0) + 36 >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    break
	                } else {
	                    c[h >> 2] = c[(c[f >> 2] | 0) + 36 >> 2];
	                    c[e >> 2] = Rj(c[h >> 2] | 0, c[g >> 2] | 0) | 0;
	                    break
	                } else c[e >> 2] = 0; while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function Pm(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if ((c[h >> 2] | 0) != 0 ? !((c[j >> 2] | 0) == 0 ? 1 : (c[(c[h >> 2] | 0) + 44 >> 2] | 0) == 0) : 0) {
	                    c[k >> 2] = Om(c[(c[h >> 2] | 0) + 44 >> 2] | 0, c[j >> 2] | 0) | 0;
	                    if ((c[k >> 2] | 0) == 0 ? (c[(c[h >> 2] | 0) + 48 >> 2] | 0) != 0 : 0)c[k >> 2] = Om(c[(c[h >> 2] | 0) + 48 >> 2] | 0, c[j >> 2] | 0) | 0;
	                    if ((c[k >> 2] | 0) == 0 & (c[g >> 2] | 0) != 0) {
	                        jn(c[g >> 2] | 0, c[h >> 2] | 0, 537, 81e3, c[j >> 2] | 0, 0, 0);
	                        c[f >> 2] = 0;
	                        l = c[f >> 2] | 0;
	                        i = e;
	                        return l | 0
	                    } else {
	                        c[f >> 2] = 1;
	                        l = c[f >> 2] | 0;
	                        i = e;
	                        return l | 0
	                    }
	                }
	                c[f >> 2] = -1;
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function Qm(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                a:do if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 44 >> 2] | 0) != 0 : 0) {
	                    c[h >> 2] = Lm(c[(c[f >> 2] | 0) + 44 >> 2] | 0, c[g >> 2] | 0) | 0;
	                    if ((c[h >> 2] | 0) == 0 ? (c[(c[f >> 2] | 0) + 48 >> 2] | 0) != 0 : 0)c[h >> 2] = Lm(c[(c[f >> 2] | 0) + 48 >> 2] | 0, c[g >> 2] | 0) | 0;
	                    if (!(c[h >> 2] | 0)) {
	                        c[e >> 2] = -1;
	                        break
	                    }
	                    switch (c[(c[h >> 2] | 0) + 36 >> 2] | 0) {
	                        case 4:
	                        {
	                            c[e >> 2] = 0;
	                            break a;
	                            break
	                        }
	                        case 0:
	                        {
	                            c[e >> 2] = -1;
	                            break a;
	                            break
	                        }
	                        case 3:
	                        case 2:
	                        case 1:
	                        {
	                            c[e >> 2] = 1;
	                            break a;
	                            break
	                        }
	                        default:
	                        {
	                            c[e >> 2] = 1;
	                            break a
	                        }
	                    }
	                } else j = 3; while (0);
	                if ((j | 0) == 3)c[e >> 2] = -1;
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function Rm(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e;
	                c[e + 12 >> 2] = a;
	                c[e + 8 >> 2] = b;
	                c[e + 4 >> 2] = d;
	                c[f >> 2] = 1;
	                i = e;
	                return c[f >> 2] | 0
	            }

	            function Sm(b, e, f, g, h) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0;
	                j = i;
	                i = i + 112 | 0;
	                k = j + 44 | 0;
	                l = j + 40 | 0;
	                m = j + 36 | 0;
	                n = j + 32 | 0;
	                o = j + 28 | 0;
	                p = j + 24 | 0;
	                q = j + 20 | 0;
	                r = j + 16 | 0;
	                s = j + 12 | 0;
	                t = j + 8 | 0;
	                u = j + 4 | 0;
	                v = j + 48 | 0;
	                w = j;
	                c[l >> 2] = b;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                c[p >> 2] = h;
	                c[t >> 2] = 0;
	                c[u >> 2] = 0;
	                if (!(c[m >> 2] | 0)) {
	                    c[k >> 2] = 0;
	                    x = c[k >> 2] | 0;
	                    i = j;
	                    return x | 0
	                }
	                if (!(c[n >> 2] | 0)) {
	                    c[k >> 2] = 0;
	                    x = c[k >> 2] | 0;
	                    i = j;
	                    return x | 0
	                }
	                if (!(c[o >> 2] | 0)) {
	                    c[k >> 2] = 0;
	                    x = c[k >> 2] | 0;
	                    i = j;
	                    return x | 0
	                }
	                if (!(c[p >> 2] | 0)) {
	                    c[k >> 2] = 0;
	                    x = c[k >> 2] | 0;
	                    i = j;
	                    return x | 0
	                }
	                if ((c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                    c[w >> 2] = Bh(c[(c[n >> 2] | 0) + 8 >> 2] | 0, c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0, v, 50) | 0;
	                    if (!(c[w >> 2] | 0)) {
	                        c[k >> 2] = 0;
	                        x = c[k >> 2] | 0;
	                        i = j;
	                        return x | 0
	                    }
	                    c[t >> 2] = Fm(c[(c[m >> 2] | 0) + 44 >> 2] | 0, c[w >> 2] | 0, c[o >> 2] | 0) | 0;
	                    if (((c[t >> 2] | 0) == 0 ? (c[(c[m >> 2] | 0) + 48 >> 2] | 0) != 0 : 0) ? (c[t >> 2] = Fm(c[(c[m >> 2] | 0) + 48 >> 2] | 0, c[w >> 2] | 0, c[o >> 2] | 0) | 0, (c[t >> 2] | 0) != 0) : 0)c[u >> 2] = 1;
	                    if ((c[w >> 2] | 0) != (v | 0) ? (c[w >> 2] | 0) != (c[(c[n >> 2] | 0) + 8 >> 2] | 0) : 0)zb[c[135736 >> 2] & 511](c[w >> 2] | 0)
	                }
	                if ((c[t >> 2] | 0) == 0 ? (c[(c[m >> 2] | 0) + 44 >> 2] | 0) != 0 : 0)c[t >> 2] = Fm(c[(c[m >> 2] | 0) + 44 >> 2] | 0, c[(c[n >> 2] | 0) + 8 >> 2] | 0, c[o >> 2] | 0) | 0;
	                if (((c[t >> 2] | 0) == 0 ? (c[(c[m >> 2] | 0) + 48 >> 2] | 0) != 0 : 0) ? (c[t >> 2] = Fm(c[(c[m >> 2] | 0) + 48 >> 2] | 0, c[(c[n >> 2] | 0) + 8 >> 2] | 0, c[o >> 2] | 0) | 0, (c[t >> 2] | 0) != 0) : 0)c[u >> 2] = 1;
	                if (!(c[t >> 2] | 0)) {
	                    c[k >> 2] = 0;
	                    x = c[k >> 2] | 0;
	                    i = j;
	                    return x | 0
	                }
	                if ((c[(c[t >> 2] | 0) + 40 >> 2] | 0) == 1) {
	                    c[k >> 2] = 0;
	                    x = c[k >> 2] | 0;
	                    i = j;
	                    return x | 0
	                }
	                c[q >> 2] = my(c[p >> 2] | 0) | 0;
	                if (!(c[q >> 2] | 0)) {
	                    c[k >> 2] = 0;
	                    x = c[k >> 2] | 0;
	                    i = j;
	                    return x | 0
	                }
	                c[s >> 2] = c[p >> 2];
	                c[r >> 2] = c[q >> 2];
	                while (1) {
	                    if ((d[c[s >> 2] >> 0] | 0 | 0) != 32)break;
	                    c[s >> 2] = (c[s >> 2] | 0) + 1
	                }
	                while (1) {
	                    if (!(d[c[s >> 2] >> 0] | 0))break;
	                    if ((d[c[s >> 2] >> 0] | 0 | 0) != 32) {
	                        t = c[s >> 2] | 0;
	                        c[s >> 2] = t + 1;
	                        w = a[t >> 0] | 0;
	                        t = c[r >> 2] | 0;
	                        c[r >> 2] = t + 1;
	                        a[t >> 0] = w;
	                        continue
	                    }
	                    while (1) {
	                        y = c[s >> 2] | 0;
	                        if ((d[c[s >> 2] >> 0] | 0 | 0) != 32)break;
	                        c[s >> 2] = y + 1
	                    }
	                    if (!(d[y >> 0] | 0))continue;
	                    w = c[r >> 2] | 0;
	                    c[r >> 2] = w + 1;
	                    a[w >> 0] = 32
	                }
	                a[c[r >> 2] >> 0] = 0;
	                if (((c[u >> 2] | 0) == 1 ? (c[(c[m >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) ? (qy(c[p >> 2] | 0, c[q >> 2] | 0) | 0) == 0 : 0) {
	                    jn(c[l >> 2] | 0, c[n >> 2] | 0, 530, 81032, c[o >> 2] | 0, c[(c[n >> 2] | 0) + 8 >> 2] | 0, 0);
	                    c[(c[l >> 2] | 0) + 36 >> 2] = 0
	                }
	                c[k >> 2] = c[q >> 2];
	                x = c[k >> 2] | 0;
	                i = j;
	                return x | 0
	            }

	            function Tm(b, e, f, g) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                h = i;
	                i = i + 96 | 0;
	                j = h + 36 | 0;
	                k = h + 32 | 0;
	                l = h + 28 | 0;
	                m = h + 24 | 0;
	                n = h + 20 | 0;
	                o = h + 16 | 0;
	                p = h + 12 | 0;
	                q = h + 8 | 0;
	                r = h + 4 | 0;
	                s = h + 40 | 0;
	                t = h;
	                c[k >> 2] = b;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                c[n >> 2] = g;
	                c[r >> 2] = 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[j >> 2] = 0;
	                    u = c[j >> 2] | 0;
	                    i = h;
	                    return u | 0
	                }
	                if (!(c[l >> 2] | 0)) {
	                    c[j >> 2] = 0;
	                    u = c[j >> 2] | 0;
	                    i = h;
	                    return u | 0
	                }
	                if (!(c[m >> 2] | 0)) {
	                    c[j >> 2] = 0;
	                    u = c[j >> 2] | 0;
	                    i = h;
	                    return u | 0
	                }
	                if (!(c[n >> 2] | 0)) {
	                    c[j >> 2] = 0;
	                    u = c[j >> 2] | 0;
	                    i = h;
	                    return u | 0
	                }
	                if ((c[(c[l >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                    c[t >> 2] = Bh(c[(c[l >> 2] | 0) + 8 >> 2] | 0, c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0, s, 50) | 0;
	                    if (!(c[t >> 2] | 0)) {
	                        c[j >> 2] = 0;
	                        u = c[j >> 2] | 0;
	                        i = h;
	                        return u | 0
	                    }
	                    if ((c[t >> 2] | 0) != (s | 0) ? (c[t >> 2] | 0) != (c[(c[l >> 2] | 0) + 8 >> 2] | 0) : 0)zb[c[135736 >> 2] & 511](c[t >> 2] | 0)
	                }
	                c[r >> 2] = Fm(c[(c[k >> 2] | 0) + 44 >> 2] | 0, c[(c[l >> 2] | 0) + 8 >> 2] | 0, c[m >> 2] | 0) | 0;
	                if ((c[r >> 2] | 0) == 0 ? (c[(c[k >> 2] | 0) + 48 >> 2] | 0) != 0 : 0)c[r >> 2] = Fm(c[(c[k >> 2] | 0) + 48 >> 2] | 0, c[(c[l >> 2] | 0) + 8 >> 2] | 0, c[m >> 2] | 0) | 0;
	                if (!(c[r >> 2] | 0)) {
	                    c[j >> 2] = 0;
	                    u = c[j >> 2] | 0;
	                    i = h;
	                    return u | 0
	                }
	                if ((c[(c[r >> 2] | 0) + 40 >> 2] | 0) == 1) {
	                    c[j >> 2] = 0;
	                    u = c[j >> 2] | 0;
	                    i = h;
	                    return u | 0
	                }
	                c[o >> 2] = my(c[n >> 2] | 0) | 0;
	                if (!(c[o >> 2] | 0)) {
	                    c[j >> 2] = 0;
	                    u = c[j >> 2] | 0;
	                    i = h;
	                    return u | 0
	                }
	                c[q >> 2] = c[n >> 2];
	                c[p >> 2] = c[o >> 2];
	                while (1) {
	                    if ((d[c[q >> 2] >> 0] | 0 | 0) != 32)break;
	                    c[q >> 2] = (c[q >> 2] | 0) + 1
	                }
	                while (1) {
	                    if (!(d[c[q >> 2] >> 0] | 0))break;
	                    if ((d[c[q >> 2] >> 0] | 0 | 0) != 32) {
	                        n = c[q >> 2] | 0;
	                        c[q >> 2] = n + 1;
	                        r = a[n >> 0] | 0;
	                        n = c[p >> 2] | 0;
	                        c[p >> 2] = n + 1;
	                        a[n >> 0] = r;
	                        continue
	                    }
	                    while (1) {
	                        v = c[q >> 2] | 0;
	                        if ((d[c[q >> 2] >> 0] | 0 | 0) != 32)break;
	                        c[q >> 2] = v + 1
	                    }
	                    if (!(d[v >> 0] | 0))continue;
	                    r = c[p >> 2] | 0;
	                    c[p >> 2] = r + 1;
	                    a[r >> 0] = 32
	                }
	                a[c[p >> 2] >> 0] = 0;
	                c[j >> 2] = c[o >> 2];
	                u = c[j >> 2] | 0;
	                i = h;
	                return u | 0
	            }

	            function Um(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 40 | 0;
	                g = e + 36 | 0;
	                h = e + 32 | 0;
	                j = e + 28 | 0;
	                k = e + 24 | 0;
	                l = e + 20 | 0;
	                m = e + 16 | 0;
	                n = e + 12 | 0;
	                o = e + 8 | 0;
	                p = e + 4 | 0;
	                q = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 1;
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                }
	                if ((c[(c[h >> 2] | 0) + 44 >> 2] | 0) == 0 ? (c[(c[h >> 2] | 0) + 48 >> 2] | 0) == 0 : 0) {
	                    c[f >> 2] = 0;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                }
	                if (!(c[j >> 2] | 0)) {
	                    c[f >> 2] = 1;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                }
	                if (c[(c[j >> 2] | 0) + 48 >> 2] | 0) {
	                    c[l >> 2] = qn(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 40 >> 2] | 0, c[(c[j >> 2] | 0) + 48 >> 2] | 0) | 0;
	                    if (!(c[l >> 2] | 0))jn(c[g >> 2] | 0, c[j >> 2] | 0, 500, 81120, c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[(c[j >> 2] | 0) + 60 >> 2] | 0, 0);
	                    c[k >> 2] = c[k >> 2] & c[l >> 2]
	                }
	                if (((c[(c[j >> 2] | 0) + 40 >> 2] | 0) == 2 ? (c[(c[j >> 2] | 0) + 44 >> 2] | 0) != 3 : 0) ? (c[(c[j >> 2] | 0) + 44 >> 2] | 0) != 2 : 0) {
	                    jn(c[g >> 2] | 0, c[j >> 2] | 0, 512, 81184, c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[(c[j >> 2] | 0) + 60 >> 2] | 0, 0);
	                    c[k >> 2] = 0
	                }
	                do if ((c[(c[j >> 2] | 0) + 40 >> 2] | 0) == 2) {
	                    c[n >> 2] = Lm(c[(c[h >> 2] | 0) + 44 >> 2] | 0, c[(c[j >> 2] | 0) + 60 >> 2] | 0) | 0;
	                    if (!(c[n >> 2] | 0)) {
	                        c[m >> 2] = 0;
	                        if (c[(c[h >> 2] | 0) + 44 >> 2] | 0) {
	                            c[o >> 2] = c[(c[(c[h >> 2] | 0) + 44 >> 2] | 0) + 44 >> 2];
	                            Yj(c[o >> 2] | 0, 0, 0, c[(c[j >> 2] | 0) + 60 >> 2] | 0, 253, m)
	                        }
	                    } else c[m >> 2] = un(0, c[n >> 2] | 0, 0) | 0;
	                    if ((c[m >> 2] | 0) > 1) {
	                        Jn(c[g >> 2] | 0, c[j >> 2] | 0, 514, 81256, c[(c[j >> 2] | 0) + 60 >> 2] | 0, c[m >> 2] | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0);
	                        break
	                    }
	                    if (c[(c[h >> 2] | 0) + 48 >> 2] | 0) {
	                        c[p >> 2] = 0;
	                        c[n >> 2] = Lm(c[(c[h >> 2] | 0) + 48 >> 2] | 0, c[(c[j >> 2] | 0) + 60 >> 2] | 0) | 0;
	                        if (c[n >> 2] | 0)c[p >> 2] = un(0, c[n >> 2] | 0, 0) | 0;
	                        if ((c[p >> 2] | 0) > 1) {
	                            Jn(c[g >> 2] | 0, c[j >> 2] | 0, 514, 81328, c[(c[j >> 2] | 0) + 60 >> 2] | 0, c[p >> 2] | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0);
	                            break
	                        }
	                        if (((c[p >> 2] | 0) + (c[m >> 2] | 0) | 0) > 1)jn(c[g >> 2] | 0, c[j >> 2] | 0, 514, 81400, c[(c[j >> 2] | 0) + 60 >> 2] | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0, 0)
	                    }
	                } while (0);
	                if ((c[(c[j >> 2] | 0) + 48 >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 52 >> 2] | 0) != 0 : 0) {
	                    c[q >> 2] = c[(c[j >> 2] | 0) + 52 >> 2];
	                    while (1) {
	                        if (!(c[q >> 2] | 0))break;
	                        if (qy(c[(c[q >> 2] | 0) + 4 >> 2] | 0, c[(c[j >> 2] | 0) + 48 >> 2] | 0) | 0)break;
	                        c[q >> 2] = c[c[q >> 2] >> 2]
	                    }
	                    if (!(c[q >> 2] | 0)) {
	                        jn(c[g >> 2] | 0, c[j >> 2] | 0, 502, 81480, c[(c[j >> 2] | 0) + 48 >> 2] | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[(c[j >> 2] | 0) + 60 >> 2] | 0);
	                        c[k >> 2] = 0
	                    }
	                }
	                c[f >> 2] = c[k >> 2];
	                r = c[f >> 2] | 0;
	                i = e;
	                return r | 0
	            }

	            function Vm(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 32 | 0;
	                g = e + 28 | 0;
	                h = e + 24 | 0;
	                j = e + 20 | 0;
	                k = e + 16 | 0;
	                l = e + 12 | 0;
	                m = e + 8 | 0;
	                n = e + 4 | 0;
	                o = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 1;
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    p = c[f >> 2] | 0;
	                    i = e;
	                    return p | 0
	                }
	                if ((c[(c[h >> 2] | 0) + 44 >> 2] | 0) == 0 ? (c[(c[h >> 2] | 0) + 48 >> 2] | 0) == 0 : 0) {
	                    c[f >> 2] = 0;
	                    p = c[f >> 2] | 0;
	                    i = e;
	                    return p | 0
	                }
	                if (!(c[j >> 2] | 0)) {
	                    c[f >> 2] = 1;
	                    p = c[f >> 2] | 0;
	                    i = e;
	                    return p | 0
	                }
	                a:do if ((c[(c[j >> 2] | 0) + 36 >> 2] | 0) == 3) {
	                    c[m >> 2] = c[(c[j >> 2] | 0) + 40 >> 2];
	                    while (1) {
	                        if (!(c[m >> 2] | 0))break a;
	                        if ((c[c[m >> 2] >> 2] | 0) != 4)break a;
	                        if (!(c[(c[m >> 2] | 0) + 12 >> 2] | 0))break a;
	                        b:do if ((c[c[(c[m >> 2] | 0) + 12 >> 2] >> 2] | 0) == 2) {
	                            c[o >> 2] = c[(c[(c[m >> 2] | 0) + 12 >> 2] | 0) + 8 >> 2];
	                            c[n >> 2] = c[(c[m >> 2] | 0) + 16 >> 2];
	                            while (1) {
	                                if (!(c[n >> 2] | 0))break b;
	                                q = c[n >> 2] | 0;
	                                if ((c[c[n >> 2] >> 2] | 0) == 2)break;
	                                if (!(c[q + 12 >> 2] | 0))break b;
	                                if ((c[c[(c[n >> 2] | 0) + 12 >> 2] >> 2] | 0) != 2)break b;
	                                if ((qy(c[(c[(c[n >> 2] | 0) + 12 >> 2] | 0) + 8 >> 2] | 0, c[o >> 2] | 0) | 0) != 0 ? (qy(c[(c[(c[n >> 2] | 0) + 12 >> 2] | 0) + 24 >> 2] | 0, c[(c[(c[m >> 2] | 0) + 12 >> 2] | 0) + 24 >> 2] | 0) | 0) != 0 : 0) {
	                                    d = c[g >> 2] | 0;
	                                    b = c[j >> 2] | 0;
	                                    a = c[(c[j >> 2] | 0) + 8 >> 2] | 0;
	                                    if (!(c[(c[(c[m >> 2] | 0) + 12 >> 2] | 0) + 24 >> 2] | 0))jn(d, b, 503, 81672, a, c[o >> 2] | 0, 0); else jn(d, b, 503, 81728, a, c[(c[(c[m >> 2] | 0) + 12 >> 2] | 0) + 24 >> 2] | 0, c[o >> 2] | 0);
	                                    c[k >> 2] = 0
	                                }
	                                c[n >> 2] = c[(c[n >> 2] | 0) + 16 >> 2]
	                            }
	                            if ((qy(c[q + 8 >> 2] | 0, c[o >> 2] | 0) | 0) != 0 ? (qy(c[(c[n >> 2] | 0) + 24 >> 2] | 0, c[(c[(c[m >> 2] | 0) + 12 >> 2] | 0) + 24 >> 2] | 0) | 0) != 0 : 0) {
	                                a = c[g >> 2] | 0;
	                                b = c[j >> 2] | 0;
	                                d = c[(c[j >> 2] | 0) + 8 >> 2] | 0;
	                                if (!(c[(c[(c[m >> 2] | 0) + 12 >> 2] | 0) + 24 >> 2] | 0))jn(a, b, 503, 81560, d, c[o >> 2] | 0, 0); else jn(a, b, 503, 81616, d, c[(c[(c[m >> 2] | 0) + 12 >> 2] | 0) + 24 >> 2] | 0, c[o >> 2] | 0);
	                                c[k >> 2] = 0
	                            }
	                        } while (0);
	                        c[m >> 2] = c[(c[m >> 2] | 0) + 16 >> 2]
	                    }
	                } while (0);
	                c[l >> 2] = Lm(c[(c[h >> 2] | 0) + 44 >> 2] | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0) | 0;
	                do if ((c[l >> 2] | 0) != 0 ? (c[l >> 2] | 0) != (c[j >> 2] | 0) : 0) {
	                    if ((c[(c[l >> 2] | 0) + 48 >> 2] | 0) != (c[(c[j >> 2] | 0) + 48 >> 2] | 0) ? (qy(c[(c[l >> 2] | 0) + 48 >> 2] | 0, c[(c[j >> 2] | 0) + 48 >> 2] | 0) | 0) == 0 : 0)break;
	                    if (c[(c[l >> 2] | 0) + 36 >> 2] | 0) {
	                        jn(c[g >> 2] | 0, c[j >> 2] | 0, 509, 79992, c[(c[j >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                        c[k >> 2] = 0
	                    }
	                } while (0);
	                c[l >> 2] = Lm(c[(c[h >> 2] | 0) + 48 >> 2] | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0) | 0;
	                do if ((c[l >> 2] | 0) != 0 ? (c[l >> 2] | 0) != (c[j >> 2] | 0) : 0) {
	                    if ((c[(c[l >> 2] | 0) + 48 >> 2] | 0) != (c[(c[j >> 2] | 0) + 48 >> 2] | 0) ? (qy(c[(c[l >> 2] | 0) + 48 >> 2] | 0, c[(c[j >> 2] | 0) + 48 >> 2] | 0) | 0) == 0 : 0)break;
	                    if (c[(c[l >> 2] | 0) + 36 >> 2] | 0) {
	                        jn(c[g >> 2] | 0, c[j >> 2] | 0, 509, 79992, c[(c[j >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                        c[k >> 2] = 0
	                    }
	                } while (0);
	                c[f >> 2] = c[k >> 2];
	                p = c[f >> 2] | 0;
	                i = e;
	                return p | 0
	            }

	            function Wm(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0;
	                g = i;
	                i = i + 112 | 0;
	                h = g + 48 | 0;
	                j = g + 44 | 0;
	                k = g + 40 | 0;
	                l = g + 36 | 0;
	                m = g + 32 | 0;
	                n = g + 28 | 0;
	                o = g + 24 | 0;
	                p = g + 20 | 0;
	                q = g + 16 | 0;
	                r = g + 52 | 0;
	                s = g + 12 | 0;
	                t = g + 8 | 0;
	                u = g + 4 | 0;
	                v = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = 0;
	                c[q >> 2] = 1;
	                if (!(c[k >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    w = c[h >> 2] | 0;
	                    i = g;
	                    return w | 0
	                }
	                if ((c[(c[k >> 2] | 0) + 44 >> 2] | 0) == 0 ? (c[(c[k >> 2] | 0) + 48 >> 2] | 0) == 0 : 0) {
	                    c[h >> 2] = 0;
	                    w = c[h >> 2] | 0;
	                    i = g;
	                    return w | 0
	                }
	                if ((c[l >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                    if ((c[m >> 2] | 0) != 0 ? (c[(c[m >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                        if ((c[(c[l >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                            c[s >> 2] = Bh(c[(c[l >> 2] | 0) + 8 >> 2] | 0, c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0, r, 50) | 0;
	                            if (!(c[s >> 2] | 0)) {
	                                c[h >> 2] = 0;
	                                w = c[h >> 2] | 0;
	                                i = g;
	                                return w | 0
	                            }
	                            f = c[(c[k >> 2] | 0) + 44 >> 2] | 0;
	                            e = c[s >> 2] | 0;
	                            d = c[(c[m >> 2] | 0) + 8 >> 2] | 0;
	                            if (c[(c[m >> 2] | 0) + 36 >> 2] | 0) {
	                                c[o >> 2] = Nm(f, e, d, c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0;
	                                if ((c[o >> 2] | 0) == 0 ? (c[(c[k >> 2] | 0) + 48 >> 2] | 0) != 0 : 0)c[o >> 2] = Nm(c[(c[k >> 2] | 0) + 48 >> 2] | 0, c[s >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0, c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0
	                            } else {
	                                c[o >> 2] = Fm(f, e, d) | 0;
	                                if ((c[o >> 2] | 0) == 0 ? (c[(c[k >> 2] | 0) + 48 >> 2] | 0) != 0 : 0)c[o >> 2] = Fm(c[(c[k >> 2] | 0) + 48 >> 2] | 0, c[s >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0) | 0
	                            }
	                            if ((c[s >> 2] | 0) != (r | 0) ? (c[s >> 2] | 0) != (c[(c[l >> 2] | 0) + 8 >> 2] | 0) : 0)zb[c[135736 >> 2] & 511](c[s >> 2] | 0)
	                        }
	                        do if (!(c[o >> 2] | 0)) {
	                            s = c[(c[k >> 2] | 0) + 44 >> 2] | 0;
	                            r = c[(c[l >> 2] | 0) + 8 >> 2] | 0;
	                            d = c[(c[m >> 2] | 0) + 8 >> 2] | 0;
	                            if (c[(c[m >> 2] | 0) + 36 >> 2] | 0) {
	                                c[o >> 2] = Nm(s, r, d, c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0;
	                                if (c[o >> 2] | 0)break;
	                                if (!(c[(c[k >> 2] | 0) + 48 >> 2] | 0))break;
	                                c[o >> 2] = Nm(c[(c[k >> 2] | 0) + 48 >> 2] | 0, c[(c[l >> 2] | 0) + 8 >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0, c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0;
	                                break
	                            } else {
	                                c[o >> 2] = Fm(s, r, d) | 0;
	                                if (c[o >> 2] | 0)break;
	                                if (!(c[(c[k >> 2] | 0) + 48 >> 2] | 0))break;
	                                c[o >> 2] = Fm(c[(c[k >> 2] | 0) + 48 >> 2] | 0, c[(c[l >> 2] | 0) + 8 >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0) | 0;
	                                break
	                            }
	                        } while (0);
	                        if (!(c[o >> 2] | 0)) {
	                            jn(c[j >> 2] | 0, c[l >> 2] | 0, 533, 81784, c[(c[m >> 2] | 0) + 8 >> 2] | 0, c[(c[l >> 2] | 0) + 8 >> 2] | 0, 0);
	                            c[h >> 2] = 0;
	                            w = c[h >> 2] | 0;
	                            i = g;
	                            return w | 0
	                        }
	                        c[(c[m >> 2] | 0) + 40 >> 2] = c[(c[o >> 2] | 0) + 40 >> 2];
	                        c[p >> 2] = qn(c[k >> 2] | 0, c[(c[o >> 2] | 0) + 40 >> 2] | 0, c[n >> 2] | 0) | 0;
	                        if (!(c[p >> 2] | 0)) {
	                            jn(c[j >> 2] | 0, c[l >> 2] | 0, 502, 81832, c[(c[m >> 2] | 0) + 8 >> 2] | 0, c[(c[l >> 2] | 0) + 8 >> 2] | 0, 0);
	                            c[q >> 2] = 0
	                        }
	                        if ((c[(c[o >> 2] | 0) + 44 >> 2] | 0) == 4 ? (qy(c[n >> 2] | 0, c[(c[o >> 2] | 0) + 48 >> 2] | 0) | 0) == 0 : 0) {
	                            jn(c[j >> 2] | 0, c[l >> 2] | 0, 500, 81888, c[(c[m >> 2] | 0) + 8 >> 2] | 0, c[(c[l >> 2] | 0) + 8 >> 2] | 0, c[(c[o >> 2] | 0) + 48 >> 2] | 0);
	                            c[q >> 2] = 0
	                        }
	                        if ((c[(c[o >> 2] | 0) + 40 >> 2] | 0) == 2 ? (Cm(c[j >> 2] | 0, c[k >> 2] | 0, c[n >> 2] | 0, c[m >> 2] | 0) | 0) == 0 : 0)c[q >> 2] = 0;
	                        if (!((c[(c[o >> 2] | 0) + 40 >> 2] | 0) != 3 ? (c[(c[o >> 2] | 0) + 40 >> 2] | 0) != 4 : 0))x = 46;
	                        if ((x | 0) == 46 ? (Im(c[j >> 2] | 0, c[k >> 2] | 0, c[n >> 2] | 0, c[m >> 2] | 0) | 0) == 0 : 0)c[q >> 2] = 0;
	                        if ((c[(c[o >> 2] | 0) + 40 >> 2] | 0) == 10) {
	                            c[t >> 2] = c[(c[o >> 2] | 0) + 52 >> 2];
	                            c[u >> 2] = Om(c[(c[k >> 2] | 0) + 44 >> 2] | 0, c[n >> 2] | 0) | 0;
	                            if (!(c[u >> 2] | 0))c[u >> 2] = Om(c[(c[k >> 2] | 0) + 48 >> 2] | 0, c[n >> 2] | 0) | 0;
	                            if (!(c[u >> 2] | 0)) {
	                                jn(c[j >> 2] | 0, c[l >> 2] | 0, 537, 81952, c[n >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0, c[(c[l >> 2] | 0) + 8 >> 2] | 0);
	                                c[q >> 2] = 0
	                            }
	                            while (1) {
	                                if (!(c[t >> 2] | 0))break;
	                                if (qy(c[(c[t >> 2] | 0) + 4 >> 2] | 0, c[n >> 2] | 0) | 0)break;
	                                c[t >> 2] = c[c[t >> 2] >> 2]
	                            }
	                            if (!(c[t >> 2] | 0)) {
	                                jn(c[j >> 2] | 0, c[l >> 2] | 0, 527, 82016, c[n >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0, c[(c[l >> 2] | 0) + 8 >> 2] | 0);
	                                c[q >> 2] = 0
	                            }
	                        }
	                        if ((c[(c[o >> 2] | 0) + 40 >> 2] | 0) == 9) {
	                            c[v >> 2] = c[(c[o >> 2] | 0) + 52 >> 2];
	                            while (1) {
	                                if (!(c[v >> 2] | 0))break;
	                                if (qy(c[(c[v >> 2] | 0) + 4 >> 2] | 0, c[n >> 2] | 0) | 0)break;
	                                c[v >> 2] = c[c[v >> 2] >> 2]
	                            }
	                            if (!(c[v >> 2] | 0)) {
	                                jn(c[j >> 2] | 0, c[l >> 2] | 0, 502, 82096, c[n >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0, c[(c[l >> 2] | 0) + 8 >> 2] | 0);
	                                c[q >> 2] = 0
	                            }
	                        }
	                        if ((c[(c[o >> 2] | 0) + 44 >> 2] | 0) == 4 ? (qy(c[(c[o >> 2] | 0) + 48 >> 2] | 0, c[n >> 2] | 0) | 0) == 0 : 0) {
	                            jn(c[j >> 2] | 0, c[l >> 2] | 0, 502, 82168, c[(c[m >> 2] | 0) + 8 >> 2] | 0, c[(c[l >> 2] | 0) + 8 >> 2] | 0, c[(c[o >> 2] | 0) + 48 >> 2] | 0);
	                            c[q >> 2] = 0
	                        }
	                        l = Kn(c[j >> 2] | 0, c[k >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0, c[(c[o >> 2] | 0) + 40 >> 2] | 0, c[n >> 2] | 0) | 0;
	                        c[q >> 2] = c[q >> 2] & l;
	                        c[h >> 2] = c[q >> 2];
	                        w = c[h >> 2] | 0;
	                        i = g;
	                        return w | 0
	                    }
	                    c[h >> 2] = 0;
	                    w = c[h >> 2] | 0;
	                    i = g;
	                    return w | 0
	                }
	                c[h >> 2] = 0;
	                w = c[h >> 2] | 0;
	                i = g;
	                return w | 0
	            }

	            function Xm(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0;
	                h = i;
	                i = i + 112 | 0;
	                j = h + 52 | 0;
	                k = h + 48 | 0;
	                l = h + 44 | 0;
	                m = h + 40 | 0;
	                n = h + 36 | 0;
	                o = h + 32 | 0;
	                p = h + 28 | 0;
	                q = h + 24 | 0;
	                r = h + 20 | 0;
	                s = h + 16 | 0;
	                t = h + 56 | 0;
	                u = h + 12 | 0;
	                v = h + 8 | 0;
	                w = h + 4 | 0;
	                x = h;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                c[q >> 2] = 0;
	                c[s >> 2] = 1;
	                if (!(c[l >> 2] | 0)) {
	                    c[j >> 2] = 0;
	                    y = c[j >> 2] | 0;
	                    i = h;
	                    return y | 0
	                }
	                if ((c[(c[l >> 2] | 0) + 44 >> 2] | 0) == 0 ? (c[(c[l >> 2] | 0) + 48 >> 2] | 0) == 0 : 0) {
	                    c[j >> 2] = 0;
	                    y = c[j >> 2] | 0;
	                    i = h;
	                    return y | 0
	                }
	                if ((c[m >> 2] | 0) != 0 ? (c[(c[m >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                    if ((c[o >> 2] | 0) != 0 ? (c[(c[o >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                        if (c[n >> 2] | 0) {
	                            c[u >> 2] = Bh(c[(c[m >> 2] | 0) + 8 >> 2] | 0, c[n >> 2] | 0, t, 50) | 0;
	                            if (!(c[u >> 2] | 0)) {
	                                ln(c[k >> 2] | 0, 82216);
	                                c[j >> 2] = 0;
	                                y = c[j >> 2] | 0;
	                                i = h;
	                                return y | 0
	                            }
	                            n = c[(c[l >> 2] | 0) + 44 >> 2] | 0;
	                            g = c[u >> 2] | 0;
	                            if (c[(c[o >> 2] | 0) + 12 >> 2] | 0) {
	                                c[q >> 2] = Nm(n, g, c[(c[o >> 2] | 0) + 12 >> 2] | 0, 80392) | 0;
	                                if ((c[q >> 2] | 0) == 0 ? (c[(c[l >> 2] | 0) + 48 >> 2] | 0) != 0 : 0)c[q >> 2] = Nm(c[(c[l >> 2] | 0) + 48 >> 2] | 0, c[u >> 2] | 0, c[(c[o >> 2] | 0) + 12 >> 2] | 0, 80392) | 0
	                            } else {
	                                c[q >> 2] = Fm(n, g, 80392) | 0;
	                                if ((c[q >> 2] | 0) == 0 ? (c[(c[l >> 2] | 0) + 48 >> 2] | 0) != 0 : 0)c[q >> 2] = Fm(c[(c[l >> 2] | 0) + 48 >> 2] | 0, c[u >> 2] | 0, 80392) | 0
	                            }
	                            if ((c[u >> 2] | 0) != (t | 0) ? (c[u >> 2] | 0) != (c[(c[m >> 2] | 0) + 8 >> 2] | 0) : 0)zb[c[135736 >> 2] & 511](c[u >> 2] | 0)
	                        }
	                        do if (!(c[q >> 2] | 0)) {
	                            u = c[(c[l >> 2] | 0) + 44 >> 2] | 0;
	                            t = c[(c[m >> 2] | 0) + 8 >> 2] | 0;
	                            if (c[(c[o >> 2] | 0) + 12 >> 2] | 0) {
	                                c[q >> 2] = Nm(u, t, c[(c[o >> 2] | 0) + 12 >> 2] | 0, 80392) | 0;
	                                if (c[q >> 2] | 0)break;
	                                if (!(c[(c[l >> 2] | 0) + 48 >> 2] | 0))break;
	                                c[q >> 2] = Nm(c[(c[l >> 2] | 0) + 48 >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0, c[(c[o >> 2] | 0) + 12 >> 2] | 0, 80392) | 0;
	                                break
	                            } else {
	                                c[q >> 2] = Fm(u, t, 80392) | 0;
	                                if (c[q >> 2] | 0)break;
	                                if (!(c[(c[l >> 2] | 0) + 48 >> 2] | 0))break;
	                                c[q >> 2] = Fm(c[(c[l >> 2] | 0) + 48 >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0, 80392) | 0;
	                                break
	                            }
	                        } while (0);
	                        if (!(c[q >> 2] | 0)) {
	                            t = c[k >> 2] | 0;
	                            u = c[m >> 2] | 0;
	                            if (c[(c[o >> 2] | 0) + 12 >> 2] | 0)jn(t, u, 533, 82240, c[(c[o >> 2] | 0) + 12 >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0, 0); else jn(t, u, 533, 82296, c[(c[m >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                            c[j >> 2] = 0;
	                            y = c[j >> 2] | 0;
	                            i = h;
	                            return y | 0
	                        }
	                        c[r >> 2] = qn(c[l >> 2] | 0, c[(c[q >> 2] | 0) + 40 >> 2] | 0, c[p >> 2] | 0) | 0;
	                        if (!(c[r >> 2] | 0)) {
	                            r = c[k >> 2] | 0;
	                            u = c[m >> 2] | 0;
	                            if (c[(c[o >> 2] | 0) + 12 >> 2] | 0)jn(r, u, 516, 82352, c[(c[o >> 2] | 0) + 12 >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0, 0); else jn(r, u, 516, 82416, c[(c[m >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                            c[s >> 2] = 0
	                        }
	                        if ((c[(c[q >> 2] | 0) + 44 >> 2] | 0) == 4 ? (qy(c[p >> 2] | 0, c[(c[q >> 2] | 0) + 48 >> 2] | 0) | 0) == 0 : 0) {
	                            u = c[k >> 2] | 0;
	                            r = c[m >> 2] | 0;
	                            if (c[(c[o >> 2] | 0) + 12 >> 2] | 0)jn(u, r, 500, 82472, c[(c[o >> 2] | 0) + 12 >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0, c[(c[q >> 2] | 0) + 48 >> 2] | 0); else jn(u, r, 500, 82544, c[(c[m >> 2] | 0) + 8 >> 2] | 0, c[(c[q >> 2] | 0) + 48 >> 2] | 0, 0);
	                            c[s >> 2] = 0
	                        }
	                        if ((c[(c[q >> 2] | 0) + 40 >> 2] | 0) == 2 ? (Cm(c[k >> 2] | 0, c[l >> 2] | 0, c[p >> 2] | 0, c[o >> 2] | 0) | 0) == 0 : 0)c[s >> 2] = 0;
	                        if (!((c[(c[q >> 2] | 0) + 40 >> 2] | 0) != 3 ? (c[(c[q >> 2] | 0) + 40 >> 2] | 0) != 4 : 0))z = 54;
	                        if ((z | 0) == 54 ? (Im(c[k >> 2] | 0, c[l >> 2] | 0, c[p >> 2] | 0, c[o >> 2] | 0) | 0) == 0 : 0)c[s >> 2] = 0;
	                        if ((c[(c[q >> 2] | 0) + 40 >> 2] | 0) == 10) {
	                            c[v >> 2] = c[(c[q >> 2] | 0) + 52 >> 2];
	                            c[w >> 2] = Om(c[(c[l >> 2] | 0) + 44 >> 2] | 0, c[p >> 2] | 0) | 0;
	                            if (!(c[w >> 2] | 0))c[w >> 2] = Om(c[(c[l >> 2] | 0) + 48 >> 2] | 0, c[p >> 2] | 0) | 0;
	                            if (!(c[w >> 2] | 0)) {
	                                w = c[k >> 2] | 0;
	                                z = c[m >> 2] | 0;
	                                r = c[p >> 2] | 0;
	                                if (c[(c[o >> 2] | 0) + 12 >> 2] | 0)jn(w, z, 537, 82608, r, c[(c[o >> 2] | 0) + 12 >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0); else jn(w, z, 537, 82680, r, c[(c[m >> 2] | 0) + 8 >> 2] | 0, 0);
	                                c[s >> 2] = 0
	                            }
	                            while (1) {
	                                if (!(c[v >> 2] | 0))break;
	                                if (qy(c[(c[v >> 2] | 0) + 4 >> 2] | 0, c[p >> 2] | 0) | 0)break;
	                                c[v >> 2] = c[c[v >> 2] >> 2]
	                            }
	                            if (!(c[v >> 2] | 0)) {
	                                v = c[k >> 2] | 0;
	                                r = c[m >> 2] | 0;
	                                z = c[p >> 2] | 0;
	                                if (c[(c[o >> 2] | 0) + 12 >> 2] | 0)jn(v, r, 527, 82752, z, c[(c[o >> 2] | 0) + 12 >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0); else jn(v, r, 527, 82832, z, c[(c[m >> 2] | 0) + 8 >> 2] | 0, 0);
	                                c[s >> 2] = 0
	                            }
	                        }
	                        if ((c[(c[q >> 2] | 0) + 40 >> 2] | 0) == 9) {
	                            c[x >> 2] = c[(c[q >> 2] | 0) + 52 >> 2];
	                            while (1) {
	                                if (!(c[x >> 2] | 0))break;
	                                if (qy(c[(c[x >> 2] | 0) + 4 >> 2] | 0, c[p >> 2] | 0) | 0)break;
	                                c[x >> 2] = c[c[x >> 2] >> 2]
	                            }
	                            if (!(c[x >> 2] | 0)) {
	                                x = c[k >> 2] | 0;
	                                z = c[m >> 2] | 0;
	                                r = c[p >> 2] | 0;
	                                if (c[(c[o >> 2] | 0) + 12 >> 2] | 0)jn(x, z, 502, 82912, r, c[(c[o >> 2] | 0) + 12 >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0); else jn(x, z, 502, 82992, r, c[(c[m >> 2] | 0) + 8 >> 2] | 0, 0);
	                                c[s >> 2] = 0
	                            }
	                        }
	                        if ((c[(c[q >> 2] | 0) + 44 >> 2] | 0) == 4 ? (qy(c[(c[q >> 2] | 0) + 48 >> 2] | 0, c[p >> 2] | 0) | 0) == 0 : 0) {
	                            r = c[k >> 2] | 0;
	                            z = c[m >> 2] | 0;
	                            if (c[(c[o >> 2] | 0) + 12 >> 2] | 0)jn(r, z, 508, 83064, c[(c[o >> 2] | 0) + 12 >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0, c[(c[q >> 2] | 0) + 48 >> 2] | 0); else jn(r, z, 508, 83120, c[(c[m >> 2] | 0) + 8 >> 2] | 0, c[(c[q >> 2] | 0) + 48 >> 2] | 0, 0);
	                            c[s >> 2] = 0
	                        }
	                        m = c[k >> 2] | 0;
	                        k = c[l >> 2] | 0;
	                        if (c[(c[o >> 2] | 0) + 12 >> 2] | 0) {
	                            l = Kn(m, k, c[(c[o >> 2] | 0) + 12 >> 2] | 0, c[(c[q >> 2] | 0) + 40 >> 2] | 0, c[p >> 2] | 0) | 0;
	                            c[s >> 2] = c[s >> 2] & l
	                        } else {
	                            l = Kn(m, k, 80392, c[(c[q >> 2] | 0) + 40 >> 2] | 0, c[p >> 2] | 0) | 0;
	                            c[s >> 2] = c[s >> 2] & l
	                        }
	                        c[j >> 2] = c[s >> 2];
	                        y = c[j >> 2] | 0;
	                        i = h;
	                        return y | 0
	                    }
	                    c[j >> 2] = 0;
	                    y = c[j >> 2] | 0;
	                    i = h;
	                    return y | 0
	                }
	                c[j >> 2] = 0;
	                y = c[j >> 2] | 0;
	                i = h;
	                return y | 0
	            }

	            function Ym(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f + 36 | 0;
	                h = f + 32 | 0;
	                j = f + 28 | 0;
	                k = f + 24 | 0;
	                l = f + 20 | 0;
	                m = f + 16 | 0;
	                n = f + 12 | 0;
	                o = f + 8 | 0;
	                p = f + 4 | 0;
	                q = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = 1;
	                c[o >> 2] = 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    r = c[g >> 2] | 0;
	                    i = f;
	                    return r | 0
	                }
	                do if (((c[(c[h >> 2] | 0) + 44 >> 2] | 0) > 0 ? (c[(c[h >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) ? (c[p >> 2] = c[(c[h >> 2] | 0) + 40 >> 2], (c[c[p >> 2] >> 2] | 0) != 0) : 0) {
	                    c[q >> 2] = c[c[p >> 2] >> 2];
	                    e = c[(c[q >> 2] | 0) + 36 >> 2] | 0;
	                    if ((e | 0) == 4) {
	                        if (!(c[(c[p >> 2] | 0) + 8 >> 2] | 0))break;
	                        c[m >> 2] = qz(c[(c[p >> 2] | 0) + 8 >> 2] | 0, c[l >> 2] | 0, 0) | 0;
	                        if ((c[m >> 2] | 0) < 0) {
	                            jn(c[h >> 2] | 0, c[(c[p >> 2] | 0) + 4 >> 2] | 0, 504, 83352, c[(c[(c[p >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0, c[l >> 2] | 0, 0);
	                            c[m >> 2] = 0;
	                            break
	                        } else {
	                            c[m >> 2] = 1;
	                            break
	                        }
	                    } else if ((e | 0) == 1) {
	                        jn(c[h >> 2] | 0, c[(c[p >> 2] | 0) + 4 >> 2] | 0, 528, 83168, c[(c[(c[p >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                        c[m >> 2] = 0;
	                        break
	                    } else if ((e | 0) == 3) {
	                        if ((c[(c[q >> 2] | 0) + 40 >> 2] | 0) != 0 ? (c[c[(c[q >> 2] | 0) + 40 >> 2] >> 2] | 0) == 1 : 0) {
	                            jn(c[h >> 2] | 0, c[(c[p >> 2] | 0) + 4 >> 2] | 0, 529, 83224, c[(c[(c[p >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                            c[m >> 2] = 0;
	                            break
	                        }
	                        c[m >> 2] = Ln(c[h >> 2] | 0, c[(c[q >> 2] | 0) + 40 >> 2] | 0, c[l >> 2] | 0) | 0;
	                        if ((c[m >> 2] | 0) == 1)break;
	                        jn(c[h >> 2] | 0, c[(c[p >> 2] | 0) + 4 >> 2] | 0, 515, 83288, c[l >> 2] | 0, c[(c[(c[p >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0, 0);
	                        break
	                    } else if (!e) {
	                        c[m >> 2] = 0;
	                        break
	                    } else break
	                } while (0);
	                c[n >> 2] = Mn(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, o) | 0;
	                Nn(c[h >> 2] | 0, c[n >> 2] | 0, c[k >> 2] | 0) | 0;
	                c[g >> 2] = c[m >> 2];
	                r = c[g >> 2] | 0;
	                i = f;
	                return r | 0
	            }

	            function Zm(a, b, e) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 28 | 0;
	                h = f + 24 | 0;
	                j = f + 20 | 0;
	                k = f + 16 | 0;
	                l = f + 12 | 0;
	                m = f + 8 | 0;
	                n = f + 4 | 0;
	                o = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[l >> 2] = 1;
	                if (!(c[h >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                if ((c[k >> 2] | 0) <= 0) {
	                    c[g >> 2] = c[l >> 2];
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                a:do if (((c[(c[h >> 2] | 0) + 44 >> 2] | 0) > 0 ? (c[(c[h >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) ? (c[m >> 2] = c[(c[h >> 2] | 0) + 40 >> 2], (c[c[m >> 2] >> 2] | 0) != 0) : 0) {
	                    c[n >> 2] = c[c[m >> 2] >> 2];
	                    e = c[(c[n >> 2] | 0) + 36 >> 2] | 0;
	                    if ((e | 0) == 1) {
	                        jn(c[h >> 2] | 0, c[(c[m >> 2] | 0) + 4 >> 2] | 0, 528, 83168, c[(c[(c[m >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                        c[l >> 2] = 0;
	                        break
	                    } else if (!e) {
	                        c[l >> 2] = 0;
	                        break
	                    } else if ((e | 0) == 4) {
	                        if ((c[k >> 2] | 0) <= 0)break;
	                        c[o >> 2] = 0;
	                        b:while (1) {
	                            if ((c[o >> 2] | 0) >= (c[k >> 2] | 0))break a;
	                            do if ((d[(c[j >> 2] | 0) + (c[o >> 2] | 0) >> 0] | 0 | 0) != 32) {
	                                if (9 <= (d[(c[j >> 2] | 0) + (c[o >> 2] | 0) >> 0] | 0 | 0) ? (d[(c[j >> 2] | 0) + (c[o >> 2] | 0) >> 0] | 0 | 0) <= 10 : 0)break;
	                                if ((d[(c[j >> 2] | 0) + (c[o >> 2] | 0) >> 0] | 0 | 0) != 13)break b
	                            } while (0);
	                            c[o >> 2] = (c[o >> 2] | 0) + 1
	                        }
	                        jn(c[h >> 2] | 0, c[(c[m >> 2] | 0) + 4 >> 2] | 0, 504, 83416, c[(c[(c[m >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                        c[l >> 2] = 0;
	                        break
	                    } else break
	                } while (0);
	                c[g >> 2] = c[l >> 2];
	                p = c[g >> 2] | 0;
	                i = f;
	                return p | 0
	            }

	            function _m(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 28 | 0;
	                h = f + 24 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[h >> 2] = a;
	                c[f + 20 >> 2] = b;
	                c[f + 16 >> 2] = d;
	                c[f + 12 >> 2] = e;
	                c[j >> 2] = 1;
	                if (!(c[h >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                if ((c[(c[h >> 2] | 0) + 44 >> 2] | 0) > 0 ? (c[(c[h >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) {
	                    c[k >> 2] = c[(c[h >> 2] | 0) + 40 >> 2];
	                    do if (((c[c[k >> 2] >> 2] | 0) != 0 ? (c[l >> 2] = c[c[k >> 2] >> 2], (c[(c[l >> 2] | 0) + 36 >> 2] | 0) == 4) : 0) ? (c[(c[k >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                        c[j >> 2] = qz(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 0, 0) | 0;
	                        if (!(c[j >> 2] | 0)) {
	                            jn(c[h >> 2] | 0, c[(c[k >> 2] | 0) + 4 >> 2] | 0, 504, 83480, c[(c[(c[k >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                            break
	                        } else {
	                            c[j >> 2] = 1;
	                            break
	                        }
	                    } while (0);
	                    On(c[h >> 2] | 0) | 0
	                }
	                c[g >> 2] = c[j >> 2];
	                m = c[g >> 2] | 0;
	                i = f;
	                return m | 0
	            }

	            function $m(a, b, e) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0;
	                f = i;
	                i = i + 144 | 0;
	                g = f + 80 | 0;
	                h = f + 76 | 0;
	                j = f + 72 | 0;
	                k = f + 68 | 0;
	                l = f + 64 | 0;
	                m = f + 60 | 0;
	                n = f + 56 | 0;
	                o = f + 52 | 0;
	                p = f + 48 | 0;
	                q = f + 44 | 0;
	                r = f + 40 | 0;
	                s = f + 36 | 0;
	                t = f + 84 | 0;
	                u = f + 32 | 0;
	                v = f + 28 | 0;
	                w = f + 24 | 0;
	                x = f + 20 | 0;
	                y = f + 16 | 0;
	                z = f + 12 | 0;
	                A = f + 8 | 0;
	                B = f + 4 | 0;
	                C = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[l >> 2] = 0;
	                c[p >> 2] = 1;
	                c[s >> 2] = 0;
	                if (!(c[j >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    D = c[g >> 2] | 0;
	                    i = f;
	                    return D | 0
	                }
	                if ((c[(c[j >> 2] | 0) + 44 >> 2] | 0) == 0 ? (c[(c[j >> 2] | 0) + 48 >> 2] | 0) == 0 : 0) {
	                    c[g >> 2] = 0;
	                    D = c[g >> 2] | 0;
	                    i = f;
	                    return D | 0
	                }
	                if (!(c[k >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    D = c[g >> 2] | 0;
	                    i = f;
	                    return D | 0
	                }
	                do switch (c[(c[k >> 2] | 0) + 4 >> 2] | 0) {
	                    case 8:
	                    case 7:
	                    case 5:
	                    case 4:
	                    {
	                        c[g >> 2] = 1;
	                        D = c[g >> 2] | 0;
	                        i = f;
	                        return D | 0
	                    }
	                    case 6:
	                    {
	                        jn(c[h >> 2] | 0, c[k >> 2] | 0, 1, 83680, 0, 0, 0);
	                        c[g >> 2] = 0;
	                        D = c[g >> 2] | 0;
	                        i = f;
	                        return D | 0
	                    }
	                    case 11:
	                    case 10:
	                    case 9:
	                    {
	                        jn(c[h >> 2] | 0, c[k >> 2] | 0, 1, 83744, 0, 0, 0);
	                        c[g >> 2] = 0;
	                        D = c[g >> 2] | 0;
	                        i = f;
	                        return D | 0
	                    }
	                    case 20:
	                    case 19:
	                    {
	                        c[g >> 2] = 1;
	                        D = c[g >> 2] | 0;
	                        i = f;
	                        return D | 0
	                    }
	                    case 1:
	                    {
	                        c[l >> 2] = Mn(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, s) | 0;
	                        if (!(c[l >> 2] | 0)) {
	                            c[g >> 2] = 0;
	                            D = c[g >> 2] | 0;
	                            i = f;
	                            return D | 0
	                        }
	                        a:do if (!(c[(c[h >> 2] | 0) + 44 >> 2] | 0)) {
	                            e = c[(c[l >> 2] | 0) + 36 >> 2] | 0;
	                            if (!e) {
	                                jn(c[h >> 2] | 0, c[k >> 2] | 0, 534, 83832, c[(c[k >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                                c[g >> 2] = 0;
	                                D = c[g >> 2] | 0;
	                                i = f;
	                                return D | 0
	                            } else if ((e | 0) == 4) {
	                                b:do if ((c[s >> 2] | 0) == 1 ? (c[(c[j >> 2] | 0) + 40 >> 2] | 0) == 1 : 0) {
	                                    c[o >> 2] = c[(c[k >> 2] | 0) + 12 >> 2];
	                                    while (1) {
	                                        if (!(c[o >> 2] | 0))break b;
	                                        if ((c[(c[o >> 2] | 0) + 4 >> 2] | 0) == 3) {
	                                            c[v >> 2] = c[(c[o >> 2] | 0) + 40 >> 2];
	                                            while (1) {
	                                                do if ((d[c[v >> 2] >> 0] | 0 | 0) == 32)E = 1; else {
	                                                    if (9 <= (d[c[v >> 2] >> 0] | 0 | 0) ? (d[c[v >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                                        E = 1;
	                                                        break
	                                                    }
	                                                    E = (d[c[v >> 2] >> 0] | 0 | 0) == 13
	                                                } while (0);
	                                                F = c[v >> 2] | 0;
	                                                if (!E)break;
	                                                c[v >> 2] = F + 1
	                                            }
	                                            if (!(d[F >> 0] | 0))break
	                                        }
	                                        c[o >> 2] = c[(c[o >> 2] | 0) + 24 >> 2]
	                                    }
	                                    jn(c[h >> 2] | 0, c[k >> 2] | 0, 532, 83904, c[(c[k >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                                    c[p >> 2] = 0
	                                } while (0);
	                                c[o >> 2] = c[(c[k >> 2] | 0) + 12 >> 2];
	                                c[m >> 2] = c[(c[l >> 2] | 0) + 40 >> 2];
	                                c[q >> 2] = Qn(c[h >> 2] | 0, c[o >> 2] | 0, c[l >> 2] | 0, 1, c[k >> 2] | 0) | 0;
	                                if ((c[q >> 2] | 0) > 0)break;
	                                c[p >> 2] = c[q >> 2];
	                                break
	                            } else if ((e | 0) == 3) {
	                                if ((c[(c[l >> 2] | 0) + 40 >> 2] | 0) != 0 ? (c[c[(c[l >> 2] | 0) + 40 >> 2] >> 2] | 0) == 1 : 0) {
	                                    c[p >> 2] = Pn(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                                    if (c[p >> 2] | 0)break;
	                                    jn(c[h >> 2] | 0, c[k >> 2] | 0, 529, 83224, c[(c[k >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                                    break
	                                }
	                                c[o >> 2] = c[(c[k >> 2] | 0) + 12 >> 2];
	                                c:while (1) {
	                                    if (!(c[o >> 2] | 0))break a;
	                                    do if ((c[(c[o >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                                        c[r >> 2] = c[(c[o >> 2] | 0) + 8 >> 2];
	                                        if ((c[(c[o >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                                            c[u >> 2] = Bh(c[(c[o >> 2] | 0) + 8 >> 2] | 0, c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0, t, 50) | 0;
	                                            if (!(c[u >> 2] | 0))break c;
	                                            c[m >> 2] = c[(c[l >> 2] | 0) + 40 >> 2];
	                                            d:while (1) {
	                                                if (!(c[m >> 2] | 0))break;
	                                                b = c[m >> 2] | 0;
	                                                e:do if ((c[c[m >> 2] >> 2] | 0) == 2) {
	                                                    if (qy(c[b + 8 >> 2] | 0, c[u >> 2] | 0) | 0)break d
	                                                } else {
	                                                    do if ((c[b >> 2] | 0) == 4) {
	                                                        if (!(c[(c[m >> 2] | 0) + 12 >> 2] | 0))break;
	                                                        if ((c[c[(c[m >> 2] | 0) + 12 >> 2] >> 2] | 0) != 2)break;
	                                                        if (qy(c[(c[(c[m >> 2] | 0) + 12 >> 2] | 0) + 8 >> 2] | 0, c[u >> 2] | 0) | 0)break d; else break e
	                                                    } while (0);
	                                                    if ((c[c[m >> 2] >> 2] | 0) != 4) {
	                                                        G = 53;
	                                                        break d
	                                                    }
	                                                    if (!(c[(c[m >> 2] | 0) + 12 >> 2] | 0)) {
	                                                        G = 53;
	                                                        break d
	                                                    }
	                                                    if ((c[c[(c[m >> 2] | 0) + 12 >> 2] >> 2] | 0) != 1) {
	                                                        G = 53;
	                                                        break d
	                                                    }
	                                                } while (0);
	                                                c[m >> 2] = c[(c[m >> 2] | 0) + 16 >> 2]
	                                            }
	                                            if ((G | 0) == 53) {
	                                                G = 0;
	                                                mn(0, 519, 83864, 0)
	                                            }
	                                            if ((c[u >> 2] | 0) != (t | 0) ? (c[u >> 2] | 0) != (c[(c[o >> 2] | 0) + 8 >> 2] | 0) : 0)zb[c[135736 >> 2] & 511](c[u >> 2] | 0);
	                                            if (c[m >> 2] | 0)break
	                                        }
	                                        c[m >> 2] = c[(c[l >> 2] | 0) + 40 >> 2];
	                                        f:while (1) {
	                                            if (!(c[m >> 2] | 0))break;
	                                            b = c[m >> 2] | 0;
	                                            g:do if ((c[c[m >> 2] >> 2] | 0) == 2) {
	                                                if (qy(c[b + 8 >> 2] | 0, c[r >> 2] | 0) | 0)break f
	                                            } else {
	                                                do if ((c[b >> 2] | 0) == 4) {
	                                                    if (!(c[(c[m >> 2] | 0) + 12 >> 2] | 0))break;
	                                                    if ((c[c[(c[m >> 2] | 0) + 12 >> 2] >> 2] | 0) != 2)break;
	                                                    if (qy(c[(c[(c[m >> 2] | 0) + 12 >> 2] | 0) + 8 >> 2] | 0, c[r >> 2] | 0) | 0)break f; else break g
	                                                } while (0);
	                                                if ((c[c[m >> 2] >> 2] | 0) != 4) {
	                                                    G = 70;
	                                                    break f
	                                                }
	                                                if (!(c[(c[m >> 2] | 0) + 12 >> 2] | 0)) {
	                                                    G = 70;
	                                                    break f
	                                                }
	                                                if ((c[c[(c[m >> 2] | 0) + 12 >> 2] >> 2] | 0) != 1) {
	                                                    G = 70;
	                                                    break f
	                                                }
	                                            } while (0);
	                                            c[m >> 2] = c[(c[m >> 2] | 0) + 16 >> 2]
	                                        }
	                                        if ((G | 0) == 70) {
	                                            G = 0;
	                                            mn(c[h >> 2] | 0, 519, 83864, 0)
	                                        }
	                                        if (!(c[m >> 2] | 0)) {
	                                            jn(c[h >> 2] | 0, c[k >> 2] | 0, 515, 83288, c[r >> 2] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0, 0);
	                                            c[p >> 2] = 0
	                                        }
	                                    } while (0);
	                                    c[o >> 2] = c[(c[o >> 2] | 0) + 24 >> 2]
	                                }
	                                c[g >> 2] = 0;
	                                D = c[g >> 2] | 0;
	                                i = f;
	                                return D | 0
	                            } else if ((e | 0) == 1) {
	                                if (!(c[(c[k >> 2] | 0) + 12 >> 2] | 0))break;
	                                jn(c[h >> 2] | 0, c[k >> 2] | 0, 528, 83168, c[(c[k >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                                c[p >> 2] = 0;
	                                break
	                            } else break
	                        } while (0);
	                        c[n >> 2] = c[(c[l >> 2] | 0) + 44 >> 2];
	                        while (1) {
	                            if (!(c[n >> 2] | 0))break;
	                            h:do if ((c[(c[n >> 2] | 0) + 44 >> 2] | 0) == 2) {
	                                c[w >> 2] = -1;
	                                i:do if ((c[(c[n >> 2] | 0) + 56 >> 2] | 0) == 0 ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 80392) | 0) != 0 : 0) {
	                                    c[x >> 2] = c[(c[k >> 2] | 0) + 48 >> 2];
	                                    while (1) {
	                                        if (!(c[x >> 2] | 0))break i;
	                                        if (!(c[(c[x >> 2] | 0) + 12 >> 2] | 0))break h;
	                                        c[x >> 2] = c[c[x >> 2] >> 2]
	                                    }
	                                } else G = 100; while (0);
	                                j:do if ((G | 0) == 100) {
	                                    G = 0;
	                                    b = (qy(c[(c[n >> 2] | 0) + 56 >> 2] | 0, 80392) | 0) != 0;
	                                    a = c[k >> 2] | 0;
	                                    if (b) {
	                                        c[y >> 2] = c[a + 48 >> 2];
	                                        while (1) {
	                                            if (!(c[y >> 2] | 0))break j;
	                                            if (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, c[(c[y >> 2] | 0) + 12 >> 2] | 0) | 0)break h;
	                                            c[y >> 2] = c[c[y >> 2] >> 2]
	                                        }
	                                    }
	                                    c[z >> 2] = c[a + 44 >> 2];
	                                    while (1) {
	                                        if (!(c[z >> 2] | 0))break j;
	                                        do if (qy(c[(c[z >> 2] | 0) + 8 >> 2] | 0, c[(c[n >> 2] | 0) + 8 >> 2] | 0) | 0) {
	                                            if (!(c[(c[n >> 2] | 0) + 56 >> 2] | 0))break h;
	                                            c[A >> 2] = c[(c[z >> 2] | 0) + 36 >> 2];
	                                            if (!(c[A >> 2] | 0))c[A >> 2] = c[(c[k >> 2] | 0) + 36 >> 2];
	                                            if (!(c[A >> 2] | 0)) {
	                                                if ((c[w >> 2] | 0) >= 0)break;
	                                                c[w >> 2] = 0;
	                                                break
	                                            }
	                                            if (qy(c[(c[A >> 2] | 0) + 12 >> 2] | 0, c[(c[n >> 2] | 0) + 56 >> 2] | 0) | 0)break h;
	                                            if ((c[w >> 2] | 0) >= 1)break;
	                                            c[w >> 2] = 1
	                                        } while (0);
	                                        c[z >> 2] = c[(c[z >> 2] | 0) + 24 >> 2]
	                                    }
	                                } while (0);
	                                if ((c[w >> 2] | 0) == -1) {
	                                    a = c[h >> 2] | 0;
	                                    b = c[k >> 2] | 0;
	                                    H = c[(c[k >> 2] | 0) + 8 >> 2] | 0;
	                                    I = c[n >> 2] | 0;
	                                    if (!(c[(c[n >> 2] | 0) + 56 >> 2] | 0)) {
	                                        jn(a, b, 518, 83984, H, c[I + 8 >> 2] | 0, 0);
	                                        c[p >> 2] = 0;
	                                        break
	                                    } else {
	                                        jn(a, b, 518, 84024, H, c[I + 56 >> 2] | 0, c[(c[n >> 2] | 0) + 8 >> 2] | 0);
	                                        c[p >> 2] = 0;
	                                        break
	                                    }
	                                }
	                                if (!(c[w >> 2] | 0)) {
	                                    rn(c[h >> 2] | 0, c[k >> 2] | 0, 524, 84072, c[(c[k >> 2] | 0) + 8 >> 2] | 0, c[(c[n >> 2] | 0) + 56 >> 2] | 0, c[(c[n >> 2] | 0) + 8 >> 2] | 0);
	                                    break
	                                }
	                                if ((c[w >> 2] | 0) == 1)rn(c[h >> 2] | 0, c[k >> 2] | 0, 506, 84128, c[(c[k >> 2] | 0) + 8 >> 2] | 0, c[(c[n >> 2] | 0) + 56 >> 2] | 0, c[(c[n >> 2] | 0) + 8 >> 2] | 0)
	                            } else if ((c[(c[n >> 2] | 0) + 44 >> 2] | 0) == 4) {
	                                if ((c[(c[n >> 2] | 0) + 56 >> 2] | 0) == 0 ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 80392) | 0) != 0 : 0) {
	                                    c[B >> 2] = c[(c[k >> 2] | 0) + 48 >> 2];
	                                    while (1) {
	                                        if (!(c[B >> 2] | 0))break h;
	                                        if (!(c[(c[B >> 2] | 0) + 12 >> 2] | 0))break;
	                                        c[B >> 2] = c[c[B >> 2] >> 2]
	                                    }
	                                    if (qy(c[(c[n >> 2] | 0) + 48 >> 2] | 0, c[(c[B >> 2] | 0) + 8 >> 2] | 0) | 0)break;
	                                    jn(c[h >> 2] | 0, c[k >> 2] | 0, 507, 84192, c[(c[k >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                                    c[p >> 2] = 0;
	                                    break
	                                }
	                                if (qy(c[(c[n >> 2] | 0) + 56 >> 2] | 0, 80392) | 0) {
	                                    c[C >> 2] = c[(c[k >> 2] | 0) + 48 >> 2];
	                                    while (1) {
	                                        if (!(c[C >> 2] | 0))break h;
	                                        if (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, c[(c[C >> 2] | 0) + 12 >> 2] | 0) | 0)break;
	                                        c[C >> 2] = c[c[C >> 2] >> 2]
	                                    }
	                                    if (!(qy(c[(c[n >> 2] | 0) + 48 >> 2] | 0, c[(c[C >> 2] | 0) + 8 >> 2] | 0) | 0)) {
	                                        jn(c[h >> 2] | 0, c[k >> 2] | 0, 508, 84264, c[(c[k >> 2] | 0) + 8 >> 2] | 0, c[(c[C >> 2] | 0) + 12 >> 2] | 0, 0);
	                                        c[p >> 2] = 0
	                                    }
	                                }
	                            } while (0);
	                            c[n >> 2] = c[(c[n >> 2] | 0) + 36 >> 2]
	                        }
	                        c[g >> 2] = c[p >> 2];
	                        D = c[g >> 2] | 0;
	                        i = f;
	                        return D | 0
	                    }
	                    case 3:
	                    {
	                        if (c[(c[k >> 2] | 0) + 12 >> 2] | 0) {
	                            jn(c[h >> 2] | 0, c[k >> 2] | 0, 1, 83584, 0, 0, 0);
	                            c[g >> 2] = 0;
	                            D = c[g >> 2] | 0;
	                            i = f;
	                            return D | 0
	                        }
	                        if (c[(c[k >> 2] | 0) + 36 >> 2] | 0) {
	                            jn(c[h >> 2] | 0, c[k >> 2] | 0, 1, 83616, 0, 0, 0);
	                            c[g >> 2] = 0;
	                            D = c[g >> 2] | 0;
	                            i = f;
	                            return D | 0
	                        }
	                        if (!(c[(c[k >> 2] | 0) + 40 >> 2] | 0)) {
	                            jn(c[h >> 2] | 0, c[k >> 2] | 0, 1, 83648, 0, 0, 0);
	                            c[g >> 2] = 0;
	                            D = c[g >> 2] | 0;
	                            i = f;
	                            return D | 0
	                        } else {
	                            c[g >> 2] = 1;
	                            D = c[g >> 2] | 0;
	                            i = f;
	                            return D | 0
	                        }
	                        break
	                    }
	                    case 2:
	                    {
	                        jn(c[h >> 2] | 0, c[k >> 2] | 0, 1, 83552, 0, 0, 0);
	                        c[g >> 2] = 0;
	                        D = c[g >> 2] | 0;
	                        i = f;
	                        return D | 0
	                    }
	                    case 13:
	                    {
	                        jn(c[h >> 2] | 0, c[k >> 2] | 0, 1, 83776, 0, 0, 0);
	                        c[g >> 2] = 0;
	                        D = c[g >> 2] | 0;
	                        i = f;
	                        return D | 0
	                    }
	                    case 12:
	                    {
	                        jn(c[h >> 2] | 0, c[k >> 2] | 0, 1, 83712, 0, 0, 0);
	                        c[g >> 2] = 0;
	                        D = c[g >> 2] | 0;
	                        i = f;
	                        return D | 0
	                    }
	                    default:
	                    {
	                        jn(c[h >> 2] | 0, c[k >> 2] | 0, 1, 83808, 0, 0, 0);
	                        c[g >> 2] = 0;
	                        D = c[g >> 2] | 0;
	                        i = f;
	                        return D | 0
	                    }
	                } while (0);
	                return 0
	            }

	            function an(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 80 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d + 24 | 0;
	                l = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                c[h >> 2] = Pi(c[g >> 2] | 0) | 0;
	                if ((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                    do if (((c[(c[g >> 2] | 0) + 44 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 44 >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (qy(c[(c[(c[g >> 2] | 0) + 44 >> 2] | 0) + 8 >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0) | 0) == 0 : 0) {
	                        if ((c[(c[h >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                            c[l >> 2] = Bh(c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0, k, 50) | 0;
	                            if (!(c[l >> 2] | 0)) {
	                                ln(c[f >> 2] | 0, 0);
	                                c[e >> 2] = 0;
	                                m = c[e >> 2] | 0;
	                                i = d;
	                                return m | 0
	                            }
	                            c[j >> 2] = qy(c[(c[(c[g >> 2] | 0) + 44 >> 2] | 0) + 8 >> 2] | 0, c[l >> 2] | 0) | 0;
	                            if ((c[l >> 2] | 0) != (k | 0) ? (c[l >> 2] | 0) != (c[(c[h >> 2] | 0) + 8 >> 2] | 0) : 0)zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                            if ((c[j >> 2] | 0) == 1)break
	                        }
	                        if ((qy(c[(c[(c[g >> 2] | 0) + 44 >> 2] | 0) + 8 >> 2] | 0, 84352) | 0) != 0 ? (qy(c[(c[h >> 2] | 0) + 8 >> 2] | 0, 84360) | 0) != 0 : 0)break;
	                        jn(c[f >> 2] | 0, c[h >> 2] | 0, 531, 84368, c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[(c[(c[g >> 2] | 0) + 44 >> 2] | 0) + 8 >> 2] | 0, 0);
	                        c[e >> 2] = 0;
	                        m = c[e >> 2] | 0;
	                        i = d;
	                        return m | 0
	                    } while (0);
	                    c[e >> 2] = 1;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                mn(c[f >> 2] | 0, 525, 84328, 0);
	                c[e >> 2] = 0;
	                m = c[e >> 2] | 0;
	                i = d;
	                return m | 0
	            }

	            function bn(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 32 | 0;
	                g = e + 28 | 0;
	                h = e + 24 | 0;
	                j = e + 20 | 0;
	                k = e + 16 | 0;
	                l = e + 12 | 0;
	                m = e + 8 | 0;
	                n = e + 4 | 0;
	                o = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[o >> 2] = 1;
	                if (!(c[j >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    p = c[f >> 2] | 0;
	                    i = e;
	                    return p | 0
	                }
	                if (((c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 19 ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 20 : 0) ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                    if (!(c[h >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        p = c[f >> 2] | 0;
	                        i = e;
	                        return p | 0
	                    }
	                    if ((c[(c[h >> 2] | 0) + 44 >> 2] | 0) == 0 ? (c[(c[h >> 2] | 0) + 48 >> 2] | 0) == 0 : 0) {
	                        c[f >> 2] = 0;
	                        p = c[f >> 2] | 0;
	                        i = e;
	                        return p | 0
	                    }
	                    if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) == 5) {
	                        c[f >> 2] = 1;
	                        p = c[f >> 2] | 0;
	                        i = e;
	                        return p | 0
	                    }
	                    d = $m(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                    c[o >> 2] = c[o >> 2] & d;
	                    a:do if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                        c[l >> 2] = c[(c[j >> 2] | 0) + 44 >> 2];
	                        while (1) {
	                            if (!(c[l >> 2] | 0))break;
	                            c[n >> 2] = _h(c[h >> 2] | 0, c[(c[l >> 2] | 0) + 12 >> 2] | 0, 0) | 0;
	                            d = Wm(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[l >> 2] | 0, c[n >> 2] | 0) | 0;
	                            c[o >> 2] = c[o >> 2] & d;
	                            if (c[n >> 2] | 0)zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                            c[l >> 2] = c[(c[l >> 2] | 0) + 24 >> 2]
	                        }
	                        c[m >> 2] = c[(c[j >> 2] | 0) + 48 >> 2];
	                        while (1) {
	                            if (!(c[m >> 2] | 0))break a;
	                            d = c[g >> 2] | 0;
	                            b = c[h >> 2] | 0;
	                            a = c[j >> 2] | 0;
	                            if (!(c[(c[j >> 2] | 0) + 36 >> 2] | 0)) {
	                                q = Xm(d, b, a, 0, c[m >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0) | 0;
	                                c[o >> 2] = c[o >> 2] & q
	                            } else {
	                                q = Xm(d, b, a, c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0, c[m >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0) | 0;
	                                c[o >> 2] = c[o >> 2] & q
	                            }
	                            c[m >> 2] = c[c[m >> 2] >> 2]
	                        }
	                    } while (0);
	                    c[k >> 2] = c[(c[j >> 2] | 0) + 12 >> 2];
	                    while (1) {
	                        if (!(c[k >> 2] | 0))break;
	                        j = bn(c[g >> 2] | 0, c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                        c[o >> 2] = c[o >> 2] & j;
	                        c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                    }
	                    c[f >> 2] = c[o >> 2];
	                    p = c[f >> 2] | 0;
	                    i = e;
	                    return p | 0
	                }
	                c[f >> 2] = 1;
	                p = c[f >> 2] | 0;
	                i = e;
	                return p | 0
	            }

	            function cn(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                b = c[f >> 2] | 0;
	                if (!(c[g >> 2] | 0)) {
	                    mn(b, 521, 84416, 0);
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                } else {
	                    c[j >> 2] = c[b + 28 >> 2];
	                    c[(c[f >> 2] | 0) + 28 >> 2] = 0;
	                    c[h >> 2] = c[(c[g >> 2] | 0) + 68 >> 2];
	                    c[(c[f >> 2] | 0) + 32 >> 2] = c[g >> 2];
	                    c[(c[f >> 2] | 0) + 36 >> 2] = 1;
	                    Wj(c[h >> 2] | 0, 254, c[f >> 2] | 0);
	                    c[(c[f >> 2] | 0) + 28 >> 2] = c[j >> 2];
	                    c[e >> 2] = c[(c[f >> 2] | 0) + 36 >> 2];
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                return 0
	            }

	            function dn(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 28 | 0;
	                g = e + 24 | 0;
	                h = e + 20 | 0;
	                j = e + 16 | 0;
	                k = e + 12 | 0;
	                l = e + 8 | 0;
	                m = e + 4 | 0;
	                n = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (!(c[j >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                c[l >> 2] = c[(c[h >> 2] | 0) + 48 >> 2];
	                c[m >> 2] = c[(c[h >> 2] | 0) + 44 >> 2];
	                c[(c[h >> 2] | 0) + 48 >> 2] = c[j >> 2];
	                c[(c[h >> 2] | 0) + 44 >> 2] = 0;
	                c[k >> 2] = an(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[(c[h >> 2] | 0) + 48 >> 2] = c[l >> 2];
	                    c[(c[h >> 2] | 0) + 44 >> 2] = c[m >> 2];
	                    c[f >> 2] = c[k >> 2];
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                if (c[(c[h >> 2] | 0) + 64 >> 2] | 0) {
	                    Dm(c[(c[h >> 2] | 0) + 64 >> 2] | 0);
	                    c[(c[h >> 2] | 0) + 64 >> 2] = 0
	                }
	                if (c[(c[h >> 2] | 0) + 68 >> 2] | 0) {
	                    Jm(c[(c[h >> 2] | 0) + 68 >> 2] | 0);
	                    c[(c[h >> 2] | 0) + 68 >> 2] = 0
	                }
	                c[n >> 2] = Pi(c[h >> 2] | 0) | 0;
	                c[k >> 2] = bn(c[g >> 2] | 0, c[h >> 2] | 0, c[n >> 2] | 0) | 0;
	                n = cn(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                c[k >> 2] = c[k >> 2] & n;
	                c[(c[h >> 2] | 0) + 48 >> 2] = c[l >> 2];
	                c[(c[h >> 2] | 0) + 44 >> 2] = c[m >> 2];
	                c[f >> 2] = c[k >> 2];
	                o = c[f >> 2] | 0;
	                i = e;
	                return o | 0
	            }

	            function en(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[g >> 2] | 0) == 0 | (c[f >> 2] | 0) == 0) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                if ((c[(c[g >> 2] | 0) + 44 >> 2] | 0) == 0 ? (c[(c[g >> 2] | 0) + 48 >> 2] | 0) == 0 : 0) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                c[(c[f >> 2] | 0) + 32 >> 2] = c[g >> 2];
	                c[(c[f >> 2] | 0) + 36 >> 2] = 1;
	                c[h >> 2] = c[(c[g >> 2] | 0) + 44 >> 2];
	                if ((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 44 >> 2] | 0) != 0 : 0) {
	                    c[j >> 2] = c[(c[h >> 2] | 0) + 44 >> 2];
	                    Wj(c[j >> 2] | 0, 255, c[f >> 2] | 0)
	                }
	                if ((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 48 >> 2] | 0) != 0 : 0) {
	                    c[k >> 2] = c[(c[h >> 2] | 0) + 48 >> 2];
	                    Wj(c[k >> 2] | 0, 256, c[f >> 2] | 0)
	                }
	                c[h >> 2] = c[(c[g >> 2] | 0) + 48 >> 2];
	                if ((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 44 >> 2] | 0) != 0 : 0) {
	                    c[j >> 2] = c[(c[h >> 2] | 0) + 44 >> 2];
	                    Wj(c[j >> 2] | 0, 255, c[f >> 2] | 0)
	                }
	                if ((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 48 >> 2] | 0) != 0 : 0) {
	                    c[k >> 2] = c[(c[h >> 2] | 0) + 48 >> 2];
	                    Wj(c[k >> 2] | 0, 256, c[f >> 2] | 0)
	                }
	                c[e >> 2] = c[(c[f >> 2] | 0) + 36 >> 2];
	                l = c[e >> 2] | 0;
	                i = d;
	                return l | 0
	            }

	            function fn(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                if ((c[(c[g >> 2] | 0) + 44 >> 2] | 0) == 0 ? (c[(c[g >> 2] | 0) + 48 >> 2] | 0) == 0 : 0) {
	                    mn(c[f >> 2] | 0, 522, 84456, 0);
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                do if (c[(c[g >> 2] | 0) + 44 >> 2] | 0) {
	                    if ((c[(c[(c[g >> 2] | 0) + 44 >> 2] | 0) + 56 >> 2] | 0) == 0 ? (c[(c[(c[g >> 2] | 0) + 44 >> 2] | 0) + 52 >> 2] | 0) == 0 : 0)break;
	                    if (!(c[(c[g >> 2] | 0) + 48 >> 2] | 0)) {
	                        if (c[(c[(c[g >> 2] | 0) + 44 >> 2] | 0) + 56 >> 2] | 0) {
	                            c[k >> 2] = Hl(c[(c[(c[g >> 2] | 0) + 44 >> 2] | 0) + 56 >> 2] | 0, c[(c[g >> 2] | 0) + 72 >> 2] | 0) | 0;
	                            if (!(c[k >> 2] | 0)) {
	                                mn(c[f >> 2] | 0, 517, 84472, c[(c[(c[g >> 2] | 0) + 44 >> 2] | 0) + 56 >> 2] | 0);
	                                c[e >> 2] = 0;
	                                l = c[e >> 2] | 0;
	                                i = d;
	                                return l | 0
	                            }
	                        } else c[k >> 2] = 0;
	                        b = Wf(c[(c[(c[g >> 2] | 0) + 44 >> 2] | 0) + 52 >> 2] | 0, c[k >> 2] | 0) | 0;
	                        c[(c[g >> 2] | 0) + 48 >> 2] = b;
	                        if (c[k >> 2] | 0)zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                        if (!(c[(c[g >> 2] | 0) + 48 >> 2] | 0)) {
	                            b = c[f >> 2] | 0;
	                            a = c[(c[g >> 2] | 0) + 44 >> 2] | 0;
	                            if (c[(c[(c[g >> 2] | 0) + 44 >> 2] | 0) + 56 >> 2] | 0)mn(b, 517, 84520, c[a + 56 >> 2] | 0); else mn(b, 517, 84520, c[a + 52 >> 2] | 0);
	                            c[e >> 2] = 0;
	                            l = c[e >> 2] | 0;
	                            i = d;
	                            return l | 0
	                        }
	                    }
	                } while (0);
	                if (c[(c[g >> 2] | 0) + 64 >> 2] | 0) {
	                    Dm(c[(c[g >> 2] | 0) + 64 >> 2] | 0);
	                    c[(c[g >> 2] | 0) + 64 >> 2] = 0
	                }
	                if (c[(c[g >> 2] | 0) + 68 >> 2] | 0) {
	                    Jm(c[(c[g >> 2] | 0) + 68 >> 2] | 0);
	                    c[(c[g >> 2] | 0) + 68 >> 2] = 0
	                }
	                c[h >> 2] = en(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                if (an(c[f >> 2] | 0, c[g >> 2] | 0) | 0) {
	                    c[j >> 2] = Pi(c[g >> 2] | 0) | 0;
	                    k = bn(c[f >> 2] | 0, c[g >> 2] | 0, c[j >> 2] | 0) | 0;
	                    c[h >> 2] = c[h >> 2] & k;
	                    k = cn(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                    c[h >> 2] = c[h >> 2] & k;
	                    c[e >> 2] = c[h >> 2];
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                } else {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                return 0
	            }

	            function gn(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0) {
	                    c[g >> 2] = -1;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                if ((c[c[k >> 2] >> 2] | 0) >= (c[l >> 2] | 0)) {
	                    c[g >> 2] = c[c[k >> 2] >> 2];
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                e = c[c[h >> 2] >> 2] | 0;
	                do if ((e | 0) == 4) {
	                    gn(c[(c[h >> 2] | 0) + 12 >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0;
	                    gn(c[(c[h >> 2] | 0) + 16 >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0
	                } else if ((e | 0) == 2) {
	                    c[m >> 2] = 0;
	                    while (1) {
	                        o = c[(c[h >> 2] | 0) + 8 >> 2] | 0;
	                        if ((c[m >> 2] | 0) >= (c[c[k >> 2] >> 2] | 0)) {
	                            p = 17;
	                            break
	                        }
	                        if (qy(o, c[(c[j >> 2] | 0) + (c[m >> 2] << 2) >> 2] | 0) | 0)break;
	                        c[m >> 2] = (c[m >> 2] | 0) + 1
	                    }
	                    if ((p | 0) == 17) {
	                        d = c[k >> 2] | 0;
	                        b = c[d >> 2] | 0;
	                        c[d >> 2] = b + 1;
	                        c[(c[j >> 2] | 0) + (b << 2) >> 2] = o;
	                        break
	                    }
	                    c[g >> 2] = c[c[k >> 2] >> 2];
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                } else if ((e | 0) == 1) {
	                    c[m >> 2] = 0;
	                    while (1) {
	                        if ((c[m >> 2] | 0) >= (c[c[k >> 2] >> 2] | 0)) {
	                            p = 11;
	                            break
	                        }
	                        if (qy(79640, c[(c[j >> 2] | 0) + (c[m >> 2] << 2) >> 2] | 0) | 0)break;
	                        c[m >> 2] = (c[m >> 2] | 0) + 1
	                    }
	                    if ((p | 0) == 11) {
	                        b = c[k >> 2] | 0;
	                        d = c[b >> 2] | 0;
	                        c[b >> 2] = d + 1;
	                        c[(c[j >> 2] | 0) + (d << 2) >> 2] = 79640;
	                        break
	                    }
	                    c[g >> 2] = c[c[k >> 2] >> 2];
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                } else if ((e | 0) == 3) {
	                    gn(c[(c[h >> 2] | 0) + 12 >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0;
	                    gn(c[(c[h >> 2] | 0) + 16 >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0
	                } while (0);
	                c[g >> 2] = c[c[k >> 2] >> 2];
	                n = c[g >> 2] | 0;
	                i = f;
	                return n | 0
	            }

	            function hn(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0;
	                f = i;
	                i = i + 1168 | 0;
	                g = f + 1160 | 0;
	                h = f + 1156 | 0;
	                j = f + 1152 | 0;
	                k = f + 1148 | 0;
	                l = f + 1144 | 0;
	                m = f + 1080 | 0;
	                n = f + 1072 | 0;
	                o = f + 48 | 0;
	                p = f + 44 | 0;
	                q = f + 40 | 0;
	                r = f + 36 | 0;
	                s = f + 32 | 0;
	                t = f + 28 | 0;
	                u = f + 24 | 0;
	                v = f + 20 | 0;
	                w = f + 16 | 0;
	                x = f + 12 | 0;
	                y = f + 8 | 0;
	                z = f + 4 | 0;
	                A = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[n >> 2] = 0;
	                cU(o | 0, 0, 1024) | 0;
	                c[p >> 2] = 0;
	                if ((c[h >> 2] | 0) == 0 & (c[j >> 2] | 0) == 0) {
	                    c[g >> 2] = -1;
	                    B = c[g >> 2] | 0;
	                    i = f;
	                    return B | 0
	                }
	                if (!(c[k >> 2] | 0)) {
	                    c[g >> 2] = -1;
	                    B = c[g >> 2] | 0;
	                    i = f;
	                    return B | 0
	                }
	                if ((c[l >> 2] | 0) <= 0) {
	                    c[g >> 2] = -1;
	                    B = c[g >> 2] | 0;
	                    i = f;
	                    return B | 0
	                }
	                e = m + 0 | 0;
	                d = e + 64 | 0;
	                do {
	                    c[e >> 2] = 0;
	                    e = e + 4 | 0
	                } while ((e | 0) < (d | 0));
	                c[m + 4 >> 2] = 257;
	                c[n >> 2] = 0;
	                c[s >> 2] = (c[h >> 2] | 0) != 0 ? c[h >> 2] | 0 : c[j >> 2] | 0;
	                c[t >> 2] = c[(c[s >> 2] | 0) + 20 >> 2];
	                c[z >> 2] = Lm(c[(c[(c[t >> 2] | 0) + 32 >> 2] | 0) + 44 >> 2] | 0, c[(c[t >> 2] | 0) + 8 >> 2] | 0) | 0;
	                if ((c[z >> 2] | 0) == 0 ? (c[(c[(c[t >> 2] | 0) + 32 >> 2] | 0) + 48 >> 2] | 0) != 0 : 0)c[z >> 2] = Lm(c[(c[(c[t >> 2] | 0) + 32 >> 2] | 0) + 48 >> 2] | 0, c[(c[t >> 2] | 0) + 8 >> 2] | 0) | 0;
	                if (!(c[z >> 2] | 0)) {
	                    c[g >> 2] = -1;
	                    B = c[g >> 2] | 0;
	                    i = f;
	                    return B | 0
	                }
	                if (c[h >> 2] | 0)C = c[(c[h >> 2] | 0) + 24 >> 2] | 0; else C = 0;
	                c[v >> 2] = C;
	                if (c[j >> 2] | 0)D = c[(c[j >> 2] | 0) + 28 >> 2] | 0; else D = 0;
	                c[w >> 2] = D;
	                c[x >> 2] = c[(c[t >> 2] | 0) + 12 >> 2];
	                c[y >> 2] = c[(c[t >> 2] | 0) + 16 >> 2];
	                c[u >> 2] = ji(c[(c[s >> 2] | 0) + 32 >> 2] | 0, 0, 84568, 0) | 0;
	                if (!(c[u >> 2] | 0)) {
	                    c[g >> 2] = -1;
	                    B = c[g >> 2] | 0;
	                    i = f;
	                    return B | 0
	                }
	                c[(c[u >> 2] | 0) + 20 >> 2] = c[t >> 2];
	                c[(c[u >> 2] | 0) + 28 >> 2] = c[h >> 2];
	                c[(c[u >> 2] | 0) + 24 >> 2] = c[j >> 2];
	                c[r >> 2] = c[(c[u >> 2] | 0) + 8 >> 2];
	                s = c[u >> 2] | 0;
	                if (c[h >> 2] | 0)c[(c[h >> 2] | 0) + 24 >> 2] = s; else c[(c[t >> 2] | 0) + 12 >> 2] = s;
	                s = c[u >> 2] | 0;
	                if (c[j >> 2] | 0)c[(c[j >> 2] | 0) + 28 >> 2] = s; else c[(c[t >> 2] | 0) + 16 >> 2] = s;
	                c[p >> 2] = gn(c[(c[z >> 2] | 0) + 40 >> 2] | 0, o, p, 256) | 0;
	                c[q >> 2] = 0;
	                while (1) {
	                    if ((c[q >> 2] | 0) >= (c[p >> 2] | 0))break;
	                    c[(c[u >> 2] | 0) + 8 >> 2] = c[o + (c[q >> 2] << 2) >> 2];
	                    if ($m(m, c[(c[t >> 2] | 0) + 32 >> 2] | 0, c[t >> 2] | 0) | 0) {
	                        c[A >> 2] = 0;
	                        while (1) {
	                            if ((c[A >> 2] | 0) >= (c[n >> 2] | 0))break;
	                            if (qy(c[o + (c[q >> 2] << 2) >> 2] | 0, c[(c[k >> 2] | 0) + (c[A >> 2] << 2) >> 2] | 0) | 0)break;
	                            c[A >> 2] = (c[A >> 2] | 0) + 1
	                        }
	                        z = c[o + (c[q >> 2] << 2) >> 2] | 0;
	                        s = c[n >> 2] | 0;
	                        c[n >> 2] = s + 1;
	                        c[(c[k >> 2] | 0) + (s << 2) >> 2] = z;
	                        if ((c[n >> 2] | 0) >= (c[l >> 2] | 0))break
	                    }
	                    c[q >> 2] = (c[q >> 2] | 0) + 1
	                }
	                if (c[h >> 2] | 0)c[(c[h >> 2] | 0) + 24 >> 2] = c[v >> 2];
	                if (c[j >> 2] | 0)c[(c[j >> 2] | 0) + 28 >> 2] = c[w >> 2];
	                c[(c[t >> 2] | 0) + 12 >> 2] = c[x >> 2];
	                c[(c[t >> 2] | 0) + 16 >> 2] = c[y >> 2];
	                c[(c[u >> 2] | 0) + 8 >> 2] = c[r >> 2];
	                Rh(c[u >> 2] | 0);
	                c[g >> 2] = c[n >> 2];
	                B = c[g >> 2] | 0;
	                i = f;
	                return B | 0
	            }

	            function jn(a, b, d, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0;
	                j = i;
	                i = i + 64 | 0;
	                k = j;
	                l = j + 56 | 0;
	                m = j + 52 | 0;
	                n = j + 48 | 0;
	                o = j + 44 | 0;
	                p = j + 40 | 0;
	                q = j + 36 | 0;
	                r = j + 32 | 0;
	                s = j + 28 | 0;
	                t = j + 24 | 0;
	                u = j + 20 | 0;
	                v = j + 16 | 0;
	                w = j + 12 | 0;
	                c[l >> 2] = a;
	                c[m >> 2] = b;
	                c[n >> 2] = d;
	                c[o >> 2] = e;
	                c[p >> 2] = f;
	                c[q >> 2] = g;
	                c[r >> 2] = h;
	                c[s >> 2] = 0;
	                c[t >> 2] = 0;
	                c[u >> 2] = 0;
	                c[v >> 2] = 0;
	                do if (c[l >> 2] | 0) {
	                    c[t >> 2] = c[(c[l >> 2] | 0) + 4 >> 2];
	                    c[v >> 2] = c[c[l >> 2] >> 2];
	                    if ((c[(c[l >> 2] | 0) + 28 >> 2] | 0) != -1412623820 ? (c[(c[l >> 2] | 0) + 28 >> 2] | 0) != -1412623819 : 0)break;
	                    c[w >> 2] = (c[l >> 2] | 0) - (c[c[l >> 2] >> 2] | 0);
	                    if ((c[w >> 2] | 0) > 0 & (c[w >> 2] | 0) < 250)c[u >> 2] = c[c[l >> 2] >> 2]
	                } while (0);
	                l = c[s >> 2] | 0;
	                s = c[t >> 2] | 0;
	                t = c[v >> 2] | 0;
	                v = c[u >> 2] | 0;
	                u = c[m >> 2] | 0;
	                m = c[n >> 2] | 0;
	                n = c[p >> 2] | 0;
	                w = c[p >> 2] | 0;
	                h = c[r >> 2] | 0;
	                g = c[o >> 2] | 0;
	                o = c[q >> 2] | 0;
	                q = c[r >> 2] | 0;
	                c[k >> 2] = c[p >> 2];
	                c[k + 4 >> 2] = o;
	                c[k + 8 >> 2] = q;
	                Xd(l, s, t, v, u, 23, m, 2, 0, 0, n, w, h, 0, 0, g, k);
	                i = j;
	                return
	            }

	            function kn(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                e = i;
	                i = i + 112 | 0;
	                f = e + 44 | 0;
	                g = e + 40 | 0;
	                h = e + 36 | 0;
	                j = e + 32 | 0;
	                k = e + 28 | 0;
	                l = e + 48 | 0;
	                m = e + 24 | 0;
	                n = e + 20 | 0;
	                o = e + 16 | 0;
	                p = e + 12 | 0;
	                q = e + 8 | 0;
	                r = e + 4 | 0;
	                s = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (!(c[g >> 2] | 0)) {
	                    jn(c[h >> 2] | 0, 0, 1, 85712, c[j >> 2] | 0, 0, 0);
	                    c[f >> 2] = 0;
	                    t = c[f >> 2] | 0;
	                    i = e;
	                    return t | 0
	                }
	                d = c[c[g >> 2] >> 2] | 0;
	                do if ((d | 0) == 2) {
	                    c[k >> 2] = c[(c[h >> 2] | 0) + 60 >> 2];
	                    c[m >> 2] = Bh(c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[(c[g >> 2] | 0) + 24 >> 2] | 0, l, 50) | 0;
	                    if (!(c[m >> 2] | 0)) {
	                        ln(c[h >> 2] | 0, 85800);
	                        c[f >> 2] = 0;
	                        t = c[f >> 2] | 0;
	                        i = e;
	                        return t | 0
	                    }
	                    b = c[(c[g >> 2] | 0) + 4 >> 2] | 0;
	                    if ((b | 0) == 4) {
	                        a = Dz(c[(c[h >> 2] | 0) + 56 >> 2] | 0, c[(c[h >> 2] | 0) + 60 >> 2] | 0, 0, c[m >> 2] | 0, 0) | 0;
	                        c[(c[h >> 2] | 0) + 60 >> 2] = a;
	                        Dz(c[(c[h >> 2] | 0) + 56 >> 2] | 0, c[(c[h >> 2] | 0) + 60 >> 2] | 0, c[(c[h >> 2] | 0) + 60 >> 2] | 0, c[m >> 2] | 0, 0) | 0
	                    } else if ((b | 0) == 1) {
	                        a = Dz(c[(c[h >> 2] | 0) + 56 >> 2] | 0, c[(c[h >> 2] | 0) + 60 >> 2] | 0, 0, c[m >> 2] | 0, 0) | 0;
	                        c[(c[h >> 2] | 0) + 60 >> 2] = a
	                    } else if ((b | 0) == 2) {
	                        a = Dz(c[(c[h >> 2] | 0) + 56 >> 2] | 0, c[(c[h >> 2] | 0) + 60 >> 2] | 0, 0, c[m >> 2] | 0, 0) | 0;
	                        c[(c[h >> 2] | 0) + 60 >> 2] = a;
	                        Jz(c[(c[h >> 2] | 0) + 56 >> 2] | 0, c[k >> 2] | 0, c[(c[h >> 2] | 0) + 60 >> 2] | 0) | 0
	                    } else if ((b | 0) == 3) {
	                        b = Jz(c[(c[h >> 2] | 0) + 56 >> 2] | 0, c[(c[h >> 2] | 0) + 60 >> 2] | 0, 0) | 0;
	                        c[(c[h >> 2] | 0) + 60 >> 2] = b;
	                        Dz(c[(c[h >> 2] | 0) + 56 >> 2] | 0, c[(c[h >> 2] | 0) + 60 >> 2] | 0, c[(c[h >> 2] | 0) + 60 >> 2] | 0, c[m >> 2] | 0, 0) | 0
	                    }
	                    if ((c[m >> 2] | 0) != (l | 0) ? (c[m >> 2] | 0) != (c[(c[g >> 2] | 0) + 8 >> 2] | 0) : 0)zb[c[135736 >> 2] & 511](c[m >> 2] | 0)
	                } else if ((d | 0) == 4) {
	                    c[s >> 2] = c[(c[g >> 2] | 0) + 4 >> 2];
	                    if ((c[s >> 2] | 0) == 4 | (c[s >> 2] | 0) == 3) {
	                        b = Jz(c[(c[h >> 2] | 0) + 56 >> 2] | 0, c[(c[h >> 2] | 0) + 60 >> 2] | 0, 0) | 0;
	                        c[(c[h >> 2] | 0) + 60 >> 2] = b
	                    }
	                    c[q >> 2] = c[(c[h >> 2] | 0) + 60 >> 2];
	                    c[r >> 2] = Iz(c[(c[h >> 2] | 0) + 56 >> 2] | 0) | 0;
	                    do {
	                        c[(c[h >> 2] | 0) + 60 >> 2] = c[q >> 2];
	                        kn(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                        Jz(c[(c[h >> 2] | 0) + 56 >> 2] | 0, c[(c[h >> 2] | 0) + 60 >> 2] | 0, c[r >> 2] | 0) | 0;
	                        c[g >> 2] = c[(c[g >> 2] | 0) + 16 >> 2];
	                        if ((c[c[g >> 2] >> 2] | 0) != 4)break
	                    } while ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1);
	                    c[(c[h >> 2] | 0) + 60 >> 2] = c[q >> 2];
	                    kn(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                    Jz(c[(c[h >> 2] | 0) + 56 >> 2] | 0, c[(c[h >> 2] | 0) + 60 >> 2] | 0, c[r >> 2] | 0) | 0;
	                    b = Jz(c[(c[h >> 2] | 0) + 56 >> 2] | 0, c[r >> 2] | 0, 0) | 0;
	                    c[(c[h >> 2] | 0) + 60 >> 2] = b;
	                    b = c[s >> 2] | 0;
	                    if ((b | 0) == 3) {
	                        Jz(c[(c[h >> 2] | 0) + 56 >> 2] | 0, c[q >> 2] | 0, c[(c[h >> 2] | 0) + 60 >> 2] | 0) | 0;
	                        Jz(c[(c[h >> 2] | 0) + 56 >> 2] | 0, c[r >> 2] | 0, c[q >> 2] | 0) | 0;
	                        break
	                    } else if ((b | 0) == 4) {
	                        Jz(c[(c[h >> 2] | 0) + 56 >> 2] | 0, c[r >> 2] | 0, c[q >> 2] | 0) | 0;
	                        break
	                    } else if ((b | 0) == 2) {
	                        Jz(c[(c[h >> 2] | 0) + 56 >> 2] | 0, c[q >> 2] | 0, c[(c[h >> 2] | 0) + 60 >> 2] | 0) | 0;
	                        break
	                    } else break
	                } else if ((d | 0) == 1) {
	                    jn(c[h >> 2] | 0, 0, 1, 85760, c[j >> 2] | 0, 0, 0);
	                    c[f >> 2] = 0;
	                    t = c[f >> 2] | 0;
	                    i = e;
	                    return t | 0
	                } else if ((d | 0) == 3) {
	                    c[n >> 2] = c[(c[h >> 2] | 0) + 60 >> 2];
	                    c[p >> 2] = c[(c[g >> 2] | 0) + 4 >> 2];
	                    if ((c[p >> 2] | 0) != 1) {
	                        b = Jz(c[(c[h >> 2] | 0) + 56 >> 2] | 0, c[n >> 2] | 0, 0) | 0;
	                        c[(c[h >> 2] | 0) + 60 >> 2] = b;
	                        c[n >> 2] = c[(c[h >> 2] | 0) + 60 >> 2]
	                    }
	                    do {
	                        kn(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                        c[g >> 2] = c[(c[g >> 2] | 0) + 16 >> 2];
	                        if ((c[c[g >> 2] >> 2] | 0) != 3)break
	                    } while ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1);
	                    kn(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                    c[o >> 2] = c[(c[h >> 2] | 0) + 60 >> 2];
	                    b = Jz(c[(c[h >> 2] | 0) + 56 >> 2] | 0, c[o >> 2] | 0, 0) | 0;
	                    c[(c[h >> 2] | 0) + 60 >> 2] = b;
	                    b = c[p >> 2] | 0;
	                    if ((b | 0) == 3) {
	                        Jz(c[(c[h >> 2] | 0) + 56 >> 2] | 0, c[n >> 2] | 0, c[(c[h >> 2] | 0) + 60 >> 2] | 0) | 0;
	                        Jz(c[(c[h >> 2] | 0) + 56 >> 2] | 0, c[o >> 2] | 0, c[n >> 2] | 0) | 0;
	                        break
	                    } else if ((b | 0) == 2) {
	                        Jz(c[(c[h >> 2] | 0) + 56 >> 2] | 0, c[n >> 2] | 0, c[(c[h >> 2] | 0) + 60 >> 2] | 0) | 0;
	                        break
	                    } else if ((b | 0) == 4) {
	                        Jz(c[(c[h >> 2] | 0) + 56 >> 2] | 0, c[o >> 2] | 0, c[n >> 2] | 0) | 0;
	                        break
	                    } else break
	                } else {
	                    mn(c[h >> 2] | 0, 1, 85824, c[j >> 2] | 0);
	                    c[f >> 2] = 0;
	                    t = c[f >> 2] | 0;
	                    i = e;
	                    return t | 0
	                } while (0);
	                c[f >> 2] = 1;
	                t = c[f >> 2] | 0;
	                i = e;
	                return t | 0
	            }

	            function ln(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 24 | 0;
	                g = d + 20 | 0;
	                h = d + 16 | 0;
	                j = d + 12 | 0;
	                k = d + 8 | 0;
	                l = d + 4 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                c[j >> 2] = 0;
	                c[k >> 2] = 0;
	                do if (c[f >> 2] | 0) {
	                    c[h >> 2] = c[(c[f >> 2] | 0) + 4 >> 2];
	                    c[k >> 2] = c[c[f >> 2] >> 2];
	                    if ((c[(c[f >> 2] | 0) + 28 >> 2] | 0) != -1412623820 ? (c[(c[f >> 2] | 0) + 28 >> 2] | 0) != -1412623819 : 0)break;
	                    c[l >> 2] = (c[f >> 2] | 0) - (c[c[f >> 2] >> 2] | 0);
	                    if ((c[l >> 2] | 0) > 0 & (c[l >> 2] | 0) < 250)c[j >> 2] = c[c[f >> 2] >> 2]
	                } while (0);
	                f = c[h >> 2] | 0;
	                h = c[k >> 2] | 0;
	                k = c[j >> 2] | 0;
	                if (c[g >> 2] | 0) {
	                    j = c[g >> 2] | 0;
	                    c[e >> 2] = c[g >> 2];
	                    Xd(0, f, h, k, 0, 23, 2, 3, 0, 0, j, 0, 0, 0, 0, 85648, e);
	                    i = d;
	                    return
	                } else {
	                    Xd(0, f, h, k, 0, 23, 2, 3, 0, 0, 0, 0, 0, 0, 0, 85680, e);
	                    i = d;
	                    return
	                }
	            }

	            function mn(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f;
	                h = f + 32 | 0;
	                j = f + 28 | 0;
	                k = f + 24 | 0;
	                l = f + 20 | 0;
	                m = f + 16 | 0;
	                n = f + 12 | 0;
	                o = f + 8 | 0;
	                p = f + 4 | 0;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = 0;
	                c[n >> 2] = 0;
	                c[o >> 2] = 0;
	                do if (c[h >> 2] | 0) {
	                    c[m >> 2] = c[(c[h >> 2] | 0) + 4 >> 2];
	                    c[o >> 2] = c[c[h >> 2] >> 2];
	                    if ((c[(c[h >> 2] | 0) + 28 >> 2] | 0) != -1412623820 ? (c[(c[h >> 2] | 0) + 28 >> 2] | 0) != -1412623819 : 0)break;
	                    c[p >> 2] = (c[h >> 2] | 0) - (c[c[h >> 2] >> 2] | 0);
	                    if ((c[p >> 2] | 0) > 0 & (c[p >> 2] | 0) < 250)c[n >> 2] = c[c[h >> 2] >> 2]
	                } while (0);
	                h = c[m >> 2] | 0;
	                m = c[o >> 2] | 0;
	                o = c[n >> 2] | 0;
	                n = c[j >> 2] | 0;
	                if (c[l >> 2] | 0) {
	                    j = c[l >> 2] | 0;
	                    p = c[k >> 2] | 0;
	                    c[g >> 2] = c[l >> 2];
	                    Xd(0, h, m, o, 0, 23, n, 2, 0, 0, j, 0, 0, 0, 0, p, g);
	                    i = f;
	                    return
	                } else {
	                    c[g >> 2] = c[k >> 2];
	                    Xd(0, h, m, o, 0, 23, n, 2, 0, 0, 0, 0, 0, 0, 0, 85640, g);
	                    i = f;
	                    return
	                }
	            }

	            function nn(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                Qh(c[d >> 2] | 0);
	                lm(c[(c[d >> 2] | 0) + 32 >> 2] | 0, c[(c[d >> 2] | 0) + 40 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 8 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 48 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 48 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 52 >> 2] | 0)zz(c[(c[d >> 2] | 0) + 52 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function on(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](56) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    ln(0, 79472);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = (c[f >> 2] | 0) + 0 | 0;
	                h = a + 56 | 0;
	                do {
	                    c[a >> 2] = 0;
	                    a = a + 4 | 0
	                } while ((a | 0) < (h | 0));
	                c[(c[f >> 2] | 0) + 4 >> 2] = 15;
	                c[(c[f >> 2] | 0) + 36 >> 2] = c[(c[e >> 2] | 0) + 36 >> 2];
	                if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                    a = my(c[(c[e >> 2] | 0) + 8 >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 8 >> 2] = a
	                } else c[(c[f >> 2] | 0) + 8 >> 2] = 0;
	                if (c[(c[e >> 2] | 0) + 48 >> 2] | 0) {
	                    a = my(c[(c[e >> 2] | 0) + 48 >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 48 >> 2] = a
	                } else c[(c[f >> 2] | 0) + 48 >> 2] = 0;
	                a = km(c[(c[e >> 2] | 0) + 40 >> 2] | 0) | 0;
	                c[(c[f >> 2] | 0) + 40 >> 2] = a;
	                c[(c[f >> 2] | 0) + 44 >> 2] = 0;
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function pn(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if (!(c[g >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                if (c[h >> 2] | 0)rj(c[f >> 2] | 0, 79632);
	                d = c[c[g >> 2] >> 2] | 0;
	                a:do if ((d | 0) == 1)rj(c[f >> 2] | 0, 79640); else if ((d | 0) == 4) {
	                    if ((c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2] | 0) != 4 ? (c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2] | 0) != 3 : 0)pn(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] | 0, 0); else pn(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] | 0, 1);
	                    rj(c[f >> 2] | 0, 79664);
	                    do if ((c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) != 3) {
	                        if ((c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) == 4 ? (c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) != 1 : 0)break;
	                        pn(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 16 >> 2] | 0, 0);
	                        break a
	                    } while (0);
	                    pn(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 16 >> 2] | 0, 1)
	                } else if ((d | 0) == 2) {
	                    if (c[(c[g >> 2] | 0) + 24 >> 2] | 0) {
	                        qj(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 24 >> 2] | 0);
	                        rj(c[f >> 2] | 0, 79648)
	                    }
	                    qj(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0)
	                } else if ((d | 0) == 3) {
	                    if ((c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2] | 0) != 4 ? (c[c[(c[g >> 2] | 0) + 12 >> 2] >> 2] | 0) != 3 : 0)pn(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] | 0, 0); else pn(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] | 0, 1);
	                    rj(c[f >> 2] | 0, 79656);
	                    do if ((c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) != 4) {
	                        if ((c[c[(c[g >> 2] | 0) + 16 >> 2] >> 2] | 0) == 3 ? (c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) != 1 : 0)break;
	                        pn(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 16 >> 2] | 0, 0);
	                        break a
	                    } while (0);
	                    pn(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 16 >> 2] | 0, 1)
	                } else mn(0, 1, 79568, 0); while (0);
	                if (c[h >> 2] | 0)rj(c[f >> 2] | 0, 79672);
	                h = c[(c[g >> 2] | 0) + 4 >> 2] | 0;
	                if ((h | 0) == 2) {
	                    rj(c[f >> 2] | 0, 79680);
	                    i = e;
	                    return
	                } else if ((h | 0) == 3) {
	                    rj(c[f >> 2] | 0, 79688);
	                    i = e;
	                    return
	                } else if ((h | 0) == 4) {
	                    rj(c[f >> 2] | 0, 79696);
	                    i = e;
	                    return
	                } else {
	                    i = e;
	                    return
	                }
	            }

	            function qn(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                switch (c[h >> 2] | 0) {
	                    case 10:
	                    case 2:
	                    case 3:
	                    case 5:
	                    {
	                        c[f >> 2] = En(c[g >> 2] | 0, c[j >> 2] | 0) | 0;
	                        break
	                    }
	                    case 7:
	                    {
	                        c[f >> 2] = Gn(c[g >> 2] | 0, c[j >> 2] | 0) | 0;
	                        break
	                    }
	                    case 4:
	                    case 6:
	                    {
	                        c[f >> 2] = Fn(c[g >> 2] | 0, c[j >> 2] | 0) | 0;
	                        break
	                    }
	                    case 9:
	                    case 8:
	                    {
	                        c[f >> 2] = Hn(c[g >> 2] | 0, c[j >> 2] | 0) | 0;
	                        break
	                    }
	                    default:
	                        c[f >> 2] = 1
	                }
	                i = e;
	                return c[f >> 2] | 0
	            }

	            function rn(a, b, d, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0;
	                j = i;
	                i = i + 64 | 0;
	                k = j;
	                l = j + 56 | 0;
	                m = j + 52 | 0;
	                n = j + 48 | 0;
	                o = j + 44 | 0;
	                p = j + 40 | 0;
	                q = j + 36 | 0;
	                r = j + 32 | 0;
	                s = j + 28 | 0;
	                t = j + 24 | 0;
	                u = j + 20 | 0;
	                v = j + 16 | 0;
	                w = j + 12 | 0;
	                c[l >> 2] = a;
	                c[m >> 2] = b;
	                c[n >> 2] = d;
	                c[o >> 2] = e;
	                c[p >> 2] = f;
	                c[q >> 2] = g;
	                c[r >> 2] = h;
	                c[s >> 2] = 0;
	                c[t >> 2] = 0;
	                c[u >> 2] = 0;
	                c[v >> 2] = 0;
	                do if (c[l >> 2] | 0) {
	                    c[t >> 2] = c[(c[l >> 2] | 0) + 8 >> 2];
	                    c[v >> 2] = c[c[l >> 2] >> 2];
	                    if ((c[(c[l >> 2] | 0) + 28 >> 2] | 0) != -1412623820 ? (c[(c[l >> 2] | 0) + 28 >> 2] | 0) != -1412623819 : 0)break;
	                    c[w >> 2] = (c[l >> 2] | 0) - (c[c[l >> 2] >> 2] | 0);
	                    if ((c[w >> 2] | 0) > 0 & (c[w >> 2] | 0) < 250)c[u >> 2] = c[c[l >> 2] >> 2]
	                } while (0);
	                l = c[s >> 2] | 0;
	                s = c[t >> 2] | 0;
	                t = c[v >> 2] | 0;
	                v = c[u >> 2] | 0;
	                u = c[m >> 2] | 0;
	                m = c[n >> 2] | 0;
	                n = c[p >> 2] | 0;
	                w = c[p >> 2] | 0;
	                h = c[r >> 2] | 0;
	                g = c[o >> 2] | 0;
	                o = c[q >> 2] | 0;
	                q = c[r >> 2] | 0;
	                c[k >> 2] = c[p >> 2];
	                c[k + 4 >> 2] = o;
	                c[k + 8 >> 2] = q;
	                Xd(l, s, t, v, u, 23, m, 1, 0, 0, n, w, h, 0, 0, g, k);
	                i = j;
	                return
	            }

	            function sn(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 32 >> 2] | 0)c[e >> 2] = c[(c[(c[d >> 2] | 0) + 32 >> 2] | 0) + 80 >> 2]; else c[e >> 2] = 0;
	                Qh(c[d >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 52 >> 2] | 0)rm(c[(c[d >> 2] | 0) + 52 >> 2] | 0);
	                a = (c[(c[d >> 2] | 0) + 60 >> 2] | 0) != 0;
	                if (c[e >> 2] | 0) {
	                    if (a ? (CP(c[e >> 2] | 0, c[(c[d >> 2] | 0) + 60 >> 2] | 0) | 0) == 0 : 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 60 >> 2] | 0);
	                    if ((c[(c[d >> 2] | 0) + 8 >> 2] | 0) != 0 ? (CP(c[e >> 2] | 0, c[(c[d >> 2] | 0) + 8 >> 2] | 0) | 0) == 0 : 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                    if ((c[(c[d >> 2] | 0) + 56 >> 2] | 0) != 0 ? (CP(c[e >> 2] | 0, c[(c[d >> 2] | 0) + 56 >> 2] | 0) | 0) == 0 : 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 56 >> 2] | 0);
	                    if ((c[(c[d >> 2] | 0) + 48 >> 2] | 0) != 0 ? (CP(c[e >> 2] | 0, c[(c[d >> 2] | 0) + 48 >> 2] | 0) | 0) == 0 : 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 48 >> 2] | 0)
	                } else {
	                    if (a)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 60 >> 2] | 0);
	                    if (c[(c[d >> 2] | 0) + 8 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                    if (c[(c[d >> 2] | 0) + 48 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 48 >> 2] | 0);
	                    if (c[(c[d >> 2] | 0) + 56 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 56 >> 2] | 0)
	                }
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function tn(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 32 | 0;
	                g = e + 28 | 0;
	                h = e + 24 | 0;
	                j = e + 20 | 0;
	                k = e + 16 | 0;
	                l = e + 12 | 0;
	                m = e + 8 | 0;
	                n = e + 4 | 0;
	                o = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[m >> 2] = 0;
	                c[n >> 2] = 0;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    p = c[f >> 2] | 0;
	                    i = e;
	                    return p | 0
	                }
	                if (!(c[(c[g >> 2] | 0) + 40 >> 2] | 0)) {
	                    c[o >> 2] = 0;
	                    if (c[(c[g >> 2] | 0) + 32 >> 2] | 0)c[o >> 2] = c[(c[(c[g >> 2] | 0) + 32 >> 2] | 0) + 80 >> 2];
	                    if (!(c[j >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        p = c[f >> 2] | 0;
	                        i = e;
	                        return p | 0
	                    }
	                    c[k >> 2] = c[(c[g >> 2] | 0) + 40 >> 2];
	                    if (!(c[k >> 2] | 0)) {
	                        c[k >> 2] = Jj(0, c[o >> 2] | 0) | 0;
	                        c[(c[g >> 2] | 0) + 40 >> 2] = c[k >> 2]
	                    }
	                    if (!(c[k >> 2] | 0)) {
	                        ln(0, 85552);
	                        c[f >> 2] = 0;
	                        p = c[f >> 2] | 0;
	                        i = e;
	                        return p | 0
	                    }
	                }
	                c[k >> 2] = c[(c[g >> 2] | 0) + 40 >> 2];
	                c[m >> 2] = Ch(c[h >> 2] | 0, n) | 0;
	                if (c[m >> 2] | 0)c[h >> 2] = c[m >> 2];
	                c[l >> 2] = Tj(c[k >> 2] | 0, c[h >> 2] | 0, c[n >> 2] | 0) | 0;
	                do if ((c[l >> 2] | 0) == 0 & (c[j >> 2] | 0) != 0) {
	                    c[l >> 2] = Cb[c[135744 >> 2] & 511](56) | 0;
	                    if (c[l >> 2] | 0) {
	                        g = (c[l >> 2] | 0) + 0 | 0;
	                        o = g + 56 | 0;
	                        do {
	                            c[g >> 2] = 0;
	                            g = g + 4 | 0
	                        } while ((g | 0) < (o | 0));
	                        c[(c[l >> 2] | 0) + 4 >> 2] = 15;
	                        g = my(c[h >> 2] | 0) | 0;
	                        c[(c[l >> 2] | 0) + 8 >> 2] = g;
	                        g = my(c[n >> 2] | 0) | 0;
	                        c[(c[l >> 2] | 0) + 48 >> 2] = g;
	                        c[(c[l >> 2] | 0) + 36 >> 2] = 0;
	                        Nj(c[k >> 2] | 0, c[h >> 2] | 0, c[n >> 2] | 0, c[l >> 2] | 0) | 0;
	                        break
	                    }
	                    ln(0, 79472);
	                    c[f >> 2] = 0;
	                    p = c[f >> 2] | 0;
	                    i = e;
	                    return p | 0
	                } while (0);
	                if (c[n >> 2] | 0)zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                if (c[m >> 2] | 0)zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                c[f >> 2] = c[l >> 2];
	                p = c[f >> 2] | 0;
	                i = e;
	                return p | 0
	            }

	            function un(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[l >> 2] = 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                c[k >> 2] = c[(c[h >> 2] | 0) + 44 >> 2];
	                while (1) {
	                    if (!(c[k >> 2] | 0))break;
	                    if ((c[(c[k >> 2] | 0) + 40 >> 2] | 0) == 2 ? (c[l >> 2] = (c[l >> 2] | 0) + 1, (c[l >> 2] | 0) > 1 & (c[j >> 2] | 0) != 0) : 0)jn(c[g >> 2] | 0, c[h >> 2] | 0, 520, 85584, c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0, 0);
	                    c[k >> 2] = c[(c[k >> 2] | 0) + 36 >> 2]
	                }
	                c[f >> 2] = c[l >> 2];
	                m = c[f >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function vn(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](64) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    ln(0, 79472);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = (c[f >> 2] | 0) + 0 | 0;
	                h = a + 64 | 0;
	                do {
	                    c[a >> 2] = 0;
	                    a = a + 4 | 0
	                } while ((a | 0) < (h | 0));
	                c[(c[f >> 2] | 0) + 4 >> 2] = 16;
	                c[(c[f >> 2] | 0) + 40 >> 2] = c[(c[e >> 2] | 0) + 40 >> 2];
	                c[(c[f >> 2] | 0) + 44 >> 2] = c[(c[e >> 2] | 0) + 44 >> 2];
	                a = sm(c[(c[e >> 2] | 0) + 52 >> 2] | 0) | 0;
	                c[(c[f >> 2] | 0) + 52 >> 2] = a;
	                if (c[(c[e >> 2] | 0) + 60 >> 2] | 0) {
	                    a = my(c[(c[e >> 2] | 0) + 60 >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 60 >> 2] = a
	                }
	                if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                    a = my(c[(c[e >> 2] | 0) + 8 >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 8 >> 2] = a
	                }
	                if (c[(c[e >> 2] | 0) + 56 >> 2] | 0) {
	                    a = my(c[(c[e >> 2] | 0) + 56 >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 56 >> 2] = a
	                }
	                if (c[(c[e >> 2] | 0) + 48 >> 2] | 0) {
	                    a = my(c[(c[e >> 2] | 0) + 48 >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 48 >> 2] = a
	                }
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function wn(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if ((c[e >> 2] | 0) == 0 | (c[f >> 2] | 0) == 0) {
	                    i = d;
	                    return
	                }
	                qj(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 4 >> 2] | 0);
	                b = c[e >> 2] | 0;
	                if (!(c[c[f >> 2] >> 2] | 0)) {
	                    rj(b, 79672);
	                    i = d;
	                    return
	                } else {
	                    rj(b, 79664);
	                    wn(c[e >> 2] | 0, c[c[f >> 2] >> 2] | 0);
	                    i = d;
	                    return
	                }
	            }

	            function xn(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[c[d >> 2] >> 2] | 0)zb[c[135736 >> 2] & 511](c[c[d >> 2] >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 4 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 4 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 8 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function yn(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](12) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    ln(0, 79472);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                if (c[c[e >> 2] >> 2] | 0) {
	                    a = my(c[c[e >> 2] >> 2] | 0) | 0;
	                    c[c[f >> 2] >> 2] = a
	                } else c[c[f >> 2] >> 2] = 0;
	                if (c[(c[e >> 2] | 0) + 4 >> 2] | 0) {
	                    a = my(c[(c[e >> 2] | 0) + 4 >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 4 >> 2] = a
	                } else c[(c[f >> 2] | 0) + 4 >> 2] = 0;
	                if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                    a = my(c[(c[e >> 2] | 0) + 8 >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 8 >> 2] = a
	                } else c[(c[f >> 2] | 0) + 8 >> 2] = 0;
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function zn(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                Am(c[f >> 2] | 0, c[e >> 2] | 0);
	                i = d;
	                return
	            }

	            function An(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                c[e >> 2] = 0;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 20 >> 2] | 0)c[e >> 2] = c[(c[(c[d >> 2] | 0) + 20 >> 2] | 0) + 80 >> 2];
	                do if ((c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 0 ? (c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                    if ((c[e >> 2] | 0) != 0 ? (CP(c[e >> 2] | 0, c[(c[d >> 2] | 0) + 4 >> 2] | 0) | 0) != 0 : 0)break;
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 4 >> 2] | 0)
	                } while (0);
	                do if ((c[(c[d >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[(c[d >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                    if ((c[e >> 2] | 0) != 0 ? (CP(c[e >> 2] | 0, c[(c[d >> 2] | 0) + 12 >> 2] | 0) | 0) != 0 : 0)break;
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 12 >> 2] | 0)
	                } while (0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function Bn(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                c[e >> 2] = OS(c[d >> 2] | 0) | 0;
	                if (!(c[e >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[e >> 2] | 0) + 4 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[e >> 2] | 0) + 4 >> 2] | 0);
	                if (c[(c[e >> 2] | 0) + 12 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[e >> 2] | 0) + 12 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[e >> 2] | 0);
	                i = b;
	                return
	            }

	            function Cn(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0;
	                d = i;
	                i = i + 16 | 0;
	                c[d + 4 >> 2] = a;
	                c[d >> 2] = b;
	                i = d;
	                return 0
	            }

	            function Dn(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                MS(c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function En(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                c[h >> 2] = c[g >> 2];
	                c[j >> 2] = oe(0, c[h >> 2] | 0, k) | 0;
	                c[h >> 2] = (c[h >> 2] | 0) + (c[k >> 2] | 0);
	                if (!(Vn(c[f >> 2] | 0, c[j >> 2] | 0) | 0)) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                c[j >> 2] = oe(0, c[h >> 2] | 0, k) | 0;
	                c[h >> 2] = (c[h >> 2] | 0) + (c[k >> 2] | 0);
	                while (1) {
	                    if (!(Wn(c[f >> 2] | 0, c[j >> 2] | 0) | 0))break;
	                    c[j >> 2] = oe(0, c[h >> 2] | 0, k) | 0;
	                    c[h >> 2] = (c[h >> 2] | 0) + (c[k >> 2] | 0)
	                }
	                if (c[j >> 2] | 0) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                } else {
	                    c[e >> 2] = 1;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                return 0
	            }

	            function Fn(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                c[h >> 2] = c[g >> 2];
	                c[j >> 2] = oe(0, c[h >> 2] | 0, k) | 0;
	                c[h >> 2] = (c[h >> 2] | 0) + (c[k >> 2] | 0);
	                if (!(Vn(c[f >> 2] | 0, c[j >> 2] | 0) | 0)) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                c[j >> 2] = oe(0, c[h >> 2] | 0, k) | 0;
	                c[h >> 2] = (c[h >> 2] | 0) + (c[k >> 2] | 0);
	                while (1) {
	                    if (!(Wn(c[f >> 2] | 0, c[j >> 2] | 0) | 0))break;
	                    c[j >> 2] = oe(0, c[h >> 2] | 0, k) | 0;
	                    c[h >> 2] = (c[h >> 2] | 0) + (c[k >> 2] | 0)
	                }
	                a:while (1) {
	                    if ((c[j >> 2] | 0) != 32)break;
	                    while (1) {
	                        if ((c[j >> 2] | 0) != 32)break;
	                        c[j >> 2] = oe(0, c[h >> 2] | 0, k) | 0;
	                        c[h >> 2] = (c[h >> 2] | 0) + (c[k >> 2] | 0)
	                    }
	                    if (!(Vn(c[f >> 2] | 0, c[j >> 2] | 0) | 0)) {
	                        m = 12;
	                        break
	                    }
	                    c[j >> 2] = oe(0, c[h >> 2] | 0, k) | 0;
	                    c[h >> 2] = (c[h >> 2] | 0) + (c[k >> 2] | 0);
	                    while (1) {
	                        if (!(Wn(c[f >> 2] | 0, c[j >> 2] | 0) | 0))continue a;
	                        c[j >> 2] = oe(0, c[h >> 2] | 0, k) | 0;
	                        c[h >> 2] = (c[h >> 2] | 0) + (c[k >> 2] | 0)
	                    }
	                }
	                if ((m | 0) == 12) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                if (c[j >> 2] | 0) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                } else {
	                    c[e >> 2] = 1;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                return 0
	            }

	            function Gn(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                c[h >> 2] = c[g >> 2];
	                c[j >> 2] = oe(0, c[h >> 2] | 0, k) | 0;
	                c[h >> 2] = (c[h >> 2] | 0) + (c[k >> 2] | 0);
	                if (!(Wn(c[f >> 2] | 0, c[j >> 2] | 0) | 0)) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                c[j >> 2] = oe(0, c[h >> 2] | 0, k) | 0;
	                c[h >> 2] = (c[h >> 2] | 0) + (c[k >> 2] | 0);
	                while (1) {
	                    if (!(Wn(c[f >> 2] | 0, c[j >> 2] | 0) | 0))break;
	                    c[j >> 2] = oe(0, c[h >> 2] | 0, k) | 0;
	                    c[h >> 2] = (c[h >> 2] | 0) + (c[k >> 2] | 0)
	                }
	                if (c[j >> 2] | 0) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                } else {
	                    c[e >> 2] = 1;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                return 0
	            }

	            function Hn(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                c[h >> 2] = c[g >> 2];
	                c[j >> 2] = oe(0, c[h >> 2] | 0, k) | 0;
	                c[h >> 2] = (c[h >> 2] | 0) + (c[k >> 2] | 0);
	                while (1) {
	                    if ((c[j >> 2] | 0) < 256) {
	                        if ((c[j >> 2] | 0) != 32 ? !(9 <= (c[j >> 2] | 0) & (c[j >> 2] | 0) <= 10) : 0)m = (c[j >> 2] | 0) == 13; else m = 1;
	                        n = m & 1
	                    } else n = 0;
	                    if (!n)break;
	                    c[j >> 2] = oe(0, c[h >> 2] | 0, k) | 0;
	                    c[h >> 2] = (c[h >> 2] | 0) + (c[k >> 2] | 0)
	                }
	                if (!(Wn(c[f >> 2] | 0, c[j >> 2] | 0) | 0)) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                while (1) {
	                    if (!(Wn(c[f >> 2] | 0, c[j >> 2] | 0) | 0))break;
	                    c[j >> 2] = oe(0, c[h >> 2] | 0, k) | 0;
	                    c[h >> 2] = (c[h >> 2] | 0) + (c[k >> 2] | 0)
	                }
	                a:while (1) {
	                    if ((c[j >> 2] | 0) != 32) {
	                        o = 25;
	                        break
	                    }
	                    while (1) {
	                        if ((c[j >> 2] | 0) != 32)break;
	                        c[j >> 2] = oe(0, c[h >> 2] | 0, k) | 0;
	                        c[h >> 2] = (c[h >> 2] | 0) + (c[k >> 2] | 0)
	                    }
	                    if (!(c[j >> 2] | 0)) {
	                        o = 19;
	                        break
	                    }
	                    if (!(Wn(c[f >> 2] | 0, c[j >> 2] | 0) | 0)) {
	                        o = 21;
	                        break
	                    }
	                    c[j >> 2] = oe(0, c[h >> 2] | 0, k) | 0;
	                    c[h >> 2] = (c[h >> 2] | 0) + (c[k >> 2] | 0);
	                    while (1) {
	                        if (!(Wn(c[f >> 2] | 0, c[j >> 2] | 0) | 0))continue a;
	                        c[j >> 2] = oe(0, c[h >> 2] | 0, k) | 0;
	                        c[h >> 2] = (c[h >> 2] | 0) + (c[k >> 2] | 0)
	                    }
	                }
	                if ((o | 0) == 19) {
	                    c[e >> 2] = 1;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                } else if ((o | 0) == 21) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                } else if ((o | 0) == 25)if (c[j >> 2] | 0) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                } else {
	                    c[e >> 2] = 1;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                return 0
	            }

	            function In(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[e >> 2] = d;
	                if ((c[(c[f >> 2] | 0) + 40 >> 2] | 0) != 2) {
	                    i = e;
	                    return
	                }
	                f = c[g >> 2] | 0;
	                c[f >> 2] = (c[f >> 2] | 0) + 1;
	                i = e;
	                return
	            }

	            function Jn(a, b, d, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0;
	                j = i;
	                i = i + 64 | 0;
	                k = j;
	                l = j + 56 | 0;
	                m = j + 52 | 0;
	                n = j + 48 | 0;
	                o = j + 44 | 0;
	                p = j + 40 | 0;
	                q = j + 36 | 0;
	                r = j + 32 | 0;
	                s = j + 28 | 0;
	                t = j + 24 | 0;
	                u = j + 20 | 0;
	                v = j + 16 | 0;
	                w = j + 12 | 0;
	                c[l >> 2] = a;
	                c[m >> 2] = b;
	                c[n >> 2] = d;
	                c[o >> 2] = e;
	                c[p >> 2] = f;
	                c[q >> 2] = g;
	                c[r >> 2] = h;
	                c[s >> 2] = 0;
	                c[t >> 2] = 0;
	                c[u >> 2] = 0;
	                c[v >> 2] = 0;
	                do if (c[l >> 2] | 0) {
	                    c[t >> 2] = c[(c[l >> 2] | 0) + 4 >> 2];
	                    c[v >> 2] = c[c[l >> 2] >> 2];
	                    if ((c[(c[l >> 2] | 0) + 28 >> 2] | 0) != -1412623820 ? (c[(c[l >> 2] | 0) + 28 >> 2] | 0) != -1412623819 : 0)break;
	                    c[w >> 2] = (c[l >> 2] | 0) - (c[c[l >> 2] >> 2] | 0);
	                    if ((c[w >> 2] | 0) > 0 & (c[w >> 2] | 0) < 250)c[u >> 2] = c[c[l >> 2] >> 2]
	                } while (0);
	                l = c[s >> 2] | 0;
	                s = c[t >> 2] | 0;
	                t = c[v >> 2] | 0;
	                v = c[u >> 2] | 0;
	                u = c[m >> 2] | 0;
	                m = c[n >> 2] | 0;
	                n = c[p >> 2] | 0;
	                w = c[r >> 2] | 0;
	                h = c[q >> 2] | 0;
	                g = c[o >> 2] | 0;
	                o = c[q >> 2] | 0;
	                q = c[r >> 2] | 0;
	                c[k >> 2] = c[p >> 2];
	                c[k + 4 >> 2] = o;
	                c[k + 8 >> 2] = q;
	                Xd(l, s, t, v, u, 23, m, 2, 0, 0, n, w, 0, h, 0, g, k);
	                i = j;
	                return
	            }

	            function Kn(b, e, f, g, h) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0;
	                j = i;
	                i = i + 64 | 0;
	                k = j + 48 | 0;
	                l = j + 44 | 0;
	                m = j + 40 | 0;
	                n = j + 36 | 0;
	                o = j + 32 | 0;
	                p = j + 28 | 0;
	                q = j + 24 | 0;
	                r = j + 20 | 0;
	                s = j + 16 | 0;
	                t = j + 12 | 0;
	                u = j + 8 | 0;
	                v = j + 52 | 0;
	                w = j + 4 | 0;
	                x = j;
	                c[l >> 2] = b;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                c[p >> 2] = h;
	                c[q >> 2] = 1;
	                h = c[o >> 2] | 0;
	                do if ((h | 0) == 5) {
	                    c[r >> 2] = ad(c[m >> 2] | 0, c[p >> 2] | 0) | 0;
	                    if ((c[r >> 2] | 0) == 0 ? (c[(c[m >> 2] | 0) + 40 >> 2] | 0) == 1 : 0) {
	                        c[(c[m >> 2] | 0) + 40 >> 2] = 0;
	                        c[r >> 2] = ad(c[m >> 2] | 0, c[p >> 2] | 0) | 0
	                    }
	                    if (!(c[r >> 2] | 0)) {
	                        jn(c[l >> 2] | 0, c[m >> 2] | 0, 535, 85248, c[n >> 2] | 0, c[p >> 2] | 0, 0);
	                        c[q >> 2] = 0;
	                        break
	                    }
	                    if ((c[(c[r >> 2] | 0) + 48 >> 2] | 0) != 3) {
	                        jn(c[l >> 2] | 0, c[m >> 2] | 0, 511, 85304, c[n >> 2] | 0, c[p >> 2] | 0, 0);
	                        c[q >> 2] = 0
	                    }
	                } else if ((h | 0) == 10) {
	                    c[x >> 2] = Om(c[(c[m >> 2] | 0) + 44 >> 2] | 0, c[p >> 2] | 0) | 0;
	                    if ((c[x >> 2] | 0) == 0 ? (c[(c[m >> 2] | 0) + 48 >> 2] | 0) != 0 : 0)c[x >> 2] = Om(c[(c[m >> 2] | 0) + 48 >> 2] | 0, c[p >> 2] | 0) | 0;
	                    if (!(c[x >> 2] | 0)) {
	                        jn(c[l >> 2] | 0, c[m >> 2] | 0, 537, 85488, c[n >> 2] | 0, c[p >> 2] | 0, 0);
	                        c[q >> 2] = 0
	                    }
	                } else if ((h | 0) == 6) {
	                    c[t >> 2] = 0;
	                    c[s >> 2] = my(c[p >> 2] | 0) | 0;
	                    if (!(c[s >> 2] | 0)) {
	                        c[k >> 2] = 0;
	                        y = c[k >> 2] | 0;
	                        i = j;
	                        return y | 0
	                    }
	                    c[u >> 2] = c[s >> 2];
	                    a:while (1) {
	                        if (!(d[c[u >> 2] >> 0] | 0))break;
	                        c[t >> 2] = c[u >> 2];
	                        while (1) {
	                            if (d[c[u >> 2] >> 0] | 0) {
	                                do if ((d[c[u >> 2] >> 0] | 0 | 0) == 32)z = 1; else {
	                                    if (9 <= (d[c[u >> 2] >> 0] | 0 | 0) ? (d[c[u >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                        z = 1;
	                                        break
	                                    }
	                                    z = (d[c[u >> 2] >> 0] | 0 | 0) == 13
	                                } while (0);
	                                A = z ^ 1
	                            } else A = 0;
	                            B = c[u >> 2] | 0;
	                            if (!A)break;
	                            c[u >> 2] = B + 1
	                        }
	                        a[v >> 0] = a[B >> 0] | 0;
	                        a[c[u >> 2] >> 0] = 0;
	                        c[w >> 2] = ad(c[m >> 2] | 0, c[t >> 2] | 0) | 0;
	                        if (c[w >> 2] | 0) {
	                            if ((c[(c[w >> 2] | 0) + 48 >> 2] | 0) != 3) {
	                                jn(c[l >> 2] | 0, c[m >> 2] | 0, 511, 85424, c[n >> 2] | 0, c[t >> 2] | 0, 0);
	                                c[q >> 2] = 0
	                            }
	                        } else {
	                            jn(c[l >> 2] | 0, c[m >> 2] | 0, 535, 85368, c[n >> 2] | 0, c[t >> 2] | 0, 0);
	                            c[q >> 2] = 0
	                        }
	                        if (!(d[v >> 0] | 0))break;
	                        a[c[u >> 2] >> 0] = a[v >> 0] | 0;
	                        while (1) {
	                            do if ((d[c[u >> 2] >> 0] | 0 | 0) != 32) {
	                                if (9 <= (d[c[u >> 2] >> 0] | 0 | 0) ? (d[c[u >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                                if ((d[c[u >> 2] >> 0] | 0 | 0) != 13)continue a
	                            } while (0);
	                            c[u >> 2] = (c[u >> 2] | 0) + 1
	                        }
	                    }
	                    zb[c[135736 >> 2] & 511](c[s >> 2] | 0)
	                } while (0);
	                c[k >> 2] = c[q >> 2];
	                y = c[k >> 2] | 0;
	                i = j;
	                return y | 0
	            }

	            function Ln(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = Dh(c[j >> 2] | 0, l) | 0;
	                a:do if (!(c[k >> 2] | 0)) {
	                    b:while (1) {
	                        if (!(c[h >> 2] | 0))break a;
	                        d = c[h >> 2] | 0;
	                        do if ((c[c[h >> 2] >> 2] | 0) == 2) {
	                            if ((c[d + 24 >> 2] | 0) == 0 ? (qy(c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[j >> 2] | 0) | 0) != 0 : 0) {
	                                m = 6;
	                                break b
	                            }
	                        } else {
	                            if (((c[d >> 2] | 0) == 4 ? (c[(c[h >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[c[(c[h >> 2] | 0) + 12 >> 2] >> 2] | 0) == 2 : 0) {
	                                if (c[(c[(c[h >> 2] | 0) + 12 >> 2] | 0) + 24 >> 2] | 0)break;
	                                if (qy(c[(c[(c[h >> 2] | 0) + 12 >> 2] | 0) + 8 >> 2] | 0, c[j >> 2] | 0) | 0) {
	                                    m = 12;
	                                    break b
	                                } else break
	                            }
	                            if ((c[c[h >> 2] >> 2] | 0) != 4) {
	                                m = 16;
	                                break b
	                            }
	                            if (!(c[(c[h >> 2] | 0) + 12 >> 2] | 0)) {
	                                m = 16;
	                                break b
	                            }
	                            if ((c[c[(c[h >> 2] | 0) + 12 >> 2] >> 2] | 0) != 1) {
	                                m = 16;
	                                break b
	                            }
	                        } while (0);
	                        c[h >> 2] = c[(c[h >> 2] | 0) + 16 >> 2]
	                    }
	                    if ((m | 0) == 6) {
	                        c[f >> 2] = 1;
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    } else if ((m | 0) == 12) {
	                        c[f >> 2] = 1;
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    } else if ((m | 0) == 16) {
	                        mn(0, 519, 83864, 0);
	                        break
	                    }
	                } else {
	                    c:while (1) {
	                        if (!(c[h >> 2] | 0))break a;
	                        d = c[h >> 2] | 0;
	                        do if ((c[c[h >> 2] >> 2] | 0) == 2) {
	                            if (((c[d + 24 >> 2] | 0) != 0 ? (sy(c[(c[h >> 2] | 0) + 24 >> 2] | 0, c[j >> 2] | 0, c[l >> 2] | 0) | 0) == 0 : 0) ? (qy(c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[k >> 2] | 0) | 0) != 0 : 0) {
	                                m = 23;
	                                break c
	                            }
	                        } else {
	                            if (((c[d >> 2] | 0) == 4 ? (c[(c[h >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[c[(c[h >> 2] | 0) + 12 >> 2] >> 2] | 0) == 2 : 0) {
	                                if (!(c[(c[(c[h >> 2] | 0) + 12 >> 2] | 0) + 24 >> 2] | 0))break;
	                                if (sy(c[(c[(c[h >> 2] | 0) + 12 >> 2] | 0) + 24 >> 2] | 0, c[j >> 2] | 0, c[l >> 2] | 0) | 0)break;
	                                if (qy(c[(c[(c[h >> 2] | 0) + 12 >> 2] | 0) + 8 >> 2] | 0, c[k >> 2] | 0) | 0) {
	                                    m = 30;
	                                    break c
	                                } else break
	                            }
	                            if ((c[c[h >> 2] >> 2] | 0) != 4) {
	                                m = 34;
	                                break c
	                            }
	                            if (!(c[(c[h >> 2] | 0) + 12 >> 2] | 0)) {
	                                m = 34;
	                                break c
	                            }
	                            if ((c[c[(c[h >> 2] | 0) + 12 >> 2] >> 2] | 0) != 1) {
	                                m = 34;
	                                break c
	                            }
	                        } while (0);
	                        c[h >> 2] = c[(c[h >> 2] | 0) + 16 >> 2]
	                    }
	                    if ((m | 0) == 23) {
	                        c[f >> 2] = 1;
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    } else if ((m | 0) == 30) {
	                        c[f >> 2] = 1;
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    } else if ((m | 0) == 34) {
	                        mn(c[g >> 2] | 0, 519, 83864, 0);
	                        break
	                    }
	                } while (0);
	                c[f >> 2] = 0;
	                n = c[f >> 2] | 0;
	                i = e;
	                return n | 0
	            }

	            function Mn(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 24 | 0;
	                h = f + 20 | 0;
	                j = f + 16 | 0;
	                k = f + 12 | 0;
	                l = f + 8 | 0;
	                m = f + 4 | 0;
	                n = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = 0;
	                c[n >> 2] = 0;
	                if (!((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0) ? (c[(c[k >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                    if (c[l >> 2] | 0)c[c[l >> 2] >> 2] = 0;
	                    if ((c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0)c[n >> 2] = c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2];
	                    if ((((c[n >> 2] | 0) != 0 ? (c[m >> 2] = Mm(c[(c[j >> 2] | 0) + 44 >> 2] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0, c[n >> 2] | 0) | 0, (c[m >> 2] | 0) == 0) : 0) ? (c[(c[j >> 2] | 0) + 48 >> 2] | 0) != 0 : 0) ? (c[m >> 2] = Mm(c[(c[j >> 2] | 0) + 48 >> 2] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0, c[n >> 2] | 0) | 0, (c[m >> 2] | 0) != 0 & (c[l >> 2] | 0) != 0) : 0)c[c[l >> 2] >> 2] = 1;
	                    if ((((c[m >> 2] | 0) == 0 ? (c[m >> 2] = Lm(c[(c[j >> 2] | 0) + 44 >> 2] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0) | 0, (c[m >> 2] | 0) == 0) : 0) ? (c[(c[j >> 2] | 0) + 48 >> 2] | 0) != 0 : 0) ? (c[m >> 2] = Lm(c[(c[j >> 2] | 0) + 48 >> 2] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0) | 0, (c[m >> 2] | 0) != 0 & (c[l >> 2] | 0) != 0) : 0)c[c[l >> 2] >> 2] = 1;
	                    if (!(c[m >> 2] | 0))jn(c[h >> 2] | 0, c[k >> 2] | 0, 534, 83832, c[(c[k >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                    c[g >> 2] = c[m >> 2];
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                c[g >> 2] = 0;
	                o = c[g >> 2] | 0;
	                i = f;
	                return o | 0
	            }

	            function Nn(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (!((c[(c[g >> 2] | 0) + 48 >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 52 >> 2] | 0) != 0 : 0))l = 3;
	                if ((l | 0) == 3 ? (c[(c[g >> 2] | 0) + 48 >> 2] = 10, l = Cb[c[135744 >> 2] & 511]((c[(c[g >> 2] | 0) + 48 >> 2] | 0) * 12 | 0) | 0, c[(c[g >> 2] | 0) + 52 >> 2] = l, (c[(c[g >> 2] | 0) + 52 >> 2] | 0) == 0) : 0) {
	                    ln(c[g >> 2] | 0, 79472);
	                    c[f >> 2] = -1;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                do if ((c[(c[g >> 2] | 0) + 44 >> 2] | 0) >= (c[(c[g >> 2] | 0) + 48 >> 2] | 0)) {
	                    c[k >> 2] = Hb[c[135760 >> 2] & 511](c[(c[g >> 2] | 0) + 52 >> 2] | 0, (c[(c[g >> 2] | 0) + 48 >> 2] << 1) * 12 | 0) | 0;
	                    l = c[g >> 2] | 0;
	                    if (c[k >> 2] | 0) {
	                        d = l + 48 | 0;
	                        c[d >> 2] = c[d >> 2] << 1;
	                        c[(c[g >> 2] | 0) + 52 >> 2] = c[k >> 2];
	                        break
	                    }
	                    ln(l, 85184);
	                    c[f >> 2] = -1;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                } while (0);
	                c[(c[g >> 2] | 0) + 40 >> 2] = (c[(c[g >> 2] | 0) + 52 >> 2] | 0) + ((c[(c[g >> 2] | 0) + 44 >> 2] | 0) * 12 | 0);
	                c[(c[(c[g >> 2] | 0) + 52 >> 2] | 0) + ((c[(c[g >> 2] | 0) + 44 >> 2] | 0) * 12 | 0) >> 2] = c[h >> 2];
	                c[(c[(c[g >> 2] | 0) + 52 >> 2] | 0) + ((c[(c[g >> 2] | 0) + 44 >> 2] | 0) * 12 | 0) + 4 >> 2] = c[j >> 2];
	                do if ((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 36 >> 2] | 0) == 4 : 0) {
	                    if (!(c[(c[h >> 2] | 0) + 52 >> 2] | 0))em(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                    if (c[(c[h >> 2] | 0) + 52 >> 2] | 0) {
	                        k = oz(c[(c[h >> 2] | 0) + 52 >> 2] | 0, 0, 0) | 0;
	                        c[(c[(c[g >> 2] | 0) + 52 >> 2] | 0) + ((c[(c[g >> 2] | 0) + 44 >> 2] | 0) * 12 | 0) + 8 >> 2] = k;
	                        break
	                    } else {
	                        c[(c[(c[g >> 2] | 0) + 52 >> 2] | 0) + ((c[(c[g >> 2] | 0) + 44 >> 2] | 0) * 12 | 0) + 8 >> 2] = 0;
	                        jn(c[g >> 2] | 0, c[h >> 2] | 0, 1, 85200, c[(c[j >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                        break
	                    }
	                } while (0);
	                j = (c[g >> 2] | 0) + 44 | 0;
	                g = c[j >> 2] | 0;
	                c[j >> 2] = g + 1;
	                c[f >> 2] = g;
	                m = c[f >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function On(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) < 1) {
	                    c[d >> 2] = -1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = (c[e >> 2] | 0) + 44 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + -1;
	                c[f >> 2] = c[(c[(c[e >> 2] | 0) + 52 >> 2] | 0) + ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) * 12 | 0) >> 2];
	                c[(c[(c[e >> 2] | 0) + 52 >> 2] | 0) + ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) * 12 | 0) >> 2] = 0;
	                c[(c[(c[e >> 2] | 0) + 52 >> 2] | 0) + ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) * 12 | 0) + 4 >> 2] = 0;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 36 >> 2] | 0) == 4 : 0)pz(c[(c[(c[e >> 2] | 0) + 52 >> 2] | 0) + ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) * 12 | 0) + 8 >> 2] | 0);
	                c[(c[(c[e >> 2] | 0) + 52 >> 2] | 0) + ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) * 12 | 0) + 8 >> 2] = 0;
	                f = c[e >> 2] | 0;
	                if ((c[(c[e >> 2] | 0) + 44 >> 2] | 0) >= 1)c[(c[e >> 2] | 0) + 40 >> 2] = (c[(c[e >> 2] | 0) + 52 >> 2] | 0) + (((c[f + 44 >> 2] | 0) - 1 | 0) * 12 | 0); else c[f + 40 >> 2] = 0;
	                c[d >> 2] = c[(c[e >> 2] | 0) + 44 >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function Pn(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 20 | 0;
	                h = e + 16 | 0;
	                j = e + 12 | 0;
	                k = e + 8 | 0;
	                l = e + 4 | 0;
	                m = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 1;
	                if (!((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) {
	                    c[m >> 2] = c[(c[j >> 2] | 0) + 12 >> 2];
	                    c[l >> 2] = c[m >> 2];
	                    a:while (1) {
	                        if (!(c[l >> 2] | 0))break;
	                        switch (c[(c[l >> 2] | 0) + 4 >> 2] | 0) {
	                            case 4:
	                            case 3:
	                            case 7:
	                            case 8:
	                                break;
	                            case 5:
	                            {
	                                if ((c[(c[l >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[(c[(c[l >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                                    Xn(c[g >> 2] | 0, c[l >> 2] | 0) | 0;
	                                    c[l >> 2] = c[(c[(c[l >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2];
	                                    continue a
	                                }
	                                break
	                            }
	                            default:
	                            {
	                                n = 10;
	                                break a
	                            }
	                        }
	                        c[l >> 2] = c[(c[l >> 2] | 0) + 24 >> 2];
	                        while (1) {
	                            if (c[l >> 2] | 0)continue a;
	                            c[l >> 2] = Yn(c[g >> 2] | 0) | 0;
	                            if (!(c[l >> 2] | 0))continue a;
	                            c[l >> 2] = c[(c[l >> 2] | 0) + 24 >> 2]
	                        }
	                    }
	                    if ((n | 0) == 10)c[k >> 2] = 0;
	                    c[(c[g >> 2] | 0) + 20 >> 2] = 0;
	                    c[(c[g >> 2] | 0) + 16 >> 2] = 0;
	                    if (c[(c[g >> 2] | 0) + 24 >> 2] | 0) {
	                        zb[c[135736 >> 2] & 511](c[(c[g >> 2] | 0) + 24 >> 2] | 0);
	                        c[(c[g >> 2] | 0) + 24 >> 2] = 0
	                    }
	                    c[f >> 2] = c[k >> 2];
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                c[f >> 2] = 0;
	                o = c[f >> 2] | 0;
	                i = e;
	                return o | 0
	            }

	            function Qn(b, d, e, f, g) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0;
	                h = i;
	                i = i + 10112 | 0;
	                j = h + 44 | 0;
	                k = h + 40 | 0;
	                l = h + 36 | 0;
	                m = h + 32 | 0;
	                n = h + 28 | 0;
	                o = h + 24 | 0;
	                p = h + 20 | 0;
	                q = h + 16 | 0;
	                r = h + 12 | 0;
	                s = h + 8 | 0;
	                t = h + 4 | 0;
	                u = h + 10048 | 0;
	                v = h;
	                w = h + 5048 | 0;
	                x = h + 48 | 0;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                c[p >> 2] = 1;
	                if ((c[m >> 2] | 0) == 0 | (c[o >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0) {
	                    c[j >> 2] = -1;
	                    y = c[j >> 2] | 0;
	                    i = h;
	                    return y | 0
	                }
	                c[r >> 2] = c[(c[m >> 2] | 0) + 40 >> 2];
	                c[s >> 2] = c[(c[m >> 2] | 0) + 8 >> 2];
	                if (!(c[(c[m >> 2] | 0) + 52 >> 2] | 0))c[p >> 2] = em(c[k >> 2] | 0, c[m >> 2] | 0) | 0;
	                if (!(c[(c[m >> 2] | 0) + 52 >> 2] | 0)) {
	                    c[j >> 2] = -1;
	                    y = c[j >> 2] | 0;
	                    i = h;
	                    return y | 0
	                }
	                if (!(wz(c[(c[m >> 2] | 0) + 52 >> 2] | 0) | 0)) {
	                    c[j >> 2] = -1;
	                    y = c[j >> 2] | 0;
	                    i = h;
	                    return y | 0
	                }
	                c[(c[k >> 2] | 0) + 20 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 16 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 24 >> 2] = 0;
	                c[t >> 2] = oz(c[(c[m >> 2] | 0) + 52 >> 2] | 0, 0, 0) | 0;
	                if (c[t >> 2] | 0) {
	                    c[q >> 2] = c[l >> 2];
	                    a:while (1) {
	                        if (!(c[q >> 2] | 0)) {
	                            z = 31;
	                            break
	                        }
	                        m = c[(c[q >> 2] | 0) + 4 >> 2] | 0;
	                        do if ((m | 0) == 3) {
	                            if (!(ij(c[q >> 2] | 0) | 0)) {
	                                z = 17;
	                                break a
	                            }
	                        } else if ((m | 0) == 1) {
	                            if ((c[(c[q >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[q >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                                c[v >> 2] = Bh(c[(c[q >> 2] | 0) + 8 >> 2] | 0, c[(c[(c[q >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0, u, 50) | 0;
	                                if (!(c[v >> 2] | 0)) {
	                                    z = 22;
	                                    break a
	                                }
	                                c[p >> 2] = qz(c[t >> 2] | 0, c[v >> 2] | 0, 0) | 0;
	                                if ((c[v >> 2] | 0) == (u | 0))break;
	                                if ((c[v >> 2] | 0) == (c[(c[q >> 2] | 0) + 8 >> 2] | 0))break;
	                                zb[c[135736 >> 2] & 511](c[v >> 2] | 0);
	                                break
	                            }
	                            c[p >> 2] = qz(c[t >> 2] | 0, c[(c[q >> 2] | 0) + 8 >> 2] | 0, 0) | 0
	                        } else if ((m | 0) == 4) {
	                            z = 18;
	                            break a
	                        } else if (((m | 0) == 5 ? (c[(c[q >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[(c[(c[q >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                            Xn(c[k >> 2] | 0, c[q >> 2] | 0) | 0;
	                            c[q >> 2] = c[(c[(c[q >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2];
	                            continue a
	                        } while (0);
	                        c[q >> 2] = c[(c[q >> 2] | 0) + 24 >> 2];
	                        while (1) {
	                            if (c[q >> 2] | 0)continue a;
	                            c[q >> 2] = Yn(c[k >> 2] | 0) | 0;
	                            if (!(c[q >> 2] | 0))continue a;
	                            c[q >> 2] = c[(c[q >> 2] | 0) + 24 >> 2]
	                        }
	                    }
	                    if ((z | 0) == 17)c[p >> 2] = 0; else if ((z | 0) == 18)c[p >> 2] = 0; else if ((z | 0) == 22)c[p >> 2] = -1; else if ((z | 0) == 31)c[p >> 2] = qz(c[t >> 2] | 0, 0, 0) | 0;
	                    pz(c[t >> 2] | 0)
	                }
	                if ((c[n >> 2] | 0) != 0 & (c[p >> 2] | 0) != 1 & (c[p >> 2] | 0) != -3) {
	                    do if (c[k >> 2] | 0) {
	                        a[w >> 0] = 0;
	                        fm(w, 5e3, c[r >> 2] | 0, 1);
	                        a[x >> 0] = 0;
	                        Zn(x, 5e3, c[l >> 2] | 0, 1);
	                        n = c[k >> 2] | 0;
	                        t = c[o >> 2] | 0;
	                        if (c[s >> 2] | 0) {
	                            jn(n, t, 504, 84936, c[s >> 2] | 0, w, x);
	                            break
	                        } else {
	                            jn(n, t, 504, 85008, w, x, 0);
	                            break
	                        }
	                    } else {
	                        t = c[k >> 2] | 0;
	                        n = c[o >> 2] | 0;
	                        if (c[s >> 2] | 0) {
	                            jn(t, n, 504, 85072, c[s >> 2] | 0, 0, 0);
	                            break
	                        } else {
	                            jn(t, n, 504, 85120, 0, 0, 0);
	                            break
	                        }
	                    } while (0);
	                    c[p >> 2] = 0
	                }
	                if ((c[p >> 2] | 0) == -3)c[p >> 2] = 1;
	                c[(c[k >> 2] | 0) + 20 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 16 >> 2] = 0;
	                if (c[(c[k >> 2] | 0) + 24 >> 2] | 0) {
	                    zb[c[135736 >> 2] & 511](c[(c[k >> 2] | 0) + 24 >> 2] | 0);
	                    c[(c[k >> 2] | 0) + 24 >> 2] = 0
	                }
	                c[j >> 2] = c[p >> 2];
	                y = c[j >> 2] | 0;
	                i = h;
	                return y | 0
	            }

	            function Rn(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if (!(c[f >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                c[j >> 2] = c[g >> 2];
	                c[j + 4 >> 2] = c[h >> 2];
	                PS(c[f >> 2] | 0, 258, j);
	                i = e;
	                return
	            }

	            function Sn(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 20 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[e + 16 >> 2] = d;
	                c[k >> 2] = 0;
	                if (!(c[f >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                d = c[(c[f >> 2] | 0) + 40 >> 2] | 0;
	                a:do if ((d | 0) == 5 | (d | 0) == 6 | (d | 0) == 10) {
	                    if (((c[(c[f >> 2] | 0) + 48 >> 2] | 0) != 0 ? (c[h >> 2] = Kn(c[g >> 2] | 0, c[(c[g >> 2] | 0) + 32 >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0, c[(c[f >> 2] | 0) + 40 >> 2] | 0, c[(c[f >> 2] | 0) + 48 >> 2] | 0) | 0, (c[h >> 2] | 0) == 0) : 0) ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) == 1 : 0)c[(c[g >> 2] | 0) + 36 >> 2] = 0;
	                    if (c[(c[f >> 2] | 0) + 52 >> 2] | 0) {
	                        c[l >> 2] = c[(c[f >> 2] | 0) + 52 >> 2];
	                        while (1) {
	                            if (!(c[l >> 2] | 0))break a;
	                            c[h >> 2] = Kn(c[g >> 2] | 0, c[(c[g >> 2] | 0) + 32 >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0, c[(c[f >> 2] | 0) + 40 >> 2] | 0, c[(c[l >> 2] | 0) + 4 >> 2] | 0) | 0;
	                            if ((c[h >> 2] | 0) == 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) == 1 : 0)c[(c[g >> 2] | 0) + 36 >> 2] = 0;
	                            c[l >> 2] = c[c[l >> 2] >> 2]
	                        }
	                    }
	                } while (0);
	                if ((c[(c[f >> 2] | 0) + 40 >> 2] | 0) != 10) {
	                    i = e;
	                    return
	                }
	                c[j >> 2] = c[(c[f >> 2] | 0) + 32 >> 2];
	                if (!(c[(c[f >> 2] | 0) + 60 >> 2] | 0)) {
	                    mn(c[g >> 2] | 0, 1, 84584, c[(c[f >> 2] | 0) + 8 >> 2] | 0);
	                    i = e;
	                    return
	                }
	                if (c[j >> 2] | 0)c[k >> 2] = Lm(c[(c[j >> 2] | 0) + 44 >> 2] | 0, c[(c[f >> 2] | 0) + 60 >> 2] | 0) | 0;
	                if ((c[k >> 2] | 0) == 0 & (c[j >> 2] | 0) != 0)c[k >> 2] = Lm(c[(c[j >> 2] | 0) + 48 >> 2] | 0, c[(c[f >> 2] | 0) + 60 >> 2] | 0) | 0;
	                if (((c[k >> 2] | 0) == 0 ? (c[(c[f >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) ? (c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 4 >> 2] | 0) == 14 : 0)c[k >> 2] = Lm(c[(c[f >> 2] | 0) + 20 >> 2] | 0, c[(c[f >> 2] | 0) + 60 >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    jn(c[g >> 2] | 0, 0, 534, 84640, c[(c[f >> 2] | 0) + 8 >> 2] | 0, c[(c[f >> 2] | 0) + 60 >> 2] | 0, 0);
	                    i = e;
	                    return
	                }
	                if ((c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 1) {
	                    i = e;
	                    return
	                }
	                jn(c[g >> 2] | 0, 0, 510, 84696, c[(c[f >> 2] | 0) + 8 >> 2] | 0, c[(c[f >> 2] | 0) + 60 >> 2] | 0, 0);
	                c[(c[g >> 2] | 0) + 36 >> 2] = 0;
	                i = e;
	                return
	            }

	            function Tn(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[e + 8 >> 2] = d;
	                if (!(c[f >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                if ((c[(c[f >> 2] | 0) + 48 >> 2] | 0) != 3) {
	                    i = e;
	                    return
	                }
	                c[h >> 2] = c[(c[f >> 2] | 0) + 40 >> 2];
	                if (!(c[h >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                c[j >> 2] = Pm(c[g >> 2] | 0, c[(c[f >> 2] | 0) + 32 >> 2] | 0, c[h >> 2] | 0) | 0;
	                if ((c[j >> 2] | 0) == 1) {
	                    i = e;
	                    return
	                }
	                c[(c[g >> 2] | 0) + 36 >> 2] = 0;
	                i = e;
	                return
	            }

	            function Un(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                d = i;
	                i = i + 16 | 0;
	                c[d + 4 >> 2] = a;
	                c[d >> 2] = b;
	                i = d;
	                return
	            }

	            function Vn(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                a:do if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 92 >> 2] & 4 | 0) != 0 : 0) {
	                    b = c[g >> 2] | 0;
	                    if ((c[g >> 2] | 0) < 256) {
	                        if (((!(65 <= (b | 0) & (c[g >> 2] | 0) <= 90) ? !(97 <= (c[g >> 2] | 0) & (c[g >> 2] | 0) <= 122) : 0) ? !(192 <= (c[g >> 2] | 0) & (c[g >> 2] | 0) <= 214) : 0) ? !(216 <= (c[g >> 2] | 0) & (c[g >> 2] | 0) <= 246 | 248 <= (c[g >> 2] | 0)) : 0)h = 24
	                    } else if (!(DQ(b, 199744) | 0))h = 24;
	                    do if ((h | 0) == 24) {
	                        b = c[g >> 2] | 0;
	                        if ((c[g >> 2] | 0) < 256)if ((b | 0) == 95 | (c[g >> 2] | 0) == 58)break; else break a;
	                        if (!(19968 <= (b | 0) & (c[g >> 2] | 0) <= 40869 | (c[g >> 2] | 0) == 12295) ? !(12321 <= (c[g >> 2] | 0) & (c[g >> 2] | 0) <= 12329 | (c[g >> 2] | 0) == 95 | (c[g >> 2] | 0) == 58) : 0)break a
	                    } while (0);
	                    c[e >> 2] = 1;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } else h = 3; while (0);
	                do if ((h | 0) == 3) {
	                    if (((((((((((((!((c[g >> 2] | 0) >= 97 & (c[g >> 2] | 0) <= 122) ? !((c[g >> 2] | 0) >= 65 & (c[g >> 2] | 0) <= 90 | (c[g >> 2] | 0) == 95 | (c[g >> 2] | 0) == 58) : 0) ? !((c[g >> 2] | 0) >= 192 & (c[g >> 2] | 0) <= 214) : 0) ? !((c[g >> 2] | 0) >= 216 & (c[g >> 2] | 0) <= 246) : 0) ? !((c[g >> 2] | 0) >= 248 & (c[g >> 2] | 0) <= 767) : 0) ? !((c[g >> 2] | 0) >= 880 & (c[g >> 2] | 0) <= 893) : 0) ? !((c[g >> 2] | 0) >= 895 & (c[g >> 2] | 0) <= 8191) : 0) ? !((c[g >> 2] | 0) >= 8204 & (c[g >> 2] | 0) <= 8205) : 0) ? !((c[g >> 2] | 0) >= 8304 & (c[g >> 2] | 0) <= 8591) : 0) ? !((c[g >> 2] | 0) >= 11264 & (c[g >> 2] | 0) <= 12271) : 0) ? !((c[g >> 2] | 0) >= 12289 & (c[g >> 2] | 0) <= 55295) : 0) ? !((c[g >> 2] | 0) >= 63744 & (c[g >> 2] | 0) <= 64975) : 0) ? !((c[g >> 2] | 0) >= 65008 & (c[g >> 2] | 0) <= 65533) : 0) ? !((c[g >> 2] | 0) >= 65536 & (c[g >> 2] | 0) <= 983039) : 0)break;
	                    c[e >> 2] = 1;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } while (0);
	                c[e >> 2] = 0;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function Wn(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                a:do if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 92 >> 2] & 4 | 0) != 0 : 0) {
	                    b = c[g >> 2] | 0;
	                    if ((c[g >> 2] | 0) < 256) {
	                        if (((!(65 <= (b | 0) & (c[g >> 2] | 0) <= 90) ? !(97 <= (c[g >> 2] | 0) & (c[g >> 2] | 0) <= 122) : 0) ? !(192 <= (c[g >> 2] | 0) & (c[g >> 2] | 0) <= 214) : 0) ? !(216 <= (c[g >> 2] | 0) & (c[g >> 2] | 0) <= 246 | 248 <= (c[g >> 2] | 0)) : 0)h = 27
	                    } else if (!(DQ(b, 199744) | 0))h = 27;
	                    do if ((h | 0) == 27) {
	                        if ((c[g >> 2] | 0) >= 256) {
	                            if (19968 <= (c[g >> 2] | 0) & (c[g >> 2] | 0) <= 40869 | (c[g >> 2] | 0) == 12295)break;
	                            if (12321 <= (c[g >> 2] | 0) & (c[g >> 2] | 0) <= 12329)break
	                        }
	                        b = c[g >> 2] | 0;
	                        if ((c[g >> 2] | 0) < 256) {
	                            if (48 <= (b | 0) & (c[g >> 2] | 0) <= 57 | (c[g >> 2] | 0) == 46 | (c[g >> 2] | 0) == 45 | (c[g >> 2] | 0) == 95 | (c[g >> 2] | 0) == 58)break
	                        } else {
	                            a = (DQ(b, 200216) | 0) != 0;
	                            if (a | (c[g >> 2] | 0) == 46 | (c[g >> 2] | 0) == 45 | (c[g >> 2] | 0) == 95 | (c[g >> 2] | 0) == 58)break
	                        }
	                        if ((c[g >> 2] | 0) >= 256 ? (DQ(c[g >> 2] | 0, 200144) | 0) != 0 : 0)break;
	                        a = c[g >> 2] | 0;
	                        if ((c[g >> 2] | 0) < 256)if ((a | 0) == 183)break; else break a; else if (DQ(a, 200272) | 0)break; else break a
	                    } while (0);
	                    c[e >> 2] = 1;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } else h = 3; while (0);
	                do if ((h | 0) == 3) {
	                    if ((((((((((((((((!((c[g >> 2] | 0) >= 97 & (c[g >> 2] | 0) <= 122) ? !((c[g >> 2] | 0) >= 65 & (c[g >> 2] | 0) <= 90) : 0) ? !((c[g >> 2] | 0) >= 48 & (c[g >> 2] | 0) <= 57 | (c[g >> 2] | 0) == 95 | (c[g >> 2] | 0) == 58 | (c[g >> 2] | 0) == 45 | (c[g >> 2] | 0) == 46 | (c[g >> 2] | 0) == 183) : 0) ? !((c[g >> 2] | 0) >= 192 & (c[g >> 2] | 0) <= 214) : 0) ? !((c[g >> 2] | 0) >= 216 & (c[g >> 2] | 0) <= 246) : 0) ? !((c[g >> 2] | 0) >= 248 & (c[g >> 2] | 0) <= 767) : 0) ? !((c[g >> 2] | 0) >= 768 & (c[g >> 2] | 0) <= 879) : 0) ? !((c[g >> 2] | 0) >= 880 & (c[g >> 2] | 0) <= 893) : 0) ? !((c[g >> 2] | 0) >= 895 & (c[g >> 2] | 0) <= 8191) : 0) ? !((c[g >> 2] | 0) >= 8204 & (c[g >> 2] | 0) <= 8205) : 0) ? !((c[g >> 2] | 0) >= 8255 & (c[g >> 2] | 0) <= 8256) : 0) ? !((c[g >> 2] | 0) >= 8304 & (c[g >> 2] | 0) <= 8591) : 0) ? !((c[g >> 2] | 0) >= 11264 & (c[g >> 2] | 0) <= 12271) : 0) ? !((c[g >> 2] | 0) >= 12289 & (c[g >> 2] | 0) <= 55295) : 0) ? !((c[g >> 2] | 0) >= 63744 & (c[g >> 2] | 0) <= 64975) : 0) ? !((c[g >> 2] | 0) >= 65008 & (c[g >> 2] | 0) <= 65533) : 0) ? !((c[g >> 2] | 0) >= 65536 & (c[g >> 2] | 0) <= 983039) : 0)break;
	                    c[e >> 2] = 1;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } while (0);
	                c[e >> 2] = 0;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function Xn(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[(c[f >> 2] | 0) + 20 >> 2] | 0) <= 0 ? (c[(c[f >> 2] | 0) + 20 >> 2] = 4, b = Cb[c[135744 >> 2] & 511](c[(c[f >> 2] | 0) + 20 >> 2] << 2) | 0, c[(c[f >> 2] | 0) + 24 >> 2] = b, (c[(c[f >> 2] | 0) + 24 >> 2] | 0) == 0) : 0) {
	                    ln(c[f >> 2] | 0, 79472);
	                    c[(c[f >> 2] | 0) + 20 >> 2] = 0;
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                do if ((c[(c[f >> 2] | 0) + 16 >> 2] | 0) >= (c[(c[f >> 2] | 0) + 20 >> 2] | 0)) {
	                    c[h >> 2] = Hb[c[135760 >> 2] & 511](c[(c[f >> 2] | 0) + 24 >> 2] | 0, c[(c[f >> 2] | 0) + 20 >> 2] << 1 << 2) | 0;
	                    b = c[f >> 2] | 0;
	                    if (c[h >> 2] | 0) {
	                        a = b + 20 | 0;
	                        c[a >> 2] = c[a >> 2] << 1;
	                        c[(c[f >> 2] | 0) + 24 >> 2] = c[h >> 2];
	                        break
	                    }
	                    ln(b, 85184);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } while (0);
	                c[(c[(c[f >> 2] | 0) + 24 >> 2] | 0) + (c[(c[f >> 2] | 0) + 16 >> 2] << 2) >> 2] = c[g >> 2];
	                c[(c[f >> 2] | 0) + 12 >> 2] = c[g >> 2];
	                g = (c[f >> 2] | 0) + 16 | 0;
	                f = c[g >> 2] | 0;
	                c[g >> 2] = f + 1;
	                c[e >> 2] = f;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function Yn(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if ((c[(c[e >> 2] | 0) + 16 >> 2] | 0) <= 0) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = (c[e >> 2] | 0) + 16 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + -1;
	                a = c[e >> 2] | 0;
	                if ((c[(c[e >> 2] | 0) + 16 >> 2] | 0) > 0)c[(c[e >> 2] | 0) + 12 >> 2] = c[(c[(c[e >> 2] | 0) + 24 >> 2] | 0) + ((c[a + 16 >> 2] | 0) - 1 << 2) >> 2]; else c[a + 12 >> 2] = 0;
	                c[f >> 2] = c[(c[(c[e >> 2] | 0) + 24 >> 2] | 0) + (c[(c[e >> 2] | 0) + 16 >> 2] << 2) >> 2];
	                c[(c[(c[e >> 2] | 0) + 24 >> 2] | 0) + (c[(c[e >> 2] | 0) + 16 >> 2] << 2) >> 2] = 0;
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function Zn(b, d, e, f) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 20 | 0;
	                j = g + 16 | 0;
	                k = g + 12 | 0;
	                l = g + 8 | 0;
	                m = g + 4 | 0;
	                n = g;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[l >> 2] = f;
	                if (!(c[k >> 2] | 0)) {
	                    i = g;
	                    return
	                }
	                if (c[l >> 2] | 0)_T(c[h >> 2] | 0, 79632) | 0;
	                c[m >> 2] = c[k >> 2];
	                a:while (1) {
	                    if (!(c[m >> 2] | 0)) {
	                        o = 30;
	                        break
	                    }
	                    c[n >> 2] = ZT(c[h >> 2] | 0) | 0;
	                    if (((c[j >> 2] | 0) - (c[n >> 2] | 0) | 0) < 50) {
	                        o = 7;
	                        break
	                    }
	                    switch (c[(c[m >> 2] | 0) + 4 >> 2] | 0) {
	                        case 3:
	                        {
	                            if (!(ij(c[m >> 2] | 0) | 0))o = 25;
	                            break
	                        }
	                        case 1:
	                        {
	                            if ((c[(c[m >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                                k = (c[j >> 2] | 0) - (c[n >> 2] | 0) | 0;
	                                if ((k | 0) < ((xy(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) + 10 | 0)) {
	                                    o = 14;
	                                    break a
	                                }
	                                _T(c[h >> 2] | 0, c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0;
	                                _T(c[h >> 2] | 0, 79648) | 0
	                            }
	                            if (((c[j >> 2] | 0) - (c[n >> 2] | 0) | 0) < ((xy(c[(c[m >> 2] | 0) + 8 >> 2] | 0) | 0) + 10 | 0)) {
	                                o = 19;
	                                break a
	                            }
	                            _T(c[h >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0) | 0;
	                            if (c[(c[m >> 2] | 0) + 24 >> 2] | 0)_T(c[h >> 2] | 0, 80064) | 0;
	                            break
	                        }
	                        case 18:
	                        case 12:
	                        case 11:
	                        case 10:
	                        case 13:
	                        case 21:
	                        case 9:
	                        case 2:
	                        {
	                            _T(c[h >> 2] | 0, 85176) | 0;
	                            if (c[(c[m >> 2] | 0) + 24 >> 2] | 0)_T(c[h >> 2] | 0, 80064) | 0;
	                            break
	                        }
	                        case 5:
	                        case 4:
	                        {
	                            o = 25;
	                            break
	                        }
	                        default:
	                        {
	                        }
	                    }
	                    if ((o | 0) == 25 ? (o = 0, _T(c[h >> 2] | 0, 85168) | 0, (c[(c[m >> 2] | 0) + 24 >> 2] | 0) != 0) : 0)_T(c[h >> 2] | 0, 80064) | 0;
	                    c[m >> 2] = c[(c[m >> 2] | 0) + 24 >> 2]
	                }
	                if ((o | 0) == 7) {
	                    if (((c[j >> 2] | 0) - (c[n >> 2] | 0) | 0) <= 4) {
	                        i = g;
	                        return
	                    }
	                    if ((a[(c[h >> 2] | 0) + ((c[n >> 2] | 0) - 1) >> 0] | 0) == 46) {
	                        i = g;
	                        return
	                    }
	                    _T(c[h >> 2] | 0, 79624) | 0;
	                    i = g;
	                    return
	                } else if ((o | 0) == 14) {
	                    if (((c[j >> 2] | 0) - (c[n >> 2] | 0) | 0) <= 4) {
	                        i = g;
	                        return
	                    }
	                    if ((a[(c[h >> 2] | 0) + ((c[n >> 2] | 0) - 1) >> 0] | 0) == 46) {
	                        i = g;
	                        return
	                    }
	                    _T(c[h >> 2] | 0, 79624) | 0;
	                    i = g;
	                    return
	                } else if ((o | 0) == 19) {
	                    if (((c[j >> 2] | 0) - (c[n >> 2] | 0) | 0) <= 4) {
	                        i = g;
	                        return
	                    }
	                    if ((a[(c[h >> 2] | 0) + ((c[n >> 2] | 0) - 1) >> 0] | 0) == 46) {
	                        i = g;
	                        return
	                    }
	                    _T(c[h >> 2] | 0, 79624) | 0;
	                    i = g;
	                    return
	                } else if ((o | 0) == 30) {
	                    if (!(c[l >> 2] | 0)) {
	                        i = g;
	                        return
	                    }
	                    _T(c[h >> 2] | 0, 79672) | 0;
	                    i = g;
	                    return
	                }
	            }

	            function _n(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[g >> 2] = c[f >> 2];
	                $n(c[e >> 2] | 0, c[c[g >> 2] >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] | 0);
	                i = d;
	                return 1
	            }

	            function $n(b, e, f) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0;
	                g = i;
	                i = i + 48 | 0;
	                h = g + 40 | 0;
	                j = g + 36 | 0;
	                k = g + 32 | 0;
	                l = g + 28 | 0;
	                m = g + 24 | 0;
	                n = g + 20 | 0;
	                o = g + 16 | 0;
	                p = g + 12 | 0;
	                q = g + 45 | 0;
	                r = g + 8 | 0;
	                s = g + 4 | 0;
	                t = g;
	                u = g + 44 | 0;
	                c[h >> 2] = b;
	                c[j >> 2] = e;
	                c[k >> 2] = f;
	                if (!(c[h >> 2] | 0)) {
	                    i = g;
	                    return
	                }
	                if ((c[(c[h >> 2] | 0) + 8 >> 2] | 0) == 0 ? (c[(c[h >> 2] | 0) + 12 >> 2] | 0) == 0 : 0) {
	                    i = g;
	                    return
	                }
	                c[m >> 2] = c[(c[h >> 2] | 0) + 8 >> 2];
	                if (!(c[m >> 2] | 0)) {
	                    c[o >> 2] = 0;
	                    c[n >> 2] = my(c[k >> 2] | 0) | 0;
	                    if (!(c[n >> 2] | 0)) {
	                        c[(c[j >> 2] | 0) + 36 >> 2] = 0;
	                        i = g;
	                        return
	                    }
	                    c[p >> 2] = c[n >> 2];
	                    a:while (1) {
	                        if (!(d[c[p >> 2] >> 0] | 0))break;
	                        c[o >> 2] = c[p >> 2];
	                        while (1) {
	                            if (d[c[p >> 2] >> 0] | 0) {
	                                do if ((d[c[p >> 2] >> 0] | 0 | 0) == 32)v = 1; else {
	                                    if (9 <= (d[c[p >> 2] >> 0] | 0 | 0) ? (d[c[p >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                        v = 1;
	                                        break
	                                    }
	                                    v = (d[c[p >> 2] >> 0] | 0 | 0) == 13
	                                } while (0);
	                                w = v ^ 1
	                            } else w = 0;
	                            x = c[p >> 2] | 0;
	                            if (!w)break;
	                            c[p >> 2] = x + 1
	                        }
	                        a[q >> 0] = a[x >> 0] | 0;
	                        a[c[p >> 2] >> 0] = 0;
	                        c[l >> 2] = Hm(c[(c[j >> 2] | 0) + 32 >> 2] | 0, c[o >> 2] | 0) | 0;
	                        if (!(c[l >> 2] | 0)) {
	                            Jn(c[j >> 2] | 0, 0, 536, 84752, c[(c[h >> 2] | 0) + 12 >> 2] | 0, c[(c[h >> 2] | 0) + 16 >> 2] | 0, c[o >> 2] | 0);
	                            c[(c[j >> 2] | 0) + 36 >> 2] = 0
	                        }
	                        if (!(d[q >> 0] | 0))break;
	                        a[c[p >> 2] >> 0] = a[q >> 0] | 0;
	                        while (1) {
	                            do if ((d[c[p >> 2] >> 0] | 0 | 0) != 32) {
	                                if (9 <= (d[c[p >> 2] >> 0] | 0 | 0) ? (d[c[p >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                                if ((d[c[p >> 2] >> 0] | 0 | 0) != 13)continue a
	                            } while (0);
	                            c[p >> 2] = (c[p >> 2] | 0) + 1
	                        }
	                    }
	                    zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                    i = g;
	                    return
	                }
	                if ((c[(c[m >> 2] | 0) + 40 >> 2] | 0) == 3) {
	                    c[l >> 2] = Hm(c[(c[j >> 2] | 0) + 32 >> 2] | 0, c[k >> 2] | 0) | 0;
	                    if (c[l >> 2] | 0) {
	                        i = g;
	                        return
	                    }
	                    jn(c[j >> 2] | 0, c[(c[m >> 2] | 0) + 20 >> 2] | 0, 536, 84808, c[(c[m >> 2] | 0) + 8 >> 2] | 0, c[k >> 2] | 0, 0);
	                    c[(c[j >> 2] | 0) + 36 >> 2] = 0;
	                    i = g;
	                    return
	                }
	                if ((c[(c[m >> 2] | 0) + 40 >> 2] | 0) != 4) {
	                    i = g;
	                    return
	                }
	                c[s >> 2] = 0;
	                c[r >> 2] = my(c[k >> 2] | 0) | 0;
	                if (!(c[r >> 2] | 0)) {
	                    ln(c[j >> 2] | 0, 84864);
	                    c[(c[j >> 2] | 0) + 36 >> 2] = 0;
	                    i = g;
	                    return
	                }
	                c[t >> 2] = c[r >> 2];
	                b:while (1) {
	                    if (!(d[c[t >> 2] >> 0] | 0))break;
	                    c[s >> 2] = c[t >> 2];
	                    while (1) {
	                        if (d[c[t >> 2] >> 0] | 0) {
	                            do if ((d[c[t >> 2] >> 0] | 0 | 0) == 32)y = 1; else {
	                                if (9 <= (d[c[t >> 2] >> 0] | 0 | 0) ? (d[c[t >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                    y = 1;
	                                    break
	                                }
	                                y = (d[c[t >> 2] >> 0] | 0 | 0) == 13
	                            } while (0);
	                            z = y ^ 1
	                        } else z = 0;
	                        A = c[t >> 2] | 0;
	                        if (!z)break;
	                        c[t >> 2] = A + 1
	                    }
	                    a[u >> 0] = a[A >> 0] | 0;
	                    a[c[t >> 2] >> 0] = 0;
	                    c[l >> 2] = Hm(c[(c[j >> 2] | 0) + 32 >> 2] | 0, c[s >> 2] | 0) | 0;
	                    if (!(c[l >> 2] | 0)) {
	                        jn(c[j >> 2] | 0, c[(c[m >> 2] | 0) + 20 >> 2] | 0, 536, 84880, c[(c[m >> 2] | 0) + 8 >> 2] | 0, c[s >> 2] | 0, 0);
	                        c[(c[j >> 2] | 0) + 36 >> 2] = 0
	                    }
	                    if (!(d[u >> 0] | 0))break;
	                    a[c[t >> 2] >> 0] = a[u >> 0] | 0;
	                    while (1) {
	                        do if ((d[c[t >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[t >> 2] >> 0] | 0 | 0) ? (d[c[t >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[t >> 2] >> 0] | 0 | 0) != 13)continue b
	                        } while (0);
	                        c[t >> 2] = (c[t >> 2] | 0) + 1
	                    }
	                }
	                zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                i = g;
	                return
	            }

	            function ao() {
	                var a = 0, b = 0, d = 0, e = 0, f = 0;
	                a = i;
	                i = i + 16 | 0;
	                b = a + 4 | 0;
	                d = a;
	                c[d >> 2] = 0;
	                if (c[21466] | 0) {
	                    i = a;
	                    return
	                }
	                c[b >> 2] = 0;
	                while (1) {
	                    if ((c[b >> 2] | 0) >= 100)break;
	                    c[85872 + (c[b >> 2] << 2) >> 2] = 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 1
	                }
	                c[b >> 2] = 0;
	                a:while (1) {
	                    if (!((c[b >> 2] | 0) < 99 ? (c[86272 + (c[d >> 2] << 2) >> 2] | 0) != 0 : 0))break;
	                    e = 86272 + (c[d >> 2] << 2) | 0;
	                    f = c[b >> 2] | 0;
	                    c[b >> 2] = f + 1;
	                    c[85872 + (f << 2) >> 2] = e;
	                    while (1) {
	                        e = (c[86272 + (c[d >> 2] << 2) >> 2] | 0) != 0;
	                        c[d >> 2] = (c[d >> 2] | 0) + 1;
	                        if (!e)continue a
	                    }
	                }
	                c[21466] = 1;
	                i = a;
	                return
	            }

	            function bo(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                while (1) {
	                    if ((c[f >> 2] | 0) >>> 0 >= 92) {
	                        g = 6;
	                        break
	                    }
	                    a = (ty(c[e >> 2] | 0, c[87848 + ((c[f >> 2] | 0) * 36 | 0) >> 2] | 0) | 0) != 0;
	                    h = c[f >> 2] | 0;
	                    if (!a) {
	                        g = 4;
	                        break
	                    }
	                    c[f >> 2] = h + 1
	                }
	                if ((g | 0) == 4) {
	                    c[d >> 2] = 87848 + (h * 36 | 0);
	                    j = c[d >> 2] | 0;
	                    i = b;
	                    return j | 0
	                } else if ((g | 0) == 6) {
	                    c[d >> 2] = 0;
	                    j = c[d >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                return 0
	            }

	            function co(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                while (1) {
	                    if ((c[f >> 2] | 0) >>> 0 >= 253) {
	                        g = 6;
	                        break
	                    }
	                    a = (qy(c[e >> 2] | 0, c[91164 + ((c[f >> 2] | 0) * 12 | 0) >> 2] | 0) | 0) != 0;
	                    h = c[f >> 2] | 0;
	                    if (a) {
	                        g = 4;
	                        break
	                    }
	                    c[f >> 2] = h + 1
	                }
	                if ((g | 0) == 4) {
	                    c[d >> 2] = 91160 + (h * 12 | 0);
	                    j = c[d >> 2] | 0;
	                    i = b;
	                    return j | 0
	                } else if ((g | 0) == 6) {
	                    c[d >> 2] = 0;
	                    j = c[d >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                return 0
	            }

	            function eo(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                while (1) {
	                    if ((c[f >> 2] | 0) >>> 0 >= 253)break;
	                    g = c[f >> 2] | 0;
	                    if ((c[91160 + ((c[f >> 2] | 0) * 12 | 0) >> 2] | 0) >>> 0 >= (c[e >> 2] | 0) >>> 0) {
	                        h = 4;
	                        break
	                    }
	                    c[f >> 2] = g + 1
	                }
	                if ((h | 0) == 4 ? (c[91160 + (g * 12 | 0) >> 2] | 0) >>> 0 <= (c[e >> 2] | 0) >>> 0 : 0) {
	                    c[d >> 2] = 91160 + ((c[f >> 2] | 0) * 12 | 0);
	                    j = c[d >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                c[d >> 2] = 0;
	                j = c[d >> 2] | 0;
	                i = b;
	                return j | 0
	            }

	            function fo(b, e, f, g) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0;
	                h = i;
	                i = i + 96 | 0;
	                j = h;
	                k = h + 64 | 0;
	                l = h + 60 | 0;
	                m = h + 56 | 0;
	                n = h + 52 | 0;
	                o = h + 48 | 0;
	                p = h + 44 | 0;
	                q = h + 40 | 0;
	                r = h + 36 | 0;
	                s = h + 32 | 0;
	                t = h + 28 | 0;
	                u = h + 24 | 0;
	                v = h + 20 | 0;
	                w = h + 16 | 0;
	                x = h + 12 | 0;
	                y = h + 8 | 0;
	                z = h + 4 | 0;
	                A = h + 72 | 0;
	                c[l >> 2] = b;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                c[p >> 2] = c[n >> 2];
	                c[r >> 2] = c[l >> 2];
	                c[s >> 2] = c[n >> 2];
	                if ((c[l >> 2] | 0) == 0 | (c[m >> 2] | 0) == 0 | (c[o >> 2] | 0) == 0) {
	                    c[k >> 2] = -1;
	                    B = c[k >> 2] | 0;
	                    i = h;
	                    return B | 0
	                }
	                if (!(c[n >> 2] | 0)) {
	                    c[c[m >> 2] >> 2] = 0;
	                    c[c[o >> 2] >> 2] = 0;
	                    c[k >> 2] = 0;
	                    B = c[k >> 2] | 0;
	                    i = h;
	                    return B | 0
	                }
	                c[t >> 2] = (c[n >> 2] | 0) + (c[c[o >> 2] >> 2] | 0);
	                c[q >> 2] = (c[l >> 2] | 0) + (c[c[m >> 2] >> 2] | 0);
	                a:while (1) {
	                    if ((c[n >> 2] | 0) >>> 0 >= (c[t >> 2] | 0) >>> 0) {
	                        C = 32;
	                        break
	                    }
	                    g = c[n >> 2] | 0;
	                    c[n >> 2] = g + 1;
	                    c[v >> 2] = d[g >> 0];
	                    g = c[v >> 2] | 0;
	                    do if ((c[v >> 2] | 0) >>> 0 < 128) {
	                        c[u >> 2] = g;
	                        c[w >> 2] = 0
	                    } else {
	                        if (g >>> 0 < 192) {
	                            C = 10;
	                            break a
	                        }
	                        f = c[v >> 2] | 0;
	                        if ((c[v >> 2] | 0) >>> 0 < 224) {
	                            c[u >> 2] = f & 31;
	                            c[w >> 2] = 1;
	                            break
	                        }
	                        e = c[v >> 2] | 0;
	                        if (f >>> 0 < 240) {
	                            c[u >> 2] = e & 15;
	                            c[w >> 2] = 2;
	                            break
	                        }
	                        if (e >>> 0 >= 248) {
	                            C = 17;
	                            break a
	                        }
	                        c[u >> 2] = c[v >> 2] & 7;
	                        c[w >> 2] = 3
	                    } while (0);
	                    if (((c[t >> 2] | 0) - (c[n >> 2] | 0) | 0) < (c[w >> 2] | 0)) {
	                        C = 32;
	                        break
	                    }
	                    while (1) {
	                        if (!(c[w >> 2] | 0))break;
	                        if ((c[n >> 2] | 0) >>> 0 >= (c[t >> 2] | 0) >>> 0)break;
	                        g = c[n >> 2] | 0;
	                        c[n >> 2] = g + 1;
	                        e = d[g >> 0] | 0;
	                        c[v >> 2] = e;
	                        if ((e & 192 | 0) != 128)break;
	                        c[u >> 2] = c[u >> 2] << 6;
	                        c[u >> 2] = c[u >> 2] | c[v >> 2] & 63;
	                        c[w >> 2] = (c[w >> 2] | 0) + -1
	                    }
	                    if ((c[u >> 2] | 0) >>> 0 < 128) {
	                        if (((c[l >> 2] | 0) + 1 | 0) >>> 0 >= (c[q >> 2] | 0) >>> 0) {
	                            C = 32;
	                            break
	                        }
	                        e = c[u >> 2] & 255;
	                        g = c[l >> 2] | 0;
	                        c[l >> 2] = g + 1;
	                        a[g >> 0] = e
	                    } else {
	                        c[y >> 2] = eo(c[u >> 2] | 0) | 0;
	                        if (!(c[y >> 2] | 0)) {
	                            c[j >> 2] = c[u >> 2];
	                            JT(A, 16, 94200, j) | 0;
	                            c[z >> 2] = A
	                        } else c[z >> 2] = c[(c[y >> 2] | 0) + 4 >> 2];
	                        c[x >> 2] = ZT(c[z >> 2] | 0) | 0;
	                        if (((c[l >> 2] | 0) + 2 + (c[x >> 2] | 0) | 0) >>> 0 >= (c[q >> 2] | 0) >>> 0) {
	                            C = 32;
	                            break
	                        }
	                        e = c[l >> 2] | 0;
	                        c[l >> 2] = e + 1;
	                        a[e >> 0] = 38;
	                        eU(c[l >> 2] | 0, c[z >> 2] | 0, c[x >> 2] | 0) | 0;
	                        c[l >> 2] = (c[l >> 2] | 0) + (c[x >> 2] | 0);
	                        e = c[l >> 2] | 0;
	                        c[l >> 2] = e + 1;
	                        a[e >> 0] = 59
	                    }
	                    c[p >> 2] = c[n >> 2]
	                }
	                if ((C | 0) == 10) {
	                    c[c[m >> 2] >> 2] = (c[l >> 2] | 0) - (c[r >> 2] | 0);
	                    c[c[o >> 2] >> 2] = (c[p >> 2] | 0) - (c[s >> 2] | 0);
	                    c[k >> 2] = -2;
	                    B = c[k >> 2] | 0;
	                    i = h;
	                    return B | 0
	                } else if ((C | 0) == 17) {
	                    c[c[m >> 2] >> 2] = (c[l >> 2] | 0) - (c[r >> 2] | 0);
	                    c[c[o >> 2] >> 2] = (c[p >> 2] | 0) - (c[s >> 2] | 0);
	                    c[k >> 2] = -2;
	                    B = c[k >> 2] | 0;
	                    i = h;
	                    return B | 0
	                } else if ((C | 0) == 32) {
	                    c[c[m >> 2] >> 2] = (c[l >> 2] | 0) - (c[r >> 2] | 0);
	                    c[c[o >> 2] >> 2] = (c[p >> 2] | 0) - (c[s >> 2] | 0);
	                    c[k >> 2] = 0;
	                    B = c[k >> 2] | 0;
	                    i = h;
	                    return B | 0
	                }
	                return 0
	            }

	            function go(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = Cb[c[135744 >> 2] & 511](96) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    xo(0, 94208);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                b = (c[h >> 2] | 0) + 0 | 0;
	                a = b + 96 | 0;
	                do {
	                    c[b >> 2] = 0;
	                    b = b + 4 | 0
	                } while ((b | 0) < (a | 0));
	                c[(c[h >> 2] | 0) + 4 >> 2] = 13;
	                c[(c[h >> 2] | 0) + 56 >> 2] = 0;
	                c[(c[h >> 2] | 0) + 44 >> 2] = 0;
	                c[(c[h >> 2] | 0) + 32 >> 2] = c[h >> 2];
	                c[(c[h >> 2] | 0) + 8 >> 2] = 0;
	                c[(c[h >> 2] | 0) + 12 >> 2] = 0;
	                c[(c[h >> 2] | 0) + 48 >> 2] = 0;
	                c[(c[h >> 2] | 0) + 52 >> 2] = 0;
	                c[(c[h >> 2] | 0) + 60 >> 2] = 0;
	                c[(c[h >> 2] | 0) + 40 >> 2] = 1;
	                c[(c[h >> 2] | 0) + 36 >> 2] = 0;
	                c[(c[h >> 2] | 0) + 64 >> 2] = 0;
	                c[(c[h >> 2] | 0) + 68 >> 2] = 0;
	                c[c[h >> 2] >> 2] = 0;
	                c[(c[h >> 2] | 0) + 76 >> 2] = 1;
	                c[(c[h >> 2] | 0) + 92 >> 2] = 160;
	                if ((c[g >> 2] | 0) != 0 | (c[f >> 2] | 0) != 0)Oh(c[h >> 2] | 0, 94240, c[g >> 2] | 0, c[f >> 2] | 0) | 0;
	                c[e >> 2] = c[h >> 2];
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function ho(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[k >> 2] = 0;
	                if (c[h >> 2] | 0)c[c[h >> 2] >> 2] = 0;
	                if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) {
	                    do if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 38) {
	                        me(c[g >> 2] | 0);
	                        c[j >> 2] = yo(c[g >> 2] | 0) | 0;
	                        b = c[g >> 2] | 0;
	                        if (!(c[j >> 2] | 0)) {
	                            zo(b, 68, 94336, 0, 0);
	                            break
	                        }
	                        if ((c[b + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)ke(c[(c[g >> 2] | 0) + 36 >> 2] | 0, 250) | 0;
	                        if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 59) {
	                            zo(c[g >> 2] | 0, 23, 94368, 0, 0);
	                            if (!(c[h >> 2] | 0))break;
	                            c[c[h >> 2] >> 2] = c[j >> 2];
	                            break
	                        }
	                        if (c[h >> 2] | 0)c[c[h >> 2] >> 2] = c[j >> 2];
	                        c[k >> 2] = co(c[j >> 2] | 0) | 0;
	                        if (c[k >> 2] | 0)me(c[g >> 2] | 0)
	                    } while (0);
	                    c[f >> 2] = c[k >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[f >> 2] = 0;
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function io(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[f >> 2] = a;
	                c[g >> 2] = 0;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) {
	                    do if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 38 ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 35 : 0) {
	                        if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) != 120 ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) != 88 : 0) {
	                            h = 23;
	                            break
	                        }
	                        a = (c[f >> 2] | 0) + 200 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 3;
	                        a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 3;
	                        a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 3;
	                        a:while (1) {
	                            if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 59)break;
	                            if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 57 : 0)c[g >> 2] = (c[g >> 2] << 4) + ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) - 48); else h = 13;
	                            do if ((h | 0) == 13) {
	                                h = 0;
	                                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) >= 97 ? (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 102 : 0) {
	                                    c[g >> 2] = (c[g >> 2] << 4) + ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) - 97) + 10;
	                                    break
	                                }
	                                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) < 65) {
	                                    h = 19;
	                                    break a
	                                }
	                                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) > 70) {
	                                    h = 19;
	                                    break a
	                                }
	                                c[g >> 2] = (c[g >> 2] << 4) + ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) - 65) + 10
	                            } while (0);
	                            me(c[f >> 2] | 0)
	                        }
	                        if ((h | 0) == 19)zo(c[f >> 2] | 0, 6, 94448, 0, 0);
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 59)me(c[f >> 2] | 0)
	                    } else h = 23; while (0);
	                    do if ((h | 0) == 23) {
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 38 ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 35 : 0) {
	                            a = (c[f >> 2] | 0) + 200 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 2;
	                            a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 2;
	                            a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 2;
	                            while (1) {
	                                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 59)break;
	                                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) < 48) {
	                                    h = 30;
	                                    break
	                                }
	                                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) > 57) {
	                                    h = 30;
	                                    break
	                                }
	                                c[g >> 2] = ((c[g >> 2] | 0) * 10 | 0) + ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) - 48);
	                                me(c[f >> 2] | 0)
	                            }
	                            if ((h | 0) == 30)zo(c[f >> 2] | 0, 7, 94448, 0, 0);
	                            if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 59)break;
	                            me(c[f >> 2] | 0);
	                            break
	                        }
	                        zo(c[f >> 2] | 0, 8, 94488, 0, 0)
	                    } while (0);
	                    a = c[g >> 2] | 0;
	                    if ((c[g >> 2] | 0) < 256)if (9 <= (a | 0) & (c[g >> 2] | 0) <= 10 | (c[g >> 2] | 0) == 13 | 32 <= (c[g >> 2] | 0))h = 39; else h = 40; else if ((!(256 <= (a | 0) & (c[g >> 2] | 0) <= 55295) ? !(57344 <= (c[g >> 2] | 0) & (c[g >> 2] | 0) <= 65533) : 0) ? !(65536 <= (c[g >> 2] | 0) & (c[g >> 2] | 0) <= 1114111) : 0)h = 40; else h = 39;
	                    if ((h | 0) == 39) {
	                        c[e >> 2] = c[g >> 2];
	                        j = c[e >> 2] | 0;
	                        i = b;
	                        return j | 0
	                    } else if ((h | 0) == 40) {
	                        Ao(c[f >> 2] | 0, 9, 94528, c[g >> 2] | 0);
	                        c[e >> 2] = 0;
	                        j = c[e >> 2] | 0;
	                        i = b;
	                        return j | 0
	                    }
	                }
	                zo(c[f >> 2] | 0, 1, 94408, 0, 0);
	                c[e >> 2] = 0;
	                j = c[e >> 2] | 0;
	                i = b;
	                return j | 0
	            }

	            function jo(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                Eo(c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function ko(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 16 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = b;
	                Rf();
	                rQ();
	                if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) {
	                    c[(c[g >> 2] | 0) + 32 >> 2] = 1;
	                    c[(c[g >> 2] | 0) + 280 >> 2] = 1;
	                    if ((c[(c[g >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)ke(c[(c[g >> 2] | 0) + 36 >> 2] | 0, 250) | 0;
	                    if ((c[c[g >> 2] >> 2] | 0) != 0 ? (c[(c[c[g >> 2] >> 2] | 0) + 44 >> 2] | 0) != 0 : 0)Ab[c[(c[c[g >> 2] >> 2] | 0) + 44 >> 2] & 511](c[(c[g >> 2] | 0) + 4 >> 2] | 0, 136080);
	                    if ((c[(c[g >> 2] | 0) + 24 >> 2] | 0) == 0 ? ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) >= 4 : 0) {
	                        if (c[(c[g >> 2] | 0) + 176 >> 2] | 0)l = -1; else l = d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                        a[h >> 0] = l;
	                        a[h + 1 >> 0] = a[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0;
	                        a[h + 2 >> 0] = a[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0;
	                        a[h + 3 >> 0] = a[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0;
	                        c[j >> 2] = sd(h, 4) | 0;
	                        if (c[j >> 2] | 0)re(c[g >> 2] | 0, c[j >> 2] | 0) | 0
	                    }
	                    Fo(c[g >> 2] | 0) | 0;
	                    if (!(d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0))zo(c[g >> 2] | 0, 4, 94672, 0, 0);
	                    if (((c[c[g >> 2] >> 2] | 0) != 0 ? (c[(c[c[g >> 2] >> 2] | 0) + 48 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 212 >> 2] | 0) == 0 : 0)zb[c[(c[c[g >> 2] >> 2] | 0) + 48 >> 2] & 511](c[(c[g >> 2] | 0) + 4 >> 2] | 0);
	                    while (1) {
	                        if ((((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 33 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 45 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 45 : 0)m = 1; else if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60)m = (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 63; else m = 0;
	                        n = c[g >> 2] | 0;
	                        if (!m)break;
	                        Go(n);
	                        Ho(c[g >> 2] | 0);
	                        Fo(c[g >> 2] | 0) | 0
	                    }
	                    if (((((((((d[c[(c[n + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 33 : 0) ? (WS(d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0) | 0) == 68 : 0) ? (WS(d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0) | 0) == 79 : 0) ? (WS(d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0) | 0) == 67 : 0) ? (WS(d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0) | 0) == 84 : 0) ? (WS(d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 6 >> 0] | 0) | 0) == 89 : 0) ? (WS(d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 7 >> 0] | 0) | 0) == 80 : 0) ? (WS(d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 8 >> 0] | 0) | 0) == 69 : 0)Io(c[g >> 2] | 0);
	                    Fo(c[g >> 2] | 0) | 0;
	                    while (1) {
	                        if ((((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 33 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 45 : 0) ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 45 : 0)o = 1; else if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60)o = (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 63; else o = 0;
	                        p = c[g >> 2] | 0;
	                        if (!o)break;
	                        Go(p);
	                        Ho(c[g >> 2] | 0);
	                        Fo(c[g >> 2] | 0) | 0
	                    }
	                    Eo(p);
	                    if (!(d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0))Do(c[g >> 2] | 0);
	                    if ((c[c[g >> 2] >> 2] | 0) != 0 ? (c[(c[c[g >> 2] >> 2] | 0) + 52 >> 2] | 0) != 0 : 0)zb[c[(c[c[g >> 2] >> 2] | 0) + 52 >> 2] & 511](c[(c[g >> 2] | 0) + 4 >> 2] | 0);
	                    if (((c[(c[g >> 2] | 0) + 360 >> 2] & 4 | 0) == 0 ? (c[(c[g >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (c[k >> 2] = Nh(c[(c[g >> 2] | 0) + 8 >> 2] | 0) | 0, (c[k >> 2] | 0) == 0) : 0) {
	                        k = Oh(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 94240, 94296, 94248) | 0;
	                        c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] = k
	                    }
	                    if (c[(c[g >> 2] | 0) + 12 >> 2] | 0) {
	                        c[f >> 2] = 0;
	                        q = c[f >> 2] | 0;
	                        i = e;
	                        return q | 0
	                    } else {
	                        c[f >> 2] = -1;
	                        q = c[f >> 2] | 0;
	                        i = e;
	                        return q | 0
	                    }
	                }
	                zo(c[g >> 2] | 0, 1, 94632, 0, 0);
	                c[f >> 2] = 1;
	                q = c[f >> 2] | 0;
	                i = e;
	                return q | 0
	            }

	            function lo(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                Ae(c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function mo() {
	                var a = 0, b = 0, d = 0, e = 0, f = 0;
	                a = i;
	                i = i + 16 | 0;
	                b = a + 4 | 0;
	                d = a;
	                c[d >> 2] = Cb[c[135744 >> 2] & 511](472) | 0;
	                do if (c[d >> 2] | 0) {
	                    cU(c[d >> 2] | 0, 0, 472) | 0;
	                    e = (Jo(c[d >> 2] | 0) | 0) < 0;
	                    f = c[d >> 2] | 0;
	                    if (e) {
	                        lo(f);
	                        c[b >> 2] = 0;
	                        break
	                    } else {
	                        c[b >> 2] = f;
	                        break
	                    }
	                } else {
	                    xo(0, 94696);
	                    c[b >> 2] = 0
	                } while (0);
	                i = a;
	                return c[b >> 2] | 0
	            }

	            function no(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                do if (c[f >> 2] | 0) {
	                    if ((c[g >> 2] | 0) <= 0) {
	                        c[e >> 2] = 0;
	                        break
	                    }
	                    c[h >> 2] = mo() | 0;
	                    if (!(c[h >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        break
	                    }
	                    c[k >> 2] = Hk(c[f >> 2] | 0, c[g >> 2] | 0, 0) | 0;
	                    if (!(c[k >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        break
	                    }
	                    c[j >> 2] = ue(c[h >> 2] | 0) | 0;
	                    if (!(c[j >> 2] | 0)) {
	                        Ae(c[h >> 2] | 0);
	                        c[e >> 2] = 0;
	                        break
	                    } else {
	                        c[(c[j >> 2] | 0) + 4 >> 2] = 0;
	                        c[c[j >> 2] >> 2] = c[k >> 2];
	                        iz(c[(c[k >> 2] | 0) + 16 >> 2] | 0, c[j >> 2] | 0) | 0;
	                        Oe(c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                        c[e >> 2] = c[h >> 2];
	                        break
	                    }
	                } else c[e >> 2] = 0; while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function oo(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f + 44 | 0;
	                h = f + 40 | 0;
	                j = f + 36 | 0;
	                k = f + 32 | 0;
	                l = f + 28 | 0;
	                m = f + 24 | 0;
	                n = f + 20 | 0;
	                o = f + 16 | 0;
	                p = f + 12 | 0;
	                q = f + 8 | 0;
	                r = f + 4 | 0;
	                s = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if ((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) {
	                    do if ((((c[k >> 2] | 0) > 0 & (c[j >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[c[(c[h >> 2] | 0) + 36 >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[h >> 2] | 0) + 172 >> 2] | 0) != -1 : 0) {
	                        c[m >> 2] = jz(c[(c[c[(c[h >> 2] | 0) + 36 >> 2] >> 2] | 0) + 16 >> 2] | 0, c[(c[h >> 2] | 0) + 36 >> 2] | 0) | 0;
	                        c[n >> 2] = (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0);
	                        c[o >> 2] = Lk(c[c[(c[h >> 2] | 0) + 36 >> 2] >> 2] | 0, c[k >> 2] | 0, c[j >> 2] | 0) | 0;
	                        e = c[h >> 2] | 0;
	                        if ((c[o >> 2] | 0) >= 0) {
	                            kz(c[(c[c[e + 36 >> 2] >> 2] | 0) + 16 >> 2] | 0, c[(c[h >> 2] | 0) + 36 >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0) | 0;
	                            break
	                        }
	                        c[e + 84 >> 2] = -1;
	                        c[(c[h >> 2] | 0) + 212 >> 2] = 1;
	                        c[g >> 2] = -1;
	                        t = c[g >> 2] | 0;
	                        i = f;
	                        return t | 0
	                    } else u = 11; while (0);
	                    do if (((((((u | 0) == 11 ? (c[(c[h >> 2] | 0) + 172 >> 2] | 0) != -1 : 0) ? (c[(c[h >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[c[(c[h >> 2] | 0) + 36 >> 2] >> 2] | 0) != 0 : 0) ? (c[p >> 2] = c[c[(c[h >> 2] | 0) + 36 >> 2] >> 2], (c[(c[p >> 2] | 0) + 12 >> 2] | 0) != 0) : 0) ? (c[(c[p >> 2] | 0) + 16 >> 2] | 0) != 0 : 0) ? (c[(c[p >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) {
	                        c[r >> 2] = jz(c[(c[p >> 2] | 0) + 16 >> 2] | 0, c[(c[h >> 2] | 0) + 36 >> 2] | 0) | 0;
	                        c[s >> 2] = (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0);
	                        c[q >> 2] = Fd(c[p >> 2] | 0, c[l >> 2] | 0) | 0;
	                        if ((c[q >> 2] | 0) >= 0) {
	                            kz(c[(c[p >> 2] | 0) + 16 >> 2] | 0, c[(c[h >> 2] | 0) + 36 >> 2] | 0, c[r >> 2] | 0, c[s >> 2] | 0) | 0;
	                            break
	                        }
	                        zo(c[h >> 2] | 0, 81, 94760, 0, 0);
	                        c[g >> 2] = 81;
	                        t = c[g >> 2] | 0;
	                        i = f;
	                        return t | 0
	                    } while (0);
	                    Ko(c[h >> 2] | 0, c[l >> 2] | 0) | 0;
	                    if (c[l >> 2] | 0) {
	                        if (((c[(c[h >> 2] | 0) + 172 >> 2] | 0) != -1 ? (c[(c[h >> 2] | 0) + 172 >> 2] | 0) != 14 : 0) ? (c[(c[h >> 2] | 0) + 172 >> 2] | 0) != 1 : 0) {
	                            c[(c[h >> 2] | 0) + 84 >> 2] = 5;
	                            c[(c[h >> 2] | 0) + 12 >> 2] = 0
	                        }
	                        if (((c[(c[h >> 2] | 0) + 172 >> 2] | 0) != -1 ? (c[c[h >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[c[h >> 2] >> 2] | 0) + 52 >> 2] | 0) != 0 : 0)zb[c[(c[c[h >> 2] >> 2] | 0) + 52 >> 2] & 511](c[(c[h >> 2] | 0) + 4 >> 2] | 0);
	                        c[(c[h >> 2] | 0) + 172 >> 2] = -1
	                    }
	                    c[g >> 2] = c[(c[h >> 2] | 0) + 84 >> 2];
	                    t = c[g >> 2] | 0;
	                    i = f;
	                    return t | 0
	                }
	                zo(c[h >> 2] | 0, 1, 94728, 0, 0);
	                c[g >> 2] = 1;
	                t = c[g >> 2] | 0;
	                i = f;
	                return t | 0
	            }

	            function po(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h + 44 | 0;
	                k = h + 40 | 0;
	                l = h + 36 | 0;
	                m = h + 32 | 0;
	                n = h + 28 | 0;
	                o = h + 24 | 0;
	                p = h + 20 | 0;
	                q = h + 16 | 0;
	                r = h + 12 | 0;
	                s = h + 8 | 0;
	                t = h + 4 | 0;
	                u = h;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                Rf();
	                c[s >> 2] = vk(c[p >> 2] | 0) | 0;
	                if (!(c[s >> 2] | 0)) {
	                    c[j >> 2] = 0;
	                    v = c[j >> 2] | 0;
	                    i = h;
	                    return v | 0
	                }
	                c[q >> 2] = mo() | 0;
	                if (!(c[q >> 2] | 0)) {
	                    yk(c[s >> 2] | 0);
	                    c[j >> 2] = 0;
	                    v = c[j >> 2] | 0;
	                    i = h;
	                    return v | 0
	                }
	                if (!((c[p >> 2] | 0) != 1 ? (c[(c[s >> 2] | 0) + 12 >> 2] | 0) == 0 : 0))c[(c[q >> 2] | 0) + 256 >> 2] = 1;
	                do if (c[k >> 2] | 0) {
	                    if ((c[c[q >> 2] >> 2] | 0) != 136096)zb[c[135736 >> 2] & 511](c[c[q >> 2] >> 2] | 0);
	                    p = Cb[c[135744 >> 2] & 511](128) | 0;
	                    c[c[q >> 2] >> 2] = p;
	                    if (!(c[c[q >> 2] >> 2] | 0)) {
	                        zb[c[135736 >> 2] & 511](c[s >> 2] | 0);
	                        zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                        c[j >> 2] = 0;
	                        v = c[j >> 2] | 0;
	                        i = h;
	                        return v | 0
	                    } else {
	                        p = (c[c[q >> 2] >> 2] | 0) + 0 | 0;
	                        g = (c[k >> 2] | 0) + 0 | 0;
	                        f = p + 128 | 0;
	                        do {
	                            c[p >> 2] = c[g >> 2];
	                            p = p + 4 | 0;
	                            g = g + 4 | 0
	                        } while ((p | 0) < (f | 0));
	                        if (!(c[l >> 2] | 0))break;
	                        c[(c[q >> 2] | 0) + 4 >> 2] = c[l >> 2];
	                        break
	                    }
	                } while (0);
	                if (!(c[o >> 2] | 0))c[(c[q >> 2] | 0) + 180 >> 2] = 0; else {
	                    l = Rk(c[o >> 2] | 0) | 0;
	                    c[(c[q >> 2] | 0) + 180 >> 2] = l
	                }
	                c[r >> 2] = Lo(c[q >> 2] | 0) | 0;
	                if (!(c[r >> 2] | 0)) {
	                    Ae(c[q >> 2] | 0);
	                    zb[c[135736 >> 2] & 511](c[s >> 2] | 0);
	                    c[j >> 2] = 0;
	                    v = c[j >> 2] | 0;
	                    i = h;
	                    return v | 0
	                }
	                if (!(c[o >> 2] | 0))c[(c[r >> 2] | 0) + 4 >> 2] = 0; else {
	                    l = Jl(c[o >> 2] | 0) | 0;
	                    c[(c[r >> 2] | 0) + 4 >> 2] = l
	                }
	                c[c[r >> 2] >> 2] = c[s >> 2];
	                iz(c[(c[s >> 2] | 0) + 16 >> 2] | 0, c[r >> 2] | 0) | 0;
	                Oe(c[q >> 2] | 0, c[r >> 2] | 0) | 0;
	                if (((c[n >> 2] | 0) > 0 & (c[m >> 2] | 0) != 0 ? (c[(c[q >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[c[(c[q >> 2] | 0) + 36 >> 2] >> 2] | 0) != 0 : 0) {
	                    c[t >> 2] = jz(c[(c[c[(c[q >> 2] | 0) + 36 >> 2] >> 2] | 0) + 16 >> 2] | 0, c[(c[q >> 2] | 0) + 36 >> 2] | 0) | 0;
	                    c[u >> 2] = (c[(c[(c[q >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[q >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0);
	                    Lk(c[c[(c[q >> 2] | 0) + 36 >> 2] >> 2] | 0, c[n >> 2] | 0, c[m >> 2] | 0) | 0;
	                    kz(c[(c[c[(c[q >> 2] | 0) + 36 >> 2] >> 2] | 0) + 16 >> 2] | 0, c[(c[q >> 2] | 0) + 36 >> 2] | 0, c[t >> 2] | 0, c[u >> 2] | 0) | 0
	                }
	                c[(c[q >> 2] | 0) + 292 >> 2] = 1;
	                c[j >> 2] = c[q >> 2];
	                v = c[j >> 2] | 0;
	                i = h;
	                return v | 0
	            }

	            function qo(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                d = i;
	                i = i + 48 | 0;
	                e = d;
	                f = d + 36 | 0;
	                g = d + 32 | 0;
	                h = d + 28 | 0;
	                j = d + 24 | 0;
	                k = d + 20 | 0;
	                l = d + 16 | 0;
	                m = d + 12 | 0;
	                n = d + 8 | 0;
	                o = d + 4 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[n >> 2] = 94776;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    p = c[f >> 2] | 0;
	                    i = d;
	                    return p | 0
	                }
	                c[j >> 2] = mo() | 0;
	                if (!(c[j >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    p = c[f >> 2] | 0;
	                    i = d;
	                    return p | 0
	                }
	                c[l >> 2] = Jl(c[g >> 2] | 0) | 0;
	                if (!(c[l >> 2] | 0)) {
	                    if (c[34014] | 0)Db[c[135968 + 88 >> 2] & 511](0, 94792, e);
	                    Ae(c[j >> 2] | 0);
	                    c[f >> 2] = 0;
	                    p = c[f >> 2] | 0;
	                    i = d;
	                    return p | 0
	                }
	                c[k >> 2] = Vk(c[l >> 2] | 0, 0, c[j >> 2] | 0) | 0;
	                zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                l = c[j >> 2] | 0;
	                if (!(c[k >> 2] | 0)) {
	                    Ae(l);
	                    c[f >> 2] = 0;
	                    p = c[f >> 2] | 0;
	                    i = d;
	                    return p | 0
	                }
	                Oe(l, c[k >> 2] | 0) | 0;
	                if (((c[h >> 2] | 0) != 0 ? (c[o >> 2] = ZT(c[h >> 2] | 0) | 0, (c[o >> 2] | 0) >>> 0 < 1e3) : 0) ? (k = c[33938] | 0, l = xy(c[n >> 2] | 0) | 0, c[m >> 2] = Cb[k & 511](l + (c[o >> 2] | 0) + 1 | 0) | 0, (c[m >> 2] | 0) != 0) : 0) {
	                    gU(c[m >> 2] | 0, c[n >> 2] | 0) | 0;
	                    _T(c[m >> 2] | 0, c[h >> 2] | 0) | 0;
	                    Mo(c[j >> 2] | 0, c[m >> 2] | 0);
	                    zb[c[135736 >> 2] & 511](c[m >> 2] | 0)
	                }
	                c[f >> 2] = c[j >> 2];
	                p = c[f >> 2] | 0;
	                i = d;
	                return p | 0
	            }

	            function ro(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 28 | 0;
	                h = f + 24 | 0;
	                j = f + 20 | 0;
	                k = f + 16 | 0;
	                l = f + 12 | 0;
	                m = f + 8 | 0;
	                n = f + 4 | 0;
	                o = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[o >> 2] = 0;
	                Rf();
	                c[n >> 2] = qo(c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                if (!(c[n >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                if (c[k >> 2] | 0) {
	                    c[o >> 2] = c[c[n >> 2] >> 2];
	                    c[c[n >> 2] >> 2] = c[k >> 2];
	                    c[(c[n >> 2] | 0) + 4 >> 2] = c[l >> 2]
	                }
	                ko(c[n >> 2] | 0) | 0;
	                c[m >> 2] = c[(c[n >> 2] | 0) + 8 >> 2];
	                if (c[k >> 2] | 0) {
	                    c[c[n >> 2] >> 2] = c[o >> 2];
	                    c[(c[n >> 2] | 0) + 4 >> 2] = 0
	                }
	                lo(c[n >> 2] | 0);
	                c[g >> 2] = c[m >> 2];
	                p = c[g >> 2] | 0;
	                i = f;
	                return p | 0
	            }

	            function so(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                b = ro(c[e >> 2] | 0, c[f >> 2] | 0, 0, 0) | 0;
	                i = d;
	                return b | 0
	            }

	            function to(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                if (c[g >> 2] & 64) {
	                    c[(c[c[f >> 2] >> 2] | 0) + 84 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 116 >> 2] = 0;
	                    c[g >> 2] = (c[g >> 2] | 0) - 64;
	                    b = (c[f >> 2] | 0) + 360 | 0;
	                    c[b >> 2] = c[b >> 2] | 64
	                }
	                if (c[g >> 2] & 32) {
	                    c[(c[c[f >> 2] >> 2] | 0) + 88 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 112 >> 2] = 0;
	                    c[(c[c[f >> 2] >> 2] | 0) + 92 >> 2] = 0;
	                    c[g >> 2] = (c[g >> 2] | 0) - 32;
	                    b = (c[f >> 2] | 0) + 360 | 0;
	                    c[b >> 2] = c[b >> 2] | 32
	                }
	                b = (c[f >> 2] | 0) + 268 | 0;
	                if (c[g >> 2] & 128) {
	                    c[b >> 2] = 1;
	                    c[g >> 2] = (c[g >> 2] | 0) - 128;
	                    a = (c[f >> 2] | 0) + 360 | 0;
	                    c[a >> 2] = c[a >> 2] | 128
	                } else c[b >> 2] = 0;
	                b = (c[f >> 2] | 0) + 208 | 0;
	                if (c[g >> 2] & 256) {
	                    c[b >> 2] = 0;
	                    c[(c[c[f >> 2] >> 2] | 0) + 72 >> 2] = 65;
	                    c[g >> 2] = (c[g >> 2] | 0) - 256;
	                    a = (c[f >> 2] | 0) + 360 | 0;
	                    c[a >> 2] = c[a >> 2] | 256
	                } else c[b >> 2] = 1;
	                b = (c[f >> 2] | 0) + 288 | 0;
	                if (c[g >> 2] & 1) {
	                    c[b >> 2] = 1;
	                    c[g >> 2] = (c[g >> 2] | 0) - 1
	                } else c[b >> 2] = 0;
	                if (c[g >> 2] & 65536) {
	                    b = (c[f >> 2] | 0) + 360 | 0;
	                    c[b >> 2] = c[b >> 2] | 65536;
	                    c[g >> 2] = (c[g >> 2] | 0) - 65536
	                }
	                if (c[g >> 2] & 524288) {
	                    b = (c[f >> 2] | 0) + 360 | 0;
	                    c[b >> 2] = c[b >> 2] | 524288;
	                    c[g >> 2] = (c[g >> 2] | 0) - 524288
	                }
	                if (c[g >> 2] & 4) {
	                    b = (c[f >> 2] | 0) + 360 | 0;
	                    c[b >> 2] = c[b >> 2] | 4;
	                    c[g >> 2] = (c[g >> 2] | 0) - 4
	                }
	                if (c[g >> 2] & 2097152) {
	                    b = (c[f >> 2] | 0) + 360 | 0;
	                    c[b >> 2] = c[b >> 2] | 2097152;
	                    c[g >> 2] = (c[g >> 2] | 0) - 2097152
	                }
	                if (c[g >> 2] & 8192) {
	                    b = (c[f >> 2] | 0) + 360 | 0;
	                    c[b >> 2] = c[b >> 2] | 8192;
	                    c[g >> 2] = (c[g >> 2] | 0) - 8192
	                }
	                c[(c[f >> 2] | 0) + 364 >> 2] = 0;
	                c[e >> 2] = c[g >> 2];
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function uo(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                Rf();
	                c[k >> 2] = qo(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } else {
	                    c[f >> 2] = No(c[k >> 2] | 0, 0, 0, c[j >> 2] | 0, 0) | 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                return 0
	            }

	            function vo(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 24 | 0;
	                j = g + 20 | 0;
	                k = g + 16 | 0;
	                l = g + 12 | 0;
	                m = g + 8 | 0;
	                n = g + 4 | 0;
	                o = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                Rf();
	                c[o >> 2] = Zf(c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                if (!(c[o >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    p = c[h >> 2] | 0;
	                    i = g;
	                    return p | 0
	                }
	                rQ();
	                if (c[c[o >> 2] >> 2] | 0) {
	                    k = (c[c[o >> 2] >> 2] | 0) + 0 | 0;
	                    j = 136096 | 0;
	                    f = k + 112 | 0;
	                    do {
	                        c[k >> 2] = c[j >> 2];
	                        k = k + 4 | 0;
	                        j = j + 4 | 0
	                    } while ((k | 0) < (f | 0))
	                }
	                c[h >> 2] = No(c[o >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0, 0) | 0;
	                p = c[h >> 2] | 0;
	                i = g;
	                return p | 0
	            }

	            function wo(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[k >> 2] = 0;
	                if (!(c[21466] | 0))ao();
	                c[j >> 2] = 0;
	                while (1) {
	                    if ((c[j >> 2] | 0) >= 100)break;
	                    c[k >> 2] = c[85872 + (c[j >> 2] << 2) >> 2];
	                    if (!(c[k >> 2] | 0)) {
	                        l = 6;
	                        break
	                    }
	                    if (qy(c[c[k >> 2] >> 2] | 0, c[f >> 2] | 0) | 0)break;
	                    c[j >> 2] = (c[j >> 2] | 0) + 1
	                }
	                if ((l | 0) == 6) {
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                c[h >> 2] = ((c[k >> 2] | 0) - 86272 | 0) / 4 | 0;
	                c[h >> 2] = (c[h >> 2] | 0) + 1;
	                while (1) {
	                    if (!(c[86272 + (c[h >> 2] << 2) >> 2] | 0)) {
	                        l = 14;
	                        break
	                    }
	                    if (qy(c[86272 + (c[h >> 2] << 2) >> 2] | 0, c[g >> 2] | 0) | 0) {
	                        l = 12;
	                        break
	                    }
	                    c[h >> 2] = (c[h >> 2] | 0) + 1
	                }
	                if ((l | 0) == 12) {
	                    c[e >> 2] = 1;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                } else if ((l | 0) == 14) {
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                return 0
	            }

	            function xo(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 212 >> 2] | 0) != 0 : 0) ? (c[(c[f >> 2] | 0) + 172 >> 2] | 0) == -1 : 0) {
	                    i = d;
	                    return
	                }
	                if (c[f >> 2] | 0) {
	                    c[(c[f >> 2] | 0) + 84 >> 2] = 2;
	                    c[(c[f >> 2] | 0) + 172 >> 2] = -1;
	                    c[(c[f >> 2] | 0) + 212 >> 2] = 1
	                }
	                b = c[f >> 2] | 0;
	                if (c[g >> 2] | 0) {
	                    f = c[g >> 2] | 0;
	                    c[e >> 2] = c[g >> 2];
	                    Xd(0, 0, 0, b, 0, 1, 2, 3, 0, 0, f, 0, 0, 0, 0, 98040, e);
	                    i = d;
	                    return
	                } else {
	                    Xd(0, 0, 0, b, 0, 1, 2, 3, 0, 0, 0, 0, 0, 0, 0, 98072, e);
	                    i = d;
	                    return
	                }
	            }

	            function yo(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                b = i;
	                i = i + 32 | 0;
	                e = b + 16 | 0;
	                f = b + 12 | 0;
	                g = b + 8 | 0;
	                h = b + 4 | 0;
	                j = b;
	                c[f >> 2] = a;
	                c[j >> 2] = 0;
	                if ((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0;
	                c[g >> 2] = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                if ((d[c[g >> 2] >> 0] | 0 | 0) >= 97 ? (d[c[g >> 2] >> 0] | 0 | 0) <= 122 : 0)k = 10; else k = 6;
	                do if ((k | 0) == 6) {
	                    if ((d[c[g >> 2] >> 0] | 0 | 0) >= 65 ? (d[c[g >> 2] >> 0] | 0 | 0) <= 90 : 0) {
	                        k = 10;
	                        break
	                    }
	                    if (!((d[c[g >> 2] >> 0] | 0 | 0) != 95 ? (d[c[g >> 2] >> 0] | 0 | 0) != 58 : 0))k = 10
	                } while (0);
	                if ((k | 0) == 10) {
	                    c[g >> 2] = (c[g >> 2] | 0) + 1;
	                    while (1) {
	                        if ((d[c[g >> 2] >> 0] | 0 | 0) >= 97 ? (d[c[g >> 2] >> 0] | 0 | 0) <= 122 : 0)l = 1; else k = 13;
	                        do if ((k | 0) == 13) {
	                            k = 0;
	                            if ((d[c[g >> 2] >> 0] | 0 | 0) >= 65 ? (d[c[g >> 2] >> 0] | 0 | 0) <= 90 : 0) {
	                                l = 1;
	                                break
	                            }
	                            if ((d[c[g >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[g >> 2] >> 0] | 0 | 0) <= 57 : 0) {
	                                l = 1;
	                                break
	                            }
	                            if (((d[c[g >> 2] >> 0] | 0 | 0) != 95 ? (d[c[g >> 2] >> 0] | 0 | 0) != 45 : 0) ? (d[c[g >> 2] >> 0] | 0 | 0) != 58 : 0)l = (d[c[g >> 2] >> 0] | 0 | 0) == 46; else l = 1
	                        } while (0);
	                        m = c[g >> 2] | 0;
	                        if (!l)break;
	                        c[g >> 2] = m + 1
	                    }
	                    if ((d[m >> 0] | 0 | 0) > 0 ? (d[c[g >> 2] >> 0] | 0 | 0) < 128 : 0) {
	                        c[j >> 2] = (c[g >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0);
	                        c[h >> 2] = AP(c[(c[f >> 2] | 0) + 296 >> 2] | 0, c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0, c[j >> 2] | 0) | 0;
	                        c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] = c[g >> 2];
	                        g = (c[f >> 2] | 0) + 200 | 0;
	                        c[g >> 2] = (c[g >> 2] | 0) + (c[j >> 2] | 0);
	                        g = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                        c[g >> 2] = (c[g >> 2] | 0) + (c[j >> 2] | 0);
	                        c[e >> 2] = c[h >> 2];
	                        n = c[e >> 2] | 0;
	                        i = b;
	                        return n | 0
	                    }
	                }
	                c[e >> 2] = Oo(c[f >> 2] | 0) | 0;
	                n = c[e >> 2] | 0;
	                i = b;
	                return n | 0
	            }

	            function zo(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g;
	                j = g + 24 | 0;
	                k = g + 20 | 0;
	                l = g + 16 | 0;
	                m = g + 12 | 0;
	                n = g + 8 | 0;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                if (((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 212 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 172 >> 2] | 0) == -1 : 0) {
	                    i = g;
	                    return
	                }
	                if (c[j >> 2] | 0)c[(c[j >> 2] | 0) + 84 >> 2] = c[k >> 2];
	                f = c[j >> 2] | 0;
	                e = c[k >> 2] | 0;
	                k = c[m >> 2] | 0;
	                d = c[n >> 2] | 0;
	                b = c[l >> 2] | 0;
	                l = c[n >> 2] | 0;
	                c[h >> 2] = c[m >> 2];
	                c[h + 4 >> 2] = l;
	                Xd(0, 0, 0, f, 0, 5, e, 2, 0, 0, k, d, 0, 0, 0, b, h);
	                if (!(c[j >> 2] | 0)) {
	                    i = g;
	                    return
	                }
	                c[(c[j >> 2] | 0) + 12 >> 2] = 0;
	                i = g;
	                return
	            }

	            function Ao(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if (((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 212 >> 2] | 0) != 0 : 0) ? (c[(c[h >> 2] | 0) + 172 >> 2] | 0) == -1 : 0) {
	                    i = f;
	                    return
	                }
	                if (c[h >> 2] | 0)c[(c[h >> 2] | 0) + 84 >> 2] = c[j >> 2];
	                e = c[h >> 2] | 0;
	                d = c[j >> 2] | 0;
	                j = c[l >> 2] | 0;
	                b = c[k >> 2] | 0;
	                c[g >> 2] = c[l >> 2];
	                Xd(0, 0, 0, e, 0, 5, d, 2, 0, 0, 0, 0, 0, j, 0, b, g);
	                if (!(c[h >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                c[(c[h >> 2] | 0) + 12 >> 2] = 0;
	                i = f;
	                return
	            }

	            function Bo(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                b = i;
	                i = i + 64 | 0;
	                e = b + 52 | 0;
	                f = b + 48 | 0;
	                g = b + 44 | 0;
	                h = b + 40 | 0;
	                j = b + 36 | 0;
	                k = b + 32 | 0;
	                l = b + 28 | 0;
	                m = b + 24 | 0;
	                n = b + 20 | 0;
	                o = b + 16 | 0;
	                p = b + 12 | 0;
	                q = b + 8 | 0;
	                r = b + 4 | 0;
	                s = b;
	                c[f >> 2] = a;
	                c[l >> 2] = 0;
	                c[n >> 2] = 0;
	                c[p >> 2] = 0;
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) {
	                    if ((c[(c[f >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                        c[e >> 2] = -1;
	                        t = c[e >> 2] | 0;
	                        i = b;
	                        return t | 0
	                    }
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 60) {
	                        c[e >> 2] = -1;
	                        t = c[e >> 2] | 0;
	                        i = b;
	                        return t | 0
	                    }
	                    me(c[f >> 2] | 0);
	                    c[k >> 2] = c[(c[f >> 2] | 0) + 300 >> 2];
	                    c[m >> 2] = c[(c[f >> 2] | 0) + 304 >> 2];
	                    if ((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0;
	                    c[g >> 2] = Po(c[f >> 2] | 0) | 0;
	                    if (!(c[g >> 2] | 0)) {
	                        zo(c[f >> 2] | 0, 68, 97520, 0, 0);
	                        while (1) {
	                            if (!(9 <= (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0))u = 15;
	                            if (((u | 0) == 15 ? (u = 0, (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13) : 0) ? 32 > (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) : 0)break;
	                            if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 62)break;
	                            if ((c[(c[f >> 2] | 0) + 172 >> 2] | 0) == -1)break;
	                            me(c[f >> 2] | 0)
	                        }
	                        c[e >> 2] = -1;
	                        t = c[e >> 2] | 0;
	                        i = b;
	                        return t | 0
	                    }
	                    if (qy(c[g >> 2] | 0, 96200) | 0)c[n >> 2] = 1;
	                    Qo(c[f >> 2] | 0, c[g >> 2] | 0);
	                    Ro(c[f >> 2] | 0, c[g >> 2] | 0);
	                    if ((c[(c[f >> 2] | 0) + 188 >> 2] | 0) > 0 ? (qy(c[g >> 2] | 0, 94240) | 0) != 0 : 0) {
	                        zo(c[f >> 2] | 0, 800, 97656, c[g >> 2] | 0, 0);
	                        c[p >> 2] = 1;
	                        a = (c[f >> 2] | 0) + 248 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1
	                    }
	                    if ((c[(c[f >> 2] | 0) + 188 >> 2] | 0) != 1 ? (qy(c[g >> 2] | 0, 95656) | 0) != 0 : 0) {
	                        zo(c[f >> 2] | 0, 800, 97704, c[g >> 2] | 0, 0);
	                        c[p >> 2] = 1;
	                        a = (c[f >> 2] | 0) + 248 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1
	                    }
	                    a:do if (qy(c[g >> 2] | 0, 95648) | 0) {
	                        c[q >> 2] = 0;
	                        while (1) {
	                            if ((c[q >> 2] | 0) >= (c[(c[f >> 2] | 0) + 188 >> 2] | 0))break a;
	                            if (qy(c[(c[(c[f >> 2] | 0) + 196 >> 2] | 0) + (c[q >> 2] << 2) >> 2] | 0, 95648) | 0) {
	                                zo(c[f >> 2] | 0, 800, 97752, c[g >> 2] | 0, 0);
	                                c[p >> 2] = 1;
	                                a = (c[f >> 2] | 0) + 248 | 0;
	                                c[a >> 2] = (c[a >> 2] | 0) + 1
	                            }
	                            c[q >> 2] = (c[q >> 2] | 0) + 1
	                        }
	                    } while (0);
	                    Fo(c[f >> 2] | 0) | 0;
	                    while (1) {
	                        if (!(9 <= (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0))u = 38;
	                        if (((u | 0) == 38 ? (u = 0, (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13) : 0) ? 32 > (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) : 0)break;
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 62)break;
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 47 ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 62 : 0)break;
	                        c[r >> 2] = c[(c[f >> 2] | 0) + 200 >> 2];
	                        if ((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0;
	                        c[h >> 2] = So(c[f >> 2] | 0, j) | 0;
	                        b:do if (c[h >> 2] | 0) {
	                            c[o >> 2] = 0;
	                            while (1) {
	                                if ((c[o >> 2] | 0) >= (c[l >> 2] | 0))break;
	                                if (qy(c[(c[k >> 2] | 0) + (c[o >> 2] << 2) >> 2] | 0, c[h >> 2] | 0) | 0) {
	                                    u = 50;
	                                    break
	                                }
	                                c[o >> 2] = (c[o >> 2] | 0) + 2
	                            }
	                            if ((u | 0) == 50) {
	                                u = 0;
	                                zo(c[f >> 2] | 0, 42, 97800, c[h >> 2] | 0, 0);
	                                if (!(c[j >> 2] | 0))break;
	                                zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                                break
	                            }
	                            do if (!(c[k >> 2] | 0)) {
	                                c[m >> 2] = 22;
	                                c[k >> 2] = Cb[c[135744 >> 2] & 511](c[m >> 2] << 2) | 0;
	                                if (c[k >> 2] | 0) {
	                                    c[(c[f >> 2] | 0) + 300 >> 2] = c[k >> 2];
	                                    c[(c[f >> 2] | 0) + 304 >> 2] = c[m >> 2];
	                                    break
	                                }
	                                xo(c[f >> 2] | 0, 0);
	                                if (!(c[j >> 2] | 0))break b;
	                                zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                                break b
	                            } else {
	                                if (((c[l >> 2] | 0) + 4 | 0) <= (c[m >> 2] | 0))break;
	                                c[m >> 2] = c[m >> 2] << 1;
	                                c[s >> 2] = Hb[c[135760 >> 2] & 511](c[k >> 2] | 0, c[m >> 2] << 2) | 0;
	                                if (c[s >> 2] | 0) {
	                                    c[k >> 2] = c[s >> 2];
	                                    c[(c[f >> 2] | 0) + 300 >> 2] = c[k >> 2];
	                                    c[(c[f >> 2] | 0) + 304 >> 2] = c[m >> 2];
	                                    break
	                                }
	                                xo(c[f >> 2] | 0, 0);
	                                if (!(c[j >> 2] | 0))break b;
	                                zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                                break b
	                            } while (0);
	                            q = c[h >> 2] | 0;
	                            a = c[l >> 2] | 0;
	                            c[l >> 2] = a + 1;
	                            c[(c[k >> 2] | 0) + (a << 2) >> 2] = q;
	                            q = c[j >> 2] | 0;
	                            a = c[l >> 2] | 0;
	                            c[l >> 2] = a + 1;
	                            c[(c[k >> 2] | 0) + (a << 2) >> 2] = q;
	                            c[(c[k >> 2] | 0) + (c[l >> 2] << 2) >> 2] = 0;
	                            c[(c[k >> 2] | 0) + ((c[l >> 2] | 0) + 1 << 2) >> 2] = 0
	                        } else {
	                            if (c[j >> 2] | 0)zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                            while (1) {
	                                if (!(9 <= (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0))u = 68;
	                                do if ((u | 0) == 68) {
	                                    u = 0;
	                                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 13)break;
	                                    if (32 > (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0))break b
	                                } while (0);
	                                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 32)break b;
	                                if (9 <= (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break b;
	                                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 13)break b;
	                                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 62)break b;
	                                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 47 ? (d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 62 : 0)break b;
	                                me(c[f >> 2] | 0)
	                            }
	                        } while (0);
	                        Fo(c[f >> 2] | 0) | 0;
	                        if ((c[r >> 2] | 0) == (c[(c[f >> 2] | 0) + 200 >> 2] | 0)) {
	                            u = 79;
	                            break
	                        }
	                    }
	                    if ((u | 0) == 79)zo(c[f >> 2] | 0, 1, 97824, 0, 0);
	                    if ((c[n >> 2] | 0) != 0 & (c[l >> 2] | 0) != 0)To(c[f >> 2] | 0, c[k >> 2] | 0);
	                    do if (((c[p >> 2] | 0) == 0 ? (Uo(c[f >> 2] | 0, c[g >> 2] | 0) | 0, (c[c[f >> 2] >> 2] | 0) != 0) : 0) ? (c[(c[c[f >> 2] >> 2] | 0) + 56 >> 2] | 0) != 0 : 0) {
	                        n = c[(c[c[f >> 2] >> 2] | 0) + 56 >> 2] | 0;
	                        u = c[(c[f >> 2] | 0) + 4 >> 2] | 0;
	                        r = c[g >> 2] | 0;
	                        if (c[l >> 2] | 0) {
	                            Db[n & 511](u, r, c[k >> 2] | 0);
	                            break
	                        } else {
	                            Db[n & 511](u, r, 0);
	                            break
	                        }
	                    } while (0);
	                    c:do if (c[k >> 2] | 0) {
	                        c[o >> 2] = 1;
	                        while (1) {
	                            if ((c[o >> 2] | 0) >= (c[l >> 2] | 0))break c;
	                            if (c[(c[k >> 2] | 0) + (c[o >> 2] << 2) >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[k >> 2] | 0) + (c[o >> 2] << 2) >> 2] | 0);
	                            c[o >> 2] = (c[o >> 2] | 0) + 2
	                        }
	                    } while (0);
	                    c[e >> 2] = c[p >> 2];
	                    t = c[e >> 2] | 0;
	                    i = b;
	                    return t | 0
	                }
	                zo(c[f >> 2] | 0, 1, 97616, 0, 0);
	                c[e >> 2] = -1;
	                t = c[e >> 2] | 0;
	                i = b;
	                return t | 0
	            }

	            function Co(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if ((c[(c[e >> 2] | 0) + 188 >> 2] | 0) <= 0) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = (c[e >> 2] | 0) + 188 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + -1;
	                if ((c[(c[e >> 2] | 0) + 188 >> 2] | 0) < 0) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = c[e >> 2] | 0;
	                if ((c[(c[e >> 2] | 0) + 188 >> 2] | 0) > 0)c[(c[e >> 2] | 0) + 184 >> 2] = c[(c[(c[e >> 2] | 0) + 196 >> 2] | 0) + ((c[a + 188 >> 2] | 0) - 1 << 2) >> 2]; else c[a + 184 >> 2] = 0;
	                c[f >> 2] = c[(c[(c[e >> 2] | 0) + 196 >> 2] | 0) + (c[(c[e >> 2] | 0) + 188 >> 2] << 2) >> 2];
	                c[(c[(c[e >> 2] | 0) + 196 >> 2] | 0) + (c[(c[e >> 2] | 0) + 188 >> 2] << 2) >> 2] = 0;
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function Do(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                if (!(c[(c[d >> 2] | 0) + 188 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                c[e >> 2] = (c[(c[d >> 2] | 0) + 188 >> 2] | 0) - 1;
	                while (1) {
	                    if ((c[e >> 2] | 0) < 0)break;
	                    if ((c[c[d >> 2] >> 2] | 0) != 0 ? (c[(c[c[d >> 2] >> 2] | 0) + 60 >> 2] | 0) != 0 : 0)Ab[c[(c[c[d >> 2] >> 2] | 0) + 60 >> 2] & 511](c[(c[d >> 2] | 0) + 4 >> 2] | 0, c[(c[d >> 2] | 0) + 184 >> 2] | 0);
	                    Co(c[d >> 2] | 0) | 0;
	                    c[e >> 2] = (c[e >> 2] | 0) + -1
	                }
	                i = b;
	                return
	            }

	            function Eo(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                b = i;
	                i = i + 32 | 0;
	                e = b + 16 | 0;
	                f = b + 12 | 0;
	                g = b + 8 | 0;
	                h = b + 4 | 0;
	                j = b;
	                c[e >> 2] = a;
	                c[f >> 2] = my(c[(c[e >> 2] | 0) + 184 >> 2] | 0) | 0;
	                c[g >> 2] = c[(c[e >> 2] | 0) + 188 >> 2];
	                a:while (1) {
	                    c[j >> 2] = c[(c[e >> 2] | 0) + 200 >> 2];
	                    if ((c[(c[e >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)ke(c[(c[e >> 2] | 0) + 36 >> 2] | 0, 250) | 0;
	                    if ((c[(c[e >> 2] | 0) + 172 >> 2] | 0) == -1)break;
	                    if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 47 : 0) {
	                        if (!(Vo(c[e >> 2] | 0) | 0))continue;
	                        if ((c[f >> 2] | 0) == 0 ? (c[(c[e >> 2] | 0) + 188 >> 2] | 0) != 0 : 0)continue;
	                        if (c[f >> 2] | 0)zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                        c[f >> 2] = my(c[(c[e >> 2] | 0) + 184 >> 2] | 0) | 0;
	                        c[g >> 2] = c[(c[e >> 2] | 0) + 188 >> 2];
	                        continue
	                    }
	                    b:do if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60) {
	                        if (!(65 <= (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) <= 90 : 0))k = 17;
	                        do if ((k | 0) == 17) {
	                            k = 0;
	                            if (97 <= (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) <= 122 : 0)break;
	                            if ((d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) != 95 ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) != 58 : 0)break b
	                        } while (0);
	                        c[h >> 2] = Wo(c[e >> 2] | 0) | 0;
	                        a = c[e >> 2] | 0;
	                        if (c[h >> 2] | 0) {
	                            if (!(c[a + 184 >> 2] | 0))break;
	                            if ((wo(c[h >> 2] | 0, c[(c[e >> 2] | 0) + 184 >> 2] | 0) | 0) != 1)break;
	                            Qo(c[e >> 2] | 0, c[h >> 2] | 0);
	                            continue a
	                        }
	                        zo(a, 68, 97520, 0, 0);
	                        while (1) {
	                            if (9 <= (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)k = 27; else if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13 ? 32 > (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) : 0)l = 0; else k = 27;
	                            if ((k | 0) == 27) {
	                                k = 0;
	                                l = (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 62
	                            }
	                            m = c[e >> 2] | 0;
	                            if (!l)break;
	                            me(m)
	                        }
	                        _o(m);
	                        if (c[f >> 2] | 0)zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                        c[f >> 2] = my(c[(c[e >> 2] | 0) + 184 >> 2] | 0) | 0;
	                        c[g >> 2] = c[(c[e >> 2] | 0) + 188 >> 2];
	                        continue a
	                    } while (0);
	                    if (((c[(c[e >> 2] | 0) + 188 >> 2] | 0) > 0 ? (c[g >> 2] | 0) >= (c[(c[e >> 2] | 0) + 188 >> 2] | 0) : 0) ? (qy(c[f >> 2] | 0, c[(c[e >> 2] | 0) + 184 >> 2] | 0) | 0) == 0 : 0) {
	                        _o(c[e >> 2] | 0);
	                        if (c[f >> 2] | 0)zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                        c[f >> 2] = my(c[(c[e >> 2] | 0) + 184 >> 2] | 0) | 0;
	                        c[g >> 2] = c[(c[e >> 2] | 0) + 188 >> 2];
	                        continue
	                    }
	                    do if (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) {
	                        if ((qy(c[f >> 2] | 0, 94992) | 0) == 0 ? (qy(c[f >> 2] | 0, 95e3) | 0) == 0 : 0) {
	                            k = 46;
	                            break
	                        }
	                        Xo(c[e >> 2] | 0)
	                    } else k = 46; while (0);
	                    if ((k | 0) == 46) {
	                        k = 0;
	                        if (((((((((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 33 : 0) ? (WS(d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0) | 0) == 68 : 0) ? (WS(d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0) | 0) == 79 : 0) ? (WS(d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0) | 0) == 67 : 0) ? (WS(d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0) | 0) == 84 : 0) ? (WS(d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 6 >> 0] | 0) | 0) == 89 : 0) ? (WS(d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 7 >> 0] | 0) | 0) == 80 : 0) ? (WS(d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 8 >> 0] | 0) | 0) == 69 : 0) {
	                            zo(c[e >> 2] | 0, 800, 95008, 95040, 0);
	                            Io(c[e >> 2] | 0)
	                        }
	                        if ((((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 33 : 0) ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) == 45 : 0) ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) == 45 : 0)Go(c[e >> 2] | 0); else k = 61;
	                        do if ((k | 0) == 61) {
	                            k = 0;
	                            if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60 ? (d[(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 63 : 0) {
	                                Ho(c[e >> 2] | 0);
	                                break
	                            }
	                            a = c[e >> 2] | 0;
	                            if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 60) {
	                                $o(a);
	                                if (c[f >> 2] | 0)zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                                c[f >> 2] = my(c[(c[e >> 2] | 0) + 184 >> 2] | 0) | 0;
	                                c[g >> 2] = c[(c[e >> 2] | 0) + 188 >> 2];
	                                break
	                            }
	                            n = c[e >> 2] | 0;
	                            if ((d[c[(c[a + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 38) {
	                                Yo(n);
	                                break
	                            }
	                            o = c[e >> 2] | 0;
	                            if (!(d[c[(c[n + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0)) {
	                                k = 71;
	                                break a
	                            }
	                            Zo(o)
	                        } while (0);
	                        if ((c[j >> 2] | 0) == (c[(c[e >> 2] | 0) + 200 >> 2] | 0)) {
	                            k = 74;
	                            break
	                        }
	                    }
	                    if (c[(c[e >> 2] | 0) + 292 >> 2] | 0)continue;
	                    if (((c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) >= 250)continue;
	                    ke(c[(c[e >> 2] | 0) + 36 >> 2] | 0, 250) | 0
	                }
	                if ((k | 0) == 71)Do(o); else if ((k | 0) == 74 ? (c[(c[e >> 2] | 0) + 52 >> 2] | 0) != 0 : 0)zo(c[e >> 2] | 0, 1, 95064, 0, 0);
	                if (!(c[f >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                i = b;
	                return
	            }

	            function Fo(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                a:while (1) {
	                    do if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 0 ? (ke(c[(c[e >> 2] | 0) + 36 >> 2] | 0, 250) | 0) <= 0 : 0)Ve(c[e >> 2] | 0) | 0; else {
	                        a = c[(c[e >> 2] | 0) + 36 >> 2] | 0;
	                        if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                            g = a + 28 | 0;
	                            c[g >> 2] = (c[g >> 2] | 0) + 1;
	                            c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                        } else {
	                            g = a + 32 | 0;
	                            c[g >> 2] = (c[g >> 2] | 0) + 1
	                        }
	                        g = (c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                        c[g >> 2] = (c[g >> 2] | 0) + 1;
	                        g = (c[e >> 2] | 0) + 200 | 0;
	                        c[g >> 2] = (c[g >> 2] | 0) + 1;
	                        if (!(d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0))ke(c[(c[e >> 2] | 0) + 36 >> 2] | 0, 250) | 0
	                    }
	                    c[f >> 2] = (c[f >> 2] | 0) + 1
	                }
	                i = b;
	                return c[f >> 2] | 0
	            }

	            function Go(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 44 | 0;
	                g = e + 40 | 0;
	                h = e + 36 | 0;
	                j = e + 32 | 0;
	                k = e + 28 | 0;
	                l = e + 24 | 0;
	                m = e + 20 | 0;
	                n = e + 16 | 0;
	                o = e + 12 | 0;
	                p = e + 8 | 0;
	                q = e + 4 | 0;
	                r = e;
	                c[f >> 2] = b;
	                c[g >> 2] = 0;
	                c[j >> 2] = 100;
	                if (c[(c[f >> 2] | 0) + 176 >> 2] | 0)s = -1; else s = d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                if ((s | 0) != 60) {
	                    i = e;
	                    return
	                }
	                if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) != 33) {
	                    i = e;
	                    return
	                }
	                if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0 | 0) != 45) {
	                    i = e;
	                    return
	                }
	                if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0 | 0) != 45) {
	                    i = e;
	                    return
	                }
	                c[q >> 2] = c[(c[f >> 2] | 0) + 172 >> 2];
	                c[(c[f >> 2] | 0) + 172 >> 2] = 5;
	                if (((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)le(c[(c[f >> 2] | 0) + 36 >> 2] | 0);
	                s = (c[f >> 2] | 0) + 200 | 0;
	                c[s >> 2] = (c[s >> 2] | 0) + 4;
	                s = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                c[s >> 2] = (c[s >> 2] | 0) + 4;
	                s = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                c[s >> 2] = (c[s >> 2] | 0) + 4;
	                c[g >> 2] = Cb[c[135752 >> 2] & 511](c[j >> 2] | 0) | 0;
	                s = c[f >> 2] | 0;
	                if (!(c[g >> 2] | 0)) {
	                    xo(s, 97424);
	                    c[(c[f >> 2] | 0) + 172 >> 2] = c[q >> 2];
	                    i = e;
	                    return
	                }
	                c[k >> 2] = ap(s, l) | 0;
	                s = c[(c[f >> 2] | 0) + 36 >> 2] | 0;
	                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                    b = s + 28 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 1;
	                    c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                } else {
	                    b = s + 32 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 1
	                }
	                c[(c[f >> 2] | 0) + 176 >> 2] = 0;
	                b = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                c[b >> 2] = (c[b >> 2] | 0) + (c[l >> 2] | 0);
	                b = (c[f >> 2] | 0) + 200 | 0;
	                c[b >> 2] = (c[b >> 2] | 0) + 1;
	                c[m >> 2] = ap(c[f >> 2] | 0, n) | 0;
	                b = c[(c[f >> 2] | 0) + 36 >> 2] | 0;
	                if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                    s = b + 28 | 0;
	                    c[s >> 2] = (c[s >> 2] | 0) + 1;
	                    c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                } else {
	                    s = b + 32 | 0;
	                    c[s >> 2] = (c[s >> 2] | 0) + 1
	                }
	                c[(c[f >> 2] | 0) + 176 >> 2] = 0;
	                s = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                c[s >> 2] = (c[s >> 2] | 0) + (c[n >> 2] | 0);
	                s = (c[f >> 2] | 0) + 200 | 0;
	                c[s >> 2] = (c[s >> 2] | 0) + 1;
	                c[o >> 2] = ap(c[f >> 2] | 0, p) | 0;
	                c[h >> 2] = 0;
	                while (1) {
	                    s = c[o >> 2] | 0;
	                    if ((c[o >> 2] | 0) < 256)if (9 <= (s | 0) & (c[o >> 2] | 0) <= 10 | (c[o >> 2] | 0) == 13 | 32 <= (c[o >> 2] | 0))t = 24; else u = 0; else if ((!(256 <= (s | 0) & (c[o >> 2] | 0) <= 55295) ? !(57344 <= (c[o >> 2] | 0) & (c[o >> 2] | 0) <= 65533) : 0) ? !(65536 <= (c[o >> 2] | 0) & (c[o >> 2] | 0) <= 1114111) : 0)u = 0; else t = 24;
	                    if ((t | 0) == 24) {
	                        t = 0;
	                        if ((c[o >> 2] | 0) != 62 | (c[m >> 2] | 0) != 45)u = 1; else u = (c[k >> 2] | 0) != 45
	                    }
	                    v = c[h >> 2] | 0;
	                    if (!u)break;
	                    if ((v + 5 | 0) >= (c[j >> 2] | 0)) {
	                        c[j >> 2] = c[j >> 2] << 1;
	                        c[r >> 2] = Hb[c[135760 >> 2] & 511](c[g >> 2] | 0, c[j >> 2] | 0) | 0;
	                        if (!(c[r >> 2] | 0)) {
	                            t = 29;
	                            break
	                        }
	                        c[g >> 2] = c[r >> 2]
	                    }
	                    if ((c[l >> 2] | 0) == 1) {
	                        s = c[k >> 2] & 255;
	                        b = c[h >> 2] | 0;
	                        c[h >> 2] = b + 1;
	                        a[(c[g >> 2] | 0) + b >> 0] = s
	                    } else {
	                        s = qe(c[l >> 2] | 0, (c[g >> 2] | 0) + (c[h >> 2] | 0) | 0, c[k >> 2] | 0) | 0;
	                        c[h >> 2] = (c[h >> 2] | 0) + s
	                    }
	                    c[k >> 2] = c[m >> 2];
	                    c[l >> 2] = c[n >> 2];
	                    c[m >> 2] = c[o >> 2];
	                    c[n >> 2] = c[p >> 2];
	                    s = c[(c[f >> 2] | 0) + 36 >> 2] | 0;
	                    if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                        b = s + 28 | 0;
	                        c[b >> 2] = (c[b >> 2] | 0) + 1;
	                        c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                    } else {
	                        b = s + 32 | 0;
	                        c[b >> 2] = (c[b >> 2] | 0) + 1
	                    }
	                    c[(c[f >> 2] | 0) + 176 >> 2] = 0;
	                    b = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + (c[p >> 2] | 0);
	                    b = (c[f >> 2] | 0) + 200 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 1;
	                    c[o >> 2] = ap(c[f >> 2] | 0, p) | 0;
	                    if (c[o >> 2] | 0)continue;
	                    if (((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)le(c[(c[f >> 2] | 0) + 36 >> 2] | 0);
	                    if ((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0;
	                    c[o >> 2] = ap(c[f >> 2] | 0, p) | 0
	                }
	                if ((t | 0) == 29) {
	                    zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                    xo(c[f >> 2] | 0, 97456);
	                    c[(c[f >> 2] | 0) + 172 >> 2] = c[q >> 2];
	                    i = e;
	                    return
	                }
	                a[(c[g >> 2] | 0) + v >> 0] = 0;
	                v = c[o >> 2] | 0;
	                if ((c[o >> 2] | 0) < 256)if (9 <= (v | 0) & (c[o >> 2] | 0) <= 10 | (c[o >> 2] | 0) == 13 | 32 <= (c[o >> 2] | 0))t = 51; else t = 50; else if ((!(256 <= (v | 0) & (c[o >> 2] | 0) <= 55295) ? !(57344 <= (c[o >> 2] | 0) & (c[o >> 2] | 0) <= 65533) : 0) ? !(65536 <= (c[o >> 2] | 0) & (c[o >> 2] | 0) <= 1114111) : 0)t = 50; else t = 51;
	                if ((t | 0) == 50) {
	                    zo(c[f >> 2] | 0, 45, 97480, c[g >> 2] | 0, 0);
	                    zb[c[135736 >> 2] & 511](c[g >> 2] | 0)
	                } else if ((t | 0) == 51) {
	                    me(c[f >> 2] | 0);
	                    if (((c[c[f >> 2] >> 2] | 0) != 0 ? (c[(c[c[f >> 2] >> 2] | 0) + 80 >> 2] | 0) != 0 : 0) ? (c[(c[f >> 2] | 0) + 212 >> 2] | 0) == 0 : 0)Ab[c[(c[c[f >> 2] >> 2] | 0) + 80 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0, c[g >> 2] | 0);
	                    zb[c[135736 >> 2] & 511](c[g >> 2] | 0)
	                }
	                c[(c[f >> 2] | 0) + 172 >> 2] = c[q >> 2];
	                i = e;
	                return
	            }

	            function Ho(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 36 | 0;
	                g = e + 32 | 0;
	                h = e + 28 | 0;
	                j = e + 24 | 0;
	                k = e + 20 | 0;
	                l = e + 16 | 0;
	                m = e + 12 | 0;
	                n = e + 8 | 0;
	                o = e + 4 | 0;
	                p = e;
	                c[f >> 2] = b;
	                c[g >> 2] = 0;
	                c[h >> 2] = 0;
	                c[j >> 2] = 100;
	                c[o >> 2] = 0;
	                if (c[(c[f >> 2] | 0) + 176 >> 2] | 0)q = -1; else q = d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                if ((q | 0) != 60) {
	                    i = e;
	                    return
	                }
	                if ((d[(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) != 63) {
	                    i = e;
	                    return
	                }
	                c[n >> 2] = c[(c[f >> 2] | 0) + 172 >> 2];
	                c[(c[f >> 2] | 0) + 172 >> 2] = 2;
	                q = (c[f >> 2] | 0) + 200 | 0;
	                c[q >> 2] = (c[q >> 2] | 0) + 2;
	                q = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                c[q >> 2] = (c[q >> 2] | 0) + 2;
	                q = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                c[q >> 2] = (c[q >> 2] | 0) + 2;
	                if (((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 500 : 0)le(c[(c[f >> 2] | 0) + 36 >> 2] | 0);
	                c[m >> 2] = yo(c[f >> 2] | 0) | 0;
	                q = c[f >> 2] | 0;
	                if (c[m >> 2] | 0) {
	                    if (c[q + 176 >> 2] | 0)r = -1; else r = d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                    if ((r | 0) == 62) {
	                        r = (c[f >> 2] | 0) + 200 | 0;
	                        c[r >> 2] = (c[r >> 2] | 0) + 1;
	                        r = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                        c[r >> 2] = (c[r >> 2] | 0) + 1;
	                        r = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                        c[r >> 2] = (c[r >> 2] | 0) + 1;
	                        if (((c[c[f >> 2] >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 212 >> 2] | 0) == 0 : 0) ? (c[(c[c[f >> 2] >> 2] | 0) + 76 >> 2] | 0) != 0 : 0)Db[c[(c[c[f >> 2] >> 2] | 0) + 76 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0, c[m >> 2] | 0, 0);
	                        c[(c[f >> 2] | 0) + 172 >> 2] = c[n >> 2];
	                        i = e;
	                        return
	                    }
	                    c[g >> 2] = Cb[c[135752 >> 2] & 511](c[j >> 2] | 0) | 0;
	                    r = c[f >> 2] | 0;
	                    if (!(c[g >> 2] | 0)) {
	                        xo(r, 0);
	                        c[(c[f >> 2] | 0) + 172 >> 2] = c[n >> 2];
	                        i = e;
	                        return
	                    }
	                    c[k >> 2] = d[c[(c[r + 36 >> 2] | 0) + 16 >> 2] >> 0];
	                    if ((c[k >> 2] | 0) < 256) {
	                        if ((c[k >> 2] | 0) != 32 ? !(9 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 10 | (c[k >> 2] | 0) == 13) : 0)s = 22
	                    } else s = 22;
	                    if ((s | 0) == 22)zo(c[f >> 2] | 0, 65, 97328, c[m >> 2] | 0, 0);
	                    Fo(c[f >> 2] | 0) | 0;
	                    c[k >> 2] = ap(c[f >> 2] | 0, l) | 0;
	                    while (1) {
	                        r = c[k >> 2] | 0;
	                        if ((c[k >> 2] | 0) < 256)if (9 <= (r | 0) & (c[k >> 2] | 0) <= 10 | (c[k >> 2] | 0) == 13 | 32 <= (c[k >> 2] | 0))s = 29; else t = 0; else if ((!(256 <= (r | 0) & (c[k >> 2] | 0) <= 55295) ? !(57344 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 65533) : 0) ? !(65536 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 1114111) : 0)t = 0; else s = 29;
	                        if ((s | 0) == 29) {
	                            s = 0;
	                            t = (c[k >> 2] | 0) != 62
	                        }
	                        u = c[h >> 2] | 0;
	                        if (!t)break;
	                        if ((u + 5 | 0) >= (c[j >> 2] | 0)) {
	                            c[j >> 2] = c[j >> 2] << 1;
	                            c[p >> 2] = Hb[c[135760 >> 2] & 511](c[g >> 2] | 0, c[j >> 2] | 0) | 0;
	                            if (!(c[p >> 2] | 0)) {
	                                s = 33;
	                                break
	                            }
	                            c[g >> 2] = c[p >> 2]
	                        }
	                        c[o >> 2] = (c[o >> 2] | 0) + 1;
	                        if ((c[o >> 2] | 0) > 50) {
	                            if ((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0;
	                            c[o >> 2] = 0
	                        }
	                        if ((c[l >> 2] | 0) == 1) {
	                            r = c[k >> 2] & 255;
	                            b = c[h >> 2] | 0;
	                            c[h >> 2] = b + 1;
	                            a[(c[g >> 2] | 0) + b >> 0] = r
	                        } else {
	                            r = qe(c[l >> 2] | 0, (c[g >> 2] | 0) + (c[h >> 2] | 0) | 0, c[k >> 2] | 0) | 0;
	                            c[h >> 2] = (c[h >> 2] | 0) + r
	                        }
	                        r = c[(c[f >> 2] | 0) + 36 >> 2] | 0;
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                            b = r + 28 | 0;
	                            c[b >> 2] = (c[b >> 2] | 0) + 1;
	                            c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                        } else {
	                            b = r + 32 | 0;
	                            c[b >> 2] = (c[b >> 2] | 0) + 1
	                        }
	                        c[(c[f >> 2] | 0) + 176 >> 2] = 0;
	                        b = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                        c[b >> 2] = (c[b >> 2] | 0) + (c[l >> 2] | 0);
	                        b = (c[f >> 2] | 0) + 200 | 0;
	                        c[b >> 2] = (c[b >> 2] | 0) + 1;
	                        c[k >> 2] = ap(c[f >> 2] | 0, l) | 0;
	                        if (c[k >> 2] | 0)continue;
	                        do if (((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0) > 500) {
	                            if (((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) >= 500)break;
	                            le(c[(c[f >> 2] | 0) + 36 >> 2] | 0)
	                        } while (0);
	                        do if (!(c[(c[f >> 2] | 0) + 292 >> 2] | 0)) {
	                            if (((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) >= 250)break;
	                            ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0
	                        } while (0);
	                        c[k >> 2] = ap(c[f >> 2] | 0, l) | 0
	                    }
	                    if ((s | 0) == 33) {
	                        xo(c[f >> 2] | 0, 0);
	                        zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                        c[(c[f >> 2] | 0) + 172 >> 2] = c[n >> 2];
	                        i = e;
	                        return
	                    }
	                    a[(c[g >> 2] | 0) + u >> 0] = 0;
	                    u = c[f >> 2] | 0;
	                    if ((c[k >> 2] | 0) == 62) {
	                        k = u + 200 | 0;
	                        c[k >> 2] = (c[k >> 2] | 0) + 1;
	                        k = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                        c[k >> 2] = (c[k >> 2] | 0) + 1;
	                        k = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                        c[k >> 2] = (c[k >> 2] | 0) + 1;
	                        if (((c[c[f >> 2] >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 212 >> 2] | 0) == 0 : 0) ? (c[(c[c[f >> 2] >> 2] | 0) + 76 >> 2] | 0) != 0 : 0)Db[c[(c[c[f >> 2] >> 2] | 0) + 76 >> 2] & 511](c[(c[f >> 2] | 0) + 4 >> 2] | 0, c[m >> 2] | 0, c[g >> 2] | 0)
	                    } else zo(u, 47, 97360, c[m >> 2] | 0, 0);
	                    zb[c[135736 >> 2] & 511](c[g >> 2] | 0)
	                } else zo(q, 46, 97392, 0, 0);
	                c[(c[f >> 2] | 0) + 172 >> 2] = c[n >> 2];
	                i = e;
	                return
	            }

	            function Io(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                g = b + 4 | 0;
	                h = b;
	                c[e >> 2] = a;
	                c[g >> 2] = 0;
	                c[h >> 2] = 0;
	                a = (c[e >> 2] | 0) + 200 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + 9;
	                a = (c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + 9;
	                a = (c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + 9;
	                Fo(c[e >> 2] | 0) | 0;
	                c[f >> 2] = yo(c[e >> 2] | 0) | 0;
	                if (!(c[f >> 2] | 0))zo(c[e >> 2] | 0, 68, 96976, 0, 0);
	                Fo(c[e >> 2] | 0) | 0;
	                c[h >> 2] = bp(c[e >> 2] | 0, g) | 0;
	                Fo(c[e >> 2] | 0) | 0;
	                if ((d[c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 62)zo(c[e >> 2] | 0, 61, 97024, 0, 0);
	                me(c[e >> 2] | 0);
	                if (((c[c[e >> 2] >> 2] | 0) != 0 ? (c[c[c[e >> 2] >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[e >> 2] | 0) + 212 >> 2] | 0) == 0 : 0)Jb[c[c[c[e >> 2] >> 2] >> 2] & 511](c[(c[e >> 2] | 0) + 4 >> 2] | 0, c[f >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0);
	                if (c[h >> 2] | 0)zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                if (!(c[g >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                i = b;
	                return
	            }

	            function Jo(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = -1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                cU(c[e >> 2] | 0, 0, 472) | 0;
	                a = xP() | 0;
	                c[(c[e >> 2] | 0) + 296 >> 2] = a;
	                if (!(c[(c[e >> 2] | 0) + 296 >> 2] | 0)) {
	                    xo(0, 96936);
	                    c[d >> 2] = -1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](128) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    xo(0, 96936);
	                    c[d >> 2] = -1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = (c[f >> 2] | 0) + 0 | 0;
	                h = a + 128 | 0;
	                do {
	                    c[a >> 2] = 0;
	                    a = a + 4 | 0
	                } while ((a | 0) < (h | 0));
	                j = Cb[c[135744 >> 2] & 511](20) | 0;
	                c[(c[e >> 2] | 0) + 48 >> 2] = j;
	                if (!(c[(c[e >> 2] | 0) + 48 >> 2] | 0)) {
	                    xo(0, 96936);
	                    c[(c[e >> 2] | 0) + 40 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 44 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 36 >> 2] = 0;
	                    c[d >> 2] = -1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[(c[e >> 2] | 0) + 40 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 44 >> 2] = 5;
	                c[(c[e >> 2] | 0) + 36 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 20 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 24 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 28 >> 2] = -1;
	                c[(c[e >> 2] | 0) + 172 >> 2] = 0;
	                j = Cb[c[135744 >> 2] & 511](40) | 0;
	                c[(c[e >> 2] | 0) + 64 >> 2] = j;
	                if (!(c[(c[e >> 2] | 0) + 64 >> 2] | 0)) {
	                    xo(0, 96936);
	                    c[(c[e >> 2] | 0) + 56 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 60 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 52 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 40 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 44 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 36 >> 2] = 0;
	                    c[d >> 2] = -1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[(c[e >> 2] | 0) + 56 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 60 >> 2] = 10;
	                c[(c[e >> 2] | 0) + 52 >> 2] = 0;
	                j = Cb[c[135744 >> 2] & 511](40) | 0;
	                c[(c[e >> 2] | 0) + 196 >> 2] = j;
	                if (!(c[(c[e >> 2] | 0) + 196 >> 2] | 0)) {
	                    xo(0, 96936);
	                    c[(c[e >> 2] | 0) + 188 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 192 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 184 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 56 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 60 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 52 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 40 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 44 >> 2] = 0;
	                    c[(c[e >> 2] | 0) + 36 >> 2] = 0;
	                    c[d >> 2] = -1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[(c[e >> 2] | 0) + 188 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 192 >> 2] = 10;
	                c[(c[e >> 2] | 0) + 184 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 460 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 452 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 456 >> 2] = 0;
	                if (!(c[f >> 2] | 0))c[c[e >> 2] >> 2] = 136096; else {
	                    c[c[e >> 2] >> 2] = c[f >> 2];
	                    a = (c[f >> 2] | 0) + 0 | 0;
	                    f = 136096 | 0;
	                    h = a + 112 | 0;
	                    do {
	                        c[a >> 2] = c[f >> 2];
	                        a = a + 4 | 0;
	                        f = f + 4 | 0
	                    } while ((a | 0) < (h | 0))
	                }
	                c[(c[e >> 2] | 0) + 4 >> 2] = c[e >> 2];
	                c[(c[e >> 2] | 0) + 8 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 12 >> 2] = 1;
	                c[(c[e >> 2] | 0) + 16 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 280 >> 2] = c[33962];
	                c[(c[e >> 2] | 0) + 32 >> 2] = 1;
	                c[(c[e >> 2] | 0) + 136 >> 2] = -1412623820;
	                c[(c[e >> 2] | 0) + 108 >> 2] = c[e >> 2];
	                c[(c[e >> 2] | 0) + 112 >> 2] = 224;
	                c[(c[e >> 2] | 0) + 116 >> 2] = 225;
	                c[(c[e >> 2] | 0) + 68 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 104 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 200 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 204 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 284 >> 2] = 0;
	                ze((c[e >> 2] | 0) + 72 | 0);
	                c[d >> 2] = 0;
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function Ko(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0;
	                f = i;
	                i = i + 80 | 0;
	                g = f + 60 | 0;
	                h = f + 56 | 0;
	                j = f + 52 | 0;
	                k = f + 48 | 0;
	                l = f + 44 | 0;
	                m = f + 69 | 0;
	                n = f + 68 | 0;
	                o = f + 24 | 0;
	                p = f + 20 | 0;
	                q = f + 16 | 0;
	                r = f + 12 | 0;
	                s = f + 8 | 0;
	                t = f + 66 | 0;
	                u = f + 4 | 0;
	                v = f + 64 | 0;
	                w = f;
	                c[g >> 2] = b;
	                c[h >> 2] = e;
	                c[j >> 2] = 0;
	                c[l >> 2] = 0;
	                a:while (1) {
	                    c[k >> 2] = c[(c[g >> 2] | 0) + 36 >> 2];
	                    if (!(c[k >> 2] | 0))break;
	                    e = c[k >> 2] | 0;
	                    if (!(c[c[k >> 2] >> 2] | 0))c[l >> 2] = (c[e + 24 >> 2] | 0) - ((c[(c[k >> 2] | 0) + 16 >> 2] | 0) - (c[(c[k >> 2] | 0) + 12 >> 2] | 0)); else {
	                        b = _y(c[(c[e >> 2] | 0) + 16 >> 2] | 0) | 0;
	                        c[l >> 2] = b - ((c[(c[k >> 2] | 0) + 16 >> 2] | 0) - (c[(c[k >> 2] | 0) + 12 >> 2] | 0))
	                    }
	                    if (((((c[l >> 2] | 0) == 0 & (c[h >> 2] | 0) != 0 ? (Do(c[g >> 2] | 0), (c[(c[g >> 2] | 0) + 188 >> 2] | 0) == 0) : 0) ? (c[(c[g >> 2] | 0) + 172 >> 2] | 0) != -1 : 0) ? (c[(c[g >> 2] | 0) + 172 >> 2] = -1, (c[c[g >> 2] >> 2] | 0) != 0) : 0) ? (c[(c[c[g >> 2] >> 2] | 0) + 52 >> 2] | 0) != 0 : 0)zb[c[(c[c[g >> 2] >> 2] | 0) + 52 >> 2] & 511](c[(c[g >> 2] | 0) + 4 >> 2] | 0);
	                    if ((c[l >> 2] | 0) < 1)break;
	                    a[m >> 0] = a[c[(c[k >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                    b = c[g >> 2] | 0;
	                    if (!(d[m >> 0] | 0)) {
	                        e = b + 200 | 0;
	                        c[e >> 2] = (c[e >> 2] | 0) + 1;
	                        e = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                        c[e >> 2] = (c[e >> 2] | 0) + 1;
	                        e = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                        c[e >> 2] = (c[e >> 2] | 0) + 1;
	                        continue
	                    }
	                    do switch (c[b + 172 >> 2] | 0) {
	                        case 1:
	                        {
	                            Fo(c[g >> 2] | 0) | 0;
	                            e = c[k >> 2] | 0;
	                            if (!(c[c[k >> 2] >> 2] | 0))c[l >> 2] = (c[e + 24 >> 2] | 0) - ((c[(c[k >> 2] | 0) + 16 >> 2] | 0) - (c[(c[k >> 2] | 0) + 12 >> 2] | 0)); else {
	                                x = _y(c[(c[e >> 2] | 0) + 16 >> 2] | 0) | 0;
	                                c[l >> 2] = x - ((c[(c[k >> 2] | 0) + 16 >> 2] | 0) - (c[(c[k >> 2] | 0) + 12 >> 2] | 0))
	                            }
	                            if ((c[l >> 2] | 0) < 1)break a;
	                            if ((c[l >> 2] | 0) < 2) {
	                                if (!(c[h >> 2] | 0))break a;
	                                a[n >> 0] = 32
	                            } else a[n >> 0] = a[(c[(c[k >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0;
	                            a[m >> 0] = a[c[(c[k >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                            if ((((d[m >> 0] | 0) == 60 ? (d[n >> 0] | 0) == 33 : 0) ? (d[(c[(c[k >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0) == 45 : 0) ? (d[(c[(c[k >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0) == 45 : 0) {
	                                if ((c[h >> 2] | 0) == 0 ? (cp(c[g >> 2] | 0, 45, 45, 62, 1, 1) | 0) < 0 : 0)break a;
	                                Go(c[g >> 2] | 0);
	                                c[(c[g >> 2] | 0) + 172 >> 2] = 1;
	                                continue a
	                            }
	                            if ((d[m >> 0] | 0) == 60 ? (d[n >> 0] | 0) == 63 : 0) {
	                                if ((c[h >> 2] | 0) == 0 ? (cp(c[g >> 2] | 0, 62, 0, 0, 0, 1) | 0) < 0 : 0)break a;
	                                Ho(c[g >> 2] | 0);
	                                c[(c[g >> 2] | 0) + 172 >> 2] = 1;
	                                continue a
	                            }
	                            do if (((((((d[m >> 0] | 0) == 60 ? (d[n >> 0] | 0) == 33 : 0) ? (WS(d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0) | 0) == 68 : 0) ? (WS(d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0) | 0) == 79 : 0) ? (WS(d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0) | 0) == 67 : 0) ? (WS(d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0) | 0) == 84 : 0) ? (WS(d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 6 >> 0] | 0) | 0) == 89 : 0) {
	                                if ((WS(d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 7 >> 0] | 0) | 0) != 80)break;
	                                if ((WS(d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 8 >> 0] | 0) | 0) != 69)break;
	                                if ((c[h >> 2] | 0) == 0 ? (cp(c[g >> 2] | 0, 62, 0, 0, 0, 1) | 0) < 0 : 0)break a;
	                                Io(c[g >> 2] | 0);
	                                c[(c[g >> 2] | 0) + 172 >> 2] = 4;
	                                continue a
	                            } while (0);
	                            if ((d[m >> 0] | 0) == 60 ? (d[n >> 0] | 0) == 33 & (c[l >> 2] | 0) < 9 : 0)break a;
	                            c[(c[g >> 2] | 0) + 172 >> 2] = 6;
	                            continue a;
	                            break
	                        }
	                        case 9:
	                        {
	                            if ((c[l >> 2] | 0) < 2)break a;
	                            if ((c[h >> 2] | 0) == 0 ? (cp(c[g >> 2] | 0, 62, 0, 0, 0, 1) | 0) < 0 : 0)break a;
	                            Vo(c[g >> 2] | 0) | 0;
	                            x = (c[g >> 2] | 0) + 172 | 0;
	                            if (!(c[(c[g >> 2] | 0) + 188 >> 2] | 0))c[x >> 2] = 14; else c[x >> 2] = 7;
	                            c[(c[g >> 2] | 0) + 204 >> 2] = 0;
	                            continue a;
	                            break
	                        }
	                        case 8:
	                        {
	                            zo(c[g >> 2] | 0, 1, 95104, 0, 0);
	                            c[(c[g >> 2] | 0) + 172 >> 2] = 7;
	                            c[(c[g >> 2] | 0) + 204 >> 2] = 0;
	                            continue a;
	                            break
	                        }
	                        case 3:
	                        {
	                            zo(c[g >> 2] | 0, 1, 95144, 0, 0);
	                            c[(c[g >> 2] | 0) + 172 >> 2] = 7;
	                            c[(c[g >> 2] | 0) + 204 >> 2] = 0;
	                            continue a;
	                            break
	                        }
	                        case 7:
	                        {
	                            if (c[(c[g >> 2] | 0) + 176 >> 2] | 0) {
	                                a[t + 0 >> 0] = 0;
	                                a[t + 1 >> 0] = 0;
	                                a[t >> 0] = c[(c[g >> 2] | 0) + 176 >> 2];
	                                ep(c[g >> 2] | 0) | 0;
	                                if ((c[c[g >> 2] >> 2] | 0) != 0 ? (c[(c[c[g >> 2] >> 2] | 0) + 68 >> 2] | 0) != 0 : 0)Db[c[(c[c[g >> 2] >> 2] | 0) + 68 >> 2] & 511](c[(c[g >> 2] | 0) + 4 >> 2] | 0, t, 1);
	                                c[(c[g >> 2] | 0) + 176 >> 2] = 0;
	                                c[(c[g >> 2] | 0) + 204 >> 2] = 0
	                            }
	                            if (((c[l >> 2] | 0) == 1 & (c[h >> 2] | 0) != 0 ? (a[m >> 0] = a[c[(c[k >> 2] | 0) + 16 >> 2] >> 0] | 0, (d[m >> 0] | 0) != 60) : 0) ? (d[m >> 0] | 0) != 38 : 0) {
	                                b:do if (c[c[g >> 2] >> 2] | 0) {
	                                    do if ((d[m >> 0] | 0) != 32) {
	                                        if (9 <= (d[m >> 0] | 0) ? (d[m >> 0] | 0) <= 10 : 0)break;
	                                        if ((d[m >> 0] | 0) != 13) {
	                                            ep(c[g >> 2] | 0) | 0;
	                                            if (!(c[(c[c[g >> 2] >> 2] | 0) + 68 >> 2] | 0))break b;
	                                            Db[c[(c[c[g >> 2] >> 2] | 0) + 68 >> 2] & 511](c[(c[g >> 2] | 0) + 4 >> 2] | 0, m, 1);
	                                            break b
	                                        }
	                                    } while (0);
	                                    x = c[c[g >> 2] >> 2] | 0;
	                                    if (c[(c[g >> 2] | 0) + 208 >> 2] | 0) {
	                                        if (!(c[x + 68 >> 2] | 0))break;
	                                        Db[c[(c[c[g >> 2] >> 2] | 0) + 68 >> 2] & 511](c[(c[g >> 2] | 0) + 4 >> 2] | 0, m, 1);
	                                        break
	                                    } else {
	                                        if (!(c[x + 72 >> 2] | 0))break;
	                                        Db[c[(c[c[g >> 2] >> 2] | 0) + 72 >> 2] & 511](c[(c[g >> 2] | 0) + 4 >> 2] | 0, m, 1);
	                                        break
	                                    }
	                                } while (0);
	                                c[(c[g >> 2] | 0) + 176 >> 2] = 0;
	                                c[(c[g >> 2] | 0) + 204 >> 2] = 0;
	                                x = (c[k >> 2] | 0) + 16 | 0;
	                                c[x >> 2] = (c[x >> 2] | 0) + 1;
	                                continue a
	                            }
	                            if ((c[l >> 2] | 0) < 2)break a;
	                            a[m >> 0] = a[c[(c[k >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                            a[n >> 0] = a[(c[(c[k >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0;
	                            c[s >> 2] = c[(c[g >> 2] | 0) + 200 >> 2];
	                            c:do if ((qy(c[(c[g >> 2] | 0) + 184 >> 2] | 0, 94992) | 0) == 0 ? (qy(c[(c[g >> 2] | 0) + 184 >> 2] | 0, 95e3) | 0) == 0 : 0) {
	                                do if ((((((d[m >> 0] | 0) == 60 ? (d[n >> 0] | 0) == 33 : 0) ? (WS(d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0) | 0) == 68 : 0) ? (WS(d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0) | 0) == 79 : 0) ? (WS(d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0) | 0) == 67 : 0) ? (WS(d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0) | 0) == 84 : 0) {
	                                    if ((WS(d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 6 >> 0] | 0) | 0) != 89)break;
	                                    if ((WS(d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 7 >> 0] | 0) | 0) != 80)break;
	                                    if ((WS(d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 8 >> 0] | 0) | 0) != 69)break;
	                                    if ((c[h >> 2] | 0) == 0 ? (cp(c[g >> 2] | 0, 62, 0, 0, 0, 1) | 0) < 0 : 0)break a;
	                                    zo(c[g >> 2] | 0, 800, 95008, 95040, 0);
	                                    Io(c[g >> 2] | 0);
	                                    break c
	                                } while (0);
	                                if ((((d[m >> 0] | 0) == 60 ? (d[n >> 0] | 0) == 33 : 0) ? (d[(c[(c[k >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0) == 45 : 0) ? (d[(c[(c[k >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0) == 45 : 0) {
	                                    if ((c[h >> 2] | 0) == 0 ? (cp(c[g >> 2] | 0, 45, 45, 62, 1, 1) | 0) < 0 : 0)break a;
	                                    Go(c[g >> 2] | 0);
	                                    c[(c[g >> 2] | 0) + 172 >> 2] = 7;
	                                    break
	                                }
	                                if ((d[m >> 0] | 0) == 60 ? (d[n >> 0] | 0) == 63 : 0) {
	                                    if ((c[h >> 2] | 0) == 0 ? (cp(c[g >> 2] | 0, 62, 0, 0, 0, 1) | 0) < 0 : 0)break a;
	                                    Ho(c[g >> 2] | 0);
	                                    c[(c[g >> 2] | 0) + 172 >> 2] = 7;
	                                    break
	                                }
	                                if ((d[m >> 0] | 0) == 60 ? (d[n >> 0] | 0) == 33 & (c[l >> 2] | 0) < 4 : 0)break a;
	                                if ((d[m >> 0] | 0) == 60 ? (d[n >> 0] | 0) == 47 : 0) {
	                                    c[(c[g >> 2] | 0) + 172 >> 2] = 9;
	                                    c[(c[g >> 2] | 0) + 204 >> 2] = 0;
	                                    continue a
	                                }
	                                if ((d[m >> 0] | 0) == 60) {
	                                    c[(c[g >> 2] | 0) + 172 >> 2] = 6;
	                                    c[(c[g >> 2] | 0) + 204 >> 2] = 0;
	                                    continue a
	                                }
	                                x = (c[h >> 2] | 0) != 0;
	                                if ((d[m >> 0] | 0) == 38) {
	                                    if (!x ? (fp(c[g >> 2] | 0, 95048, 4) | 0) < 0 : 0)break a;
	                                    Yo(c[g >> 2] | 0);
	                                    break
	                                } else {
	                                    if (!x ? (fp(c[g >> 2] | 0, 95056, 2) | 0) < 0 : 0)break a;
	                                    c[(c[g >> 2] | 0) + 204 >> 2] = 0;
	                                    Zo(c[g >> 2] | 0);
	                                    break
	                                }
	                            } else y = 187; while (0);
	                            if ((y | 0) == 187) {
	                                y = 0;
	                                if (!(c[h >> 2] | 0)) {
	                                    c[u >> 2] = cp(c[g >> 2] | 0, 60, 47, 0, 0, 0) | 0;
	                                    if ((c[u >> 2] | 0) < 0)break a;
	                                    a[v >> 0] = a[(c[(c[k >> 2] | 0) + 16 >> 2] | 0) + ((c[u >> 2] | 0) + 2) >> 0] | 0;
	                                    if (!(d[v >> 0] | 0))break a
	                                }
	                                Xo(c[g >> 2] | 0);
	                                if ((d[m >> 0] | 0) == 60 ? (d[n >> 0] | 0) == 47 : 0) {
	                                    c[(c[g >> 2] | 0) + 172 >> 2] = 9;
	                                    c[(c[g >> 2] | 0) + 204 >> 2] = 0;
	                                    continue a
	                                }
	                            }
	                            if ((c[s >> 2] | 0) != (c[(c[g >> 2] | 0) + 200 >> 2] | 0))continue a;
	                            if (c[(c[g >> 2] | 0) + 52 >> 2] | 0)zo(c[g >> 2] | 0, 1, 95064, 0, 0);
	                            me(c[g >> 2] | 0);
	                            continue a;
	                            break
	                        }
	                        case 6:
	                        {
	                            if ((c[l >> 2] | 0) < 1)break a;
	                            if ((c[l >> 2] | 0) < 2) {
	                                if (!(c[h >> 2] | 0))break a;
	                                a[n >> 0] = 32
	                            } else a[n >> 0] = a[(c[(c[k >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0;
	                            a[m >> 0] = a[c[(c[k >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                            if ((d[m >> 0] | 0) != 60) {
	                                c[(c[g >> 2] | 0) + 172 >> 2] = 7;
	                                continue a
	                            }
	                            if ((d[n >> 0] | 0) == 47) {
	                                c[(c[g >> 2] | 0) + 172 >> 2] = 9;
	                                c[(c[g >> 2] | 0) + 204 >> 2] = 0;
	                                continue a
	                            }
	                            if ((c[h >> 2] | 0) == 0 ? (cp(c[g >> 2] | 0, 62, 0, 0, 0, 1) | 0) < 0 : 0)break a;
	                            if (c[(c[g >> 2] | 0) + 68 >> 2] | 0) {
	                                c[o + 4 >> 2] = (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 36 >> 2] | 0) + ((c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0));
	                                c[o + 8 >> 2] = c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2]
	                            }
	                            c[q >> 2] = Bo(c[g >> 2] | 0) | 0;
	                            c[p >> 2] = c[(c[g >> 2] | 0) + 184 >> 2];
	                            if ((c[q >> 2] | 0) == -1 | (c[p >> 2] | 0) == 0) {
	                                if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) != 62)continue a;
	                                me(c[g >> 2] | 0);
	                                continue a
	                            }
	                            c[r >> 2] = bo(c[p >> 2] | 0) | 0;
	                            if (!(c[r >> 2] | 0))zo(c[g >> 2] | 0, 801, 94576, c[p >> 2] | 0, 0);
	                            if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) == 47 ? (d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0) == 62 : 0) {
	                                x = (c[g >> 2] | 0) + 200 | 0;
	                                c[x >> 2] = (c[x >> 2] | 0) + 2;
	                                x = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                                c[x >> 2] = (c[x >> 2] | 0) + 2;
	                                x = (c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 32 | 0;
	                                c[x >> 2] = (c[x >> 2] | 0) + 2;
	                                do if (c[c[g >> 2] >> 2] | 0) {
	                                    if (!(c[(c[c[g >> 2] >> 2] | 0) + 60 >> 2] | 0))break;
	                                    Ab[c[(c[c[g >> 2] >> 2] | 0) + 60 >> 2] & 511](c[(c[g >> 2] | 0) + 4 >> 2] | 0, c[p >> 2] | 0)
	                                } while (0);
	                                Co(c[g >> 2] | 0) | 0;
	                                c[(c[g >> 2] | 0) + 172 >> 2] = 7;
	                                continue a
	                            }
	                            x = c[g >> 2] | 0;
	                            if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) != 62) {
	                                zo(x, 73, 94592, c[p >> 2] | 0, 0);
	                                if (qy(c[p >> 2] | 0, c[(c[g >> 2] | 0) + 184 >> 2] | 0) | 0) {
	                                    Re(c[g >> 2] | 0) | 0;
	                                    Co(c[g >> 2] | 0) | 0
	                                }
	                                if (c[(c[g >> 2] | 0) + 68 >> 2] | 0)dp(c[g >> 2] | 0, o) | 0;
	                                c[(c[g >> 2] | 0) + 172 >> 2] = 7;
	                                continue a
	                            }
	                            me(x);
	                            if ((c[r >> 2] | 0) != 0 ? (a[(c[r >> 2] | 0) + 7 >> 0] | 0) != 0 : 0) {
	                                do if (c[c[g >> 2] >> 2] | 0) {
	                                    if (!(c[(c[c[g >> 2] >> 2] | 0) + 60 >> 2] | 0))break;
	                                    Ab[c[(c[c[g >> 2] >> 2] | 0) + 60 >> 2] & 511](c[(c[g >> 2] | 0) + 4 >> 2] | 0, c[p >> 2] | 0)
	                                } while (0);
	                                Co(c[g >> 2] | 0) | 0
	                            }
	                            if (c[(c[g >> 2] | 0) + 68 >> 2] | 0)dp(c[g >> 2] | 0, o) | 0;
	                            c[(c[g >> 2] | 0) + 172 >> 2] = 7;
	                            continue a;
	                            break
	                        }
	                        case 0:
	                        {
	                            a[m >> 0] = a[c[(c[k >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                            do if ((d[m >> 0] | 0) != 32) {
	                                if (9 <= (d[m >> 0] | 0) ? (d[m >> 0] | 0) <= 10 : 0) {
	                                    y = 20;
	                                    break
	                                }
	                                if ((d[m >> 0] | 0) == 13)y = 20
	                            } else y = 20; while (0);
	                            do if ((y | 0) == 20) {
	                                y = 0;
	                                Fo(c[g >> 2] | 0) | 0;
	                                x = c[k >> 2] | 0;
	                                if (!(c[c[k >> 2] >> 2] | 0)) {
	                                    c[l >> 2] = (c[x + 24 >> 2] | 0) - ((c[(c[k >> 2] | 0) + 16 >> 2] | 0) - (c[(c[k >> 2] | 0) + 12 >> 2] | 0));
	                                    break
	                                } else {
	                                    e = _y(c[(c[x >> 2] | 0) + 16 >> 2] | 0) | 0;
	                                    c[l >> 2] = e - ((c[(c[k >> 2] | 0) + 16 >> 2] | 0) - (c[(c[k >> 2] | 0) + 12 >> 2] | 0));
	                                    break
	                                }
	                            } while (0);
	                            if ((c[c[g >> 2] >> 2] | 0) != 0 ? (c[(c[c[g >> 2] >> 2] | 0) + 44 >> 2] | 0) != 0 : 0)Ab[c[(c[c[g >> 2] >> 2] | 0) + 44 >> 2] & 511](c[(c[g >> 2] | 0) + 4 >> 2] | 0, 136080);
	                            if (((c[c[g >> 2] >> 2] | 0) != 0 ? (c[(c[c[g >> 2] >> 2] | 0) + 48 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 212 >> 2] | 0) == 0 : 0)zb[c[(c[c[g >> 2] >> 2] | 0) + 48 >> 2] & 511](c[(c[g >> 2] | 0) + 4 >> 2] | 0);
	                            a[m >> 0] = a[c[(c[k >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                            a[n >> 0] = a[(c[(c[k >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0;
	                            if (((((((((d[m >> 0] | 0) == 60 ? (d[n >> 0] | 0) == 33 : 0) ? (WS(d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0) | 0) == 68 : 0) ? (WS(d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0) | 0) == 79 : 0) ? (WS(d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 4 >> 0] | 0) | 0) == 67 : 0) ? (WS(d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 5 >> 0] | 0) | 0) == 84 : 0) ? (WS(d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 6 >> 0] | 0) | 0) == 89 : 0) ? (WS(d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 7 >> 0] | 0) | 0) == 80 : 0) ? (WS(d[(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 8 >> 0] | 0) | 0) == 69 : 0) {
	                                if ((c[h >> 2] | 0) == 0 ? (cp(c[g >> 2] | 0, 62, 0, 0, 0, 1) | 0) < 0 : 0)break a;
	                                Io(c[g >> 2] | 0);
	                                c[(c[g >> 2] | 0) + 172 >> 2] = 4;
	                                continue a
	                            }
	                            c[(c[g >> 2] | 0) + 172 >> 2] = 1;
	                            continue a;
	                            break
	                        }
	                        case 14:
	                        {
	                            e = c[k >> 2] | 0;
	                            if (!(c[c[k >> 2] >> 2] | 0))c[l >> 2] = (c[e + 24 >> 2] | 0) - ((c[(c[k >> 2] | 0) + 16 >> 2] | 0) - (c[(c[k >> 2] | 0) + 12 >> 2] | 0)); else {
	                                x = _y(c[(c[e >> 2] | 0) + 16 >> 2] | 0) | 0;
	                                c[l >> 2] = x - ((c[(c[k >> 2] | 0) + 16 >> 2] | 0) - (c[(c[k >> 2] | 0) + 12 >> 2] | 0))
	                            }
	                            if ((c[l >> 2] | 0) < 1)break a;
	                            a[m >> 0] = a[c[(c[k >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                            if ((d[m >> 0] | 0) == 32) {
	                                y = 105;
	                                break a
	                            }
	                            if (9 <= (d[m >> 0] | 0) ? (d[m >> 0] | 0) <= 10 : 0) {
	                                y = 105;
	                                break a
	                            }
	                            if ((d[m >> 0] | 0) == 13) {
	                                y = 105;
	                                break a
	                            }
	                            if ((c[l >> 2] | 0) < 2)break a;
	                            a[n >> 0] = a[(c[(c[k >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0;
	                            if ((((d[m >> 0] | 0) == 60 ? (d[n >> 0] | 0) == 33 : 0) ? (d[(c[(c[k >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0) == 45 : 0) ? (d[(c[(c[k >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0) == 45 : 0) {
	                                if ((c[h >> 2] | 0) == 0 ? (cp(c[g >> 2] | 0, 45, 45, 62, 1, 1) | 0) < 0 : 0)break a;
	                                Go(c[g >> 2] | 0);
	                                c[(c[g >> 2] | 0) + 172 >> 2] = 14;
	                                continue a
	                            }
	                            if ((d[m >> 0] | 0) != 60) {
	                                y = 119;
	                                break a
	                            }
	                            if ((d[n >> 0] | 0) != 63) {
	                                y = 119;
	                                break a
	                            }
	                            if ((c[h >> 2] | 0) == 0 ? (cp(c[g >> 2] | 0, 62, 0, 0, 0, 1) | 0) < 0 : 0)break a;
	                            Ho(c[g >> 2] | 0);
	                            c[(c[g >> 2] | 0) + 172 >> 2] = 14;
	                            continue a;
	                            break
	                        }
	                        case 4:
	                        {
	                            Fo(c[g >> 2] | 0) | 0;
	                            x = c[k >> 2] | 0;
	                            if (!(c[c[k >> 2] >> 2] | 0))c[l >> 2] = (c[x + 24 >> 2] | 0) - ((c[(c[k >> 2] | 0) + 16 >> 2] | 0) - (c[(c[k >> 2] | 0) + 12 >> 2] | 0)); else {
	                                e = _y(c[(c[x >> 2] | 0) + 16 >> 2] | 0) | 0;
	                                c[l >> 2] = e - ((c[(c[k >> 2] | 0) + 16 >> 2] | 0) - (c[(c[k >> 2] | 0) + 12 >> 2] | 0))
	                            }
	                            if ((c[l >> 2] | 0) < 2)break a;
	                            a[m >> 0] = a[c[(c[k >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                            a[n >> 0] = a[(c[(c[k >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0;
	                            if ((((d[m >> 0] | 0) == 60 ? (d[n >> 0] | 0) == 33 : 0) ? (d[(c[(c[k >> 2] | 0) + 16 >> 2] | 0) + 2 >> 0] | 0) == 45 : 0) ? (d[(c[(c[k >> 2] | 0) + 16 >> 2] | 0) + 3 >> 0] | 0) == 45 : 0) {
	                                if ((c[h >> 2] | 0) == 0 ? (cp(c[g >> 2] | 0, 45, 45, 62, 1, 1) | 0) < 0 : 0)break a;
	                                Go(c[g >> 2] | 0);
	                                c[(c[g >> 2] | 0) + 172 >> 2] = 4;
	                                continue a
	                            }
	                            if ((d[m >> 0] | 0) == 60 ? (d[n >> 0] | 0) == 63 : 0) {
	                                if ((c[h >> 2] | 0) == 0 ? (cp(c[g >> 2] | 0, 62, 0, 0, 0, 1) | 0) < 0 : 0)break a;
	                                Ho(c[g >> 2] | 0);
	                                c[(c[g >> 2] | 0) + 172 >> 2] = 4;
	                                continue a
	                            }
	                            if ((d[m >> 0] | 0) == 60 ? (d[n >> 0] | 0) == 33 & (c[l >> 2] | 0) < 4 : 0)break a;
	                            c[(c[g >> 2] | 0) + 172 >> 2] = 6;
	                            continue a;
	                            break
	                        }
	                        case 5:
	                        {
	                            zo(c[g >> 2] | 0, 1, 95184, 0, 0);
	                            c[(c[g >> 2] | 0) + 172 >> 2] = 7;
	                            c[(c[g >> 2] | 0) + 204 >> 2] = 0;
	                            continue a;
	                            break
	                        }
	                        case 2:
	                        {
	                            zo(c[g >> 2] | 0, 1, 95224, 0, 0);
	                            c[(c[g >> 2] | 0) + 172 >> 2] = 7;
	                            c[(c[g >> 2] | 0) + 204 >> 2] = 0;
	                            continue a;
	                            break
	                        }
	                        case 10:
	                        {
	                            zo(c[g >> 2] | 0, 1, 95264, 0, 0);
	                            c[(c[g >> 2] | 0) + 172 >> 2] = 7;
	                            c[(c[g >> 2] | 0) + 204 >> 2] = 0;
	                            continue a;
	                            break
	                        }
	                        case 11:
	                        {
	                            zo(c[g >> 2] | 0, 1, 95312, 0, 0);
	                            c[(c[g >> 2] | 0) + 172 >> 2] = 7;
	                            c[(c[g >> 2] | 0) + 204 >> 2] = 0;
	                            continue a;
	                            break
	                        }
	                        case 12:
	                        {
	                            zo(c[g >> 2] | 0, 1, 95360, 0, 0);
	                            c[(c[g >> 2] | 0) + 172 >> 2] = 6;
	                            c[(c[g >> 2] | 0) + 204 >> 2] = 0;
	                            continue a;
	                            break
	                        }
	                        case 13:
	                        {
	                            zo(c[g >> 2] | 0, 1, 95408, 0, 0);
	                            c[(c[g >> 2] | 0) + 172 >> 2] = 7;
	                            c[(c[g >> 2] | 0) + 204 >> 2] = 0;
	                            continue a;
	                            break
	                        }
	                        case 15:
	                        {
	                            zo(c[g >> 2] | 0, 1, 95472, 0, 0);
	                            c[(c[g >> 2] | 0) + 172 >> 2] = 7;
	                            c[(c[g >> 2] | 0) + 204 >> 2] = 0;
	                            continue a;
	                            break
	                        }
	                        case 16:
	                        {
	                            zo(c[g >> 2] | 0, 1, 95528, 0, 0);
	                            c[(c[g >> 2] | 0) + 172 >> 2] = 7;
	                            c[(c[g >> 2] | 0) + 204 >> 2] = 0;
	                            continue a;
	                            break
	                        }
	                        case -1:
	                        {
	                            break a;
	                            break
	                        }
	                        default:
	                            continue a
	                    } while (0)
	                }
	                do if ((y | 0) == 105)Zo(c[g >> 2] | 0); else if ((y | 0) == 119) {
	                    if ((d[m >> 0] | 0) == 60 ? (d[n >> 0] | 0) == 33 & (c[l >> 2] | 0) < 4 : 0)break;
	                    c[(c[g >> 2] | 0) + 84 >> 2] = 5;
	                    c[(c[g >> 2] | 0) + 12 >> 2] = 0;
	                    c[(c[g >> 2] | 0) + 172 >> 2] = -1;
	                    if ((c[c[g >> 2] >> 2] | 0) != 0 ? (c[(c[c[g >> 2] >> 2] | 0) + 52 >> 2] | 0) != 0 : 0)zb[c[(c[c[g >> 2] >> 2] | 0) + 52 >> 2] & 511](c[(c[g >> 2] | 0) + 4 >> 2] | 0)
	                } while (0);
	                if (((((c[l >> 2] | 0) == 0 & (c[h >> 2] | 0) != 0 ? (Do(c[g >> 2] | 0), (c[(c[g >> 2] | 0) + 188 >> 2] | 0) == 0) : 0) ? (c[(c[g >> 2] | 0) + 172 >> 2] | 0) != -1 : 0) ? (c[(c[g >> 2] | 0) + 172 >> 2] = -1, (c[c[g >> 2] >> 2] | 0) != 0) : 0) ? (c[(c[c[g >> 2] >> 2] | 0) + 52 >> 2] | 0) != 0 : 0)zb[c[(c[c[g >> 2] >> 2] | 0) + 52 >> 2] & 511](c[(c[g >> 2] | 0) + 4 >> 2] | 0);
	                if (c[(c[g >> 2] | 0) + 360 >> 2] & 4) {
	                    z = c[j >> 2] | 0;
	                    i = f;
	                    return z | 0
	                }
	                if (!(c[(c[g >> 2] | 0) + 8 >> 2] | 0)) {
	                    z = c[j >> 2] | 0;
	                    i = f;
	                    return z | 0
	                }
	                if (((c[h >> 2] | 0) == 0 ? (c[(c[g >> 2] | 0) + 172 >> 2] | 0) != -1 : 0) ? (c[(c[g >> 2] | 0) + 172 >> 2] | 0) != 14 : 0) {
	                    z = c[j >> 2] | 0;
	                    i = f;
	                    return z | 0
	                }
	                c[w >> 2] = Nh(c[(c[g >> 2] | 0) + 8 >> 2] | 0) | 0;
	                if (c[w >> 2] | 0) {
	                    z = c[j >> 2] | 0;
	                    i = f;
	                    return z | 0
	                }
	                w = Oh(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 94240, 94296, 94248) | 0;
	                c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] = w;
	                z = c[j >> 2] | 0;
	                i = f;
	                return z | 0
	            }

	            function Lo(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](60) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    xo(c[e >> 2] | 0, 94952);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    e = (c[f >> 2] | 0) + 0 | 0;
	                    a = e + 60 | 0;
	                    do {
	                        c[e >> 2] = 0;
	                        e = e + 4 | 0
	                    } while ((e | 0) < (a | 0));
	                    c[(c[f >> 2] | 0) + 4 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 8 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 12 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 16 >> 2] = 0;
	                    c[c[f >> 2] >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 28 >> 2] = 1;
	                    c[(c[f >> 2] | 0) + 32 >> 2] = 1;
	                    c[c[f >> 2] >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 40 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 48 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 36 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 24 >> 2] = 0;
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function Mo(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                c[h >> 2] = yy(c[g >> 2] | 0, 94816) | 0;
	                if (c[h >> 2] | 0)c[h >> 2] = (c[h >> 2] | 0) + 7;
	                a:do if (c[h >> 2] | 0) {
	                    do if ((d[c[h >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[h >> 2] >> 0] | 0 | 0) ? (d[c[h >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[h >> 2] >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    c[h >> 2] = yy(c[g >> 2] | 0, 94824) | 0
	                } while (0);
	                if (!(c[h >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                if ((d[c[h >> 2] >> 0] | 0 | 0) != 61) {
	                    i = e;
	                    return
	                }
	                c[h >> 2] = (c[h >> 2] | 0) + 1;
	                gp(c[f >> 2] | 0, c[h >> 2] | 0);
	                i = e;
	                return
	            }

	            function No(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 24 | 0;
	                j = g + 20 | 0;
	                k = g + 16 | 0;
	                l = g + 12 | 0;
	                m = g + 8 | 0;
	                n = g + 4 | 0;
	                o = g;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                to(c[h >> 2] | 0, c[l >> 2] | 0) | 0;
	                c[(c[h >> 2] | 0) + 32 >> 2] = 1;
	                if ((c[k >> 2] | 0) != 0 ? (c[o >> 2] = Dd(c[k >> 2] | 0) | 0, (c[o >> 2] | 0) != 0) : 0) {
	                    se(c[h >> 2] | 0, c[o >> 2] | 0) | 0;
	                    if (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 44 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 44 >> 2] | 0);
	                    o = my(c[k >> 2] | 0) | 0;
	                    c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 44 >> 2] = o
	                }
	                if (((c[j >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) == 0 : 0) {
	                    o = my(c[j >> 2] | 0) | 0;
	                    c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] = o
	                }
	                ko(c[h >> 2] | 0) | 0;
	                c[n >> 2] = c[(c[h >> 2] | 0) + 8 >> 2];
	                c[(c[h >> 2] | 0) + 8 >> 2] = 0;
	                if (c[m >> 2] | 0) {
	                    p = c[n >> 2] | 0;
	                    i = g;
	                    return p | 0
	                }
	                if (((c[n >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 364 >> 2] | 0) != 0 : 0) ? (c[(c[n >> 2] | 0) + 80 >> 2] | 0) == (c[(c[h >> 2] | 0) + 296 >> 2] | 0) : 0)c[(c[h >> 2] | 0) + 296 >> 2] = 0;
	                Ae(c[h >> 2] | 0);
	                p = c[n >> 2] | 0;
	                i = g;
	                return p | 0
	            }

	            function Oo(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                b = i;
	                i = i + 32 | 0;
	                e = b + 20 | 0;
	                f = b + 16 | 0;
	                g = b + 12 | 0;
	                h = b + 8 | 0;
	                j = b + 4 | 0;
	                k = b;
	                c[f >> 2] = a;
	                c[g >> 2] = 0;
	                c[k >> 2] = 0;
	                if ((c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0 ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0;
	                c[j >> 2] = ap(c[f >> 2] | 0, h) | 0;
	                a:do if (!((c[j >> 2] | 0) == 32 | (c[j >> 2] | 0) == 62 | (c[j >> 2] | 0) == 47)) {
	                    a = c[j >> 2] | 0;
	                    if ((c[j >> 2] | 0) < 256) {
	                        if (((!(65 <= (a | 0) & (c[j >> 2] | 0) <= 90) ? !(97 <= (c[j >> 2] | 0) & (c[j >> 2] | 0) <= 122) : 0) ? !(192 <= (c[j >> 2] | 0) & (c[j >> 2] | 0) <= 214) : 0) ? !(216 <= (c[j >> 2] | 0) & (c[j >> 2] | 0) <= 246 | 248 <= (c[j >> 2] | 0)) : 0)l = 11
	                    } else if (!(DQ(a, 199744) | 0))l = 11;
	                    do if ((l | 0) == 11) {
	                        a = c[j >> 2] | 0;
	                        if ((c[j >> 2] | 0) < 256)if ((a | 0) != 95 & (c[j >> 2] | 0) != 58)break a; else break;
	                        if (!(19968 <= (a | 0) & (c[j >> 2] | 0) <= 40869 | (c[j >> 2] | 0) == 12295) ? (12321 <= (c[j >> 2] | 0) & (c[j >> 2] | 0) <= 12329 ^ 1) & (c[j >> 2] | 0) != 95 & (c[j >> 2] | 0) != 58 : 0)break a
	                    } while (0);
	                    b:while (1) {
	                        if (!((c[j >> 2] | 0) != 32 & (c[j >> 2] | 0) != 62 & (c[j >> 2] | 0) != 47))break;
	                        a = c[j >> 2] | 0;
	                        if ((c[j >> 2] | 0) < 256) {
	                            if (((!(65 <= (a | 0) & (c[j >> 2] | 0) <= 90) ? !(97 <= (c[j >> 2] | 0) & (c[j >> 2] | 0) <= 122) : 0) ? !(192 <= (c[j >> 2] | 0) & (c[j >> 2] | 0) <= 214) : 0) ? !(216 <= (c[j >> 2] | 0) & (c[j >> 2] | 0) <= 246 | 248 <= (c[j >> 2] | 0)) : 0)l = 23
	                        } else if (!(DQ(a, 199744) | 0))l = 23;
	                        do if ((l | 0) == 23) {
	                            l = 0;
	                            if ((c[j >> 2] | 0) >= 256) {
	                                if (19968 <= (c[j >> 2] | 0) & (c[j >> 2] | 0) <= 40869 | (c[j >> 2] | 0) == 12295)break;
	                                if (12321 <= (c[j >> 2] | 0) & (c[j >> 2] | 0) <= 12329)break
	                            }
	                            a = c[j >> 2] | 0;
	                            if ((c[j >> 2] | 0) < 256) {
	                                if (48 <= (a | 0) & (c[j >> 2] | 0) <= 57 | (c[j >> 2] | 0) == 46 | (c[j >> 2] | 0) == 45 | (c[j >> 2] | 0) == 95 | (c[j >> 2] | 0) == 58)break
	                            } else {
	                                m = (DQ(a, 200216) | 0) != 0;
	                                if (m | (c[j >> 2] | 0) == 46 | (c[j >> 2] | 0) == 45 | (c[j >> 2] | 0) == 95 | (c[j >> 2] | 0) == 58)break
	                            }
	                            if ((c[j >> 2] | 0) >= 256 ? (DQ(c[j >> 2] | 0, 200144) | 0) != 0 : 0)break;
	                            m = c[j >> 2] | 0;
	                            if ((c[j >> 2] | 0) < 256)n = (m | 0) == 183 & 1; else n = DQ(m, 200272) | 0;
	                            if (!n)break b
	                        } while (0);
	                        m = c[k >> 2] | 0;
	                        c[k >> 2] = m + 1;
	                        if (((m | 0) > 100 ? (c[k >> 2] = 0, (c[(c[f >> 2] | 0) + 292 >> 2] | 0) == 0) : 0) ? ((c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 20 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0) < 250 : 0)ke(c[(c[f >> 2] | 0) + 36 >> 2] | 0, 250) | 0;
	                        c[g >> 2] = (c[g >> 2] | 0) + (c[h >> 2] | 0);
	                        m = c[(c[f >> 2] | 0) + 36 >> 2] | 0;
	                        if ((d[c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 10) {
	                            a = m + 28 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1;
	                            c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2] = 1
	                        } else {
	                            a = m + 32 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1
	                        }
	                        c[(c[f >> 2] | 0) + 176 >> 2] = 0;
	                        a = (c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + (c[h >> 2] | 0);
	                        a = (c[f >> 2] | 0) + 200 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1;
	                        c[j >> 2] = ap(c[f >> 2] | 0, h) | 0
	                    }
	                    c[e >> 2] = AP(c[(c[f >> 2] | 0) + 296 >> 2] | 0, (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + (0 - (c[g >> 2] | 0)) | 0, c[g >> 2] | 0) | 0;
	                    o = c[e >> 2] | 0;
	                    i = b;
	                    return o | 0
	                } while (0);
	                c[e >> 2] = 0;
	                o = c[e >> 2] | 0;
	                i = b;
	                return o | 0
	            }

	            function Po(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 112 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                j = e + 12 | 0;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                if (!(65 <= (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 90 : 0))k = 3;
	                do if ((k | 0) == 3) {
	                    if (97 <= (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 122 : 0)break;
	                    if (((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 95 ? (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 58 : 0) ? (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 46 : 0) {
	                        c[f >> 2] = 0;
	                        l = c[f >> 2] | 0;
	                        i = e;
	                        return l | 0
	                    }
	                } while (0);
	                while (1) {
	                    do if ((c[h >> 2] | 0) < 100) {
	                        if (65 <= (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 90 : 0) {
	                            m = 1;
	                            break
	                        }
	                        if (97 <= (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 122 : 0) {
	                            m = 1;
	                            break
	                        }
	                        if (48 <= (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) ? (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 57 : 0) {
	                            m = 1;
	                            break
	                        }
	                        if (((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 58 ? (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 45 : 0) ? (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) != 95 : 0)m = (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 46; else m = 1
	                    } else m = 0; while (0);
	                    n = c[g >> 2] | 0;
	                    if (!m)break;
	                    if ((d[c[(c[n + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) >= 65 ? (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) <= 90 : 0)a[j + (c[h >> 2] | 0) >> 0] = (d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0) + 32; else a[j + (c[h >> 2] | 0) >> 0] = d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0;
	                    c[h >> 2] = (c[h >> 2] | 0) + 1;
	                    me(c[g >> 2] | 0)
	                }
	                c[f >> 2] = AP(c[n + 296 >> 2] | 0, j, c[h >> 2] | 0) | 0;
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function Qo(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                while (1) {
	                    if (!(c[f >> 2] | 0))break;
	                    if (!(c[(c[e >> 2] | 0) + 184 >> 2] | 0))break;
	                    if (!(wo(c[f >> 2] | 0, c[(c[e >> 2] | 0) + 184 >> 2] | 0) | 0))break;
	                    if ((c[c[e >> 2] >> 2] | 0) != 0 ? (c[(c[c[e >> 2] >> 2] | 0) + 60 >> 2] | 0) != 0 : 0)Ab[c[(c[c[e >> 2] >> 2] | 0) + 60 >> 2] & 511](c[(c[e >> 2] | 0) + 4 >> 2] | 0, c[(c[e >> 2] | 0) + 184 >> 2] | 0);
	                    Co(c[e >> 2] | 0) | 0
	                }
	                if (!(c[f >> 2] | 0)) {
	                    Do(c[e >> 2] | 0);
	                    i = d;
	                    return
	                }
	                while (1) {
	                    if (c[f >> 2] | 0) {
	                        g = 20;
	                        break
	                    }
	                    if (!(c[(c[e >> 2] | 0) + 184 >> 2] | 0)) {
	                        g = 20;
	                        break
	                    }
	                    if (((qy(c[(c[e >> 2] | 0) + 184 >> 2] | 0, 95656) | 0) == 0 ? (qy(c[(c[e >> 2] | 0) + 184 >> 2] | 0, 95648) | 0) == 0 : 0) ? (qy(c[(c[e >> 2] | 0) + 184 >> 2] | 0, 94240) | 0) == 0 : 0) {
	                        g = 20;
	                        break
	                    }
	                    if ((c[c[e >> 2] >> 2] | 0) != 0 ? (c[(c[c[e >> 2] >> 2] | 0) + 60 >> 2] | 0) != 0 : 0)Ab[c[(c[c[e >> 2] >> 2] | 0) + 60 >> 2] & 511](c[(c[e >> 2] | 0) + 4 >> 2] | 0, c[(c[e >> 2] | 0) + 184 >> 2] | 0);
	                    Co(c[e >> 2] | 0) | 0
	                }
	                if ((g | 0) == 20) {
	                    i = d;
	                    return
	                }
	            }

	            function Ro(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!((c[23702] | 0) != 0 ? (c[(c[e >> 2] | 0) + 360 >> 2] & 8192 | 0) == 0 : 0)) {
	                    i = d;
	                    return
	                }
	                if (qy(c[f >> 2] | 0, 94240) | 0) {
	                    i = d;
	                    return
	                }
	                if (((c[(c[e >> 2] | 0) + 188 >> 2] | 0) <= 0 ? (Uo(c[e >> 2] | 0, 94240) | 0, (c[c[e >> 2] >> 2] | 0) != 0) : 0) ? (c[(c[c[e >> 2] >> 2] | 0) + 56 >> 2] | 0) != 0 : 0)Db[c[(c[c[e >> 2] >> 2] | 0) + 56 >> 2] & 511](c[(c[e >> 2] | 0) + 4 >> 2] | 0, 94240, 0);
	                if (qy(c[f >> 2] | 0, 95648) | 0) {
	                    i = d;
	                    return
	                }
	                if (qy(c[f >> 2] | 0, 95656) | 0) {
	                    i = d;
	                    return
	                }
	                do if ((c[(c[e >> 2] | 0) + 188 >> 2] | 0) <= 1) {
	                    if ((((((qy(c[f >> 2] | 0, 94992) | 0) == 0 ? (qy(c[f >> 2] | 0, 95e3) | 0) == 0 : 0) ? (qy(c[f >> 2] | 0, 96200) | 0) == 0 : 0) ? (qy(c[f >> 2] | 0, 96208) | 0) == 0 : 0) ? (qy(c[f >> 2] | 0, 96216) | 0) == 0 : 0) ? (qy(c[f >> 2] | 0, 96224) | 0) == 0 : 0)break;
	                    if ((c[(c[e >> 2] | 0) + 32 >> 2] | 0) >= 3) {
	                        i = d;
	                        return
	                    }
	                    Uo(c[e >> 2] | 0, 95656) | 0;
	                    if (!(c[c[e >> 2] >> 2] | 0)) {
	                        i = d;
	                        return
	                    }
	                    if (!(c[(c[c[e >> 2] >> 2] | 0) + 56 >> 2] | 0)) {
	                        i = d;
	                        return
	                    }
	                    Db[c[(c[c[e >> 2] >> 2] | 0) + 56 >> 2] & 511](c[(c[e >> 2] | 0) + 4 >> 2] | 0, 95656, 0);
	                    i = d;
	                    return
	                } while (0);
	                if (qy(c[f >> 2] | 0, 96232) | 0) {
	                    i = d;
	                    return
	                }
	                if (qy(c[f >> 2] | 0, 96248) | 0) {
	                    i = d;
	                    return
	                }
	                if (qy(c[f >> 2] | 0, 96256) | 0) {
	                    i = d;
	                    return
	                }
	                if ((c[(c[e >> 2] | 0) + 32 >> 2] | 0) >= 10) {
	                    i = d;
	                    return
	                }
	                c[g >> 2] = 0;
	                while (1) {
	                    if ((c[g >> 2] | 0) >= (c[(c[e >> 2] | 0) + 188 >> 2] | 0)) {
	                        h = 29;
	                        break
	                    }
	                    if (qy(c[(c[(c[e >> 2] | 0) + 196 >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0, 95648) | 0) {
	                        h = 32;
	                        break
	                    }
	                    if (qy(c[(c[(c[e >> 2] | 0) + 196 >> 2] | 0) + (c[g >> 2] << 2) >> 2] | 0, 95656) | 0) {
	                        h = 32;
	                        break
	                    }
	                    c[g >> 2] = (c[g >> 2] | 0) + 1
	                }
	                if ((h | 0) == 29) {
	                    Uo(c[e >> 2] | 0, 95648) | 0;
	                    if (!(c[c[e >> 2] >> 2] | 0)) {
	                        i = d;
	                        return
	                    }
	                    if (!(c[(c[c[e >> 2] >> 2] | 0) + 56 >> 2] | 0)) {
	                        i = d;
	                        return
	                    }
	                    Db[c[(c[c[e >> 2] >> 2] | 0) + 56 >> 2] & 511](c[(c[e >> 2] | 0) + 4 >> 2] | 0, 95648, 0);
	                    i = d;
	                    return
	                } else if ((h | 0) == 32) {
	                    i = d;
	                    return
	                }
	            }

	            function So(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[k >> 2] = 0;
	                c[c[h >> 2] >> 2] = 0;
	                c[j >> 2] = Po(c[g >> 2] | 0) | 0;
	                b = c[g >> 2] | 0;
	                if (!(c[j >> 2] | 0)) {
	                    zo(b, 68, 97912, 0, 0);
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                Fo(b) | 0;
	                if ((d[c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 61) {
	                    me(c[g >> 2] | 0);
	                    Fo(c[g >> 2] | 0) | 0;
	                    c[k >> 2] = hp(c[g >> 2] | 0) | 0
	                }
	                c[c[h >> 2] >> 2] = c[k >> 2];
	                c[f >> 2] = c[j >> 2];
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function To(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 24 | 0;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                l = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[k >> 2] = 0;
	                c[l >> 2] = 0;
	                if ((c[e >> 2] | 0) == 0 | (c[f >> 2] | 0) == 0) {
	                    i = d;
	                    return
	                }
	                c[g >> 2] = 0;
	                b = c[g >> 2] | 0;
	                c[g >> 2] = b + 1;
	                c[h >> 2] = c[(c[f >> 2] | 0) + (b << 2) >> 2];
	                while (1) {
	                    if (!(c[h >> 2] | 0))break;
	                    b = c[g >> 2] | 0;
	                    c[g >> 2] = b + 1;
	                    c[j >> 2] = c[(c[f >> 2] | 0) + (b << 2) >> 2];
	                    if (((c[j >> 2] | 0) != 0 ? (ty(c[h >> 2] | 0, 97872) | 0) == 0 : 0) ? (ty(c[j >> 2] | 0, 97888) | 0) == 0 : 0)c[k >> 2] = 1; else m = 8;
	                    do if ((m | 0) == 8) {
	                        m = 0;
	                        if ((c[j >> 2] | 0) != 0 ? (ty(c[h >> 2] | 0, 94816) | 0) == 0 : 0) {
	                            gp(c[e >> 2] | 0, c[j >> 2] | 0);
	                            break
	                        }
	                        if ((c[j >> 2] | 0) != 0 ? (ty(c[h >> 2] | 0, 97904) | 0) == 0 : 0)c[l >> 2] = c[j >> 2]
	                    } while (0);
	                    b = c[g >> 2] | 0;
	                    c[g >> 2] = b + 1;
	                    c[h >> 2] = c[(c[f >> 2] | 0) + (b << 2) >> 2]
	                }
	                if (!((c[k >> 2] | 0) != 0 & (c[l >> 2] | 0) != 0)) {
	                    i = d;
	                    return
	                }
	                Mo(c[e >> 2] | 0, c[l >> 2] | 0);
	                i = d;
	                return
	            }

	            function Uo(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[(c[f >> 2] | 0) + 32 >> 2] | 0) < 3 ? (qy(c[g >> 2] | 0, 95656) | 0) != 0 : 0)c[(c[f >> 2] | 0) + 32 >> 2] = 3;
	                if ((c[(c[f >> 2] | 0) + 32 >> 2] | 0) < 10 ? (qy(c[g >> 2] | 0, 95648) | 0) != 0 : 0)c[(c[f >> 2] | 0) + 32 >> 2] = 10;
	                if ((c[(c[f >> 2] | 0) + 188 >> 2] | 0) >= (c[(c[f >> 2] | 0) + 192 >> 2] | 0) ? (b = (c[f >> 2] | 0) + 192 | 0, c[b >> 2] = c[b >> 2] << 1, b = Hb[c[135760 >> 2] & 511](c[(c[f >> 2] | 0) + 196 >> 2] | 0, c[(c[f >> 2] | 0) + 192 >> 2] << 2) | 0, c[(c[f >> 2] | 0) + 196 >> 2] = b, (c[(c[f >> 2] | 0) + 196 >> 2] | 0) == 0) : 0) {
	                    xo(c[f >> 2] | 0, 0);
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                c[(c[(c[f >> 2] | 0) + 196 >> 2] | 0) + (c[(c[f >> 2] | 0) + 188 >> 2] << 2) >> 2] = c[g >> 2];
	                c[(c[f >> 2] | 0) + 184 >> 2] = c[g >> 2];
	                g = (c[f >> 2] | 0) + 188 | 0;
	                f = c[g >> 2] | 0;
	                c[g >> 2] = f + 1;
	                c[e >> 2] = f;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function rF(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0;
	                b = i;
	                i = i + 80 | 0;
	                d = b + 64 | 0;
	                e = b + 60 | 0;
	                f = b + 56 | 0;
	                g = b + 52 | 0;
	                h = b + 48 | 0;
	                j = b + 44 | 0;
	                k = b + 40 | 0;
	                l = b + 36 | 0;
	                m = b + 32 | 0;
	                n = b + 28 | 0;
	                o = b + 24 | 0;
	                p = b + 20 | 0;
	                q = b + 16 | 0;
	                r = b + 12 | 0;
	                s = b + 8 | 0;
	                t = b + 4 | 0;
	                u = b;
	                c[e >> 2] = a;
	                c[f >> 2] = c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 56 >> 2];
	                a:while (1) {
	                    if (!(c[f >> 2] | 0)) {
	                        v = 48;
	                        break
	                    }
	                    b:do if (((c[(c[f >> 2] | 0) + 20 >> 2] | 0) == 24 ? (c[(c[f >> 2] | 0) + 32 >> 2] | 0) != 0 : 0) ? (c[(c[(c[f >> 2] | 0) + 32 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                        c[q >> 2] = 0;
	                        c[m >> 2] = c[(c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) + 32 >> 2];
	                        c[g >> 2] = c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 52 >> 2];
	                        while (1) {
	                            if (!(c[g >> 2] | 0))break;
	                            if ((c[(c[(c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) == (c[(c[g >> 2] | 0) + 4 >> 2] | 0))break;
	                            c[g >> 2] = c[c[g >> 2] >> 2]
	                        }
	                        if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 20 >> 2] | 0) != 0 : 0)w = (c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 4 >> 2] | 0) != 0; else w = 0;
	                        c[n >> 2] = w ? 1 : 0;
	                        c[h >> 2] = 0;
	                        while (1) {
	                            if ((c[h >> 2] | 0) >= (c[(c[(c[f >> 2] | 0) + 32 >> 2] | 0) + 4 >> 2] | 0))break b;
	                            c[l >> 2] = 0;
	                            c[q >> 2] = c[(c[c[(c[f >> 2] | 0) + 32 >> 2] >> 2] | 0) + (c[h >> 2] << 2) >> 2];
	                            c:do if (c[g >> 2] | 0) {
	                                c[o >> 2] = c[(c[q >> 2] | 0) + 4 >> 2];
	                                c[j >> 2] = 0;
	                                while (1) {
	                                    if ((c[j >> 2] | 0) >= (c[(c[g >> 2] | 0) + 12 >> 2] | 0))break;
	                                    c[p >> 2] = c[(c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) + 4 >> 2];
	                                    c[k >> 2] = 0;
	                                    while (1) {
	                                        if ((c[k >> 2] | 0) >= (c[m >> 2] | 0))break;
	                                        c[l >> 2] = VD(c[(c[(c[p >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0, c[(c[(c[o >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0) | 0;
	                                        if (!(c[l >> 2] | 0))break;
	                                        if ((c[l >> 2] | 0) == -1) {
	                                            v = 22;
	                                            break a
	                                        }
	                                        c[k >> 2] = (c[k >> 2] | 0) + 1
	                                    }
	                                    if ((c[l >> 2] | 0) == 1)break;
	                                    c[j >> 2] = (c[j >> 2] | 0) + 1
	                                }
	                                if ((c[l >> 2] | 0) == 0 & (c[n >> 2] | 0) != 0) {
	                                    c[j >> 2] = 0;
	                                    while (1) {
	                                        if ((c[j >> 2] | 0) >= (c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 4 >> 2] | 0))break c;
	                                        c[p >> 2] = c[(c[(c[c[(c[g >> 2] | 0) + 20 >> 2] >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) + 4 >> 2];
	                                        c[k >> 2] = 0;
	                                        while (1) {
	                                            if ((c[k >> 2] | 0) >= (c[m >> 2] | 0))break;
	                                            c[l >> 2] = VD(c[(c[(c[p >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0, c[(c[(c[o >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0) | 0;
	                                            if (!(c[l >> 2] | 0))break;
	                                            if ((c[l >> 2] | 0) == -1) {
	                                                v = 33;
	                                                break a
	                                            }
	                                            c[k >> 2] = (c[k >> 2] | 0) + 1
	                                        }
	                                        if ((c[l >> 2] | 0) == 1)break;
	                                        c[j >> 2] = (c[j >> 2] | 0) + 1
	                                    }
	                                    c[r >> 2] = 0;
	                                    c[s >> 2] = 0;
	                                    a = c[e >> 2] | 0;
	                                    x = c[q >> 2] | 0;
	                                    y = c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0;
	                                    z = $G(c[e >> 2] | 0, r, c[(c[q >> 2] | 0) + 4 >> 2] | 0, c[m >> 2] | 0) | 0;
	                                    eH(a, 1877, x, y, 142400, z, YD(s, c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) | 0);
	                                    if (c[r >> 2] | 0) {
	                                        zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                                        c[r >> 2] = 0
	                                    }
	                                    if (c[s >> 2] | 0) {
	                                        zb[c[135736 >> 2] & 511](c[s >> 2] | 0);
	                                        c[s >> 2] = 0
	                                    }
	                                }
	                            } while (0);
	                            if (!(c[l >> 2] | 0)) {
	                                c[t >> 2] = 0;
	                                c[u >> 2] = 0;
	                                z = c[e >> 2] | 0;
	                                y = c[q >> 2] | 0;
	                                x = c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0;
	                                a = $G(c[e >> 2] | 0, t, c[(c[q >> 2] | 0) + 4 >> 2] | 0, c[m >> 2] | 0) | 0;
	                                eH(z, 1877, y, x, 142464, a, YD(u, c[(c[(c[f >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) | 0);
	                                if (c[t >> 2] | 0) {
	                                    zb[c[135736 >> 2] & 511](c[t >> 2] | 0);
	                                    c[t >> 2] = 0
	                                }
	                                if (c[u >> 2] | 0) {
	                                    zb[c[135736 >> 2] & 511](c[u >> 2] | 0);
	                                    c[u >> 2] = 0
	                                }
	                            }
	                            c[h >> 2] = (c[h >> 2] | 0) + 1
	                        }
	                    } while (0);
	                    c[f >> 2] = c[(c[f >> 2] | 0) + 8 >> 2]
	                }
	                if ((v | 0) == 22) {
	                    c[d >> 2] = -1;
	                    A = c[d >> 2] | 0;
	                    i = b;
	                    return A | 0
	                } else if ((v | 0) == 33) {
	                    c[d >> 2] = -1;
	                    A = c[d >> 2] | 0;
	                    i = b;
	                    return A | 0
	                } else if ((v | 0) == 48) {
	                    c[d >> 2] = 0;
	                    A = c[d >> 2] | 0;
	                    i = b;
	                    return A | 0
	                }
	                return 0
	            }

	            function sF(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0;
	                b = i;
	                i = i + 80 | 0;
	                d = b + 64 | 0;
	                e = b + 60 | 0;
	                f = b + 56 | 0;
	                g = b + 52 | 0;
	                h = b + 48 | 0;
	                j = b + 44 | 0;
	                k = b + 40 | 0;
	                l = b + 36 | 0;
	                m = b + 32 | 0;
	                n = b + 28 | 0;
	                o = b + 24 | 0;
	                p = b + 20 | 0;
	                q = b + 16 | 0;
	                r = b + 12 | 0;
	                s = b + 8 | 0;
	                t = b + 4 | 0;
	                u = b;
	                c[e >> 2] = a;
	                c[h >> 2] = 0;
	                c[k >> 2] = 0;
	                c[r >> 2] = 0;
	                c[f >> 2] = c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + 52 >> 2];
	                if (!(c[f >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    v = c[d >> 2] | 0;
	                    i = b;
	                    return v | 0
	                }
	                c[g >> 2] = (c[(c[(c[e >> 2] | 0) + 100 >> 2] | 0) + ((c[(c[e >> 2] | 0) + 96 >> 2] | 0) - 1 << 2) >> 2] | 0) + 52;
	                a:while (1) {
	                    if (!(c[f >> 2] | 0)) {
	                        w = 87;
	                        break
	                    }
	                    if (!(c[(c[f >> 2] | 0) + 12 >> 2] | 0)) {
	                        if ((c[(c[f >> 2] | 0) + 20 >> 2] | 0) != 0 ? (c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0)w = 8
	                    } else w = 8;
	                    b:do if ((w | 0) == 8) {
	                        w = 0;
	                        c:do if (!(c[(c[e >> 2] | 0) + 188 >> 2] | 0)) {
	                            c[n >> 2] = c[(c[e >> 2] | 0) + 112 >> 2];
	                            while (1) {
	                                x = c[n >> 2] | 0;
	                                if ((c[(c[n >> 2] | 0) + 4 >> 2] | 0) == (c[(c[f >> 2] | 0) + 4 >> 2] | 0))break;
	                                c[n >> 2] = c[x >> 2];
	                                if (!(c[n >> 2] | 0))break c
	                            }
	                            if ((c[x + 8 >> 2] | 0) == -1)break b;
	                            if ((c[(c[n >> 2] | 0) + 8 >> 2] | 0) >= (c[(c[e >> 2] | 0) + 96 >> 2] | 0))break b
	                        } while (0);
	                        if (c[g >> 2] | 0)c[h >> 2] = c[c[g >> 2] >> 2];
	                        while (1) {
	                            if (!(c[h >> 2] | 0))break;
	                            if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == (c[(c[f >> 2] | 0) + 4 >> 2] | 0))break;
	                            c[h >> 2] = c[c[h >> 2] >> 2]
	                        }
	                        if (!(c[h >> 2] | 0)) {
	                            c[h >> 2] = fH(c[(c[f >> 2] | 0) + 4 >> 2] | 0) | 0;
	                            if (!(c[h >> 2] | 0))break a;
	                            do if (c[(c[f >> 2] | 0) + 12 >> 2] | 0) {
	                                if (!(c[(c[e >> 2] | 0) + 192 >> 2] | 0)) {
	                                    c[(c[h >> 2] | 0) + 8 >> 2] = c[(c[f >> 2] | 0) + 8 >> 2];
	                                    c[(c[f >> 2] | 0) + 8 >> 2] = 0;
	                                    c[(c[h >> 2] | 0) + 16 >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                                    c[(c[f >> 2] | 0) + 16 >> 2] = 0;
	                                    c[(c[h >> 2] | 0) + 12 >> 2] = c[(c[f >> 2] | 0) + 12 >> 2];
	                                    c[(c[f >> 2] | 0) + 12 >> 2] = 0;
	                                    break
	                                }
	                                a = Cb[c[135744 >> 2] & 511](c[(c[f >> 2] | 0) + 12 >> 2] << 2) | 0;
	                                c[(c[h >> 2] | 0) + 8 >> 2] = a;
	                                if (!(c[(c[h >> 2] | 0) + 8 >> 2] | 0)) {
	                                    w = 76;
	                                    break a
	                                }
	                                c[(c[h >> 2] | 0) + 16 >> 2] = c[(c[f >> 2] | 0) + 12 >> 2];
	                                c[(c[h >> 2] | 0) + 12 >> 2] = c[(c[f >> 2] | 0) + 12 >> 2];
	                                eU(c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0, c[(c[f >> 2] | 0) + 12 >> 2] << 2 | 0) | 0
	                            } while (0);
	                            if (c[(c[f >> 2] | 0) + 20 >> 2] | 0) {
	                                if (c[(c[h >> 2] | 0) + 20 >> 2] | 0)oB(c[(c[h >> 2] | 0) + 20 >> 2] | 0);
	                                c[(c[h >> 2] | 0) + 20 >> 2] = c[(c[f >> 2] | 0) + 20 >> 2];
	                                c[(c[f >> 2] | 0) + 20 >> 2] = 0
	                            }
	                            if (!(c[g >> 2] | 0))break;
	                            if (!(c[c[g >> 2] >> 2] | 0)) {
	                                c[c[g >> 2] >> 2] = c[h >> 2];
	                                break
	                            } else {
	                                c[c[h >> 2] >> 2] = c[c[g >> 2] >> 2];
	                                c[c[g >> 2] >> 2] = c[h >> 2];
	                                break
	                            }
	                        }
	                        c[t >> 2] = c[(c[h >> 2] | 0) + 12 >> 2];
	                        if ((c[(c[h >> 2] | 0) + 20 >> 2] | 0) != 0 ? (c[(c[(c[h >> 2] | 0) + 20 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                            c[u >> 2] = c[(c[(c[h >> 2] | 0) + 20 >> 2] | 0) + 4 >> 2];
	                            c[l >> 2] = c[c[(c[h >> 2] | 0) + 20 >> 2] >> 2]
	                        } else {
	                            c[l >> 2] = 0;
	                            c[u >> 2] = 0
	                        }
	                        c[m >> 2] = c[(c[h >> 2] | 0) + 8 >> 2];
	                        c[s >> 2] = c[(c[(c[f >> 2] | 0) + 4 >> 2] | 0) + 32 >> 2];
	                        c[o >> 2] = 0;
	                        while (1) {
	                            if ((c[o >> 2] | 0) >= (c[(c[f >> 2] | 0) + 12 >> 2] | 0))break b;
	                            c[j >> 2] = c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + (c[o >> 2] << 2) >> 2];
	                            do if (c[j >> 2] | 0) {
	                                if (c[u >> 2] | 0) {
	                                    c[p >> 2] = 0;
	                                    d:while (1) {
	                                        if ((c[p >> 2] | 0) >= (c[u >> 2] | 0))break;
	                                        e:do if ((c[s >> 2] | 0) == 1) {
	                                            c[r >> 2] = VD(c[(c[c[(c[j >> 2] | 0) + 4 >> 2] >> 2] | 0) + 4 >> 2] | 0, c[(c[c[(c[(c[l >> 2] | 0) + (c[p >> 2] << 2) >> 2] | 0) + 4 >> 2] >> 2] | 0) + 4 >> 2] | 0) | 0;
	                                            if ((c[r >> 2] | 0) == -1)break a;
	                                            if (c[r >> 2] | 0)break;
	                                            c[p >> 2] = (c[p >> 2] | 0) + 1;
	                                            continue d
	                                        } else {
	                                            c[k >> 2] = c[(c[l >> 2] | 0) + (c[p >> 2] << 2) >> 2];
	                                            c[q >> 2] = 0;
	                                            while (1) {
	                                                if ((c[q >> 2] | 0) >= (c[s >> 2] | 0))break e;
	                                                c[r >> 2] = VD(c[(c[(c[(c[j >> 2] | 0) + 4 >> 2] | 0) + (c[q >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0, c[(c[(c[(c[k >> 2] | 0) + 4 >> 2] | 0) + (c[q >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0) | 0;
	                                                if ((c[r >> 2] | 0) == -1)break a;
	                                                if (!(c[r >> 2] | 0))break e;
	                                                c[q >> 2] = (c[q >> 2] | 0) + 1
	                                            }
	                                        } while (0);
	                                        if ((c[r >> 2] | 0) == 1)break;
	                                        c[p >> 2] = (c[p >> 2] | 0) + 1
	                                    }
	                                    if (!((c[t >> 2] | 0) != 0 ? (c[p >> 2] | 0) == (c[u >> 2] | 0) : 0))break
	                                } else if (!(c[t >> 2] | 0))break;
	                                c[p >> 2] = 0;
	                                f:while (1) {
	                                    if ((c[p >> 2] | 0) >= (c[t >> 2] | 0))break;
	                                    c[k >> 2] = c[(c[m >> 2] | 0) + (c[p >> 2] << 2) >> 2];
	                                    g:do if ((c[s >> 2] | 0) == 1) {
	                                        c[r >> 2] = VD(c[(c[c[(c[j >> 2] | 0) + 4 >> 2] >> 2] | 0) + 4 >> 2] | 0, c[(c[c[(c[k >> 2] | 0) + 4 >> 2] >> 2] | 0) + 4 >> 2] | 0) | 0;
	                                        if ((c[r >> 2] | 0) == -1)break a;
	                                        if (!(c[r >> 2] | 0)) {
	                                            c[p >> 2] = (c[p >> 2] | 0) + 1;
	                                            continue f
	                                        }
	                                    } else {
	                                        c[q >> 2] = 0;
	                                        while (1) {
	                                            if ((c[q >> 2] | 0) >= (c[s >> 2] | 0))break g;
	                                            c[r >> 2] = VD(c[(c[(c[(c[j >> 2] | 0) + 4 >> 2] | 0) + (c[q >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0, c[(c[(c[(c[k >> 2] | 0) + 4 >> 2] | 0) + (c[q >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0) | 0;
	                                            if ((c[r >> 2] | 0) == -1)break a;
	                                            if (!(c[r >> 2] | 0))break g;
	                                            c[q >> 2] = (c[q >> 2] | 0) + 1
	                                        }
	                                    } while (0);
	                                    if ((c[r >> 2] | 0) == 1)break;
	                                    c[p >> 2] = (c[p >> 2] | 0) + 1
	                                }
	                                if ((c[p >> 2] | 0) != (c[t >> 2] | 0)) {
	                                    c[t >> 2] = (c[t >> 2] | 0) + -1;
	                                    a = (c[h >> 2] | 0) + 12 | 0;
	                                    c[a >> 2] = (c[a >> 2] | 0) + -1;
	                                    c[(c[m >> 2] | 0) + (c[p >> 2] << 2) >> 2] = c[(c[m >> 2] | 0) + (c[t >> 2] << 2) >> 2];
	                                    if ((c[(c[h >> 2] | 0) + 12 >> 2] | 0) != (c[t >> 2] | 0))c[(c[m >> 2] | 0) + (c[t >> 2] << 2) >> 2] = c[(c[m >> 2] | 0) + (c[(c[h >> 2] | 0) + 12 >> 2] << 2) >> 2];
	                                    if ((c[(c[h >> 2] | 0) + 20 >> 2] | 0) == 0 ? (a = JB() | 0, c[(c[h >> 2] | 0) + 20 >> 2] = a, (c[(c[h >> 2] | 0) + 20 >> 2] | 0) == 0) : 0)break a;
	                                    bE(c[(c[h >> 2] | 0) + 20 >> 2] | 0, c[k >> 2] | 0) | 0;
	                                    break
	                                }
	                                if (c[(c[h >> 2] | 0) + 8 >> 2] | 0) {
	                                    if ((c[(c[h >> 2] | 0) + 12 >> 2] | 0) >= (c[(c[h >> 2] | 0) + 16 >> 2] | 0) ? (a = (c[h >> 2] | 0) + 16 | 0, c[a >> 2] = c[a >> 2] << 1, a = Hb[c[135760 >> 2] & 511](c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[(c[h >> 2] | 0) + 16 >> 2] << 2) | 0, c[(c[h >> 2] | 0) + 8 >> 2] = a, (c[(c[h >> 2] | 0) + 8 >> 2] | 0) == 0) : 0) {
	                                        w = 68;
	                                        break a
	                                    }
	                                } else {
	                                    a = Cb[c[135744 >> 2] & 511](40) | 0;
	                                    c[(c[h >> 2] | 0) + 8 >> 2] = a;
	                                    if (!(c[(c[h >> 2] | 0) + 8 >> 2] | 0)) {
	                                        w = 64;
	                                        break a
	                                    }
	                                    c[(c[h >> 2] | 0) + 16 >> 2] = 1
	                                }
	                                c[m >> 2] = c[(c[h >> 2] | 0) + 8 >> 2];
	                                a = c[j >> 2] | 0;
	                                y = (c[h >> 2] | 0) + 12 | 0;
	                                z = c[y >> 2] | 0;
	                                c[y >> 2] = z + 1;
	                                c[(c[m >> 2] | 0) + (z << 2) >> 2] = a
	                            } while (0);
	                            c[o >> 2] = (c[o >> 2] | 0) + 1
	                        }
	                    } while (0);
	                    c[f >> 2] = c[c[f >> 2] >> 2]
	                }
	                if ((w | 0) == 64)IB(0, 142168, 0); else if ((w | 0) == 68)IB(0, 142208, 0); else if ((w | 0) == 76) {
	                    IB(0, 142256, 0);
	                    OD(c[h >> 2] | 0)
	                } else if ((w | 0) == 87) {
	                    c[d >> 2] = 0;
	                    v = c[d >> 2] | 0;
	                    i = b;
	                    return v | 0
	                }
	                c[d >> 2] = -1;
	                v = c[d >> 2] | 0;
	                i = b;
	                return v | 0
	            }

	            function tF(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = rB() | 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[(c[h >> 2] | 0) + 80 >> 2] = c[g >> 2];
	                yP(c[g >> 2] | 0) | 0;
	                if (c[f >> 2] | 0) {
	                    b = AP(c[g >> 2] | 0, c[f >> 2] | 0, -1) | 0;
	                    c[(c[h >> 2] | 0) + 44 >> 2] = b
	                }
	                c[e >> 2] = c[h >> 2];
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function uF(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[g >> 2] = Cb[c[135744 >> 2] & 511](12) | 0;
	                if (!(c[g >> 2] | 0)) {
	                    IB(c[f >> 2] | 0, 141168, 0);
	                    i = d;
	                    return
	                }
	                c[(c[g >> 2] | 0) + 8 >> 2] = -1;
	                c[(c[g >> 2] | 0) + 4 >> 2] = c[e >> 2];
	                c[c[g >> 2] >> 2] = 0;
	                if (!(c[(c[f >> 2] | 0) + 112 >> 2] | 0))c[(c[f >> 2] | 0) + 112 >> 2] = c[g >> 2]; else {
	                    c[c[g >> 2] >> 2] = c[(c[f >> 2] | 0) + 112 >> 2];
	                    c[(c[f >> 2] | 0) + 112 >> 2] = c[g >> 2]
	                }
	                if (c[(c[f >> 2] | 0) + 184 >> 2] | 0) {
	                    i = d;
	                    return
	                }
	                if ((c[c[e >> 2] >> 2] | 0) != 24) {
	                    i = d;
	                    return
	                }
	                c[(c[f >> 2] | 0) + 184 >> 2] = 1;
	                i = d;
	                return
	            }

	            function vF(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 16 | 0;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                g = b + 4 | 0;
	                h = b;
	                c[d >> 2] = a;
	                while (1) {
	                    if (!(c[d >> 2] | 0))break;
	                    c[e >> 2] = c[(c[d >> 2] | 0) + 8 >> 2];
	                    if (c[(c[d >> 2] | 0) + 24 >> 2] | 0) {
	                        c[f >> 2] = 0;
	                        while (1) {
	                            if ((c[f >> 2] | 0) >= (c[(c[d >> 2] | 0) + 28 >> 2] | 0))break;
	                            if (c[(c[(c[d >> 2] | 0) + 24 >> 2] | 0) + (c[f >> 2] << 2) >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[(c[d >> 2] | 0) + 24 >> 2] | 0) + (c[f >> 2] << 2) >> 2] | 0);
	                            c[f >> 2] = (c[f >> 2] | 0) + 1
	                        }
	                        zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 24 >> 2] | 0)
	                    }
	                    if (c[(c[d >> 2] | 0) + 32 >> 2] | 0) {
	                        a:do if ((c[(c[d >> 2] | 0) + 20 >> 2] | 0) == 24) {
	                            c[g >> 2] = 0;
	                            while (1) {
	                                if ((c[g >> 2] | 0) >= (c[(c[(c[d >> 2] | 0) + 32 >> 2] | 0) + 4 >> 2] | 0))break a;
	                                c[h >> 2] = c[(c[c[(c[d >> 2] | 0) + 32 >> 2] >> 2] | 0) + (c[g >> 2] << 2) >> 2];
	                                zb[c[135736 >> 2] & 511](c[(c[h >> 2] | 0) + 4 >> 2] | 0);
	                                zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                                c[g >> 2] = (c[g >> 2] | 0) + 1
	                            }
	                        } while (0);
	                        oB(c[(c[d >> 2] | 0) + 32 >> 2] | 0)
	                    }
	                    zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                    c[d >> 2] = c[e >> 2]
	                }
	                i = b;
	                return
	            }

	            function wF(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (c[c[d >> 2] >> 2] | 0) {
	                    zb[c[135736 >> 2] & 511](c[c[d >> 2] >> 2] | 0);
	                    c[c[d >> 2] >> 2] = 0
	                }
	                c[(c[d >> 2] | 0) + 4 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 8 >> 2] = 0;
	                i = b;
	                return
	            }

	            function xF(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                do switch (c[e >> 2] | 0) {
	                    case 18:
	                    {
	                        c[d >> 2] = 143832;
	                        break
	                    }
	                    case 17:
	                    {
	                        c[d >> 2] = 143776;
	                        break
	                    }
	                    case 24:
	                    {
	                        c[d >> 2] = 144e3;
	                        break
	                    }
	                    case 6:
	                    {
	                        c[d >> 2] = 143856;
	                        break
	                    }
	                    case 8:
	                    {
	                        c[d >> 2] = 143904;
	                        break
	                    }
	                    case 22:
	                    {
	                        c[d >> 2] = 143944;
	                        break
	                    }
	                    case 23:
	                    {
	                        c[d >> 2] = 143976;
	                        break
	                    }
	                    case 16:
	                    {
	                        c[d >> 2] = 143800;
	                        break
	                    }
	                    case 26:
	                    {
	                        c[d >> 2] = 143736;
	                        break
	                    }
	                    case 14:
	                    {
	                        c[d >> 2] = 143712;
	                        break
	                    }
	                    case 1:
	                    {
	                        c[d >> 2] = 143688;
	                        break
	                    }
	                    case 2e3:
	                    {
	                        c[d >> 2] = 144048;
	                        break
	                    }
	                    case 7:
	                    {
	                        c[d >> 2] = 143880;
	                        break
	                    }
	                    case 2001:
	                    {
	                        c[d >> 2] = 144088;
	                        break
	                    }
	                    case 4:
	                    {
	                        c[d >> 2] = 143688;
	                        break
	                    }
	                    case 25:
	                    {
	                        c[d >> 2] = 143928;
	                        break
	                    }
	                    case 5:
	                    {
	                        c[d >> 2] = 143664;
	                        break
	                    }
	                    case 2:
	                    {
	                        c[d >> 2] = 144032;
	                        break
	                    }
	                    case 15:
	                    {
	                        c[d >> 2] = 143752;
	                        break
	                    }
	                    default:
	                        c[d >> 2] = 144136
	                } while (0);
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function yF(a, b, d, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                j = i;
	                i = i + 32 | 0;
	                k = j + 24 | 0;
	                l = j + 20 | 0;
	                m = j + 16 | 0;
	                n = j + 12 | 0;
	                o = j + 8 | 0;
	                p = j + 4 | 0;
	                q = j;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                c[q >> 2] = h;
	                $D(c[k >> 2] | 0, 2, c[l >> 2] | 0, c[m >> 2] | 0, 0, c[n >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0, 0);
	                i = j;
	                return
	            }

	            function zF(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 32 | 0;
	                g = e + 28 | 0;
	                h = e + 24 | 0;
	                j = e + 20 | 0;
	                k = e + 16 | 0;
	                l = e + 12 | 0;
	                m = e + 8 | 0;
	                n = e + 4 | 0;
	                o = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[m >> 2] = 0;
	                c[o >> 2] = 0;
	                if (c[c[h >> 2] >> 2] | 0)zb[c[135736 >> 2] & 511](c[c[h >> 2] >> 2] | 0);
	                c[c[h >> 2] >> 2] = 0;
	                a:while (1) {
	                    c[l >> 2] = QD(c[(c[j >> 2] | 0) + 64 >> 2] | 0) | 0;
	                    c[k >> 2] = c[(c[j >> 2] | 0) + 68 >> 2];
	                    while (1) {
	                        if (!(c[k >> 2] | 0))break;
	                        if ((c[c[k >> 2] >> 2] | 0) == 1007) {
	                            c[o >> 2] = 1;
	                            c[n >> 2] = gH(c[(c[k >> 2] | 0) + 32 >> 2] | 0, c[l >> 2] | 0, m) | 0;
	                            if ((c[n >> 2] | 0) == -1)break a;
	                            if (!(c[c[h >> 2] >> 2] | 0)) {
	                                d = my(142568) | 0;
	                                c[c[h >> 2] >> 2] = d
	                            } else {
	                                d = By(c[c[h >> 2] >> 2] | 0, 157648) | 0;
	                                c[c[h >> 2] >> 2] = d
	                            }
	                            d = By(c[c[h >> 2] >> 2] | 0, c[m >> 2] | 0) | 0;
	                            c[c[h >> 2] >> 2] = d;
	                            d = By(c[c[h >> 2] >> 2] | 0, 142568) | 0;
	                            c[c[h >> 2] >> 2] = d;
	                            if (c[m >> 2] | 0) {
	                                zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                                c[m >> 2] = 0
	                            }
	                        }
	                        c[k >> 2] = c[(c[k >> 2] | 0) + 4 >> 2]
	                    }
	                    if (c[o >> 2] | 0) {
	                        p = 20;
	                        break
	                    }
	                    c[j >> 2] = c[(c[j >> 2] | 0) + 64 >> 2];
	                    if (!(c[j >> 2] | 0)) {
	                        p = 20;
	                        break
	                    }
	                    if ((c[c[j >> 2] >> 2] | 0) == 1) {
	                        p = 20;
	                        break
	                    }
	                }
	                if ((p | 0) == 20) {
	                    c[f >> 2] = c[c[h >> 2] >> 2];
	                    q = c[f >> 2] | 0;
	                    i = e;
	                    return q | 0
	                }
	                xB(c[g >> 2] | 0, 157568, 157600);
	                if (c[c[h >> 2] >> 2] | 0)zb[c[135736 >> 2] & 511](c[c[h >> 2] >> 2] | 0);
	                c[c[h >> 2] >> 2] = 0;
	                c[f >> 2] = 0;
	                q = c[f >> 2] | 0;
	                i = e;
	                return q | 0
	            }

	            function AF(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                do switch (c[c[e >> 2] >> 2] | 0) {
	                    case 14:
	                    {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 52 >> 2];
	                        break
	                    }
	                    case 2e3:
	                    {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 16 >> 2];
	                        break
	                    }
	                    case 15:
	                    {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 56 >> 2];
	                        break
	                    }
	                    case 18:
	                    {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 16 >> 2];
	                        break
	                    }
	                    case 26:
	                    {
	                        if (c[(c[e >> 2] | 0) + 12 >> 2] | 0)c[d >> 2] = AF(c[(c[e >> 2] | 0) + 12 >> 2] | 0) | 0; else f = 13;
	                        break
	                    }
	                    case 24:
	                    case 22:
	                    case 23:
	                    {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 20 >> 2];
	                        break
	                    }
	                    case 1:
	                    {
	                        c[d >> 2] = 142520;
	                        break
	                    }
	                    case 16:
	                    {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 52 >> 2];
	                        break
	                    }
	                    case 5:
	                    case 4:
	                    {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 112 >> 2];
	                        break
	                    }
	                    case 17:
	                    {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 20 >> 2];
	                        break
	                    }
	                    default:
	                        f = 13
	                } while (0);
	                if ((f | 0) == 13)c[d >> 2] = 0;
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function BF(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                a:do switch (c[c[e >> 2] >> 2] | 0) {
	                    case 17:
	                    {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 16 >> 2];
	                        break
	                    }
	                    case 18:
	                    {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 4 >> 2];
	                        break
	                    }
	                    case 14:
	                    {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 8 >> 2];
	                        break
	                    }
	                    case 16:
	                    {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 8 >> 2];
	                        break
	                    }
	                    case 5:
	                    case 4:
	                    case 1:
	                    {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 8 >> 2];
	                        break
	                    }
	                    case 2e3:
	                    {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 12 >> 2];
	                        break
	                    }
	                    case 26:
	                    {
	                        if (c[(c[e >> 2] | 0) + 12 >> 2] | 0) {
	                            c[d >> 2] = BF(c[(c[e >> 2] | 0) + 12 >> 2] | 0) | 0;
	                            break a
	                        } else {
	                            c[d >> 2] = 0;
	                            break a
	                        }
	                        break
	                    }
	                    case 15:
	                    {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 8 >> 2];
	                        break
	                    }
	                    case 24:
	                    case 22:
	                    case 23:
	                    {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 16 >> 2];
	                        break
	                    }
	                    default:
	                        c[d >> 2] = 0
	                } while (0);
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function CF(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 24 | 0;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                l = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                c[j >> 2] = hH(c[g >> 2] | 0) | 0;
	                c[h >> 2] = Eh(c[j >> 2] | 0, 1) | 0;
	                do if (!(c[h >> 2] | 0)) {
	                    if ((c[(c[g >> 2] | 0) + 40 >> 2] | 0) != 2) {
	                        c[l >> 2] = SH(c[j >> 2] | 0) | 0;
	                        if (c[l >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                            c[j >> 2] = c[l >> 2]
	                        }
	                        c[k >> 2] = Cm(0, c[(c[g >> 2] | 0) + 32 >> 2] | 0, c[j >> 2] | 0, c[g >> 2] | 0) | 0;
	                        if (!(c[k >> 2] | 0)) {
	                            c[h >> 2] = 3037;
	                            b = c[f >> 2] | 0;
	                            a = c[g >> 2] | 0;
	                            n = IH(23) | 0;
	                            hE(b, 3037, 0, a, n, 0, 0, 161408, c[j >> 2] | 0, 0);
	                            break
	                        } else {
	                            c[(c[g >> 2] | 0) + 40 >> 2] = 2;
	                            break
	                        }
	                    }
	                } else if ((c[h >> 2] | 0) > 0) {
	                    c[h >> 2] = 3037;
	                    n = c[f >> 2] | 0;
	                    a = c[g >> 2] | 0;
	                    b = IH(23) | 0;
	                    hE(n, 3037, 0, a, b, 0, 0, 161456, c[j >> 2] | 0, 0)
	                } while (0);
	                if (c[j >> 2] | 0)zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                c[e >> 2] = c[h >> 2];
	                m = c[e >> 2] | 0;
	                i = d;
	                return m | 0
	            }

	            function DF(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 24 | 0;
	                j = g + 20 | 0;
	                k = g + 16 | 0;
	                l = g + 12 | 0;
	                m = g + 8 | 0;
	                n = g + 4 | 0;
	                o = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = 0;
	                if ((c[j >> 2] | 0) == 0 | (c[n >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0) {
	                    c[h >> 2] = -1;
	                    p = c[h >> 2] | 0;
	                    i = g;
	                    return p | 0
	                }
	                if ((c[c[n >> 2] >> 2] | 0) != 1) {
	                    xB(c[j >> 2] | 0, 162480, 162512);
	                    c[h >> 2] = -1;
	                    p = c[h >> 2] | 0;
	                    i = g;
	                    return p | 0
	                }
	                switch (c[(c[n >> 2] | 0) + 88 >> 2] | 0) {
	                    case 17:
	                    case 16:
	                    case 29:
	                    case 21:
	                    case 22:
	                        break;
	                    default:
	                    {
	                        xB(c[j >> 2] | 0, 162480, 162552);
	                        c[h >> 2] = -1;
	                        p = c[h >> 2] | 0;
	                        i = g;
	                        return p | 0
	                    }
	                }
	                c[o >> 2] = TH(c[n >> 2] | 0, c[m >> 2] | 0, 0, c[l >> 2] | 0) | 0;
	                if ((c[o >> 2] | 0) < 0) {
	                    xB(c[j >> 2] | 0, 162480, 162624);
	                    c[h >> 2] = -1;
	                    p = c[h >> 2] | 0;
	                    i = g;
	                    return p | 0
	                }
	                if ((c[o >> 2] | 0) > 0) {
	                    if (c[(c[n >> 2] | 0) + 48 >> 2] & 64)c[o >> 2] = 1825; else c[o >> 2] = 1824;
	                    hE(c[j >> 2] | 0, c[o >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[n >> 2] | 0, 0, c[m >> 2] | 0, 0, 0, 0)
	                }
	                c[h >> 2] = c[o >> 2];
	                p = c[h >> 2] | 0;
	                i = g;
	                return p | 0
	            }

	            function EF(a, b, d, e, f, g, h, j, k, l, m, n) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                k = k | 0;
	                l = l | 0;
	                m = m | 0;
	                n = n | 0;
	                var o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0;
	                o = i;
	                i = i + 80 | 0;
	                p = o;
	                q = o + 76 | 0;
	                r = o + 72 | 0;
	                s = o + 68 | 0;
	                t = o + 64 | 0;
	                u = o + 60 | 0;
	                v = o + 56 | 0;
	                w = o + 52 | 0;
	                x = o + 48 | 0;
	                y = o + 44 | 0;
	                z = o + 40 | 0;
	                A = o + 36 | 0;
	                B = o + 32 | 0;
	                C = o + 28 | 0;
	                D = o + 24 | 0;
	                E = o + 20 | 0;
	                c[q >> 2] = a;
	                c[r >> 2] = b;
	                c[s >> 2] = d;
	                c[t >> 2] = e;
	                c[u >> 2] = f;
	                c[v >> 2] = g;
	                c[w >> 2] = h;
	                c[x >> 2] = j;
	                c[y >> 2] = k;
	                c[z >> 2] = l;
	                c[A >> 2] = m;
	                c[B >> 2] = n;
	                c[C >> 2] = 0;
	                c[D >> 2] = 0;
	                c[E >> 2] = 0;
	                if (c[q >> 2] | 0) {
	                    n = (c[q >> 2] | 0) + 20 | 0;
	                    c[n >> 2] = (c[n >> 2] | 0) + 1;
	                    c[(c[q >> 2] | 0) + 16 >> 2] = c[s >> 2];
	                    c[C >> 2] = c[(c[q >> 2] | 0) + 8 >> 2];
	                    c[E >> 2] = c[(c[q >> 2] | 0) + 4 >> 2];
	                    c[D >> 2] = c[(c[q >> 2] | 0) + 24 >> 2]
	                }
	                n = c[D >> 2] | 0;
	                D = c[C >> 2] | 0;
	                C = c[E >> 2] | 0;
	                E = c[q >> 2] | 0;
	                q = c[r >> 2] | 0;
	                r = c[s >> 2] | 0;
	                s = c[t >> 2] | 0;
	                t = c[u >> 2] | 0;
	                u = c[v >> 2] | 0;
	                v = c[w >> 2] | 0;
	                w = c[y >> 2] | 0;
	                y = c[z >> 2] | 0;
	                z = c[A >> 2] | 0;
	                A = c[B >> 2] | 0;
	                c[p >> 2] = c[x >> 2];
	                c[p + 4 >> 2] = w;
	                c[p + 8 >> 2] = y;
	                c[p + 12 >> 2] = z;
	                c[p + 16 >> 2] = A;
	                Xd(n, D, C, E, q, 16, r, 2, 0, 0, s, t, u, 0, 0, v, p);
	                i = o;
	                return
	            }

	            function FF(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = Cb[c[135744 >> 2] & 511](8) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    tC(c[f >> 2] | 0, 168864, c[g >> 2] | 0);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } else {
	                    f = c[h >> 2] | 0;
	                    c[f + 0 >> 2] = 0;
	                    c[f + 4 >> 2] = 0;
	                    c[(c[h >> 2] | 0) + 4 >> 2] = c[g >> 2];
	                    c[e >> 2] = c[h >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                return 0
	            }

	            function GF(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[f + 12 >> 2] = d;
	                c[j >> 2] = e;
	                c[k >> 2] = 0;
	                c[l >> 2] = 0;
	                HC(k, c[g >> 2] | 0, c[(c[j >> 2] | 0) + 20 >> 2] | 0) | 0;
	                e = c[g >> 2] | 0;
	                g = c[h >> 2] | 0;
	                h = c[j >> 2] | 0;
	                d = c[k >> 2] | 0;
	                IC(e, g, h, 163216, d, iH(l, c[(c[j >> 2] | 0) + 36 >> 2] | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0) | 0, 0, 0);
	                if (c[k >> 2] | 0) {
	                    zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    c[k >> 2] = 0
	                }
	                if (!(c[l >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                c[l >> 2] = 0;
	                i = f;
	                return
	            }

	            function HF(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                h = i;
	                i = i + 32 | 0;
	                j = h + 28 | 0;
	                k = h + 24 | 0;
	                l = h + 20 | 0;
	                m = h + 16 | 0;
	                n = h + 12 | 0;
	                o = h + 8 | 0;
	                p = h + 4 | 0;
	                q = h;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                if ((c[k >> 2] | 0) == 0 | (c[o >> 2] | 0) == 0) {
	                    if (c[p >> 2] | 0)c[c[p >> 2] >> 2] = 0;
	                    c[j >> 2] = -1;
	                    r = c[j >> 2] | 0;
	                    i = h;
	                    return r | 0
	                }
	                if ((c[c[o >> 2] >> 2] | 0) != 1) {
	                    if (c[p >> 2] | 0)c[c[p >> 2] >> 2] = 0;
	                    PC(c[k >> 2] | 0, c[m >> 2] | 0, 3069, 168672, c[(c[o >> 2] | 0) + 8 >> 2] | 0, 0);
	                    c[j >> 2] = -1;
	                    r = c[j >> 2] | 0;
	                    i = h;
	                    return r | 0
	                }
	                c[q >> 2] = dE(c[m >> 2] | 0, c[n >> 2] | 0) | 0;
	                if (c[q >> 2] | 0) {
	                    c[j >> 2] = eE(c[k >> 2] | 0, c[l >> 2] | 0, c[q >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0) | 0;
	                    r = c[j >> 2] | 0;
	                    i = h;
	                    return r | 0
	                }
	                if (c[p >> 2] | 0)c[c[p >> 2] >> 2] = 0;
	                c[j >> 2] = 0;
	                r = c[j >> 2] | 0;
	                i = h;
	                return r | 0
	            }

	            function IF(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if ((c[g >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[k >> 2] = c[(c[g >> 2] | 0) + 44 >> 2];
	                while (1) {
	                    if (!(c[k >> 2] | 0)) {
	                        m = 10;
	                        break
	                    }
	                    if (((c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, c[j >> 2] | 0) | 0) != 0 : 0) ? (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[h >> 2] | 0) | 0) != 0 : 0) {
	                        m = 8;
	                        break
	                    }
	                    c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                }
	                if ((m | 0) == 8) {
	                    c[f >> 2] = c[k >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } else if ((m | 0) == 10) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                return 0
	            }

	            function JF(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 20 | 0;
	                h = e + 16 | 0;
	                j = e + 12 | 0;
	                k = e + 8 | 0;
	                l = e + 4 | 0;
	                m = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (c[h >> 2] | 0) {
	                    if (!(c[j >> 2] | 0)) {
	                        c[f >> 2] = c[h >> 2];
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    }
	                    c[m >> 2] = 0;
	                    c[k >> 2] = Xi(c[(c[j >> 2] | 0) + 32 >> 2] | 0, c[j >> 2] | 0) | 0;
	                    d = c[h >> 2] | 0;
	                    if (!(c[k >> 2] | 0))c[l >> 2] = Hl(d, c[(c[(c[j >> 2] | 0) + 32 >> 2] | 0) + 72 >> 2] | 0) | 0; else {
	                        c[l >> 2] = Hl(d, c[k >> 2] | 0) | 0;
	                        zb[c[135736 >> 2] & 511](c[k >> 2] | 0)
	                    }
	                    if (c[l >> 2] | 0) {
	                        c[m >> 2] = AP(c[g >> 2] | 0, c[l >> 2] | 0, -1) | 0;
	                        zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                        c[f >> 2] = c[m >> 2];
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    }
	                }
	                c[f >> 2] = 0;
	                n = c[f >> 2] | 0;
	                i = e;
	                return n | 0
	            }

	            function KF(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[l >> 2] = 0;
	                if (!(c[j >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                if (c[(c[j >> 2] | 0) + 32 >> 2] | 0) {
	                    xB(c[g >> 2] | 0, 168128, 168152);
	                    c[f >> 2] = -1;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                d = c[g >> 2] | 0;
	                if (!(c[(c[j >> 2] | 0) + 20 >> 2] | 0)) {
	                    xB(d, 168128, 168176);
	                    c[f >> 2] = -1;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                if (!(c[d + 28 >> 2] | 0)) {
	                    xB(c[g >> 2] | 0, 168128, 155336);
	                    c[f >> 2] = -1;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                c[k >> 2] = tF(c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[(c[g >> 2] | 0) + 80 >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[f >> 2] = -1;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                c[(c[k >> 2] | 0) + 28 >> 2] = c[(c[g >> 2] | 0) + 28 >> 2];
	                c[(c[k >> 2] | 0) + 36 >> 2] = c[h >> 2];
	                aB(c[k >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] | 0);
	                cB(c[k >> 2] | 0, c[(c[g >> 2] | 0) + 24 >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] | 0);
	                c[(c[k >> 2] | 0) + 40 >> 2] = c[(c[g >> 2] | 0) + 40 >> 2];
	                c[l >> 2] = GB(c[k >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                if (c[l >> 2] | 0)c[(c[g >> 2] | 0) + 16 >> 2] = c[l >> 2];
	                j = (c[g >> 2] | 0) + 20 | 0;
	                c[j >> 2] = (c[j >> 2] | 0) + (c[(c[k >> 2] | 0) + 20 >> 2] | 0);
	                c[(c[g >> 2] | 0) + 40 >> 2] = c[(c[k >> 2] | 0) + 40 >> 2];
	                c[(c[k >> 2] | 0) + 28 >> 2] = 0;
	                YA(c[k >> 2] | 0);
	                c[f >> 2] = c[l >> 2];
	                m = c[f >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function LF(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f + 40 | 0;
	                h = f + 36 | 0;
	                j = f + 32 | 0;
	                k = f + 28 | 0;
	                l = f + 24 | 0;
	                m = f + 20 | 0;
	                n = f + 16 | 0;
	                o = f + 12 | 0;
	                p = f + 8 | 0;
	                q = f + 4 | 0;
	                r = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = 0;
	                c[n >> 2] = 0;
	                c[o >> 2] = 0;
	                c[p >> 2] = 0;
	                c[q >> 2] = 0;
	                c[r >> 2] = 0;
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0) {
	                    c[g >> 2] = -1;
	                    s = c[g >> 2] | 0;
	                    i = f;
	                    return s | 0
	                }
	                c[o >> 2] = jH(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, n, c[l >> 2] | 0) | 0;
	                if (c[o >> 2] | 0) {
	                    c[g >> 2] = c[o >> 2];
	                    s = c[g >> 2] | 0;
	                    i = f;
	                    return s | 0
	                }
	                c[o >> 2] = FB(c[h >> 2] | 0, c[l >> 2] | 0, c[n >> 2] | 0, 0, 0, 0, c[k >> 2] | 0, c[(c[h >> 2] | 0) + 112 >> 2] | 0, 0, r) | 0;
	                if (c[o >> 2] | 0) {
	                    c[g >> 2] = c[o >> 2];
	                    s = c[g >> 2] | 0;
	                    i = f;
	                    return s | 0
	                }
	                a:do if ((c[r >> 2] | 0) != 0 ? (c[(c[r >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) {
	                    e = c[(c[h >> 2] | 0) + 112 >> 2] | 0;
	                    do if (c[(c[r >> 2] | 0) + 12 >> 2] | 0) {
	                        if (!e) {
	                            AB(c[h >> 2] | 0, 3050, c[k >> 2] | 0, 0, 167648, c[n >> 2] | 0, 0);
	                            break
	                        }
	                        if (qy(c[(c[r >> 2] | 0) + 12 >> 2] | 0, c[(c[h >> 2] | 0) + 112 >> 2] | 0) | 0)break a;
	                        oG(c[h >> 2] | 0, 3050, 0, c[k >> 2] | 0, 167792, c[(c[r >> 2] | 0) + 12 >> 2] | 0, c[n >> 2] | 0, c[(c[h >> 2] | 0) + 112 >> 2] | 0)
	                    } else {
	                        if (!e)break a;
	                        c[p >> 2] = 1;
	                        if ((c[(c[r >> 2] | 0) + 32 >> 2] | 0) != 0 ? (c[(c[r >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                            AB(c[h >> 2] | 0, 3050, c[k >> 2] | 0, 0, 167912, c[n >> 2] | 0, 0);
	                            break
	                        }
	                        c[(c[r >> 2] | 0) + 16 >> 2] = c[(c[h >> 2] | 0) + 112 >> 2];
	                        break a
	                    } while (0);
	                    c[g >> 2] = c[(c[h >> 2] | 0) + 16 >> 2];
	                    s = c[g >> 2] | 0;
	                    i = f;
	                    return s | 0
	                } else t = 9; while (0);
	                do if ((t | 0) == 9)if ((c[l >> 2] | 0) == 2) {
	                    c[o >> 2] = 3050;
	                    AB(c[h >> 2] | 0, c[o >> 2] | 0, c[k >> 2] | 0, 0, 167544, c[n >> 2] | 0, 0);
	                    break
	                } else {
	                    c[o >> 2] = 3081;
	                    AB(c[h >> 2] | 0, c[o >> 2] | 0, c[k >> 2] | 0, 0, 167592, c[n >> 2] | 0, 0);
	                    break
	                } while (0);
	                if (((c[r >> 2] | 0) != 0 ? (c[(c[r >> 2] | 0) + 32 >> 2] | 0) == 0 : 0) ? (c[(c[r >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) {
	                    do if (c[p >> 2] | 0)if (!(c[(c[j >> 2] | 0) + 24 >> 2] & 512)) {
	                        n = (c[j >> 2] | 0) + 24 | 0;
	                        c[n >> 2] = c[n >> 2] | 512;
	                        break
	                    } else {
	                        c[q >> 2] = 1;
	                        break
	                    } while (0);
	                    KF(c[h >> 2] | 0, c[j >> 2] | 0, c[r >> 2] | 0) | 0;
	                    if (!((c[p >> 2] | 0) == 0 | (c[q >> 2] | 0) != 0)) {
	                        q = (c[j >> 2] | 0) + 24 | 0;
	                        c[q >> 2] = c[q >> 2] ^ 512
	                    }
	                }
	                c[m >> 2] = c[(c[k >> 2] | 0) + 12 >> 2];
	                if ((c[l >> 2] | 0) != 3) {
	                    if ((((c[m >> 2] | 0) != 0 ? (c[(c[m >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 160992) | 0) != 0 : 0) ? (qy(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0)c[m >> 2] = c[(c[m >> 2] | 0) + 24 >> 2]
	                } else {
	                    c[(c[h >> 2] | 0) + 116 >> 2] = c[r >> 2];
	                    c[(c[h >> 2] | 0) + 100 >> 2] = 1;
	                    b:while (1) {
	                        if (!((((c[m >> 2] | 0) != 0 ? (c[(c[m >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 160992) | 0) != 0 : 0) ? (qy(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0))t = 37;
	                        do if ((t | 0) == 37) {
	                            t = 0;
	                            if ((((c[m >> 2] | 0) != 0 ? (c[(c[m >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 161024) | 0) != 0 : 0) ? (qy(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0)break;
	                            if ((((c[m >> 2] | 0) != 0 ? (c[(c[m >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 161008) | 0) != 0 : 0) ? (qy(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0)break;
	                            if ((((c[m >> 2] | 0) != 0 ? (c[(c[m >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 161080) | 0) != 0 : 0) ? (qy(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0)break;
	                            if (!(c[m >> 2] | 0))break b;
	                            if (!(c[(c[m >> 2] | 0) + 36 >> 2] | 0))break b;
	                            if (!(qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 161064) | 0))break b;
	                            if (!(qy(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0))break b
	                        } while (0);
	                        if (!((((c[m >> 2] | 0) != 0 ? (c[(c[m >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 160992) | 0) != 0 : 0) ? (qy(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0))t = 57;
	                        do if ((t | 0) == 57) {
	                            t = 0;
	                            if ((((c[m >> 2] | 0) != 0 ? (c[(c[m >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 161024) | 0) != 0 : 0) ? (qy(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                                oE(c[h >> 2] | 0, c[j >> 2] | 0, c[m >> 2] | 0, 1) | 0;
	                                break
	                            }
	                            if ((((c[m >> 2] | 0) != 0 ? (c[(c[m >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 161008) | 0) != 0 : 0) ? (qy(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                                nE(c[h >> 2] | 0, c[j >> 2] | 0, c[m >> 2] | 0, 1) | 0;
	                                break
	                            }
	                            if ((((c[m >> 2] | 0) != 0 ? (c[(c[m >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 161080) | 0) != 0 : 0) ? (qy(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                                sE(c[h >> 2] | 0, c[j >> 2] | 0, c[m >> 2] | 0) | 0;
	                                break
	                            }
	                            if ((((c[m >> 2] | 0) != 0 ? (c[(c[m >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 161064) | 0) != 0 : 0) ? (qy(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0)rE(c[h >> 2] | 0, c[j >> 2] | 0, c[m >> 2] | 0) | 0
	                        } while (0);
	                        c[m >> 2] = c[(c[m >> 2] | 0) + 24 >> 2]
	                    }
	                    c[(c[h >> 2] | 0) + 116 >> 2] = 0;
	                    c[(c[h >> 2] | 0) + 100 >> 2] = 0
	                }
	                do if (c[m >> 2] | 0) {
	                    c[o >> 2] = 3033;
	                    j = c[h >> 2] | 0;
	                    t = c[o >> 2] | 0;
	                    r = c[k >> 2] | 0;
	                    q = c[m >> 2] | 0;
	                    if ((c[l >> 2] | 0) == 3) {
	                        uE(j, t, 0, r, q, 0, 168056);
	                        break
	                    } else {
	                        uE(j, t, 0, r, q, 0, 161392);
	                        break
	                    }
	                } while (0);
	                c[g >> 2] = c[o >> 2];
	                s = c[g >> 2] | 0;
	                i = f;
	                return s | 0
	            }

	            function MF(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                h = i;
	                i = i + 32 | 0;
	                j = h + 24 | 0;
	                k = h + 20 | 0;
	                l = h + 16 | 0;
	                m = h + 12 | 0;
	                n = h + 8 | 0;
	                o = h + 4 | 0;
	                p = h;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                c[p >> 2] = 0;
	                GC(p, 0, c[l >> 2] | 0, c[m >> 2] | 0) | 0;
	                l = c[j >> 2] | 0;
	                j = c[m >> 2] | 0;
	                m = c[k >> 2] | 0;
	                k = c[p >> 2] | 0;
	                if (c[o >> 2] | 0)PC(l, j, m, 161256, k, c[o >> 2] | 0); else PC(l, j, m, 163272, k, c[n >> 2] | 0);
	                if (!(c[p >> 2] | 0)) {
	                    i = h;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                c[p >> 2] = 0;
	                i = h;
	                return
	            }

	            function NF(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = 0;
	                c[k >> 2] = 0;
	                c[j >> 2] = _i(c[h >> 2] | 0) | 0;
	                do if (!(qy(c[j >> 2] | 0, 165504) | 0)) {
	                    if (qy(c[j >> 2] | 0, 165512) | 0) {
	                        c[k >> 2] = 0;
	                        break
	                    }
	                    if (qy(c[j >> 2] | 0, 161736) | 0) {
	                        c[k >> 2] = 1;
	                        break
	                    }
	                    if (qy(c[j >> 2] | 0, 165520) | 0) {
	                        c[k >> 2] = 0;
	                        break
	                    } else {
	                        d = c[f >> 2] | 0;
	                        b = c[g >> 2] | 0;
	                        a = c[h >> 2] | 0;
	                        l = IH(15) | 0;
	                        hE(d, 1714, b, a, l, 0, c[j >> 2] | 0, 0, 0, 0);
	                        break
	                    }
	                } else c[k >> 2] = 1; while (0);
	                if (!(c[j >> 2] | 0)) {
	                    m = c[k >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                m = c[k >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function OF(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 28 | 0;
	                h = f + 24 | 0;
	                j = f + 20 | 0;
	                k = f + 16 | 0;
	                l = f + 12 | 0;
	                m = f + 8 | 0;
	                n = f + 4 | 0;
	                o = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[n >> 2] = 0;
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0) {
	                    c[g >> 2] = -1;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                c[c[l >> 2] >> 2] = 0;
	                c[m >> 2] = c[(c[h >> 2] | 0) + 84 >> 2];
	                c[(c[m >> 2] | 0) + 52 >> 2] = 4;
	                c[o >> 2] = c[(c[k >> 2] | 0) + 44 >> 2];
	                while (1) {
	                    if (!(c[o >> 2] | 0))break;
	                    e = c[o >> 2] | 0;
	                    if (!(c[(c[o >> 2] | 0) + 36 >> 2] | 0)) {
	                        if (!(qy(c[e + 8 >> 2] | 0, 161384) | 0))GF(c[h >> 2] | 0, 3035, 0, c[o >> 2] | 0)
	                    } else if (qy(c[(c[e + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)GF(c[h >> 2] | 0, 3035, 0, c[o >> 2] | 0);
	                    c[o >> 2] = c[(c[o >> 2] | 0) + 24 >> 2]
	                }
	                cE(c[h >> 2] | 0, c[k >> 2] | 0, 161384) | 0;
	                c[n >> 2] = c[(c[k >> 2] | 0) + 12 >> 2];
	                if ((((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 160992) | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    o = c[m >> 2] | 0;
	                    kH(o, jE(c[h >> 2] | 0, c[n >> 2] | 0, 1) | 0) | 0;
	                    c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2]
	                }
	                if (!(c[n >> 2] | 0))uE(c[h >> 2] | 0, 3034, 0, c[k >> 2] | 0, 0, 0, 167392);
	                if (!(c[n >> 2] | 0))uE(c[h >> 2] | 0, 3034, 0, c[k >> 2] | 0, 0, 0, 167392);
	                if ((((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 165456) | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    UF(c[h >> 2] | 0, c[j >> 2] | 0, c[n >> 2] | 0, 9) | 0;
	                    c[c[l >> 2] >> 2] = 1;
	                    c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2]
	                } else q = 25;
	                if (((((q | 0) == 25 ? (c[n >> 2] | 0) != 0 : 0) ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 165440) | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    lH(c[h >> 2] | 0, c[j >> 2] | 0, c[n >> 2] | 0, 9) | 0;
	                    c[c[l >> 2] >> 2] = 1;
	                    c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2]
	                }
	                if (c[n >> 2] | 0)uE(c[h >> 2] | 0, 3033, 0, c[k >> 2] | 0, c[n >> 2] | 0, 0, 167392);
	                c[g >> 2] = 0;
	                p = c[g >> 2] | 0;
	                i = f;
	                return p | 0
	            }

	            function PF(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 28 | 0;
	                h = f + 24 | 0;
	                j = f + 20 | 0;
	                k = f + 16 | 0;
	                l = f + 12 | 0;
	                m = f + 8 | 0;
	                n = f + 4 | 0;
	                o = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[n >> 2] = 0;
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0) {
	                    c[g >> 2] = -1;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                c[c[l >> 2] >> 2] = 0;
	                c[m >> 2] = c[(c[h >> 2] | 0) + 84 >> 2];
	                c[o >> 2] = c[(c[k >> 2] | 0) + 44 >> 2];
	                while (1) {
	                    if (!(c[o >> 2] | 0))break;
	                    e = c[o >> 2] | 0;
	                    if (!(c[(c[o >> 2] | 0) + 36 >> 2] | 0)) {
	                        if ((qy(c[e + 8 >> 2] | 0, 161384) | 0) == 0 ? (qy(c[(c[o >> 2] | 0) + 8 >> 2] | 0, 167064) | 0) == 0 : 0)GF(c[h >> 2] | 0, 3035, 0, c[o >> 2] | 0)
	                    } else if (qy(c[(c[e + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)GF(c[h >> 2] | 0, 3035, 0, c[o >> 2] | 0);
	                    c[o >> 2] = c[(c[o >> 2] | 0) + 24 >> 2]
	                }
	                cE(c[h >> 2] | 0, c[k >> 2] | 0, 161384) | 0;
	                if ((gG(c[h >> 2] | 0, c[k >> 2] | 0, 167064, 0) | 0) != 0 ? (c[(c[m >> 2] | 0) + 48 >> 2] & 1 | 0) == 0 : 0) {
	                    o = (c[m >> 2] | 0) + 48 | 0;
	                    c[o >> 2] = c[o >> 2] | 1
	                }
	                c[n >> 2] = c[(c[k >> 2] | 0) + 12 >> 2];
	                if ((((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 160992) | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    o = c[m >> 2] | 0;
	                    kH(o, jE(c[h >> 2] | 0, c[n >> 2] | 0, 1) | 0) | 0;
	                    c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2]
	                }
	                if (!(c[n >> 2] | 0))uE(c[h >> 2] | 0, 3034, 0, c[k >> 2] | 0, 0, 0, 167392);
	                if (!(c[n >> 2] | 0))uE(c[h >> 2] | 0, 3034, 0, c[k >> 2] | 0, 0, 0, 167392);
	                if ((((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 165456) | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    UF(c[h >> 2] | 0, c[j >> 2] | 0, c[n >> 2] | 0, 10) | 0;
	                    c[c[l >> 2] >> 2] = 1;
	                    c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2]
	                } else q = 29;
	                if (((((q | 0) == 29 ? (c[n >> 2] | 0) != 0 : 0) ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 165440) | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    lH(c[h >> 2] | 0, c[j >> 2] | 0, c[n >> 2] | 0, 10) | 0;
	                    c[c[l >> 2] >> 2] = 1;
	                    c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2]
	                }
	                if (c[n >> 2] | 0)uE(c[h >> 2] | 0, 3033, 0, c[k >> 2] | 0, c[n >> 2] | 0, 0, 167392);
	                c[g >> 2] = 0;
	                p = c[g >> 2] | 0;
	                i = f;
	                return p | 0
	            }

	            function QF(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0;
	                g = i;
	                i = i + 80 | 0;
	                h = g + 76 | 0;
	                j = g + 72 | 0;
	                k = g + 68 | 0;
	                l = g + 64 | 0;
	                m = g + 60 | 0;
	                n = g + 56 | 0;
	                o = g + 52 | 0;
	                p = g + 48 | 0;
	                q = g + 44 | 0;
	                r = g + 40 | 0;
	                s = g + 36 | 0;
	                t = g + 32 | 0;
	                u = g + 28 | 0;
	                v = g + 24 | 0;
	                w = g + 20 | 0;
	                x = g + 16 | 0;
	                y = g + 12 | 0;
	                z = g + 8 | 0;
	                A = g + 4 | 0;
	                B = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[p >> 2] = 0;
	                c[q >> 2] = 0;
	                c[s >> 2] = 1;
	                c[t >> 2] = 1;
	                c[v >> 2] = 0;
	                if ((c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0) {
	                    c[h >> 2] = 0;
	                    C = c[h >> 2] | 0;
	                    i = g;
	                    return C | 0
	                }
	                c[o >> 2] = YE(c[j >> 2] | 0, c[k >> 2] | 0, c[m >> 2] | 0, c[l >> 2] | 0) | 0;
	                if (!(c[o >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    C = c[h >> 2] | 0;
	                    i = g;
	                    return C | 0
	                }
	                a:do if (c[n >> 2] | 0) {
	                    f = c[j >> 2] | 0;
	                    e = c[l >> 2] | 0;
	                    if ((c[m >> 2] | 0) == 8) {
	                        c[s >> 2] = XF(f, e, 0, 1, 1, 161728) | 0;
	                        c[t >> 2] = YF(c[j >> 2] | 0, c[l >> 2] | 0, 1, 1, 1, 161736) | 0
	                    } else {
	                        c[s >> 2] = XF(f, e, 0, -1, 1, 161744) | 0;
	                        c[t >> 2] = YF(c[j >> 2] | 0, c[l >> 2] | 0, 0, 1073741824, 1, 161768) | 0
	                    }
	                    ZF(c[j >> 2] | 0, 0, c[l >> 2] | 0, c[s >> 2] | 0, c[t >> 2] | 0) | 0;
	                    c[p >> 2] = XE(c[j >> 2] | 0, c[l >> 2] | 0, c[s >> 2] | 0, c[t >> 2] | 0) | 0;
	                    if (!(c[p >> 2] | 0)) {
	                        c[h >> 2] = 0;
	                        C = c[h >> 2] | 0;
	                        i = g;
	                        return C | 0
	                    }
	                    c[(c[p >> 2] | 0) + 12 >> 2] = c[o >> 2];
	                    c[r >> 2] = c[(c[l >> 2] | 0) + 44 >> 2];
	                    while (1) {
	                        if (!(c[r >> 2] | 0))break a;
	                        e = c[r >> 2] | 0;
	                        if (!(c[(c[r >> 2] | 0) + 36 >> 2] | 0)) {
	                            if (((qy(c[e + 8 >> 2] | 0, 161384) | 0) == 0 ? (qy(c[(c[r >> 2] | 0) + 8 >> 2] | 0, 161808) | 0) == 0 : 0) ? (qy(c[(c[r >> 2] | 0) + 8 >> 2] | 0, 161824) | 0) == 0 : 0)GF(c[j >> 2] | 0, 3035, 0, c[r >> 2] | 0)
	                        } else if (qy(c[(c[e + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)GF(c[j >> 2] | 0, 3035, 0, c[r >> 2] | 0);
	                        c[r >> 2] = c[(c[r >> 2] | 0) + 24 >> 2]
	                    }
	                } else {
	                    c[r >> 2] = c[(c[l >> 2] | 0) + 44 >> 2];
	                    while (1) {
	                        if (!(c[r >> 2] | 0))break a;
	                        e = c[r >> 2] | 0;
	                        if (!(c[(c[r >> 2] | 0) + 36 >> 2] | 0)) {
	                            if (!(qy(c[e + 8 >> 2] | 0, 161384) | 0))GF(c[j >> 2] | 0, 3035, 0, c[r >> 2] | 0)
	                        } else if (qy(c[(c[e + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)GF(c[j >> 2] | 0, 3035, 0, c[r >> 2] | 0);
	                        c[r >> 2] = c[(c[r >> 2] | 0) + 24 >> 2]
	                    }
	                } while (0);
	                cE(c[j >> 2] | 0, c[l >> 2] | 0, 161384) | 0;
	                c[q >> 2] = c[(c[l >> 2] | 0) + 12 >> 2];
	                if ((((c[q >> 2] | 0) != 0 ? (c[(c[q >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[q >> 2] | 0) + 8 >> 2] | 0, 160992) | 0) != 0 : 0) ? (qy(c[(c[(c[q >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    r = jE(c[j >> 2] | 0, c[q >> 2] | 0, 1) | 0;
	                    c[(c[o >> 2] | 0) + 4 >> 2] = r;
	                    c[q >> 2] = c[(c[q >> 2] | 0) + 24 >> 2]
	                }
	                if ((c[m >> 2] | 0) == 8) {
	                    c[x >> 2] = 0;
	                    while (1) {
	                        if (!(c[q >> 2] | 0))break;
	                        if (!(c[(c[q >> 2] | 0) + 36 >> 2] | 0))break;
	                        if (!(qy(c[(c[q >> 2] | 0) + 8 >> 2] | 0, 161040) | 0))break;
	                        if (!(qy(c[(c[(c[q >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0))break;
	                        c[w >> 2] = pE(c[j >> 2] | 0, c[k >> 2] | 0, c[q >> 2] | 0, u, 0) | 0;
	                        if (c[w >> 2] | 0) {
	                            if (c[u >> 2] | 0)c[v >> 2] = (c[v >> 2] | 0) + 1;
	                            if ((c[(c[w >> 2] | 0) + 16 >> 2] | 0) > 1) {
	                                GE(c[j >> 2] | 0, 3091, 0, c[q >> 2] | 0, 161840, 0);
	                                c[(c[w >> 2] | 0) + 16 >> 2] = 1
	                            }
	                            if ((c[(c[w >> 2] | 0) + 20 >> 2] | 0) > 1) {
	                                GE(c[j >> 2] | 0, 3091, 0, c[q >> 2] | 0, 161888, 0);
	                                c[(c[w >> 2] | 0) + 20 >> 2] = 1
	                            }
	                            m = c[w >> 2] | 0;
	                            if (!(c[x >> 2] | 0))c[(c[o >> 2] | 0) + 12 >> 2] = m; else c[(c[x >> 2] | 0) + 8 >> 2] = m;
	                            c[x >> 2] = c[w >> 2]
	                        }
	                        c[q >> 2] = c[(c[q >> 2] | 0) + 24 >> 2]
	                    }
	                    if (c[q >> 2] | 0)uE(c[j >> 2] | 0, 3033, 0, c[l >> 2] | 0, c[q >> 2] | 0, 0, 161936)
	                } else {
	                    c[y >> 2] = 0;
	                    c[z >> 2] = 0;
	                    while (1) {
	                        if ((((c[q >> 2] | 0) != 0 ? (c[(c[q >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[q >> 2] | 0) + 8 >> 2] | 0, 161040) | 0) != 0 : 0) ? (qy(c[(c[(c[q >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0)D = 1; else E = 59;
	                        do if ((E | 0) == 59) {
	                            E = 0;
	                            if ((((c[q >> 2] | 0) != 0 ? (c[(c[q >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[q >> 2] | 0) + 8 >> 2] | 0, 161080) | 0) != 0 : 0) ? (qy(c[(c[(c[q >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                                D = 1;
	                                break
	                            }
	                            if ((((c[q >> 2] | 0) != 0 ? (c[(c[q >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[q >> 2] | 0) + 8 >> 2] | 0, 161976) | 0) != 0 : 0) ? (qy(c[(c[(c[q >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                                D = 1;
	                                break
	                            }
	                            if ((((c[q >> 2] | 0) != 0 ? (c[(c[q >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[q >> 2] | 0) + 8 >> 2] | 0, 161656) | 0) != 0 : 0) ? (qy(c[(c[(c[q >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                                D = 1;
	                                break
	                            }
	                            if (((c[q >> 2] | 0) != 0 ? (c[(c[q >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[q >> 2] | 0) + 8 >> 2] | 0, 161664) | 0) != 0 : 0)D = (qy(c[(c[(c[q >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0; else D = 0
	                        } while (0);
	                        F = (c[q >> 2] | 0) != 0;
	                        if (!D)break;
	                        if (((F ? (c[(c[q >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[q >> 2] | 0) + 8 >> 2] | 0, 161040) | 0) != 0 : 0) ? (qy(c[(c[(c[q >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                            c[y >> 2] = pE(c[j >> 2] | 0, c[k >> 2] | 0, c[q >> 2] | 0, u, 0) | 0;
	                            if ((c[y >> 2] | 0) != 0 & (c[u >> 2] | 0) != 0)c[v >> 2] = (c[v >> 2] | 0) + 1
	                        } else E = 82;
	                        do if ((E | 0) == 82) {
	                            E = 0;
	                            if ((((c[q >> 2] | 0) != 0 ? (c[(c[q >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[q >> 2] | 0) + 8 >> 2] | 0, 161080) | 0) != 0 : 0) ? (qy(c[(c[(c[q >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                                c[y >> 2] = RF(c[j >> 2] | 0, c[k >> 2] | 0, c[q >> 2] | 0) | 0;
	                                if (c[y >> 2] | 0)c[v >> 2] = (c[v >> 2] | 0) + 1;
	                                if (!(c[(c[j >> 2] | 0) + 100 >> 2] | 0))break;
	                                if (!(c[(c[j >> 2] | 0) + 120 >> 2] | 0))break;
	                                if (!((c[y >> 2] | 0) != 0 ? (c[c[(c[(c[j >> 2] | 0) + 120 >> 2] | 0) + 4 >> 2] >> 2] | 0) == 17 : 0))break;
	                                if (!(c[(c[y >> 2] | 0) + 12 >> 2] | 0))break;
	                                if ((c[(c[(c[y >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2] | 0) != (c[(c[(c[j >> 2] | 0) + 120 >> 2] | 0) + 16 >> 2] | 0))break;
	                                if ((c[(c[(c[y >> 2] | 0) + 12 >> 2] | 0) + 16 >> 2] | 0) != (c[(c[(c[j >> 2] | 0) + 120 >> 2] | 0) + 20 >> 2] | 0))break;
	                                do if (c[(c[j >> 2] | 0) + 124 >> 2] | 0) {
	                                    c[A >> 2] = 0;
	                                    w = c[j >> 2] | 0;
	                                    x = c[q >> 2] | 0;
	                                    AB(w, 3081, x, 0, 161984, BB(A, c[(c[(c[j >> 2] | 0) + 120 >> 2] | 0) + 20 >> 2] | 0, c[(c[(c[j >> 2] | 0) + 120 >> 2] | 0) + 16 >> 2] | 0) | 0, 0);
	                                    if (c[A >> 2] | 0) {
	                                        zb[c[135736 >> 2] & 511](c[A >> 2] | 0);
	                                        c[A >> 2] = 0
	                                    }
	                                    c[y >> 2] = 0
	                                } else {
	                                    if ((c[(c[y >> 2] | 0) + 16 >> 2] | 0) == 1 ? (c[(c[y >> 2] | 0) + 20 >> 2] | 0) == 1 : 0)break;
	                                    c[B >> 2] = 0;
	                                    x = c[j >> 2] | 0;
	                                    w = c[q >> 2] | 0;
	                                    AB(x, 3081, w, 0, 162096, BB(B, c[(c[(c[j >> 2] | 0) + 120 >> 2] | 0) + 20 >> 2] | 0, c[(c[(c[j >> 2] | 0) + 120 >> 2] | 0) + 16 >> 2] | 0) | 0, 0);
	                                    if (c[B >> 2] | 0) {
	                                        zb[c[135736 >> 2] & 511](c[B >> 2] | 0);
	                                        c[B >> 2] = 0
	                                    }
	                                    c[y >> 2] = 0
	                                } while (0);
	                                c[(c[(c[j >> 2] | 0) + 120 >> 2] | 0) + 8 >> 2] = c[y >> 2];
	                                w = (c[j >> 2] | 0) + 124 | 0;
	                                c[w >> 2] = (c[w >> 2] | 0) + 1;
	                                break
	                            }
	                            if ((((c[q >> 2] | 0) != 0 ? (c[(c[q >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[q >> 2] | 0) + 8 >> 2] | 0, 161976) | 0) != 0 : 0) ? (qy(c[(c[(c[q >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                                c[y >> 2] = mH(c[j >> 2] | 0, c[k >> 2] | 0, c[q >> 2] | 0) | 0;
	                                break
	                            }
	                            if ((((c[q >> 2] | 0) != 0 ? (c[(c[q >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[q >> 2] | 0) + 8 >> 2] | 0, 161656) | 0) != 0 : 0) ? (qy(c[(c[(c[q >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                                c[y >> 2] = QF(c[j >> 2] | 0, c[k >> 2] | 0, c[q >> 2] | 0, 7, 1) | 0;
	                                break
	                            }
	                            if ((((c[q >> 2] | 0) != 0 ? (c[(c[q >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[q >> 2] | 0) + 8 >> 2] | 0, 161664) | 0) != 0 : 0) ? (qy(c[(c[(c[q >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0)c[y >> 2] = QF(c[j >> 2] | 0, c[k >> 2] | 0, c[q >> 2] | 0, 6, 1) | 0
	                        } while (0);
	                        if (c[y >> 2] | 0) {
	                            w = c[y >> 2] | 0;
	                            if (!(c[z >> 2] | 0))c[(c[o >> 2] | 0) + 12 >> 2] = w; else c[(c[z >> 2] | 0) + 8 >> 2] = w;
	                            c[z >> 2] = c[y >> 2]
	                        }
	                        c[q >> 2] = c[(c[q >> 2] | 0) + 24 >> 2]
	                    }
	                    if (F)uE(c[j >> 2] | 0, 3033, 0, c[l >> 2] | 0, c[q >> 2] | 0, 0, 162240)
	                }
	                if ((c[t >> 2] | 0) == 0 & (c[s >> 2] | 0) == 0) {
	                    c[h >> 2] = 0;
	                    C = c[h >> 2] | 0;
	                    i = g;
	                    return C | 0
	                }
	                if (c[v >> 2] | 0)dG((c[(c[j >> 2] | 0) + 28 >> 2] | 0) + 20 | 0, 10, c[o >> 2] | 0) | 0;
	                if (c[n >> 2] | 0) {
	                    c[h >> 2] = c[p >> 2];
	                    C = c[h >> 2] | 0;
	                    i = g;
	                    return C | 0
	                } else {
	                    c[h >> 2] = c[o >> 2];
	                    C = c[h >> 2] | 0;
	                    i = g;
	                    return C | 0
	                }
	                return 0
	            }

	            function RF(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 40 | 0;
	                g = e + 36 | 0;
	                h = e + 32 | 0;
	                j = e + 28 | 0;
	                k = e + 24 | 0;
	                l = e + 20 | 0;
	                m = e + 16 | 0;
	                n = e + 12 | 0;
	                o = e + 8 | 0;
	                p = e + 4 | 0;
	                q = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[l >> 2] = 0;
	                c[n >> 2] = 0;
	                c[o >> 2] = 0;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                }
	                c[m >> 2] = dE(c[j >> 2] | 0, 160064) | 0;
	                d = c[g >> 2] | 0;
	                if (!(c[m >> 2] | 0)) {
	                    MF(d, 3036, 0, c[j >> 2] | 0, 160064, 0);
	                    c[f >> 2] = 0;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                }
	                if (_F(d, c[h >> 2] | 0, 0, c[m >> 2] | 0, o, n) | 0) {
	                    c[f >> 2] = 0;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                }
	                $F(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[m >> 2] | 0, c[o >> 2] | 0) | 0;
	                c[p >> 2] = XF(c[g >> 2] | 0, c[j >> 2] | 0, 0, -1, 1, 161744) | 0;
	                c[q >> 2] = YF(c[g >> 2] | 0, c[j >> 2] | 0, 0, 1073741824, 1, 161768) | 0;
	                c[m >> 2] = c[(c[j >> 2] | 0) + 44 >> 2];
	                while (1) {
	                    if (!(c[m >> 2] | 0))break;
	                    h = c[m >> 2] | 0;
	                    if (!(c[(c[m >> 2] | 0) + 36 >> 2] | 0)) {
	                        if ((((qy(c[h + 8 >> 2] | 0, 160064) | 0) == 0 ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 161384) | 0) == 0 : 0) ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 161824) | 0) == 0 : 0) ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 161808) | 0) == 0 : 0)GF(c[g >> 2] | 0, 3035, 0, c[m >> 2] | 0)
	                    } else if (qy(c[(c[h + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)GF(c[g >> 2] | 0, 3035, 0, c[m >> 2] | 0);
	                    c[m >> 2] = c[(c[m >> 2] | 0) + 24 >> 2]
	                }
	                cE(c[g >> 2] | 0, c[j >> 2] | 0, 161384) | 0;
	                c[k >> 2] = XE(c[g >> 2] | 0, c[j >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                }
	                m = cG(c[g >> 2] | 0, 17, c[n >> 2] | 0, c[o >> 2] | 0) | 0;
	                c[(c[k >> 2] | 0) + 12 >> 2] = m;
	                ZF(c[g >> 2] | 0, c[k >> 2] | 0, c[j >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0) | 0;
	                c[l >> 2] = c[(c[j >> 2] | 0) + 12 >> 2];
	                if ((((c[l >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[l >> 2] | 0) + 8 >> 2] | 0, 160992) | 0) != 0 : 0) ? (qy(c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    m = jE(c[g >> 2] | 0, c[l >> 2] | 0, 1) | 0;
	                    c[(c[k >> 2] | 0) + 4 >> 2] = m;
	                    c[l >> 2] = c[(c[l >> 2] | 0) + 24 >> 2]
	                }
	                if (c[l >> 2] | 0)uE(c[g >> 2] | 0, 3033, 0, c[j >> 2] | 0, c[l >> 2] | 0, 0, 161392);
	                if ((c[p >> 2] | 0) == 0 & (c[q >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                } else {
	                    c[f >> 2] = c[k >> 2];
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                }
	                return 0
	            }

	            function SF(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                h = i;
	                i = i + 32 | 0;
	                j = h + 28 | 0;
	                k = h + 24 | 0;
	                l = h + 20 | 0;
	                m = h + 16 | 0;
	                n = h + 12 | 0;
	                o = h + 8 | 0;
	                p = h + 4 | 0;
	                q = h;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                while (1) {
	                    if (!((((c[c[m >> 2] >> 2] | 0) != 0 ? (c[(c[c[m >> 2] >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[c[m >> 2] >> 2] | 0) + 8 >> 2] | 0, 161048) | 0) != 0 : 0) ? (qy(c[(c[(c[c[m >> 2] >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0)) {
	                        if (!(c[c[m >> 2] >> 2] | 0)) {
	                            r = 24;
	                            break
	                        }
	                        if (!(c[(c[c[m >> 2] >> 2] | 0) + 36 >> 2] | 0)) {
	                            r = 24;
	                            break
	                        }
	                        if (!(qy(c[(c[c[m >> 2] >> 2] | 0) + 8 >> 2] | 0, 161064) | 0)) {
	                            r = 24;
	                            break
	                        }
	                        if (!(qy(c[(c[(c[c[m >> 2] >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)) {
	                            r = 24;
	                            break
	                        }
	                    }
	                    if ((((c[c[m >> 2] >> 2] | 0) != 0 ? (c[(c[c[m >> 2] >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[c[m >> 2] >> 2] | 0) + 8 >> 2] | 0, 161048) | 0) != 0 : 0) ? (qy(c[(c[(c[c[m >> 2] >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0)c[q >> 2] = nH(c[k >> 2] | 0, c[l >> 2] | 0, c[c[m >> 2] >> 2] | 0, c[c[n >> 2] >> 2] | 0, c[o >> 2] | 0) | 0; else r = 15;
	                    if ((r | 0) == 15 ? (r = 0, c[q >> 2] = oH(c[k >> 2] | 0, c[l >> 2] | 0, c[c[m >> 2] >> 2] | 0) | 0, (c[q >> 2] | 0) != 0 & (c[p >> 2] | 0) != 0) : 0)c[c[p >> 2] >> 2] = 1;
	                    if (c[q >> 2] | 0) {
	                        if ((c[c[n >> 2] >> 2] | 0) == 0 ? (g = JB() | 0, c[c[n >> 2] >> 2] = g, (c[c[n >> 2] >> 2] | 0) == 0) : 0) {
	                            r = 20;
	                            break
	                        }
	                        if ((pG(c[c[n >> 2] >> 2] | 0, 2, c[q >> 2] | 0) | 0) == -1) {
	                            r = 22;
	                            break
	                        }
	                    }
	                    c[c[m >> 2] >> 2] = c[(c[c[m >> 2] >> 2] | 0) + 24 >> 2]
	                }
	                if ((r | 0) == 20) {
	                    c[j >> 2] = -1;
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                } else if ((r | 0) == 22) {
	                    c[j >> 2] = -1;
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                } else if ((r | 0) == 24) {
	                    c[j >> 2] = 0;
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                }
	                return 0
	            }

	            function TF(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 20 | 0;
	                h = e + 16 | 0;
	                j = e + 12 | 0;
	                k = e + 8 | 0;
	                l = e + 4 | 0;
	                m = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[l >> 2] = 0;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                c[k >> 2] = qG(c[g >> 2] | 0, c[h >> 2] | 0, 21, c[j >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                c[m >> 2] = c[(c[j >> 2] | 0) + 44 >> 2];
	                while (1) {
	                    if (!(c[m >> 2] | 0))break;
	                    d = c[m >> 2] | 0;
	                    if (!(c[(c[m >> 2] | 0) + 36 >> 2] | 0)) {
	                        if (((qy(c[d + 8 >> 2] | 0, 161384) | 0) == 0 ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 162304) | 0) == 0 : 0) ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 162320) | 0) == 0 : 0)GF(c[g >> 2] | 0, 3035, 0, c[m >> 2] | 0)
	                    } else if (qy(c[(c[d + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)GF(c[g >> 2] | 0, 3035, 0, c[m >> 2] | 0);
	                    c[m >> 2] = c[(c[m >> 2] | 0) + 24 >> 2]
	                }
	                cE(c[g >> 2] | 0, c[j >> 2] | 0, 161384) | 0;
	                if (pH(c[g >> 2] | 0, c[h >> 2] | 0, c[k >> 2] | 0, c[j >> 2] | 0) | 0) {
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                c[l >> 2] = c[(c[j >> 2] | 0) + 12 >> 2];
	                if ((((c[l >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[l >> 2] | 0) + 8 >> 2] | 0, 160992) | 0) != 0 : 0) ? (qy(c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    h = jE(c[g >> 2] | 0, c[l >> 2] | 0, 1) | 0;
	                    c[(c[k >> 2] | 0) + 8 >> 2] = h;
	                    c[l >> 2] = c[(c[l >> 2] | 0) + 24 >> 2]
	                }
	                if (c[l >> 2] | 0)uE(c[g >> 2] | 0, 3033, 0, c[j >> 2] | 0, c[l >> 2] | 0, 0, 161392);
	                c[f >> 2] = c[k >> 2];
	                n = c[f >> 2] | 0;
	                i = e;
	                return n | 0
	            }

	            function UF(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0;
	                f = i;
	                i = i + 64 | 0;
	                g = f + 52 | 0;
	                h = f + 48 | 0;
	                j = f + 44 | 0;
	                k = f + 40 | 0;
	                l = f + 36 | 0;
	                m = f + 32 | 0;
	                n = f + 28 | 0;
	                o = f + 24 | 0;
	                p = f + 20 | 0;
	                q = f + 16 | 0;
	                r = f + 12 | 0;
	                s = f + 8 | 0;
	                t = f + 4 | 0;
	                u = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[n >> 2] = 0;
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0) {
	                    c[g >> 2] = 0;
	                    v = c[g >> 2] | 0;
	                    i = f;
	                    return v | 0
	                }
	                c[m >> 2] = c[(c[h >> 2] | 0) + 84 >> 2];
	                e = (c[m >> 2] | 0) + 48 | 0;
	                c[e >> 2] = c[e >> 2] | 4;
	                c[o >> 2] = c[(c[k >> 2] | 0) + 44 >> 2];
	                while (1) {
	                    if (!(c[o >> 2] | 0))break;
	                    e = c[o >> 2] | 0;
	                    if (!(c[(c[o >> 2] | 0) + 36 >> 2] | 0)) {
	                        if ((qy(c[e + 8 >> 2] | 0, 161384) | 0) == 0 ? (qy(c[(c[o >> 2] | 0) + 8 >> 2] | 0, 151424) | 0) == 0 : 0)GF(c[h >> 2] | 0, 3035, 0, c[o >> 2] | 0)
	                    } else if (qy(c[(c[e + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)GF(c[h >> 2] | 0, 3035, 0, c[o >> 2] | 0);
	                    c[o >> 2] = c[(c[o >> 2] | 0) + 24 >> 2]
	                }
	                cE(c[h >> 2] | 0, c[k >> 2] | 0, 161384) | 0;
	                do if (!(fG(c[h >> 2] | 0, c[j >> 2] | 0, 0, c[k >> 2] | 0, 151424, (c[m >> 2] | 0) + 60 | 0, (c[m >> 2] | 0) + 56 | 0) | 0)) {
	                    if ((c[(c[m >> 2] | 0) + 56 >> 2] | 0) == 0 ? (c[c[m >> 2] >> 2] | 0) == 5 : 0) {
	                        MF(c[h >> 2] | 0, 3036, 0, c[k >> 2] | 0, 151424, 0);
	                        break
	                    }
	                    if ((c[(c[h >> 2] | 0) + 100 >> 2] | 0) != 0 ? (c[(c[m >> 2] | 0) + 48 >> 2] & 8 | 0) != 0 : 0) {
	                        if (!(c[(c[m >> 2] | 0) + 56 >> 2] | 0)) {
	                            MF(c[h >> 2] | 0, 3036, 0, c[k >> 2] | 0, 151424, 0);
	                            break
	                        }
	                        if ((qy(c[(c[m >> 2] | 0) + 56 >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0) | 0) != 0 ? (qy(c[(c[m >> 2] | 0) + 60 >> 2] | 0, c[(c[m >> 2] | 0) + 112 >> 2] | 0) | 0) != 0 : 0)break;
	                        c[p >> 2] = 0;
	                        c[q >> 2] = 0;
	                        o = c[h >> 2] | 0;
	                        e = c[k >> 2] | 0;
	                        d = BB(p, c[(c[m >> 2] | 0) + 60 >> 2] | 0, c[(c[m >> 2] | 0) + 56 >> 2] | 0) | 0;
	                        oG(o, 3081, 0, e, 166112, d, BB(q, c[(c[m >> 2] | 0) + 112 >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0) | 0, 0);
	                        if (c[p >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                            c[p >> 2] = 0
	                        }
	                        if (c[q >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                            c[q >> 2] = 0
	                        }
	                        c[(c[m >> 2] | 0) + 56 >> 2] = 0;
	                        c[(c[m >> 2] | 0) + 60 >> 2] = 0
	                    }
	                } while (0);
	                c[n >> 2] = c[(c[k >> 2] | 0) + 12 >> 2];
	                if ((((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 160992) | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    q = c[m >> 2] | 0;
	                    kH(q, jE(c[h >> 2] | 0, c[n >> 2] | 0, 1) | 0) | 0;
	                    c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2]
	                }
	                do if ((c[l >> 2] | 0) == 4) {
	                    if ((((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 161024) | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        q = c[h >> 2] | 0;
	                        if (c[(c[m >> 2] | 0) + 56 >> 2] | 0)uE(q, 3005, 0, c[k >> 2] | 0, c[n >> 2] | 0, 166232, 0); else {
	                            p = oE(q, c[j >> 2] | 0, c[n >> 2] | 0, 0) | 0;
	                            c[(c[m >> 2] | 0) + 64 >> 2] = p
	                        }
	                        c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2];
	                        break
	                    }
	                    if (!(c[(c[m >> 2] | 0) + 56 >> 2] | 0))uE(c[h >> 2] | 0, 3005, 0, c[k >> 2] | 0, c[n >> 2] | 0, 166304, 0)
	                } else {
	                    if ((c[l >> 2] | 0) != 10) {
	                        if (!((c[l >> 2] | 0) == 9 & (c[n >> 2] | 0) != 0))break;
	                        if (!(c[(c[n >> 2] | 0) + 36 >> 2] | 0))break;
	                        if (!(qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 161024) | 0))break;
	                        if (!(qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0))break;
	                        p = oE(c[h >> 2] | 0, c[j >> 2] | 0, c[n >> 2] | 0, 0) | 0;
	                        c[(c[m >> 2] | 0) + 104 >> 2] = p;
	                        if (c[(c[m >> 2] | 0) + 104 >> 2] | 0) {
	                            c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2];
	                            break
	                        }
	                        c[g >> 2] = 0;
	                        v = c[g >> 2] | 0;
	                        i = f;
	                        return v | 0
	                    }
	                    if ((((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 161648) | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        p = QF(c[h >> 2] | 0, c[j >> 2] | 0, c[n >> 2] | 0, 8, 1) | 0;
	                        c[(c[m >> 2] | 0) + 28 >> 2] = p;
	                        c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2];
	                        break
	                    }
	                    if ((((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 161656) | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        p = QF(c[h >> 2] | 0, c[j >> 2] | 0, c[n >> 2] | 0, 7, 1) | 0;
	                        c[(c[m >> 2] | 0) + 28 >> 2] = p;
	                        c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2];
	                        break
	                    }
	                    if ((((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 161664) | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        p = QF(c[h >> 2] | 0, c[j >> 2] | 0, c[n >> 2] | 0, 6, 1) | 0;
	                        c[(c[m >> 2] | 0) + 28 >> 2] = p;
	                        c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2];
	                        break
	                    }
	                    if ((((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 161080) | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        p = RF(c[h >> 2] | 0, c[j >> 2] | 0, c[n >> 2] | 0) | 0;
	                        c[(c[m >> 2] | 0) + 28 >> 2] = p;
	                        c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2]
	                    }
	                } while (0);
	                a:do if ((c[l >> 2] | 0) == 4 | (c[l >> 2] | 0) == 9) {
	                    c[s >> 2] = 0;
	                    b:while (1) {
	                        if (!((((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 157848) | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0))w = 77;
	                        c:do if ((w | 0) == 77) {
	                            w = 0;
	                            if ((((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 157832) | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0)break;
	                            if ((((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 157816) | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0)break;
	                            if ((((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 157800) | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0)break;
	                            if ((((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 157936) | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0)break;
	                            if ((((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 157952) | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0)break;
	                            if ((((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 157792) | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0)break;
	                            if ((((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 157880) | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0)break;
	                            if ((((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 157864) | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0)break;
	                            do if ((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) {
	                                if (!(qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 157896) | 0))break;
	                                if (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)break c
	                            } while (0);
	                            do if (c[n >> 2] | 0) {
	                                if (!(c[(c[n >> 2] | 0) + 36 >> 2] | 0))break;
	                                if (!(qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 157904) | 0))break;
	                                if (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)break c
	                            } while (0);
	                            if (!(c[n >> 2] | 0))break b;
	                            if (!(c[(c[n >> 2] | 0) + 36 >> 2] | 0))break b;
	                            if (!(qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 157920) | 0))break b;
	                            if (!(qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0))break b
	                        } while (0);
	                        c[r >> 2] = qH(c[h >> 2] | 0, c[j >> 2] | 0, c[n >> 2] | 0) | 0;
	                        if (c[r >> 2] | 0) {
	                            p = c[r >> 2] | 0;
	                            if (!(c[s >> 2] | 0))c[(c[m >> 2] | 0) + 68 >> 2] = p; else c[(c[s >> 2] | 0) + 4 >> 2] = p;
	                            c[s >> 2] = c[r >> 2];
	                            c[(c[s >> 2] | 0) + 4 >> 2] = 0
	                        }
	                        c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2]
	                    }
	                    if (c[(c[m >> 2] | 0) + 68 >> 2] | 0) {
	                        c[u >> 2] = 0;
	                        c[r >> 2] = c[(c[m >> 2] | 0) + 68 >> 2];
	                        while (1) {
	                            c[t >> 2] = Cb[c[135744 >> 2] & 511](8) | 0;
	                            if (!(c[t >> 2] | 0))break;
	                            c[(c[t >> 2] | 0) + 4 >> 2] = c[r >> 2];
	                            c[c[t >> 2] >> 2] = 0;
	                            p = c[t >> 2] | 0;
	                            if (!(c[u >> 2] | 0))c[(c[m >> 2] | 0) + 96 >> 2] = p; else c[c[u >> 2] >> 2] = p;
	                            c[u >> 2] = c[t >> 2];
	                            c[r >> 2] = c[(c[r >> 2] | 0) + 4 >> 2];
	                            if (!(c[r >> 2] | 0))break a
	                        }
	                        tC(c[h >> 2] | 0, 166376, 0);
	                        zb[c[135736 >> 2] & 511](c[t >> 2] | 0);
	                        c[g >> 2] = 0;
	                        v = c[g >> 2] | 0;
	                        i = f;
	                        return v | 0
	                    }
	                } while (0);
	                if ((c[c[m >> 2] >> 2] | 0) == 5) {
	                    if ((SF(c[h >> 2] | 0, c[j >> 2] | 0, n, (c[m >> 2] | 0) + 116 | 0, 12, 0) | 0) == -1) {
	                        c[g >> 2] = 0;
	                        v = c[g >> 2] | 0;
	                        i = f;
	                        return v | 0
	                    }
	                    if ((((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 163328) | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        t = TF(c[h >> 2] | 0, c[j >> 2] | 0, c[n >> 2] | 0) | 0;
	                        c[(c[m >> 2] | 0) + 84 >> 2] = t;
	                        c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2]
	                    }
	                }
	                do if (c[n >> 2] | 0) {
	                    if ((c[l >> 2] | 0) == 10) {
	                        uE(c[h >> 2] | 0, 3033, 0, c[k >> 2] | 0, c[n >> 2] | 0, 0, 166400);
	                        break
	                    }
	                    t = c[h >> 2] | 0;
	                    m = c[k >> 2] | 0;
	                    j = c[n >> 2] | 0;
	                    if ((c[l >> 2] | 0) == 9) {
	                        uE(t, 3033, 0, m, j, 0, 166504);
	                        break
	                    } else {
	                        uE(t, 3033, 0, m, j, 0, 166752);
	                        break
	                    }
	                } while (0);
	                c[g >> 2] = 0;
	                v = c[g >> 2] | 0;
	                i = f;
	                return v | 0
	            }

	            function VF(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 20 | 0;
	                h = e + 16 | 0;
	                j = e + 12 | 0;
	                k = e + 8 | 0;
	                l = e + 4 | 0;
	                m = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[l >> 2] = 0;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                c[k >> 2] = c[(c[g >> 2] | 0) + 84 >> 2];
	                d = (c[k >> 2] | 0) + 48 | 0;
	                c[d >> 2] = c[d >> 2] | 64;
	                d = IH(46) | 0;
	                c[(c[k >> 2] | 0) + 64 >> 2] = d;
	                c[m >> 2] = c[(c[j >> 2] | 0) + 44 >> 2];
	                while (1) {
	                    if (!(c[m >> 2] | 0))break;
	                    d = c[m >> 2] | 0;
	                    if (!(c[(c[m >> 2] | 0) + 36 >> 2] | 0)) {
	                        if ((qy(c[d + 8 >> 2] | 0, 161384) | 0) == 0 ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 160400) | 0) == 0 : 0)GF(c[g >> 2] | 0, 3035, 0, c[m >> 2] | 0)
	                    } else if (qy(c[(c[d + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)GF(c[g >> 2] | 0, 3035, 0, c[m >> 2] | 0);
	                    c[m >> 2] = c[(c[m >> 2] | 0) + 24 >> 2]
	                }
	                cE(c[g >> 2] | 0, c[j >> 2] | 0, 161384) | 0;
	                fG(c[g >> 2] | 0, c[h >> 2] | 0, 0, c[j >> 2] | 0, 160400, (c[k >> 2] | 0) + 60 | 0, (c[k >> 2] | 0) + 56 | 0) | 0;
	                c[l >> 2] = c[(c[j >> 2] | 0) + 12 >> 2];
	                if ((((c[l >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[l >> 2] | 0) + 8 >> 2] | 0, 160992) | 0) != 0 : 0) ? (qy(c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    m = c[k >> 2] | 0;
	                    kH(m, jE(c[g >> 2] | 0, c[l >> 2] | 0, 1) | 0) | 0;
	                    c[l >> 2] = c[(c[l >> 2] | 0) + 24 >> 2]
	                }
	                if ((((c[l >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[l >> 2] | 0) + 8 >> 2] | 0, 161024) | 0) != 0 : 0) ? (qy(c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    m = c[g >> 2] | 0;
	                    if (c[(c[k >> 2] | 0) + 56 >> 2] | 0)GE(m, 3e3, 0, c[j >> 2] | 0, 165952, 0); else {
	                        d = oE(m, c[h >> 2] | 0, c[l >> 2] | 0, 0) | 0;
	                        c[(c[k >> 2] | 0) + 28 >> 2] = d
	                    }
	                    c[l >> 2] = c[(c[l >> 2] | 0) + 24 >> 2]
	                } else o = 25;
	                if ((o | 0) == 25 ? (c[(c[k >> 2] | 0) + 56 >> 2] | 0) == 0 : 0)GE(c[g >> 2] | 0, 3e3, 0, c[j >> 2] | 0, 166032, 0);
	                if (c[l >> 2] | 0)uE(c[g >> 2] | 0, 3033, 0, c[j >> 2] | 0, c[l >> 2] | 0, 0, 164200);
	                if (((c[(c[k >> 2] | 0) + 56 >> 2] | 0) == 0 ? (c[(c[k >> 2] | 0) + 28 >> 2] | 0) == 0 : 0) ? (dE(c[j >> 2] | 0, 160400) | 0) == 0 : 0)GE(c[g >> 2] | 0, 3e3, 0, c[j >> 2] | 0, 166032, 0);
	                c[f >> 2] = 0;
	                n = c[f >> 2] | 0;
	                i = e;
	                return n | 0
	            }

	            function WF(a, b, e) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0;
	                f = i;
	                i = i + 80 | 0;
	                g = f + 64 | 0;
	                h = f + 60 | 0;
	                j = f + 56 | 0;
	                k = f + 52 | 0;
	                l = f + 48 | 0;
	                m = f + 44 | 0;
	                n = f + 40 | 0;
	                o = f + 36 | 0;
	                p = f + 32 | 0;
	                q = f + 28 | 0;
	                r = f + 24 | 0;
	                s = f + 20 | 0;
	                t = f + 16 | 0;
	                u = f + 12 | 0;
	                v = f + 8 | 0;
	                w = f + 4 | 0;
	                x = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[m >> 2] = 0;
	                c[o >> 2] = 0;
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0) {
	                    c[g >> 2] = -1;
	                    y = c[g >> 2] | 0;
	                    i = f;
	                    return y | 0
	                }
	                c[l >> 2] = c[(c[h >> 2] | 0) + 84 >> 2];
	                e = (c[l >> 2] | 0) + 48 | 0;
	                c[e >> 2] = c[e >> 2] | 128;
	                e = IH(46) | 0;
	                c[(c[l >> 2] | 0) + 64 >> 2] = e;
	                c[n >> 2] = c[(c[k >> 2] | 0) + 44 >> 2];
	                while (1) {
	                    if (!(c[n >> 2] | 0))break;
	                    e = c[n >> 2] | 0;
	                    if (!(c[(c[n >> 2] | 0) + 36 >> 2] | 0)) {
	                        if ((qy(c[e + 8 >> 2] | 0, 161384) | 0) == 0 ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 160512) | 0) == 0 : 0)GF(c[h >> 2] | 0, 3035, 0, c[n >> 2] | 0)
	                    } else if (qy(c[(c[e + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)GF(c[h >> 2] | 0, 3035, 0, c[n >> 2] | 0);
	                    c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2]
	                }
	                cE(c[h >> 2] | 0, c[k >> 2] | 0, 161384) | 0;
	                c[n >> 2] = dE(c[k >> 2] | 0, 160512) | 0;
	                a:do if (c[n >> 2] | 0) {
	                    c[u >> 2] = 0;
	                    c[o >> 2] = fE(c[h >> 2] | 0, c[n >> 2] | 0) | 0;
	                    c[(c[l >> 2] | 0) + 56 >> 2] = c[o >> 2];
	                    while (1) {
	                        do if ((d[c[o >> 2] >> 0] | 0 | 0) == 32)z = 1; else {
	                            if (9 <= (d[c[o >> 2] >> 0] | 0 | 0) ? (d[c[o >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                z = 1;
	                                break
	                            }
	                            z = (d[c[o >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        e = c[o >> 2] | 0;
	                        if (z) {
	                            c[o >> 2] = e + 1;
	                            continue
	                        }
	                        c[p >> 2] = e;
	                        while (1) {
	                            if (d[c[p >> 2] >> 0] | 0) {
	                                do if ((d[c[p >> 2] >> 0] | 0 | 0) == 32)A = 1; else {
	                                    if (9 <= (d[c[p >> 2] >> 0] | 0 | 0) ? (d[c[p >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                        A = 1;
	                                        break
	                                    }
	                                    A = (d[c[p >> 2] >> 0] | 0 | 0) == 13
	                                } while (0);
	                                B = A ^ 1
	                            } else B = 0;
	                            C = c[p >> 2] | 0;
	                            if (!B)break;
	                            c[p >> 2] = C + 1
	                        }
	                        if ((C | 0) == (c[o >> 2] | 0))break a;
	                        c[q >> 2] = ly(c[o >> 2] | 0, (c[p >> 2] | 0) - (c[o >> 2] | 0) | 0) | 0;
	                        if (!(rH(c[h >> 2] | 0, c[j >> 2] | 0, 0, c[n >> 2] | 0, c[q >> 2] | 0, s, r) | 0)) {
	                            c[t >> 2] = Cb[c[135744 >> 2] & 511](8) | 0;
	                            if (!(c[t >> 2] | 0)) {
	                                D = 32;
	                                break
	                            }
	                            c[(c[t >> 2] | 0) + 4 >> 2] = 0;
	                            c[c[t >> 2] >> 2] = 0;
	                            e = c[t >> 2] | 0;
	                            if (!(c[u >> 2] | 0))c[(c[l >> 2] | 0) + 92 >> 2] = e; else c[c[u >> 2] >> 2] = e;
	                            c[u >> 2] = c[t >> 2];
	                            c[v >> 2] = cG(c[h >> 2] | 0, 4, c[r >> 2] | 0, c[s >> 2] | 0) | 0;
	                            if (!(c[v >> 2] | 0))break;
	                            c[(c[t >> 2] | 0) + 4 >> 2] = c[v >> 2]
	                        }
	                        if (c[q >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                            c[q >> 2] = 0
	                        }
	                        c[o >> 2] = c[p >> 2];
	                        if (!(d[c[o >> 2] >> 0] | 0))break a
	                    }
	                    if ((D | 0) == 32) {
	                        tC(c[h >> 2] | 0, 165784, 0);
	                        c[g >> 2] = -1;
	                        y = c[g >> 2] | 0;
	                        i = f;
	                        return y | 0
	                    }
	                    if (c[q >> 2] | 0) {
	                        zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                        c[q >> 2] = 0
	                    }
	                    c[g >> 2] = -1;
	                    y = c[g >> 2] | 0;
	                    i = f;
	                    return y | 0
	                } while (0);
	                c[m >> 2] = c[(c[k >> 2] | 0) + 12 >> 2];
	                if ((((c[m >> 2] | 0) != 0 ? (c[(c[m >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 160992) | 0) != 0 : 0) ? (qy(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    q = c[l >> 2] | 0;
	                    kH(q, jE(c[h >> 2] | 0, c[m >> 2] | 0, 1) | 0) | 0;
	                    c[m >> 2] = c[(c[m >> 2] | 0) + 24 >> 2]
	                }
	                b:do if ((((c[m >> 2] | 0) != 0 ? (c[(c[m >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 161024) | 0) != 0 : 0) ? (qy(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    c[x >> 2] = 0;
	                    while (1) {
	                        if (!(c[m >> 2] | 0))break b;
	                        if (!(c[(c[m >> 2] | 0) + 36 >> 2] | 0))break b;
	                        if (!(qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 161024) | 0))break b;
	                        if (!(qy(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0))break b;
	                        c[w >> 2] = oE(c[h >> 2] | 0, c[j >> 2] | 0, c[m >> 2] | 0, 0) | 0;
	                        if (c[w >> 2] | 0) {
	                            q = c[w >> 2] | 0;
	                            if (!(c[x >> 2] | 0)) {
	                                c[(c[l >> 2] | 0) + 28 >> 2] = q;
	                                c[x >> 2] = c[w >> 2]
	                            } else {
	                                c[(c[x >> 2] | 0) + 4 >> 2] = q;
	                                c[x >> 2] = c[w >> 2]
	                            }
	                            c[(c[x >> 2] | 0) + 4 >> 2] = 0
	                        }
	                        c[m >> 2] = c[(c[m >> 2] | 0) + 24 >> 2]
	                    }
	                } while (0);
	                if (c[m >> 2] | 0)uE(c[h >> 2] | 0, 3033, 0, c[k >> 2] | 0, c[m >> 2] | 0, 0, 165832);
	                if ((c[n >> 2] | 0) == 0 ? (c[(c[l >> 2] | 0) + 28 >> 2] | 0) == 0 : 0)GE(c[h >> 2] | 0, 3007, 0, c[k >> 2] | 0, 165864, 0);
	                c[g >> 2] = 0;
	                y = c[g >> 2] | 0;
	                i = f;
	                return y | 0
	            }

	            function XF(a, b, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0;
	                j = i;
	                i = i + 48 | 0;
	                k = j + 40 | 0;
	                l = j + 36 | 0;
	                m = j + 32 | 0;
	                n = j + 28 | 0;
	                o = j + 24 | 0;
	                p = j + 20 | 0;
	                q = j + 16 | 0;
	                r = j + 12 | 0;
	                s = j + 8 | 0;
	                t = j + 4 | 0;
	                u = j;
	                c[l >> 2] = a;
	                c[m >> 2] = b;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                c[q >> 2] = h;
	                c[t >> 2] = 0;
	                c[u >> 2] = dE(c[m >> 2] | 0, 161824) | 0;
	                if (!(c[u >> 2] | 0)) {
	                    c[k >> 2] = c[p >> 2];
	                    v = c[k >> 2] | 0;
	                    i = j;
	                    return v | 0
	                }
	                c[r >> 2] = fE(c[l >> 2] | 0, c[u >> 2] | 0) | 0;
	                c[s >> 2] = c[r >> 2];
	                while (1) {
	                    do if ((d[c[s >> 2] >> 0] | 0 | 0) == 32)w = 1; else {
	                        if (9 <= (d[c[s >> 2] >> 0] | 0 | 0) ? (d[c[s >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            w = 1;
	                            break
	                        }
	                        w = (d[c[s >> 2] >> 0] | 0 | 0) == 13
	                    } while (0);
	                    x = c[s >> 2] | 0;
	                    if (!w)break;
	                    c[s >> 2] = x + 1
	                }
	                if (!(d[x >> 0] | 0)) {
	                    hE(c[l >> 2] | 0, 3037, 0, c[u >> 2] | 0, 0, c[q >> 2] | 0, c[r >> 2] | 0, 0, 0, 0);
	                    c[k >> 2] = c[p >> 2];
	                    v = c[k >> 2] | 0;
	                    i = j;
	                    return v | 0
	                }
	                while (1) {
	                    if ((d[c[s >> 2] >> 0] | 0 | 0) < 48)break;
	                    if ((d[c[s >> 2] >> 0] | 0 | 0) > 57)break;
	                    c[t >> 2] = ((c[t >> 2] | 0) * 10 | 0) + ((d[c[s >> 2] >> 0] | 0) - 48);
	                    c[s >> 2] = (c[s >> 2] | 0) + 1
	                }
	                while (1) {
	                    do if ((d[c[s >> 2] >> 0] | 0 | 0) == 32)y = 1; else {
	                        if (9 <= (d[c[s >> 2] >> 0] | 0 | 0) ? (d[c[s >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            y = 1;
	                            break
	                        }
	                        y = (d[c[s >> 2] >> 0] | 0 | 0) == 13
	                    } while (0);
	                    z = c[s >> 2] | 0;
	                    if (!y)break;
	                    c[s >> 2] = z + 1
	                }
	                do if ((d[z >> 0] | 0 | 0) == 0 ? (c[t >> 2] | 0) >= (c[n >> 2] | 0) : 0) {
	                    if ((c[o >> 2] | 0) != -1 ? (c[t >> 2] | 0) > (c[o >> 2] | 0) : 0)break;
	                    c[k >> 2] = c[t >> 2];
	                    v = c[k >> 2] | 0;
	                    i = j;
	                    return v | 0
	                } while (0);
	                hE(c[l >> 2] | 0, 3037, 0, c[u >> 2] | 0, 0, c[q >> 2] | 0, c[r >> 2] | 0, 0, 0, 0);
	                c[k >> 2] = c[p >> 2];
	                v = c[k >> 2] | 0;
	                i = j;
	                return v | 0
	            }

	            function YF(a, b, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0;
	                j = i;
	                i = i + 48 | 0;
	                k = j + 40 | 0;
	                l = j + 36 | 0;
	                m = j + 32 | 0;
	                n = j + 28 | 0;
	                o = j + 24 | 0;
	                p = j + 20 | 0;
	                q = j + 16 | 0;
	                r = j + 12 | 0;
	                s = j + 8 | 0;
	                t = j + 4 | 0;
	                u = j;
	                c[l >> 2] = a;
	                c[m >> 2] = b;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                c[q >> 2] = h;
	                c[t >> 2] = 0;
	                c[u >> 2] = dE(c[m >> 2] | 0, 161808) | 0;
	                if (!(c[u >> 2] | 0)) {
	                    c[k >> 2] = c[p >> 2];
	                    v = c[k >> 2] | 0;
	                    i = j;
	                    return v | 0
	                }
	                c[r >> 2] = fE(c[l >> 2] | 0, c[u >> 2] | 0) | 0;
	                if (qy(c[r >> 2] | 0, 163200) | 0)if ((c[o >> 2] | 0) != 1073741824) {
	                    hE(c[l >> 2] | 0, 3037, 0, c[u >> 2] | 0, 0, c[q >> 2] | 0, c[r >> 2] | 0, 0, 0, 0);
	                    c[k >> 2] = c[p >> 2];
	                    v = c[k >> 2] | 0;
	                    i = j;
	                    return v | 0
	                } else {
	                    c[k >> 2] = 1073741824;
	                    v = c[k >> 2] | 0;
	                    i = j;
	                    return v | 0
	                }
	                c[s >> 2] = c[r >> 2];
	                while (1) {
	                    do if ((d[c[s >> 2] >> 0] | 0 | 0) == 32)w = 1; else {
	                        if (9 <= (d[c[s >> 2] >> 0] | 0 | 0) ? (d[c[s >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            w = 1;
	                            break
	                        }
	                        w = (d[c[s >> 2] >> 0] | 0 | 0) == 13
	                    } while (0);
	                    x = c[s >> 2] | 0;
	                    if (!w)break;
	                    c[s >> 2] = x + 1
	                }
	                if (!(d[x >> 0] | 0)) {
	                    hE(c[l >> 2] | 0, 3037, 0, c[u >> 2] | 0, 0, c[q >> 2] | 0, c[r >> 2] | 0, 0, 0, 0);
	                    c[k >> 2] = c[p >> 2];
	                    v = c[k >> 2] | 0;
	                    i = j;
	                    return v | 0
	                }
	                while (1) {
	                    if ((d[c[s >> 2] >> 0] | 0 | 0) < 48)break;
	                    if ((d[c[s >> 2] >> 0] | 0 | 0) > 57)break;
	                    c[t >> 2] = ((c[t >> 2] | 0) * 10 | 0) + ((d[c[s >> 2] >> 0] | 0) - 48);
	                    c[s >> 2] = (c[s >> 2] | 0) + 1
	                }
	                while (1) {
	                    do if ((d[c[s >> 2] >> 0] | 0 | 0) == 32)y = 1; else {
	                        if (9 <= (d[c[s >> 2] >> 0] | 0 | 0) ? (d[c[s >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            y = 1;
	                            break
	                        }
	                        y = (d[c[s >> 2] >> 0] | 0 | 0) == 13
	                    } while (0);
	                    z = c[s >> 2] | 0;
	                    if (!y)break;
	                    c[s >> 2] = z + 1
	                }
	                do if ((d[z >> 0] | 0 | 0) == 0 ? (c[t >> 2] | 0) >= (c[n >> 2] | 0) : 0) {
	                    if ((c[o >> 2] | 0) != -1 ? (c[t >> 2] | 0) > (c[o >> 2] | 0) : 0)break;
	                    c[k >> 2] = c[t >> 2];
	                    v = c[k >> 2] | 0;
	                    i = j;
	                    return v | 0
	                } while (0);
	                hE(c[l >> 2] | 0, 3037, 0, c[u >> 2] | 0, 0, c[q >> 2] | 0, c[r >> 2] | 0, 0, 0, 0);
	                c[k >> 2] = c[p >> 2];
	                v = c[k >> 2] | 0;
	                i = j;
	                return v | 0
	            }

	            function ZF(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 20 | 0;
	                j = g + 16 | 0;
	                k = g + 8 | 0;
	                l = g + 4 | 0;
	                m = g;
	                c[j >> 2] = a;
	                c[g + 12 >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                if ((c[m >> 2] | 0) == 0 & (c[l >> 2] | 0) == 0) {
	                    c[h >> 2] = 0;
	                    n = c[h >> 2] | 0;
	                    i = g;
	                    return n | 0
	                }
	                if ((c[m >> 2] | 0) != 1073741824) {
	                    if ((c[m >> 2] | 0) < 1) {
	                        f = c[j >> 2] | 0;
	                        bG(f, 3044, 0, 0, dE(c[k >> 2] | 0, 161808) | 0, 163048);
	                        c[h >> 2] = 3044;
	                        n = c[h >> 2] | 0;
	                        i = g;
	                        return n | 0
	                    }
	                    if ((c[l >> 2] | 0) > (c[m >> 2] | 0)) {
	                        m = c[j >> 2] | 0;
	                        bG(m, 3043, 0, 0, dE(c[k >> 2] | 0, 161824) | 0, 163096);
	                        c[h >> 2] = 3043;
	                        n = c[h >> 2] | 0;
	                        i = g;
	                        return n | 0
	                    }
	                }
	                c[h >> 2] = 0;
	                n = c[h >> 2] | 0;
	                i = g;
	                return n | 0
	            }

	            function _F(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                h = i;
	                i = i + 32 | 0;
	                j = h + 24 | 0;
	                k = h + 20 | 0;
	                l = h + 16 | 0;
	                m = h + 12 | 0;
	                n = h + 8 | 0;
	                o = h + 4 | 0;
	                p = h;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                c[p >> 2] = fE(c[j >> 2] | 0, c[m >> 2] | 0) | 0;
	                g = rH(c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0, c[p >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0) | 0;
	                i = h;
	                return g | 0
	            }

	            function $F(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 28 | 0;
	                j = g + 24 | 0;
	                k = g + 16 | 0;
	                l = g + 12 | 0;
	                m = g + 8 | 0;
	                n = g + 4 | 0;
	                o = g;
	                c[j >> 2] = a;
	                c[g + 20 >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                if (qy(c[(c[j >> 2] | 0) + 112 >> 2] | 0, c[m >> 2] | 0) | 0) {
	                    c[h >> 2] = 0;
	                    p = c[h >> 2] | 0;
	                    i = g;
	                    return p | 0
	                }
	                if (qy(c[38526] | 0, c[m >> 2] | 0) | 0) {
	                    c[h >> 2] = 0;
	                    p = c[h >> 2] | 0;
	                    i = g;
	                    return p | 0
	                }
	                a:do if (c[(c[(c[(c[j >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] | 0) + 24 >> 2] | 0) {
	                    c[n >> 2] = c[(c[(c[(c[j >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] | 0) + 24 >> 2];
	                    while (1) {
	                        if (!((c[(c[n >> 2] | 0) + 4 >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 4 >> 2] | 0) != 1 : 0))q = 9;
	                        if ((q | 0) == 9 ? (q = 0, (qy(c[m >> 2] | 0, c[(c[n >> 2] | 0) + 8 >> 2] | 0) | 0) != 0) : 0)break;
	                        c[n >> 2] = c[c[n >> 2] >> 2];
	                        if (!(c[n >> 2] | 0))break a
	                    }
	                    c[h >> 2] = 0;
	                    p = c[h >> 2] | 0;
	                    i = g;
	                    return p | 0
	                } while (0);
	                if (c[l >> 2] | 0)r = c[l >> 2] | 0; else r = c[k >> 2] | 0;
	                c[o >> 2] = r;
	                r = c[j >> 2] | 0;
	                j = c[o >> 2] | 0;
	                if (!(c[m >> 2] | 0))AB(r, 3004, j, 0, 162704, 0, 0); else AB(r, 3004, j, 0, 162824, c[m >> 2] | 0, 0);
	                c[h >> 2] = 3004;
	                p = c[h >> 2] | 0;
	                i = g;
	                return p | 0
	            }

	            function aG(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                h = i;
	                i = i + 32 | 0;
	                j = h + 24 | 0;
	                k = h + 20 | 0;
	                l = h + 16 | 0;
	                m = h + 12 | 0;
	                n = h + 8 | 0;
	                o = h + 4 | 0;
	                p = h;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                c[p >> 2] = 0;
	                GC(p, 0, c[l >> 2] | 0, c[(c[m >> 2] | 0) + 20 >> 2] | 0) | 0;
	                EF(c[j >> 2] | 0, c[m >> 2] | 0, c[k >> 2] | 0, 0, 0, 0, 164296, c[p >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, 0, 0);
	                if (!(c[p >> 2] | 0)) {
	                    i = h;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                c[p >> 2] = 0;
	                i = h;
	                return
	            }

	            function bG(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                h = i;
	                i = i + 32 | 0;
	                j = h + 24 | 0;
	                k = h + 20 | 0;
	                l = h + 16 | 0;
	                m = h + 12 | 0;
	                n = h + 8 | 0;
	                o = h + 4 | 0;
	                p = h;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                c[p >> 2] = 0;
	                do if (c[l >> 2] | 0) {
	                    g = c[l >> 2] | 0;
	                    if (!(c[c[l >> 2] >> 2] | 0)) {
	                        GC(g, 0, c[m >> 2] | 0, c[(c[n >> 2] | 0) + 20 >> 2] | 0) | 0;
	                        c[p >> 2] = c[c[l >> 2] >> 2];
	                        break
	                    } else {
	                        c[p >> 2] = c[g >> 2];
	                        break
	                    }
	                } else GC(p, 0, c[m >> 2] | 0, c[(c[n >> 2] | 0) + 20 >> 2] | 0) | 0; while (0);
	                m = c[j >> 2] | 0;
	                if (!(c[n >> 2] | 0))EF(m, 0, c[k >> 2] | 0, 0, 0, 0, 163160, c[p >> 2] | 0, 163192, c[o >> 2] | 0, 0, 0); else EF(m, c[n >> 2] | 0, c[k >> 2] | 0, 0, 0, 0, 163160, c[p >> 2] | 0, c[(c[n >> 2] | 0) + 8 >> 2] | 0, c[o >> 2] | 0, 0, 0);
	                if (!((c[l >> 2] | 0) == 0 & (c[p >> 2] | 0) != 0)) {
	                    i = h;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                c[p >> 2] = 0;
	                i = h;
	                return
	            }

	            function cG(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = Cb[c[135744 >> 2] & 511](24) | 0;
	                if (!(c[m >> 2] | 0)) {
	                    tC(c[h >> 2] | 0, 162672, 0);
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                } else {
	                    c[(c[m >> 2] | 0) + 20 >> 2] = 0;
	                    c[c[m >> 2] >> 2] = 2e3;
	                    c[(c[m >> 2] | 0) + 12 >> 2] = c[k >> 2];
	                    c[(c[m >> 2] | 0) + 16 >> 2] = c[l >> 2];
	                    c[(c[m >> 2] | 0) + 4 >> 2] = 0;
	                    c[(c[m >> 2] | 0) + 8 >> 2] = c[j >> 2];
	                    dG((c[(c[(c[h >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] | 0) + 48 | 0, 10, c[m >> 2] | 0) | 0;
	                    c[g >> 2] = c[m >> 2];
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                return 0
	            }

	            function dG(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if ((c[c[g >> 2] >> 2] | 0) == 0 ? (d = JB() | 0, c[c[g >> 2] >> 2] = d, (c[c[g >> 2] >> 2] | 0) == 0) : 0) {
	                    c[f >> 2] = -1;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                pG(c[c[g >> 2] >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                c[f >> 2] = 0;
	                k = c[f >> 2] | 0;
	                i = e;
	                return k | 0
	            }

	            function eG(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 24 | 0;
	                j = g + 20 | 0;
	                k = g + 16 | 0;
	                l = g + 12 | 0;
	                m = g + 8 | 0;
	                n = g + 4 | 0;
	                o = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = 0;
	                if ((c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0) {
	                    c[h >> 2] = 0;
	                    p = c[h >> 2] | 0;
	                    i = g;
	                    return p | 0
	                }
	                c[o >> 2] = Cb[c[135744 >> 2] & 511](104) | 0;
	                if (!(c[o >> 2] | 0)) {
	                    tC(c[j >> 2] | 0, 165528, 0);
	                    c[h >> 2] = 0;
	                    p = c[h >> 2] | 0;
	                    i = g;
	                    return p | 0
	                }
	                f = (c[o >> 2] | 0) + 0 | 0;
	                e = f + 104 | 0;
	                do {
	                    c[f >> 2] = 0;
	                    f = f + 4 | 0
	                } while ((f | 0) < (e | 0));
	                c[c[o >> 2] >> 2] = 14;
	                c[(c[o >> 2] | 0) + 8 >> 2] = c[k >> 2];
	                c[(c[o >> 2] | 0) + 52 >> 2] = c[l >> 2];
	                c[(c[o >> 2] | 0) + 36 >> 2] = c[m >> 2];
	                m = c[(c[(c[j >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] | 0;
	                if (c[n >> 2] | 0)dG(m + 44 | 0, 5, c[o >> 2] | 0) | 0; else dG(m + 48 | 0, 10, c[o >> 2] | 0) | 0;
	                dG((c[(c[j >> 2] | 0) + 28 >> 2] | 0) + 20 | 0, 10, c[o >> 2] | 0) | 0;
	                c[h >> 2] = c[o >> 2];
	                p = c[h >> 2] | 0;
	                i = g;
	                return p | 0
	            }

	            function fG(a, b, d, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                j = i;
	                i = i + 48 | 0;
	                k = j + 32 | 0;
	                l = j + 28 | 0;
	                m = j + 24 | 0;
	                n = j + 20 | 0;
	                o = j + 16 | 0;
	                p = j + 12 | 0;
	                q = j + 8 | 0;
	                r = j + 4 | 0;
	                s = j;
	                c[l >> 2] = a;
	                c[m >> 2] = b;
	                c[n >> 2] = d;
	                c[o >> 2] = e;
	                c[p >> 2] = f;
	                c[q >> 2] = g;
	                c[r >> 2] = h;
	                c[s >> 2] = dE(c[o >> 2] | 0, c[p >> 2] | 0) | 0;
	                if (!(c[s >> 2] | 0)) {
	                    c[c[r >> 2] >> 2] = 0;
	                    c[c[q >> 2] >> 2] = 0;
	                    c[k >> 2] = 0;
	                    t = c[k >> 2] | 0;
	                    i = j;
	                    return t | 0
	                } else {
	                    c[k >> 2] = _F(c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0, c[s >> 2] | 0, c[q >> 2] | 0, c[r >> 2] | 0) | 0;
	                    t = c[k >> 2] | 0;
	                    i = j;
	                    return t | 0
	                }
	                return 0
	            }

	            function gG(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = RC(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                if (!(c[m >> 2] | 0)) {
	                    c[g >> 2] = c[l >> 2];
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                do if (!(qy(c[m >> 2] | 0, 165504) | 0)) {
	                    if (qy(c[m >> 2] | 0, 165512) | 0) {
	                        c[l >> 2] = 0;
	                        break
	                    }
	                    if (qy(c[m >> 2] | 0, 161736) | 0) {
	                        c[l >> 2] = 1;
	                        break
	                    }
	                    if (qy(c[m >> 2] | 0, 165520) | 0) {
	                        c[l >> 2] = 0;
	                        break
	                    } else {
	                        e = c[h >> 2] | 0;
	                        d = dE(c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                        b = IH(15) | 0;
	                        hE(e, 1714, 0, d, b, 0, c[m >> 2] | 0, 0, 0, 0);
	                        break
	                    }
	                } else c[l >> 2] = 1; while (0);
	                c[g >> 2] = c[l >> 2];
	                n = c[g >> 2] | 0;
	                i = f;
	                return n | 0
	            }

	            function hG(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                g = i;
	                i = i + 48 | 0;
	                h = g + 44 | 0;
	                j = g + 40 | 0;
	                k = g + 36 | 0;
	                l = g + 32 | 0;
	                m = g + 28 | 0;
	                n = g + 24 | 0;
	                o = g + 20 | 0;
	                p = g + 16 | 0;
	                q = g + 12 | 0;
	                r = g + 8 | 0;
	                s = g + 4 | 0;
	                t = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = 0;
	                c[p >> 2] = 0;
	                c[r >> 2] = 0;
	                c[s >> 2] = 0;
	                c[t >> 2] = 0;
	                c[q >> 2] = c[(c[l >> 2] | 0) + 44 >> 2];
	                while (1) {
	                    if (!(c[q >> 2] | 0))break;
	                    f = c[q >> 2] | 0;
	                    do if (!(c[(c[q >> 2] | 0) + 36 >> 2] | 0)) {
	                        if ((qy(c[f + 8 >> 2] | 0, 161384) | 0) == 0 ? (qy(c[(c[q >> 2] | 0) + 8 >> 2] | 0, 161352) | 0) == 0 : 0) {
	                            if ((c[m >> 2] | 0) == 24 ? (qy(c[(c[q >> 2] | 0) + 8 >> 2] | 0, 160144) | 0) != 0 : 0)break;
	                            GF(c[j >> 2] | 0, 3035, 0, c[q >> 2] | 0)
	                        }
	                    } else if (qy(c[(c[f + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)GF(c[j >> 2] | 0, 3035, 0, c[q >> 2] | 0); while (0);
	                    c[q >> 2] = c[(c[q >> 2] | 0) + 24 >> 2]
	                }
	                c[q >> 2] = dE(c[l >> 2] | 0, 161352) | 0;
	                f = c[j >> 2] | 0;
	                if (!(c[q >> 2] | 0)) {
	                    MF(f, 3036, 0, c[l >> 2] | 0, 161352, 0);
	                    c[h >> 2] = 0;
	                    u = c[h >> 2] | 0;
	                    i = g;
	                    return u | 0
	                }
	                e = c[q >> 2] | 0;
	                if (eE(f, 0, e, IH(22) | 0, r) | 0) {
	                    c[h >> 2] = 0;
	                    u = c[h >> 2] | 0;
	                    i = g;
	                    return u | 0
	                }
	                c[o >> 2] = sH(c[j >> 2] | 0, c[k >> 2] | 0, c[r >> 2] | 0, c[n >> 2] | 0, c[m >> 2] | 0, c[l >> 2] | 0) | 0;
	                if (!(c[o >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    u = c[h >> 2] | 0;
	                    i = g;
	                    return u | 0
	                }
	                cE(c[j >> 2] | 0, c[l >> 2] | 0, 161384) | 0;
	                do if ((c[m >> 2] | 0) == 24) {
	                    c[q >> 2] = dE(c[l >> 2] | 0, 160144) | 0;
	                    n = c[j >> 2] | 0;
	                    if (!(c[q >> 2] | 0)) {
	                        MF(n, 3036, 0, c[l >> 2] | 0, 160144, 0);
	                        break
	                    }
	                    r = cG(n, 23, 0, 0) | 0;
	                    c[(c[o >> 2] | 0) + 36 >> 2] = r;
	                    if (c[(c[o >> 2] | 0) + 36 >> 2] | 0) {
	                        _F(c[j >> 2] | 0, c[k >> 2] | 0, 0, c[q >> 2] | 0, (c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 16 | 0, (c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 12 | 0) | 0;
	                        $F(c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[q >> 2] | 0, c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) | 0;
	                        break
	                    }
	                    c[h >> 2] = 0;
	                    u = c[h >> 2] | 0;
	                    i = g;
	                    return u | 0
	                } while (0);
	                c[p >> 2] = c[(c[l >> 2] | 0) + 12 >> 2];
	                if ((((c[p >> 2] | 0) != 0 ? (c[(c[p >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[p >> 2] | 0) + 8 >> 2] | 0, 160992) | 0) != 0 : 0) ? (qy(c[(c[(c[p >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    q = jE(c[j >> 2] | 0, c[p >> 2] | 0, 1) | 0;
	                    c[(c[o >> 2] | 0) + 4 >> 2] = q;
	                    c[p >> 2] = c[(c[p >> 2] | 0) + 24 >> 2]
	                }
	                if (!(c[p >> 2] | 0))uE(c[j >> 2] | 0, 3034, 0, c[l >> 2] | 0, c[p >> 2] | 0, 164808, 164840);
	                a:do if ((((c[p >> 2] | 0) != 0 ? (c[(c[p >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[p >> 2] | 0) + 8 >> 2] | 0, 164880) | 0) != 0 : 0) ? (qy(c[(c[(c[p >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    q = tH(c[j >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0, 0) | 0;
	                    c[(c[o >> 2] | 0) + 24 >> 2] = q;
	                    c[p >> 2] = c[(c[p >> 2] | 0) + 24 >> 2];
	                    if ((((c[p >> 2] | 0) != 0 ? (c[(c[p >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[p >> 2] | 0) + 8 >> 2] | 0, 164896) | 0) != 0 : 0) ? (qy(c[(c[(c[p >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0)while (1) {
	                        c[s >> 2] = tH(c[j >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0, 1) | 0;
	                        if (c[s >> 2] | 0) {
	                            c[(c[s >> 2] | 0) + 8 >> 2] = c[(c[o >> 2] | 0) + 32 >> 2];
	                            q = (c[o >> 2] | 0) + 32 | 0;
	                            c[q >> 2] = (c[q >> 2] | 0) + 1;
	                            q = c[s >> 2] | 0;
	                            if (c[t >> 2] | 0)c[c[t >> 2] >> 2] = q; else c[(c[o >> 2] | 0) + 28 >> 2] = q;
	                            c[t >> 2] = c[s >> 2]
	                        }
	                        c[p >> 2] = c[(c[p >> 2] | 0) + 24 >> 2];
	                        if (!(c[p >> 2] | 0))break a;
	                        if (!(c[(c[p >> 2] | 0) + 36 >> 2] | 0))break a;
	                        if (!(qy(c[(c[p >> 2] | 0) + 8 >> 2] | 0, 164896) | 0))break a;
	                        if (!(qy(c[(c[(c[p >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0))break a
	                    }
	                    uE(c[j >> 2] | 0, 3033, 0, c[l >> 2] | 0, c[p >> 2] | 0, 0, 164840)
	                } while (0);
	                if (c[p >> 2] | 0)uE(c[j >> 2] | 0, 3033, 0, c[l >> 2] | 0, c[p >> 2] | 0, 0, 164840);
	                c[h >> 2] = c[o >> 2];
	                u = c[h >> 2] | 0;
	                i = g;
	                return u | 0
	            }

	            function iG(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                h = i;
	                i = i + 32 | 0;
	                j = h + 28 | 0;
	                k = h + 24 | 0;
	                l = h + 20 | 0;
	                m = h + 16 | 0;
	                n = h + 12 | 0;
	                o = h + 8 | 0;
	                p = h + 4 | 0;
	                q = h;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                c[q >> 2] = 0;
	                if ((c[k >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0) {
	                    c[j >> 2] = 0;
	                    r = c[j >> 2] | 0;
	                    i = h;
	                    return r | 0
	                }
	                c[q >> 2] = Cb[c[135744 >> 2] & 511](76) | 0;
	                if (!(c[q >> 2] | 0)) {
	                    tC(c[k >> 2] | 0, 164272, 0);
	                    c[j >> 2] = 0;
	                    r = c[j >> 2] | 0;
	                    i = h;
	                    return r | 0
	                }
	                l = (c[q >> 2] | 0) + 0 | 0;
	                g = l + 76 | 0;
	                do {
	                    c[l >> 2] = 0;
	                    l = l + 4 | 0
	                } while ((l | 0) < (g | 0));
	                c[c[q >> 2] >> 2] = 15;
	                c[(c[q >> 2] | 0) + 52 >> 2] = c[o >> 2];
	                c[(c[q >> 2] | 0) + 8 >> 2] = c[m >> 2];
	                c[(c[q >> 2] | 0) + 56 >> 2] = c[n >> 2];
	                n = c[(c[(c[k >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] | 0;
	                if (c[p >> 2] | 0)dG(n + 44 | 0, 5, c[q >> 2] | 0) | 0; else dG(n + 48 | 0, 10, c[q >> 2] | 0) | 0;
	                dG((c[(c[k >> 2] | 0) + 28 >> 2] | 0) + 20 | 0, 10, c[q >> 2] | 0) | 0;
	                c[j >> 2] = c[q >> 2];
	                r = c[j >> 2] | 0;
	                i = h;
	                return r | 0
	            }

	            function jG(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 24 | 0;
	                j = g + 20 | 0;
	                k = g + 12 | 0;
	                l = g + 8 | 0;
	                m = g + 4 | 0;
	                n = g;
	                c[j >> 2] = a;
	                c[g + 16 >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                c[n >> 2] = 0;
	                if ((c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0) {
	                    c[h >> 2] = 0;
	                    o = c[h >> 2] | 0;
	                    i = g;
	                    return o | 0
	                }
	                c[n >> 2] = Cb[c[135744 >> 2] & 511](60) | 0;
	                if (!(c[n >> 2] | 0)) {
	                    tC(c[j >> 2] | 0, 164360, 0);
	                    c[h >> 2] = 0;
	                    o = c[h >> 2] | 0;
	                    i = g;
	                    return o | 0
	                }
	                f = (c[n >> 2] | 0) + 0 | 0;
	                e = f + 60 | 0;
	                do {
	                    c[f >> 2] = 0;
	                    f = f + 4 | 0
	                } while ((f | 0) < (e | 0));
	                c[c[n >> 2] >> 2] = 16;
	                c[(c[n >> 2] | 0) + 8 >> 2] = c[k >> 2];
	                c[(c[n >> 2] | 0) + 52 >> 2] = c[l >> 2];
	                c[(c[n >> 2] | 0) + 32 >> 2] = c[m >> 2];
	                m = (c[n >> 2] | 0) + 36 | 0;
	                c[m >> 2] = c[m >> 2] | 2;
	                do if (c[(c[j >> 2] | 0) + 100 >> 2] | 0) {
	                    m = GG(c[j >> 2] | 0, c[(c[j >> 2] | 0) + 116 >> 2] | 0, c[n >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0;
	                    c[(c[j >> 2] | 0) + 120 >> 2] = m;
	                    if (c[(c[j >> 2] | 0) + 120 >> 2] | 0) {
	                        c[(c[j >> 2] | 0) + 124 >> 2] = 0;
	                        break
	                    }
	                    zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                    c[h >> 2] = 0;
	                    o = c[h >> 2] | 0;
	                    i = g;
	                    return o | 0
	                } while (0);
	                dG((c[(c[(c[j >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] | 0) + 44 | 0, 5, c[n >> 2] | 0) | 0;
	                dG((c[(c[j >> 2] | 0) + 28 >> 2] | 0) + 20 | 0, 10, c[n >> 2] | 0) | 0;
	                c[h >> 2] = c[n >> 2];
	                o = c[h >> 2] | 0;
	                i = g;
	                return o | 0
	            }

	            function kG(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 24 | 0;
	                j = g + 20 | 0;
	                k = g + 16 | 0;
	                l = g + 12 | 0;
	                m = g + 8 | 0;
	                n = g + 4 | 0;
	                o = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = 0;
	                if ((c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0) {
	                    c[h >> 2] = 0;
	                    p = c[h >> 2] | 0;
	                    i = g;
	                    return p | 0
	                }
	                c[o >> 2] = Cb[c[135744 >> 2] & 511](32) | 0;
	                if (!(c[o >> 2] | 0)) {
	                    tC(c[j >> 2] | 0, 163256, 0);
	                    c[h >> 2] = 0;
	                    p = c[h >> 2] | 0;
	                    i = g;
	                    return p | 0
	                }
	                k = c[o >> 2] | 0;
	                c[k + 0 >> 2] = 0;
	                c[k + 4 >> 2] = 0;
	                c[k + 8 >> 2] = 0;
	                c[k + 12 >> 2] = 0;
	                c[k + 16 >> 2] = 0;
	                c[k + 20 >> 2] = 0;
	                c[k + 24 >> 2] = 0;
	                c[k + 28 >> 2] = 0;
	                c[(c[o >> 2] | 0) + 16 >> 2] = c[l >> 2];
	                c[c[o >> 2] >> 2] = 17;
	                c[(c[o >> 2] | 0) + 24 >> 2] = c[n >> 2];
	                c[(c[o >> 2] | 0) + 20 >> 2] = c[m >> 2];
	                do if (c[(c[j >> 2] | 0) + 100 >> 2] | 0) {
	                    n = GG(c[j >> 2] | 0, c[(c[j >> 2] | 0) + 116 >> 2] | 0, c[o >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0) | 0;
	                    c[(c[j >> 2] | 0) + 120 >> 2] = n;
	                    if (c[(c[j >> 2] | 0) + 120 >> 2] | 0) {
	                        c[(c[j >> 2] | 0) + 124 >> 2] = 0;
	                        break
	                    }
	                    zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                    c[h >> 2] = 0;
	                    p = c[h >> 2] | 0;
	                    i = g;
	                    return p | 0
	                } while (0);
	                dG((c[(c[(c[j >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] | 0) + 44 | 0, 5, c[o >> 2] | 0) | 0;
	                dG((c[(c[j >> 2] | 0) + 28 >> 2] | 0) + 20 | 0, 10, c[o >> 2] | 0) | 0;
	                c[h >> 2] = c[o >> 2];
	                p = c[h >> 2] | 0;
	                i = g;
	                return p | 0
	            }

	            function lG(a, b, d, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                j = i;
	                i = i + 32 | 0;
	                k = j + 24 | 0;
	                l = j + 20 | 0;
	                m = j + 16 | 0;
	                n = j + 12 | 0;
	                o = j + 8 | 0;
	                p = j + 4 | 0;
	                q = j;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                c[q >> 2] = h;
	                h = c[k >> 2] | 0;
	                if (c[m >> 2] | 0) {
	                    PC(h, c[m >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0);
	                    i = j;
	                    return
	                } else {
	                    PC(h, c[l >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0);
	                    i = j;
	                    return
	                }
	            }

	            function mG(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 24 | 0;
	                j = g + 20 | 0;
	                k = g + 16 | 0;
	                l = g + 12 | 0;
	                m = g + 8 | 0;
	                n = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[g + 4 >> 2] = f;
	                c[n >> 2] = 0;
	                if ((c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0) {
	                    c[h >> 2] = 0;
	                    o = c[h >> 2] | 0;
	                    i = g;
	                    return o | 0
	                }
	                c[n >> 2] = Cb[c[135744 >> 2] & 511](20) | 0;
	                if (!(c[n >> 2] | 0)) {
	                    tC(c[j >> 2] | 0, 161632, 0);
	                    c[h >> 2] = 0;
	                    o = c[h >> 2] | 0;
	                    i = g;
	                    return o | 0
	                } else {
	                    k = c[n >> 2] | 0;
	                    c[k + 0 >> 2] = 0;
	                    c[k + 4 >> 2] = 0;
	                    c[k + 8 >> 2] = 0;
	                    c[k + 12 >> 2] = 0;
	                    c[k + 16 >> 2] = 0;
	                    c[c[n >> 2] >> 2] = 18;
	                    c[(c[n >> 2] | 0) + 4 >> 2] = c[l >> 2];
	                    c[(c[n >> 2] | 0) + 16 >> 2] = c[m >> 2];
	                    dG((c[(c[(c[j >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] | 0) + 44 | 0, 5, c[n >> 2] | 0) | 0;
	                    c[h >> 2] = c[n >> 2];
	                    o = c[h >> 2] | 0;
	                    i = g;
	                    return o | 0
	                }
	                return 0
	            }

	            function nG(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 0;
	                if ((c[h >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                do if (c[g >> 2] | 0) {
	                    if ((qy(c[j >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] | 0) | 0) != 0 ? (c[k >> 2] = Rj(c[(c[g >> 2] | 0) + 56 >> 2] | 0, c[h >> 2] | 0) | 0, (c[k >> 2] | 0) != 0) : 0)break;
	                    if (($j(c[(c[g >> 2] | 0) + 48 >> 2] | 0) | 0) > 1) {
	                        d = c[(c[g >> 2] | 0) + 48 >> 2] | 0;
	                        if (!(c[j >> 2] | 0))c[l >> 2] = Rj(d, 145792) | 0; else c[l >> 2] = Rj(d, c[j >> 2] | 0) | 0;
	                        if (c[l >> 2] | 0)c[k >> 2] = Rj(c[(c[(c[l >> 2] | 0) + 52 >> 2] | 0) + 56 >> 2] | 0, c[h >> 2] | 0) | 0
	                    }
	                } while (0);
	                c[f >> 2] = c[k >> 2];
	                m = c[f >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function oG(a, b, d, e, f, g, h, j) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                var k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                k = i;
	                i = i + 48 | 0;
	                l = k + 36 | 0;
	                m = k + 32 | 0;
	                n = k + 28 | 0;
	                o = k + 24 | 0;
	                p = k + 20 | 0;
	                q = k + 16 | 0;
	                r = k + 12 | 0;
	                s = k + 8 | 0;
	                t = k + 4 | 0;
	                u = k;
	                c[l >> 2] = a;
	                c[m >> 2] = b;
	                c[n >> 2] = d;
	                c[o >> 2] = e;
	                c[p >> 2] = f;
	                c[q >> 2] = g;
	                c[r >> 2] = h;
	                c[s >> 2] = j;
	                c[t >> 2] = 0;
	                c[u >> 2] = 0;
	                GC(t, 0, c[n >> 2] | 0, c[o >> 2] | 0) | 0;
	                c[u >> 2] = my(147824) | 0;
	                c[u >> 2] = By(c[u >> 2] | 0, c[p >> 2] | 0) | 0;
	                c[u >> 2] = By(c[u >> 2] | 0, 142704) | 0;
	                if ((c[o >> 2] | 0) == 0 & (c[n >> 2] | 0) != 0)c[o >> 2] = FC(c[n >> 2] | 0) | 0;
	                EF(c[l >> 2] | 0, c[o >> 2] | 0, c[m >> 2] | 0, 0, 0, 0, c[u >> 2] | 0, c[t >> 2] | 0, c[q >> 2] | 0, c[r >> 2] | 0, c[s >> 2] | 0, 0);
	                if (c[t >> 2] | 0) {
	                    zb[c[135736 >> 2] & 511](c[t >> 2] | 0);
	                    c[t >> 2] = 0
	                }
	                if (!(c[u >> 2] | 0)) {
	                    i = k;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[u >> 2] | 0);
	                c[u >> 2] = 0;
	                i = k;
	                return
	            }

	            function pG(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                do if (c[c[g >> 2] >> 2] | 0) {
	                    if ((c[(c[g >> 2] | 0) + 8 >> 2] | 0) <= (c[(c[g >> 2] | 0) + 4 >> 2] | 0) ? (d = (c[g >> 2] | 0) + 8 | 0, c[d >> 2] = c[d >> 2] << 1, d = Hb[c[135760 >> 2] & 511](c[c[g >> 2] >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] << 2) | 0, c[c[g >> 2] >> 2] = d, (c[c[g >> 2] >> 2] | 0) == 0) : 0) {
	                        tC(0, 142376, 0);
	                        c[(c[g >> 2] | 0) + 8 >> 2] = 0;
	                        c[f >> 2] = -1;
	                        k = c[f >> 2] | 0;
	                        i = e;
	                        return k | 0
	                    }
	                } else {
	                    if ((c[h >> 2] | 0) <= 0)c[h >> 2] = 1;
	                    d = Cb[c[135744 >> 2] & 511](c[h >> 2] << 2) | 0;
	                    c[c[g >> 2] >> 2] = d;
	                    if (c[c[g >> 2] >> 2] | 0) {
	                        c[(c[g >> 2] | 0) + 8 >> 2] = c[h >> 2];
	                        break
	                    }
	                    tC(0, 142344, 0);
	                    c[f >> 2] = -1;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                } while (0);
	                h = c[j >> 2] | 0;
	                j = (c[g >> 2] | 0) + 4 | 0;
	                d = c[j >> 2] | 0;
	                c[j >> 2] = d + 1;
	                c[(c[c[g >> 2] >> 2] | 0) + (d << 2) >> 2] = h;
	                c[f >> 2] = 0;
	                k = c[f >> 2] | 0;
	                i = e;
	                return k | 0
	            }

	            function qG(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = 0;
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                c[m >> 2] = Cb[c[135744 >> 2] & 511](44) | 0;
	                if (!(c[m >> 2] | 0)) {
	                    tC(c[h >> 2] | 0, 153064, 0);
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                } else {
	                    j = (c[m >> 2] | 0) + 0 | 0;
	                    e = j + 44 | 0;
	                    do {
	                        c[j >> 2] = 0;
	                        j = j + 4 | 0
	                    } while ((j | 0) < (e | 0));
	                    c[c[m >> 2] >> 2] = c[k >> 2];
	                    c[(c[m >> 2] | 0) + 12 >> 2] = c[l >> 2];
	                    dG((c[(c[(c[h >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] | 0) + 48 | 0, 10, c[m >> 2] | 0) | 0;
	                    c[g >> 2] = c[m >> 2];
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                return 0
	            }

	            function rG(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 20 | 0;
	                h = e + 16 | 0;
	                j = e + 12 | 0;
	                k = e + 8 | 0;
	                l = e + 4 | 0;
	                m = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if ((c[j >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) {
	                    c[f >> 2] = -1;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                c[(c[h >> 2] | 0) + 28 >> 2] = c[(c[j >> 2] | 0) + 28 >> 2];
	                c[k >> 2] = c[(c[j >> 2] | 0) + 32 >> 2];
	                c[m >> 2] = 0;
	                while (1) {
	                    if (!(c[k >> 2] | 0))break;
	                    c[l >> 2] = uH(c[g >> 2] | 0) | 0;
	                    if (!(c[l >> 2] | 0)) {
	                        o = 6;
	                        break
	                    }
	                    c[(c[l >> 2] | 0) + 4 >> 2] = c[(c[k >> 2] | 0) + 4 >> 2];
	                    d = c[l >> 2] | 0;
	                    if (!(c[m >> 2] | 0))c[(c[h >> 2] | 0) + 32 >> 2] = d; else c[c[m >> 2] >> 2] = d;
	                    c[m >> 2] = c[l >> 2];
	                    c[k >> 2] = c[c[k >> 2] >> 2]
	                }
	                if ((o | 0) == 6) {
	                    c[f >> 2] = -1;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                if (c[(c[h >> 2] | 0) + 36 >> 2] | 0)nB(c[(c[h >> 2] | 0) + 36 >> 2] | 0);
	                do if (c[(c[j >> 2] | 0) + 36 >> 2] | 0) {
	                    o = uH(c[g >> 2] | 0) | 0;
	                    c[(c[h >> 2] | 0) + 36 >> 2] = o;
	                    if (c[(c[h >> 2] | 0) + 36 >> 2] | 0) {
	                        c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] = c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2];
	                        break
	                    }
	                    c[f >> 2] = -1;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                } else c[(c[h >> 2] | 0) + 36 >> 2] = 0; while (0);
	                c[f >> 2] = 0;
	                n = c[f >> 2] | 0;
	                i = e;
	                return n | 0
	            }

	            function sG(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 40 | 0;
	                g = e + 36 | 0;
	                h = e + 32 | 0;
	                j = e + 28 | 0;
	                k = e + 24 | 0;
	                l = e + 20 | 0;
	                m = e + 16 | 0;
	                n = e + 12 | 0;
	                o = e + 8 | 0;
	                p = e + 4 | 0;
	                q = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                do if (((c[(c[h >> 2] | 0) + 28 >> 2] | 0) == (c[(c[j >> 2] | 0) + 28 >> 2] | 0) ? ((c[(c[h >> 2] | 0) + 32 >> 2] | 0) == 0 | 0) == ((c[(c[j >> 2] | 0) + 32 >> 2] | 0) == 0 | 0) : 0) ? ((c[(c[h >> 2] | 0) + 36 >> 2] | 0) == 0 | 0) == ((c[(c[j >> 2] | 0) + 36 >> 2] | 0) == 0 | 0) : 0) {
	                    if ((c[(c[h >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) != (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) : 0)break;
	                    if (!(c[(c[h >> 2] | 0) + 32 >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    }
	                    c[o >> 2] = 0;
	                    c[k >> 2] = c[(c[h >> 2] | 0) + 32 >> 2];
	                    while (1) {
	                        if (!(c[k >> 2] | 0))break;
	                        c[o >> 2] = 0;
	                        c[l >> 2] = c[(c[j >> 2] | 0) + 32 >> 2];
	                        while (1) {
	                            if (!(c[l >> 2] | 0))break;
	                            if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == (c[(c[l >> 2] | 0) + 4 >> 2] | 0)) {
	                                s = 12;
	                                break
	                            }
	                            c[l >> 2] = c[c[l >> 2] >> 2]
	                        }
	                        if ((s | 0) == 12) {
	                            s = 0;
	                            c[o >> 2] = 1
	                        }
	                        if (!(c[o >> 2] | 0))break;
	                        c[k >> 2] = c[c[k >> 2] >> 2]
	                    }
	                    if (c[o >> 2] | 0) {
	                        c[f >> 2] = 0;
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    }
	                } while (0);
	                if ((c[(c[h >> 2] | 0) + 28 >> 2] | 0) != (c[(c[j >> 2] | 0) + 28 >> 2] | 0) ? (c[(c[h >> 2] | 0) + 28 >> 2] | 0) != 0 : 0)if ((rG(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0) == -1) {
	                    c[f >> 2] = -1;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                } else {
	                    c[f >> 2] = 0;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                }
	                if (!((c[(c[h >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 32 >> 2] | 0) != 0 : 0))s = 26;
	                do if ((s | 0) == 26) {
	                    if ((c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 32 >> 2] | 0) != 0 : 0)break;
	                    if ((c[(c[h >> 2] | 0) + 32 >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 32 >> 2] | 0) != 0 : 0) {
	                        c[k >> 2] = c[(c[h >> 2] | 0) + 32 >> 2];
	                        c[m >> 2] = 0;
	                        while (1) {
	                            if (!(c[k >> 2] | 0))break;
	                            c[q >> 2] = 0;
	                            c[l >> 2] = c[(c[j >> 2] | 0) + 32 >> 2];
	                            while (1) {
	                                if (!(c[l >> 2] | 0))break;
	                                if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == (c[(c[l >> 2] | 0) + 4 >> 2] | 0)) {
	                                    s = 57;
	                                    break
	                                }
	                                c[l >> 2] = c[c[l >> 2] >> 2]
	                            }
	                            if ((s | 0) == 57) {
	                                s = 0;
	                                c[q >> 2] = 1
	                            }
	                            if (c[q >> 2] | 0) {
	                                c[m >> 2] = c[k >> 2];
	                                c[k >> 2] = c[c[k >> 2] >> 2];
	                                continue
	                            }
	                            o = c[c[k >> 2] >> 2] | 0;
	                            if (!(c[m >> 2] | 0))c[(c[h >> 2] | 0) + 32 >> 2] = o; else c[c[m >> 2] >> 2] = o;
	                            c[n >> 2] = c[c[k >> 2] >> 2];
	                            zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                            c[k >> 2] = c[n >> 2]
	                        }
	                        c[f >> 2] = 0;
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    }
	                    if (((((c[(c[h >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) != (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) : 0) ? (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) ? (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                        PC(c[g >> 2] | 0, c[(c[h >> 2] | 0) + 12 >> 2] | 0, 1793, 153008, 0, 0);
	                        c[f >> 2] = 1793;
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    }
	                    if ((((c[(c[h >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) != (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) : 0) ? (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) == 0 : 0)c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] = c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2];
	                    c[f >> 2] = 0;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                } while (0);
	                if (!(c[(c[h >> 2] | 0) + 32 >> 2] | 0)) {
	                    c[p >> 2] = c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2];
	                    if ((rG(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0) == -1) {
	                        c[f >> 2] = -1;
	                        r = c[f >> 2] | 0;
	                        i = e;
	                        return r | 0
	                    }
	                } else c[p >> 2] = c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2];
	                c[m >> 2] = 0;
	                c[k >> 2] = c[(c[h >> 2] | 0) + 32 >> 2];
	                while (1) {
	                    if (!(c[k >> 2] | 0))break;
	                    if (!(c[(c[k >> 2] | 0) + 4 >> 2] | 0)) {
	                        s = 35;
	                        break
	                    }
	                    c[m >> 2] = c[k >> 2];
	                    c[k >> 2] = c[c[k >> 2] >> 2]
	                }
	                if ((s | 0) == 35) {
	                    s = c[c[k >> 2] >> 2] | 0;
	                    if (!(c[m >> 2] | 0))c[(c[h >> 2] | 0) + 32 >> 2] = s; else c[c[m >> 2] >> 2] = s;
	                    zb[c[135736 >> 2] & 511](c[k >> 2] | 0)
	                }
	                a:do if (c[p >> 2] | 0) {
	                    c[m >> 2] = 0;
	                    c[k >> 2] = c[(c[h >> 2] | 0) + 32 >> 2];
	                    while (1) {
	                        if (!(c[k >> 2] | 0))break a;
	                        if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == (c[p >> 2] | 0))break;
	                        c[m >> 2] = c[k >> 2];
	                        c[k >> 2] = c[c[k >> 2] >> 2]
	                    }
	                    s = c[c[k >> 2] >> 2] | 0;
	                    if (!(c[m >> 2] | 0))c[(c[h >> 2] | 0) + 32 >> 2] = s; else c[c[m >> 2] >> 2] = s;
	                    zb[c[135736 >> 2] & 511](c[k >> 2] | 0)
	                } while (0);
	                c[f >> 2] = 0;
	                r = c[f >> 2] | 0;
	                i = e;
	                return r | 0
	            }

	            function tG(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                do if (c[c[g >> 2] >> 2] | 0) {
	                    if ((c[(c[g >> 2] | 0) + 8 >> 2] | 0) <= (c[(c[g >> 2] | 0) + 4 >> 2] | 0) ? (d = (c[g >> 2] | 0) + 8 | 0, c[d >> 2] = c[d >> 2] << 1, d = Hb[c[135760 >> 2] & 511](c[c[g >> 2] >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] << 2) | 0, c[c[g >> 2] >> 2] = d, (c[c[g >> 2] >> 2] | 0) == 0) : 0) {
	                        tC(0, 142376, 0);
	                        c[(c[g >> 2] | 0) + 8 >> 2] = 0;
	                        c[f >> 2] = -1;
	                        l = c[f >> 2] | 0;
	                        i = e;
	                        return l | 0
	                    }
	                } else {
	                    d = Cb[c[135744 >> 2] & 511](80) | 0;
	                    c[c[g >> 2] >> 2] = d;
	                    if (c[c[g >> 2] >> 2] | 0) {
	                        c[(c[g >> 2] | 0) + 8 >> 2] = 20;
	                        break
	                    }
	                    tC(0, 142344, 0);
	                    c[f >> 2] = -1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } while (0);
	                if ((c[j >> 2] | 0) >= (c[(c[g >> 2] | 0) + 4 >> 2] | 0)) {
	                    d = c[h >> 2] | 0;
	                    b = (c[g >> 2] | 0) + 4 | 0;
	                    a = c[b >> 2] | 0;
	                    c[b >> 2] = a + 1;
	                    c[(c[c[g >> 2] >> 2] | 0) + (a << 2) >> 2] = d
	                } else {
	                    c[k >> 2] = c[(c[g >> 2] | 0) + 4 >> 2];
	                    while (1) {
	                        if ((c[k >> 2] | 0) <= (c[j >> 2] | 0))break;
	                        c[(c[c[g >> 2] >> 2] | 0) + (c[k >> 2] << 2) >> 2] = c[(c[c[g >> 2] >> 2] | 0) + ((c[k >> 2] | 0) - 1 << 2) >> 2];
	                        c[k >> 2] = (c[k >> 2] | 0) + -1
	                    }
	                    c[(c[c[g >> 2] >> 2] | 0) + (c[j >> 2] << 2) >> 2] = c[h >> 2];
	                    h = (c[g >> 2] | 0) + 4 | 0;
	                    c[h >> 2] = (c[h >> 2] | 0) + 1
	                }
	                c[f >> 2] = 0;
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function uG(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                do if (c[f >> 2] | 0)if (c[(c[f >> 2] | 0) + 48 >> 2] & c[g >> 2]) {
	                    c[e >> 2] = 1;
	                    break
	                } else {
	                    c[e >> 2] = 0;
	                    break
	                } else c[e >> 2] = 0; while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function vG(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 24 | 0;
	                j = g + 20 | 0;
	                k = g + 16 | 0;
	                l = g + 12 | 0;
	                m = g + 8 | 0;
	                n = g + 4 | 0;
	                o = g;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                c[n >> 2] = 0;
	                c[o >> 2] = 0;
	                GC(n, 0, c[k >> 2] | 0, c[(c[k >> 2] | 0) + 36 >> 2] | 0) | 0;
	                f = c[h >> 2] | 0;
	                h = c[(c[k >> 2] | 0) + 36 >> 2] | 0;
	                k = c[j >> 2] | 0;
	                j = c[n >> 2] | 0;
	                e = zB(c[c[m >> 2] >> 2] | 0) | 0;
	                EF(f, h, k, 0, 0, 0, 149488, j, e, GC(o, 0, c[l >> 2] | 0, 0) | 0, 0, 0);
	                if (c[n >> 2] | 0) {
	                    zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                    c[n >> 2] = 0
	                }
	                if (!(c[o >> 2] | 0)) {
	                    i = g;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                c[o >> 2] = 0;
	                i = g;
	                return
	            }

	            function wG(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[l >> 2] = 0;
	                GC(l, 0, c[j >> 2] | 0, c[(c[j >> 2] | 0) + 36 >> 2] | 0) | 0;
	                e = c[g >> 2] | 0;
	                g = c[(c[j >> 2] | 0) + 36 >> 2] | 0;
	                j = c[h >> 2] | 0;
	                h = c[l >> 2] | 0;
	                PC(e, g, j, 149448, h, zB(c[c[k >> 2] >> 2] | 0) | 0);
	                if (!(c[l >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                c[l >> 2] = 0;
	                i = f;
	                return
	            }

	            function xG(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if ((c[j >> 2] | 0) == (c[k >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                if (((c[c[j >> 2] >> 2] | 0) != 1 ? (c[(c[j >> 2] | 0) + 48 >> 2] & 4194304 | 0) == 0 : 0) ? (KE(c[j >> 2] | 0, c[h >> 2] | 0) | 0) == -1 : 0) {
	                    c[g >> 2] = -1;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                if (((c[c[k >> 2] >> 2] | 0) != 1 ? (c[(c[k >> 2] | 0) + 48 >> 2] & 4194304 | 0) == 0 : 0) ? (KE(c[k >> 2] | 0, c[h >> 2] | 0) | 0) == -1 : 0) {
	                    c[g >> 2] = -1;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                if ((c[l >> 2] & 1 | 0) == 0 ? (uG(c[(c[j >> 2] | 0) + 64 >> 2] | 0, 1024) | 0) == 0 : 0) {
	                    if ((c[(c[j >> 2] | 0) + 64 >> 2] | 0) == (c[k >> 2] | 0)) {
	                        c[g >> 2] = 0;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    if (!((c[c[(c[j >> 2] | 0) + 64 >> 2] >> 2] | 0) == 1 ? (c[(c[(c[j >> 2] | 0) + 64 >> 2] | 0) + 88 >> 2] | 0) == 45 : 0))o = 18;
	                    if ((o | 0) == 18 ? (xG(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 64 >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0) == 0 : 0) {
	                        c[g >> 2] = 0;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    do if ((c[c[k >> 2] >> 2] | 0) == 1 ? (c[(c[k >> 2] | 0) + 88 >> 2] | 0) == 46 : 0) {
	                        if ((c[(c[j >> 2] | 0) + 48 >> 2] & 64 | 0) == 0 ? (c[(c[j >> 2] | 0) + 48 >> 2] & 128 | 0) == 0 : 0)break;
	                        c[g >> 2] = 0;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    } while (0);
	                    a:do if (c[(c[k >> 2] | 0) + 48 >> 2] & 128) {
	                        c[m >> 2] = c[(c[k >> 2] | 0) + 92 >> 2];
	                        while (1) {
	                            if (!(c[m >> 2] | 0))break a;
	                            if (((c[c[(c[m >> 2] | 0) + 4 >> 2] >> 2] | 0) != 1 ? (c[(c[(c[m >> 2] | 0) + 4 >> 2] | 0) + 48 >> 2] & 4194304 | 0) == 0 : 0) ? (KE(c[(c[m >> 2] | 0) + 4 >> 2] | 0, c[h >> 2] | 0) | 0) == -1 : 0) {
	                                o = 31;
	                                break
	                            }
	                            if (!(xG(c[h >> 2] | 0, c[j >> 2] | 0, c[(c[m >> 2] | 0) + 4 >> 2] | 0, c[l >> 2] | 0) | 0)) {
	                                o = 33;
	                                break
	                            }
	                            c[m >> 2] = c[c[m >> 2] >> 2]
	                        }
	                        if ((o | 0) == 31) {
	                            c[g >> 2] = -1;
	                            n = c[g >> 2] | 0;
	                            i = f;
	                            return n | 0
	                        } else if ((o | 0) == 33) {
	                            c[g >> 2] = 0;
	                            n = c[g >> 2] | 0;
	                            i = f;
	                            return n | 0
	                        }
	                    } while (0);
	                    c[g >> 2] = 3032;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                c[g >> 2] = 3031;
	                n = c[g >> 2] | 0;
	                i = f;
	                return n | 0
	            }

	            function yG(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                do if (!(c[(c[e >> 2] | 0) + 92 >> 2] | 0)) {
	                    a = eB(0) | 0;
	                    c[(c[e >> 2] | 0) + 92 >> 2] = a;
	                    a = c[e >> 2] | 0;
	                    if (c[(c[e >> 2] | 0) + 92 >> 2] | 0) {
	                        bB(c[a + 92 >> 2] | 0, c[(c[e >> 2] | 0) + 8 >> 2] | 0, c[(c[e >> 2] | 0) + 12 >> 2] | 0, c[(c[e >> 2] | 0) + 4 >> 2] | 0);
	                        dB(c[(c[e >> 2] | 0) + 92 >> 2] | 0, c[(c[e >> 2] | 0) + 24 >> 2] | 0, c[(c[e >> 2] | 0) + 4 >> 2] | 0);
	                        break
	                    }
	                    PC(a, 0, 3069, 148224, 0, 0);
	                    c[d >> 2] = -1;
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                } while (0);
	                c[d >> 2] = 0;
	                f = c[d >> 2] | 0;
	                i = b;
	                return f | 0
	            }

	            function zG(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                h = i;
	                i = i + 32 | 0;
	                j = h + 24 | 0;
	                k = h + 20 | 0;
	                l = h + 16 | 0;
	                m = h + 12 | 0;
	                n = h + 8 | 0;
	                o = h + 4 | 0;
	                p = h;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                c[p >> 2] = 0;
	                c[p >> 2] = my(142568) | 0;
	                g = c[p >> 2] | 0;
	                c[p >> 2] = By(g, zB(c[c[k >> 2] >> 2] | 0) | 0) | 0;
	                c[p >> 2] = By(c[p >> 2] | 0, 147720) | 0;
	                if (!(c[m >> 2] | 0))c[p >> 2] = By(c[p >> 2] | 0, 147736) | 0;
	                g = c[p >> 2] | 0;
	                if ((c[m >> 2] | 0) == 1)c[p >> 2] = By(g, 147752) | 0; else c[p >> 2] = By(g, 147768) | 0;
	                if (c[n >> 2] | 0)c[p >> 2] = By(c[p >> 2] | 0, 147784) | 0;
	                c[p >> 2] = By(c[p >> 2] | 0, 143656) | 0;
	                n = c[p >> 2] | 0;
	                c[p >> 2] = By(n, zB(c[c[l >> 2] >> 2] | 0) | 0) | 0;
	                l = c[p >> 2] | 0;
	                if (c[o >> 2] | 0)c[p >> 2] = By(l, 147800) | 0; else c[p >> 2] = By(l, 142568) | 0;
	                GE(c[j >> 2] | 0, 1717, c[k >> 2] | 0, 0, c[p >> 2] | 0, 0);
	                if (!(c[p >> 2] | 0)) {
	                    i = h;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                i = h;
	                return
	            }

	            function AG(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                ce(16, 2, 0, 0, c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function BG(a, b, d, e, f, g, h, j, k, l) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                k = k | 0;
	                l = l | 0;
	                var m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0;
	                m = i;
	                i = i + 48 | 0;
	                n = m + 44 | 0;
	                o = m + 40 | 0;
	                p = m + 36 | 0;
	                q = m + 32 | 0;
	                r = m + 28 | 0;
	                s = m + 24 | 0;
	                t = m + 20 | 0;
	                u = m + 16 | 0;
	                v = m + 12 | 0;
	                w = m + 8 | 0;
	                x = m + 4 | 0;
	                y = m;
	                c[n >> 2] = a;
	                c[o >> 2] = b;
	                c[p >> 2] = d;
	                c[q >> 2] = e;
	                c[r >> 2] = f;
	                c[s >> 2] = g;
	                c[t >> 2] = h;
	                c[u >> 2] = j;
	                c[v >> 2] = k;
	                c[w >> 2] = l;
	                c[x >> 2] = 0;
	                c[y >> 2] = 0;
	                GC(y, 0, c[q >> 2] | 0, 0) | 0;
	                c[y >> 2] = By(c[y >> 2] | 0, 144448) | 0;
	                q = c[y >> 2] | 0;
	                c[y >> 2] = By(q, GC(x, 0, c[r >> 2] | 0, 0) | 0) | 0;
	                if (c[x >> 2] | 0) {
	                    zb[c[135736 >> 2] & 511](c[x >> 2] | 0);
	                    c[x >> 2] = 0
	                }
	                c[y >> 2] = By(c[y >> 2] | 0, 152080) | 0;
	                c[y >> 2] = By(c[y >> 2] | 0, c[s >> 2] | 0) | 0;
	                c[y >> 2] = By(c[y >> 2] | 0, 142704) | 0;
	                IC(c[n >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0, c[y >> 2] | 0, c[t >> 2] | 0, c[u >> 2] | 0, c[v >> 2] | 0, c[w >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[y >> 2] | 0);
	                i = m;
	                return
	            }

	            function CG(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[c[j >> 2] >> 2] = 0;
	                c[c[k >> 2] >> 2] = 0;
	                if (c[l >> 2] | 0)c[c[l >> 2] >> 2] = 0;
	                e = c[h >> 2] | 0;
	                if (c[(c[h >> 2] | 0) + 28 >> 2] | 0) {
	                    c[c[k >> 2] >> 2] = c[e + 28 >> 2];
	                    if (c[l >> 2] | 0)c[c[l >> 2] >> 2] = c[(c[h >> 2] | 0) + 32 >> 2];
	                    if (c[(c[h >> 2] | 0) + 16 >> 2] & 1)c[c[j >> 2] >> 2] = 1;
	                    c[g >> 2] = 1;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                if ((c[e + 12 >> 2] | 0) != 0 ? (c[(c[(c[h >> 2] | 0) + 12 >> 2] | 0) + 44 >> 2] | 0) != 0 : 0) {
	                    c[c[k >> 2] >> 2] = c[(c[(c[h >> 2] | 0) + 12 >> 2] | 0) + 44 >> 2];
	                    if (c[l >> 2] | 0)c[c[l >> 2] >> 2] = c[(c[(c[h >> 2] | 0) + 12 >> 2] | 0) + 68 >> 2];
	                    if (c[(c[(c[h >> 2] | 0) + 12 >> 2] | 0) + 60 >> 2] & 512)c[c[j >> 2] >> 2] = 1;
	                    c[g >> 2] = 1;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                c[g >> 2] = 0;
	                m = c[g >> 2] | 0;
	                i = f;
	                return m | 0
	            }

	            function DG(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                if (c[(c[f >> 2] | 0) + 28 >> 2] | 0) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                b = c[f >> 2] | 0;
	                a:do if (!(c[(c[f >> 2] | 0) + 32 >> 2] | 0)) {
	                    if ((c[b + 36 >> 2] | 0) != 0 & (c[g >> 2] | 0) != 0 ? (qy(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0, c[g >> 2] | 0) | 0) == 0 : 0) {
	                        c[e >> 2] = 0;
	                        j = c[e >> 2] | 0;
	                        i = d;
	                        return j | 0
	                    }
	                } else {
	                    c[h >> 2] = c[b + 32 >> 2];
	                    while (1) {
	                        if (!(c[h >> 2] | 0))break a;
	                        if (qy(c[(c[h >> 2] | 0) + 4 >> 2] | 0, c[g >> 2] | 0) | 0)break;
	                        c[h >> 2] = c[c[h >> 2] >> 2]
	                    }
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } while (0);
	                c[e >> 2] = 1;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function EG(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 24 | 0;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                l = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (c[(c[g >> 2] | 0) + 28 >> 2] | 0) {
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                if (((c[(c[f >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) == (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) : 0) {
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                do if (c[(c[f >> 2] | 0) + 32 >> 2] | 0) {
	                    if (!(c[(c[g >> 2] | 0) + 32 >> 2] | 0)) {
	                        if (!(c[(c[g >> 2] | 0) + 36 >> 2] | 0))break;
	                        c[l >> 2] = c[(c[f >> 2] | 0) + 32 >> 2];
	                        while (1) {
	                            if (!(c[l >> 2] | 0)) {
	                                n = 27;
	                                break
	                            }
	                            if ((c[(c[l >> 2] | 0) + 4 >> 2] | 0) == (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0)) {
	                                n = 25;
	                                break
	                            }
	                            c[l >> 2] = c[c[l >> 2] >> 2]
	                        }
	                        if ((n | 0) == 25) {
	                            c[e >> 2] = 1;
	                            m = c[e >> 2] | 0;
	                            i = d;
	                            return m | 0
	                        } else if ((n | 0) == 27) {
	                            c[e >> 2] = 0;
	                            m = c[e >> 2] | 0;
	                            i = d;
	                            return m | 0
	                        }
	                    }
	                    c[k >> 2] = 0;
	                    c[h >> 2] = c[(c[f >> 2] | 0) + 32 >> 2];
	                    while (1) {
	                        if (!(c[h >> 2] | 0))break;
	                        c[k >> 2] = 0;
	                        c[j >> 2] = c[(c[g >> 2] | 0) + 32 >> 2];
	                        while (1) {
	                            if (!(c[j >> 2] | 0))break;
	                            if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == (c[(c[j >> 2] | 0) + 4 >> 2] | 0)) {
	                                n = 14;
	                                break
	                            }
	                            c[j >> 2] = c[c[j >> 2] >> 2]
	                        }
	                        if ((n | 0) == 14) {
	                            n = 0;
	                            c[k >> 2] = 1
	                        }
	                        if (!(c[k >> 2] | 0)) {
	                            n = 17;
	                            break
	                        }
	                        c[h >> 2] = c[c[h >> 2] >> 2]
	                    }
	                    if ((n | 0) == 17) {
	                        c[e >> 2] = 1;
	                        m = c[e >> 2] | 0;
	                        i = d;
	                        return m | 0
	                    }
	                    if (c[k >> 2] | 0) {
	                        c[e >> 2] = 0;
	                        m = c[e >> 2] | 0;
	                        i = d;
	                        return m | 0
	                    }
	                } while (0);
	                c[e >> 2] = 1;
	                m = c[e >> 2] | 0;
	                i = d;
	                return m | 0
	            }

	            function FG(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                if (((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 16 >> 2] | 0) != 0 : 0) ? (c[(c[e >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                    if (!(((c[c[(c[e >> 2] | 0) + 12 >> 2] >> 2] | 0) != 6 ? (c[c[(c[e >> 2] | 0) + 12 >> 2] >> 2] | 0) != 7 : 0) ? (c[c[(c[e >> 2] | 0) + 12 >> 2] >> 2] | 0) != 8 : 0))f = 8;
	                    if ((f | 0) == 8 ? (vH(c[e >> 2] | 0) | 0) == 0 : 0) {
	                        c[d >> 2] = 1;
	                        g = c[d >> 2] | 0;
	                        i = b;
	                        return g | 0
	                    }
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[d >> 2] = 1;
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function GG(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 24 | 0;
	                j = g + 20 | 0;
	                k = g + 16 | 0;
	                l = g + 12 | 0;
	                m = g + 8 | 0;
	                n = g + 4 | 0;
	                o = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = Cb[c[135744 >> 2] & 511](28) | 0;
	                if (!(c[o >> 2] | 0)) {
	                    tC(c[j >> 2] | 0, 153320, 0);
	                    c[h >> 2] = 0;
	                    p = c[h >> 2] | 0;
	                    i = g;
	                    return p | 0
	                }
	                f = c[o >> 2] | 0;
	                c[f + 0 >> 2] = 0;
	                c[f + 4 >> 2] = 0;
	                c[f + 8 >> 2] = 0;
	                c[f + 12 >> 2] = 0;
	                c[f + 16 >> 2] = 0;
	                c[f + 20 >> 2] = 0;
	                c[f + 24 >> 2] = 0;
	                c[(c[o >> 2] | 0) + 4 >> 2] = c[l >> 2];
	                c[(c[o >> 2] | 0) + 24 >> 2] = c[k >> 2];
	                c[(c[o >> 2] | 0) + 16 >> 2] = c[m >> 2];
	                c[(c[o >> 2] | 0) + 20 >> 2] = c[n >> 2];
	                n = c[o >> 2] | 0;
	                m = c[(c[j >> 2] | 0) + 28 >> 2] | 0;
	                if (!(c[(c[(c[j >> 2] | 0) + 28 >> 2] | 0) + 28 >> 2] | 0))c[m + 28 >> 2] = n; else c[c[m + 32 >> 2] >> 2] = n;
	                c[(c[(c[j >> 2] | 0) + 28 >> 2] | 0) + 32 >> 2] = c[o >> 2];
	                c[h >> 2] = c[o >> 2];
	                p = c[h >> 2] | 0;
	                i = g;
	                return p | 0
	            }

	            function HG(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 44 | 0;
	                g = e + 40 | 0;
	                h = e + 36 | 0;
	                j = e + 32 | 0;
	                k = e + 28 | 0;
	                l = e + 24 | 0;
	                m = e + 20 | 0;
	                n = e + 16 | 0;
	                o = e + 12 | 0;
	                p = e + 8 | 0;
	                q = e + 4 | 0;
	                r = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                do if (((c[(c[h >> 2] | 0) + 28 >> 2] | 0) == (c[(c[j >> 2] | 0) + 28 >> 2] | 0) ? ((c[(c[h >> 2] | 0) + 32 >> 2] | 0) == 0 | 0) == ((c[(c[j >> 2] | 0) + 32 >> 2] | 0) == 0 | 0) : 0) ? ((c[(c[h >> 2] | 0) + 36 >> 2] | 0) == 0 | 0) == ((c[(c[j >> 2] | 0) + 36 >> 2] | 0) == 0 | 0) : 0) {
	                    if ((c[(c[h >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) != (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) : 0)break;
	                    if (!(c[(c[h >> 2] | 0) + 32 >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        s = c[f >> 2] | 0;
	                        i = e;
	                        return s | 0
	                    }
	                    c[n >> 2] = 0;
	                    c[k >> 2] = c[(c[h >> 2] | 0) + 32 >> 2];
	                    while (1) {
	                        if (!(c[k >> 2] | 0))break;
	                        c[n >> 2] = 0;
	                        c[l >> 2] = c[(c[j >> 2] | 0) + 32 >> 2];
	                        while (1) {
	                            if (!(c[l >> 2] | 0))break;
	                            if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == (c[(c[l >> 2] | 0) + 4 >> 2] | 0)) {
	                                t = 12;
	                                break
	                            }
	                            c[l >> 2] = c[c[l >> 2] >> 2]
	                        }
	                        if ((t | 0) == 12) {
	                            t = 0;
	                            c[n >> 2] = 1
	                        }
	                        if (!(c[n >> 2] | 0))break;
	                        c[k >> 2] = c[c[k >> 2] >> 2]
	                    }
	                    if (c[n >> 2] | 0) {
	                        c[f >> 2] = 0;
	                        s = c[f >> 2] | 0;
	                        i = e;
	                        return s | 0
	                    }
	                } while (0);
	                n = c[h >> 2] | 0;
	                if ((c[(c[h >> 2] | 0) + 28 >> 2] | 0) != (c[(c[j >> 2] | 0) + 28 >> 2] | 0)) {
	                    if (!(c[n + 28 >> 2] | 0)) {
	                        c[(c[h >> 2] | 0) + 28 >> 2] = 1;
	                        if (c[(c[h >> 2] | 0) + 32 >> 2] | 0) {
	                            nB(c[(c[h >> 2] | 0) + 32 >> 2] | 0);
	                            c[(c[h >> 2] | 0) + 32 >> 2] = 0
	                        }
	                        if (c[(c[h >> 2] | 0) + 36 >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[(c[h >> 2] | 0) + 36 >> 2] | 0);
	                            c[(c[h >> 2] | 0) + 36 >> 2] = 0
	                        }
	                    }
	                    c[f >> 2] = 0;
	                    s = c[f >> 2] | 0;
	                    i = e;
	                    return s | 0
	                }
	                if ((c[n + 32 >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 32 >> 2] | 0) != 0 : 0) {
	                    c[k >> 2] = c[(c[j >> 2] | 0) + 32 >> 2];
	                    c[p >> 2] = c[(c[h >> 2] | 0) + 32 >> 2];
	                    while (1) {
	                        if (!(c[k >> 2] | 0)) {
	                            t = 40;
	                            break
	                        }
	                        c[o >> 2] = 0;
	                        c[l >> 2] = c[p >> 2];
	                        while (1) {
	                            if (!(c[l >> 2] | 0))break;
	                            if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == (c[(c[l >> 2] | 0) + 4 >> 2] | 0)) {
	                                t = 33;
	                                break
	                            }
	                            c[l >> 2] = c[c[l >> 2] >> 2]
	                        }
	                        if ((t | 0) == 33) {
	                            t = 0;
	                            c[o >> 2] = 1
	                        }
	                        if (!(c[o >> 2] | 0)) {
	                            c[m >> 2] = uH(c[g >> 2] | 0) | 0;
	                            if (!(c[m >> 2] | 0)) {
	                                t = 37;
	                                break
	                            }
	                            c[(c[m >> 2] | 0) + 4 >> 2] = c[(c[k >> 2] | 0) + 4 >> 2];
	                            c[c[m >> 2] >> 2] = c[(c[h >> 2] | 0) + 32 >> 2];
	                            c[(c[h >> 2] | 0) + 32 >> 2] = c[m >> 2]
	                        }
	                        c[k >> 2] = c[c[k >> 2] >> 2]
	                    }
	                    if ((t | 0) == 37) {
	                        c[f >> 2] = -1;
	                        s = c[f >> 2] | 0;
	                        i = e;
	                        return s | 0
	                    } else if ((t | 0) == 40) {
	                        c[f >> 2] = 0;
	                        s = c[f >> 2] | 0;
	                        i = e;
	                        return s | 0
	                    }
	                }
	                if (((c[(c[h >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) != (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) : 0) {
	                    c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] = 0;
	                    c[f >> 2] = 0;
	                    s = c[f >> 2] | 0;
	                    i = e;
	                    return s | 0
	                }
	                if (!(((c[(c[h >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 32 >> 2] | 0) != 0 : 0))t = 48;
	                do if ((t | 0) == 48) {
	                    if (((c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) ? (c[(c[h >> 2] | 0) + 32 >> 2] | 0) != 0 : 0)break;
	                    if (!(((c[(c[h >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) == 0 : 0) ? (c[(c[j >> 2] | 0) + 32 >> 2] | 0) != 0 : 0))t = 87;
	                    do if ((t | 0) == 87) {
	                        if (((c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) == 0 : 0) ? (c[(c[h >> 2] | 0) + 32 >> 2] | 0) != 0 : 0)break;
	                        c[f >> 2] = 0;
	                        s = c[f >> 2] | 0;
	                        i = e;
	                        return s | 0
	                    } while (0);
	                    if (c[(c[h >> 2] | 0) + 32 >> 2] | 0)c[k >> 2] = c[(c[h >> 2] | 0) + 32 >> 2]; else c[k >> 2] = c[(c[j >> 2] | 0) + 32 >> 2];
	                    while (1) {
	                        if (!(c[k >> 2] | 0))break;
	                        if (!(c[(c[k >> 2] | 0) + 4 >> 2] | 0)) {
	                            t = 95;
	                            break
	                        }
	                        c[k >> 2] = c[c[k >> 2] >> 2]
	                    }
	                    if ((t | 0) == 95) {
	                        c[(c[h >> 2] | 0) + 28 >> 2] = 1;
	                        if (c[(c[h >> 2] | 0) + 32 >> 2] | 0) {
	                            nB(c[(c[h >> 2] | 0) + 32 >> 2] | 0);
	                            c[(c[h >> 2] | 0) + 32 >> 2] = 0
	                        }
	                        if (c[(c[h >> 2] | 0) + 36 >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[(c[h >> 2] | 0) + 36 >> 2] | 0);
	                            c[(c[h >> 2] | 0) + 36 >> 2] = 0
	                        }
	                        c[f >> 2] = 0;
	                        s = c[f >> 2] | 0;
	                        i = e;
	                        return s | 0
	                    }
	                    do if (!(c[(c[h >> 2] | 0) + 36 >> 2] | 0)) {
	                        if (c[(c[h >> 2] | 0) + 32 >> 2] | 0) {
	                            nB(c[(c[h >> 2] | 0) + 32 >> 2] | 0);
	                            c[(c[h >> 2] | 0) + 32 >> 2] = 0
	                        }
	                        m = uH(c[g >> 2] | 0) | 0;
	                        c[(c[h >> 2] | 0) + 36 >> 2] = m;
	                        if (c[(c[h >> 2] | 0) + 36 >> 2] | 0) {
	                            c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] = 0;
	                            break
	                        }
	                        c[f >> 2] = -1;
	                        s = c[f >> 2] | 0;
	                        i = e;
	                        return s | 0
	                    } while (0);
	                    c[f >> 2] = 0;
	                    s = c[f >> 2] | 0;
	                    i = e;
	                    return s | 0
	                } while (0);
	                c[r >> 2] = 0;
	                if (c[(c[h >> 2] | 0) + 32 >> 2] | 0) {
	                    c[k >> 2] = c[(c[h >> 2] | 0) + 32 >> 2];
	                    c[l >> 2] = c[(c[j >> 2] | 0) + 36 >> 2]
	                } else {
	                    c[k >> 2] = c[(c[j >> 2] | 0) + 32 >> 2];
	                    c[l >> 2] = c[(c[h >> 2] | 0) + 36 >> 2]
	                }
	                c[q >> 2] = 0;
	                while (1) {
	                    if (!(c[k >> 2] | 0))break;
	                    if (c[(c[k >> 2] | 0) + 4 >> 2] | 0) {
	                        if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == (c[(c[l >> 2] | 0) + 4 >> 2] | 0))c[q >> 2] = 1
	                    } else c[r >> 2] = 1;
	                    if ((c[q >> 2] | 0) != 0 & (c[r >> 2] | 0) != 0)break;
	                    c[k >> 2] = c[c[k >> 2] >> 2]
	                }
	                do if ((c[q >> 2] | 0) != 0 & (c[r >> 2] | 0) != 0) {
	                    c[(c[h >> 2] | 0) + 28 >> 2] = 1;
	                    if (c[(c[h >> 2] | 0) + 32 >> 2] | 0) {
	                        nB(c[(c[h >> 2] | 0) + 32 >> 2] | 0);
	                        c[(c[h >> 2] | 0) + 32 >> 2] = 0
	                    }
	                    if (c[(c[h >> 2] | 0) + 36 >> 2] | 0) {
	                        zb[c[135736 >> 2] & 511](c[(c[h >> 2] | 0) + 36 >> 2] | 0);
	                        c[(c[h >> 2] | 0) + 36 >> 2] = 0
	                    }
	                } else {
	                    if (!((c[q >> 2] | 0) == 0 | (c[r >> 2] | 0) != 0)) {
	                        if (c[(c[h >> 2] | 0) + 32 >> 2] | 0) {
	                            nB(c[(c[h >> 2] | 0) + 32 >> 2] | 0);
	                            c[(c[h >> 2] | 0) + 32 >> 2] = 0
	                        }
	                        if ((c[(c[h >> 2] | 0) + 36 >> 2] | 0) == 0 ? (k = uH(c[g >> 2] | 0) | 0, c[(c[h >> 2] | 0) + 36 >> 2] = k, (c[(c[h >> 2] | 0) + 36 >> 2] | 0) == 0) : 0) {
	                            c[f >> 2] = -1;
	                            s = c[f >> 2] | 0;
	                            i = e;
	                            return s | 0
	                        }
	                        c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] = 0;
	                        break
	                    }
	                    if ((c[q >> 2] | 0) == 0 & (c[r >> 2] | 0) != 0) {
	                        PC(c[g >> 2] | 0, c[(c[h >> 2] | 0) + 12 >> 2] | 0, 1794, 152712, 0, 0);
	                        c[f >> 2] = 1794;
	                        s = c[f >> 2] | 0;
	                        i = e;
	                        return s | 0
	                    }
	                    if (!((c[q >> 2] | 0) != 0 | (c[r >> 2] | 0) != 0) ? (c[(c[h >> 2] | 0) + 36 >> 2] | 0) == 0 : 0) {
	                        if (c[(c[h >> 2] | 0) + 32 >> 2] | 0) {
	                            nB(c[(c[h >> 2] | 0) + 32 >> 2] | 0);
	                            c[(c[h >> 2] | 0) + 32 >> 2] = 0
	                        }
	                        k = uH(c[g >> 2] | 0) | 0;
	                        c[(c[h >> 2] | 0) + 36 >> 2] = k;
	                        if (c[(c[h >> 2] | 0) + 36 >> 2] | 0) {
	                            c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] = c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2];
	                            break
	                        }
	                        c[f >> 2] = -1;
	                        s = c[f >> 2] | 0;
	                        i = e;
	                        return s | 0
	                    }
	                } while (0);
	                c[f >> 2] = 0;
	                s = c[f >> 2] | 0;
	                i = e;
	                return s | 0
	            }

	            function IG(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                d = i;
	                i = i + 48 | 0;
	                e = d + 40 | 0;
	                f = d + 36 | 0;
	                g = d + 32 | 0;
	                h = d + 28 | 0;
	                j = d + 24 | 0;
	                k = d + 20 | 0;
	                l = d + 16 | 0;
	                m = d + 12 | 0;
	                n = d + 8 | 0;
	                o = d + 4 | 0;
	                p = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                do if (c[(c[g >> 2] | 0) + 64 >> 2] | 0) {
	                    if ((c[c[(c[g >> 2] | 0) + 64 >> 2] >> 2] | 0) != 4) {
	                        if ((c[c[(c[g >> 2] | 0) + 64 >> 2] >> 2] | 0) != 1)break;
	                        if ((c[(c[(c[g >> 2] | 0) + 64 >> 2] | 0) + 88 >> 2] | 0) == 45)break
	                    }
	                    if (!(c[(c[g >> 2] | 0) + 48 >> 2] & 2)) {
	                        AB(c[f >> 2] | 0, 3076, 0, c[g >> 2] | 0, 152344, 0, 0);
	                        c[e >> 2] = 3076;
	                        q = c[e >> 2] | 0;
	                        i = d;
	                        return q | 0
	                    }
	                } while (0);
	                a:do if ((c[(c[g >> 2] | 0) + 116 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 116 >> 2] | 0) + 4 >> 2] | 0) > 1 : 0) {
	                    c[h >> 2] = c[(c[g >> 2] | 0) + 116 >> 2];
	                    c[n >> 2] = 0;
	                    c[l >> 2] = (c[(c[h >> 2] | 0) + 4 >> 2] | 0) - 1;
	                    b:while (1) {
	                        if ((c[l >> 2] | 0) < 0)break a;
	                        c[j >> 2] = c[(c[c[h >> 2] >> 2] | 0) + (c[l >> 2] << 2) >> 2];
	                        c:do if ((c[l >> 2] | 0) > 0) {
	                            c[m >> 2] = (c[l >> 2] | 0) - 1;
	                            while (1) {
	                                if ((c[m >> 2] | 0) < 0) {
	                                    r = 20;
	                                    break c
	                                }
	                                c[k >> 2] = c[(c[c[h >> 2] >> 2] | 0) + (c[m >> 2] << 2) >> 2];
	                                if ((c[(c[(c[j >> 2] | 0) + 12 >> 2] | 0) + 8 >> 2] | 0) == (c[(c[(c[k >> 2] | 0) + 12 >> 2] | 0) + 8 >> 2] | 0) ? (c[(c[(c[j >> 2] | 0) + 12 >> 2] | 0) + 56 >> 2] | 0) == (c[(c[(c[k >> 2] | 0) + 12 >> 2] | 0) + 56 >> 2] | 0) : 0)break;
	                                c[m >> 2] = (c[m >> 2] | 0) + -1
	                            }
	                            c[o >> 2] = 0;
	                            b = c[f >> 2] | 0;
	                            a = c[g >> 2] | 0;
	                            AB(b, 3087, 0, a, 152424, ZD(o, c[j >> 2] | 0) | 0, 0);
	                            if (c[o >> 2] | 0) {
	                                zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                                c[o >> 2] = 0
	                            }
	                            if ((TE(c[h >> 2] | 0, c[l >> 2] | 0) | 0) == -1)break b
	                        } else r = 20; while (0);
	                        if (((r | 0) == 20 ? (r = 0, (c[(c[(c[j >> 2] | 0) + 12 >> 2] | 0) + 48 >> 2] | 0) != 0) : 0) ? (SE(c[(c[(c[j >> 2] | 0) + 12 >> 2] | 0) + 48 >> 2] | 0, 23) | 0) != 0 : 0) {
	                            if (c[n >> 2] | 0) {
	                                c[p >> 2] = 0;
	                                a = c[f >> 2] | 0;
	                                b = c[g >> 2] | 0;
	                                AB(a, 3087, 0, b, 152440, ZD(p, c[j >> 2] | 0) | 0, 0);
	                                if (c[p >> 2] | 0) {
	                                    zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                                    c[p >> 2] = 0
	                                }
	                                if ((TE(c[h >> 2] | 0, c[l >> 2] | 0) | 0) == -1)break
	                            }
	                            c[n >> 2] = 1
	                        }
	                        c[l >> 2] = (c[l >> 2] | 0) + -1
	                    }
	                    c[e >> 2] = -1;
	                    q = c[e >> 2] | 0;
	                    i = d;
	                    return q | 0
	                } while (0);
	                c[e >> 2] = 0;
	                q = c[e >> 2] | 0;
	                i = d;
	                return q | 0
	            }

	            function JG(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = c[(c[g >> 2] | 0) + 64 >> 2];
	                if ((c[c[h >> 2] >> 2] | 0) != 5 ? (c[(c[h >> 2] | 0) + 88 >> 2] | 0) != 45 : 0) {
	                    if ((c[(c[g >> 2] | 0) + 104 >> 2] | 0) != (c[h >> 2] | 0)) {
	                        GE(c[f >> 2] | 0, 3063, c[g >> 2] | 0, 0, 152296, 0);
	                        c[e >> 2] = 3063;
	                        j = c[e >> 2] | 0;
	                        i = d;
	                        return j | 0
	                    }
	                    if (c[(c[h >> 2] | 0) + 48 >> 2] & 512) {
	                        GE(c[f >> 2] | 0, 3063, c[g >> 2] | 0, 0, 152088, 0);
	                        c[e >> 2] = 3063;
	                        j = c[e >> 2] | 0;
	                        i = d;
	                        return j | 0
	                    }
	                } else k = 3;
	                do if ((k | 0) == 3) {
	                    if (c[(c[h >> 2] | 0) + 48 >> 2] & 512) {
	                        GE(c[f >> 2] | 0, 3063, c[g >> 2] | 0, 0, 152088, 0);
	                        c[e >> 2] = 3063;
	                        j = c[e >> 2] | 0;
	                        i = d;
	                        return j | 0
	                    }
	                    if ((c[(c[g >> 2] | 0) + 104 >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 104 >> 2] | 0) == (c[(c[h >> 2] | 0) + 104 >> 2] | 0) : 0)break;
	                    if ((c[(c[g >> 2] | 0) + 52 >> 2] | 0) == 1 ? (c[(c[h >> 2] | 0) + 52 >> 2] | 0) == 1 : 0)break;
	                    if (!(c[(c[g >> 2] | 0) + 28 >> 2] | 0)) {
	                        GE(c[f >> 2] | 0, 3063, c[g >> 2] | 0, 0, 152152, 0);
	                        c[e >> 2] = 3063;
	                        j = c[e >> 2] | 0;
	                        i = d;
	                        return j | 0
	                    }
	                    if ((c[(c[h >> 2] | 0) + 52 >> 2] | 0) != 1) {
	                        if ((c[(c[g >> 2] | 0) + 52 >> 2] | 0) == (c[(c[h >> 2] | 0) + 52 >> 2] | 0)) {
	                            if ((c[(c[g >> 2] | 0) + 52 >> 2] | 0) == 3)break;
	                            if ((c[(c[g >> 2] | 0) + 52 >> 2] | 0) == 2)break
	                        }
	                        GE(c[f >> 2] | 0, 3063, c[g >> 2] | 0, 0, 152200, 0);
	                        c[e >> 2] = 3063;
	                        j = c[e >> 2] | 0;
	                        i = d;
	                        return j | 0
	                    }
	                } while (0);
	                c[e >> 2] = 0;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function KG(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 24 | 0;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                l = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = c[(c[g >> 2] | 0) + 64 >> 2];
	                if ((c[c[h >> 2] >> 2] | 0) != 5 ? (c[(c[h >> 2] | 0) + 88 >> 2] | 0) != 45 : 0) {
	                    AB(c[f >> 2] | 0, 1787, c[(c[g >> 2] | 0) + 36 >> 2] | 0, c[g >> 2] | 0, 150744, 0, 0);
	                    c[e >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                b = c[f >> 2] | 0;
	                if (c[(c[h >> 2] | 0) + 48 >> 2] & 1024) {
	                    AB(b, 1787, c[(c[g >> 2] | 0) + 36 >> 2] | 0, c[g >> 2] | 0, 150784, 0, 0);
	                    c[e >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                if ((UE(b, 0, c[g >> 2] | 0, c[h >> 2] | 0, c[(c[g >> 2] | 0) + 116 >> 2] | 0, c[(c[h >> 2] | 0) + 116 >> 2] | 0, c[(c[g >> 2] | 0) + 84 >> 2] | 0, c[(c[h >> 2] | 0) + 84 >> 2] | 0) | 0) == -1) {
	                    c[e >> 2] = -1;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                do if ((c[(c[h >> 2] | 0) + 88 >> 2] | 0) != 45) {
	                    if ((c[(c[g >> 2] | 0) + 52 >> 2] | 0) != 4 ? (c[(c[g >> 2] | 0) + 52 >> 2] | 0) != 6 : 0) {
	                        if ((c[(c[g >> 2] | 0) + 52 >> 2] | 0) == 1) {
	                            if ((c[(c[h >> 2] | 0) + 52 >> 2] | 0) == 1)break;
	                            if (!((c[(c[h >> 2] | 0) + 52 >> 2] | 0) != 2 ? (c[(c[h >> 2] | 0) + 52 >> 2] | 0) != 3 : 0))n = 28;
	                            if ((n | 0) == 28 ? (FG(c[(c[h >> 2] | 0) + 28 >> 2] | 0) | 0) != 0 : 0)break;
	                            GE(c[f >> 2] | 0, 1787, c[g >> 2] | 0, 0, 151040, 0);
	                            c[e >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                            m = c[e >> 2] | 0;
	                            i = d;
	                            return m | 0
	                        }
	                        if ((c[(c[g >> 2] | 0) + 52 >> 2] | 0) != 2 ? (c[(c[g >> 2] | 0) + 52 >> 2] | 0) != 3 : 0) {
	                            GE(c[f >> 2] | 0, 1787, c[g >> 2] | 0, 0, 151256, 0);
	                            c[e >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                            m = c[e >> 2] | 0;
	                            i = d;
	                            return m | 0
	                        }
	                        if ((c[(c[g >> 2] | 0) + 52 >> 2] | 0) != 3)break;
	                        if ((c[(c[h >> 2] | 0) + 52 >> 2] | 0) == 3)break;
	                        GE(c[f >> 2] | 0, 1787, c[g >> 2] | 0, 0, 151160, 0);
	                        c[e >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                        m = c[e >> 2] | 0;
	                        i = d;
	                        return m | 0
	                    }
	                    if ((c[(c[h >> 2] | 0) + 52 >> 2] | 0) != 4 ? (c[(c[h >> 2] | 0) + 52 >> 2] | 0) != 6 : 0) {
	                        if ((c[(c[h >> 2] | 0) + 52 >> 2] | 0) == 3 ? (FG(c[(c[h >> 2] | 0) + 28 >> 2] | 0) | 0) != 0 : 0)break;
	                        GE(c[f >> 2] | 0, 1787, c[g >> 2] | 0, 0, 150936, 0);
	                        c[e >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                        m = c[e >> 2] | 0;
	                        i = d;
	                        return m | 0
	                    }
	                    c[j >> 2] = xG(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 104 >> 2] | 0, c[(c[h >> 2] | 0) + 104 >> 2] | 0, 0) | 0;
	                    if (c[j >> 2] | 0) {
	                        c[k >> 2] = 0;
	                        c[l >> 2] = 0;
	                        if ((c[j >> 2] | 0) == -1) {
	                            c[e >> 2] = -1;
	                            m = c[e >> 2] | 0;
	                            i = d;
	                            return m | 0
	                        }
	                        b = c[f >> 2] | 0;
	                        a = c[g >> 2] | 0;
	                        o = ZD(k, c[(c[g >> 2] | 0) + 104 >> 2] | 0) | 0;
	                        AB(b, 1787, 0, a, 150848, o, ZD(l, c[(c[h >> 2] | 0) + 104 >> 2] | 0) | 0);
	                        if (c[k >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                            c[k >> 2] = 0
	                        }
	                        if (c[l >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                            c[l >> 2] = 0
	                        }
	                        c[e >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                        m = c[e >> 2] | 0;
	                        i = d;
	                        return m | 0
	                    }
	                } while (0);
	                c[e >> 2] = 0;
	                m = c[e >> 2] | 0;
	                i = d;
	                return m | 0
	            }

	            function LG(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[(c[g >> 2] | 0) + 80 >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                b = c[g >> 2] | 0;
	                if ((c[(c[g >> 2] | 0) + 80 >> 2] | 0) == (c[f >> 2] | 0)) {
	                    c[e >> 2] = b;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                if (c[(c[b + 80 >> 2] | 0) + 48 >> 2] & 512) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } else {
	                    b = (c[(c[g >> 2] | 0) + 80 >> 2] | 0) + 48 | 0;
	                    c[b >> 2] = c[b >> 2] | 512;
	                    c[h >> 2] = LG(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 80 >> 2] | 0) | 0;
	                    f = (c[(c[g >> 2] | 0) + 80 >> 2] | 0) + 48 | 0;
	                    c[f >> 2] = c[f >> 2] ^ 512;
	                    c[e >> 2] = c[h >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                return 0
	            }

	            function MG(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                do if ((c[c[j >> 2] >> 2] | 0) != 4) {
	                    if ((c[c[j >> 2] >> 2] | 0) == 1 ? (c[(c[j >> 2] | 0) + 88 >> 2] | 0) != 45 : 0)break;
	                    c[g >> 2] = wH(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                } while (0);
	                c[g >> 2] = xG(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0;
	                m = c[g >> 2] | 0;
	                i = f;
	                return m | 0
	            }

	            function NG(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 24 | 0;
	                j = g + 20 | 0;
	                k = g + 16 | 0;
	                l = g + 12 | 0;
	                m = g + 8 | 0;
	                n = g + 4 | 0;
	                o = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = 0;
	                if (!((c[c[l >> 2] >> 2] | 0) != 5 ? (c[(c[l >> 2] | 0) + 88 >> 2] | 0) != 45 : 0))p = 3;
	                do if (((p | 0) == 3 ? (c[(c[l >> 2] | 0) + 52 >> 2] | 0) != 4 : 0) ? (c[(c[l >> 2] | 0) + 52 >> 2] | 0) != 6 : 0) {
	                    if ((c[(c[l >> 2] | 0) + 52 >> 2] | 0) == 3 ? (FG(c[(c[l >> 2] | 0) + 28 >> 2] | 0) | 0) != 0 : 0)break;
	                    GE(c[j >> 2] | 0, 3059, c[l >> 2] | 0, c[(c[l >> 2] | 0) + 36 >> 2] | 0, 159240, 0);
	                    c[h >> 2] = 3059;
	                    q = c[h >> 2] | 0;
	                    i = g;
	                    return q | 0
	                } while (0);
	                do if ((c[c[l >> 2] >> 2] | 0) == 4)p = 11; else {
	                    if ((c[c[l >> 2] >> 2] | 0) == 1 ? (c[(c[l >> 2] | 0) + 88 >> 2] | 0) != 45 : 0) {
	                        p = 11;
	                        break
	                    }
	                    if ((c[(c[l >> 2] | 0) + 52 >> 2] | 0) != 4 ? (c[(c[l >> 2] | 0) + 52 >> 2] | 0) != 6 : 0) {
	                        c[h >> 2] = c[o >> 2];
	                        q = c[h >> 2] | 0;
	                        i = g;
	                        return q | 0
	                    }
	                    c[o >> 2] = yB(c[j >> 2] | 0, c[k >> 2] | 0, c[(c[l >> 2] | 0) + 104 >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0, 1, 1, 0) | 0
	                } while (0);
	                if ((p | 0) == 11)c[o >> 2] = yB(c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0, 1, 1, 0) | 0;
	                if ((c[o >> 2] | 0) < 0)xB(c[j >> 2] | 0, 159384, 141832);
	                c[h >> 2] = c[o >> 2];
	                q = c[h >> 2] | 0;
	                i = g;
	                return q | 0
	            }

	            function OG(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 0;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    c[f >> 2] = -1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[k >> 2] = xH(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0))c[k >> 2] = yH(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[f >> 2] = -1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                if ((bE(c[(c[k >> 2] | 0) + 4 >> 2] | 0, c[j >> 2] | 0) | 0) == -1) {
	                    c[f >> 2] = -1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } else {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                return 0
	            }

	            function PG(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                d = i;
	                i = i + 48 | 0;
	                e = d + 32 | 0;
	                f = d + 28 | 0;
	                g = d + 24 | 0;
	                h = d + 20 | 0;
	                j = d + 16 | 0;
	                k = d + 12 | 0;
	                l = d + 8 | 0;
	                m = d + 4 | 0;
	                n = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                if (!(c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 48 >> 2] & 131072)) {
	                    c[j >> 2] = c[(c[g >> 2] | 0) + 12 >> 2];
	                    if (c[(c[j >> 2] | 0) + 48 >> 2] & 16) {
	                        c[e >> 2] = 0;
	                        o = c[e >> 2] | 0;
	                        i = d;
	                        return o | 0
	                    }
	                    do if ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) == 1) {
	                        c[k >> 2] = c[(c[f >> 2] | 0) + 76 >> 2];
	                        b = Ez(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[k >> 2] | 0, 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[(c[j >> 2] | 0) + 52 >> 2] | 0, c[j >> 2] | 0) | 0;
	                        c[(c[f >> 2] | 0) + 76 >> 2] = b
	                    } else {
	                        if ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) >= 1073741824 ? (c[(c[g >> 2] | 0) + 16 >> 2] | 0) < 2 : 0) {
	                            c[k >> 2] = c[(c[f >> 2] | 0) + 76 >> 2];
	                            b = Ez(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[k >> 2] | 0, 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[(c[j >> 2] | 0) + 52 >> 2] | 0, c[j >> 2] | 0) | 0;
	                            c[(c[f >> 2] | 0) + 76 >> 2] = b;
	                            b = Ez(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[(c[j >> 2] | 0) + 52 >> 2] | 0, c[j >> 2] | 0) | 0;
	                            c[(c[f >> 2] | 0) + 76 >> 2] = b;
	                            break
	                        }
	                        if ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) == 1073741824)p = 1073741824; else p = (c[(c[g >> 2] | 0) + 20 >> 2] | 0) - 1 | 0;
	                        c[m >> 2] = p;
	                        if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) < 1)q = 0; else q = (c[(c[g >> 2] | 0) + 16 >> 2] | 0) - 1 | 0;
	                        c[n >> 2] = q;
	                        c[k >> 2] = Jz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0, 0) | 0;
	                        c[l >> 2] = Lz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[n >> 2] | 0, c[m >> 2] | 0) | 0;
	                        b = Ez(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[k >> 2] | 0, 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[(c[j >> 2] | 0) + 52 >> 2] | 0, c[j >> 2] | 0) | 0;
	                        c[(c[f >> 2] | 0) + 76 >> 2] = b;
	                        Mz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0;
	                        b = Nz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0, 0, c[l >> 2] | 0) | 0;
	                        c[(c[f >> 2] | 0) + 76 >> 2] = b
	                    } while (0);
	                    if (!(c[(c[g >> 2] | 0) + 16 >> 2] | 0)) {
	                        Jz(c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[k >> 2] | 0, c[(c[f >> 2] | 0) + 76 >> 2] | 0) | 0;
	                        c[h >> 2] = 1
	                    }
	                } else c[h >> 2] = QG(c[f >> 2] | 0, c[g >> 2] | 0, -1, 0) | 0;
	                c[e >> 2] = c[h >> 2];
	                o = c[e >> 2] | 0;
	                i = d;
	                return o | 0
	            }

	            function QG(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0;
	                f = i;
	                i = i + 64 | 0;
	                g = f + 56 | 0;
	                h = f + 52 | 0;
	                j = f + 48 | 0;
	                k = f + 44 | 0;
	                l = f + 40 | 0;
	                m = f + 36 | 0;
	                n = f + 32 | 0;
	                o = f + 28 | 0;
	                p = f + 24 | 0;
	                q = f + 20 | 0;
	                r = f + 16 | 0;
	                s = f + 12 | 0;
	                t = f + 8 | 0;
	                u = f + 4 | 0;
	                v = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[s >> 2] = 0;
	                c[o >> 2] = c[(c[j >> 2] | 0) + 12 >> 2];
	                c[m >> 2] = c[(c[h >> 2] | 0) + 76 >> 2];
	                if (!(c[l >> 2] | 0))c[l >> 2] = Iz(c[(c[h >> 2] | 0) + 64 >> 2] | 0) | 0;
	                c[q >> 2] = xH(c[h >> 2] | 0, c[o >> 2] | 0) | 0;
	                if (!(c[q >> 2] | 0)) {
	                    e = c[h >> 2] | 0;
	                    d = FC(c[j >> 2] | 0) | 0;
	                    PC(e, d, 3069, 158280, c[(c[o >> 2] | 0) + 8 >> 2] | 0, 0);
	                    c[g >> 2] = 0;
	                    w = c[g >> 2] | 0;
	                    i = f;
	                    return w | 0
	                }
	                a:do if ((c[k >> 2] | 0) >= 0) {
	                    c[n >> 2] = Mz(c[(c[h >> 2] | 0) + 64 >> 2] | 0, c[m >> 2] | 0, 0, c[k >> 2] | 0) | 0;
	                    Ez(c[(c[h >> 2] | 0) + 64 >> 2] | 0, c[n >> 2] | 0, c[l >> 2] | 0, c[(c[o >> 2] | 0) + 8 >> 2] | 0, c[(c[o >> 2] | 0) + 52 >> 2] | 0, c[o >> 2] | 0) | 0;
	                    c[r >> 2] = 0;
	                    while (1) {
	                        if ((c[r >> 2] | 0) >= (c[(c[(c[q >> 2] | 0) + 4 >> 2] | 0) + 4 >> 2] | 0))break a;
	                        c[p >> 2] = c[(c[c[(c[q >> 2] | 0) + 4 >> 2] >> 2] | 0) + (c[r >> 2] << 2) >> 2];
	                        Ez(c[(c[h >> 2] | 0) + 64 >> 2] | 0, c[n >> 2] | 0, c[l >> 2] | 0, c[(c[p >> 2] | 0) + 8 >> 2] | 0, c[(c[p >> 2] | 0) + 52 >> 2] | 0, c[p >> 2] | 0) | 0;
	                        c[r >> 2] = (c[r >> 2] | 0) + 1
	                    }
	                } else {
	                    if ((c[(c[j >> 2] | 0) + 20 >> 2] | 0) == 1) {
	                        d = c[(c[h >> 2] | 0) + 64 >> 2] | 0;
	                        e = Ez(c[(c[h >> 2] | 0) + 64 >> 2] | 0, c[m >> 2] | 0, 0, c[(c[o >> 2] | 0) + 8 >> 2] | 0, c[(c[o >> 2] | 0) + 52 >> 2] | 0, c[o >> 2] | 0) | 0;
	                        Jz(d, e, c[l >> 2] | 0) | 0;
	                        c[r >> 2] = 0;
	                        while (1) {
	                            if ((c[r >> 2] | 0) >= (c[(c[(c[q >> 2] | 0) + 4 >> 2] | 0) + 4 >> 2] | 0))break a;
	                            c[p >> 2] = c[(c[c[(c[q >> 2] | 0) + 4 >> 2] >> 2] | 0) + (c[r >> 2] << 2) >> 2];
	                            c[n >> 2] = Ez(c[(c[h >> 2] | 0) + 64 >> 2] | 0, c[m >> 2] | 0, 0, c[(c[p >> 2] | 0) + 8 >> 2] | 0, c[(c[p >> 2] | 0) + 52 >> 2] | 0, c[p >> 2] | 0) | 0;
	                            Jz(c[(c[h >> 2] | 0) + 64 >> 2] | 0, c[n >> 2] | 0, c[l >> 2] | 0) | 0;
	                            c[r >> 2] = (c[r >> 2] | 0) + 1
	                        }
	                    }
	                    if ((c[(c[j >> 2] | 0) + 20 >> 2] | 0) == 1073741824)x = 1073741824; else x = (c[(c[j >> 2] | 0) + 20 >> 2] | 0) - 1 | 0;
	                    c[u >> 2] = x;
	                    if ((c[(c[j >> 2] | 0) + 16 >> 2] | 0) < 1)y = 0; else y = (c[(c[j >> 2] | 0) + 16 >> 2] | 0) - 1 | 0;
	                    c[v >> 2] = y;
	                    c[k >> 2] = Lz(c[(c[h >> 2] | 0) + 64 >> 2] | 0, c[v >> 2] | 0, c[u >> 2] | 0) | 0;
	                    c[t >> 2] = Iz(c[(c[h >> 2] | 0) + 64 >> 2] | 0) | 0;
	                    e = c[(c[h >> 2] | 0) + 64 >> 2] | 0;
	                    d = Ez(c[(c[h >> 2] | 0) + 64 >> 2] | 0, c[m >> 2] | 0, 0, c[(c[o >> 2] | 0) + 8 >> 2] | 0, c[(c[o >> 2] | 0) + 52 >> 2] | 0, c[o >> 2] | 0) | 0;
	                    Jz(e, d, c[t >> 2] | 0) | 0;
	                    c[r >> 2] = 0;
	                    while (1) {
	                        if ((c[r >> 2] | 0) >= (c[(c[(c[q >> 2] | 0) + 4 >> 2] | 0) + 4 >> 2] | 0))break;
	                        c[p >> 2] = c[(c[c[(c[q >> 2] | 0) + 4 >> 2] >> 2] | 0) + (c[r >> 2] << 2) >> 2];
	                        d = c[(c[h >> 2] | 0) + 64 >> 2] | 0;
	                        e = Ez(c[(c[h >> 2] | 0) + 64 >> 2] | 0, c[m >> 2] | 0, 0, c[(c[p >> 2] | 0) + 8 >> 2] | 0, c[(c[p >> 2] | 0) + 52 >> 2] | 0, c[p >> 2] | 0) | 0;
	                        Jz(d, e, c[t >> 2] | 0) | 0;
	                        c[r >> 2] = (c[r >> 2] | 0) + 1
	                    }
	                    Mz(c[(c[h >> 2] | 0) + 64 >> 2] | 0, c[t >> 2] | 0, c[m >> 2] | 0, c[k >> 2] | 0) | 0;
	                    Nz(c[(c[h >> 2] | 0) + 64 >> 2] | 0, c[t >> 2] | 0, c[l >> 2] | 0, c[k >> 2] | 0) | 0
	                } while (0);
	                if (!(c[(c[j >> 2] | 0) + 16 >> 2] | 0)) {
	                    Jz(c[(c[h >> 2] | 0) + 64 >> 2] | 0, c[m >> 2] | 0, c[l >> 2] | 0) | 0;
	                    c[s >> 2] = 1
	                }
	                c[(c[h >> 2] | 0) + 76 >> 2] = c[l >> 2];
	                c[g >> 2] = c[s >> 2];
	                w = c[g >> 2] | 0;
	                i = f;
	                return w | 0
	            }

	            function RG(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[(c[f >> 2] | 0) + 168 >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                c[h >> 2] = 0;
	                while (1) {
	                    if ((c[h >> 2] | 0) >= (c[(c[f >> 2] | 0) + 168 >> 2] | 0)) {
	                        l = 8;
	                        break
	                    }
	                    c[j >> 2] = c[(c[(c[f >> 2] | 0) + 164 >> 2] | 0) + (c[h >> 2] << 2) >> 2];
	                    if ((c[(c[j >> 2] | 0) + 48 >> 2] | 0) == (c[g >> 2] | 0)) {
	                        l = 6;
	                        break
	                    }
	                    c[h >> 2] = (c[h >> 2] | 0) + 1
	                }
	                if ((l | 0) == 6) {
	                    c[e >> 2] = c[j >> 2];
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                } else if ((l | 0) == 8) {
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                return 0
	            }

	            function SG(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                g = i;
	                i = i + 48 | 0;
	                h = g + 32 | 0;
	                j = g + 28 | 0;
	                k = g + 24 | 0;
	                l = g + 20 | 0;
	                m = g + 16 | 0;
	                n = g + 12 | 0;
	                o = g + 8 | 0;
	                p = g + 4 | 0;
	                q = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = 0;
	                c[q >> 2] = 0;
	                if ((c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0) {
	                    c[h >> 2] = -1;
	                    r = c[h >> 2] | 0;
	                    i = g;
	                    return r | 0
	                }
	                f = c[j >> 2] | 0;
	                if (!(c[(c[j >> 2] | 0) + 88 >> 2] | 0)) {
	                    xB(f, 155272, 155304);
	                    c[h >> 2] = -1;
	                    r = c[h >> 2] | 0;
	                    i = g;
	                    return r | 0
	                }
	                c[p >> 2] = c[f + 88 >> 2];
	                f = c[p >> 2] | 0;
	                if (!(c[(c[p >> 2] | 0) + 28 >> 2] | 0)) {
	                    xB(f, 155272, 155336);
	                    c[h >> 2] = -1;
	                    r = c[h >> 2] | 0;
	                    i = g;
	                    return r | 0
	                }
	                c[n >> 2] = JF(c[f + 80 >> 2] | 0, c[n >> 2] | 0, c[l >> 2] | 0) | 0;
	                c[o >> 2] = FB(c[p >> 2] | 0, 1, c[n >> 2] | 0, 0, 0, 0, c[l >> 2] | 0, 0, c[m >> 2] | 0, q) | 0;
	                if (c[o >> 2] | 0) {
	                    c[h >> 2] = c[o >> 2];
	                    r = c[h >> 2] | 0;
	                    i = g;
	                    return r | 0
	                }
	                if (!(c[q >> 2] | 0)) {
	                    NC(c[j >> 2] | 0, 1879, c[l >> 2] | 0, 0, 155352, c[n >> 2] | 0, 0, 0);
	                    c[h >> 2] = c[o >> 2];
	                    r = c[h >> 2] | 0;
	                    i = g;
	                    return r | 0
	                }
	                if ((c[q >> 2] | 0) != 0 ? (c[(c[(c[p >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] | 0) == 0 : 0)c[(c[(c[p >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] = c[q >> 2];
	                if (((c[q >> 2] | 0) != 0 ? (c[(c[q >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) ? (c[(c[q >> 2] | 0) + 32 >> 2] | 0) == 0 : 0) {
	                    c[(c[p >> 2] | 0) + 20 >> 2] = 0;
	                    c[(c[p >> 2] | 0) + 16 >> 2] = 0;
	                    c[(c[p >> 2] | 0) + 48 >> 2] = c[(c[q >> 2] | 0) + 20 >> 2];
	                    c[o >> 2] = GB(c[p >> 2] | 0, c[k >> 2] | 0, c[q >> 2] | 0) | 0;
	                    if ((c[o >> 2] | 0) == -1) {
	                        c[(c[p >> 2] | 0) + 48 >> 2] = 0;
	                        c[(c[p >> 2] | 0) + 48 >> 2] = 0;
	                        c[h >> 2] = -1;
	                        r = c[h >> 2] | 0;
	                        i = g;
	                        return r | 0
	                    }
	                    if ((c[o >> 2] | 0) == 0 ? (c[(c[p >> 2] | 0) + 20 >> 2] | 0) != 0 : 0)c[o >> 2] = c[(c[p >> 2] | 0) + 16 >> 2];
	                    k = c[p >> 2] | 0;
	                    if (!(c[(c[p >> 2] | 0) + 20 >> 2] | 0)) {
	                        HB(k, c[q >> 2] | 0) | 0;
	                        c[o >> 2] = c[(c[p >> 2] | 0) + 16 >> 2];
	                        if ((c[o >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 52 >> 2] | 0) == 0 : 0)c[(c[j >> 2] | 0) + 52 >> 2] = c[o >> 2];
	                        q = (c[j >> 2] | 0) + 56 | 0;
	                        c[q >> 2] = (c[q >> 2] | 0) + (c[(c[p >> 2] | 0) + 20 >> 2] | 0)
	                    } else {
	                        q = (c[j >> 2] | 0) + 56 | 0;
	                        c[q >> 2] = (c[q >> 2] | 0) + (c[k + 20 >> 2] | 0)
	                    }
	                    c[(c[p >> 2] | 0) + 48 >> 2] = 0;
	                    c[h >> 2] = c[o >> 2];
	                    r = c[h >> 2] | 0;
	                    i = g;
	                    return r | 0
	                }
	                c[h >> 2] = 0;
	                r = c[h >> 2] | 0;
	                i = g;
	                return r | 0
	            }

	            function TG(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f + 40 | 0;
	                h = f + 36 | 0;
	                j = f + 32 | 0;
	                k = f + 28 | 0;
	                l = f + 24 | 0;
	                m = f + 20 | 0;
	                n = f + 16 | 0;
	                o = f + 12 | 0;
	                p = f + 8 | 0;
	                q = f + 4 | 0;
	                r = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[g >> 2] = -1;
	                    s = c[g >> 2] | 0;
	                    i = f;
	                    return s | 0
	                }
	                c[c[k >> 2] >> 2] = 0;
	                if (!(c[j >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    s = c[g >> 2] | 0;
	                    i = f;
	                    return s | 0
	                }
	                c[n >> 2] = 0;
	                c[o >> 2] = 0;
	                c[(c[h >> 2] | 0) + 108 >> 2] = c[j >> 2];
	                c[m >> 2] = zH(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 20 >> 2] | 0, n, o) | 0;
	                do if (c[m >> 2] | 0) {
	                    if ((c[m >> 2] | 0) < 0) {
	                        xB(c[h >> 2] | 0, 146768, 146808);
	                        c[(c[h >> 2] | 0) + 108 >> 2] = c[(c[(c[h >> 2] | 0) + 100 >> 2] | 0) + (c[(c[h >> 2] | 0) + 96 >> 2] << 2) >> 2];
	                        c[g >> 2] = -1;
	                        s = c[g >> 2] | 0;
	                        i = f;
	                        return s | 0
	                    }
	                } else {
	                    j = wE(c[(c[h >> 2] | 0) + 20 >> 2] | 0, c[o >> 2] | 0, c[n >> 2] | 0) | 0;
	                    c[c[k >> 2] >> 2] = j;
	                    if (!(c[c[k >> 2] >> 2] | 0)) {
	                        c[p >> 2] = 0;
	                        j = c[h >> 2] | 0;
	                        e = IH(21) | 0;
	                        AB(j, 1851, 0, e, 146880, BB(p, c[n >> 2] | 0, c[o >> 2] | 0) | 0, 0);
	                        if (c[p >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                            c[p >> 2] = 0
	                        }
	                        c[m >> 2] = c[(c[h >> 2] | 0) + 52 >> 2];
	                        break
	                    }
	                    if (c[l >> 2] | 0) {
	                        c[q >> 2] = 0;
	                        if (!((c[(c[l >> 2] | 0) + 48 >> 2] & 2048 | 0) == 0 ? (c[(c[(c[l >> 2] | 0) + 28 >> 2] | 0) + 48 >> 2] & 262144 | 0) == 0 : 0))c[q >> 2] = c[q >> 2] | 2;
	                        if (!((c[(c[l >> 2] | 0) + 48 >> 2] & 4096 | 0) == 0 ? (c[(c[(c[l >> 2] | 0) + 28 >> 2] | 0) + 48 >> 2] & 524288 | 0) == 0 : 0))c[q >> 2] = c[q >> 2] | 1;
	                        if (MG(c[h >> 2] | 0, c[c[k >> 2] >> 2] | 0, c[(c[l >> 2] | 0) + 28 >> 2] | 0, c[q >> 2] | 0) | 0) {
	                            c[r >> 2] = 0;
	                            e = c[h >> 2] | 0;
	                            AB(e, 1852, 0, 0, 146968, BB(r, c[(c[c[k >> 2] >> 2] | 0) + 112 >> 2] | 0, c[(c[c[k >> 2] >> 2] | 0) + 8 >> 2] | 0) | 0, 0);
	                            if (c[r >> 2] | 0) {
	                                zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                                c[r >> 2] = 0
	                            }
	                            c[m >> 2] = c[(c[h >> 2] | 0) + 52 >> 2];
	                            c[c[k >> 2] >> 2] = 0
	                        }
	                    }
	                } while (0);
	                c[(c[h >> 2] | 0) + 108 >> 2] = c[(c[(c[h >> 2] | 0) + 100 >> 2] | 0) + (c[(c[h >> 2] | 0) + 96 >> 2] << 2) >> 2];
	                c[g >> 2] = c[m >> 2];
	                s = c[g >> 2] | 0;
	                i = f;
	                return s | 0
	            }

	            function UG(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 28 | 0;
	                f = d + 24 | 0;
	                g = d + 20 | 0;
	                h = d + 16 | 0;
	                j = d + 12 | 0;
	                k = d + 8 | 0;
	                l = d + 4 | 0;
	                m = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[j >> 2] = 0;
	                c[k >> 2] = c[(c[g >> 2] | 0) + 100 >> 2];
	                if (!(c[k >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                if (c[(c[(c[f >> 2] | 0) + 108 >> 2] | 0) + 56 >> 2] | 0) {
	                    xB(c[f >> 2] | 0, 146584, 146616);
	                    c[e >> 2] = -1;
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                a:while (1) {
	                    do if ((c[c[k >> 2] >> 2] | 0) == 24 ? (c[l >> 2] = c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2], (c[l >> 2] | 0) != 0) : 0) {
	                        c[(c[(c[f >> 2] | 0) + 108 >> 2] | 0) + 76 >> 2] = 1;
	                        c[m >> 2] = c[(c[f >> 2] | 0) + 112 >> 2];
	                        while (1) {
	                            if (!(c[m >> 2] | 0))break;
	                            if ((c[(c[m >> 2] | 0) + 4 >> 2] | 0) == (c[l >> 2] | 0))break;
	                            c[m >> 2] = c[c[m >> 2] >> 2]
	                        }
	                        if (!(c[m >> 2] | 0)) {
	                            o = 12;
	                            break a
	                        }
	                        if ((c[(c[m >> 2] | 0) + 8 >> 2] | 0) != -1 ? (c[(c[f >> 2] | 0) + 96 >> 2] | 0) >= (c[(c[m >> 2] | 0) + 8 >> 2] | 0) : 0)break;
	                        c[(c[m >> 2] | 0) + 8 >> 2] = c[(c[f >> 2] | 0) + 96 >> 2]
	                    } while (0);
	                    c[m >> 2] = c[(c[f >> 2] | 0) + 112 >> 2];
	                    while (1) {
	                        if (!(c[m >> 2] | 0))break;
	                        if ((c[(c[m >> 2] | 0) + 4 >> 2] | 0) == (c[k >> 2] | 0))break;
	                        c[m >> 2] = c[c[m >> 2] >> 2]
	                    }
	                    p = c[f >> 2] | 0;
	                    if (!(c[m >> 2] | 0)) {
	                        o = 21;
	                        break
	                    }
	                    if (c[p + 124 >> 2] | 0) {
	                        c[h >> 2] = c[(c[f >> 2] | 0) + 124 >> 2];
	                        c[(c[f >> 2] | 0) + 124 >> 2] = c[(c[h >> 2] | 0) + 12 >> 2];
	                        c[(c[h >> 2] | 0) + 12 >> 2] = 0
	                    } else {
	                        c[h >> 2] = Cb[c[135744 >> 2] & 511](36) | 0;
	                        if (!(c[h >> 2] | 0)) {
	                            o = 25;
	                            break
	                        }
	                        g = (c[h >> 2] | 0) + 0 | 0;
	                        b = g + 36 | 0;
	                        do {
	                            c[g >> 2] = 0;
	                            g = g + 4 | 0
	                        } while ((g | 0) < (b | 0))
	                    }
	                    g = c[h >> 2] | 0;
	                    if (!(c[j >> 2] | 0))c[(c[(c[f >> 2] | 0) + 108 >> 2] | 0) + 56 >> 2] = g; else c[(c[j >> 2] | 0) + 8 >> 2] = g;
	                    c[j >> 2] = c[h >> 2];
	                    c[c[h >> 2] >> 2] = 0;
	                    c[(c[h >> 2] | 0) + 4 >> 2] = c[(c[f >> 2] | 0) + 96 >> 2];
	                    c[(c[h >> 2] | 0) + 16 >> 2] = c[m >> 2];
	                    c[(c[h >> 2] | 0) + 20 >> 2] = c[c[(c[m >> 2] | 0) + 4 >> 2] >> 2];
	                    if ((VG(c[f >> 2] | 0, c[h >> 2] | 0, c[(c[k >> 2] | 0) + 24 >> 2] | 0, 1) | 0) == -1) {
	                        o = 31;
	                        break
	                    }
	                    c[k >> 2] = c[(c[k >> 2] | 0) + 8 >> 2];
	                    if (!(c[k >> 2] | 0)) {
	                        o = 33;
	                        break
	                    }
	                }
	                if ((o | 0) == 12) {
	                    xB(c[f >> 2] | 0, 146584, 146672);
	                    c[e >> 2] = -1;
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                } else if ((o | 0) == 21) {
	                    xB(p, 146584, 146672);
	                    c[e >> 2] = -1;
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                } else if ((o | 0) == 25) {
	                    IB(c[f >> 2] | 0, 146736, 0);
	                    c[e >> 2] = -1;
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                } else if ((o | 0) == 31) {
	                    c[e >> 2] = -1;
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                } else if ((o | 0) == 33) {
	                    c[e >> 2] = 0;
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                return 0
	            }

	            function VG(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                do if (c[(c[h >> 2] | 0) + 120 >> 2] | 0) {
	                    c[m >> 2] = c[(c[h >> 2] | 0) + 120 >> 2];
	                    c[(c[h >> 2] | 0) + 120 >> 2] = c[(c[m >> 2] | 0) + 4 >> 2];
	                    c[(c[m >> 2] | 0) + 4 >> 2] = 0
	                } else {
	                    c[m >> 2] = Cb[c[135744 >> 2] & 511](36) | 0;
	                    if (c[m >> 2] | 0) {
	                        e = (c[m >> 2] | 0) + 0 | 0;
	                        d = e + 36 | 0;
	                        do {
	                            c[e >> 2] = 0;
	                            e = e + 4 | 0
	                        } while ((e | 0) < (d | 0));
	                        break
	                    }
	                    IB(0, 146088, 0);
	                    c[g >> 2] = -1;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                } while (0);
	                if (c[(c[h >> 2] | 0) + 116 >> 2] | 0)c[(c[m >> 2] | 0) + 4 >> 2] = c[(c[h >> 2] | 0) + 116 >> 2];
	                c[(c[h >> 2] | 0) + 116 >> 2] = c[m >> 2];
	                if (c[(c[m >> 2] | 0) + 32 >> 2] | 0)GQ(c[(c[m >> 2] | 0) + 32 >> 2] | 0);
	                e = OQ(c[(c[k >> 2] | 0) + 16 >> 2] | 0) | 0;
	                c[(c[m >> 2] | 0) + 32 >> 2] = e;
	                if (!(c[(c[m >> 2] | 0) + 32 >> 2] | 0)) {
	                    xB(c[h >> 2] | 0, 146120, 146152);
	                    c[g >> 2] = -1;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                } else {
	                    c[c[m >> 2] >> 2] = c[l >> 2];
	                    c[(c[m >> 2] | 0) + 8 >> 2] = c[(c[h >> 2] | 0) + 96 >> 2];
	                    c[(c[m >> 2] | 0) + 24 >> 2] = c[j >> 2];
	                    c[(c[m >> 2] | 0) + 28 >> 2] = c[k >> 2];
	                    c[(c[m >> 2] | 0) + 16 >> 2] = 0;
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                return 0
	            }

	            function WG(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                if (!(c[(c[e >> 2] | 0) + 116 >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                c[f >> 2] = c[(c[e >> 2] | 0) + 116 >> 2];
	                while (1) {
	                    c[g >> 2] = KQ(c[(c[f >> 2] | 0) + 32 >> 2] | 0) | 0;
	                    if ((c[g >> 2] | 0) == -1) {
	                        j = 5;
	                        break
	                    }
	                    c[f >> 2] = c[(c[f >> 2] | 0) + 4 >> 2];
	                    if (!(c[f >> 2] | 0)) {
	                        j = 7;
	                        break
	                    }
	                }
	                if ((j | 0) == 5) {
	                    c[d >> 2] = -1;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                } else if ((j | 0) == 7) {
	                    c[d >> 2] = 0;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                return 0
	            }

	            function XG(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[l >> 2] = 0;
	                c[m >> 2] = 0;
	                HC(l, c[g >> 2] | 0, c[k >> 2] | 0) | 0;
	                c[l >> 2] = By(c[l >> 2] | 0, 145232) | 0;
	                e = c[g >> 2] | 0;
	                g = c[h >> 2] | 0;
	                h = c[k >> 2] | 0;
	                d = c[l >> 2] | 0;
	                PD(e, g, h, d, AH(m, c[j >> 2] | 0, c[k >> 2] | 0) | 0, 0);
	                if (c[m >> 2] | 0) {
	                    zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                    c[m >> 2] = 0
	                }
	                if (!(c[l >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                c[l >> 2] = 0;
	                i = f;
	                return
	            }

	            function YG(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                b = ZD(c[e >> 2] | 0, c[f >> 2] | 0) | 0;
	                i = d;
	                return b | 0
	            }

	            function ZG(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                do if (c[(c[f >> 2] | 0) + 140 >> 2] | 0) {
	                    if ((c[(c[f >> 2] | 0) + 148 >> 2] | 0) <= (c[(c[f >> 2] | 0) + 144 >> 2] | 0) ? (b = (c[f >> 2] | 0) + 148 | 0, c[b >> 2] = c[b >> 2] << 1, b = Hb[c[135760 >> 2] & 511](c[(c[f >> 2] | 0) + 140 >> 2] | 0, c[(c[f >> 2] | 0) + 148 >> 2] << 2) | 0, c[(c[f >> 2] | 0) + 140 >> 2] = b, (c[(c[f >> 2] | 0) + 140 >> 2] | 0) == 0) : 0) {
	                        IB(c[f >> 2] | 0, 143616, 0);
	                        c[e >> 2] = -1;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                } else {
	                    b = Cb[c[135744 >> 2] & 511](160) | 0;
	                    c[(c[f >> 2] | 0) + 140 >> 2] = b;
	                    b = c[f >> 2] | 0;
	                    if (c[(c[f >> 2] | 0) + 140 >> 2] | 0) {
	                        c[b + 148 >> 2] = 40;
	                        break
	                    }
	                    IB(b, 143576, 0);
	                    c[e >> 2] = -1;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                } while (0);
	                b = c[g >> 2] | 0;
	                g = (c[f >> 2] | 0) + 144 | 0;
	                a = c[g >> 2] | 0;
	                c[g >> 2] = a + 1;
	                c[(c[(c[f >> 2] | 0) + 140 >> 2] | 0) + (a << 2) >> 2] = b;
	                c[e >> 2] = 0;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function _G(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                c[d + 4 >> 2] = a;
	                c[e >> 2] = b;
	                if (!(c[(c[e >> 2] | 0) + 32 >> 2] | 0)) {
	                    b = JB() | 0;
	                    c[(c[e >> 2] | 0) + 32 >> 2] = b
	                }
	                i = d;
	                return c[(c[e >> 2] | 0) + 32 >> 2] | 0
	            }

	            function $G(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 24 | 0;
	                h = f + 20 | 0;
	                j = f + 16 | 0;
	                k = f + 12 | 0;
	                l = f + 8 | 0;
	                m = f + 4 | 0;
	                n = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[n >> 2] = 0;
	                e = my(142560) | 0;
	                c[c[h >> 2] >> 2] = e;
	                c[l >> 2] = 0;
	                while (1) {
	                    o = c[c[h >> 2] >> 2] | 0;
	                    if ((c[l >> 2] | 0) >= (c[k >> 2] | 0))break;
	                    e = By(o, 142568) | 0;
	                    c[c[h >> 2] >> 2] = e;
	                    e = c[(c[(c[j >> 2] | 0) + (c[l >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0;
	                    c[m >> 2] = gH(e, QD(c[c[(c[j >> 2] | 0) + (c[l >> 2] << 2) >> 2] >> 2] | 0) | 0, n) | 0;
	                    if (!(c[m >> 2] | 0)) {
	                        e = By(c[c[h >> 2] >> 2] | 0, c[n >> 2] | 0) | 0;
	                        c[c[h >> 2] >> 2] = e
	                    } else {
	                        xB(c[g >> 2] | 0, 142576, 142608);
	                        e = By(c[c[h >> 2] >> 2] | 0, 142648) | 0;
	                        c[c[h >> 2] >> 2] = e
	                    }
	                    e = c[c[h >> 2] >> 2] | 0;
	                    if ((c[l >> 2] | 0) < ((c[k >> 2] | 0) - 1 | 0)) {
	                        d = By(e, 142656) | 0;
	                        c[c[h >> 2] >> 2] = d
	                    } else {
	                        d = By(e, 142568) | 0;
	                        c[c[h >> 2] >> 2] = d
	                    }
	                    if (c[n >> 2] | 0) {
	                        zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                        c[n >> 2] = 0
	                    }
	                    c[l >> 2] = (c[l >> 2] | 0) + 1
	                }
	                l = By(o, 142664) | 0;
	                c[c[h >> 2] >> 2] = l;
	                i = f;
	                return c[c[h >> 2] >> 2] | 0
	            }

	            function aH(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                do if (c[(c[f >> 2] | 0) + 128 >> 2] | 0) {
	                    if ((c[(c[f >> 2] | 0) + 136 >> 2] | 0) <= (c[(c[f >> 2] | 0) + 132 >> 2] | 0) ? (b = (c[f >> 2] | 0) + 136 | 0, c[b >> 2] = c[b >> 2] << 1, b = Hb[c[135760 >> 2] & 511](c[(c[f >> 2] | 0) + 128 >> 2] | 0, c[(c[f >> 2] | 0) + 136 >> 2] << 2) | 0, c[(c[f >> 2] | 0) + 128 >> 2] = b, (c[(c[f >> 2] | 0) + 128 >> 2] | 0) == 0) : 0) {
	                        IB(c[f >> 2] | 0, 143528, 0);
	                        c[e >> 2] = -1;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                } else {
	                    b = Cb[c[135744 >> 2] & 511](80) | 0;
	                    c[(c[f >> 2] | 0) + 128 >> 2] = b;
	                    b = c[f >> 2] | 0;
	                    if (c[(c[f >> 2] | 0) + 128 >> 2] | 0) {
	                        c[b + 136 >> 2] = 20;
	                        break
	                    }
	                    IB(b, 143488, 0);
	                    c[e >> 2] = -1;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                } while (0);
	                b = c[g >> 2] | 0;
	                g = (c[f >> 2] | 0) + 132 | 0;
	                a = c[g >> 2] | 0;
	                c[g >> 2] = a + 1;
	                c[(c[(c[f >> 2] | 0) + 128 >> 2] | 0) + (a << 2) >> 2] = b;
	                c[e >> 2] = 0;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function bH(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[h >> 2] = AP(c[(c[g >> 2] | 0) + 156 >> 2] | 0, c[h >> 2] | 0, -1) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = -1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                if ((c[j >> 2] | 0) != 0 ? (c[j >> 2] = AP(c[(c[g >> 2] | 0) + 156 >> 2] | 0, c[j >> 2] | 0, -1) | 0, (c[j >> 2] | 0) == 0) : 0) {
	                    c[f >> 2] = -1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[k >> 2] = 0;
	                while (1) {
	                    if ((c[k >> 2] | 0) >= (c[(c[(c[g >> 2] | 0) + 180 >> 2] | 0) + 4 >> 2] | 0)) {
	                        m = 12;
	                        break
	                    }
	                    if ((c[(c[c[(c[g >> 2] | 0) + 180 >> 2] >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) == (c[h >> 2] | 0) ? (c[(c[c[(c[g >> 2] | 0) + 180 >> 2] >> 2] | 0) + ((c[k >> 2] | 0) + 1 << 2) >> 2] | 0) == (c[j >> 2] | 0) : 0) {
	                        m = 10;
	                        break
	                    }
	                    c[k >> 2] = (c[k >> 2] | 0) + 2
	                }
	                if ((m | 0) == 10) {
	                    c[f >> 2] = c[k >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } else if ((m | 0) == 12) {
	                    c[k >> 2] = c[(c[(c[g >> 2] | 0) + 180 >> 2] | 0) + 4 >> 2];
	                    bE(c[(c[g >> 2] | 0) + 180 >> 2] | 0, c[h >> 2] | 0) | 0;
	                    bE(c[(c[g >> 2] | 0) + 180 >> 2] | 0, c[j >> 2] | 0) | 0;
	                    c[f >> 2] = c[k >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                return 0
	            }

	            function cH(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = c[(c[(c[f >> 2] | 0) + 100 >> 2] | 0) + (c[(c[g >> 2] | 0) + 4 >> 2] << 2) >> 2];
	                if (!(c[(c[h >> 2] | 0) + 52 >> 2] | 0)) {
	                    f = fH(c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) | 0;
	                    c[(c[h >> 2] | 0) + 52 >> 2] = f;
	                    if (!(c[(c[h >> 2] | 0) + 52 >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        k = c[e >> 2] | 0;
	                        i = d;
	                        return k | 0
	                    } else {
	                        c[e >> 2] = c[(c[h >> 2] | 0) + 52 >> 2];
	                        k = c[e >> 2] | 0;
	                        i = d;
	                        return k | 0
	                    }
	                }
	                c[j >> 2] = 0;
	                c[j >> 2] = c[(c[h >> 2] | 0) + 52 >> 2];
	                while (1) {
	                    l = c[j >> 2] | 0;
	                    if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) == (c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0)) {
	                        m = 7;
	                        break
	                    }
	                    if (!(c[l >> 2] | 0)) {
	                        m = 9;
	                        break
	                    }
	                    c[j >> 2] = c[c[j >> 2] >> 2];
	                    if (!(c[j >> 2] | 0)) {
	                        m = 13;
	                        break
	                    }
	                }
	                if ((m | 0) == 7) {
	                    c[e >> 2] = l;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                } else if ((m | 0) == 9) {
	                    l = fH(c[(c[(c[g >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) | 0;
	                    c[c[j >> 2] >> 2] = l;
	                    if (!(c[c[j >> 2] >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        k = c[e >> 2] | 0;
	                        i = d;
	                        return k | 0
	                    } else {
	                        c[e >> 2] = c[c[j >> 2] >> 2];
	                        k = c[e >> 2] | 0;
	                        i = d;
	                        return k | 0
	                    }
	                } else if ((m | 0) == 13) {
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                return 0
	            }

	            function dH(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                b = (c[f >> 2] | 0) + 16 | 0;
	                if (!(c[(c[f >> 2] | 0) + 8 >> 2] | 0)) {
	                    c[b >> 2] = 10;
	                    a = Cb[c[135744 >> 2] & 511](40) | 0;
	                    c[(c[f >> 2] | 0) + 8 >> 2] = a;
	                    if (!(c[(c[f >> 2] | 0) + 8 >> 2] | 0)) {
	                        IB(0, 142256, 0);
	                        c[e >> 2] = -1;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                } else if ((c[b >> 2] | 0) <= (c[(c[f >> 2] | 0) + 12 >> 2] | 0) ? (b = (c[f >> 2] | 0) + 16 | 0, c[b >> 2] = c[b >> 2] << 1, b = Hb[c[135760 >> 2] & 511](c[(c[f >> 2] | 0) + 8 >> 2] | 0, c[(c[f >> 2] | 0) + 16 >> 2] << 2) | 0, c[(c[f >> 2] | 0) + 8 >> 2] = b, (c[(c[f >> 2] | 0) + 8 >> 2] | 0) == 0) : 0) {
	                    IB(0, 142712, 0);
	                    c[e >> 2] = -1;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                b = c[g >> 2] | 0;
	                g = (c[f >> 2] | 0) + 12 | 0;
	                a = c[g >> 2] | 0;
	                c[g >> 2] = a + 1;
	                c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + (a << 2) >> 2] = b;
	                c[e >> 2] = 0;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function eH(a, b, d, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                j = i;
	                i = i + 48 | 0;
	                k = j + 32 | 0;
	                l = j + 28 | 0;
	                m = j + 24 | 0;
	                n = j + 16 | 0;
	                o = j + 12 | 0;
	                p = j + 8 | 0;
	                q = j + 4 | 0;
	                r = j;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[j + 20 >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                c[p >> 2] = h;
	                c[q >> 2] = 0;
	                c[r >> 2] = 0;
	                c[q >> 2] = my(142688) | 0;
	                c[q >> 2] = By(c[q >> 2] | 0, c[n >> 2] | 0) | 0;
	                c[q >> 2] = By(c[q >> 2] | 0, 142704) | 0;
	                n = c[k >> 2] | 0;
	                h = c[l >> 2] | 0;
	                l = c[(c[m >> 2] | 0) + 8 >> 2] | 0;
	                g = c[q >> 2] | 0;
	                f = BB(r, c[(c[c[(c[k >> 2] | 0) + 180 >> 2] >> 2] | 0) + ((c[(c[m >> 2] | 0) + 12 >> 2] | 0) + 1 << 2) >> 2] | 0, c[(c[c[(c[k >> 2] | 0) + 180 >> 2] >> 2] | 0) + (c[(c[m >> 2] | 0) + 12 >> 2] << 2) >> 2] | 0) | 0;
	                $D(n, 2, h, 0, l, g, f, c[o >> 2] | 0, c[p >> 2] | 0, 0);
	                if (c[r >> 2] | 0) {
	                    zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                    c[r >> 2] = 0
	                }
	                if (!(c[q >> 2] | 0)) {
	                    i = j;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                c[q >> 2] = 0;
	                i = j;
	                return
	            }

	            function fH(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](24) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    IB(0, 142304, 0);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    a = c[f >> 2] | 0;
	                    c[a + 0 >> 2] = 0;
	                    c[a + 4 >> 2] = 0;
	                    c[a + 8 >> 2] = 0;
	                    c[a + 12 >> 2] = 0;
	                    c[a + 16 >> 2] = 0;
	                    c[a + 20 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 4 >> 2] = c[e >> 2];
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function gH(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 28 | 0;
	                g = e + 24 | 0;
	                h = e + 20 | 0;
	                j = e + 16 | 0;
	                k = e + 12 | 0;
	                l = e + 8 | 0;
	                m = e + 4 | 0;
	                n = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[n >> 2] = 0;
	                if ((c[j >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[f >> 2] = -1;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                d = (KH(c[g >> 2] | 0) | 0) != 0;
	                c[k >> 2] = d ? 1 : 0;
	                c[c[j >> 2] >> 2] = 0;
	                while (1) {
	                    c[m >> 2] = 0;
	                    c[l >> 2] = dI(c[g >> 2] | 0) | 0;
	                    d = c[l >> 2] | 0;
	                    if ((d | 0) == 46 | (d | 0) == 2 | (d | 0) == 1) {
	                        c[m >> 2] = LH(c[g >> 2] | 0) | 0;
	                        if (c[m >> 2] | 0) {
	                            if ((c[h >> 2] | 0) != 3) {
	                                if ((c[h >> 2] | 0) == 2)c[n >> 2] = RH(c[m >> 2] | 0) | 0
	                            } else c[n >> 2] = SH(c[m >> 2] | 0) | 0;
	                            if (c[n >> 2] | 0)c[m >> 2] = c[n >> 2]
	                        }
	                    } else {
	                        d = (cI(c[g >> 2] | 0, n) | 0) == -1;
	                        p = c[n >> 2] | 0;
	                        if (d)break;
	                        c[m >> 2] = p
	                    }
	                    d = c[m >> 2] | 0;
	                    do if (!(c[c[j >> 2] >> 2] | 0)) {
	                        if (d) {
	                            b = my(c[m >> 2] | 0) | 0;
	                            c[c[j >> 2] >> 2] = b;
	                            break
	                        }
	                        if (!(c[k >> 2] | 0)) {
	                            b = my(142672) | 0;
	                            c[c[j >> 2] >> 2] = b
	                        }
	                    } else if (d) {
	                        b = By(c[c[j >> 2] >> 2] | 0, 142680) | 0;
	                        c[c[j >> 2] >> 2] = b;
	                        b = By(c[c[j >> 2] >> 2] | 0, c[m >> 2] | 0) | 0;
	                        c[c[j >> 2] >> 2] = b
	                    } while (0);
	                    if (c[n >> 2] | 0) {
	                        zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                        c[n >> 2] = 0
	                    }
	                    c[g >> 2] = KH(c[g >> 2] | 0) | 0;
	                    if (!(c[g >> 2] | 0)) {
	                        q = 26;
	                        break
	                    }
	                }
	                if ((q | 0) == 26) {
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                if (p)zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                if (c[c[j >> 2] >> 2] | 0)zb[c[135736 >> 2] & 511](c[c[j >> 2] >> 2] | 0);
	                if (c[n >> 2] | 0)zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                c[f >> 2] = -1;
	                o = c[f >> 2] | 0;
	                i = e;
	                return o | 0
	            }

	            function hH(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = _i(c[d >> 2] | 0) | 0;
	                i = b;
	                return a | 0
	            }

	            function iH(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                d = c[g >> 2] | 0;
	                if (c[h >> 2] | 0) {
	                    c[f >> 2] = BB(d, c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[j >> 2] | 0) | 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                } else {
	                    c[f >> 2] = BB(d, 0, c[j >> 2] | 0) | 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                return 0
	            }

	            function jH(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                g = i;
	                i = i + 48 | 0;
	                h = g + 32 | 0;
	                j = g + 28 | 0;
	                k = g + 24 | 0;
	                l = g + 20 | 0;
	                m = g + 16 | 0;
	                n = g + 12 | 0;
	                o = g + 8 | 0;
	                p = g + 4 | 0;
	                q = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                if ((c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0 | (c[m >> 2] | 0) == 0) {
	                    c[h >> 2] = -1;
	                    r = c[h >> 2] | 0;
	                    i = g;
	                    return r | 0
	                }
	                c[c[m >> 2] >> 2] = 0;
	                c[o >> 2] = c[(c[l >> 2] | 0) + 44 >> 2];
	                while (1) {
	                    if (!(c[o >> 2] | 0))break;
	                    k = c[o >> 2] | 0;
	                    if (!(c[(c[o >> 2] | 0) + 36 >> 2] | 0)) {
	                        if ((qy(c[k + 8 >> 2] | 0, 161384) | 0) == 0 ? (qy(c[(c[o >> 2] | 0) + 8 >> 2] | 0, 155456) | 0) == 0 : 0)GF(c[j >> 2] | 0, 3035, 0, c[o >> 2] | 0)
	                    } else if (qy(c[(c[k + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)GF(c[j >> 2] | 0, 3035, 0, c[o >> 2] | 0);
	                    c[o >> 2] = c[(c[o >> 2] | 0) + 24 >> 2]
	                }
	                cE(c[j >> 2] | 0, c[l >> 2] | 0, 161384) | 0;
	                c[o >> 2] = dE(c[l >> 2] | 0, 155456) | 0;
	                do if (c[o >> 2] | 0) {
	                    c[p >> 2] = 0;
	                    c[q >> 2] = 0;
	                    k = c[j >> 2] | 0;
	                    f = c[o >> 2] | 0;
	                    e = IH(29) | 0;
	                    if (!(eE(k, 0, f, e, c[m >> 2] | 0) | 0)) {
	                        c[p >> 2] = Xi(c[(c[l >> 2] | 0) + 32 >> 2] | 0, c[l >> 2] | 0) | 0;
	                        e = c[c[m >> 2] >> 2] | 0;
	                        if (!(c[p >> 2] | 0))c[q >> 2] = Hl(e, c[(c[(c[l >> 2] | 0) + 32 >> 2] | 0) + 72 >> 2] | 0) | 0; else {
	                            c[q >> 2] = Hl(e, c[p >> 2] | 0) | 0;
	                            zb[c[135736 >> 2] & 511](c[p >> 2] | 0)
	                        }
	                        e = c[j >> 2] | 0;
	                        if (!(c[q >> 2] | 0)) {
	                            xB(e, 168224, 168256);
	                            c[h >> 2] = -1;
	                            r = c[h >> 2] | 0;
	                            i = g;
	                            return r | 0
	                        }
	                        f = AP(c[e + 80 >> 2] | 0, c[q >> 2] | 0, -1) | 0;
	                        c[c[m >> 2] >> 2] = f;
	                        zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                        if (!(qy(c[c[m >> 2] >> 2] | 0, c[(c[j >> 2] | 0) + 44 >> 2] | 0) | 0)) {
	                            c[h >> 2] = 0;
	                            r = c[h >> 2] | 0;
	                            i = g;
	                            return r | 0
	                        }
	                        f = c[j >> 2] | 0;
	                        e = c[l >> 2] | 0;
	                        k = c[c[m >> 2] >> 2] | 0;
	                        if ((c[n >> 2] | 0) == 3) {
	                            GE(f, 3081, 0, e, 168304, k);
	                            break
	                        } else {
	                            GE(f, 3050, 0, e, 168360, k);
	                            break
	                        }
	                    }
	                } else MF(c[j >> 2] | 0, 3036, 0, c[l >> 2] | 0, 155456, 0); while (0);
	                c[h >> 2] = c[(c[j >> 2] | 0) + 16 >> 2];
	                r = c[h >> 2] | 0;
	                i = g;
	                return r | 0
	            }

	            function kH(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0;
	                d = i;
	                i = i + 96 | 0;
	                e = d + 88 | 0;
	                f = d + 84 | 0;
	                g = d + 80 | 0;
	                h = d + 76 | 0;
	                j = d + 72 | 0;
	                k = d + 68 | 0;
	                l = d + 64 | 0;
	                m = d + 60 | 0;
	                n = d + 56 | 0;
	                o = d + 52 | 0;
	                p = d + 48 | 0;
	                q = d + 44 | 0;
	                r = d + 40 | 0;
	                s = d + 36 | 0;
	                t = d + 32 | 0;
	                u = d + 28 | 0;
	                v = d + 24 | 0;
	                w = d + 20 | 0;
	                x = d + 16 | 0;
	                y = d + 12 | 0;
	                z = d + 8 | 0;
	                A = d + 4 | 0;
	                B = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = 0;
	                    C = c[e >> 2] | 0;
	                    i = d;
	                    return C | 0
	                }
	                do switch (c[c[f >> 2] >> 2] | 0) {
	                    case 16:
	                    {
	                        c[q >> 2] = c[f >> 2];
	                        c[r >> 2] = c[(c[q >> 2] | 0) + 24 >> 2];
	                        if (!(c[(c[q >> 2] | 0) + 24 >> 2] | 0)) {
	                            c[(c[q >> 2] | 0) + 24 >> 2] = c[g >> 2];
	                            c[e >> 2] = c[g >> 2];
	                            C = c[e >> 2] | 0;
	                            i = d;
	                            return C | 0
	                        }
	                        c[r >> 2] = c[(c[q >> 2] | 0) + 24 >> 2];
	                        if (c[c[r >> 2] >> 2] | 0)c[r >> 2] = c[c[r >> 2] >> 2];
	                        c[c[r >> 2] >> 2] = c[g >> 2];
	                        break
	                    }
	                    case 2:
	                    case 21:
	                    {
	                        c[m >> 2] = c[f >> 2];
	                        c[n >> 2] = c[(c[m >> 2] | 0) + 8 >> 2];
	                        if (!(c[(c[m >> 2] | 0) + 8 >> 2] | 0)) {
	                            c[(c[m >> 2] | 0) + 8 >> 2] = c[g >> 2];
	                            c[e >> 2] = c[g >> 2];
	                            C = c[e >> 2] | 0;
	                            i = d;
	                            return C | 0
	                        }
	                        c[n >> 2] = c[(c[m >> 2] | 0) + 8 >> 2];
	                        if (c[c[n >> 2] >> 2] | 0)c[n >> 2] = c[c[n >> 2] >> 2];
	                        c[c[n >> 2] >> 2] = c[g >> 2];
	                        break
	                    }
	                    case 18:
	                    {
	                        c[s >> 2] = c[f >> 2];
	                        c[t >> 2] = c[(c[s >> 2] | 0) + 8 >> 2];
	                        if (!(c[(c[s >> 2] | 0) + 8 >> 2] | 0)) {
	                            c[(c[s >> 2] | 0) + 8 >> 2] = c[g >> 2];
	                            c[e >> 2] = c[g >> 2];
	                            C = c[e >> 2] | 0;
	                            i = d;
	                            return C | 0
	                        }
	                        c[t >> 2] = c[(c[s >> 2] | 0) + 8 >> 2];
	                        if (c[c[t >> 2] >> 2] | 0)c[t >> 2] = c[c[t >> 2] >> 2];
	                        c[c[t >> 2] >> 2] = c[g >> 2];
	                        break
	                    }
	                    case 5:
	                    case 4:
	                    {
	                        c[w >> 2] = c[f >> 2];
	                        c[x >> 2] = c[(c[w >> 2] | 0) + 24 >> 2];
	                        if (!(c[(c[w >> 2] | 0) + 24 >> 2] | 0)) {
	                            c[(c[w >> 2] | 0) + 24 >> 2] = c[g >> 2];
	                            c[e >> 2] = c[g >> 2];
	                            C = c[e >> 2] | 0;
	                            i = d;
	                            return C | 0
	                        }
	                        c[x >> 2] = c[(c[w >> 2] | 0) + 24 >> 2];
	                        if (c[c[x >> 2] >> 2] | 0)c[x >> 2] = c[c[x >> 2] >> 2];
	                        c[c[x >> 2] >> 2] = c[g >> 2];
	                        break
	                    }
	                    case 1011:
	                    case 1010:
	                    case 1009:
	                    case 1008:
	                    case 1007:
	                    case 1006:
	                    case 1005:
	                    case 1004:
	                    case 1003:
	                    case 1002:
	                    case 1001:
	                    case 1e3:
	                    {
	                        c[u >> 2] = c[f >> 2];
	                        c[v >> 2] = c[(c[u >> 2] | 0) + 16 >> 2];
	                        if (!(c[(c[u >> 2] | 0) + 16 >> 2] | 0)) {
	                            c[(c[u >> 2] | 0) + 16 >> 2] = c[g >> 2];
	                            c[e >> 2] = c[g >> 2];
	                            C = c[e >> 2] | 0;
	                            i = d;
	                            return C | 0
	                        }
	                        c[v >> 2] = c[(c[u >> 2] | 0) + 16 >> 2];
	                        if (c[c[v >> 2] >> 2] | 0)c[v >> 2] = c[c[v >> 2] >> 2];
	                        c[c[v >> 2] >> 2] = c[g >> 2];
	                        break
	                    }
	                    case 17:
	                    {
	                        c[y >> 2] = c[f >> 2];
	                        c[z >> 2] = c[(c[y >> 2] | 0) + 4 >> 2];
	                        if (!(c[(c[y >> 2] | 0) + 4 >> 2] | 0)) {
	                            c[(c[y >> 2] | 0) + 4 >> 2] = c[g >> 2];
	                            c[e >> 2] = c[g >> 2];
	                            C = c[e >> 2] | 0;
	                            i = d;
	                            return C | 0
	                        }
	                        c[z >> 2] = c[(c[y >> 2] | 0) + 4 >> 2];
	                        if (c[c[z >> 2] >> 2] | 0)c[z >> 2] = c[c[z >> 2] >> 2];
	                        c[c[z >> 2] >> 2] = c[g >> 2];
	                        break
	                    }
	                    case 15:
	                    {
	                        c[k >> 2] = c[f >> 2];
	                        c[l >> 2] = c[(c[k >> 2] | 0) + 32 >> 2];
	                        if (!(c[(c[k >> 2] | 0) + 32 >> 2] | 0)) {
	                            c[(c[k >> 2] | 0) + 32 >> 2] = c[g >> 2];
	                            c[e >> 2] = c[g >> 2];
	                            C = c[e >> 2] | 0;
	                            i = d;
	                            return C | 0
	                        }
	                        c[l >> 2] = c[(c[k >> 2] | 0) + 32 >> 2];
	                        if (c[c[l >> 2] >> 2] | 0)c[l >> 2] = c[c[l >> 2] >> 2];
	                        c[c[l >> 2] >> 2] = c[g >> 2];
	                        break
	                    }
	                    case 22:
	                    case 24:
	                    case 23:
	                    case 25:
	                    {
	                        c[o >> 2] = c[f >> 2];
	                        c[p >> 2] = c[(c[o >> 2] | 0) + 4 >> 2];
	                        if (!(c[(c[o >> 2] | 0) + 4 >> 2] | 0)) {
	                            c[(c[o >> 2] | 0) + 4 >> 2] = c[g >> 2];
	                            c[e >> 2] = c[g >> 2];
	                            C = c[e >> 2] | 0;
	                            i = d;
	                            return C | 0
	                        }
	                        c[p >> 2] = c[(c[o >> 2] | 0) + 4 >> 2];
	                        if (c[c[p >> 2] >> 2] | 0)c[p >> 2] = c[c[p >> 2] >> 2];
	                        c[c[p >> 2] >> 2] = c[g >> 2];
	                        break
	                    }
	                    case 8:
	                    case 7:
	                    case 6:
	                    {
	                        c[A >> 2] = c[f >> 2];
	                        c[B >> 2] = c[(c[A >> 2] | 0) + 4 >> 2];
	                        if (!(c[(c[A >> 2] | 0) + 4 >> 2] | 0)) {
	                            c[(c[A >> 2] | 0) + 4 >> 2] = c[g >> 2];
	                            c[e >> 2] = c[g >> 2];
	                            C = c[e >> 2] | 0;
	                            i = d;
	                            return C | 0
	                        }
	                        c[B >> 2] = c[(c[A >> 2] | 0) + 4 >> 2];
	                        if (c[c[B >> 2] >> 2] | 0)c[B >> 2] = c[c[B >> 2] >> 2];
	                        c[c[B >> 2] >> 2] = c[g >> 2];
	                        break
	                    }
	                    case 14:
	                    {
	                        c[h >> 2] = c[f >> 2];
	                        c[j >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                        if (!(c[(c[h >> 2] | 0) + 24 >> 2] | 0)) {
	                            c[(c[h >> 2] | 0) + 24 >> 2] = c[g >> 2];
	                            c[e >> 2] = c[g >> 2];
	                            C = c[e >> 2] | 0;
	                            i = d;
	                            return C | 0
	                        }
	                        c[j >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                        if (c[c[j >> 2] >> 2] | 0)c[j >> 2] = c[c[j >> 2] >> 2];
	                        c[c[j >> 2] >> 2] = c[g >> 2];
	                        break
	                    }
	                    default:
	                        GE(0, 3069, 0, 0, 165080, 0)
	                } while (0);
	                c[e >> 2] = c[g >> 2];
	                C = c[e >> 2] | 0;
	                i = d;
	                return C | 0
	            }

	            function lH(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 28 | 0;
	                h = f + 24 | 0;
	                j = f + 20 | 0;
	                k = f + 16 | 0;
	                l = f + 12 | 0;
	                m = f + 8 | 0;
	                n = f + 4 | 0;
	                o = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[n >> 2] = 0;
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0) {
	                    c[g >> 2] = 0;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                c[m >> 2] = c[(c[h >> 2] | 0) + 84 >> 2];
	                e = (c[m >> 2] | 0) + 48 | 0;
	                c[e >> 2] = c[e >> 2] | 2;
	                c[o >> 2] = c[(c[k >> 2] | 0) + 44 >> 2];
	                while (1) {
	                    if (!(c[o >> 2] | 0))break;
	                    e = c[o >> 2] | 0;
	                    if (!(c[(c[o >> 2] | 0) + 36 >> 2] | 0)) {
	                        if ((qy(c[e + 8 >> 2] | 0, 161384) | 0) == 0 ? (qy(c[(c[o >> 2] | 0) + 8 >> 2] | 0, 151424) | 0) == 0 : 0)GF(c[h >> 2] | 0, 3035, 0, c[o >> 2] | 0)
	                    } else if (qy(c[(c[e + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)GF(c[h >> 2] | 0, 3035, 0, c[o >> 2] | 0);
	                    c[o >> 2] = c[(c[o >> 2] | 0) + 24 >> 2]
	                }
	                cE(c[h >> 2] | 0, c[k >> 2] | 0, 161384) | 0;
	                if ((fG(c[h >> 2] | 0, c[j >> 2] | 0, 0, c[k >> 2] | 0, 151424, (c[m >> 2] | 0) + 60 | 0, (c[m >> 2] | 0) + 56 | 0) | 0) == 0 ? (c[(c[m >> 2] | 0) + 56 >> 2] | 0) == 0 : 0)MF(c[h >> 2] | 0, 3036, 0, c[k >> 2] | 0, 151424, 0);
	                c[n >> 2] = c[(c[k >> 2] | 0) + 12 >> 2];
	                if ((((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 160992) | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    o = c[m >> 2] | 0;
	                    kH(o, jE(c[h >> 2] | 0, c[n >> 2] | 0, 1) | 0) | 0;
	                    c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2]
	                }
	                do if ((c[l >> 2] | 0) == 10) {
	                    if ((((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 161648) | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        o = QF(c[h >> 2] | 0, c[j >> 2] | 0, c[n >> 2] | 0, 8, 1) | 0;
	                        c[(c[m >> 2] | 0) + 28 >> 2] = o;
	                        c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2];
	                        break
	                    }
	                    if ((((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 161656) | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        o = QF(c[h >> 2] | 0, c[j >> 2] | 0, c[n >> 2] | 0, 7, 1) | 0;
	                        c[(c[m >> 2] | 0) + 28 >> 2] = o;
	                        c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2];
	                        break
	                    }
	                    if ((((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 161664) | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        o = QF(c[h >> 2] | 0, c[j >> 2] | 0, c[n >> 2] | 0, 6, 1) | 0;
	                        c[(c[m >> 2] | 0) + 28 >> 2] = o;
	                        c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2];
	                        break
	                    }
	                    if ((((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 161080) | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        o = RF(c[h >> 2] | 0, c[j >> 2] | 0, c[n >> 2] | 0) | 0;
	                        c[(c[m >> 2] | 0) + 28 >> 2] = o;
	                        c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2]
	                    }
	                } while (0);
	                if (c[n >> 2] | 0) {
	                    if ((SF(c[h >> 2] | 0, c[j >> 2] | 0, n, (c[m >> 2] | 0) + 116 | 0, 13, 0) | 0) == -1) {
	                        c[g >> 2] = 0;
	                        p = c[g >> 2] | 0;
	                        i = f;
	                        return p | 0
	                    }
	                    if ((((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 163328) | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        m = TF(c[h >> 2] | 0, c[j >> 2] | 0, c[n >> 2] | 0) | 0;
	                        c[(c[(c[h >> 2] | 0) + 84 >> 2] | 0) + 84 >> 2] = m;
	                        c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2]
	                    }
	                }
	                do if (c[n >> 2] | 0) {
	                    m = c[h >> 2] | 0;
	                    j = c[k >> 2] | 0;
	                    o = c[n >> 2] | 0;
	                    if ((c[l >> 2] | 0) == 10) {
	                        uE(m, 3033, 0, j, o, 0, 167440);
	                        break
	                    } else {
	                        uE(m, 3033, 0, j, o, 0, 163344);
	                        break
	                    }
	                } while (0);
	                c[g >> 2] = 0;
	                p = c[g >> 2] | 0;
	                i = f;
	                return p | 0
	            }

	            function mH(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 40 | 0;
	                g = e + 36 | 0;
	                h = e + 32 | 0;
	                j = e + 28 | 0;
	                k = e + 24 | 0;
	                l = e + 20 | 0;
	                m = e + 16 | 0;
	                n = e + 12 | 0;
	                o = e + 8 | 0;
	                p = e + 4 | 0;
	                q = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[l >> 2] = 0;
	                c[q >> 2] = 0;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                }
	                c[p >> 2] = c[(c[j >> 2] | 0) + 44 >> 2];
	                while (1) {
	                    if (!(c[p >> 2] | 0))break;
	                    d = c[p >> 2] | 0;
	                    if (!(c[(c[p >> 2] | 0) + 36 >> 2] | 0)) {
	                        if (((((qy(c[d + 8 >> 2] | 0, 161384) | 0) == 0 ? (qy(c[(c[p >> 2] | 0) + 8 >> 2] | 0, 161824) | 0) == 0 : 0) ? (qy(c[(c[p >> 2] | 0) + 8 >> 2] | 0, 161808) | 0) == 0 : 0) ? (qy(c[(c[p >> 2] | 0) + 8 >> 2] | 0, 162304) | 0) == 0 : 0) ? (qy(c[(c[p >> 2] | 0) + 8 >> 2] | 0, 162320) | 0) == 0 : 0)GF(c[g >> 2] | 0, 3035, 0, c[p >> 2] | 0)
	                    } else if (qy(c[(c[d + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)GF(c[g >> 2] | 0, 3035, 0, c[p >> 2] | 0);
	                    c[p >> 2] = c[(c[p >> 2] | 0) + 24 >> 2]
	                }
	                cE(c[g >> 2] | 0, c[j >> 2] | 0, 161384) | 0;
	                c[o >> 2] = YF(c[g >> 2] | 0, c[j >> 2] | 0, 0, 1073741824, 1, 161768) | 0;
	                c[n >> 2] = XF(c[g >> 2] | 0, c[j >> 2] | 0, 0, -1, 1, 161744) | 0;
	                ZF(c[g >> 2] | 0, 0, c[j >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0) | 0;
	                c[m >> 2] = qG(c[g >> 2] | 0, c[h >> 2] | 0, 2, c[j >> 2] | 0) | 0;
	                if (!(c[m >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                }
	                pH(c[g >> 2] | 0, c[h >> 2] | 0, c[m >> 2] | 0, c[j >> 2] | 0) | 0;
	                c[l >> 2] = c[(c[j >> 2] | 0) + 12 >> 2];
	                if ((((c[l >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[l >> 2] | 0) + 8 >> 2] | 0, 160992) | 0) != 0 : 0) ? (qy(c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    c[q >> 2] = jE(c[g >> 2] | 0, c[l >> 2] | 0, 1) | 0;
	                    c[l >> 2] = c[(c[l >> 2] | 0) + 24 >> 2]
	                }
	                if (c[l >> 2] | 0)uE(c[g >> 2] | 0, 3033, 0, c[j >> 2] | 0, c[l >> 2] | 0, 0, 161392);
	                if ((c[n >> 2] | 0) == 0 & (c[o >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                }
	                c[k >> 2] = XE(c[g >> 2] | 0, c[j >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                } else {
	                    c[(c[k >> 2] | 0) + 4 >> 2] = c[q >> 2];
	                    c[(c[k >> 2] | 0) + 12 >> 2] = c[m >> 2];
	                    c[f >> 2] = c[k >> 2];
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                }
	                return 0
	            }

	            function nH(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0;
	                g = i;
	                i = i + 112 | 0;
	                h = g + 96 | 0;
	                j = g + 92 | 0;
	                k = g + 88 | 0;
	                l = g + 84 | 0;
	                m = g + 80 | 0;
	                n = g + 76 | 0;
	                o = g + 72 | 0;
	                p = g + 68 | 0;
	                q = g + 64 | 0;
	                r = g + 60 | 0;
	                s = g + 56 | 0;
	                t = g + 52 | 0;
	                u = g + 48 | 0;
	                v = g + 44 | 0;
	                w = g + 40 | 0;
	                x = g + 36 | 0;
	                y = g + 32 | 0;
	                z = g + 28 | 0;
	                A = g + 24 | 0;
	                B = g + 20 | 0;
	                C = g + 16 | 0;
	                D = g + 12 | 0;
	                E = g + 8 | 0;
	                F = g + 4 | 0;
	                G = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[p >> 2] = 0;
	                c[q >> 2] = 0;
	                c[r >> 2] = 0;
	                c[s >> 2] = 0;
	                c[u >> 2] = 0;
	                c[v >> 2] = 0;
	                c[w >> 2] = 0;
	                c[x >> 2] = 0;
	                c[y >> 2] = 2;
	                c[A >> 2] = 0;
	                c[B >> 2] = 0;
	                if ((c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0) {
	                    c[h >> 2] = 0;
	                    H = c[h >> 2] | 0;
	                    i = g;
	                    return H | 0
	                }
	                c[t >> 2] = dE(c[l >> 2] | 0, 160064) | 0;
	                do if (c[t >> 2] | 0) {
	                    if (_F(c[j >> 2] | 0, c[k >> 2] | 0, 0, c[t >> 2] | 0, u, v) | 0) {
	                        c[h >> 2] = 0;
	                        H = c[h >> 2] | 0;
	                        i = g;
	                        return H | 0
	                    }
	                    if (!($F(c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[t >> 2] | 0, c[u >> 2] | 0) | 0)) {
	                        c[x >> 2] = 1;
	                        break
	                    }
	                    c[h >> 2] = 0;
	                    H = c[h >> 2] | 0;
	                    i = g;
	                    return H | 0
	                } while (0);
	                c[z >> 2] = c[(c[j >> 2] | 0) + 20 >> 2];
	                c[t >> 2] = c[(c[l >> 2] | 0) + 44 >> 2];
	                while (1) {
	                    if (!(c[t >> 2] | 0))break;
	                    a:do if (!(c[(c[t >> 2] | 0) + 36 >> 2] | 0)) {
	                        f = c[(c[t >> 2] | 0) + 8 >> 2] | 0;
	                        do if (c[x >> 2] | 0)if (!(qy(f, 161384) | 0))if (qy(c[(c[t >> 2] | 0) + 8 >> 2] | 0, 160064) | 0)break a; else break; else {
	                            CF(c[j >> 2] | 0, c[t >> 2] | 0) | 0;
	                            break a
	                        } else {
	                            if (qy(f, 161352) | 0)break a;
	                            if (qy(c[(c[t >> 2] | 0) + 8 >> 2] | 0, 161384) | 0) {
	                                CF(c[j >> 2] | 0, c[t >> 2] | 0) | 0;
	                                break a
	                            }
	                            if (qy(c[(c[t >> 2] | 0) + 8 >> 2] | 0, 155448) | 0) {
	                                _F(c[j >> 2] | 0, c[k >> 2] | 0, 0, c[t >> 2] | 0, u, v) | 0;
	                                break a
	                            }
	                            if (qy(c[(c[t >> 2] | 0) + 8 >> 2] | 0, 163528) | 0) {
	                                c[A >> 2] = 1;
	                                c[o >> 2] = fE(c[j >> 2] | 0, c[t >> 2] | 0) | 0;
	                                if (qy(c[o >> 2] | 0, 163536) | 0) {
	                                    c[q >> 2] = c[(c[j >> 2] | 0) + 112 >> 2];
	                                    break a
	                                }
	                                if (qy(c[o >> 2] | 0, 163552) | 0)break a;
	                                hE(c[j >> 2] | 0, 3037, 0, c[t >> 2] | 0, 0, 163568, c[o >> 2] | 0, 0, 0, 0);
	                                break a
	                            }
	                        } while (0);
	                        if (qy(c[(c[t >> 2] | 0) + 8 >> 2] | 0, 163600) | 0) {
	                            c[o >> 2] = fE(c[j >> 2] | 0, c[t >> 2] | 0) | 0;
	                            if (qy(c[o >> 2] | 0, 163608) | 0) {
	                                c[y >> 2] = 2;
	                                break
	                            }
	                            if (qy(c[o >> 2] | 0, 163624) | 0) {
	                                c[y >> 2] = 0;
	                                break
	                            }
	                            if (qy(c[o >> 2] | 0, 163640) | 0) {
	                                c[y >> 2] = 1;
	                                break
	                            } else {
	                                hE(c[j >> 2] | 0, 1774, 0, c[t >> 2] | 0, 0, 163656, c[o >> 2] | 0, 0, 0, 0);
	                                break
	                            }
	                        }
	                        if (qy(c[(c[t >> 2] | 0) + 8 >> 2] | 0, 159128) | 0) {
	                            f = c[j >> 2] | 0;
	                            e = c[t >> 2] | 0;
	                            if (c[w >> 2] | 0) {
	                                aG(f, 3051, 0, e, 159128, 159120);
	                                break
	                            } else {
	                                c[w >> 2] = fE(f, e) | 0;
	                                c[B >> 2] = 1;
	                                break
	                            }
	                        }
	                        if (qy(c[(c[t >> 2] | 0) + 8 >> 2] | 0, 159120) | 0) {
	                            e = c[j >> 2] | 0;
	                            f = c[t >> 2] | 0;
	                            if (c[w >> 2] | 0) {
	                                aG(e, 3051, 0, f, 159128, 159120);
	                                break
	                            } else {
	                                c[w >> 2] = fE(e, f) | 0;
	                                c[B >> 2] = 2;
	                                break
	                            }
	                        } else I = 43
	                    } else if (qy(c[(c[(c[t >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)I = 43; while (0);
	                    if ((I | 0) == 43) {
	                        I = 0;
	                        GF(c[j >> 2] | 0, 3035, 0, c[t >> 2] | 0)
	                    }
	                    c[t >> 2] = c[(c[t >> 2] | 0) + 24 >> 2]
	                }
	                if ((c[B >> 2] | 0) == 1 & (c[y >> 2] | 0) != 2)hE(c[j >> 2] | 0, 3052, 0, c[l >> 2] | 0, 0, 163656, 0, 163696, 0, 0);
	                if ((c[z >> 2] | 0) != (c[(c[j >> 2] | 0) + 20 >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    H = c[h >> 2] | 0;
	                    i = g;
	                    return H | 0
	                }
	                if (c[x >> 2] | 0) {
	                    if (c[y >> 2] | 0) {
	                        c[r >> 2] = BH(c[j >> 2] | 0, c[l >> 2] | 0) | 0;
	                        if (!(c[r >> 2] | 0)) {
	                            c[h >> 2] = 0;
	                            H = c[h >> 2] | 0;
	                            i = g;
	                            return H | 0
	                        }
	                        dG((c[(c[j >> 2] | 0) + 28 >> 2] | 0) + 20 | 0, 10, c[r >> 2] | 0) | 0;
	                        c[(c[r >> 2] | 0) + 24 >> 2] = c[y >> 2];
	                        c[D >> 2] = cG(c[j >> 2] | 0, 15, c[v >> 2] | 0, c[u >> 2] | 0) | 0;
	                        if (!(c[D >> 2] | 0)) {
	                            c[h >> 2] = 0;
	                            H = c[h >> 2] | 0;
	                            i = g;
	                            return H | 0
	                        }
	                        c[(c[r >> 2] | 0) + 12 >> 2] = c[D >> 2];
	                        if (c[w >> 2] | 0)c[(c[r >> 2] | 0) + 28 >> 2] = c[w >> 2];
	                        if ((c[B >> 2] | 0) == 2) {
	                            D = (c[r >> 2] | 0) + 16 | 0;
	                            c[D >> 2] = c[D >> 2] | 1
	                        }
	                    }
	                } else {
	                    if ((c[A >> 2] | 0) == 0 ? (c[(c[k >> 2] | 0) + 24 >> 2] & 2 | 0) != 0 : 0)c[q >> 2] = c[(c[j >> 2] | 0) + 112 >> 2];
	                    if (qy(c[q >> 2] | 0, c[38860] | 0) | 0)AB(c[j >> 2] | 0, 3057, c[l >> 2] | 0, 0, 163792, c[38860] | 0, 0);
	                    c[t >> 2] = dE(c[l >> 2] | 0, 161352) | 0;
	                    A = c[j >> 2] | 0;
	                    if (!(c[t >> 2] | 0)) {
	                        MF(A, 3036, 0, c[l >> 2] | 0, 161352, 0);
	                        c[h >> 2] = 0;
	                        H = c[h >> 2] | 0;
	                        i = g;
	                        return H | 0
	                    }
	                    D = c[t >> 2] | 0;
	                    if (eE(A, 0, D, IH(22) | 0, p) | 0) {
	                        c[h >> 2] = 0;
	                        H = c[h >> 2] | 0;
	                        i = g;
	                        return H | 0
	                    }
	                    if (qy(c[p >> 2] | 0, 163840) | 0) {
	                        D = c[j >> 2] | 0;
	                        A = c[t >> 2] | 0;
	                        hE(D, 3056, 0, A, IH(22) | 0, 0, 0, 163848, 0, 0);
	                        c[h >> 2] = 0;
	                        H = c[h >> 2] | 0;
	                        i = g;
	                        return H | 0
	                    }
	                    if (c[y >> 2] | 0) {
	                        c[r >> 2] = BH(c[j >> 2] | 0, c[l >> 2] | 0) | 0;
	                        if (!(c[r >> 2] | 0)) {
	                            c[h >> 2] = 0;
	                            H = c[h >> 2] | 0;
	                            i = g;
	                            return H | 0
	                        }
	                        c[(c[r >> 2] | 0) + 24 >> 2] = c[y >> 2];
	                        c[C >> 2] = iG(c[j >> 2] | 0, c[k >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0, c[l >> 2] | 0, 0) | 0;
	                        if (!(c[C >> 2] | 0)) {
	                            c[h >> 2] = 0;
	                            H = c[h >> 2] | 0;
	                            i = g;
	                            return H | 0
	                        }
	                        if (c[v >> 2] | 0) {
	                            c[(c[C >> 2] | 0) + 24 >> 2] = c[v >> 2];
	                            c[(c[C >> 2] | 0) + 28 >> 2] = c[u >> 2]
	                        }
	                        c[(c[r >> 2] | 0) + 12 >> 2] = c[C >> 2];
	                        if ((c[w >> 2] | 0) != 0 ? (c[(c[C >> 2] | 0) + 44 >> 2] = c[w >> 2], (c[B >> 2] | 0) == 2) : 0) {
	                            B = (c[C >> 2] | 0) + 60 | 0;
	                            c[B >> 2] = c[B >> 2] | 512
	                        }
	                    }
	                }
	                c[s >> 2] = c[(c[l >> 2] | 0) + 12 >> 2];
	                B = (c[s >> 2] | 0) != 0;
	                if (c[y >> 2] | 0) {
	                    if (((B ? (c[(c[s >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[s >> 2] | 0) + 8 >> 2] | 0, 160992) | 0) != 0 : 0) ? (qy(c[(c[(c[s >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        y = jE(c[j >> 2] | 0, c[s >> 2] | 0, 1) | 0;
	                        c[(c[r >> 2] | 0) + 4 >> 2] = y;
	                        c[s >> 2] = c[(c[s >> 2] | 0) + 24 >> 2]
	                    }
	                    y = (c[s >> 2] | 0) != 0;
	                    do if (c[x >> 2] | 0) {
	                        if (y) {
	                            if ((((c[s >> 2] | 0) != 0 ? (c[(c[s >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[s >> 2] | 0) + 8 >> 2] | 0, 161024) | 0) != 0 : 0) ? (qy(c[(c[(c[s >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                                uE(c[j >> 2] | 0, 3054, 0, c[l >> 2] | 0, c[s >> 2] | 0, 0, 161392);
	                                break
	                            }
	                            uE(c[j >> 2] | 0, 3033, 0, c[l >> 2] | 0, c[s >> 2] | 0, 0, 161392)
	                        }
	                    } else {
	                        if (((y ? (c[(c[s >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[s >> 2] | 0) + 8 >> 2] | 0, 161024) | 0) != 0 : 0) ? (qy(c[(c[(c[s >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                            C = c[j >> 2] | 0;
	                            if (c[(c[(c[r >> 2] | 0) + 12 >> 2] | 0) + 24 >> 2] | 0)uE(C, 3055, 0, c[l >> 2] | 0, c[s >> 2] | 0, 164128, 0); else {
	                                w = oE(C, c[k >> 2] | 0, c[s >> 2] | 0, 0) | 0;
	                                c[(c[(c[r >> 2] | 0) + 12 >> 2] | 0) + 48 >> 2] = w
	                            }
	                            c[s >> 2] = c[(c[s >> 2] | 0) + 24 >> 2]
	                        }
	                        if (c[s >> 2] | 0)uE(c[j >> 2] | 0, 3033, 0, c[l >> 2] | 0, c[s >> 2] | 0, 0, 164200)
	                    } while (0);
	                    c[h >> 2] = c[r >> 2];
	                    H = c[h >> 2] | 0;
	                    i = g;
	                    return H | 0
	                }
	                if (((B ? (c[(c[s >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[s >> 2] | 0) + 8 >> 2] | 0, 160992) | 0) != 0 : 0) ? (qy(c[(c[(c[s >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    jE(c[j >> 2] | 0, c[s >> 2] | 0, 0) | 0;
	                    c[s >> 2] = c[(c[s >> 2] | 0) + 24 >> 2]
	                }
	                if (c[s >> 2] | 0)uE(c[j >> 2] | 0, 3033, 0, c[l >> 2] | 0, c[s >> 2] | 0, 0, 161392);
	                if ((c[n >> 2] | 0) == 16) {
	                    NC(c[j >> 2] | 0, 3086, c[l >> 2] | 0, 0, 163904, 0, 0, 0);
	                    c[h >> 2] = 0;
	                    H = c[h >> 2] | 0;
	                    i = g;
	                    return H | 0
	                }
	                if ((c[n >> 2] | 0) == 13) {
	                    NC(c[j >> 2] | 0, 3086, c[l >> 2] | 0, 0, 163992, 0, 0, 0);
	                    c[h >> 2] = 0;
	                    H = c[h >> 2] | 0;
	                    i = g;
	                    return H | 0
	                }
	                if (!(c[x >> 2] | 0)) {
	                    c[v >> 2] = c[p >> 2];
	                    c[u >> 2] = c[q >> 2]
	                }
	                b:do if (c[m >> 2] | 0) {
	                    c[F >> 2] = 0;
	                    while (1) {
	                        if ((c[F >> 2] | 0) >= (c[(c[m >> 2] | 0) + 4 >> 2] | 0))break b;
	                        c[r >> 2] = c[(c[c[m >> 2] >> 2] | 0) + (c[F >> 2] << 2) >> 2];
	                        if (((c[c[r >> 2] >> 2] | 0) == 2001 ? (c[v >> 2] | 0) == (c[(c[r >> 2] | 0) + 8 >> 2] | 0) : 0) ? (c[u >> 2] | 0) == (c[(c[r >> 2] | 0) + 12 >> 2] | 0) : 0)break;
	                        c[F >> 2] = (c[F >> 2] | 0) + 1
	                    }
	                    c[G >> 2] = 0;
	                    q = c[j >> 2] | 0;
	                    p = c[l >> 2] | 0;
	                    NC(q, 3086, p, 0, 164072, BB(G, c[u >> 2] | 0, c[v >> 2] | 0) | 0, 0, 0);
	                    if (c[G >> 2] | 0) {
	                        zb[c[135736 >> 2] & 511](c[G >> 2] | 0);
	                        c[G >> 2] = 0
	                    }
	                    c[h >> 2] = 0;
	                    H = c[h >> 2] | 0;
	                    i = g;
	                    return H | 0
	                } while (0);
	                c[E >> 2] = CH(c[j >> 2] | 0) | 0;
	                if (!(c[E >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    H = c[h >> 2] | 0;
	                    i = g;
	                    return H | 0
	                }
	                c[(c[E >> 2] | 0) + 4 >> 2] = c[l >> 2];
	                c[(c[E >> 2] | 0) + 8 >> 2] = c[v >> 2];
	                c[(c[E >> 2] | 0) + 12 >> 2] = c[u >> 2];
	                if (c[x >> 2] | 0)dG((c[(c[j >> 2] | 0) + 28 >> 2] | 0) + 20 | 0, 10, c[E >> 2] | 0) | 0;
	                c[h >> 2] = c[E >> 2];
	                H = c[h >> 2] | 0;
	                i = g;
	                return H | 0
	            }

	            function oH(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 36 | 0;
	                g = e + 32 | 0;
	                h = e + 28 | 0;
	                j = e + 24 | 0;
	                k = e + 20 | 0;
	                l = e + 16 | 0;
	                m = e + 12 | 0;
	                n = e + 8 | 0;
	                o = e + 4 | 0;
	                p = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[l >> 2] = 0;
	                c[n >> 2] = 0;
	                c[o >> 2] = 0;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    q = c[f >> 2] | 0;
	                    i = e;
	                    return q | 0
	                }
	                c[m >> 2] = dE(c[j >> 2] | 0, 160064) | 0;
	                d = c[g >> 2] | 0;
	                if (!(c[m >> 2] | 0)) {
	                    MF(d, 3036, 0, c[j >> 2] | 0, 160064, 0);
	                    c[f >> 2] = 0;
	                    q = c[f >> 2] | 0;
	                    i = e;
	                    return q | 0
	                }
	                _F(d, c[h >> 2] | 0, 0, c[m >> 2] | 0, n, o) | 0;
	                if ($F(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0) | 0) {
	                    c[f >> 2] = 0;
	                    q = c[f >> 2] | 0;
	                    i = e;
	                    return q | 0
	                }
	                c[m >> 2] = c[(c[j >> 2] | 0) + 44 >> 2];
	                while (1) {
	                    if (!(c[m >> 2] | 0))break;
	                    h = c[m >> 2] | 0;
	                    if (!(c[(c[m >> 2] | 0) + 36 >> 2] | 0)) {
	                        if ((qy(c[h + 8 >> 2] | 0, 160064) | 0) == 0 ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 161384) | 0) == 0 : 0)GF(c[g >> 2] | 0, 3035, 0, c[m >> 2] | 0)
	                    } else if (qy(c[(c[h + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)GF(c[g >> 2] | 0, 3035, 0, c[m >> 2] | 0);
	                    c[m >> 2] = c[(c[m >> 2] | 0) + 24 >> 2]
	                }
	                cE(c[g >> 2] | 0, c[j >> 2] | 0, 161384) | 0;
	                c[l >> 2] = c[(c[j >> 2] | 0) + 12 >> 2];
	                if ((((c[l >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[l >> 2] | 0) + 8 >> 2] | 0, 160992) | 0) != 0 : 0) ? (qy(c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    jE(c[g >> 2] | 0, c[l >> 2] | 0, 0) | 0;
	                    c[l >> 2] = c[(c[l >> 2] | 0) + 24 >> 2]
	                }
	                if (c[l >> 2] | 0)uE(c[g >> 2] | 0, 3033, 0, c[j >> 2] | 0, c[l >> 2] | 0, 0, 161392);
	                do if (((((c[(c[g >> 2] | 0) + 100 >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 120 >> 2] | 0) != 0 : 0) ? (c[c[(c[(c[g >> 2] | 0) + 120 >> 2] | 0) + 4 >> 2] >> 2] | 0) == 16 : 0) ? (c[o >> 2] | 0) == (c[(c[(c[g >> 2] | 0) + 120 >> 2] | 0) + 16 >> 2] | 0) : 0) ? (c[n >> 2] | 0) == (c[(c[(c[g >> 2] | 0) + 120 >> 2] | 0) + 20 >> 2] | 0) : 0)if (c[(c[g >> 2] | 0) + 124 >> 2] | 0) {
	                    c[p >> 2] = 0;
	                    l = c[g >> 2] | 0;
	                    m = c[j >> 2] | 0;
	                    AB(l, 3081, m, 0, 163408, BB(p, c[n >> 2] | 0, c[o >> 2] | 0) | 0, 0);
	                    if (c[p >> 2] | 0) {
	                        zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                        c[p >> 2] = 0
	                    }
	                    c[f >> 2] = 0;
	                    q = c[f >> 2] | 0;
	                    i = e;
	                    return q | 0
	                } else {
	                    m = (c[g >> 2] | 0) + 124 | 0;
	                    c[m >> 2] = (c[m >> 2] | 0) + 1;
	                    c[k >> 2] = cG(c[g >> 2] | 0, 16, c[o >> 2] | 0, c[n >> 2] | 0) | 0;
	                    if (c[k >> 2] | 0) {
	                        c[(c[k >> 2] | 0) + 20 >> 2] = c[j >> 2];
	                        c[(c[(c[g >> 2] | 0) + 120 >> 2] | 0) + 8 >> 2] = c[k >> 2];
	                        break
	                    }
	                    c[f >> 2] = 0;
	                    q = c[f >> 2] | 0;
	                    i = e;
	                    return q | 0
	                } else r = 35; while (0);
	                do if ((r | 0) == 35) {
	                    c[k >> 2] = cG(c[g >> 2] | 0, 16, c[o >> 2] | 0, c[n >> 2] | 0) | 0;
	                    if (c[k >> 2] | 0) {
	                        c[(c[k >> 2] | 0) + 20 >> 2] = c[j >> 2];
	                        dG((c[(c[g >> 2] | 0) + 28 >> 2] | 0) + 20 | 0, 10, c[k >> 2] | 0) | 0;
	                        break
	                    }
	                    c[f >> 2] = 0;
	                    q = c[f >> 2] | 0;
	                    i = e;
	                    return q | 0
	                } while (0);
	                c[f >> 2] = c[k >> 2];
	                q = c[f >> 2] | 0;
	                i = e;
	                return q | 0
	            }

	            function pH(a, b, e, f) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0;
	                g = i;
	                i = i + 64 | 0;
	                h = g + 56 | 0;
	                j = g + 52 | 0;
	                k = g + 44 | 0;
	                l = g + 40 | 0;
	                m = g + 36 | 0;
	                n = g + 32 | 0;
	                o = g + 28 | 0;
	                p = g + 24 | 0;
	                q = g + 20 | 0;
	                r = g + 16 | 0;
	                s = g + 12 | 0;
	                t = g + 8 | 0;
	                u = g + 4 | 0;
	                v = g;
	                c[j >> 2] = a;
	                c[g + 48 >> 2] = b;
	                c[k >> 2] = e;
	                c[l >> 2] = f;
	                c[p >> 2] = 0;
	                c[s >> 2] = 0;
	                c[m >> 2] = RC(c[j >> 2] | 0, c[l >> 2] | 0, 162320) | 0;
	                do if ((c[m >> 2] | 0) != 0 ? (qy(c[m >> 2] | 0, 148184) | 0) == 0 : 0) {
	                    if (qy(c[m >> 2] | 0, 148168) | 0) {
	                        c[(c[k >> 2] | 0) + 24 >> 2] = 1;
	                        break
	                    }
	                    if (qy(c[m >> 2] | 0, 148176) | 0) {
	                        c[(c[k >> 2] | 0) + 24 >> 2] = 2;
	                        break
	                    } else {
	                        hE(c[j >> 2] | 0, 3037, 0, c[l >> 2] | 0, 0, 162336, c[m >> 2] | 0, 0, 0, 0);
	                        c[(c[k >> 2] | 0) + 24 >> 2] = 3;
	                        c[p >> 2] = 3037;
	                        break
	                    }
	                } else w = 3; while (0);
	                if ((w | 0) == 3)c[(c[k >> 2] | 0) + 24 >> 2] = 3;
	                c[t >> 2] = dE(c[l >> 2] | 0, 162304) | 0;
	                c[n >> 2] = fE(c[j >> 2] | 0, c[t >> 2] | 0) | 0;
	                a:do if ((c[t >> 2] | 0) != 0 ? (qy(c[n >> 2] | 0, 162360) | 0) == 0 : 0) {
	                    if (qy(c[n >> 2] | 0, 144400) | 0) {
	                        l = uH(c[j >> 2] | 0) | 0;
	                        c[(c[k >> 2] | 0) + 36 >> 2] = l;
	                        if (c[(c[k >> 2] | 0) + 36 >> 2] | 0) {
	                            c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] = c[(c[j >> 2] | 0) + 112 >> 2];
	                            break
	                        }
	                        c[h >> 2] = -1;
	                        x = c[h >> 2] | 0;
	                        i = g;
	                        return x | 0
	                    }
	                    c[v >> 2] = c[n >> 2];
	                    while (1) {
	                        do if ((d[c[v >> 2] >> 0] | 0 | 0) == 32)y = 1; else {
	                            if (9 <= (d[c[v >> 2] >> 0] | 0 | 0) ? (d[c[v >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                y = 1;
	                                break
	                            }
	                            y = (d[c[v >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        l = c[v >> 2] | 0;
	                        if (y) {
	                            c[v >> 2] = l + 1;
	                            continue
	                        }
	                        c[u >> 2] = l;
	                        while (1) {
	                            if (d[c[u >> 2] >> 0] | 0) {
	                                do if ((d[c[u >> 2] >> 0] | 0 | 0) == 32)z = 1; else {
	                                    if (9 <= (d[c[u >> 2] >> 0] | 0 | 0) ? (d[c[u >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                        z = 1;
	                                        break
	                                    }
	                                    z = (d[c[u >> 2] >> 0] | 0 | 0) == 13
	                                } while (0);
	                                A = z ^ 1
	                            } else A = 0;
	                            B = c[u >> 2] | 0;
	                            if (!A)break;
	                            c[u >> 2] = B + 1
	                        }
	                        if ((B | 0) == (c[v >> 2] | 0))break a;
	                        c[q >> 2] = ly(c[v >> 2] | 0, (c[u >> 2] | 0) - (c[v >> 2] | 0) | 0) | 0;
	                        if ((qy(c[q >> 2] | 0, 144400) | 0) == 0 ? (qy(c[q >> 2] | 0, 162360) | 0) == 0 : 0) {
	                            do if (!(qy(c[q >> 2] | 0, 162448) | 0))if (qy(c[q >> 2] | 0, 162472) | 0) {
	                                c[o >> 2] = 0;
	                                break
	                            } else {
	                                l = c[j >> 2] | 0;
	                                m = c[t >> 2] | 0;
	                                f = c[q >> 2] | 0;
	                                DF(l, 0, m, f, IH(29) | 0) | 0;
	                                c[o >> 2] = AP(c[(c[j >> 2] | 0) + 80 >> 2] | 0, c[q >> 2] | 0, -1) | 0;
	                                break
	                            } else c[o >> 2] = c[(c[j >> 2] | 0) + 112 >> 2]; while (0);
	                            c[r >> 2] = c[(c[k >> 2] | 0) + 32 >> 2];
	                            while (1) {
	                                if (!(c[r >> 2] | 0))break;
	                                if ((c[o >> 2] | 0) == (c[(c[r >> 2] | 0) + 4 >> 2] | 0))break;
	                                c[r >> 2] = c[c[r >> 2] >> 2]
	                            }
	                            if (!(c[r >> 2] | 0)) {
	                                c[r >> 2] = uH(c[j >> 2] | 0) | 0;
	                                if (!(c[r >> 2] | 0))break;
	                                c[(c[r >> 2] | 0) + 4 >> 2] = c[o >> 2];
	                                c[c[r >> 2] >> 2] = 0;
	                                if (c[(c[k >> 2] | 0) + 32 >> 2] | 0) {
	                                    if (c[s >> 2] | 0)c[c[s >> 2] >> 2] = c[r >> 2]
	                                } else c[(c[k >> 2] | 0) + 32 >> 2] = c[r >> 2];
	                                c[s >> 2] = c[r >> 2]
	                            }
	                        } else {
	                            hE(c[j >> 2] | 0, 1792, 0, c[t >> 2] | 0, 0, 162368, c[q >> 2] | 0, 0, 0, 0);
	                            c[p >> 2] = 1792
	                        }
	                        zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                        c[v >> 2] = c[u >> 2];
	                        if (!(d[c[v >> 2] >> 0] | 0))break a
	                    }
	                    zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                    c[h >> 2] = -1;
	                    x = c[h >> 2] | 0;
	                    i = g;
	                    return x | 0
	                } else w = 11; while (0);
	                if ((w | 0) == 11)c[(c[k >> 2] | 0) + 28 >> 2] = 1;
	                c[h >> 2] = c[p >> 2];
	                x = c[h >> 2] | 0;
	                i = g;
	                return x | 0
	            }

	            function qH(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 28 | 0;
	                g = e + 24 | 0;
	                h = e + 20 | 0;
	                j = e + 16 | 0;
	                k = e + 12 | 0;
	                l = e + 8 | 0;
	                m = e + 4 | 0;
	                n = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[l >> 2] = 0;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                c[k >> 2] = SA() | 0;
	                if (!(c[k >> 2] | 0)) {
	                    tC(c[g >> 2] | 0, 166944, c[j >> 2] | 0);
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                c[(c[k >> 2] | 0) + 20 >> 2] = c[j >> 2];
	                c[m >> 2] = RC(c[g >> 2] | 0, c[j >> 2] | 0, 166968) | 0;
	                if (!(c[m >> 2] | 0)) {
	                    lG(c[g >> 2] | 0, c[j >> 2] | 0, c[l >> 2] | 0, 1708, 166976, c[(c[j >> 2] | 0) + 8 >> 2] | 0, 0);
	                    UA(c[k >> 2] | 0);
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                if ((((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[j >> 2] | 0) + 8 >> 2] | 0, 157848) | 0) != 0 : 0) ? (qy(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0)c[c[k >> 2] >> 2] = 1e3; else p = 12;
	                do if ((p | 0) == 12) {
	                    if ((((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[j >> 2] | 0) + 8 >> 2] | 0, 157832) | 0) != 0 : 0) ? (qy(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        c[c[k >> 2] >> 2] = 1001;
	                        break
	                    }
	                    if ((((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[j >> 2] | 0) + 8 >> 2] | 0, 157816) | 0) != 0 : 0) ? (qy(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        c[c[k >> 2] >> 2] = 1002;
	                        break
	                    }
	                    if ((((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[j >> 2] | 0) + 8 >> 2] | 0, 157800) | 0) != 0 : 0) ? (qy(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        c[c[k >> 2] >> 2] = 1003;
	                        break
	                    }
	                    if ((((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[j >> 2] | 0) + 8 >> 2] | 0, 157936) | 0) != 0 : 0) ? (qy(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        c[c[k >> 2] >> 2] = 1004;
	                        break
	                    }
	                    if ((((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[j >> 2] | 0) + 8 >> 2] | 0, 157952) | 0) != 0 : 0) ? (qy(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        c[c[k >> 2] >> 2] = 1005;
	                        break
	                    }
	                    if ((((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[j >> 2] | 0) + 8 >> 2] | 0, 157792) | 0) != 0 : 0) ? (qy(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        c[c[k >> 2] >> 2] = 1006;
	                        break
	                    }
	                    if ((((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[j >> 2] | 0) + 8 >> 2] | 0, 157880) | 0) != 0 : 0) ? (qy(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        c[c[k >> 2] >> 2] = 1007;
	                        break
	                    }
	                    if ((((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[j >> 2] | 0) + 8 >> 2] | 0, 157864) | 0) != 0 : 0) ? (qy(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        c[c[k >> 2] >> 2] = 1008;
	                        break
	                    }
	                    if ((((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[j >> 2] | 0) + 8 >> 2] | 0, 157896) | 0) != 0 : 0) ? (qy(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        c[c[k >> 2] >> 2] = 1009;
	                        break
	                    }
	                    if ((((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[j >> 2] | 0) + 8 >> 2] | 0, 157904) | 0) != 0 : 0) ? (qy(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        c[c[k >> 2] >> 2] = 1010;
	                        break
	                    }
	                    if ((((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[j >> 2] | 0) + 8 >> 2] | 0, 157920) | 0) != 0 : 0) ? (qy(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                        c[c[k >> 2] >> 2] = 1011;
	                        break
	                    }
	                    lG(c[g >> 2] | 0, c[j >> 2] | 0, c[l >> 2] | 0, 1741, 167e3, c[(c[j >> 2] | 0) + 8 >> 2] | 0, 0);
	                    UA(c[k >> 2] | 0);
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                } while (0);
	                cE(c[g >> 2] | 0, c[j >> 2] | 0, 161384) | 0;
	                c[(c[k >> 2] | 0) + 8 >> 2] = c[m >> 2];
	                if ((((c[c[k >> 2] >> 2] | 0) != 1006 ? (c[c[k >> 2] >> 2] | 0) != 1007 : 0) ? (c[n >> 2] = RC(c[g >> 2] | 0, c[j >> 2] | 0, 159120) | 0, (c[n >> 2] | 0) != 0) : 0) ? (qy(c[n >> 2] | 0, 165504) | 0) != 0 : 0)c[(c[k >> 2] | 0) + 24 >> 2] = 1;
	                c[l >> 2] = c[(c[j >> 2] | 0) + 12 >> 2];
	                if ((((c[l >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[l >> 2] | 0) + 8 >> 2] | 0, 160992) | 0) != 0 : 0) ? (qy(c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    n = jE(c[g >> 2] | 0, c[l >> 2] | 0, 1) | 0;
	                    c[(c[k >> 2] | 0) + 16 >> 2] = n;
	                    c[l >> 2] = c[(c[l >> 2] | 0) + 24 >> 2]
	                }
	                if (c[l >> 2] | 0)lG(c[g >> 2] | 0, c[j >> 2] | 0, c[l >> 2] | 0, 1740, 167024, c[(c[j >> 2] | 0) + 8 >> 2] | 0, 0);
	                c[f >> 2] = c[k >> 2];
	                o = c[f >> 2] | 0;
	                i = e;
	                return o | 0
	            }

	            function rH(a, b, d, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0;
	                j = i;
	                i = i + 48 | 0;
	                k = j + 44 | 0;
	                l = j + 40 | 0;
	                m = j + 36 | 0;
	                n = j + 32 | 0;
	                o = j + 28 | 0;
	                p = j + 24 | 0;
	                q = j + 20 | 0;
	                r = j + 16 | 0;
	                s = j + 12 | 0;
	                t = j + 8 | 0;
	                u = j + 4 | 0;
	                v = j;
	                c[l >> 2] = a;
	                c[m >> 2] = b;
	                c[n >> 2] = d;
	                c[o >> 2] = e;
	                c[p >> 2] = f;
	                c[q >> 2] = g;
	                c[r >> 2] = h;
	                c[c[q >> 2] >> 2] = 0;
	                c[c[r >> 2] >> 2] = 0;
	                c[v >> 2] = Fh(c[p >> 2] | 0, 1) | 0;
	                if ((c[v >> 2] | 0) > 0) {
	                    h = c[l >> 2] | 0;
	                    g = c[n >> 2] | 0;
	                    f = c[o >> 2] | 0;
	                    e = IH(21) | 0;
	                    hE(h, 3037, g, f, e, 0, c[p >> 2] | 0, 0, 0, 0);
	                    c[c[r >> 2] >> 2] = c[p >> 2];
	                    c[k >> 2] = c[(c[l >> 2] | 0) + 16 >> 2];
	                    w = c[k >> 2] | 0;
	                    i = j;
	                    return w | 0
	                }
	                if ((c[v >> 2] | 0) < 0) {
	                    c[k >> 2] = -1;
	                    w = c[k >> 2] | 0;
	                    i = j;
	                    return w | 0
	                }
	                if (eT(c[p >> 2] | 0, 58) | 0) {
	                    v = Dh(c[p >> 2] | 0, u) | 0;
	                    c[c[r >> 2] >> 2] = v;
	                    v = AP(c[(c[l >> 2] | 0) + 80 >> 2] | 0, c[c[r >> 2] >> 2] | 0, -1) | 0;
	                    c[c[r >> 2] >> 2] = v;
	                    c[s >> 2] = AP(c[(c[l >> 2] | 0) + 80 >> 2] | 0, c[p >> 2] | 0, c[u >> 2] | 0) | 0;
	                    c[t >> 2] = cj(c[(c[o >> 2] | 0) + 32 >> 2] | 0, c[(c[o >> 2] | 0) + 20 >> 2] | 0, c[s >> 2] | 0) | 0;
	                    s = c[l >> 2] | 0;
	                    if (!(c[t >> 2] | 0)) {
	                        u = c[n >> 2] | 0;
	                        n = c[o >> 2] | 0;
	                        v = IH(21) | 0;
	                        hE(s, 3037, u, n, v, 0, c[p >> 2] | 0, 162952, c[p >> 2] | 0, 0);
	                        c[k >> 2] = c[(c[l >> 2] | 0) + 16 >> 2];
	                        w = c[k >> 2] | 0;
	                        i = j;
	                        return w | 0
	                    } else {
	                        v = AP(c[s + 80 >> 2] | 0, c[(c[t >> 2] | 0) + 8 >> 2] | 0, -1) | 0;
	                        c[c[q >> 2] >> 2] = v;
	                        c[k >> 2] = 0;
	                        w = c[k >> 2] | 0;
	                        i = j;
	                        return w | 0
	                    }
	                }
	                c[t >> 2] = cj(c[(c[o >> 2] | 0) + 32 >> 2] | 0, c[(c[o >> 2] | 0) + 20 >> 2] | 0, 0) | 0;
	                if (!(c[t >> 2] | 0)) {
	                    if (c[(c[m >> 2] | 0) + 24 >> 2] & 512)c[c[q >> 2] >> 2] = c[(c[l >> 2] | 0) + 112 >> 2]
	                } else {
	                    m = AP(c[(c[l >> 2] | 0) + 80 >> 2] | 0, c[(c[t >> 2] | 0) + 8 >> 2] | 0, -1) | 0;
	                    c[c[q >> 2] >> 2] = m
	                }
	                m = AP(c[(c[l >> 2] | 0) + 80 >> 2] | 0, c[p >> 2] | 0, -1) | 0;
	                c[c[r >> 2] >> 2] = m;
	                c[k >> 2] = 0;
	                w = c[k >> 2] | 0;
	                i = j;
	                return w | 0
	            }

	            function sH(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                h = i;
	                i = i + 32 | 0;
	                j = h + 28 | 0;
	                k = h + 24 | 0;
	                l = h + 20 | 0;
	                m = h + 16 | 0;
	                n = h + 12 | 0;
	                o = h + 8 | 0;
	                p = h + 4 | 0;
	                q = h;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                c[q >> 2] = 0;
	                if ((c[k >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0 | (c[m >> 2] | 0) == 0) {
	                    c[j >> 2] = 0;
	                    r = c[j >> 2] | 0;
	                    i = h;
	                    return r | 0
	                }
	                c[q >> 2] = Cb[c[135744 >> 2] & 511](40) | 0;
	                if (!(c[q >> 2] | 0)) {
	                    tC(c[k >> 2] | 0, 165384, 0);
	                    c[j >> 2] = 0;
	                    r = c[j >> 2] | 0;
	                    i = h;
	                    return r | 0
	                }
	                l = (c[q >> 2] | 0) + 0 | 0;
	                g = l + 40 | 0;
	                do {
	                    c[l >> 2] = 0;
	                    l = l + 4 | 0
	                } while ((l | 0) < (g | 0));
	                c[(c[q >> 2] | 0) + 20 >> 2] = c[n >> 2];
	                c[(c[q >> 2] | 0) + 16 >> 2] = c[m >> 2];
	                c[c[q >> 2] >> 2] = c[o >> 2];
	                c[(c[q >> 2] | 0) + 12 >> 2] = c[p >> 2];
	                dG((c[(c[(c[k >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] | 0) + 44 | 0, 5, c[q >> 2] | 0) | 0;
	                if ((c[o >> 2] | 0) == 24)dG((c[(c[k >> 2] | 0) + 28 >> 2] | 0) + 20 | 0, 10, c[q >> 2] | 0) | 0;
	                c[j >> 2] = c[q >> 2];
	                r = c[j >> 2] | 0;
	                i = h;
	                return r | 0
	            }

	            function tH(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 28 | 0;
	                h = f + 24 | 0;
	                j = f + 20 | 0;
	                k = f + 16 | 0;
	                l = f + 12 | 0;
	                m = f + 8 | 0;
	                n = f + 4 | 0;
	                o = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[n >> 2] = 0;
	                c[o >> 2] = c[(c[k >> 2] | 0) + 44 >> 2];
	                while (1) {
	                    if (!(c[o >> 2] | 0))break;
	                    e = c[o >> 2] | 0;
	                    if (!(c[(c[o >> 2] | 0) + 36 >> 2] | 0)) {
	                        if ((qy(c[e + 8 >> 2] | 0, 161384) | 0) == 0 ? (qy(c[(c[o >> 2] | 0) + 8 >> 2] | 0, 164904) | 0) == 0 : 0)GF(c[h >> 2] | 0, 3035, 0, c[o >> 2] | 0)
	                    } else if (qy(c[(c[e + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0)GF(c[h >> 2] | 0, 3035, 0, c[o >> 2] | 0);
	                    c[o >> 2] = c[(c[o >> 2] | 0) + 24 >> 2]
	                }
	                c[m >> 2] = Cb[c[135744 >> 2] & 511](20) | 0;
	                if (!(c[m >> 2] | 0)) {
	                    tC(c[h >> 2] | 0, 164912, 0);
	                    c[g >> 2] = 0;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                e = c[m >> 2] | 0;
	                c[e + 0 >> 2] = 0;
	                c[e + 4 >> 2] = 0;
	                c[e + 8 >> 2] = 0;
	                c[e + 12 >> 2] = 0;
	                c[e + 16 >> 2] = 0;
	                c[o >> 2] = dE(c[k >> 2] | 0, 164904) | 0;
	                e = c[h >> 2] | 0;
	                if (c[o >> 2] | 0) {
	                    d = fE(e, c[o >> 2] | 0) | 0;
	                    c[(c[m >> 2] | 0) + 12 >> 2] = d;
	                    if ((DH(c[h >> 2] | 0, c[j >> 2] | 0, c[m >> 2] | 0, c[o >> 2] | 0, c[l >> 2] | 0) | 0) == -1)PC(c[h >> 2] | 0, c[o >> 2] | 0, 3069, 164976, 0, 0)
	                } else MF(e, 3036, 0, c[k >> 2] | 0, 161352, 0);
	                cE(c[h >> 2] | 0, c[k >> 2] | 0, 161384) | 0;
	                c[n >> 2] = c[(c[k >> 2] | 0) + 12 >> 2];
	                if ((((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 160992) | 0) != 0 : 0) ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[38526] | 0) | 0) != 0 : 0) {
	                    e = c[j >> 2] | 0;
	                    kH(e, jE(c[h >> 2] | 0, c[n >> 2] | 0, 1) | 0) | 0;
	                    c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2]
	                }
	                if (c[n >> 2] | 0)uE(c[h >> 2] | 0, 3033, 0, c[k >> 2] | 0, c[n >> 2] | 0, 0, 161392);
	                c[g >> 2] = c[m >> 2];
	                p = c[g >> 2] | 0;
	                i = f;
	                return p | 0
	            }

	            function uH(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](8) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    tC(c[e >> 2] | 0, 152760, 0);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    c[(c[f >> 2] | 0) + 4 >> 2] = 0;
	                    c[c[f >> 2] >> 2] = 0;
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function vH(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 24 | 0;
	                e = b + 20 | 0;
	                f = b + 16 | 0;
	                g = b + 12 | 0;
	                h = b + 8 | 0;
	                j = b + 4 | 0;
	                k = b;
	                c[e >> 2] = a;
	                if ((c[(c[e >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 16 >> 2] | 0) != 0 : 0) {
	                    if ((c[c[(c[e >> 2] | 0) + 12 >> 2] >> 2] | 0) != 7) {
	                        c[j >> 2] = 0;
	                        c[k >> 2] = c[(c[(c[e >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2];
	                        if (!(c[k >> 2] | 0)) {
	                            c[d >> 2] = 0;
	                            l = c[d >> 2] | 0;
	                            i = b;
	                            return l | 0
	                        }
	                        do {
	                            if ((c[c[(c[k >> 2] | 0) + 12 >> 2] >> 2] | 0) != 14 ? (c[c[(c[k >> 2] | 0) + 12 >> 2] >> 2] | 0) != 2 : 0) {
	                                a = vH(c[k >> 2] | 0) | 0;
	                                c[j >> 2] = (c[j >> 2] | 0) + a
	                            } else c[j >> 2] = (c[j >> 2] | 0) + (c[(c[k >> 2] | 0) + 16 >> 2] | 0);
	                            c[k >> 2] = c[(c[k >> 2] | 0) + 8 >> 2]
	                        } while ((c[k >> 2] | 0) != 0);
	                        c[d >> 2] = ca(c[(c[e >> 2] | 0) + 16 >> 2] | 0, c[j >> 2] | 0) | 0;
	                        l = c[d >> 2] | 0;
	                        i = b;
	                        return l | 0
	                    }
	                    c[f >> 2] = -1;
	                    c[h >> 2] = c[(c[(c[e >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2];
	                    if (!(c[h >> 2] | 0)) {
	                        c[d >> 2] = 0;
	                        l = c[d >> 2] | 0;
	                        i = b;
	                        return l | 0
	                    }
	                    while (1) {
	                        if (!(c[h >> 2] | 0)) {
	                            m = 17;
	                            break
	                        }
	                        if ((c[c[(c[h >> 2] | 0) + 12 >> 2] >> 2] | 0) != 14 ? (c[c[(c[h >> 2] | 0) + 12 >> 2] >> 2] | 0) != 2 : 0)c[g >> 2] = vH(c[h >> 2] | 0) | 0; else c[g >> 2] = c[(c[h >> 2] | 0) + 16 >> 2];
	                        if (!(c[g >> 2] | 0)) {
	                            m = 13;
	                            break
	                        }
	                        if ((c[f >> 2] | 0) == -1 ? 1 : (c[f >> 2] | 0) > (c[g >> 2] | 0))c[f >> 2] = c[g >> 2];
	                        c[h >> 2] = c[(c[h >> 2] | 0) + 8 >> 2]
	                    }
	                    if ((m | 0) == 13) {
	                        c[d >> 2] = 0;
	                        l = c[d >> 2] | 0;
	                        i = b;
	                        return l | 0
	                    } else if ((m | 0) == 17) {
	                        c[d >> 2] = ca(c[(c[e >> 2] | 0) + 16 >> 2] | 0, c[f >> 2] | 0) | 0;
	                        l = c[d >> 2] | 0;
	                        i = b;
	                        return l | 0
	                    }
	                }
	                c[d >> 2] = 0;
	                l = c[d >> 2] | 0;
	                i = b;
	                return l | 0
	            }

	            function wH(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = EH(c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                if (c[m >> 2] | 0) {
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                if (!((c[l >> 2] & 2 | 0) != 0 ? (c[(c[j >> 2] | 0) + 48 >> 2] & 2 | 0) != 0 : 0))o = 4;
	                do if ((o | 0) == 4) {
	                    if ((c[l >> 2] & 1 | 0) != 0 ? (c[(c[j >> 2] | 0) + 48 >> 2] & 4 | 0) != 0 : 0)break;
	                    if ((c[(c[j >> 2] | 0) + 64 >> 2] | 0) == (c[k >> 2] | 0)) {
	                        c[g >> 2] = 0;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    if ((c[c[(c[j >> 2] | 0) + 64 >> 2] >> 2] | 0) == 1 ? (c[(c[(c[j >> 2] | 0) + 64 >> 2] | 0) + 88 >> 2] | 0) == 45 : 0) {
	                        c[g >> 2] = 1;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    if ((c[c[(c[j >> 2] | 0) + 64 >> 2] >> 2] | 0) != 5 ? (c[(c[(c[j >> 2] | 0) + 64 >> 2] | 0) + 88 >> 2] | 0) != 45 : 0) {
	                        c[g >> 2] = xG(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 64 >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    c[g >> 2] = wH(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 64 >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                } while (0);
	                c[g >> 2] = 1;
	                n = c[g >> 2] | 0;
	                i = f;
	                return n | 0
	            }

	            function xH(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 24 >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                } else {
	                    c[e >> 2] = Tj(c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 24 >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[(c[g >> 2] | 0) + 52 >> 2] | 0) | 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                return 0
	            }

	            function yH(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 24 >> 2] | 0) == 0 ? (b = Jj(10, c[(c[f >> 2] | 0) + 80 >> 2] | 0) | 0, c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 24 >> 2] = b, (c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 24 >> 2] | 0) == 0) : 0) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[h >> 2] = Cb[c[135744 >> 2] & 511](8) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    tC(0, 158408, 0);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                b = c[h >> 2] | 0;
	                c[b + 0 >> 2] = 0;
	                c[b + 4 >> 2] = 0;
	                c[c[h >> 2] >> 2] = c[g >> 2];
	                b = JB() | 0;
	                c[(c[h >> 2] | 0) + 4 >> 2] = b;
	                if (!(c[(c[h >> 2] | 0) + 4 >> 2] | 0)) {
	                    uC(c[h >> 2] | 0);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                if (Nj(c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 24 >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[(c[g >> 2] | 0) + 52 >> 2] | 0, c[h >> 2] | 0) | 0) {
	                    xB(c[f >> 2] | 0, 158456, 158480);
	                    uC(c[h >> 2] | 0);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } else {
	                    c[e >> 2] = c[h >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                return 0
	            }

	            function zH(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 28 | 0;
	                h = f + 24 | 0;
	                j = f + 20 | 0;
	                k = f + 16 | 0;
	                l = f + 12 | 0;
	                m = f + 8 | 0;
	                n = f + 4 | 0;
	                o = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = 0;
	                if ((c[k >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0) {
	                    c[g >> 2] = -1;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                c[c[k >> 2] >> 2] = 0;
	                c[c[l >> 2] >> 2] = 0;
	                c[m >> 2] = Fh(c[j >> 2] | 0, 1) | 0;
	                if ((c[m >> 2] | 0) == -1) {
	                    c[g >> 2] = -1;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                if ((c[m >> 2] | 0) > 0) {
	                    m = c[h >> 2] | 0;
	                    e = c[j >> 2] | 0;
	                    DC(m, 1824, 0, e, IH(21) | 0, 1);
	                    c[g >> 2] = 1;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                c[n >> 2] = 0;
	                c[n >> 2] = Ch(c[j >> 2] | 0, o) | 0;
	                e = c[(c[h >> 2] | 0) + 156 >> 2] | 0;
	                if (!(c[n >> 2] | 0)) {
	                    m = AP(e, c[j >> 2] | 0, -1) | 0;
	                    c[c[l >> 2] >> 2] = m
	                } else {
	                    m = AP(e, c[n >> 2] | 0, -1) | 0;
	                    c[c[l >> 2] >> 2] = m;
	                    zb[c[135736 >> 2] & 511](c[n >> 2] | 0)
	                }
	                n = RD(c[h >> 2] | 0, c[o >> 2] | 0) | 0;
	                c[c[k >> 2] >> 2] = n;
	                if ((c[o >> 2] | 0) != 0 ? (zb[c[135736 >> 2] & 511](c[o >> 2] | 0), (c[c[k >> 2] >> 2] | 0) == 0) : 0) {
	                    k = c[h >> 2] | 0;
	                    h = IH(21) | 0;
	                    AB(k, 1824, 0, h, 154112, c[j >> 2] | 0, 0);
	                    c[g >> 2] = 2;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                c[g >> 2] = 0;
	                p = c[g >> 2] | 0;
	                i = f;
	                return p | 0
	            }

	            function AH(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (c[j >> 2] | 0) {
	                    d = c[g >> 2] | 0;
	                    b = c[j >> 2] | 0;
	                    if (c[(c[j >> 2] | 0) + 36 >> 2] | 0) {
	                        c[f >> 2] = BB(d, c[(c[b + 36 >> 2] | 0) + 8 >> 2] | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        k = c[f >> 2] | 0;
	                        i = e;
	                        return k | 0
	                    } else {
	                        c[f >> 2] = BB(d, 0, c[b + 8 >> 2] | 0) | 0;
	                        k = c[f >> 2] | 0;
	                        i = e;
	                        return k | 0
	                    }
	                } else if (c[h >> 2] | 0) {
	                    c[f >> 2] = BB(c[g >> 2] | 0, c[(c[h >> 2] | 0) + 16 >> 2] | 0, c[(c[h >> 2] | 0) + 12 >> 2] | 0) | 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                } else {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                return 0
	            }

	            function BH(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[h >> 2] = Cb[c[135744 >> 2] & 511](36) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    tC(c[f >> 2] | 0, 164272, 0);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } else {
	                    b = (c[h >> 2] | 0) + 0 | 0;
	                    a = b + 36 | 0;
	                    do {
	                        c[b >> 2] = 0;
	                        b = b + 4 | 0
	                    } while ((b | 0) < (a | 0));
	                    c[c[h >> 2] >> 2] = 26;
	                    c[(c[h >> 2] | 0) + 20 >> 2] = c[g >> 2];
	                    dG((c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] | 0) + 48 | 0, 10, c[h >> 2] | 0) | 0;
	                    c[e >> 2] = c[h >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                return 0
	            }

	            function CH(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](20) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    tC(c[e >> 2] | 0, 164232, 0);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    a = c[f >> 2] | 0;
	                    c[a + 0 >> 2] = 0;
	                    c[a + 4 >> 2] = 0;
	                    c[a + 8 >> 2] = 0;
	                    c[a + 12 >> 2] = 0;
	                    c[a + 16 >> 2] = 0;
	                    c[c[f >> 2] >> 2] = 2001;
	                    dG((c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] | 0) + 48 | 0, 10, c[f >> 2] | 0) | 0;
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function DH(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                g = i;
	                i = i + 48 | 0;
	                h = g + 40 | 0;
	                j = g + 36 | 0;
	                k = g + 32 | 0;
	                l = g + 28 | 0;
	                m = g + 24 | 0;
	                n = g + 20 | 0;
	                o = g + 16 | 0;
	                p = g + 12 | 0;
	                q = g + 8 | 0;
	                r = g + 4 | 0;
	                s = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                if (!(c[l >> 2] | 0)) {
	                    PC(c[j >> 2] | 0, c[(c[k >> 2] | 0) + 12 >> 2] | 0, 3069, 165168, 0, 0);
	                    c[h >> 2] = -1;
	                    t = c[h >> 2] | 0;
	                    i = g;
	                    return t | 0
	                }
	                if (!(c[m >> 2] | 0))c[o >> 2] = c[(c[k >> 2] | 0) + 12 >> 2]; else c[o >> 2] = c[m >> 2];
	                if (!(c[(c[l >> 2] | 0) + 12 >> 2] | 0)) {
	                    GE(c[j >> 2] | 0, 3037, 0, c[o >> 2] | 0, 165248, 0);
	                    c[h >> 2] = 3037;
	                    t = c[h >> 2] | 0;
	                    i = g;
	                    return t | 0
	                }
	                c[p >> 2] = 0;
	                c[q >> 2] = 0;
	                if (!(c[m >> 2] | 0))c[q >> 2] = 0; else c[q >> 2] = bj(c[(c[m >> 2] | 0) + 32 >> 2] | 0, c[(c[m >> 2] | 0) + 20 >> 2] | 0) | 0;
	                if (c[q >> 2] | 0) {
	                    c[s >> 2] = 0;
	                    c[r >> 2] = 0;
	                    while (1) {
	                        if (!(c[(c[q >> 2] | 0) + (c[r >> 2] << 2) >> 2] | 0))break;
	                        c[s >> 2] = (c[s >> 2] | 0) + 1;
	                        c[r >> 2] = (c[r >> 2] | 0) + 1
	                    }
	                    c[p >> 2] = Cb[c[135744 >> 2] & 511]((c[s >> 2] << 1) + 1 << 2) | 0;
	                    if (!(c[p >> 2] | 0)) {
	                        tC(c[j >> 2] | 0, 165304, 0);
	                        zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                        c[h >> 2] = -1;
	                        t = c[h >> 2] | 0;
	                        i = g;
	                        return t | 0
	                    }
	                    c[r >> 2] = 0;
	                    while (1) {
	                        if ((c[r >> 2] | 0) >= (c[s >> 2] | 0))break;
	                        c[(c[p >> 2] | 0) + (c[r >> 2] << 1 << 2) >> 2] = c[(c[(c[q >> 2] | 0) + (c[r >> 2] << 2) >> 2] | 0) + 8 >> 2];
	                        c[(c[p >> 2] | 0) + ((c[r >> 2] << 1) + 1 << 2) >> 2] = c[(c[(c[q >> 2] | 0) + (c[r >> 2] << 2) >> 2] | 0) + 12 >> 2];
	                        c[r >> 2] = (c[r >> 2] | 0) + 1
	                    }
	                    c[(c[p >> 2] | 0) + (c[s >> 2] << 1 << 2) >> 2] = 0;
	                    zb[c[135736 >> 2] & 511](c[q >> 2] | 0)
	                }
	                q = c[(c[l >> 2] | 0) + 12 >> 2] | 0;
	                s = c[p >> 2] | 0;
	                if (c[n >> 2] | 0) {
	                    n = MQ(q, 0, 4, s) | 0;
	                    c[(c[l >> 2] | 0) + 16 >> 2] = n
	                } else {
	                    n = MQ(q, 0, 2, s) | 0;
	                    c[(c[l >> 2] | 0) + 16 >> 2] = n
	                }
	                if (c[p >> 2] | 0)zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                if (!(c[(c[l >> 2] | 0) + 16 >> 2] | 0)) {
	                    GE(c[j >> 2] | 0, 3037, 0, c[o >> 2] | 0, 165336, c[(c[l >> 2] | 0) + 12 >> 2] | 0);
	                    c[h >> 2] = 3037;
	                    t = c[h >> 2] | 0;
	                    i = g;
	                    return t | 0
	                } else {
	                    c[h >> 2] = 0;
	                    t = c[h >> 2] | 0;
	                    i = g;
	                    return t | 0
	                }
	                return 0
	            }

	            function EH(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                } else {
	                    c[e >> 2] = (c[f >> 2] | 0) == (c[g >> 2] | 0) & 1;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                return 0
	            }

	            function FH() {
	                var a = 0, b = 0, d = 0, e = 0, f = 0;
	                a = i;
	                i = i + 16 | 0;
	                b = a + 8 | 0;
	                d = a + 4 | 0;
	                e = a;
	                if (c[42590] | 0) {
	                    i = a;
	                    return
	                }
	                c[42592] = Ij(40) | 0;
	                c[42596] = eI(170376, 45, 0) | 0;
	                c[(c[42596] | 0) + 64 >> 2] = c[42596];
	                c[(c[42596] | 0) + 52 >> 2] = 3;
	                c[(c[42596] | 0) + 52 >> 2] = 3;
	                c[b >> 2] = fI() | 0;
	                if (!(c[b >> 2] | 0)) {
	                    i = a;
	                    return
	                }
	                c[(c[42596] | 0) + 28 >> 2] = c[b >> 2];
	                c[d >> 2] = Cb[c[135744 >> 2] & 511](20) | 0;
	                if (!(c[d >> 2] | 0)) {
	                    gI(0, 170392);
	                    i = a;
	                    return
	                }
	                f = c[d >> 2] | 0;
	                c[f + 0 >> 2] = 0;
	                c[f + 4 >> 2] = 0;
	                c[f + 8 >> 2] = 0;
	                c[f + 12 >> 2] = 0;
	                c[f + 16 >> 2] = 0;
	                c[c[d >> 2] >> 2] = 6;
	                c[(c[b >> 2] | 0) + 12 >> 2] = c[d >> 2];
	                c[b >> 2] = fI() | 0;
	                if (!(c[b >> 2] | 0)) {
	                    i = a;
	                    return
	                }
	                c[(c[b >> 2] | 0) + 16 >> 2] = 0;
	                c[(c[b >> 2] | 0) + 20 >> 2] = 1073741824;
	                c[(c[d >> 2] | 0) + 12 >> 2] = c[b >> 2];
	                c[e >> 2] = Cb[c[135744 >> 2] & 511](44) | 0;
	                if (!(c[e >> 2] | 0)) {
	                    gI(0, 170432);
	                    i = a;
	                    return
	                }
	                d = (c[e >> 2] | 0) + 0 | 0;
	                f = d + 44 | 0;
	                do {
	                    c[d >> 2] = 0;
	                    d = d + 4 | 0
	                } while ((d | 0) < (f | 0));
	                c[c[e >> 2] >> 2] = 2;
	                c[(c[e >> 2] | 0) + 28 >> 2] = 1;
	                c[(c[e >> 2] | 0) + 24 >> 2] = 2;
	                c[(c[b >> 2] | 0) + 12 >> 2] = c[e >> 2];
	                c[e >> 2] = Cb[c[135744 >> 2] & 511](44) | 0;
	                if (!(c[e >> 2] | 0)) {
	                    gI(0, 170464);
	                    i = a;
	                    return
	                } else {
	                    d = (c[e >> 2] | 0) + 0 | 0;
	                    f = d + 44 | 0;
	                    do {
	                        c[d >> 2] = 0;
	                        d = d + 4 | 0
	                    } while ((d | 0) < (f | 0));
	                    c[(c[e >> 2] | 0) + 28 >> 2] = 1;
	                    c[(c[e >> 2] | 0) + 24 >> 2] = 2;
	                    c[(c[42596] | 0) + 84 >> 2] = c[e >> 2];
	                    c[42634] = eI(170520, 46, c[42596] | 0) | 0;
	                    c[42638] = eI(170544, 1, c[42634] | 0) | 0;
	                    c[42642] = eI(170560, 3, c[42634] | 0) | 0;
	                    c[42646] = eI(170576, 10, c[42634] | 0) | 0;
	                    c[42652] = eI(170592, 11, c[42634] | 0) | 0;
	                    c[42656] = eI(170616, 4, c[42634] | 0) | 0;
	                    c[42660] = eI(170632, 8, c[42634] | 0) | 0;
	                    c[42666] = eI(170648, 9, c[42634] | 0) | 0;
	                    c[42670] = eI(170672, 6, c[42634] | 0) | 0;
	                    c[42676] = eI(170688, 7, c[42634] | 0) | 0;
	                    c[42680] = eI(170712, 5, c[42634] | 0) | 0;
	                    c[42686] = eI(170728, 12, c[42634] | 0) | 0;
	                    c[42690] = eI(170752, 13, c[42634] | 0) | 0;
	                    c[42694] = eI(170768, 14, c[42634] | 0) | 0;
	                    c[42698] = eI(170784, 15, c[42634] | 0) | 0;
	                    c[42702] = eI(170800, 29, c[42634] | 0) | 0;
	                    c[42708] = eI(170816, 43, c[42634] | 0) | 0;
	                    c[42714] = eI(170840, 44, c[42634] | 0) | 0;
	                    c[42720] = eI(170864, 28, c[42634] | 0) | 0;
	                    c[42724] = eI(170888, 21, c[42634] | 0) | 0;
	                    c[42728] = eI(170904, 30, c[42642] | 0) | 0;
	                    c[42736] = eI(170920, 31, c[42728] | 0) | 0;
	                    c[42742] = eI(170952, 32, c[42736] | 0) | 0;
	                    c[42746] = eI(170976, 37, c[42728] | 0) | 0;
	                    c[42750] = eI(170992, 35, c[42746] | 0) | 0;
	                    c[42754] = eI(171008, 39, c[42750] | 0) | 0;
	                    c[42758] = eI(171024, 41, c[42754] | 0) | 0;
	                    c[42766] = eI(171040, 33, c[42728] | 0) | 0;
	                    c[42772] = eI(171072, 38, c[42766] | 0) | 0;
	                    c[42778] = eI(171096, 36, c[42772] | 0) | 0;
	                    c[42784] = eI(171120, 40, c[42778] | 0) | 0;
	                    c[42790] = eI(171144, 42, c[42784] | 0) | 0;
	                    c[42796] = eI(171168, 34, c[42766] | 0) | 0;
	                    c[42804] = eI(171192, 2, c[42638] | 0) | 0;
	                    c[42808] = eI(171224, 16, c[42804] | 0) | 0;
	                    c[42814] = eI(171240, 17, c[42808] | 0) | 0;
	                    c[42818] = eI(171264, 20, c[42808] | 0) | 0;
	                    c[42822] = eI(171280, 18, c[42808] | 0) | 0;
	                    c[42826] = eI(171296, 22, c[42818] | 0) | 0;
	                    c[42830] = eI(171312, 23, c[42826] | 0) | 0;
	                    c[42834] = eI(171328, 24, c[42826] | 0) | 0;
	                    c[42838] = eI(171344, 26, c[42826] | 0) | 0;
	                    c[42844] = eI(171360, 27, c[42634] | 0) | 0;
	                    c[(c[42844] | 0) + 28 >> 2] = c[42838];
	                    c[42848] = eI(171384, 25, c[42634] | 0) | 0;
	                    c[(c[42848] | 0) + 28 >> 2] = c[42834];
	                    c[42854] = eI(171400, 19, c[42634] | 0) | 0;
	                    c[(c[42854] | 0) + 28 >> 2] = c[42822];
	                    c[42590] = 1;
	                    i = a;
	                    return
	                }
	            }

	            function GH() {
	                var a = 0, b = 0;
	                a = i;
	                i = i + 16 | 0;
	                b = a;
	                if (!(c[42590] | 0)) {
	                    i = a;
	                    return
	                }
	                TA(c[(c[42596] | 0) + 84 >> 2] | 0);
	                c[b >> 2] = c[(c[42596] | 0) + 28 >> 2];
	                TA(c[(c[(c[(c[b >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[(c[(c[b >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[(c[b >> 2] | 0) + 12 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[b >> 2] | 0);
	                c[(c[42596] | 0) + 28 >> 2] = 0;
	                Kj(c[42592] | 0, 360);
	                c[42590] = 0;
	                i = a;
	                return
	            }

	            function HH(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                a:do if (!(c[f >> 2] | 0))c[e >> 2] = -1; else {
	                    if ((c[c[f >> 2] >> 2] | 0) != 1) {
	                        c[e >> 2] = -1;
	                        break
	                    }
	                    switch (c[(c[f >> 2] | 0) + 88 >> 2] | 0) {
	                        case 15:
	                        {
	                            if ((c[g >> 2] | 0) == 1006 | (c[g >> 2] | 0) == 1008) {
	                                c[e >> 2] = 1;
	                                break a
	                            } else {
	                                c[e >> 2] = 0;
	                                break a
	                            }
	                            break
	                        }
	                        case 3:
	                        {
	                            if ((c[g >> 2] | 0) == 1004 | (c[g >> 2] | 0) == 1005 | (c[g >> 2] | 0) == 1006 | (c[g >> 2] | 0) == 1008 | (c[g >> 2] | 0) == 1007 | (c[g >> 2] | 0) == 1002 | (c[g >> 2] | 0) == 1003 | (c[g >> 2] | 0) == 1e3 | (c[g >> 2] | 0) == 1001) {
	                                c[e >> 2] = 1;
	                                break a
	                            } else {
	                                c[e >> 2] = 0;
	                                break a
	                            }
	                            break
	                        }
	                        case 14:
	                        case 13:
	                        case 12:
	                        case 11:
	                        case 10:
	                        case 9:
	                        case 8:
	                        case 7:
	                        case 6:
	                        case 5:
	                        case 4:
	                        {
	                            if ((c[g >> 2] | 0) == 1006 | (c[g >> 2] | 0) == 1007 | (c[g >> 2] | 0) == 1008 | (c[g >> 2] | 0) == 1002 | (c[g >> 2] | 0) == 1003 | (c[g >> 2] | 0) == 1e3 | (c[g >> 2] | 0) == 1001) {
	                                c[e >> 2] = 1;
	                                break a
	                            } else {
	                                c[e >> 2] = 0;
	                                break a
	                            }
	                            break
	                        }
	                        case 43:
	                        case 44:
	                        case 29:
	                        case 21:
	                        case 28:
	                        case 1:
	                        {
	                            if ((c[g >> 2] | 0) == 1009 | (c[g >> 2] | 0) == 1011 | (c[g >> 2] | 0) == 1010 | (c[g >> 2] | 0) == 1006 | (c[g >> 2] | 0) == 1007 | (c[g >> 2] | 0) == 1008) {
	                                c[e >> 2] = 1;
	                                break a
	                            } else {
	                                c[e >> 2] = 0;
	                                break a
	                            }
	                            break
	                        }
	                        default:
	                        {
	                            c[e >> 2] = 0;
	                            break a
	                        }
	                    }
	                } while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function IH(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                if (!(c[42590] | 0))FH();
	                do switch (c[e >> 2] | 0) {
	                    case 46:
	                    {
	                        c[d >> 2] = c[42634];
	                        break
	                    }
	                    case 38:
	                    {
	                        c[d >> 2] = c[42772];
	                        break
	                    }
	                    case 23:
	                    {
	                        c[d >> 2] = c[42830];
	                        break
	                    }
	                    case 22:
	                    {
	                        c[d >> 2] = c[42826];
	                        break
	                    }
	                    case 3:
	                    {
	                        c[d >> 2] = c[42642];
	                        break
	                    }
	                    case 34:
	                    {
	                        c[d >> 2] = c[42796];
	                        break
	                    }
	                    case 36:
	                    {
	                        c[d >> 2] = c[42778];
	                        break
	                    }
	                    case 16:
	                    {
	                        c[d >> 2] = c[42808];
	                        break
	                    }
	                    case 37:
	                    {
	                        c[d >> 2] = c[42746];
	                        break
	                    }
	                    case 44:
	                    {
	                        c[d >> 2] = c[42714];
	                        break
	                    }
	                    case 26:
	                    {
	                        c[d >> 2] = c[42838];
	                        break
	                    }
	                    case 29:
	                    {
	                        c[d >> 2] = c[42702];
	                        break
	                    }
	                    case 32:
	                    {
	                        c[d >> 2] = c[42742];
	                        break
	                    }
	                    case 15:
	                    {
	                        c[d >> 2] = c[42698];
	                        break
	                    }
	                    case 10:
	                    {
	                        c[d >> 2] = c[42646];
	                        break
	                    }
	                    case 18:
	                    {
	                        c[d >> 2] = c[42822];
	                        break
	                    }
	                    case 8:
	                    {
	                        c[d >> 2] = c[42660];
	                        break
	                    }
	                    case 5:
	                    {
	                        c[d >> 2] = c[42680];
	                        break
	                    }
	                    case 12:
	                    {
	                        c[d >> 2] = c[42686];
	                        break
	                    }
	                    case 24:
	                    {
	                        c[d >> 2] = c[42834];
	                        break
	                    }
	                    case 11:
	                    {
	                        c[d >> 2] = c[42652];
	                        break
	                    }
	                    case 30:
	                    {
	                        c[d >> 2] = c[42728];
	                        break
	                    }
	                    case 1:
	                    {
	                        c[d >> 2] = c[42638];
	                        break
	                    }
	                    case 17:
	                    {
	                        c[d >> 2] = c[42814];
	                        break
	                    }
	                    case 21:
	                    {
	                        c[d >> 2] = c[42724];
	                        break
	                    }
	                    case 28:
	                    {
	                        c[d >> 2] = c[42720];
	                        break
	                    }
	                    case 35:
	                    {
	                        c[d >> 2] = c[42750];
	                        break
	                    }
	                    case 2:
	                    {
	                        c[d >> 2] = c[42804];
	                        break
	                    }
	                    case 6:
	                    {
	                        c[d >> 2] = c[42670];
	                        break
	                    }
	                    case 27:
	                    {
	                        c[d >> 2] = c[42844];
	                        break
	                    }
	                    case 39:
	                    {
	                        c[d >> 2] = c[42754];
	                        break
	                    }
	                    case 33:
	                    {
	                        c[d >> 2] = c[42766];
	                        break
	                    }
	                    case 42:
	                    {
	                        c[d >> 2] = c[42790];
	                        break
	                    }
	                    case 4:
	                    {
	                        c[d >> 2] = c[42656];
	                        break
	                    }
	                    case 41:
	                    {
	                        c[d >> 2] = c[42758];
	                        break
	                    }
	                    case 9:
	                    {
	                        c[d >> 2] = c[42666];
	                        break
	                    }
	                    case 31:
	                    {
	                        c[d >> 2] = c[42736];
	                        break
	                    }
	                    case 45:
	                    {
	                        c[d >> 2] = c[42596];
	                        break
	                    }
	                    case 40:
	                    {
	                        c[d >> 2] = c[42784];
	                        break
	                    }
	                    case 43:
	                    {
	                        c[d >> 2] = c[42708];
	                        break
	                    }
	                    case 19:
	                    {
	                        c[d >> 2] = c[42854];
	                        break
	                    }
	                    case 7:
	                    {
	                        c[d >> 2] = c[42676];
	                        break
	                    }
	                    case 13:
	                    {
	                        c[d >> 2] = c[42690];
	                        break
	                    }
	                    case 20:
	                    {
	                        c[d >> 2] = c[42818];
	                        break
	                    }
	                    case 25:
	                    {
	                        c[d >> 2] = c[42848];
	                        break
	                    }
	                    case 14:
	                    {
	                        c[d >> 2] = c[42694];
	                        break
	                    }
	                    default:
	                        c[d >> 2] = 0
	                } while (0);
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function JH(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = -1;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                } else {
	                    c[(c[f >> 2] | 0) + 4 >> 2] = c[g >> 2];
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                return 0
	            }

	            function KH(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0))c[d >> 2] = 0; else c[d >> 2] = c[(c[e >> 2] | 0) + 4 >> 2];
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function LH(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                a:do if (!(c[e >> 2] | 0))c[d >> 2] = 0; else switch (c[c[e >> 2] >> 2] | 0) {
	                    case 29:
	                    case 26:
	                    case 24:
	                    case 23:
	                    case 22:
	                    case 20:
	                    case 18:
	                    case 17:
	                    case 16:
	                    case 46:
	                    case 2:
	                    case 1:
	                    {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 8 >> 2];
	                        break a;
	                        break
	                    }
	                    default:
	                    {
	                        c[d >> 2] = 0;
	                        break a
	                    }
	                } while (0);
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function MH(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                if ((c[e >> 2] | 0) != 0 ? (c[c[e >> 2] >> 2] | 0) == 15 : 0) {
	                    c[d >> 2] = c[(c[e >> 2] | 0) + 8 >> 2];
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                }
	                c[d >> 2] = 0;
	                f = c[d >> 2] | 0;
	                i = b;
	                return f | 0
	            }

	            function NH(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = hI(28) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[(c[h >> 2] | 0) + 8 >> 2] = c[f >> 2];
	                if (c[g >> 2] | 0)c[(c[h >> 2] | 0) + 12 >> 2] = c[g >> 2];
	                c[e >> 2] = c[h >> 2];
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function OH(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = hI(21) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } else {
	                    c[(c[h >> 2] | 0) + 8 >> 2] = c[g >> 2];
	                    c[(c[h >> 2] | 0) + 12 >> 2] = c[f >> 2];
	                    c[e >> 2] = c[h >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                return 0
	            }

	            function PH(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                while (1) {
	                    if (!(c[d >> 2] | 0))break;
	                    switch (c[c[d >> 2] >> 2] | 0) {
	                        case 46:
	                        case 29:
	                        case 27:
	                        case 26:
	                        case 25:
	                        case 24:
	                        case 23:
	                        case 22:
	                        case 20:
	                        case 19:
	                        case 18:
	                        case 17:
	                        case 16:
	                        case 2:
	                        case 1:
	                        {
	                            if (c[(c[d >> 2] | 0) + 8 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                            break
	                        }
	                        case 21:
	                        case 28:
	                        {
	                            if (c[(c[d >> 2] | 0) + 12 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 12 >> 2] | 0);
	                            if (c[(c[d >> 2] | 0) + 8 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                            break
	                        }
	                        case 44:
	                        {
	                            if (c[(c[d >> 2] | 0) + 8 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                            break
	                        }
	                        case 43:
	                        {
	                            if (c[(c[d >> 2] | 0) + 8 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                            break
	                        }
	                        default:
	                        {
	                        }
	                    }
	                    c[e >> 2] = c[d >> 2];
	                    c[d >> 2] = c[(c[d >> 2] | 0) + 4 >> 2];
	                    zb[c[135736 >> 2] & 511](c[e >> 2] | 0)
	                }
	                i = b;
	                return
	            }

	            function QH(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[42590] | 0))FH();
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                } else {
	                    c[e >> 2] = Tj(c[42592] | 0, c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                return 0
	            }

	            function RH(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = b;
	                c[h >> 2] = c[g >> 2];
	                c[j >> 2] = 0;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                while (1) {
	                    if (((d[c[h >> 2] >> 0] | 0 | 0) != 0 ? (d[c[h >> 2] >> 0] | 0 | 0) != 13 : 0) ? (d[c[h >> 2] >> 0] | 0 | 0) != 9 : 0)m = (d[c[h >> 2] >> 0] | 0 | 0) != 10; else m = 0;
	                    n = c[h >> 2] | 0;
	                    if (!m)break;
	                    c[h >> 2] = n + 1
	                }
	                if (!(d[n >> 0] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[j >> 2] = my(c[g >> 2] | 0) | 0;
	                c[k >> 2] = (c[j >> 2] | 0) + ((c[h >> 2] | 0) - (c[g >> 2] | 0));
	                do {
	                    if (!(((d[c[k >> 2] >> 0] | 0 | 0) != 13 ? (d[c[k >> 2] >> 0] | 0 | 0) != 9 : 0) ? (d[c[k >> 2] >> 0] | 0 | 0) != 10 : 0))a[c[k >> 2] >> 0] = 32;
	                    c[k >> 2] = (c[k >> 2] | 0) + 1
	                } while ((d[c[k >> 2] >> 0] | 0 | 0) != 0);
	                c[f >> 2] = c[j >> 2];
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function SH(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 20 | 0;
	                h = e + 16 | 0;
	                j = e + 12 | 0;
	                k = e + 8 | 0;
	                l = e + 4 | 0;
	                m = e;
	                c[g >> 2] = b;
	                c[h >> 2] = c[g >> 2];
	                c[m >> 2] = 0;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                while (1) {
	                    do if (d[c[h >> 2] >> 0] | 0)if ((d[c[h >> 2] >> 0] | 0 | 0) == 32)o = 1; else {
	                        if (9 <= (d[c[h >> 2] >> 0] | 0 | 0) ? (d[c[h >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            o = 1;
	                            break
	                        }
	                        o = (d[c[h >> 2] >> 0] | 0 | 0) == 13
	                    } else o = 0; while (0);
	                    p = c[h >> 2] | 0;
	                    if (!o)break;
	                    c[h >> 2] = p + 1
	                }
	                c[j >> 2] = p;
	                while (1) {
	                    if (!(d[c[j >> 2] >> 0] | 0))break;
	                    if ((d[c[j >> 2] >> 0] | 0 | 0) == 32) {
	                        if ((d[(c[j >> 2] | 0) + 1 >> 0] | 0 | 0) == 32) {
	                            q = 17;
	                            break
	                        }
	                        if (9 <= (d[(c[j >> 2] | 0) + 1 >> 0] | 0 | 0) ? (d[(c[j >> 2] | 0) + 1 >> 0] | 0 | 0) <= 10 : 0) {
	                            q = 17;
	                            break
	                        }
	                        if ((d[(c[j >> 2] | 0) + 1 >> 0] | 0 | 0) == 13) {
	                            q = 17;
	                            break
	                        }
	                    }
	                    if ((d[c[j >> 2] >> 0] | 0 | 0) == 10) {
	                        q = 21;
	                        break
	                    }
	                    if ((d[c[j >> 2] >> 0] | 0 | 0) == 9) {
	                        q = 21;
	                        break
	                    }
	                    if ((d[c[j >> 2] >> 0] | 0 | 0) == 13) {
	                        q = 21;
	                        break
	                    }
	                    c[j >> 2] = (c[j >> 2] | 0) + 1
	                }
	                if ((q | 0) == 17)c[m >> 2] = (c[j >> 2] | 0) - (c[h >> 2] | 0); else if ((q | 0) == 21)c[m >> 2] = (c[j >> 2] | 0) - (c[h >> 2] | 0);
	                if (!(c[m >> 2] | 0)) {
	                    c[k >> 2] = c[j >> 2];
	                    c[j >> 2] = (c[j >> 2] | 0) + -1;
	                    while (1) {
	                        do if ((c[j >> 2] | 0) >>> 0 > (c[h >> 2] | 0) >>> 0)if ((d[c[j >> 2] >> 0] | 0 | 0) == 32)r = 1; else {
	                            if (9 <= (d[c[j >> 2] >> 0] | 0 | 0) ? (d[c[j >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                r = 1;
	                                break
	                            }
	                            r = (d[c[j >> 2] >> 0] | 0 | 0) == 13
	                        } else r = 0; while (0);
	                        s = c[j >> 2] | 0;
	                        if (!r)break;
	                        c[j >> 2] = s + -1
	                    }
	                    c[j >> 2] = s + 1;
	                    if ((c[h >> 2] | 0) == (c[g >> 2] | 0) ? (c[k >> 2] | 0) == (c[j >> 2] | 0) : 0) {
	                        c[f >> 2] = 0;
	                        n = c[f >> 2] | 0;
	                        i = e;
	                        return n | 0
	                    }
	                    c[f >> 2] = ly(c[h >> 2] | 0, (c[j >> 2] | 0) - (c[h >> 2] | 0) | 0) | 0;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                c[h >> 2] = my(c[h >> 2] | 0) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                c[l >> 2] = (c[h >> 2] | 0) + (c[m >> 2] | 0);
	                c[j >> 2] = c[l >> 2];
	                a:while (1) {
	                    if (!(d[c[j >> 2] >> 0] | 0))break;
	                    do if ((d[c[j >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[j >> 2] >> 0] | 0 | 0) ? (d[c[j >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[j >> 2] >> 0] | 0 | 0) != 13) {
	                            m = c[j >> 2] | 0;
	                            c[j >> 2] = m + 1;
	                            k = a[m >> 0] | 0;
	                            m = c[l >> 2] | 0;
	                            c[l >> 2] = m + 1;
	                            a[m >> 0] = k;
	                            continue a
	                        }
	                    } while (0);
	                    c[j >> 2] = (c[j >> 2] | 0) + 1;
	                    while (1) {
	                        do if ((d[c[j >> 2] >> 0] | 0 | 0) == 32)t = 1; else {
	                            if (9 <= (d[c[j >> 2] >> 0] | 0 | 0) ? (d[c[j >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                t = 1;
	                                break
	                            }
	                            t = (d[c[j >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        u = c[j >> 2] | 0;
	                        if (!t)break;
	                        c[j >> 2] = u + 1
	                    }
	                    if (!(d[u >> 0] | 0))continue;
	                    k = c[l >> 2] | 0;
	                    c[l >> 2] = k + 1;
	                    a[k >> 0] = 32
	                }
	                a[c[l >> 2] >> 0] = 0;
	                c[f >> 2] = c[h >> 2];
	                n = c[f >> 2] | 0;
	                i = e;
	                return n | 0
	            }

	            function TH(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 12 | 0;
	                h = f + 8 | 0;
	                j = f + 4 | 0;
	                k = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                e = iI(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, 0, 0, 1, 1, 0) | 0;
	                i = f;
	                return e | 0
	            }

	            function UH(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 12 | 0;
	                h = f + 8 | 0;
	                j = f + 4 | 0;
	                k = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                e = iI(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, 1, 0, 1, 0, 1) | 0;
	                i = f;
	                return e | 0
	            }

	            function VH(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                d = TH(c[f >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0, 0) | 0;
	                i = e;
	                return d | 0
	            }

	            function WH(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 16 | 0;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                g = b + 4 | 0;
	                h = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                c[g >> 2] = 0;
	                a:while (1) {
	                    if (!(c[e >> 2] | 0)) {
	                        j = 20;
	                        break
	                    }
	                    switch (c[c[e >> 2] >> 2] | 0) {
	                        case 43:
	                        {
	                            c[h >> 2] = jI(c[e >> 2] | 0) | 0;
	                            if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                                a = my(c[(c[e >> 2] | 0) + 8 >> 2] | 0) | 0;
	                                c[(c[h >> 2] | 0) + 8 >> 2] = a
	                            }
	                            break
	                        }
	                        case 29:
	                        case 18:
	                        case 26:
	                        case 24:
	                        case 23:
	                        case 22:
	                        case 20:
	                        case 17:
	                        case 16:
	                        case 2:
	                        case 1:
	                        case 46:
	                        {
	                            c[h >> 2] = jI(c[e >> 2] | 0) | 0;
	                            if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                                a = my(c[(c[e >> 2] | 0) + 8 >> 2] | 0) | 0;
	                                c[(c[h >> 2] | 0) + 8 >> 2] = a
	                            }
	                            break
	                        }
	                        case 19:
	                        case 27:
	                        case 25:
	                        case 45:
	                        {
	                            j = 4;
	                            break a;
	                            break
	                        }
	                        case 28:
	                        case 21:
	                        {
	                            c[h >> 2] = jI(c[e >> 2] | 0) | 0;
	                            if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                                a = my(c[(c[e >> 2] | 0) + 8 >> 2] | 0) | 0;
	                                c[(c[h >> 2] | 0) + 8 >> 2] = a
	                            }
	                            if (c[(c[e >> 2] | 0) + 12 >> 2] | 0) {
	                                a = my(c[(c[e >> 2] | 0) + 12 >> 2] | 0) | 0;
	                                c[(c[h >> 2] | 0) + 12 >> 2] = a
	                            }
	                            break
	                        }
	                        case 44:
	                        {
	                            c[h >> 2] = jI(c[e >> 2] | 0) | 0;
	                            if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                                a = my(c[(c[e >> 2] | 0) + 8 >> 2] | 0) | 0;
	                                c[(c[h >> 2] | 0) + 8 >> 2] = a
	                            }
	                            break
	                        }
	                        default:
	                            c[h >> 2] = jI(c[e >> 2] | 0) | 0
	                    }
	                    a = c[h >> 2] | 0;
	                    if (!(c[f >> 2] | 0))c[f >> 2] = a; else c[(c[g >> 2] | 0) + 4 >> 2] = a;
	                    c[g >> 2] = c[h >> 2];
	                    c[e >> 2] = c[(c[e >> 2] | 0) + 4 >> 2]
	                }
	                if ((j | 0) == 4) {
	                    PH(c[f >> 2] | 0);
	                    c[d >> 2] = 0;
	                    k = c[d >> 2] | 0;
	                    i = b;
	                    return k | 0
	                } else if ((j | 0) == 20) {
	                    c[d >> 2] = c[f >> 2];
	                    k = c[d >> 2] | 0;
	                    i = b;
	                    return k | 0
	                }
	                return 0
	            }

	            function XH(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = -2;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                do if ((c[c[f >> 2] >> 2] | 0) != 1)if ((c[c[f >> 2] >> 2] | 0) == 2) {
	                    c[h >> 2] = 2;
	                    break
	                } else {
	                    c[h >> 2] = 3;
	                    break
	                } else c[h >> 2] = 1; while (0);
	                do if ((c[c[g >> 2] >> 2] | 0) != 1)if ((c[c[g >> 2] >> 2] | 0) == 2) {
	                    c[j >> 2] = 2;
	                    break
	                } else {
	                    c[j >> 2] = 3;
	                    break
	                } else c[j >> 2] = 1; while (0);
	                c[e >> 2] = kI(c[c[f >> 2] >> 2] | 0, c[f >> 2] | 0, 0, c[h >> 2] | 0, c[c[g >> 2] >> 2] | 0, c[g >> 2] | 0, 0, c[j >> 2] | 0) | 0;
	                k = c[e >> 2] | 0;
	                i = d;
	                return k | 0
	            }

	            function YH(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if ((c[h >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0) {
	                    c[g >> 2] = -2;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                } else {
	                    c[g >> 2] = kI(c[c[h >> 2] >> 2] | 0, c[h >> 2] | 0, 0, c[j >> 2] | 0, c[c[k >> 2] >> 2] | 0, c[k >> 2] | 0, 0, c[l >> 2] | 0) | 0;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                return 0
	            }

	            function ZH(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                } else {
	                    c[d >> 2] = c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 8 >> 2];
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                }
	                return 0
	            }

	            function _H(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if (!(c[h >> 2] | 0)) {
	                    c[g >> 2] = -1;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                do if ((c[c[h >> 2] >> 2] | 0) == 1009) {
	                    if ((c[k >> 2] | 0) != (c[(c[(c[h >> 2] | 0) + 32 >> 2] | 0) + 8 >> 2] | 0)) {
	                        if (c[l >> 2] | 0)c[c[l >> 2] >> 2] = c[(c[(c[h >> 2] | 0) + 32 >> 2] | 0) + 8 >> 2];
	                        c[g >> 2] = 1830;
	                        m = c[g >> 2] | 0;
	                        i = f;
	                        return m | 0
	                    }
	                } else {
	                    if ((c[c[h >> 2] >> 2] | 0) == 1011) {
	                        if ((c[k >> 2] | 0) >>> 0 >= (c[(c[(c[h >> 2] | 0) + 32 >> 2] | 0) + 8 >> 2] | 0) >>> 0)break;
	                        if (c[l >> 2] | 0)c[c[l >> 2] >> 2] = c[(c[(c[h >> 2] | 0) + 32 >> 2] | 0) + 8 >> 2];
	                        c[g >> 2] = 1831;
	                        m = c[g >> 2] | 0;
	                        i = f;
	                        return m | 0
	                    }
	                    if ((c[c[h >> 2] >> 2] | 0) != 1010) {
	                        c[g >> 2] = $H(0, c[h >> 2] | 0, c[j >> 2] | 0, 0) | 0;
	                        m = c[g >> 2] | 0;
	                        i = f;
	                        return m | 0
	                    }
	                    if ((c[k >> 2] | 0) >>> 0 > (c[(c[(c[h >> 2] | 0) + 32 >> 2] | 0) + 8 >> 2] | 0) >>> 0) {
	                        if (c[l >> 2] | 0)c[c[l >> 2] >> 2] = c[(c[(c[h >> 2] | 0) + 32 >> 2] | 0) + 8 >> 2];
	                        c[g >> 2] = 1832;
	                        m = c[g >> 2] | 0;
	                        i = f;
	                        return m | 0
	                    }
	                } while (0);
	                c[g >> 2] = 0;
	                m = c[g >> 2] | 0;
	                i = f;
	                return m | 0
	            }

	            function $H(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if (c[l >> 2] | 0) {
	                    c[g >> 2] = lI(c[j >> 2] | 0, 0, c[c[l >> 2] >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, 0) | 0;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                if (c[h >> 2] | 0) {
	                    c[g >> 2] = lI(c[j >> 2] | 0, 0, c[(c[h >> 2] | 0) + 88 >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, 0) | 0;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                } else {
	                    c[g >> 2] = -1;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                return 0
	            }

	            function aI(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                h = i;
	                i = i + 32 | 0;
	                j = h + 20 | 0;
	                k = h + 16 | 0;
	                l = h + 12 | 0;
	                m = h + 8 | 0;
	                n = h + 4 | 0;
	                o = h;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                g = mI(c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0) | 0;
	                i = h;
	                return g | 0
	            }

	            function bI(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                h = i;
	                i = i + 32 | 0;
	                j = h + 20 | 0;
	                k = h + 16 | 0;
	                l = h + 12 | 0;
	                m = h + 8 | 0;
	                n = h + 4 | 0;
	                o = h;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                g = lI(c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0) | 0;
	                i = h;
	                return g | 0
	            }

	            function cI(d, f) {
	                d = d | 0;
	                f = f | 0;
	                var j = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0, J = 0, K = 0, L = 0, M = 0, N = 0, O = 0, P = 0, S = 0, T = 0, U = 0, V = 0, W = 0.0;
	                j = i;
	                i = i + 512 | 0;
	                l = j + 16 | 0;
	                m = j + 148 | 0;
	                n = j + 144 | 0;
	                o = j + 140 | 0;
	                p = j + 120 | 0;
	                q = j + 116 | 0;
	                r = j + 112 | 0;
	                s = j + 108 | 0;
	                t = j + 104 | 0;
	                u = j + 100 | 0;
	                v = j + 80 | 0;
	                w = j + 76 | 0;
	                x = j + 400 | 0;
	                y = j + 72 | 0;
	                z = j + 68 | 0;
	                A = j + 64 | 0;
	                B = j + 60 | 0;
	                C = j + 56 | 0;
	                D = j + 8 | 0;
	                E = j;
	                F = j + 368 | 0;
	                G = j + 332 | 0;
	                H = j + 302 | 0;
	                I = j + 52 | 0;
	                J = j + 272 | 0;
	                K = j + 48 | 0;
	                L = j + 222 | 0;
	                M = j + 44 | 0;
	                N = j + 192 | 0;
	                O = j + 152 | 0;
	                c[n >> 2] = d;
	                c[o >> 2] = f;
	                if ((c[o >> 2] | 0) == 0 | (c[n >> 2] | 0) == 0) {
	                    c[m >> 2] = -1;
	                    P = c[m >> 2] | 0;
	                    i = j;
	                    return P | 0
	                }
	                c[c[o >> 2] >> 2] = 0;
	                a:do switch (c[c[n >> 2] >> 2] | 0) {
	                    case 9:
	                    {
	                        f = c[(c[n >> 2] | 0) + 8 >> 2] | 0;
	                        if ((c[(c[n >> 2] | 0) + 8 >> 2] | 0) < 0) {
	                            d = R(f | 0) | 0;
	                            S = c[(c[n >> 2] | 0) + 12 >> 2] & 15;
	                            c[l >> 2] = d;
	                            c[l + 4 >> 2] = S;
	                            JT(G, 35, 171648, l) | 0
	                        } else {
	                            S = c[(c[n >> 2] | 0) + 12 >> 2] & 15;
	                            c[l >> 2] = f;
	                            c[l + 4 >> 2] = S;
	                            JT(G, 35, 171664, l) | 0
	                        }
	                        S = my(G) | 0;
	                        c[c[o >> 2] >> 2] = S;
	                        break
	                    }
	                    case 8:
	                    {
	                        c[l >> 2] = c[(c[n >> 2] | 0) + 8 >> 2];
	                        JT(F, 30, 171608, l) | 0;
	                        S = my(F) | 0;
	                        c[c[o >> 2] >> 2] = S;
	                        break
	                    }
	                    case 2:
	                    {
	                        if (!(c[(c[n >> 2] | 0) + 8 >> 2] | 0)) {
	                            S = my(171424) | 0;
	                            c[c[o >> 2] >> 2] = S;
	                            break a
	                        }
	                        S = RH(c[(c[n >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        c[c[o >> 2] >> 2] = S;
	                        if (!(c[c[o >> 2] >> 2] | 0)) {
	                            S = my(c[(c[n >> 2] | 0) + 8 >> 2] | 0) | 0;
	                            c[c[o >> 2] >> 2] = S
	                        }
	                        break
	                    }
	                    case 3:
	                    {
	                        if (((e[(c[n >> 2] | 0) + 24 >> 1] | 0) >>> 8 & 65535 | 0) == 1 ? (c[(c[n >> 2] | 0) + 8 >> 2] | 0) == 0 : 0) {
	                            S = my(171448) | 0;
	                            c[c[o >> 2] >> 2] = S;
	                            break a
	                        }
	                        S = (c[n >> 2] | 0) + 8 | 0;
	                        c[p + 0 >> 2] = c[S + 0 >> 2];
	                        c[p + 4 >> 2] = c[S + 4 >> 2];
	                        c[p + 8 >> 2] = c[S + 8 >> 2];
	                        c[p + 12 >> 2] = c[S + 12 >> 2];
	                        c[p + 16 >> 2] = c[S + 16 >> 2];
	                        c[r >> 2] = 0;
	                        c[q >> 2] = ((e[p + 16 >> 1] | 0) >>> 8 & 65535) + 2;
	                        if (b[p + 16 >> 1] & 1)c[q >> 2] = (c[q >> 2] | 0) + 1;
	                        if (!(((e[p + 16 >> 1] | 0) >>> 1 & 127 | 0) != 0 ? ((e[p + 16 >> 1] | 0) >>> 1 & 127 | 0) != ((e[p + 16 >> 1] | 0) >>> 8 & 65535 | 0) : 0))c[q >> 2] = (c[q >> 2] | 0) + 1;
	                        c[r >> 2] = Cb[c[135744 >> 2] & 511](c[q >> 2] | 0) | 0;
	                        if (!(c[r >> 2] | 0)) {
	                            c[m >> 2] = -1;
	                            P = c[m >> 2] | 0;
	                            i = j;
	                            return P | 0
	                        }
	                        c[s >> 2] = c[r >> 2];
	                        if (b[p + 16 >> 1] & 1) {
	                            S = c[s >> 2] | 0;
	                            c[s >> 2] = S + 1;
	                            a[S >> 0] = 45
	                        }
	                        if (((e[p + 16 >> 1] | 0) >>> 1 & 127 | 0) == ((e[p + 16 >> 1] | 0) >>> 8 & 65535 | 0)) {
	                            S = c[s >> 2] | 0;
	                            c[s >> 2] = S + 1;
	                            a[S >> 0] = 48;
	                            S = c[s >> 2] | 0;
	                            c[s >> 2] = S + 1;
	                            a[S >> 0] = 46
	                        }
	                        do if (!(c[p + 8 >> 2] | 0)) {
	                            S = c[s >> 2] | 0;
	                            f = (c[q >> 2] | 0) - ((c[s >> 2] | 0) - (c[r >> 2] | 0)) | 0;
	                            if (c[p + 4 >> 2] | 0) {
	                                d = c[p >> 2] | 0;
	                                c[l >> 2] = c[p + 4 >> 2];
	                                c[l + 4 >> 2] = d;
	                                JT(S, f, 171472, l) | 0;
	                                break
	                            } else {
	                                c[l >> 2] = c[p >> 2];
	                                JT(S, f, 171480, l) | 0;
	                                break
	                            }
	                        } else {
	                            f = c[s >> 2] | 0;
	                            S = (c[q >> 2] | 0) - ((c[s >> 2] | 0) - (c[r >> 2] | 0)) | 0;
	                            d = c[p + 4 >> 2] | 0;
	                            T = c[p >> 2] | 0;
	                            c[l >> 2] = c[p + 8 >> 2];
	                            c[l + 4 >> 2] = d;
	                            c[l + 8 >> 2] = T;
	                            JT(f, S, 171456, l) | 0
	                        } while (0);
	                        do if ((e[p + 16 >> 1] | 0) >>> 1 & 127) {
	                            if (((e[p + 16 >> 1] | 0) >>> 1 & 127 | 0) != ((e[p + 16 >> 1] | 0) >>> 8 & 65535 | 0)) {
	                                c[t >> 2] = ((e[p + 16 >> 1] | 0) >>> 8 & 65535) - ((e[p + 16 >> 1] | 0) >>> 1 & 127);
	                                fU((c[s >> 2] | 0) + (c[t >> 2] | 0) + 1 | 0, (c[s >> 2] | 0) + (c[t >> 2] | 0) | 0, ((e[p + 16 >> 1] | 0) >>> 1 & 127) + 1 | 0) | 0;
	                                a[(c[s >> 2] | 0) + (c[t >> 2] | 0) >> 0] = 46;
	                                break
	                            }
	                            c[u >> 2] = 0;
	                            while (1) {
	                                U = c[u >> 2] | 0;
	                                if (!(a[(c[s >> 2] | 0) + (c[u >> 2] | 0) >> 0] | 0))break;
	                                c[u >> 2] = U + 1
	                            }
	                            if (U >>> 0 < ((e[p + 16 >> 1] | 0) >>> 8 & 65535) >>> 0) {
	                                fU((c[s >> 2] | 0) + (((e[p + 16 >> 1] | 0) >>> 8 & 65535) - (c[u >> 2] | 0)) | 0, c[s >> 2] | 0, (c[u >> 2] | 0) + 1 | 0) | 0;
	                                cU(c[s >> 2] | 0, 48, ((e[p + 16 >> 1] | 0) >>> 8 & 65535) - (c[u >> 2] | 0) | 0) | 0
	                            }
	                        } else {
	                            c[s >> 2] = (c[r >> 2] | 0) + (c[q >> 2] | 0) + -1;
	                            S = c[s >> 2] | 0;
	                            c[s >> 2] = S + -1;
	                            a[S >> 0] = 0;
	                            S = c[s >> 2] | 0;
	                            c[s >> 2] = S + -1;
	                            a[S >> 0] = 48;
	                            S = c[s >> 2] | 0;
	                            c[s >> 2] = S + -1;
	                            a[S >> 0] = 46
	                        } while (0);
	                        c[c[o >> 2] >> 2] = c[r >> 2];
	                        break
	                    }
	                    case 7:
	                    {
	                        S = Cb[c[135744 >> 2] & 511](8) | 0;
	                        c[c[o >> 2] >> 2] = S;
	                        if (c[c[o >> 2] >> 2] | 0) {
	                            S = c[c[o >> 2] >> 2] | 0;
	                            f = (c[(c[n >> 2] | 0) + 12 >> 2] | 0) >>> 4 & 31;
	                            c[l >> 2] = c[(c[n >> 2] | 0) + 12 >> 2] & 15;
	                            c[l + 4 >> 2] = f;
	                            JT(S, 8, 171632, l) | 0;
	                            break a
	                        }
	                        c[m >> 2] = -1;
	                        P = c[m >> 2] | 0;
	                        i = j;
	                        return P | 0
	                    }
	                    case 15:
	                    {
	                        if (c[(c[n >> 2] | 0) + 8 >> 2] | 0) {
	                            S = my(171528) | 0;
	                            c[c[o >> 2] >> 2] = S;
	                            break a
	                        } else {
	                            S = my(171536) | 0;
	                            c[c[o >> 2] >> 2] = S;
	                            break a
	                        }
	                        break
	                    }
	                    case 5:
	                    {
	                        S = Cb[c[135744 >> 2] & 511](6) | 0;
	                        c[c[o >> 2] >> 2] = S;
	                        if (c[c[o >> 2] >> 2] | 0) {
	                            S = c[c[o >> 2] >> 2] | 0;
	                            c[l >> 2] = (c[(c[n >> 2] | 0) + 12 >> 2] | 0) >>> 4 & 31;
	                            JT(S, 6, 171624, l) | 0;
	                            break a
	                        }
	                        c[m >> 2] = -1;
	                        P = c[m >> 2] | 0;
	                        i = j;
	                        return P | 0
	                    }
	                    case 42:
	                    case 40:
	                    case 38:
	                    case 36:
	                    case 35:
	                    case 39:
	                    case 41:
	                    case 37:
	                    case 33:
	                    case 32:
	                    case 31:
	                    case 34:
	                    case 30:
	                    {
	                        if (((e[(c[n >> 2] | 0) + 24 >> 1] | 0) >>> 8 & 65535 | 0) == 1 ? (c[(c[n >> 2] | 0) + 8 >> 2] | 0) == 0 : 0) {
	                            S = my(171488) | 0;
	                            c[c[o >> 2] >> 2] = S;
	                            break a
	                        }
	                        S = (c[n >> 2] | 0) + 8 | 0;
	                        c[v + 0 >> 2] = c[S + 0 >> 2];
	                        c[v + 4 >> 2] = c[S + 4 >> 2];
	                        c[v + 8 >> 2] = c[S + 8 >> 2];
	                        c[v + 12 >> 2] = c[S + 12 >> 2];
	                        c[v + 16 >> 2] = c[S + 16 >> 2];
	                        c[w >> 2] = ((e[v + 16 >> 1] | 0) >>> 8 & 65535) + 1;
	                        if (b[v + 16 >> 1] & 1)c[w >> 2] = (c[w >> 2] | 0) + 1;
	                        S = Cb[c[135744 >> 2] & 511](c[w >> 2] | 0) | 0;
	                        c[c[o >> 2] >> 2] = S;
	                        if (!(c[c[o >> 2] >> 2] | 0)) {
	                            c[m >> 2] = -1;
	                            P = c[m >> 2] | 0;
	                            i = j;
	                            return P | 0
	                        }
	                        if (c[v + 8 >> 2] | 0) {
	                            S = c[c[o >> 2] >> 2] | 0;
	                            f = c[w >> 2] | 0;
	                            T = c[v + 8 >> 2] | 0;
	                            d = c[v + 4 >> 2] | 0;
	                            V = c[v >> 2] | 0;
	                            if (b[v + 16 >> 1] & 1) {
	                                c[l >> 2] = T;
	                                c[l + 4 >> 2] = d;
	                                c[l + 8 >> 2] = V;
	                                JT(S, f, 171496, l) | 0;
	                                break a
	                            } else {
	                                c[l >> 2] = T;
	                                c[l + 4 >> 2] = d;
	                                c[l + 8 >> 2] = V;
	                                JT(S, f, 171456, l) | 0;
	                                break a
	                            }
	                        }
	                        f = (b[v + 16 >> 1] & 1 | 0) != 0;
	                        S = c[c[o >> 2] >> 2] | 0;
	                        V = c[w >> 2] | 0;
	                        if (c[v + 4 >> 2] | 0) {
	                            d = c[v + 4 >> 2] | 0;
	                            T = c[v >> 2] | 0;
	                            if (f) {
	                                c[l >> 2] = d;
	                                c[l + 4 >> 2] = T;
	                                JT(S, V, 171512, l) | 0;
	                                break a
	                            } else {
	                                c[l >> 2] = d;
	                                c[l + 4 >> 2] = T;
	                                JT(S, V, 171472, l) | 0;
	                                break a
	                            }
	                        } else {
	                            T = c[v >> 2] | 0;
	                            if (f) {
	                                c[l >> 2] = T;
	                                JT(S, V, 171520, l) | 0;
	                                break a
	                            } else {
	                                c[l >> 2] = T;
	                                JT(S, V, 171480, l) | 0;
	                                break a
	                            }
	                        }
	                        break
	                    }
	                    case 12:
	                    {
	                        c[B >> 2] = 0;
	                        c[C >> 2] = 0;
	                        h[D >> 3] = 0.0;
	                        c[y >> 2] = ~~+Q(+(+(R(c[(c[n >> 2] | 0) + 8 >> 2] | 0) | 0) / 12.0)) >>> 0;
	                        V = R(c[(c[n >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        c[z >> 2] = V - ((c[y >> 2] | 0) * 12 | 0);
	                        c[A >> 2] = ~~+Q(+(+R(+(+h[(c[n >> 2] | 0) + 16 >> 3])) / 86400.0)) >>> 0;
	                        W = +R(+(+h[(c[n >> 2] | 0) + 16 >> 3]));
	                        h[E >> 3] = W - +(((c[A >> 2] | 0) * 86400 | 0) >>> 0);
	                        if (+h[E >> 3] > 0.0 ? (c[B >> 2] = ~~+Q(+(+h[E >> 3] / 3600.0)) >>> 0, h[E >> 3] = +h[E >> 3] - +(((c[B >> 2] | 0) * 3600 | 0) >>> 0), +h[E >> 3] > 0.0) : 0) {
	                            c[C >> 2] = ~~+Q(+(+h[E >> 3] / 60.0)) >>> 0;
	                            h[D >> 3] = +h[E >> 3] - +(((c[C >> 2] | 0) * 60 | 0) >>> 0)
	                        }
	                        if ((c[(c[n >> 2] | 0) + 8 >> 2] | 0) >= 0 ? !(+h[(c[n >> 2] | 0) + 16 >> 3] < 0.0) : 0) {
	                            V = c[z >> 2] | 0;
	                            S = c[A >> 2] | 0;
	                            T = c[B >> 2] | 0;
	                            f = c[C >> 2] | 0;
	                            W = +h[D >> 3];
	                            c[l >> 2] = c[y >> 2];
	                            c[l + 4 >> 2] = V;
	                            c[l + 8 >> 2] = S;
	                            c[l + 12 >> 2] = T;
	                            c[l + 16 >> 2] = f;
	                            f = l + 20 | 0;
	                            h[k >> 3] = W;
	                            c[f >> 2] = c[k >> 2];
	                            c[f + 4 >> 2] = c[k + 4 >> 2];
	                            JT(x, 100, 171576, l) | 0
	                        } else {
	                            f = c[z >> 2] | 0;
	                            T = c[A >> 2] | 0;
	                            S = c[B >> 2] | 0;
	                            V = c[C >> 2] | 0;
	                            W = +h[D >> 3];
	                            c[l >> 2] = c[y >> 2];
	                            c[l + 4 >> 2] = f;
	                            c[l + 8 >> 2] = T;
	                            c[l + 12 >> 2] = S;
	                            c[l + 16 >> 2] = V;
	                            V = l + 20 | 0;
	                            h[k >> 3] = W;
	                            c[V >> 2] = c[k >> 2];
	                            c[V + 4 >> 2] = c[k + 4 >> 2];
	                            JT(x, 100, 171544, l) | 0
	                        }
	                        V = my(x) | 0;
	                        c[c[o >> 2] >> 2] = V;
	                        break
	                    }
	                    case 10:
	                    {
	                        do if (b[(c[n >> 2] | 0) + 24 >> 1] & 1) {
	                            c[K >> 2] = nI(c[n >> 2] | 0, 0.0) | 0;
	                            if (c[K >> 2] | 0) {
	                                V = c[(c[K >> 2] | 0) + 12 >> 2] & 15;
	                                S = (c[(c[K >> 2] | 0) + 12 >> 2] | 0) >>> 4 & 31;
	                                c[l >> 2] = c[(c[K >> 2] | 0) + 8 >> 2];
	                                c[l + 4 >> 2] = V;
	                                c[l + 8 >> 2] = S;
	                                JT(J, 30, 171728, l) | 0;
	                                PH(c[K >> 2] | 0);
	                                break
	                            }
	                            c[m >> 2] = -1;
	                            P = c[m >> 2] | 0;
	                            i = j;
	                            return P | 0
	                        } else {
	                            S = c[(c[n >> 2] | 0) + 12 >> 2] & 15;
	                            V = (c[(c[n >> 2] | 0) + 12 >> 2] | 0) >>> 4 & 31;
	                            c[l >> 2] = c[(c[n >> 2] | 0) + 8 >> 2];
	                            c[l + 4 >> 2] = S;
	                            c[l + 8 >> 2] = V;
	                            JT(J, 30, 171752, l) | 0
	                        } while (0);
	                        V = my(J) | 0;
	                        c[c[o >> 2] >> 2] = V;
	                        break
	                    }
	                    case 29:
	                    case 28:
	                    case 26:
	                    case 24:
	                    case 23:
	                    case 22:
	                    case 20:
	                    case 18:
	                    case 17:
	                    case 16:
	                    {
	                        if (!(c[(c[n >> 2] | 0) + 8 >> 2] | 0)) {
	                            c[m >> 2] = -1;
	                            P = c[m >> 2] | 0;
	                            i = j;
	                            return P | 0
	                        } else {
	                            V = SH(c[(c[n >> 2] | 0) + 8 >> 2] | 0) | 0;
	                            c[c[o >> 2] >> 2] = V;
	                            if (c[c[o >> 2] >> 2] | 0)break a;
	                            V = my(c[(c[n >> 2] | 0) + 8 >> 2] | 0) | 0;
	                            c[c[o >> 2] >> 2] = V;
	                            break a
	                        }
	                        break
	                    }
	                    case 4:
	                    {
	                        do if (b[(c[n >> 2] | 0) + 24 >> 1] & 1) {
	                            c[I >> 2] = nI(c[n >> 2] | 0, 0.0) | 0;
	                            if (c[I >> 2] | 0) {
	                                V = (c[(c[I >> 2] | 0) + 12 >> 2] | 0) >>> 14 & 63;
	                                W = +h[(c[I >> 2] | 0) + 16 >> 3];
	                                c[l >> 2] = (c[(c[I >> 2] | 0) + 12 >> 2] | 0) >>> 9 & 31;
	                                c[l + 4 >> 2] = V;
	                                V = l + 8 | 0;
	                                h[k >> 3] = W;
	                                c[V >> 2] = c[k >> 2];
	                                c[V + 4 >> 2] = c[k + 4 >> 2];
	                                JT(H, 30, 171680, l) | 0;
	                                PH(c[I >> 2] | 0);
	                                break
	                            }
	                            c[m >> 2] = -1;
	                            P = c[m >> 2] | 0;
	                            i = j;
	                            return P | 0
	                        } else {
	                            V = (c[(c[n >> 2] | 0) + 12 >> 2] | 0) >>> 14 & 63;
	                            W = +h[(c[n >> 2] | 0) + 16 >> 3];
	                            c[l >> 2] = (c[(c[n >> 2] | 0) + 12 >> 2] | 0) >>> 9 & 31;
	                            c[l + 4 >> 2] = V;
	                            V = l + 8 | 0;
	                            h[k >> 3] = W;
	                            c[V >> 2] = c[k >> 2];
	                            c[V + 4 >> 2] = c[k + 4 >> 2];
	                            JT(H, 30, 171704, l) | 0
	                        } while (0);
	                        V = my(H) | 0;
	                        c[c[o >> 2] >> 2] = V;
	                        break
	                    }
	                    case 6:
	                    {
	                        V = Cb[c[135744 >> 2] & 511](6) | 0;
	                        c[c[o >> 2] >> 2] = V;
	                        if (c[c[o >> 2] >> 2] | 0) {
	                            V = c[c[o >> 2] >> 2] | 0;
	                            c[l >> 2] = c[(c[n >> 2] | 0) + 12 >> 2] & 15;
	                            JT(V, 6, 171616, l) | 0;
	                            break a
	                        }
	                        c[m >> 2] = -1;
	                        P = c[m >> 2] | 0;
	                        i = j;
	                        return P | 0
	                    }
	                    case 43:
	                    {
	                        V = my(c[(c[n >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        c[c[o >> 2] >> 2] = V;
	                        break
	                    }
	                    case 44:
	                    {
	                        V = my(c[(c[n >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        c[c[o >> 2] >> 2] = V;
	                        break
	                    }
	                    case 13:
	                    {
	                        h[k >> 3] = +g[(c[n >> 2] | 0) + 8 >> 2];
	                        c[l >> 2] = c[k >> 2];
	                        c[l + 4 >> 2] = c[k + 4 >> 2];
	                        JT(N, 30, 171848, l) | 0;
	                        V = my(N) | 0;
	                        c[c[o >> 2] >> 2] = V;
	                        break
	                    }
	                    case 14:
	                    {
	                        h[k >> 3] = +h[(c[n >> 2] | 0) + 8 >> 3];
	                        c[l >> 2] = c[k >> 2];
	                        c[l + 4 >> 2] = c[k + 4 >> 2];
	                        JT(O, 40, 171848, l) | 0;
	                        V = my(O) | 0;
	                        c[c[o >> 2] >> 2] = V;
	                        break
	                    }
	                    case 11:
	                    {
	                        do if (b[(c[n >> 2] | 0) + 24 >> 1] & 1) {
	                            c[M >> 2] = nI(c[n >> 2] | 0, 0.0) | 0;
	                            if (c[M >> 2] | 0) {
	                                V = c[(c[M >> 2] | 0) + 12 >> 2] & 15;
	                                S = (c[(c[M >> 2] | 0) + 12 >> 2] | 0) >>> 4 & 31;
	                                T = (c[(c[M >> 2] | 0) + 12 >> 2] | 0) >>> 9 & 31;
	                                f = (c[(c[M >> 2] | 0) + 12 >> 2] | 0) >>> 14 & 63;
	                                W = +h[(c[M >> 2] | 0) + 16 >> 3];
	                                c[l >> 2] = c[(c[M >> 2] | 0) + 8 >> 2];
	                                c[l + 4 >> 2] = V;
	                                c[l + 8 >> 2] = S;
	                                c[l + 12 >> 2] = T;
	                                c[l + 16 >> 2] = f;
	                                f = l + 20 | 0;
	                                h[k >> 3] = W;
	                                c[f >> 2] = c[k >> 2];
	                                c[f + 4 >> 2] = c[k + 4 >> 2];
	                                JT(L, 50, 171768, l) | 0;
	                                PH(c[M >> 2] | 0);
	                                break
	                            }
	                            c[m >> 2] = -1;
	                            P = c[m >> 2] | 0;
	                            i = j;
	                            return P | 0
	                        } else {
	                            f = c[(c[n >> 2] | 0) + 12 >> 2] & 15;
	                            T = (c[(c[n >> 2] | 0) + 12 >> 2] | 0) >>> 4 & 31;
	                            S = (c[(c[n >> 2] | 0) + 12 >> 2] | 0) >>> 9 & 31;
	                            V = (c[(c[n >> 2] | 0) + 12 >> 2] | 0) >>> 14 & 63;
	                            W = +h[(c[n >> 2] | 0) + 16 >> 3];
	                            c[l >> 2] = c[(c[n >> 2] | 0) + 8 >> 2];
	                            c[l + 4 >> 2] = f;
	                            c[l + 8 >> 2] = T;
	                            c[l + 12 >> 2] = S;
	                            c[l + 16 >> 2] = V;
	                            V = l + 20 | 0;
	                            h[k >> 3] = W;
	                            c[V >> 2] = c[k >> 2];
	                            c[V + 4 >> 2] = c[k + 4 >> 2];
	                            JT(L, 50, 171808, l) | 0
	                        } while (0);
	                        V = my(L) | 0;
	                        c[c[o >> 2] >> 2] = V;
	                        break
	                    }
	                    case 1:
	                    {
	                        if (!(c[(c[n >> 2] | 0) + 8 >> 2] | 0)) {
	                            V = my(171424) | 0;
	                            c[c[o >> 2] >> 2] = V;
	                            break a
	                        } else {
	                            V = my(c[(c[n >> 2] | 0) + 8 >> 2] | 0) | 0;
	                            c[c[o >> 2] >> 2] = V;
	                            break a
	                        }
	                        break
	                    }
	                    case 21:
	                    {
	                        if (c[(c[n >> 2] | 0) + 12 >> 2] | 0) {
	                            V = my(171432) | 0;
	                            c[c[o >> 2] >> 2] = V;
	                            V = By(c[c[o >> 2] >> 2] | 0, c[(c[n >> 2] | 0) + 12 >> 2] | 0) | 0;
	                            c[c[o >> 2] >> 2] = V;
	                            V = By(c[c[o >> 2] >> 2] | 0, 171440) | 0;
	                            c[c[o >> 2] >> 2] = V;
	                            V = By(c[c[o >> 2] >> 2] | 0, c[(c[n >> 2] | 0) + 12 >> 2] | 0) | 0;
	                            c[c[o >> 2] >> 2] = V;
	                            break a
	                        }
	                        V = my(c[(c[n >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        c[c[o >> 2] >> 2] = V;
	                        c[m >> 2] = 0;
	                        P = c[m >> 2] | 0;
	                        i = j;
	                        return P | 0
	                    }
	                    default:
	                    {
	                        V = my(171856) | 0;
	                        c[c[o >> 2] >> 2] = V;
	                        c[m >> 2] = 1;
	                        P = c[m >> 2] | 0;
	                        i = j;
	                        return P | 0
	                    }
	                } while (0);
	                if (!(c[c[o >> 2] >> 2] | 0)) {
	                    c[m >> 2] = -1;
	                    P = c[m >> 2] | 0;
	                    i = j;
	                    return P | 0
	                } else {
	                    c[m >> 2] = 0;
	                    P = c[m >> 2] | 0;
	                    i = j;
	                    return P | 0
	                }
	                return 0
	            }

	            function dI(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0))c[d >> 2] = 0; else c[d >> 2] = c[c[e >> 2] >> 2];
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function eI(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = Cb[c[135744 >> 2] & 511](120) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    gI(0, 172376);
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                d = (c[k >> 2] | 0) + 0 | 0;
	                b = d + 120 | 0;
	                do {
	                    c[d >> 2] = 0;
	                    d = d + 4 | 0
	                } while ((d | 0) < (b | 0));
	                c[(c[k >> 2] | 0) + 8 >> 2] = c[g >> 2];
	                c[(c[k >> 2] | 0) + 112 >> 2] = 172416;
	                c[c[k >> 2] >> 2] = 1;
	                c[(c[k >> 2] | 0) + 64 >> 2] = c[j >> 2];
	                c[(c[k >> 2] | 0) + 52 >> 2] = 6;
	                switch (c[h >> 2] | 0) {
	                    case 28:
	                    case 21:
	                    case 44:
	                    case 43:
	                    case 29:
	                    case 15:
	                    case 14:
	                    case 13:
	                    case 12:
	                    case 5:
	                    case 7:
	                    case 6:
	                    case 9:
	                    case 8:
	                    case 4:
	                    case 11:
	                    case 10:
	                    case 3:
	                    case 1:
	                    {
	                        j = (c[k >> 2] | 0) + 48 | 0;
	                        c[j >> 2] = c[j >> 2] | 16384;
	                        break
	                    }
	                    default:
	                    {
	                    }
	                }
	                switch (c[h >> 2] | 0) {
	                    case 46:
	                    case 45:
	                        break;
	                    case 27:
	                    case 19:
	                    case 25:
	                    {
	                        j = (c[k >> 2] | 0) + 48 | 0;
	                        c[j >> 2] = c[j >> 2] | 64;
	                        j = oI(1) | 0;
	                        c[(c[k >> 2] | 0) + 68 >> 2] = j;
	                        j = (c[k >> 2] | 0) + 48 | 0;
	                        c[j >> 2] = c[j >> 2] | 134217728;
	                        break
	                    }
	                    default:
	                    {
	                        j = (c[k >> 2] | 0) + 48 | 0;
	                        c[j >> 2] = c[j >> 2] | 256
	                    }
	                }
	                Nj(c[42592] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0, 172416, c[k >> 2] | 0) | 0;
	                c[(c[k >> 2] | 0) + 88 >> 2] = c[h >> 2];
	                c[f >> 2] = c[k >> 2];
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function fI() {
	                var a = 0, b = 0, d = 0, e = 0, f = 0;
	                a = i;
	                i = i + 16 | 0;
	                b = a + 4 | 0;
	                d = a;
	                c[d >> 2] = 0;
	                c[d >> 2] = Cb[c[135744 >> 2] & 511](28) | 0;
	                if (!(c[d >> 2] | 0)) {
	                    gI(0, 172344);
	                    c[b >> 2] = 0;
	                    e = c[b >> 2] | 0;
	                    i = a;
	                    return e | 0
	                } else {
	                    f = c[d >> 2] | 0;
	                    c[f + 0 >> 2] = 0;
	                    c[f + 4 >> 2] = 0;
	                    c[f + 8 >> 2] = 0;
	                    c[f + 12 >> 2] = 0;
	                    c[f + 16 >> 2] = 0;
	                    c[f + 20 >> 2] = 0;
	                    c[f + 24 >> 2] = 0;
	                    c[c[d >> 2] >> 2] = 25;
	                    c[(c[d >> 2] | 0) + 16 >> 2] = 1;
	                    c[(c[d >> 2] | 0) + 20 >> 2] = 1;
	                    c[b >> 2] = c[d >> 2];
	                    e = c[b >> 2] | 0;
	                    i = a;
	                    return e | 0
	                }
	                return 0
	            }

	            function gI(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                ce(15, 2, c[e >> 2] | 0, 0, c[f >> 2] | 0);
	                i = d;
	                return
	            }

	            function hI(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](32) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    a = c[f >> 2] | 0;
	                    c[a + 0 >> 2] = 0;
	                    c[a + 4 >> 2] = 0;
	                    c[a + 8 >> 2] = 0;
	                    c[a + 12 >> 2] = 0;
	                    c[a + 16 >> 2] = 0;
	                    c[a + 20 >> 2] = 0;
	                    c[a + 24 >> 2] = 0;
	                    c[a + 28 >> 2] = 0;
	                    c[c[f >> 2] >> 2] = c[e >> 2];
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function iI(e, f, j, k, l, m, n, o, p) {
	                e = e | 0;
	                f = f | 0;
	                j = j | 0;
	                k = k | 0;
	                l = l | 0;
	                m = m | 0;
	                n = n | 0;
	                o = o | 0;
	                p = p | 0;
	                var q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0, J = 0, K = 0, L = 0, M = 0, N = 0, O = 0, P = 0, Q = 0, R = 0, S = 0, T = 0, U = 0, V = 0, W = 0, X = 0, Y = 0, Z = 0, _ = 0, $ = 0, aa = 0, ba = 0, ca = 0, da = 0, ea = 0, fa = 0, ga = 0, ha = 0, ia = 0, ja = 0, ka = 0, la = 0, ma = 0, na = 0, oa = 0, pa = 0, qa = 0, ra = 0, sa = 0, ta = 0, ua = 0, va = 0, wa = 0, xa = 0, ya = 0, za = 0, Aa = 0, Ba = 0, Ca = 0, Da = 0, Ea = 0, Fa = 0, Ga = 0, Ha = 0, Ia = 0, Ja = 0, Ka = 0, La = 0, Ma = 0, Na = 0, Oa = 0, Pa = 0, Qa = 0, Ra = 0, Sa = 0, Ta = 0, Ua = 0, Va = 0, Wa = 0, Xa = 0, Ya = 0, Za = 0, _a = 0, $a = 0, ab = 0;
	                q = i;
	                i = i + 352 | 0;
	                r = q;
	                s = q + 316 | 0;
	                t = q + 312 | 0;
	                u = q + 308 | 0;
	                v = q + 304 | 0;
	                w = q + 300 | 0;
	                x = q + 296 | 0;
	                y = q + 292 | 0;
	                z = q + 288 | 0;
	                A = q + 284 | 0;
	                B = q + 280 | 0;
	                C = q + 276 | 0;
	                D = q + 272 | 0;
	                E = q + 268 | 0;
	                F = q + 264 | 0;
	                G = q + 260 | 0;
	                H = q + 256 | 0;
	                I = q + 252 | 0;
	                J = q + 248 | 0;
	                K = q + 244 | 0;
	                L = q + 240 | 0;
	                M = q + 320 | 0;
	                N = q + 236 | 0;
	                O = q + 232 | 0;
	                P = q + 228 | 0;
	                Q = q + 224 | 0;
	                R = q + 220 | 0;
	                S = q + 216 | 0;
	                T = q + 212 | 0;
	                U = q + 208 | 0;
	                V = q + 204 | 0;
	                W = q + 200 | 0;
	                X = q + 196 | 0;
	                Y = q + 192 | 0;
	                Z = q + 188 | 0;
	                _ = q + 184 | 0;
	                $ = q + 180 | 0;
	                aa = q + 176 | 0;
	                ba = q + 172 | 0;
	                ca = q + 168 | 0;
	                da = q + 164 | 0;
	                ea = q + 160 | 0;
	                fa = q + 156 | 0;
	                ga = q + 152 | 0;
	                ha = q + 148 | 0;
	                ia = q + 144 | 0;
	                ja = q + 140 | 0;
	                ka = q + 136 | 0;
	                la = q + 132 | 0;
	                ma = q + 128 | 0;
	                na = q + 124 | 0;
	                oa = q + 120 | 0;
	                pa = q + 116 | 0;
	                qa = q + 112 | 0;
	                ra = q + 108 | 0;
	                sa = q + 104 | 0;
	                ta = q + 100 | 0;
	                ua = q + 96 | 0;
	                va = q + 92 | 0;
	                wa = q + 88 | 0;
	                xa = q + 84 | 0;
	                ya = q + 80 | 0;
	                za = q + 76 | 0;
	                Aa = q + 72 | 0;
	                Ba = q + 68 | 0;
	                Ca = q + 64 | 0;
	                Da = q + 60 | 0;
	                Ea = q + 56 | 0;
	                Fa = q + 52 | 0;
	                Ga = q + 48 | 0;
	                Ha = q + 44 | 0;
	                Ia = q + 40 | 0;
	                Ja = q + 36 | 0;
	                Ka = q + 32 | 0;
	                La = q + 28 | 0;
	                Ma = q + 24 | 0;
	                Na = q + 20 | 0;
	                Oa = q + 16 | 0;
	                Pa = q + 12 | 0;
	                Qa = q + 8 | 0;
	                c[t >> 2] = e;
	                c[u >> 2] = f;
	                c[v >> 2] = j;
	                c[w >> 2] = k;
	                c[x >> 2] = l;
	                c[y >> 2] = m;
	                c[z >> 2] = n;
	                c[A >> 2] = o;
	                c[B >> 2] = p;
	                c[D >> 2] = 0;
	                c[E >> 2] = 0;
	                if (!(c[42590] | 0))FH();
	                if (!(c[t >> 2] | 0)) {
	                    c[s >> 2] = -1;
	                    Ra = c[s >> 2] | 0;
	                    i = q;
	                    return Ra | 0
	                }
	                if (!(c[u >> 2] | 0))c[u >> 2] = 171424;
	                if (c[v >> 2] | 0)c[c[v >> 2] >> 2] = 0;
	                if ((((c[x >> 2] | 0) == 0 & (c[u >> 2] | 0) != 0 ? (c[(c[t >> 2] | 0) + 88 >> 2] | 0) != 1 : 0) ? (c[(c[t >> 2] | 0) + 88 >> 2] | 0) != 45 : 0) ? (c[(c[t >> 2] | 0) + 88 >> 2] | 0) != 46 : 0) {
	                    x = c[u >> 2] | 0;
	                    if ((c[(c[t >> 2] | 0) + 88 >> 2] | 0) == 2)c[D >> 2] = RH(x) | 0; else c[D >> 2] = SH(x) | 0;
	                    if (c[D >> 2] | 0)c[u >> 2] = c[D >> 2]
	                }
	                a:do switch (c[(c[t >> 2] | 0) + 88 >> 2] | 0) {
	                    case 11:
	                    case 10:
	                    case 9:
	                    case 8:
	                    case 7:
	                    case 6:
	                    case 5:
	                    case 4:
	                    {
	                        c[E >> 2] = qI(c[(c[t >> 2] | 0) + 88 >> 2] | 0, c[u >> 2] | 0, c[v >> 2] | 0, c[z >> 2] | 0) | 0;
	                        Sa = 571;
	                        break
	                    }
	                    case 14:
	                    case 13:
	                    {
	                        c[O >> 2] = c[u >> 2];
	                        c[P >> 2] = 0;
	                        c[Q >> 2] = 0;
	                        c[R >> 2] = 0;
	                        b:do if (c[z >> 2] | 0)while (1) {
	                            do if ((d[c[O >> 2] >> 0] | 0) != 32) {
	                                if (9 <= (d[c[O >> 2] >> 0] | 0) ? (d[c[O >> 2] >> 0] | 0) <= 10 : 0)break;
	                                if ((d[c[O >> 2] >> 0] | 0) != 13)break b
	                            } while (0);
	                            c[O >> 2] = (c[O >> 2] | 0) + 1
	                        } while (0);
	                        if (((d[c[O >> 2] >> 0] | 0) == 78 ? (d[(c[O >> 2] | 0) + 1 >> 0] | 0) == 97 : 0) ? (d[(c[O >> 2] | 0) + 2 >> 0] | 0) == 78 : 0) {
	                            c[O >> 2] = (c[O >> 2] | 0) + 3;
	                            if (d[c[O >> 2] >> 0] | 0) {
	                                Sa = 577;
	                                break a
	                            }
	                            if (!(c[v >> 2] | 0)) {
	                                Sa = 580;
	                                break a
	                            }
	                            do if ((c[t >> 2] | 0) == (c[42690] | 0)) {
	                                c[C >> 2] = hI(13) | 0;
	                                if (c[C >> 2] | 0) {
	                                    g[(c[C >> 2] | 0) + 8 >> 2] = +h[15984];
	                                    break
	                                } else {
	                                    PH(c[C >> 2] | 0);
	                                    Sa = 583;
	                                    break a
	                                }
	                            } else {
	                                c[C >> 2] = hI(14) | 0;
	                                if (c[C >> 2] | 0) {
	                                    h[(c[C >> 2] | 0) + 8 >> 3] = +h[15984];
	                                    break
	                                } else {
	                                    PH(c[C >> 2] | 0);
	                                    Sa = 583;
	                                    break a
	                                }
	                            } while (0);
	                            c[c[v >> 2] >> 2] = c[C >> 2];
	                            Sa = 580;
	                            break a
	                        }
	                        if ((d[c[O >> 2] >> 0] | 0) == 45) {
	                            c[P >> 2] = 1;
	                            c[O >> 2] = (c[O >> 2] | 0) + 1
	                        }
	                        if (((d[c[O >> 2] >> 0] | 0) == 73 ? (d[(c[O >> 2] | 0) + 1 >> 0] | 0) == 78 : 0) ? (d[(c[O >> 2] | 0) + 2 >> 0] | 0) == 70 : 0) {
	                            c[O >> 2] = (c[O >> 2] | 0) + 3;
	                            if (d[c[O >> 2] >> 0] | 0) {
	                                Sa = 577;
	                                break a
	                            }
	                            if (!(c[v >> 2] | 0)) {
	                                Sa = 580;
	                                break a
	                            }
	                            do if ((c[t >> 2] | 0) == (c[42690] | 0)) {
	                                c[C >> 2] = hI(13) | 0;
	                                if (!(c[C >> 2] | 0)) {
	                                    PH(c[C >> 2] | 0);
	                                    Sa = 583;
	                                    break a
	                                }
	                                if (c[P >> 2] | 0) {
	                                    g[(c[C >> 2] | 0) + 8 >> 2] = +h[15986];
	                                    break
	                                } else {
	                                    g[(c[C >> 2] | 0) + 8 >> 2] = +h[15985];
	                                    break
	                                }
	                            } else {
	                                c[C >> 2] = hI(14) | 0;
	                                if (!(c[C >> 2] | 0)) {
	                                    PH(c[C >> 2] | 0);
	                                    Sa = 583;
	                                    break a
	                                }
	                                if (c[P >> 2] | 0) {
	                                    h[(c[C >> 2] | 0) + 8 >> 3] = +h[15986];
	                                    break
	                                } else {
	                                    h[(c[C >> 2] | 0) + 8 >> 3] = +h[15985];
	                                    break
	                                }
	                            } while (0);
	                            c[c[v >> 2] >> 2] = c[C >> 2];
	                            Sa = 580;
	                            break a
	                        }
	                        if ((c[P >> 2] | 0) == 0 ? (d[c[O >> 2] >> 0] | 0) == 43 : 0)c[O >> 2] = (c[O >> 2] | 0) + 1;
	                        if (((d[c[O >> 2] >> 0] | 0) != 0 ? (d[c[O >> 2] >> 0] | 0) != 43 : 0) ? (d[c[O >> 2] >> 0] | 0) != 45 : 0) {
	                            while (1) {
	                                if ((d[c[O >> 2] >> 0] | 0) >= 48)Ta = (d[c[O >> 2] >> 0] | 0) <= 57; else Ta = 0;
	                                Ua = c[O >> 2] | 0;
	                                if (!Ta)break;
	                                c[O >> 2] = Ua + 1;
	                                c[Q >> 2] = (c[Q >> 2] | 0) + 1
	                            }
	                            c:do if ((d[Ua >> 0] | 0) == 46) {
	                                c[O >> 2] = (c[O >> 2] | 0) + 1;
	                                while (1) {
	                                    if ((d[c[O >> 2] >> 0] | 0) < 48)break c;
	                                    if ((d[c[O >> 2] >> 0] | 0) > 57)break c;
	                                    c[O >> 2] = (c[O >> 2] | 0) + 1;
	                                    c[R >> 2] = (c[R >> 2] | 0) + 1
	                                }
	                            } while (0);
	                            if (!((c[Q >> 2] | 0) == 0 & (c[R >> 2] | 0) == 0)) {
	                                if (!((d[c[O >> 2] >> 0] | 0) != 101 ? (d[c[O >> 2] >> 0] | 0) != 69 : 0))Sa = 168;
	                                d:do if ((Sa | 0) == 168) {
	                                    c[O >> 2] = (c[O >> 2] | 0) + 1;
	                                    if (!((d[c[O >> 2] >> 0] | 0) != 45 ? (d[c[O >> 2] >> 0] | 0) != 43 : 0))c[O >> 2] = (c[O >> 2] | 0) + 1;
	                                    while (1) {
	                                        if ((d[c[O >> 2] >> 0] | 0) < 48)break d;
	                                        if ((d[c[O >> 2] >> 0] | 0) > 57)break d;
	                                        c[O >> 2] = (c[O >> 2] | 0) + 1
	                                    }
	                                } while (0);
	                                e:do if (c[z >> 2] | 0)while (1) {
	                                    do if ((d[c[O >> 2] >> 0] | 0) != 32) {
	                                        if (9 <= (d[c[O >> 2] >> 0] | 0) ? (d[c[O >> 2] >> 0] | 0) <= 10 : 0)break;
	                                        if ((d[c[O >> 2] >> 0] | 0) != 13)break e
	                                    } while (0);
	                                    c[O >> 2] = (c[O >> 2] | 0) + 1
	                                } while (0);
	                                if (!(d[c[O >> 2] >> 0] | 0))if (c[v >> 2] | 0)if ((c[t >> 2] | 0) == (c[42690] | 0)) {
	                                    c[C >> 2] = hI(13) | 0;
	                                    if (!(c[C >> 2] | 0)) {
	                                        Sa = 583;
	                                        break a
	                                    }
	                                    x = c[u >> 2] | 0;
	                                    c[r >> 2] = (c[C >> 2] | 0) + 8;
	                                    p = (bT(x, 172216, r) | 0) == 1;
	                                    x = c[C >> 2] | 0;
	                                    if (p) {
	                                        c[c[v >> 2] >> 2] = x;
	                                        Sa = 580;
	                                        break a
	                                    } else {
	                                        PH(x);
	                                        Sa = 577;
	                                        break a
	                                    }
	                                } else {
	                                    c[C >> 2] = hI(14) | 0;
	                                    if (!(c[C >> 2] | 0)) {
	                                        Sa = 583;
	                                        break a
	                                    }
	                                    x = c[u >> 2] | 0;
	                                    c[r >> 2] = (c[C >> 2] | 0) + 8;
	                                    p = (bT(x, 172224, r) | 0) == 1;
	                                    x = c[C >> 2] | 0;
	                                    if (p) {
	                                        c[c[v >> 2] >> 2] = x;
	                                        Sa = 580;
	                                        break a
	                                    } else {
	                                        PH(x);
	                                        Sa = 577;
	                                        break a
	                                    }
	                                } else Sa = 580; else Sa = 577
	                            } else Sa = 577
	                        } else Sa = 577;
	                        break
	                    }
	                    case 2:
	                    {
	                        f:do if (c[z >> 2] | 0) {
	                            if (c[A >> 2] | 0) {
	                                x = c[u >> 2] | 0;
	                                if ((c[y >> 2] | 0) == 3)c[D >> 2] = SH(x) | 0; else c[D >> 2] = RH(x) | 0;
	                                if (c[D >> 2] | 0)c[u >> 2] = c[D >> 2]
	                            }
	                        } else {
	                            c[G >> 2] = c[u >> 2];
	                            while (1) {
	                                if (!(d[c[G >> 2] >> 0] | 0))break f;
	                                if ((d[c[G >> 2] >> 0] | 0) == 13) {
	                                    Sa = 577;
	                                    break a
	                                }
	                                if ((d[c[G >> 2] >> 0] | 0) == 10) {
	                                    Sa = 577;
	                                    break a
	                                }
	                                if ((d[c[G >> 2] >> 0] | 0) == 9) {
	                                    Sa = 577;
	                                    break a
	                                }
	                                c[G >> 2] = (c[G >> 2] | 0) + 1
	                            }
	                        } while (0);
	                        if (c[v >> 2] | 0) {
	                            c[C >> 2] = hI(2) | 0;
	                            if (c[C >> 2] | 0) {
	                                x = my(c[u >> 2] | 0) | 0;
	                                c[(c[C >> 2] | 0) + 8 >> 2] = x;
	                                c[c[v >> 2] >> 2] = c[C >> 2];
	                                Sa = 580
	                            } else Sa = 583
	                        } else Sa = 580;
	                        break
	                    }
	                    case 46:
	                    case 45:
	                    {
	                        if ((c[B >> 2] | 0) != 0 & (c[v >> 2] | 0) != 0) {
	                            c[C >> 2] = hI(46) | 0;
	                            if (c[C >> 2] | 0) {
	                                x = my(c[u >> 2] | 0) | 0;
	                                c[(c[C >> 2] | 0) + 8 >> 2] = x;
	                                c[c[v >> 2] >> 2] = c[C >> 2];
	                                Sa = 580
	                            } else Sa = 583
	                        } else Sa = 580;
	                        break
	                    }
	                    case 3:
	                    {
	                        c[H >> 2] = c[u >> 2];
	                        c[N >> 2] = M;
	                        if ((c[H >> 2] | 0) != 0 ? (d[c[H >> 2] >> 0] | 0) != 0 : 0) {
	                            g:do if (c[z >> 2] | 0)while (1) {
	                                do if ((d[c[H >> 2] >> 0] | 0) != 32) {
	                                    if (9 <= (d[c[H >> 2] >> 0] | 0) ? (d[c[H >> 2] >> 0] | 0) <= 10 : 0)break;
	                                    if ((d[c[H >> 2] >> 0] | 0) != 13)break g
	                                } while (0);
	                                c[H >> 2] = (c[H >> 2] | 0) + 1
	                            } while (0);
	                            c[J >> 2] = 0;
	                            if ((d[c[H >> 2] >> 0] | 0) != 45) {
	                                if ((d[c[H >> 2] >> 0] | 0) == 43)c[H >> 2] = (c[H >> 2] | 0) + 1
	                            } else {
	                                c[J >> 2] = 1;
	                                c[H >> 2] = (c[H >> 2] | 0) + 1
	                            }
	                            if (d[c[H >> 2] >> 0] | 0) {
	                                c[I >> 2] = 0;
	                                c[K >> 2] = -1;
	                                c[L >> 2] = 0;
	                                while (1) {
	                                    Va = c[H >> 2] | 0;
	                                    if ((d[c[H >> 2] >> 0] | 0) != 48)break;
	                                    c[H >> 2] = Va + 1;
	                                    c[L >> 2] = 1
	                                }
	                                h:do if (d[Va >> 0] | 0) {
	                                    while (1) {
	                                        if ((d[c[H >> 2] >> 0] | 0) < 48)break;
	                                        if ((d[c[H >> 2] >> 0] | 0) > 57)break;
	                                        x = c[H >> 2] | 0;
	                                        c[H >> 2] = x + 1;
	                                        p = a[x >> 0] | 0;
	                                        x = c[N >> 2] | 0;
	                                        c[N >> 2] = x + 1;
	                                        a[x >> 0] = p;
	                                        c[I >> 2] = (c[I >> 2] | 0) + 1;
	                                        if ((c[I >> 2] | 0) >>> 0 >= 24)break h
	                                    }
	                                    if ((d[c[H >> 2] >> 0] | 0) == 46) {
	                                        c[H >> 2] = (c[H >> 2] | 0) + 1;
	                                        c[K >> 2] = c[I >> 2];
	                                        do {
	                                            if ((d[c[H >> 2] >> 0] | 0) < 48)break;
	                                            if ((d[c[H >> 2] >> 0] | 0) > 57)break;
	                                            p = c[H >> 2] | 0;
	                                            c[H >> 2] = p + 1;
	                                            x = a[p >> 0] | 0;
	                                            p = c[N >> 2] | 0;
	                                            c[N >> 2] = p + 1;
	                                            a[p >> 0] = x;
	                                            c[I >> 2] = (c[I >> 2] | 0) + 1
	                                        } while ((c[I >> 2] | 0) >>> 0 < 24);
	                                        if (!((c[I >> 2] | 0) != 0 | (c[L >> 2] | 0) != 0)) {
	                                            Sa = 577;
	                                            break a
	                                        }
	                                    }
	                                } while (0);
	                                i:do if (c[z >> 2] | 0)while (1) {
	                                    do if ((d[c[H >> 2] >> 0] | 0) != 32) {
	                                        if (9 <= (d[c[H >> 2] >> 0] | 0) ? (d[c[H >> 2] >> 0] | 0) <= 10 : 0)break;
	                                        if ((d[c[H >> 2] >> 0] | 0) != 13)break i
	                                    } while (0);
	                                    c[H >> 2] = (c[H >> 2] | 0) + 1
	                                } while (0);
	                                if (!(d[c[H >> 2] >> 0] | 0))if ((c[v >> 2] | 0) != 0 ? (c[C >> 2] = hI(3) | 0, (c[C >> 2] | 0) != 0) : 0) {
	                                    if (c[I >> 2] | 0) {
	                                        j:do if ((c[K >> 2] | 0) != -1)while (1) {
	                                            if ((c[I >> 2] | 0) == (c[K >> 2] | 0))break j;
	                                            if ((d[(c[N >> 2] | 0) + -1 >> 0] | 0) != 48)break j;
	                                            c[N >> 2] = (c[N >> 2] | 0) + -1;
	                                            c[I >> 2] = (c[I >> 2] | 0) + -1
	                                        } while (0);
	                                        if (c[I >> 2] | 0) {
	                                            a[c[N >> 2] >> 0] = 0;
	                                            c[N >> 2] = M;
	                                            pI(N, (c[C >> 2] | 0) + 8 | 0, (c[C >> 2] | 0) + 12 | 0, (c[C >> 2] | 0) + 16 | 0) | 0
	                                        }
	                                    }
	                                    x = (c[C >> 2] | 0) + 24 | 0;
	                                    b[x >> 1] = b[x >> 1] & -2 | c[J >> 2] & 1;
	                                    do if (c[I >> 2] | 0) {
	                                        x = (c[C >> 2] | 0) + 24 | 0;
	                                        b[x >> 1] = b[x >> 1] & 255 | (c[I >> 2] & 255) << 8 & 65535;
	                                        if ((c[K >> 2] | 0) == -1) {
	                                            x = (c[C >> 2] | 0) + 24 | 0;
	                                            b[x >> 1] = b[x >> 1] & -255;
	                                            break
	                                        } else {
	                                            x = (c[C >> 2] | 0) + 24 | 0;
	                                            b[x >> 1] = b[x >> 1] & -255 | ((c[I >> 2] | 0) - (c[K >> 2] | 0) & 127) << 1 & 65535;
	                                            break
	                                        }
	                                    } else {
	                                        x = (c[C >> 2] | 0) + 24 | 0;
	                                        b[x >> 1] = b[x >> 1] & 255 | 256
	                                    } while (0);
	                                    c[c[v >> 2] >> 2] = c[C >> 2];
	                                    Sa = 580
	                                } else Sa = 580; else Sa = 577
	                            } else Sa = 577
	                        } else Sa = 577;
	                        break
	                    }
	                    case 1:
	                    {
	                        k:do if (!(c[z >> 2] | 0)) {
	                            c[F >> 2] = c[u >> 2];
	                            if ((c[y >> 2] | 0) == 2)while (1) {
	                                if (!(d[c[F >> 2] >> 0] | 0))break k;
	                                if ((d[c[F >> 2] >> 0] | 0) == 13) {
	                                    Sa = 577;
	                                    break a
	                                }
	                                if ((d[c[F >> 2] >> 0] | 0) == 10) {
	                                    Sa = 577;
	                                    break a
	                                }
	                                if ((d[c[F >> 2] >> 0] | 0) == 9) {
	                                    Sa = 577;
	                                    break a
	                                }
	                                c[F >> 2] = (c[F >> 2] | 0) + 1
	                            }
	                            if ((c[y >> 2] | 0) == 3)while (1) {
	                                if (!(d[c[F >> 2] >> 0] | 0))break k;
	                                if ((d[c[F >> 2] >> 0] | 0) == 13) {
	                                    Sa = 577;
	                                    break a
	                                }
	                                if ((d[c[F >> 2] >> 0] | 0) == 10) {
	                                    Sa = 577;
	                                    break a
	                                }
	                                if ((d[c[F >> 2] >> 0] | 0) == 9) {
	                                    Sa = 577;
	                                    break a
	                                }
	                                x = (d[c[F >> 2] >> 0] | 0) == 32;
	                                c[F >> 2] = (c[F >> 2] | 0) + 1;
	                                if (!x)continue;
	                                if ((d[c[F >> 2] >> 0] | 0) == 32) {
	                                    Sa = 577;
	                                    break a
	                                }
	                            }
	                        } while (0);
	                        if ((c[B >> 2] | 0) != 0 & (c[v >> 2] | 0) != 0) {
	                            if (c[A >> 2] | 0) {
	                                if ((c[y >> 2] | 0) != 3) {
	                                    if ((c[y >> 2] | 0) == 2)c[D >> 2] = RH(c[u >> 2] | 0) | 0
	                                } else c[D >> 2] = SH(c[u >> 2] | 0) | 0;
	                                if (c[D >> 2] | 0)c[u >> 2] = c[D >> 2]
	                            }
	                            c[C >> 2] = hI(1) | 0;
	                            if (c[C >> 2] | 0) {
	                                x = my(c[u >> 2] | 0) | 0;
	                                c[(c[C >> 2] | 0) + 8 >> 2] = x;
	                                c[c[v >> 2] >> 2] = c[C >> 2];
	                                Sa = 580
	                            } else Sa = 583
	                        } else Sa = 580;
	                        break
	                    }
	                    case 12:
	                    {
	                        c[E >> 2] = rI(c[t >> 2] | 0, c[u >> 2] | 0, c[v >> 2] | 0, c[z >> 2] | 0) | 0;
	                        Sa = 571;
	                        break
	                    }
	                    case 15:
	                    {
	                        c[S >> 2] = c[u >> 2];
	                        do if (c[z >> 2] | 0) {
	                            while (1) {
	                                do if ((d[c[S >> 2] >> 0] | 0) == 32)Wa = 1; else {
	                                    if (9 <= (d[c[S >> 2] >> 0] | 0) ? (d[c[S >> 2] >> 0] | 0) <= 10 : 0) {
	                                        Wa = 1;
	                                        break
	                                    }
	                                    Wa = (d[c[S >> 2] >> 0] | 0) == 13
	                                } while (0);
	                                Xa = c[S >> 2] | 0;
	                                if (!Wa)break;
	                                c[S >> 2] = Xa + 1
	                            }
	                            do if ((d[Xa >> 0] | 0) == 48) {
	                                c[E >> 2] = 0;
	                                c[S >> 2] = (c[S >> 2] | 0) + 1
	                            } else {
	                                if ((d[c[S >> 2] >> 0] | 0) == 49) {
	                                    c[E >> 2] = 1;
	                                    c[S >> 2] = (c[S >> 2] | 0) + 1;
	                                    break
	                                }
	                                x = c[S >> 2] | 0;
	                                if ((d[c[S >> 2] >> 0] | 0) == 116) {
	                                    c[S >> 2] = x + 1;
	                                    p = c[S >> 2] | 0;
	                                    c[S >> 2] = p + 1;
	                                    if ((d[p >> 0] | 0) != 114) {
	                                        Sa = 577;
	                                        break a
	                                    }
	                                    p = c[S >> 2] | 0;
	                                    c[S >> 2] = p + 1;
	                                    if ((d[p >> 0] | 0) != 117) {
	                                        Sa = 577;
	                                        break a
	                                    }
	                                    p = c[S >> 2] | 0;
	                                    c[S >> 2] = p + 1;
	                                    if ((d[p >> 0] | 0) != 101) {
	                                        Sa = 577;
	                                        break a
	                                    }
	                                    c[E >> 2] = 1;
	                                    break
	                                }
	                                if ((d[x >> 0] | 0) != 102) {
	                                    Sa = 577;
	                                    break a
	                                }
	                                c[S >> 2] = (c[S >> 2] | 0) + 1;
	                                x = c[S >> 2] | 0;
	                                c[S >> 2] = x + 1;
	                                if ((d[x >> 0] | 0) != 97) {
	                                    Sa = 577;
	                                    break a
	                                }
	                                x = c[S >> 2] | 0;
	                                c[S >> 2] = x + 1;
	                                if ((d[x >> 0] | 0) != 108) {
	                                    Sa = 577;
	                                    break a
	                                }
	                                x = c[S >> 2] | 0;
	                                c[S >> 2] = x + 1;
	                                if ((d[x >> 0] | 0) != 115) {
	                                    Sa = 577;
	                                    break a
	                                }
	                                x = c[S >> 2] | 0;
	                                c[S >> 2] = x + 1;
	                                if ((d[x >> 0] | 0) != 101) {
	                                    Sa = 577;
	                                    break a
	                                }
	                                c[E >> 2] = 0
	                            } while (0);
	                            if (d[c[S >> 2] >> 0] | 0) {
	                                while (1) {
	                                    do if ((d[c[S >> 2] >> 0] | 0) == 32)Ya = 1; else {
	                                        if (9 <= (d[c[S >> 2] >> 0] | 0) ? (d[c[S >> 2] >> 0] | 0) <= 10 : 0) {
	                                            Ya = 1;
	                                            break
	                                        }
	                                        Ya = (d[c[S >> 2] >> 0] | 0) == 13
	                                    } while (0);
	                                    Za = c[S >> 2] | 0;
	                                    if (!Ya)break;
	                                    c[S >> 2] = Za + 1
	                                }
	                                if (d[Za >> 0] | 0) {
	                                    Sa = 577;
	                                    break a
	                                }
	                            }
	                        } else {
	                            if ((d[c[S >> 2] >> 0] | 0) == 48 ? (d[(c[S >> 2] | 0) + 1 >> 0] | 0) == 0 : 0) {
	                                c[E >> 2] = 0;
	                                break
	                            }
	                            if ((d[c[S >> 2] >> 0] | 0) == 49 ? (d[(c[S >> 2] | 0) + 1 >> 0] | 0) == 0 : 0) {
	                                c[E >> 2] = 1;
	                                break
	                            }
	                            if (((((d[c[S >> 2] >> 0] | 0) == 116 ? (d[(c[S >> 2] | 0) + 1 >> 0] | 0) == 114 : 0) ? (d[(c[S >> 2] | 0) + 2 >> 0] | 0) == 117 : 0) ? (d[(c[S >> 2] | 0) + 3 >> 0] | 0) == 101 : 0) ? (d[(c[S >> 2] | 0) + 4 >> 0] | 0) == 0 : 0) {
	                                c[E >> 2] = 1;
	                                break
	                            }
	                            if ((d[c[S >> 2] >> 0] | 0) != 102) {
	                                Sa = 577;
	                                break a
	                            }
	                            if ((d[(c[S >> 2] | 0) + 1 >> 0] | 0) != 97) {
	                                Sa = 577;
	                                break a
	                            }
	                            if ((d[(c[S >> 2] | 0) + 2 >> 0] | 0) != 108) {
	                                Sa = 577;
	                                break a
	                            }
	                            if ((d[(c[S >> 2] | 0) + 3 >> 0] | 0) != 115) {
	                                Sa = 577;
	                                break a
	                            }
	                            if ((d[(c[S >> 2] | 0) + 4 >> 0] | 0) != 101) {
	                                Sa = 577;
	                                break a
	                            }
	                            if (d[(c[S >> 2] | 0) + 5 >> 0] | 0) {
	                                Sa = 577;
	                                break a
	                            }
	                            c[E >> 2] = 0
	                        } while (0);
	                        if (c[v >> 2] | 0) {
	                            c[C >> 2] = hI(15) | 0;
	                            if (c[C >> 2] | 0) {
	                                c[(c[C >> 2] | 0) + 8 >> 2] = c[E >> 2];
	                                c[c[v >> 2] >> 2] = c[C >> 2];
	                                Sa = 580
	                            } else Sa = 583
	                        } else Sa = 580;
	                        break
	                    }
	                    case 16:
	                    {
	                        c[T >> 2] = c[u >> 2];
	                        l:do if (!(c[z >> 2] | 0))while (1) {
	                            if (!(d[c[T >> 2] >> 0] | 0))break l;
	                            if ((d[c[T >> 2] >> 0] | 0) == 13) {
	                                Sa = 577;
	                                break a
	                            }
	                            if ((d[c[T >> 2] >> 0] | 0) == 10) {
	                                Sa = 577;
	                                break a
	                            }
	                            if ((d[c[T >> 2] >> 0] | 0) == 9) {
	                                Sa = 577;
	                                break a
	                            }
	                            x = (d[c[T >> 2] >> 0] | 0) == 32;
	                            c[T >> 2] = (c[T >> 2] | 0) + 1;
	                            if (!x)continue;
	                            if (!(d[c[T >> 2] >> 0] | 0)) {
	                                Sa = 577;
	                                break a
	                            }
	                            if ((d[c[T >> 2] >> 0] | 0) == 32) {
	                                Sa = 577;
	                                break a
	                            }
	                        } while (0);
	                        if (c[v >> 2] | 0) {
	                            c[C >> 2] = hI(16) | 0;
	                            if (c[C >> 2] | 0) {
	                                x = my(c[u >> 2] | 0) | 0;
	                                c[(c[C >> 2] | 0) + 8 >> 2] = x;
	                                c[c[v >> 2] >> 2] = c[C >> 2];
	                                Sa = 580
	                            } else Sa = 583
	                        } else Sa = 580;
	                        break
	                    }
	                    case 17:
	                    {
	                        if ((c[z >> 2] | 0) != 0 ? (c[D >> 2] = SH(c[u >> 2] | 0) | 0, (c[D >> 2] | 0) != 0) : 0)c[u >> 2] = c[D >> 2];
	                        if ((Ne(c[u >> 2] | 0) | 0) == 1)if (c[v >> 2] | 0) {
	                            c[C >> 2] = hI(17) | 0;
	                            if (c[C >> 2] | 0) {
	                                x = my(c[u >> 2] | 0) | 0;
	                                c[(c[C >> 2] | 0) + 8 >> 2] = x;
	                                c[c[v >> 2] >> 2] = c[C >> 2];
	                                Sa = 580
	                            } else Sa = 583
	                        } else Sa = 580; else Sa = 577;
	                        break
	                    }
	                    case 18:
	                    {
	                        if (!(Hh(c[u >> 2] | 0, 1) | 0))if (c[v >> 2] | 0) {
	                            c[C >> 2] = hI(18) | 0;
	                            if (c[C >> 2] | 0) {
	                                x = my(c[u >> 2] | 0) | 0;
	                                c[(c[C >> 2] | 0) + 8 >> 2] = x;
	                                c[c[v >> 2] >> 2] = c[C >> 2];
	                                Sa = 580
	                            } else Sa = 583
	                        } else Sa = 580; else Sa = 577;
	                        break
	                    }
	                    case 20:
	                    {
	                        c[E >> 2] = Gh(c[u >> 2] | 0, 1) | 0;
	                        if ((c[E >> 2] | 0) == 0 & (c[v >> 2] | 0) != 0 & (c[u >> 2] | 0) != 0) {
	                            c[C >> 2] = hI(20) | 0;
	                            if (c[C >> 2] | 0) {
	                                c[U >> 2] = c[u >> 2];
	                                while (1) {
	                                    do if ((d[c[U >> 2] >> 0] | 0) == 32)_a = 1; else {
	                                        if (9 <= (d[c[U >> 2] >> 0] | 0) ? (d[c[U >> 2] >> 0] | 0) <= 10 : 0) {
	                                            _a = 1;
	                                            break
	                                        }
	                                        _a = (d[c[U >> 2] >> 0] | 0) == 13
	                                    } while (0);
	                                    $a = c[U >> 2] | 0;
	                                    if (!_a)break;
	                                    c[U >> 2] = $a + 1
	                                }
	                                c[V >> 2] = $a;
	                                while (1) {
	                                    if (!(d[c[V >> 2] >> 0] | 0))break;
	                                    do if ((d[c[V >> 2] >> 0] | 0) == 32)ab = 1; else {
	                                        if (9 <= (d[c[V >> 2] >> 0] | 0) ? (d[c[V >> 2] >> 0] | 0) <= 10 : 0) {
	                                            ab = 1;
	                                            break
	                                        }
	                                        ab = (d[c[V >> 2] >> 0] | 0) == 13
	                                    } while (0);
	                                    if (!(ab ^ 1))break;
	                                    c[V >> 2] = (c[V >> 2] | 0) + 1
	                                }
	                                x = ly(c[U >> 2] | 0, (c[V >> 2] | 0) - (c[U >> 2] | 0) | 0) | 0;
	                                c[(c[C >> 2] | 0) + 8 >> 2] = x;
	                                c[c[v >> 2] >> 2] = c[C >> 2];
	                                Sa = 571
	                            } else Sa = 583
	                        } else Sa = 571;
	                        break
	                    }
	                    case 19:
	                    {
	                        c[E >> 2] = sI(c[42822] | 0, c[u >> 2] | 0, c[v >> 2] | 0, c[w >> 2] | 0) | 0;
	                        if ((c[E >> 2] | 0) > 0) {
	                            c[E >> 2] = 0;
	                            Sa = 571;
	                            break a
	                        } else {
	                            c[E >> 2] = 1;
	                            Sa = 571;
	                            break a
	                        }
	                        break
	                    }
	                    case 21:
	                    {
	                        c[W >> 2] = 0;
	                        c[X >> 2] = 0;
	                        c[E >> 2] = Fh(c[u >> 2] | 0, 1) | 0;
	                        if (c[E >> 2] | 0)Sa = 571; else {
	                            if (c[w >> 2] | 0) {
	                                c[X >> 2] = Ch(c[u >> 2] | 0, Y) | 0;
	                                c[Z >> 2] = cj(c[(c[w >> 2] | 0) + 32 >> 2] | 0, c[w >> 2] | 0, c[Y >> 2] | 0) | 0;
	                                if ((c[Z >> 2] | 0) == 0 & (c[Y >> 2] | 0) != 0) {
	                                    zb[c[135736 >> 2] & 511](c[Y >> 2] | 0);
	                                    if (!(c[X >> 2] | 0)) {
	                                        Sa = 577;
	                                        break a
	                                    }
	                                    zb[c[135736 >> 2] & 511](c[X >> 2] | 0);
	                                    Sa = 577;
	                                    break a
	                                }
	                                if (c[Z >> 2] | 0)c[W >> 2] = c[(c[Z >> 2] | 0) + 8 >> 2];
	                                if (c[Y >> 2] | 0)zb[c[135736 >> 2] & 511](c[Y >> 2] | 0)
	                            }
	                            if (!(c[v >> 2] | 0)) {
	                                if (!(c[X >> 2] | 0)) {
	                                    Sa = 571;
	                                    break a
	                                }
	                                zb[c[135736 >> 2] & 511](c[X >> 2] | 0);
	                                Sa = 571;
	                                break a
	                            }
	                            c[C >> 2] = hI(21) | 0;
	                            x = (c[X >> 2] | 0) != 0;
	                            if (!(c[C >> 2] | 0)) {
	                                if (!x) {
	                                    Sa = 583;
	                                    break a
	                                }
	                                zb[c[135736 >> 2] & 511](c[X >> 2] | 0);
	                                Sa = 583;
	                                break a
	                            }
	                            if (x)c[(c[C >> 2] | 0) + 8 >> 2] = c[X >> 2]; else {
	                                x = my(c[u >> 2] | 0) | 0;
	                                c[(c[C >> 2] | 0) + 8 >> 2] = x
	                            }
	                            if (c[W >> 2] | 0) {
	                                x = my(c[W >> 2] | 0) | 0;
	                                c[(c[C >> 2] | 0) + 12 >> 2] = x
	                            }
	                            c[c[v >> 2] >> 2] = c[C >> 2];
	                            Sa = 571
	                        }
	                        break
	                    }
	                    case 23:
	                    {
	                        c[E >> 2] = Eh(c[u >> 2] | 0, 1) | 0;
	                        if ((c[E >> 2] | 0) == 0 & (c[v >> 2] | 0) != 0) {
	                            c[C >> 2] = hI(23) | 0;
	                            if (!(c[C >> 2] | 0)) {
	                                Sa = 583;
	                                break a
	                            }
	                            x = my(c[u >> 2] | 0) | 0;
	                            c[(c[C >> 2] | 0) + 8 >> 2] = x;
	                            c[c[v >> 2] >> 2] = c[C >> 2]
	                        }
	                        if (((c[E >> 2] | 0) == 0 & (c[w >> 2] | 0) != 0 ? (c[(c[w >> 2] | 0) + 4 >> 2] | 0) == 2 : 0) ? (c[_ >> 2] = c[w >> 2], (c[(c[_ >> 2] | 0) + 40 >> 2] | 0) != 2) : 0) {
	                            c[aa >> 2] = tI(c[u >> 2] | 0) | 0;
	                            x = c[(c[w >> 2] | 0) + 32 >> 2] | 0;
	                            if (c[aa >> 2] | 0) {
	                                c[$ >> 2] = Cm(0, x, c[aa >> 2] | 0, c[_ >> 2] | 0) | 0;
	                                zb[c[135736 >> 2] & 511](c[aa >> 2] | 0)
	                            } else c[$ >> 2] = Cm(0, x, c[u >> 2] | 0, c[_ >> 2] | 0) | 0;
	                            if (!(c[$ >> 2] | 0)) {
	                                c[E >> 2] = 2;
	                                Sa = 571;
	                                break a
	                            } else {
	                                c[(c[_ >> 2] | 0) + 40 >> 2] = 2;
	                                Sa = 571;
	                                break a
	                            }
	                        } else Sa = 571;
	                        break
	                    }
	                    case 22:
	                    {
	                        c[E >> 2] = Eh(c[u >> 2] | 0, 1) | 0;
	                        if ((c[E >> 2] | 0) == 0 & (c[v >> 2] | 0) != 0) {
	                            c[C >> 2] = hI(22) | 0;
	                            if (c[C >> 2] | 0) {
	                                x = my(c[u >> 2] | 0) | 0;
	                                c[(c[C >> 2] | 0) + 8 >> 2] = x;
	                                c[c[v >> 2] >> 2] = c[C >> 2];
	                                Sa = 571
	                            } else Sa = 583
	                        } else Sa = 571;
	                        break
	                    }
	                    case 24:
	                    {
	                        c[E >> 2] = Eh(c[u >> 2] | 0, 1) | 0;
	                        if ((c[E >> 2] | 0) == 0 & (c[v >> 2] | 0) != 0) {
	                            c[C >> 2] = hI(24) | 0;
	                            if (!(c[C >> 2] | 0)) {
	                                Sa = 583;
	                                break a
	                            }
	                            x = my(c[u >> 2] | 0) | 0;
	                            c[(c[C >> 2] | 0) + 8 >> 2] = x;
	                            c[c[v >> 2] >> 2] = c[C >> 2]
	                        }
	                        if ((c[E >> 2] | 0) == 0 & (c[w >> 2] | 0) != 0 ? (c[(c[w >> 2] | 0) + 4 >> 2] | 0) == 2 : 0) {
	                            c[ba >> 2] = c[w >> 2];
	                            c[ca >> 2] = tI(c[u >> 2] | 0) | 0;
	                            x = c[(c[w >> 2] | 0) + 32 >> 2] | 0;
	                            if (c[ca >> 2] | 0) {
	                                Im(0, x, c[ca >> 2] | 0, c[ba >> 2] | 0) | 0;
	                                zb[c[135736 >> 2] & 511](c[ca >> 2] | 0)
	                            } else Im(0, x, c[u >> 2] | 0, c[ba >> 2] | 0) | 0;
	                            c[(c[ba >> 2] | 0) + 40 >> 2] = 3;
	                            Sa = 571
	                        } else Sa = 571;
	                        break
	                    }
	                    case 25:
	                    {
	                        c[E >> 2] = sI(c[42834] | 0, c[u >> 2] | 0, c[v >> 2] | 0, c[w >> 2] | 0) | 0;
	                        if ((c[E >> 2] | 0) < 0)c[E >> 2] = 2; else c[E >> 2] = 0;
	                        if ((c[E >> 2] | 0) == 0 & (c[w >> 2] | 0) != 0 ? (c[(c[w >> 2] | 0) + 4 >> 2] | 0) == 2 : 0) {
	                            c[da >> 2] = c[w >> 2];
	                            c[(c[da >> 2] | 0) + 40 >> 2] = 4;
	                            Sa = 571
	                        } else Sa = 571;
	                        break
	                    }
	                    case 26:
	                    {
	                        c[E >> 2] = Eh(c[u >> 2] | 0, 1) | 0;
	                        if (!((c[w >> 2] | 0) != 0 ? (c[(c[w >> 2] | 0) + 32 >> 2] | 0) != 0 : 0))c[E >> 2] = 3;
	                        do if (!(c[E >> 2] | 0)) {
	                            c[ea >> 2] = tI(c[u >> 2] | 0) | 0;
	                            x = c[(c[w >> 2] | 0) + 32 >> 2] | 0;
	                            if (c[ea >> 2] | 0) {
	                                c[fa >> 2] = ad(x, c[ea >> 2] | 0) | 0;
	                                zb[c[135736 >> 2] & 511](c[ea >> 2] | 0)
	                            } else c[fa >> 2] = ad(x, c[u >> 2] | 0) | 0;
	                            if ((c[fa >> 2] | 0) != 0 ? (c[(c[fa >> 2] | 0) + 48 >> 2] | 0) == 3 : 0)break;
	                            c[E >> 2] = 4
	                        } while (0);
	                        if ((c[E >> 2] | 0) == 0 & (c[v >> 2] | 0) != 0) {
	                            x = c[33976] | 0;
	                            p = c[33980] | 0;
	                            c[r >> 2] = 171992;
	                            c[r + 4 >> 2] = 2831;
	                            Db[x & 511](p, 171960, r)
	                        }
	                        if ((c[E >> 2] | 0) == 0 & (c[w >> 2] | 0) != 0 ? (c[(c[w >> 2] | 0) + 4 >> 2] | 0) == 2 : 0) {
	                            c[ga >> 2] = c[w >> 2];
	                            c[(c[ga >> 2] | 0) + 40 >> 2] = 5;
	                            Sa = 571
	                        } else Sa = 571;
	                        break
	                    }
	                    case 27:
	                    {
	                        if ((c[w >> 2] | 0) != 0 ? (c[(c[w >> 2] | 0) + 32 >> 2] | 0) != 0 : 0) {
	                            c[E >> 2] = sI(c[42838] | 0, c[u >> 2] | 0, c[v >> 2] | 0, c[w >> 2] | 0) | 0;
	                            if ((c[E >> 2] | 0) <= 0)c[E >> 2] = 1; else c[E >> 2] = 0;
	                            if (!((c[E >> 2] | 0) == 0 & (c[w >> 2] | 0) != 0)) {
	                                Sa = 571;
	                                break a
	                            }
	                            if ((c[(c[w >> 2] | 0) + 4 >> 2] | 0) != 2) {
	                                Sa = 571;
	                                break a
	                            }
	                            c[ha >> 2] = c[w >> 2];
	                            c[(c[ha >> 2] | 0) + 40 >> 2] = 6;
	                            Sa = 571;
	                            break a
	                        }
	                        if (c[D >> 2] | 0)zb[c[135736 >> 2] & 511](c[D >> 2] | 0);
	                        c[s >> 2] = 3;
	                        Ra = c[s >> 2] | 0;
	                        i = q;
	                        return Ra | 0
	                    }
	                    case 28:
	                    {
	                        c[ia >> 2] = 0;
	                        c[ja >> 2] = 0;
	                        c[E >> 2] = Fh(c[u >> 2] | 0, 1) | 0;
	                        if ((c[E >> 2] | 0) == 0 & (c[w >> 2] | 0) != 0) {
	                            c[ja >> 2] = Ch(c[u >> 2] | 0, ka) | 0;
	                            do if (c[ka >> 2] | 0) {
	                                c[la >> 2] = cj(c[(c[w >> 2] | 0) + 32 >> 2] | 0, c[w >> 2] | 0, c[ka >> 2] | 0) | 0;
	                                if (!(c[la >> 2] | 0)) {
	                                    c[E >> 2] = 1;
	                                    break
	                                }
	                                if (c[v >> 2] | 0)c[ia >> 2] = my(c[(c[la >> 2] | 0) + 8 >> 2] | 0) | 0
	                            } while (0);
	                            if ((c[ja >> 2] | 0) != 0 ? (c[v >> 2] | 0) == 0 | (c[E >> 2] | 0) != 0 : 0)zb[c[135736 >> 2] & 511](c[ja >> 2] | 0);
	                            if (c[ka >> 2] | 0)zb[c[135736 >> 2] & 511](c[ka >> 2] | 0)
	                        }
	                        if (!((c[w >> 2] | 0) != 0 ? (c[(c[w >> 2] | 0) + 32 >> 2] | 0) != 0 : 0))c[E >> 2] = 3;
	                        do if (!(c[E >> 2] | 0)) {
	                            c[E >> 2] = Pm(0, c[(c[w >> 2] | 0) + 32 >> 2] | 0, c[u >> 2] | 0) | 0;
	                            if ((c[E >> 2] | 0) == 1) {
	                                c[E >> 2] = 0;
	                                break
	                            } else {
	                                c[E >> 2] = 1;
	                                break
	                            }
	                        } while (0);
	                        if ((c[E >> 2] | 0) == 0 & (c[v >> 2] | 0) != 0) {
	                            c[C >> 2] = hI(28) | 0;
	                            p = (c[ja >> 2] | 0) != 0;
	                            if (!(c[C >> 2] | 0)) {
	                                if (p)zb[c[135736 >> 2] & 511](c[ja >> 2] | 0);
	                                if (!(c[ia >> 2] | 0)) {
	                                    Sa = 583;
	                                    break a
	                                }
	                                zb[c[135736 >> 2] & 511](c[ia >> 2] | 0);
	                                Sa = 583;
	                                break a
	                            }
	                            if (p)c[(c[C >> 2] | 0) + 8 >> 2] = c[ja >> 2]; else {
	                                p = my(c[u >> 2] | 0) | 0;
	                                c[(c[C >> 2] | 0) + 8 >> 2] = p
	                            }
	                            if (c[ia >> 2] | 0)c[(c[C >> 2] | 0) + 12 >> 2] = c[ia >> 2];
	                            c[c[v >> 2] >> 2] = c[C >> 2];
	                            Sa = 571
	                        } else Sa = 571;
	                        break
	                    }
	                    case 29:
	                    {
	                        if (d[c[u >> 2] >> 0] | 0) {
	                            if ((c[z >> 2] | 0) != 0 ? (c[D >> 2] = SH(c[u >> 2] | 0) | 0, (c[D >> 2] | 0) != 0) : 0)c[u >> 2] = c[D >> 2];
	                            c[na >> 2] = my(c[u >> 2] | 0) | 0;
	                            c[oa >> 2] = c[na >> 2];
	                            while (1) {
	                                if (!(a[c[oa >> 2] >> 0] | 0))break;
	                                do if ((((((((d[c[oa >> 2] >> 0] | 0) >= 32 ? (d[c[oa >> 2] >> 0] | 0) < 127 : 0) ? (d[c[oa >> 2] >> 0] | 0) != 32 : 0) ? (d[c[oa >> 2] >> 0] | 0) != 60 : 0) ? (d[c[oa >> 2] >> 0] | 0) != 62 : 0) ? (d[c[oa >> 2] >> 0] | 0) != 34 : 0) ? (d[c[oa >> 2] >> 0] | 0) != 123 : 0) ? (d[c[oa >> 2] >> 0] | 0) != 125 : 0) {
	                                    if ((d[c[oa >> 2] >> 0] | 0) == 124) {
	                                        Sa = 409;
	                                        break
	                                    }
	                                    if ((d[c[oa >> 2] >> 0] | 0) == 92) {
	                                        Sa = 409;
	                                        break
	                                    }
	                                    if ((d[c[oa >> 2] >> 0] | 0) == 94) {
	                                        Sa = 409;
	                                        break
	                                    }
	                                    if ((d[c[oa >> 2] >> 0] | 0) == 96) {
	                                        Sa = 409;
	                                        break
	                                    }
	                                    if ((d[c[oa >> 2] >> 0] | 0) == 39)Sa = 409
	                                } else Sa = 409; while (0);
	                                if ((Sa | 0) == 409) {
	                                    Sa = 0;
	                                    a[c[oa >> 2] >> 0] = 95
	                                }
	                                c[oa >> 2] = (c[oa >> 2] | 0) + 1
	                            }
	                            c[ma >> 2] = yl(c[na >> 2] | 0) | 0;
	                            zb[c[135736 >> 2] & 511](c[na >> 2] | 0);
	                            if (!(c[ma >> 2] | 0)) {
	                                Sa = 577;
	                                break a
	                            }
	                            Al(c[ma >> 2] | 0)
	                        }
	                        if (c[v >> 2] | 0) {
	                            c[C >> 2] = hI(29) | 0;
	                            if (!(c[C >> 2] | 0))Sa = 583; else {
	                                p = my(c[u >> 2] | 0) | 0;
	                                c[(c[C >> 2] | 0) + 8 >> 2] = p;
	                                c[c[v >> 2] >> 2] = c[C >> 2];
	                                Sa = 580
	                            }
	                        } else Sa = 580;
	                        break
	                    }
	                    case 43:
	                    {
	                        c[pa >> 2] = c[u >> 2];
	                        c[ta >> 2] = 0;
	                        if (c[pa >> 2] | 0) {
	                            m:do if (c[z >> 2] | 0)while (1) {
	                                do if ((d[c[pa >> 2] >> 0] | 0) != 32) {
	                                    if (9 <= (d[c[pa >> 2] >> 0] | 0) ? (d[c[pa >> 2] >> 0] | 0) <= 10 : 0)break;
	                                    if ((d[c[pa >> 2] >> 0] | 0) != 13)break m
	                                } while (0);
	                                c[pa >> 2] = (c[pa >> 2] | 0) + 1
	                            } while (0);
	                            c[qa >> 2] = c[pa >> 2];
	                            n:while (1) {
	                                if (!((d[c[pa >> 2] >> 0] | 0) >= 48 ? (d[c[pa >> 2] >> 0] | 0) <= 57 : 0))Sa = 426;
	                                do if ((Sa | 0) == 426) {
	                                    Sa = 0;
	                                    if ((d[c[pa >> 2] >> 0] | 0) >= 65 ? (d[c[pa >> 2] >> 0] | 0) <= 70 : 0)break;
	                                    if ((d[c[pa >> 2] >> 0] | 0) < 97)break n;
	                                    if ((d[c[pa >> 2] >> 0] | 0) > 102)break n
	                                } while (0);
	                                c[ta >> 2] = (c[ta >> 2] | 0) + 1;
	                                c[pa >> 2] = (c[pa >> 2] | 0) + 1
	                            }
	                            o:do if (c[z >> 2] | 0)while (1) {
	                                do if ((d[c[pa >> 2] >> 0] | 0) != 32) {
	                                    if (9 <= (d[c[pa >> 2] >> 0] | 0) ? (d[c[pa >> 2] >> 0] | 0) <= 10 : 0)break;
	                                    if ((d[c[pa >> 2] >> 0] | 0) != 13)break o
	                                } while (0);
	                                c[pa >> 2] = (c[pa >> 2] | 0) + 1
	                            } while (0);
	                            if ((d[c[pa >> 2] >> 0] | 0) == 0 ? ((c[ta >> 2] | 0) % 2 | 0 | 0) == 0 : 0)if (c[v >> 2] | 0) {
	                                c[C >> 2] = hI(43) | 0;
	                                if (!(c[C >> 2] | 0))Sa = 583; else {
	                                    c[pa >> 2] = ly(c[qa >> 2] | 0, c[ta >> 2] | 0) | 0;
	                                    if (!(c[pa >> 2] | 0)) {
	                                        gI(c[w >> 2] | 0, 172232);
	                                        zb[c[135736 >> 2] & 511](c[C >> 2] | 0);
	                                        Sa = 577;
	                                        break a
	                                    }
	                                    c[sa >> 2] = (c[ta >> 2] | 0) / 2 | 0;
	                                    c[ra >> 2] = c[pa >> 2];
	                                    while (1) {
	                                        p = c[ta >> 2] | 0;
	                                        c[ta >> 2] = p + -1;
	                                        if ((p | 0) <= 0)break;
	                                        if ((d[c[ra >> 2] >> 0] | 0) >= 97)a[c[ra >> 2] >> 0] = (d[c[ra >> 2] >> 0] | 0) - 32;
	                                        c[ra >> 2] = (c[ra >> 2] | 0) + 1
	                                    }
	                                    c[(c[C >> 2] | 0) + 8 >> 2] = c[pa >> 2];
	                                    c[(c[C >> 2] | 0) + 12 >> 2] = c[sa >> 2];
	                                    c[c[v >> 2] >> 2] = c[C >> 2];
	                                    Sa = 580
	                                }
	                            } else Sa = 580; else Sa = 577
	                        } else Sa = 577;
	                        break
	                    }
	                    case 44:
	                    {
	                        c[ua >> 2] = c[u >> 2];
	                        c[xa >> 2] = 0;
	                        c[ya >> 2] = 0;
	                        if (c[ua >> 2] | 0) {
	                            while (1) {
	                                if (!(a[c[ua >> 2] >> 0] | 0))break;
	                                c[za >> 2] = uI(a[c[ua >> 2] >> 0] | 0) | 0;
	                                if ((c[za >> 2] | 0) >= 0) {
	                                    if ((c[za >> 2] | 0) >= 64)break;
	                                    c[xa >> 2] = (c[xa >> 2] | 0) + 1
	                                }
	                                c[ua >> 2] = (c[ua >> 2] | 0) + 1
	                            }
	                            while (1) {
	                                if (!(a[c[ua >> 2] >> 0] | 0))break;
	                                c[Aa >> 2] = uI(a[c[ua >> 2] >> 0] | 0) | 0;
	                                if ((c[Aa >> 2] | 0) >= 0 & (c[Aa >> 2] | 0) < 64) {
	                                    Sa = 577;
	                                    break a
	                                }
	                                if ((c[Aa >> 2] | 0) == 64)c[ya >> 2] = (c[ya >> 2] | 0) + 1;
	                                c[ua >> 2] = (c[ua >> 2] | 0) + 1
	                            }
	                            c[wa >> 2] = ((c[xa >> 2] | 0) / 4 | 0) * 3;
	                            do if (!(c[ya >> 2] | 0)) {
	                                if ((c[xa >> 2] | 0) % 4 | 0) {
	                                    Sa = 577;
	                                    break a
	                                }
	                            } else {
	                                if ((c[ya >> 2] | 0) == 1) {
	                                    if (((c[xa >> 2] | 0) % 4 | 0 | 0) != 3) {
	                                        Sa = 577;
	                                        break a
	                                    }
	                                    c[Ba >> 2] = uI(a[c[ua >> 2] >> 0] | 0) | 0;
	                                    while (1) {
	                                        if (!((c[Ba >> 2] | 0) < 0 | (c[Ba >> 2] | 0) > 63))break;
	                                        c[ua >> 2] = (c[ua >> 2] | 0) + -1;
	                                        c[Ba >> 2] = uI(a[c[ua >> 2] >> 0] | 0) | 0
	                                    }
	                                    if (c[Ba >> 2] & -61) {
	                                        Sa = 577;
	                                        break a
	                                    }
	                                    c[wa >> 2] = (c[wa >> 2] | 0) + 2;
	                                    break
	                                }
	                                if ((c[ya >> 2] | 0) != 2) {
	                                    Sa = 577;
	                                    break a
	                                }
	                                if (((c[xa >> 2] | 0) % 4 | 0 | 0) != 2) {
	                                    Sa = 577;
	                                    break a
	                                }
	                                c[Ca >> 2] = uI(a[c[ua >> 2] >> 0] | 0) | 0;
	                                while (1) {
	                                    if (!((c[Ca >> 2] | 0) < 0 | (c[Ca >> 2] | 0) > 63))break;
	                                    c[ua >> 2] = (c[ua >> 2] | 0) + -1;
	                                    c[Ca >> 2] = uI(a[c[ua >> 2] >> 0] | 0) | 0
	                                }
	                                if (c[Ca >> 2] & -49) {
	                                    Sa = 577;
	                                    break a
	                                }
	                                c[wa >> 2] = (c[wa >> 2] | 0) + 1
	                            } while (0);
	                            if (c[v >> 2] | 0) {
	                                c[C >> 2] = hI(44) | 0;
	                                if (!(c[C >> 2] | 0))Sa = 583; else {
	                                    c[va >> 2] = Cb[c[135752 >> 2] & 511]((c[xa >> 2] | 0) + (c[ya >> 2] | 0) + 1 | 0) | 0;
	                                    if (!(c[va >> 2] | 0)) {
	                                        gI(c[w >> 2] | 0, 172256);
	                                        zb[c[135736 >> 2] & 511](c[C >> 2] | 0);
	                                        Sa = 577;
	                                        break a
	                                    }
	                                    c[(c[C >> 2] | 0) + 8 >> 2] = c[va >> 2];
	                                    c[ua >> 2] = c[u >> 2];
	                                    while (1) {
	                                        if (!(a[c[ua >> 2] >> 0] | 0))break;
	                                        if ((uI(a[c[ua >> 2] >> 0] | 0) | 0) >= 0) {
	                                            a[c[va >> 2] >> 0] = a[c[ua >> 2] >> 0] | 0;
	                                            c[va >> 2] = (c[va >> 2] | 0) + 1
	                                        }
	                                        c[ua >> 2] = (c[ua >> 2] | 0) + 1
	                                    }
	                                    a[c[va >> 2] >> 0] = 0;
	                                    c[(c[C >> 2] | 0) + 12 >> 2] = c[wa >> 2];
	                                    c[c[v >> 2] >> 2] = c[C >> 2];
	                                    Sa = 580
	                                }
	                            } else Sa = 580
	                        } else Sa = 577;
	                        break
	                    }
	                    case 33:
	                    case 32:
	                    case 31:
	                    case 34:
	                    case 30:
	                    {
	                        c[Da >> 2] = c[u >> 2];
	                        c[Ha >> 2] = 0;
	                        if (c[Da >> 2] | 0) {
	                            p:do if (c[z >> 2] | 0)while (1) {
	                                do if ((d[c[Da >> 2] >> 0] | 0) != 32) {
	                                    if (9 <= (d[c[Da >> 2] >> 0] | 0) ? (d[c[Da >> 2] >> 0] | 0) <= 10 : 0)break;
	                                    if ((d[c[Da >> 2] >> 0] | 0) != 13)break p
	                                } while (0);
	                                c[Da >> 2] = (c[Da >> 2] | 0) + 1
	                            } while (0);
	                            if ((d[c[Da >> 2] >> 0] | 0) != 45) {
	                                if ((d[c[Da >> 2] >> 0] | 0) == 43)c[Da >> 2] = (c[Da >> 2] | 0) + 1
	                            } else {
	                                c[Ha >> 2] = 1;
	                                c[Da >> 2] = (c[Da >> 2] | 0) + 1
	                            }
	                            c[E >> 2] = pI(Da, Ea, Fa, Ga) | 0;
	                            if ((c[E >> 2] | 0) >= 0) {
	                                q:do if (c[z >> 2] | 0)while (1) {
	                                    do if ((d[c[Da >> 2] >> 0] | 0) != 32) {
	                                        if (9 <= (d[c[Da >> 2] >> 0] | 0) ? (d[c[Da >> 2] >> 0] | 0) <= 10 : 0)break;
	                                        if ((d[c[Da >> 2] >> 0] | 0) != 13)break q
	                                    } while (0);
	                                    c[Da >> 2] = (c[Da >> 2] | 0) + 1
	                                } while (0);
	                                if (!(d[c[Da >> 2] >> 0] | 0)) {
	                                    do if ((c[(c[t >> 2] | 0) + 88 >> 2] | 0) == 31) {
	                                        if ((c[Ha >> 2] | 0) == 0 ? (c[Ga >> 2] | 0) != 0 | (c[Fa >> 2] | 0) != 0 | (c[Ea >> 2] | 0) != 0 : 0) {
	                                            Sa = 577;
	                                            break a
	                                        }
	                                    } else {
	                                        if ((c[(c[t >> 2] | 0) + 88 >> 2] | 0) == 34) {
	                                            if ((c[Ha >> 2] | 0) == 1) {
	                                                Sa = 577;
	                                                break a
	                                            }
	                                            if ((c[Ga >> 2] | 0) == 0 & (c[Fa >> 2] | 0) == 0 & (c[Ea >> 2] | 0) == 0) {
	                                                Sa = 577;
	                                                break a
	                                            } else break
	                                        }
	                                        if ((c[(c[t >> 2] | 0) + 88 >> 2] | 0) == 32) {
	                                            if (!(c[Ha >> 2] | 0)) {
	                                                Sa = 577;
	                                                break a
	                                            }
	                                            if ((c[Ga >> 2] | 0) == 0 & (c[Fa >> 2] | 0) == 0 & (c[Ea >> 2] | 0) == 0) {
	                                                Sa = 577;
	                                                break a
	                                            } else break
	                                        } else {
	                                            if (!((c[Ha >> 2] | 0) == 1 ? (c[(c[t >> 2] | 0) + 88 >> 2] | 0) == 33 : 0))break;
	                                            if ((c[Ga >> 2] | 0) != 0 | (c[Fa >> 2] | 0) != 0 | (c[Ea >> 2] | 0) != 0) {
	                                                Sa = 577;
	                                                break a
	                                            } else break
	                                        }
	                                    } while (0);
	                                    if ((c[v >> 2] | 0) != 0 ? (c[C >> 2] = hI(c[(c[t >> 2] | 0) + 88 >> 2] | 0) | 0, (c[C >> 2] | 0) != 0) : 0) {
	                                        if (!(c[E >> 2] | 0))c[E >> 2] = (c[E >> 2] | 0) + 1;
	                                        c[(c[C >> 2] | 0) + 8 >> 2] = c[Ea >> 2];
	                                        c[(c[C >> 2] | 0) + 12 >> 2] = c[Fa >> 2];
	                                        c[(c[C >> 2] | 0) + 16 >> 2] = c[Ga >> 2];
	                                        p = (c[C >> 2] | 0) + 24 | 0;
	                                        b[p >> 1] = b[p >> 1] & -2 | c[Ha >> 2] & 1;
	                                        p = (c[C >> 2] | 0) + 24 | 0;
	                                        b[p >> 1] = b[p >> 1] & -255;
	                                        p = (c[C >> 2] | 0) + 24 | 0;
	                                        b[p >> 1] = b[p >> 1] & 255 | (c[E >> 2] & 255) << 8 & 65535;
	                                        c[c[v >> 2] >> 2] = c[C >> 2];
	                                        Sa = 580
	                                    } else Sa = 580
	                                } else Sa = 577
	                            } else Sa = 577
	                        } else Sa = 577;
	                        break
	                    }
	                    case 35:
	                    case 39:
	                    case 41:
	                    case 37:
	                    {
	                        c[Ia >> 2] = c[u >> 2];
	                        c[Ma >> 2] = 0;
	                        if (c[Ia >> 2] | 0) {
	                            if ((d[c[Ia >> 2] >> 0] | 0) != 45) {
	                                if ((d[c[Ia >> 2] >> 0] | 0) == 43)c[Ia >> 2] = (c[Ia >> 2] | 0) + 1
	                            } else {
	                                c[Ma >> 2] = 1;
	                                c[Ia >> 2] = (c[Ia >> 2] | 0) + 1
	                            }
	                            c[E >> 2] = pI(Ia, Ja, Ka, La) | 0;
	                            if ((c[E >> 2] | 0) >= 0 ? (d[c[Ia >> 2] >> 0] | 0) == 0 : 0) {
	                                do if ((c[(c[t >> 2] | 0) + 88 >> 2] | 0) == 37) {
	                                    if ((c[La >> 2] | 0) >>> 0 >= 922) {
	                                        if ((c[La >> 2] | 0) >>> 0 > 922) {
	                                            Sa = 577;
	                                            break a
	                                        }
	                                        if ((c[Ka >> 2] | 0) >>> 0 >= 33720368) {
	                                            if ((c[Ka >> 2] | 0) >>> 0 > 33720368) {
	                                                Sa = 577;
	                                                break a
	                                            }
	                                            if ((c[Ma >> 2] | 0) == 0 & (c[Ja >> 2] | 0) >>> 0 > 54775807) {
	                                                Sa = 577;
	                                                break a
	                                            }
	                                            if ((c[Ma >> 2] | 0) == 1 & (c[Ja >> 2] | 0) >>> 0 > 54775808) {
	                                                Sa = 577;
	                                                break a
	                                            }
	                                        }
	                                    }
	                                } else {
	                                    if ((c[(c[t >> 2] | 0) + 88 >> 2] | 0) == 35) {
	                                        if (c[La >> 2] | 0) {
	                                            Sa = 577;
	                                            break a
	                                        }
	                                        if ((c[Ka >> 2] | 0) >>> 0 < 21)break;
	                                        if ((c[Ka >> 2] | 0) >>> 0 > 21) {
	                                            Sa = 577;
	                                            break a
	                                        }
	                                        if ((c[Ma >> 2] | 0) == 0 & (c[Ja >> 2] | 0) >>> 0 > 47483647) {
	                                            Sa = 577;
	                                            break a
	                                        }
	                                        if ((c[Ma >> 2] | 0) == 1 & (c[Ja >> 2] | 0) >>> 0 > 47483648) {
	                                            Sa = 577;
	                                            break a
	                                        } else break
	                                    }
	                                    if ((c[(c[t >> 2] | 0) + 88 >> 2] | 0) == 39) {
	                                        if ((c[Ka >> 2] | 0) != 0 | (c[La >> 2] | 0) != 0) {
	                                            Sa = 577;
	                                            break a
	                                        }
	                                        if ((c[Ma >> 2] | 0) == 1 & (c[Ja >> 2] | 0) >>> 0 > 32768) {
	                                            Sa = 577;
	                                            break a
	                                        }
	                                        if ((c[Ma >> 2] | 0) == 0 & (c[Ja >> 2] | 0) >>> 0 > 32767) {
	                                            Sa = 577;
	                                            break a
	                                        } else break
	                                    }
	                                    if ((c[(c[t >> 2] | 0) + 88 >> 2] | 0) == 41) {
	                                        if ((c[Ka >> 2] | 0) != 0 | (c[La >> 2] | 0) != 0) {
	                                            Sa = 577;
	                                            break a
	                                        }
	                                        if ((c[Ma >> 2] | 0) == 1 & (c[Ja >> 2] | 0) >>> 0 > 128) {
	                                            Sa = 577;
	                                            break a
	                                        }
	                                        if ((c[Ma >> 2] | 0) == 0 & (c[Ja >> 2] | 0) >>> 0 > 127) {
	                                            Sa = 577;
	                                            break a
	                                        }
	                                    }
	                                } while (0);
	                                if ((c[v >> 2] | 0) != 0 ? (c[C >> 2] = hI(c[(c[t >> 2] | 0) + 88 >> 2] | 0) | 0, (c[C >> 2] | 0) != 0) : 0) {
	                                    c[(c[C >> 2] | 0) + 8 >> 2] = c[Ja >> 2];
	                                    c[(c[C >> 2] | 0) + 12 >> 2] = c[Ka >> 2];
	                                    c[(c[C >> 2] | 0) + 16 >> 2] = c[La >> 2];
	                                    p = (c[C >> 2] | 0) + 24 | 0;
	                                    b[p >> 1] = b[p >> 1] & -2 | c[Ma >> 2] & 1;
	                                    p = (c[C >> 2] | 0) + 24 | 0;
	                                    b[p >> 1] = b[p >> 1] & -255;
	                                    p = (c[C >> 2] | 0) + 24 | 0;
	                                    b[p >> 1] = b[p >> 1] & 255 | (c[E >> 2] & 255) << 8 & 65535;
	                                    c[c[v >> 2] >> 2] = c[C >> 2];
	                                    Sa = 580
	                                } else Sa = 580
	                            } else Sa = 577
	                        } else Sa = 577;
	                        break
	                    }
	                    case 42:
	                    case 40:
	                    case 38:
	                    case 36:
	                    {
	                        c[Na >> 2] = c[u >> 2];
	                        if (((c[Na >> 2] | 0) != 0 ? (c[E >> 2] = pI(Na, Oa, Pa, Qa) | 0, (c[E >> 2] | 0) >= 0) : 0) ? (d[c[Na >> 2] >> 0] | 0) == 0 : 0) {
	                            do if ((c[(c[t >> 2] | 0) + 88 >> 2] | 0) == 38) {
	                                if ((c[Qa >> 2] | 0) >>> 0 >= 1844) {
	                                    if ((c[Qa >> 2] | 0) >>> 0 > 1844) {
	                                        Sa = 577;
	                                        break a
	                                    }
	                                    if ((c[Pa >> 2] | 0) >>> 0 >= 67440737 ? (c[Pa >> 2] | 0) >>> 0 > 67440737 | (c[Oa >> 2] | 0) >>> 0 > 9551615 : 0) {
	                                        Sa = 577;
	                                        break a
	                                    }
	                                }
	                            } else {
	                                if ((c[(c[t >> 2] | 0) + 88 >> 2] | 0) == 36) {
	                                    if (c[Qa >> 2] | 0) {
	                                        Sa = 577;
	                                        break a
	                                    }
	                                    if ((c[Pa >> 2] | 0) >>> 0 < 42)break;
	                                    if ((c[Pa >> 2] | 0) >>> 0 > 42 | (c[Oa >> 2] | 0) >>> 0 > 94967295) {
	                                        Sa = 577;
	                                        break a
	                                    } else break
	                                }
	                                if ((c[(c[t >> 2] | 0) + 88 >> 2] | 0) == 40)if ((c[Pa >> 2] | 0) != 0 | (c[Qa >> 2] | 0) != 0 | (c[Oa >> 2] | 0) >>> 0 > 65535) {
	                                    Sa = 577;
	                                    break a
	                                } else break;
	                                if ((c[(c[t >> 2] | 0) + 88 >> 2] | 0) == 42 ? (c[Pa >> 2] | 0) != 0 | (c[Qa >> 2] | 0) != 0 | (c[Oa >> 2] | 0) >>> 0 > 255 : 0) {
	                                    Sa = 577;
	                                    break a
	                                }
	                            } while (0);
	                            if ((c[v >> 2] | 0) != 0 ? (c[C >> 2] = hI(c[(c[t >> 2] | 0) + 88 >> 2] | 0) | 0, (c[C >> 2] | 0) != 0) : 0) {
	                                c[(c[C >> 2] | 0) + 8 >> 2] = c[Oa >> 2];
	                                c[(c[C >> 2] | 0) + 12 >> 2] = c[Pa >> 2];
	                                c[(c[C >> 2] | 0) + 16 >> 2] = c[Qa >> 2];
	                                p = (c[C >> 2] | 0) + 24 | 0;
	                                b[p >> 1] = b[p >> 1] & -2;
	                                p = (c[C >> 2] | 0) + 24 | 0;
	                                b[p >> 1] = b[p >> 1] & -255;
	                                p = (c[C >> 2] | 0) + 24 | 0;
	                                b[p >> 1] = b[p >> 1] & 255 | (c[E >> 2] & 255) << 8 & 65535;
	                                c[c[v >> 2] >> 2] = c[C >> 2];
	                                Sa = 580
	                            } else Sa = 580
	                        } else Sa = 577;
	                        break
	                    }
	                    case 0:
	                    {
	                        Sa = 583;
	                        break
	                    }
	                    default:
	                        Sa = 571
	                } while (0);
	                if ((Sa | 0) == 571) {
	                    if (c[D >> 2] | 0)zb[c[135736 >> 2] & 511](c[D >> 2] | 0);
	                    c[s >> 2] = c[E >> 2];
	                    Ra = c[s >> 2] | 0;
	                    i = q;
	                    return Ra | 0
	                } else if ((Sa | 0) == 577) {
	                    if (c[D >> 2] | 0)zb[c[135736 >> 2] & 511](c[D >> 2] | 0);
	                    c[s >> 2] = 1;
	                    Ra = c[s >> 2] | 0;
	                    i = q;
	                    return Ra | 0
	                } else if ((Sa | 0) == 580) {
	                    if (c[D >> 2] | 0)zb[c[135736 >> 2] & 511](c[D >> 2] | 0);
	                    c[s >> 2] = 0;
	                    Ra = c[s >> 2] | 0;
	                    i = q;
	                    return Ra | 0
	                } else if ((Sa | 0) == 583) {
	                    if (c[D >> 2] | 0)zb[c[135736 >> 2] & 511](c[D >> 2] | 0);
	                    c[s >> 2] = -1;
	                    Ra = c[s >> 2] | 0;
	                    i = q;
	                    return Ra | 0
	                }
	                return 0
	            }

	            function jI(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = hI(c[c[e >> 2] >> 2] | 0) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    a = c[f >> 2] | 0;
	                    h = c[e >> 2] | 0;
	                    c[a + 0 >> 2] = c[h + 0 >> 2];
	                    c[a + 4 >> 2] = c[h + 4 >> 2];
	                    c[a + 8 >> 2] = c[h + 8 >> 2];
	                    c[a + 12 >> 2] = c[h + 12 >> 2];
	                    c[a + 16 >> 2] = c[h + 16 >> 2];
	                    c[a + 20 >> 2] = c[h + 20 >> 2];
	                    c[a + 24 >> 2] = c[h + 24 >> 2];
	                    c[a + 28 >> 2] = c[h + 28 >> 2];
	                    c[(c[f >> 2] | 0) + 4 >> 2] = 0;
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function kI(a, b, d, e, f, g, h, j) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                var k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0;
	                k = i;
	                i = i + 64 | 0;
	                l = k;
	                m = k + 56 | 0;
	                n = k + 52 | 0;
	                o = k + 48 | 0;
	                p = k + 44 | 0;
	                q = k + 40 | 0;
	                r = k + 36 | 0;
	                s = k + 32 | 0;
	                t = k + 28 | 0;
	                u = k + 24 | 0;
	                v = k + 20 | 0;
	                w = k + 16 | 0;
	                x = k + 12 | 0;
	                y = k + 8 | 0;
	                c[n >> 2] = a;
	                c[o >> 2] = b;
	                c[p >> 2] = d;
	                c[q >> 2] = e;
	                c[r >> 2] = f;
	                c[s >> 2] = g;
	                c[t >> 2] = h;
	                c[u >> 2] = j;
	                a:do switch (c[n >> 2] | 0) {
	                    case 11:
	                    case 10:
	                    case 9:
	                    case 8:
	                    case 7:
	                    case 6:
	                    case 5:
	                    case 4:
	                    {
	                        if ((c[o >> 2] | 0) == 0 | (c[s >> 2] | 0) == 0) {
	                            c[m >> 2] = -2;
	                            break a
	                        }
	                        if ((c[r >> 2] | 0) == 11 | (c[r >> 2] | 0) == 4 | (c[r >> 2] | 0) == 5 | (c[r >> 2] | 0) == 6 | (c[r >> 2] | 0) == 7 | (c[r >> 2] | 0) == 8 | (c[r >> 2] | 0) == 10 | (c[r >> 2] | 0) == 9) {
	                            c[m >> 2] = xI(c[o >> 2] | 0, c[s >> 2] | 0) | 0;
	                            break a
	                        } else {
	                            c[m >> 2] = -2;
	                            break a
	                        }
	                        break
	                    }
	                    case 12:
	                    {
	                        if ((c[o >> 2] | 0) == 0 | (c[s >> 2] | 0) == 0) {
	                            c[m >> 2] = -2;
	                            break a
	                        }
	                        if ((c[r >> 2] | 0) == 12) {
	                            c[m >> 2] = wI(c[o >> 2] | 0, c[s >> 2] | 0) | 0;
	                            break a
	                        } else {
	                            c[m >> 2] = -2;
	                            break a
	                        }
	                        break
	                    }
	                    case 28:
	                    case 21:
	                    {
	                        if ((c[o >> 2] | 0) == 0 | (c[s >> 2] | 0) == 0) {
	                            c[m >> 2] = -2;
	                            break a
	                        }
	                        if (!((c[r >> 2] | 0) == 21 | (c[r >> 2] | 0) == 28)) {
	                            c[m >> 2] = -2;
	                            break a
	                        }
	                        if ((qy(c[(c[o >> 2] | 0) + 8 >> 2] | 0, c[(c[s >> 2] | 0) + 8 >> 2] | 0) | 0) != 0 ? (qy(c[(c[o >> 2] | 0) + 12 >> 2] | 0, c[(c[s >> 2] | 0) + 12 >> 2] | 0) | 0) != 0 : 0) {
	                            c[m >> 2] = 0;
	                            break a
	                        }
	                        c[m >> 2] = 2;
	                        break
	                    }
	                    case 3:
	                    case 42:
	                    case 41:
	                    case 40:
	                    case 39:
	                    case 38:
	                    case 37:
	                    case 36:
	                    case 35:
	                    case 34:
	                    case 33:
	                    case 32:
	                    case 31:
	                    case 30:
	                    {
	                        if ((c[o >> 2] | 0) == 0 | (c[s >> 2] | 0) == 0) {
	                            c[m >> 2] = -2;
	                            break a
	                        }
	                        if ((c[r >> 2] | 0) == (c[n >> 2] | 0)) {
	                            c[m >> 2] = vI(c[o >> 2] | 0, c[s >> 2] | 0) | 0;
	                            break a
	                        }
	                        if ((c[r >> 2] | 0) == 3 | (c[r >> 2] | 0) == 30 | (c[r >> 2] | 0) == 31 | (c[r >> 2] | 0) == 32 | (c[r >> 2] | 0) == 33 | (c[r >> 2] | 0) == 34 | (c[r >> 2] | 0) == 35 | (c[r >> 2] | 0) == 36 | (c[r >> 2] | 0) == 37 | (c[r >> 2] | 0) == 38 | (c[r >> 2] | 0) == 39 | (c[r >> 2] | 0) == 40 | (c[r >> 2] | 0) == 41 | (c[r >> 2] | 0) == 42) {
	                            c[m >> 2] = vI(c[o >> 2] | 0, c[s >> 2] | 0) | 0;
	                            break a
	                        } else {
	                            c[m >> 2] = -2;
	                            break a
	                        }
	                        break
	                    }
	                    case 14:
	                    case 13:
	                    {
	                        if ((c[o >> 2] | 0) == 0 | (c[s >> 2] | 0) == 0) {
	                            c[m >> 2] = -2;
	                            break a
	                        }
	                        if ((c[r >> 2] | 0) == 13 | (c[r >> 2] | 0) == 14) {
	                            c[m >> 2] = DI(c[o >> 2] | 0, c[s >> 2] | 0) | 0;
	                            break a
	                        } else {
	                            c[m >> 2] = -2;
	                            break a
	                        }
	                        break
	                    }
	                    case 44:
	                    {
	                        if ((c[o >> 2] | 0) == 0 | (c[s >> 2] | 0) == 0) {
	                            c[m >> 2] = -2;
	                            break a
	                        }
	                        if ((c[r >> 2] | 0) != 44) {
	                            c[m >> 2] = -2;
	                            break a
	                        }
	                        j = (c[o >> 2] | 0) + 8 | 0;
	                        if ((c[(c[o >> 2] | 0) + 12 >> 2] | 0) != (c[(c[s >> 2] | 0) + 12 >> 2] | 0))if ((c[j + 4 >> 2] | 0) >>> 0 > (c[(c[s >> 2] | 0) + 12 >> 2] | 0) >>> 0) {
	                            c[m >> 2] = 1;
	                            break a
	                        } else {
	                            c[m >> 2] = -1;
	                            break a
	                        }
	                        c[y >> 2] = py(c[j >> 2] | 0, c[(c[s >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        if ((c[y >> 2] | 0) > 0) {
	                            c[m >> 2] = 1;
	                            break a
	                        }
	                        if (!(c[y >> 2] | 0)) {
	                            c[m >> 2] = 0;
	                            break a
	                        } else {
	                            c[m >> 2] = -1;
	                            break a
	                        }
	                        break
	                    }
	                    case 29:
	                    case 26:
	                    case 24:
	                    case 23:
	                    case 22:
	                    case 20:
	                    case 18:
	                    case 17:
	                    case 16:
	                    case 2:
	                    case 1:
	                    case 46:
	                    {
	                        if (!(c[o >> 2] | 0))c[v >> 2] = c[p >> 2]; else c[v >> 2] = c[(c[o >> 2] | 0) + 8 >> 2];
	                        if (!(c[s >> 2] | 0))c[w >> 2] = c[t >> 2]; else c[w >> 2] = c[(c[s >> 2] | 0) + 8 >> 2];
	                        if ((c[r >> 2] | 0) == 21) {
	                            j = c[33976] | 0;
	                            h = c[33980] | 0;
	                            c[l >> 2] = 171992;
	                            c[l + 4 >> 2] = 4781;
	                            Db[j & 511](h, 171960, l);
	                            c[m >> 2] = -2;
	                            break a
	                        }
	                        do if ((c[r >> 2] | 0) == 46 | (c[r >> 2] | 0) == 1 | (c[r >> 2] | 0) == 2 | (c[r >> 2] | 0) == 16 | (c[r >> 2] | 0) == 17 | (c[r >> 2] | 0) == 18 | (c[r >> 2] | 0) == 20 | (c[r >> 2] | 0) == 22 | (c[r >> 2] | 0) == 23 | (c[r >> 2] | 0) == 24 | (c[r >> 2] | 0) == 26 | (c[r >> 2] | 0) == 29) {
	                            if ((c[q >> 2] | 0) == 1) {
	                                if ((c[u >> 2] | 0) == 1)if (qy(c[v >> 2] | 0, c[w >> 2] | 0) | 0) {
	                                    c[m >> 2] = 0;
	                                    break a
	                                } else {
	                                    c[m >> 2] = 2;
	                                    break a
	                                }
	                                if ((c[u >> 2] | 0) == 2) {
	                                    c[m >> 2] = yI(c[v >> 2] | 0, c[w >> 2] | 0, 0) | 0;
	                                    break a
	                                }
	                                if ((c[u >> 2] | 0) != 3)break;
	                                c[m >> 2] = zI(c[v >> 2] | 0, c[w >> 2] | 0, 0) | 0;
	                                break a
	                            }
	                            if ((c[q >> 2] | 0) == 2) {
	                                if ((c[u >> 2] | 0) == 1) {
	                                    c[m >> 2] = yI(c[w >> 2] | 0, c[v >> 2] | 0, 1) | 0;
	                                    break a
	                                }
	                                if ((c[u >> 2] | 0) == 2) {
	                                    c[m >> 2] = AI(c[v >> 2] | 0, c[w >> 2] | 0) | 0;
	                                    break a
	                                }
	                                if ((c[u >> 2] | 0) != 3)break;
	                                c[m >> 2] = BI(c[v >> 2] | 0, c[w >> 2] | 0, 0) | 0;
	                                break a
	                            }
	                            if ((c[q >> 2] | 0) != 3) {
	                                c[m >> 2] = -2;
	                                break a
	                            }
	                            if ((c[u >> 2] | 0) == 1) {
	                                c[m >> 2] = zI(c[w >> 2] | 0, c[v >> 2] | 0, 1) | 0;
	                                break a
	                            }
	                            if ((c[u >> 2] | 0) == 2) {
	                                c[m >> 2] = BI(c[w >> 2] | 0, c[v >> 2] | 0, 1) | 0;
	                                break a
	                            }
	                            if ((c[u >> 2] | 0) == 3) {
	                                c[m >> 2] = CI(c[v >> 2] | 0, c[w >> 2] | 0) | 0;
	                                break a
	                            }
	                        } while (0);
	                        c[m >> 2] = -2;
	                        break
	                    }
	                    case 45:
	                    case 0:
	                    {
	                        c[m >> 2] = -2;
	                        break
	                    }
	                    case 19:
	                    case 27:
	                    case 25:
	                    {
	                        h = c[33976] | 0;
	                        j = c[33980] | 0;
	                        c[l >> 2] = 171992;
	                        c[l + 4 >> 2] = 4906;
	                        Db[h & 511](j, 171960, l);
	                        z = 102;
	                        break
	                    }
	                    case 43:
	                    {
	                        if ((c[o >> 2] | 0) == 0 | (c[s >> 2] | 0) == 0) {
	                            c[m >> 2] = -2;
	                            break a
	                        }
	                        if ((c[r >> 2] | 0) != 43) {
	                            c[m >> 2] = -2;
	                            break a
	                        }
	                        j = (c[o >> 2] | 0) + 8 | 0;
	                        if ((c[(c[o >> 2] | 0) + 12 >> 2] | 0) == (c[(c[s >> 2] | 0) + 12 >> 2] | 0)) {
	                            c[x >> 2] = py(c[j >> 2] | 0, c[(c[s >> 2] | 0) + 8 >> 2] | 0) | 0;
	                            if ((c[x >> 2] | 0) > 0) {
	                                c[m >> 2] = 1;
	                                break a
	                            }
	                            if (!(c[x >> 2] | 0)) {
	                                c[m >> 2] = 0;
	                                break a
	                            }
	                        } else if ((c[j + 4 >> 2] | 0) >>> 0 > (c[(c[s >> 2] | 0) + 12 >> 2] | 0) >>> 0) {
	                            c[m >> 2] = 1;
	                            break a
	                        }
	                        c[m >> 2] = -1;
	                        break
	                    }
	                    case 15:
	                    {
	                        if ((c[o >> 2] | 0) == 0 | (c[s >> 2] | 0) == 0) {
	                            c[m >> 2] = -2;
	                            break a
	                        }
	                        if ((c[r >> 2] | 0) != 15) {
	                            c[m >> 2] = -2;
	                            break a
	                        }
	                        if ((c[(c[o >> 2] | 0) + 8 >> 2] | 0) == (c[(c[s >> 2] | 0) + 8 >> 2] | 0)) {
	                            c[m >> 2] = 0;
	                            break a
	                        }
	                        if (!(c[(c[o >> 2] | 0) + 8 >> 2] | 0)) {
	                            c[m >> 2] = -1;
	                            break a
	                        } else {
	                            c[m >> 2] = 1;
	                            break a
	                        }
	                        break
	                    }
	                    default:
	                        z = 102
	                } while (0);
	                if ((z | 0) == 102)c[m >> 2] = -2;
	                i = k;
	                return c[m >> 2] | 0
	            }

	            function lI(a, b, d, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                j = i;
	                i = i + 48 | 0;
	                k = j;
	                l = j + 40 | 0;
	                m = j + 36 | 0;
	                n = j + 32 | 0;
	                o = j + 28 | 0;
	                p = j + 24 | 0;
	                q = j + 20 | 0;
	                r = j + 16 | 0;
	                s = j + 12 | 0;
	                t = j + 8 | 0;
	                c[m >> 2] = a;
	                c[n >> 2] = b;
	                c[o >> 2] = d;
	                c[p >> 2] = f;
	                c[q >> 2] = g;
	                c[r >> 2] = h;
	                a:do if (!(c[m >> 2] | 0))c[l >> 2] = -1; else {
	                    b:do switch (c[c[m >> 2] >> 2] | 0) {
	                        case 1008:
	                        {
	                            c[l >> 2] = 0;
	                            break a;
	                            break
	                        }
	                        case 1006:
	                        {
	                            if (!(c[p >> 2] | 0)) {
	                                c[l >> 2] = -1;
	                                break a
	                            }
	                            c[s >> 2] = vz(c[(c[m >> 2] | 0) + 36 >> 2] | 0, c[p >> 2] | 0) | 0;
	                            if ((c[s >> 2] | 0) == 1) {
	                                c[l >> 2] = 0;
	                                break a
	                            }
	                            if (!(c[s >> 2] | 0)) {
	                                c[l >> 2] = 1839;
	                                break a
	                            } else {
	                                c[l >> 2] = c[s >> 2];
	                                break a
	                            }
	                            break
	                        }
	                        case 1007:
	                        {
	                            h = c[m >> 2] | 0;
	                            if (!(c[r >> 2] | 0)) {
	                                if ((c[h + 8 >> 2] | 0) != 0 ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, c[p >> 2] | 0) | 0) != 0 : 0) {
	                                    c[l >> 2] = 0;
	                                    break a
	                                }
	                            } else {
	                                c[s >> 2] = EI(c[c[h + 32 >> 2] >> 2] | 0, c[(c[m >> 2] | 0) + 32 >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, c[q >> 2] | 0, c[p >> 2] | 0, c[r >> 2] | 0) | 0;
	                                if ((c[s >> 2] | 0) == -2) {
	                                    c[l >> 2] = -1;
	                                    break a
	                                }
	                                if (!(c[s >> 2] | 0)) {
	                                    c[l >> 2] = 0;
	                                    break a
	                                }
	                            }
	                            c[l >> 2] = 1840;
	                            break a;
	                            break
	                        }
	                        case 1011:
	                        case 1010:
	                        {
	                            u = 43;
	                            break
	                        }
	                        case 1009:
	                        {
	                            if ((c[o >> 2] | 0) == 21 | (c[o >> 2] | 0) == 28) {
	                                c[l >> 2] = 0;
	                                break a
	                            } else u = 43;
	                            break
	                        }
	                        case 1005:
	                        case 1004:
	                        {
	                            do if (c[(c[m >> 2] | 0) + 32 >> 2] | 0) {
	                                if ((c[c[(c[m >> 2] | 0) + 32 >> 2] >> 2] | 0) != 34 ? (c[c[(c[m >> 2] | 0) + 32 >> 2] >> 2] | 0) != 33 : 0)break;
	                                if (!((e[(c[(c[m >> 2] | 0) + 32 >> 2] | 0) + 24 >> 1] | 0) >>> 1 & 127)) {
	                                    c:do if (c[q >> 2] | 0) {
	                                        do if ((((((((((c[c[q >> 2] >> 2] | 0) != 3 ? (c[c[q >> 2] >> 2] | 0) != 30 : 0) ? (c[c[q >> 2] >> 2] | 0) != 31 : 0) ? (c[c[q >> 2] >> 2] | 0) != 32 : 0) ? (c[c[q >> 2] >> 2] | 0) != 33 : 0) ? (c[c[q >> 2] >> 2] | 0) != 34 : 0) ? (c[c[q >> 2] >> 2] | 0) != 35 : 0) ? (c[c[q >> 2] >> 2] | 0) != 36 : 0) ? (c[c[q >> 2] >> 2] | 0) != 37 : 0) ? (c[c[q >> 2] >> 2] | 0) != 38 : 0) {
	                                            if ((c[c[q >> 2] >> 2] | 0) == 39)break;
	                                            if ((c[c[q >> 2] >> 2] | 0) == 40)break;
	                                            if ((c[c[q >> 2] >> 2] | 0) == 41)break;
	                                            if ((c[c[q >> 2] >> 2] | 0) != 42)break c
	                                        } while (0);
	                                        if ((c[c[m >> 2] >> 2] | 0) == 1004) {
	                                            if (((e[(c[q >> 2] | 0) + 24 >> 1] | 0) >>> 8 & 65535) >>> 0 <= (c[(c[(c[m >> 2] | 0) + 32 >> 2] | 0) + 8 >> 2] | 0) >>> 0)break b;
	                                            c[l >> 2] = 1837;
	                                            break a
	                                        }
	                                        if ((c[c[m >> 2] >> 2] | 0) != 1005)break b;
	                                        if (((e[(c[q >> 2] | 0) + 24 >> 1] | 0) >>> 1 & 127) >>> 0 <= (c[(c[(c[m >> 2] | 0) + 32 >> 2] | 0) + 8 >> 2] | 0) >>> 0)break b;
	                                        c[l >> 2] = 1838;
	                                        break a
	                                    } while (0);
	                                    c[l >> 2] = -1;
	                                    break a
	                                }
	                            } while (0);
	                            c[l >> 2] = -1;
	                            break a;
	                            break
	                        }
	                        case 1e3:
	                        {
	                            c[s >> 2] = XH(c[q >> 2] | 0, c[(c[m >> 2] | 0) + 32 >> 2] | 0) | 0;
	                            if ((c[s >> 2] | 0) == -2) {
	                                c[l >> 2] = -1;
	                                break a
	                            }
	                            if ((c[s >> 2] | 0) == 1 | (c[s >> 2] | 0) == 0) {
	                                c[l >> 2] = 0;
	                                break a
	                            } else {
	                                c[l >> 2] = 1833;
	                                break a
	                            }
	                            break
	                        }
	                        case 1002:
	                        {
	                            c[s >> 2] = XH(c[q >> 2] | 0, c[(c[m >> 2] | 0) + 32 >> 2] | 0) | 0;
	                            if ((c[s >> 2] | 0) == -2) {
	                                c[l >> 2] = -1;
	                                break a
	                            }
	                            if ((c[s >> 2] | 0) == -1 | (c[s >> 2] | 0) == 0) {
	                                c[l >> 2] = 0;
	                                break a
	                            } else {
	                                c[l >> 2] = 1834;
	                                break a
	                            }
	                            break
	                        }
	                        case 1001:
	                        {
	                            c[s >> 2] = XH(c[q >> 2] | 0, c[(c[m >> 2] | 0) + 32 >> 2] | 0) | 0;
	                            if ((c[s >> 2] | 0) == -2) {
	                                c[l >> 2] = -1;
	                                break a
	                            }
	                            if ((c[s >> 2] | 0) == 1) {
	                                c[l >> 2] = 0;
	                                break a
	                            } else {
	                                c[l >> 2] = 1835;
	                                break a
	                            }
	                            break
	                        }
	                        case 1003:
	                        {
	                            c[s >> 2] = XH(c[q >> 2] | 0, c[(c[m >> 2] | 0) + 32 >> 2] | 0) | 0;
	                            if ((c[s >> 2] | 0) == -2) {
	                                c[l >> 2] = -1;
	                                break a
	                            }
	                            if ((c[s >> 2] | 0) == -1) {
	                                c[l >> 2] = 0;
	                                break a
	                            } else {
	                                c[l >> 2] = 1836;
	                                break a
	                            }
	                            break
	                        }
	                        default:
	                        {
	                            h = c[33976] | 0;
	                            g = c[33980] | 0;
	                            c[k >> 2] = 171992;
	                            c[k + 4 >> 2] = 5498;
	                            Db[h & 511](g, 171960, k)
	                        }
	                    } while (0);
	                    d:do if ((u | 0) == 43) {
	                        c[t >> 2] = 0;
	                        if ((c[o >> 2] | 0) == 21 | (c[o >> 2] | 0) == 28) {
	                            c[l >> 2] = 0;
	                            break a
	                        }
	                        do if (c[(c[m >> 2] | 0) + 32 >> 2] | 0) {
	                            if ((c[c[(c[m >> 2] | 0) + 32 >> 2] >> 2] | 0) != 3 ? (c[c[(c[m >> 2] | 0) + 32 >> 2] >> 2] | 0) != 33 : 0)break;
	                            if (!((e[(c[(c[m >> 2] | 0) + 32 >> 2] | 0) + 24 >> 1] | 0) >>> 1 & 127)) {
	                                if ((c[q >> 2] | 0) != 0 ? (c[c[q >> 2] >> 2] | 0) == 43 : 0)c[t >> 2] = c[(c[q >> 2] | 0) + 12 >> 2]; else u = 53;
	                                e:do if ((u | 0) == 53) {
	                                    if ((c[q >> 2] | 0) != 0 ? (c[c[q >> 2] >> 2] | 0) == 44 : 0) {
	                                        c[t >> 2] = c[(c[q >> 2] | 0) + 12 >> 2];
	                                        break
	                                    }
	                                    switch (c[o >> 2] | 0) {
	                                        case 29:
	                                        case 23:
	                                        case 22:
	                                        case 20:
	                                        case 18:
	                                        case 17:
	                                        case 16:
	                                        case 24:
	                                        {
	                                            if (!(c[p >> 2] | 0))break e;
	                                            c[t >> 2] = FI(c[p >> 2] | 0) | 0;
	                                            break e;
	                                            break
	                                        }
	                                        case 2:
	                                        case 1:
	                                        {
	                                            if (!(c[r >> 2] | 0)) {
	                                                g = c[p >> 2] | 0;
	                                                if ((c[o >> 2] | 0) == 1) {
	                                                    c[t >> 2] = Dy(g) | 0;
	                                                    break e
	                                                } else {
	                                                    c[t >> 2] = FI(g) | 0;
	                                                    break e
	                                                }
	                                            }
	                                            if (!(c[p >> 2] | 0))break e;
	                                            g = c[p >> 2] | 0;
	                                            if ((c[r >> 2] | 0) == 3) {
	                                                c[t >> 2] = FI(g) | 0;
	                                                break e
	                                            } else {
	                                                c[t >> 2] = Dy(g) | 0;
	                                                break e
	                                            }
	                                            break
	                                        }
	                                        default:
	                                        {
	                                            g = c[33976] | 0;
	                                            h = c[33980] | 0;
	                                            c[k >> 2] = 171992;
	                                            c[k + 4 >> 2] = 5447;
	                                            Db[g & 511](h, 171960, k);
	                                            break e
	                                        }
	                                    }
	                                } while (0);
	                                if ((c[c[m >> 2] >> 2] | 0) == 1009) {
	                                    if ((c[t >> 2] | 0) == (c[(c[(c[m >> 2] | 0) + 32 >> 2] | 0) + 8 >> 2] | 0))break d;
	                                    c[l >> 2] = 1830;
	                                    break a
	                                }
	                                h = c[t >> 2] | 0;
	                                g = c[(c[(c[m >> 2] | 0) + 32 >> 2] | 0) + 8 >> 2] | 0;
	                                if ((c[c[m >> 2] >> 2] | 0) == 1011) {
	                                    if (h >>> 0 >= g >>> 0)break d;
	                                    c[l >> 2] = 1831;
	                                    break a
	                                } else {
	                                    if (h >>> 0 <= g >>> 0)break d;
	                                    c[l >> 2] = 1832;
	                                    break a
	                                }
	                            }
	                        } while (0);
	                        c[l >> 2] = -1;
	                        break a
	                    } while (0);
	                    c[l >> 2] = 0
	                } while (0);
	                i = j;
	                return c[l >> 2] | 0
	            }

	            function mI(a, b, d, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                j = i;
	                i = i + 48 | 0;
	                k = j;
	                l = j + 36 | 0;
	                m = j + 32 | 0;
	                n = j + 28 | 0;
	                o = j + 24 | 0;
	                p = j + 20 | 0;
	                q = j + 16 | 0;
	                r = j + 12 | 0;
	                s = j + 8 | 0;
	                c[m >> 2] = a;
	                c[n >> 2] = b;
	                c[o >> 2] = d;
	                c[p >> 2] = f;
	                c[q >> 2] = g;
	                c[r >> 2] = h;
	                c[s >> 2] = 0;
	                if ((c[q >> 2] | 0) == 0 | (c[m >> 2] | 0) == 0) {
	                    c[l >> 2] = -1;
	                    t = c[l >> 2] | 0;
	                    i = j;
	                    return t | 0
	                }
	                c[c[q >> 2] >> 2] = 0;
	                if (((c[c[m >> 2] >> 2] | 0) != 1009 ? (c[c[m >> 2] >> 2] | 0) != 1010 : 0) ? (c[c[m >> 2] >> 2] | 0) != 1011 : 0) {
	                    c[l >> 2] = -1;
	                    t = c[l >> 2] | 0;
	                    i = j;
	                    return t | 0
	                }
	                do if (c[(c[m >> 2] | 0) + 32 >> 2] | 0) {
	                    if ((c[c[(c[m >> 2] | 0) + 32 >> 2] >> 2] | 0) != 3 ? (c[c[(c[m >> 2] | 0) + 32 >> 2] >> 2] | 0) != 33 : 0)break;
	                    if (!((e[(c[(c[m >> 2] | 0) + 32 >> 2] | 0) + 24 >> 1] | 0) >>> 1 & 127)) {
	                        if ((c[p >> 2] | 0) != 0 ? (c[c[p >> 2] >> 2] | 0) == 43 : 0)c[s >> 2] = c[(c[p >> 2] | 0) + 12 >> 2]; else u = 15;
	                        a:do if ((u | 0) == 15) {
	                            if ((c[p >> 2] | 0) != 0 ? (c[c[p >> 2] >> 2] | 0) == 44 : 0) {
	                                c[s >> 2] = c[(c[p >> 2] | 0) + 12 >> 2];
	                                break
	                            }
	                            switch (c[n >> 2] | 0) {
	                                case 28:
	                                case 21:
	                                {
	                                    c[l >> 2] = 0;
	                                    t = c[l >> 2] | 0;
	                                    i = j;
	                                    return t | 0
	                                }
	                                case 29:
	                                case 23:
	                                case 22:
	                                case 20:
	                                case 18:
	                                case 17:
	                                case 16:
	                                case 24:
	                                {
	                                    if (!(c[o >> 2] | 0))break a;
	                                    c[s >> 2] = FI(c[o >> 2] | 0) | 0;
	                                    break a;
	                                    break
	                                }
	                                case 2:
	                                case 1:
	                                {
	                                    if (!(c[r >> 2] | 0)) {
	                                        h = c[o >> 2] | 0;
	                                        if ((c[n >> 2] | 0) == 1) {
	                                            c[s >> 2] = Dy(h) | 0;
	                                            break a
	                                        } else {
	                                            c[s >> 2] = FI(h) | 0;
	                                            break a
	                                        }
	                                    }
	                                    if (!(c[o >> 2] | 0))break a;
	                                    h = c[o >> 2] | 0;
	                                    if ((c[r >> 2] | 0) == 3) {
	                                        c[s >> 2] = FI(h) | 0;
	                                        break a
	                                    } else {
	                                        c[s >> 2] = Dy(h) | 0;
	                                        break a
	                                    }
	                                    break
	                                }
	                                default:
	                                {
	                                    h = c[33976] | 0;
	                                    g = c[33980] | 0;
	                                    c[k >> 2] = 171992;
	                                    c[k + 4 >> 2] = 5207;
	                                    Db[h & 511](g, 171960, k);
	                                    break a
	                                }
	                            }
	                        } while (0);
	                        c[c[q >> 2] >> 2] = c[s >> 2];
	                        do if ((c[c[m >> 2] >> 2] | 0) == 1009) {
	                            if ((c[s >> 2] | 0) != (c[(c[(c[m >> 2] | 0) + 32 >> 2] | 0) + 8 >> 2] | 0)) {
	                                c[l >> 2] = 1830;
	                                t = c[l >> 2] | 0;
	                                i = j;
	                                return t | 0
	                            }
	                        } else {
	                            g = c[s >> 2] | 0;
	                            h = c[(c[(c[m >> 2] | 0) + 32 >> 2] | 0) + 8 >> 2] | 0;
	                            if ((c[c[m >> 2] >> 2] | 0) == 1011) {
	                                if (g >>> 0 >= h >>> 0)break;
	                                c[l >> 2] = 1831;
	                                t = c[l >> 2] | 0;
	                                i = j;
	                                return t | 0
	                            } else {
	                                if (g >>> 0 <= h >>> 0)break;
	                                c[l >> 2] = 1832;
	                                t = c[l >> 2] | 0;
	                                i = j;
	                                return t | 0
	                            }
	                        } while (0);
	                        c[l >> 2] = 0;
	                        t = c[l >> 2] | 0;
	                        i = j;
	                        return t | 0
	                    }
	                } while (0);
	                c[l >> 2] = -1;
	                t = c[l >> 2] | 0;
	                i = j;
	                return t | 0
	            }

	            function nI(a, d) {
	                a = a | 0;
	                d = +d;
	                var e = 0, f = 0, g = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                j = e;
	                k = e + 12 | 0;
	                l = e + 8 | 0;
	                c[g >> 2] = a;
	                h[j >> 3] = d;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                if (!(((c[c[g >> 2] >> 2] | 0) != 4 ? (c[c[g >> 2] >> 2] | 0) != 11 : 0) ? (c[c[g >> 2] >> 2] | 0) != 10 : 0))n = 6;
	                if ((n | 0) == 6 ? ((b[(c[g >> 2] | 0) + 24 >> 1] << 3 & 65535) << 16 >> 16 >> 4 << 16 >> 16 | 0) != 0 : 0) {
	                    c[k >> 2] = hI(12) | 0;
	                    if (!(c[k >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        m = c[f >> 2] | 0;
	                        i = e;
	                        return m | 0
	                    }
	                    n = (c[k >> 2] | 0) + 16 | 0;
	                    h[n >> 3] = +h[n >> 3] - +h[j >> 3];
	                    c[l >> 2] = GI(c[g >> 2] | 0, c[k >> 2] | 0) | 0;
	                    if (!(c[l >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        m = c[f >> 2] | 0;
	                        i = e;
	                        return m | 0
	                    } else {
	                        PH(c[k >> 2] | 0);
	                        c[f >> 2] = c[l >> 2];
	                        m = c[f >> 2] | 0;
	                        i = e;
	                        return m | 0
	                    }
	                }
	                c[f >> 2] = jI(c[g >> 2] | 0) | 0;
	                m = c[f >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function oI(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = SA() | 0;
	                if (!(c[f >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[c[f >> 2] >> 2] = 1011;
	                a = hI(33) | 0;
	                c[(c[f >> 2] | 0) + 32 >> 2] = a;
	                if (!(c[(c[f >> 2] | 0) + 32 >> 2] | 0)) {
	                    zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    c[(c[(c[f >> 2] | 0) + 32 >> 2] | 0) + 8 >> 2] = c[e >> 2];
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function pI(a, b, e, f) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0;
	                g = i;
	                i = i + 48 | 0;
	                h = g + 44 | 0;
	                j = g + 40 | 0;
	                k = g + 36 | 0;
	                l = g + 32 | 0;
	                m = g + 28 | 0;
	                n = g + 24 | 0;
	                o = g + 20 | 0;
	                p = g + 16 | 0;
	                q = g + 12 | 0;
	                r = g + 8 | 0;
	                s = g + 4 | 0;
	                t = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                c[n >> 2] = 0;
	                c[o >> 2] = 0;
	                c[p >> 2] = 0;
	                c[r >> 2] = c[c[j >> 2] >> 2];
	                c[s >> 2] = 0;
	                c[t >> 2] = 0;
	                if ((d[c[r >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[r >> 2] >> 0] | 0 | 0) <= 57 : 0) {
	                    while (1) {
	                        u = c[r >> 2] | 0;
	                        if ((d[c[r >> 2] >> 0] | 0 | 0) != 48)break;
	                        c[r >> 2] = u + 1
	                    }
	                    c[q >> 2] = u;
	                    while (1) {
	                        if ((d[c[q >> 2] >> 0] | 0 | 0) != 0 ? (d[c[q >> 2] >> 0] | 0 | 0) >= 48 : 0)v = (d[c[q >> 2] >> 0] | 0 | 0) <= 57; else v = 0;
	                        w = c[t >> 2] | 0;
	                        if (!v)break;
	                        c[t >> 2] = w + 1;
	                        c[q >> 2] = (c[q >> 2] | 0) + 1;
	                        c[s >> 2] = (c[s >> 2] | 0) + 1
	                    }
	                    if ((w | 0) > 24) {
	                        c[c[j >> 2] >> 2] = c[q >> 2];
	                        c[h >> 2] = -1;
	                        x = c[h >> 2] | 0;
	                        i = g;
	                        return x | 0
	                    }
	                    while (1) {
	                        if ((c[t >> 2] | 0) <= 16)break;
	                        q = (c[p >> 2] | 0) * 10 | 0;
	                        w = c[r >> 2] | 0;
	                        c[r >> 2] = w + 1;
	                        c[p >> 2] = q + ((d[w >> 0] | 0) - 48);
	                        c[t >> 2] = (c[t >> 2] | 0) + -1
	                    }
	                    while (1) {
	                        if ((c[t >> 2] | 0) <= 8)break;
	                        w = (c[o >> 2] | 0) * 10 | 0;
	                        q = c[r >> 2] | 0;
	                        c[r >> 2] = q + 1;
	                        c[o >> 2] = w + ((d[q >> 0] | 0) - 48);
	                        c[t >> 2] = (c[t >> 2] | 0) + -1
	                    }
	                    while (1) {
	                        if ((c[t >> 2] | 0) <= 0)break;
	                        q = (c[n >> 2] | 0) * 10 | 0;
	                        w = c[r >> 2] | 0;
	                        c[r >> 2] = w + 1;
	                        c[n >> 2] = q + ((d[w >> 0] | 0) - 48);
	                        c[t >> 2] = (c[t >> 2] | 0) + -1
	                    }
	                    c[c[j >> 2] >> 2] = c[r >> 2];
	                    c[c[k >> 2] >> 2] = c[n >> 2];
	                    c[c[l >> 2] >> 2] = c[o >> 2];
	                    c[c[m >> 2] >> 2] = c[p >> 2];
	                    c[h >> 2] = c[s >> 2];
	                    x = c[h >> 2] | 0;
	                    i = g;
	                    return x | 0
	                }
	                c[h >> 2] = -2;
	                x = c[h >> 2] | 0;
	                i = g;
	                return x | 0
	            }

	            function qI(a, e, f, g) {
	                a = a | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                j = i;
	                i = i + 48 | 0;
	                k = j + 32 | 0;
	                l = j + 28 | 0;
	                m = j + 24 | 0;
	                n = j + 20 | 0;
	                o = j + 16 | 0;
	                p = j + 12 | 0;
	                q = j + 8 | 0;
	                r = j + 4 | 0;
	                s = j;
	                c[l >> 2] = a;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                c[r >> 2] = c[m >> 2];
	                if (!(c[m >> 2] | 0)) {
	                    c[k >> 2] = -1;
	                    t = c[k >> 2] | 0;
	                    i = j;
	                    return t | 0
	                }
	                a:do if (c[o >> 2] | 0)while (1) {
	                    do if ((d[c[r >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[r >> 2] >> 0] | 0 | 0) ? (d[c[r >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[r >> 2] >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    c[r >> 2] = (c[r >> 2] | 0) + 1
	                } while (0);
	                if (((d[c[r >> 2] >> 0] | 0 | 0) != 45 ? (d[c[r >> 2] >> 0] | 0 | 0) < 48 : 0) ? (d[c[r >> 2] >> 0] | 0 | 0) > 57 : 0) {
	                    c[k >> 2] = 1;
	                    t = c[k >> 2] | 0;
	                    i = j;
	                    return t | 0
	                }
	                c[p >> 2] = hI(0) | 0;
	                if (!(c[p >> 2] | 0)) {
	                    c[k >> 2] = -1;
	                    t = c[k >> 2] | 0;
	                    i = j;
	                    return t | 0
	                }
	                b:do if ((d[c[r >> 2] >> 0] | 0 | 0) == 45 ? (d[(c[r >> 2] | 0) + 1 >> 0] | 0 | 0) == 45 : 0) {
	                    c[r >> 2] = (c[r >> 2] | 0) + 2;
	                    if ((d[c[r >> 2] >> 0] | 0 | 0) == 45) {
	                        if ((c[l >> 2] | 0) == 6)break;
	                        c[r >> 2] = (c[r >> 2] | 0) + 1;
	                        c[q >> 2] = HI((c[p >> 2] | 0) + 8 | 0, r) | 0;
	                        if (c[q >> 2] | 0)break;
	                        if ((((d[c[r >> 2] >> 0] | 0 | 0) != 0 ? (d[c[r >> 2] >> 0] | 0 | 0) != 90 : 0) ? (d[c[r >> 2] >> 0] | 0 | 0) != 43 : 0) ? (d[c[r >> 2] >> 0] | 0 | 0) != 45 : 0)break;
	                        c[q >> 2] = II((c[p >> 2] | 0) + 8 | 0, r) | 0;
	                        if (c[q >> 2] | 0)break;
	                        if (d[c[r >> 2] >> 0] | 0)break;
	                        c[c[p >> 2] >> 2] = 5;
	                        u = 123;
	                        break
	                    }
	                    c[q >> 2] = JI((c[p >> 2] | 0) + 8 | 0, r) | 0;
	                    if (!(c[q >> 2] | 0)) {
	                        if ((d[c[r >> 2] >> 0] | 0 | 0) == 45) {
	                            c[s >> 2] = c[r >> 2];
	                            c[r >> 2] = (c[r >> 2] | 0) + 1;
	                            c[q >> 2] = HI((c[p >> 2] | 0) + 8 | 0, r) | 0;
	                            do if (!(c[q >> 2] | 0)) {
	                                if ((d[c[r >> 2] >> 0] | 0 | 0) != 0 ? (d[c[r >> 2] >> 0] | 0 | 0) == 58 : 0)break;
	                                if (((c[(c[p >> 2] | 0) + 8 >> 2] | 0) % 4 | 0 | 0) == 0 ? ((c[(c[p >> 2] | 0) + 8 >> 2] | 0) % 100 | 0 | 0) != 0 : 0)u = 35; else if ((c[(c[p >> 2] | 0) + 8 >> 2] | 0) % 400 | 0) {
	                                    if (((c[(c[p >> 2] | 0) + 12 >> 2] | 0) >>> 4 & 31) >>> 0 > (c[171912 + ((c[(c[p >> 2] | 0) + 12 >> 2] & 15) - 1 << 2) >> 2] | 0) >>> 0)break
	                                } else u = 35;
	                                if ((u | 0) == 35 ? ((c[(c[p >> 2] | 0) + 12 >> 2] | 0) >>> 4 & 31) >>> 0 > (c[171864 + ((c[(c[p >> 2] | 0) + 12 >> 2] & 15) - 1 << 2) >> 2] | 0) >>> 0 : 0)break;
	                                if ((((d[c[r >> 2] >> 0] | 0 | 0) != 0 ? (d[c[r >> 2] >> 0] | 0 | 0) != 90 : 0) ? (d[c[r >> 2] >> 0] | 0 | 0) != 43 : 0) ? (d[c[r >> 2] >> 0] | 0 | 0) != 45 : 0)break b;
	                                c[q >> 2] = II((c[p >> 2] | 0) + 8 | 0, r) | 0;
	                                if (c[q >> 2] | 0)break b;
	                                if (d[c[r >> 2] >> 0] | 0)break b;
	                                c[c[p >> 2] >> 2] = 7;
	                                u = 123;
	                                break b
	                            } while (0);
	                            c[r >> 2] = c[s >> 2]
	                        }
	                        if ((((d[c[r >> 2] >> 0] | 0 | 0) != 0 ? (d[c[r >> 2] >> 0] | 0 | 0) != 90 : 0) ? (d[c[r >> 2] >> 0] | 0 | 0) != 43 : 0) ? (d[c[r >> 2] >> 0] | 0 | 0) != 45 : 0)break;
	                        c[q >> 2] = II((c[p >> 2] | 0) + 8 | 0, r) | 0;
	                        if ((c[q >> 2] | 0) == 0 ? (d[c[r >> 2] >> 0] | 0 | 0) == 0 : 0) {
	                            c[c[p >> 2] >> 2] = 6;
	                            u = 123
	                        }
	                    }
	                } else u = 52; while (0);
	                c:do if ((u | 0) == 52) {
	                    do if (((d[c[r >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[r >> 2] >> 0] | 0 | 0) <= 57 : 0) ? (c[q >> 2] = KI((c[p >> 2] | 0) + 8 | 0, r) | 0, (c[q >> 2] | 0) == 0) : 0) {
	                        if ((((d[c[r >> 2] >> 0] | 0 | 0) != 0 ? (d[c[r >> 2] >> 0] | 0 | 0) != 90 : 0) ? (d[c[r >> 2] >> 0] | 0 | 0) != 43 : 0) ? (d[c[r >> 2] >> 0] | 0 | 0) != 45 : 0)break;
	                        c[q >> 2] = II((c[p >> 2] | 0) + 8 | 0, r) | 0;
	                        if (!(c[q >> 2] | 0)) {
	                            if (d[c[r >> 2] >> 0] | 0)break c;
	                            c[c[p >> 2] >> 2] = 4;
	                            u = 123;
	                            break c
	                        }
	                    } while (0);
	                    c[r >> 2] = c[m >> 2];
	                    c[q >> 2] = LI((c[p >> 2] | 0) + 8 | 0, r) | 0;
	                    if (!(c[q >> 2] | 0)) {
	                        if (!((((d[c[r >> 2] >> 0] | 0 | 0) != 0 ? (d[c[r >> 2] >> 0] | 0 | 0) != 90 : 0) ? (d[c[r >> 2] >> 0] | 0 | 0) != 43 : 0) ? (d[c[r >> 2] >> 0] | 0 | 0) != 45 : 0))u = 67;
	                        if ((u | 0) == 67 ? (c[q >> 2] = II((c[p >> 2] | 0) + 8 | 0, r) | 0, (c[q >> 2] | 0) == 0) : 0) {
	                            if (d[c[r >> 2] >> 0] | 0)break;
	                            c[c[p >> 2] >> 2] = 8;
	                            u = 123;
	                            break
	                        }
	                        if ((d[c[r >> 2] >> 0] | 0 | 0) == 45 ? (c[r >> 2] = (c[r >> 2] | 0) + 1, c[q >> 2] = JI((c[p >> 2] | 0) + 8 | 0, r) | 0, (c[q >> 2] | 0) == 0) : 0) {
	                            if (!((((d[c[r >> 2] >> 0] | 0 | 0) != 0 ? (d[c[r >> 2] >> 0] | 0 | 0) != 90 : 0) ? (d[c[r >> 2] >> 0] | 0 | 0) != 43 : 0) ? (d[c[r >> 2] >> 0] | 0 | 0) != 45 : 0))u = 76;
	                            if ((u | 0) == 76 ? (c[q >> 2] = II((c[p >> 2] | 0) + 8 | 0, r) | 0, (c[q >> 2] | 0) == 0) : 0) {
	                                if (d[c[r >> 2] >> 0] | 0)break;
	                                c[c[p >> 2] >> 2] = 9;
	                                u = 123;
	                                break
	                            }
	                            if (((((d[c[r >> 2] >> 0] | 0 | 0) == 45 ? (c[r >> 2] = (c[r >> 2] | 0) + 1, c[q >> 2] = HI((c[p >> 2] | 0) + 8 | 0, r) | 0, (c[q >> 2] | 0) == 0) : 0) ? (c[(c[p >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (c[(c[p >> 2] | 0) + 12 >> 2] & 15 | 0) >= 1 : 0) ? (c[(c[p >> 2] | 0) + 12 >> 2] & 15 | 0) <= 12 : 0) {
	                                if (((c[(c[p >> 2] | 0) + 8 >> 2] | 0) % 4 | 0 | 0) == 0 ? ((c[(c[p >> 2] | 0) + 8 >> 2] | 0) % 100 | 0 | 0) != 0 : 0)u = 87; else if ((c[(c[p >> 2] | 0) + 8 >> 2] | 0) % 400 | 0) {
	                                    if (((c[(c[p >> 2] | 0) + 12 >> 2] | 0) >>> 4 & 31) >>> 0 > (c[171912 + ((c[(c[p >> 2] | 0) + 12 >> 2] & 15) - 1 << 2) >> 2] | 0) >>> 0)break
	                                } else u = 87;
	                                if ((u | 0) == 87 ? ((c[(c[p >> 2] | 0) + 12 >> 2] | 0) >>> 4 & 31) >>> 0 > (c[171864 + ((c[(c[p >> 2] | 0) + 12 >> 2] & 15) - 1 << 2) >> 2] | 0) >>> 0 : 0)break;
	                                do if (d[c[r >> 2] >> 0] | 0) {
	                                    if ((d[c[r >> 2] >> 0] | 0 | 0) == 90) {
	                                        u = 93;
	                                        break
	                                    }
	                                    if ((d[c[r >> 2] >> 0] | 0 | 0) == 43) {
	                                        u = 93;
	                                        break
	                                    }
	                                    if ((d[c[r >> 2] >> 0] | 0 | 0) == 45)u = 93
	                                } else u = 93; while (0);
	                                do if ((u | 0) == 93) {
	                                    c[q >> 2] = II((c[p >> 2] | 0) + 8 | 0, r) | 0;
	                                    if (c[q >> 2] | 0)break;
	                                    if (d[c[r >> 2] >> 0] | 0)break c;
	                                    c[c[p >> 2] >> 2] = 10;
	                                    u = 123;
	                                    break c
	                                } while (0);
	                                if ((d[c[r >> 2] >> 0] | 0 | 0) == 84) {
	                                    c[r >> 2] = (c[r >> 2] | 0) + 1;
	                                    c[q >> 2] = KI((c[p >> 2] | 0) + 8 | 0, r) | 0;
	                                    if (c[q >> 2] | 0)break;
	                                    c[q >> 2] = II((c[p >> 2] | 0) + 8 | 0, r) | 0;
	                                    d:do if (c[o >> 2] | 0)while (1) {
	                                        do if ((d[c[r >> 2] >> 0] | 0 | 0) != 32) {
	                                            if (9 <= (d[c[r >> 2] >> 0] | 0 | 0) ? (d[c[r >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                                            if ((d[c[r >> 2] >> 0] | 0 | 0) != 13)break d
	                                        } while (0);
	                                        c[r >> 2] = (c[r >> 2] | 0) + 1
	                                    } while (0);
	                                    if (c[q >> 2] | 0)break;
	                                    if (d[c[r >> 2] >> 0] | 0)break;
	                                    if (!(c[(c[p >> 2] | 0) + 8 >> 2] | 0))break;
	                                    if ((c[(c[p >> 2] | 0) + 12 >> 2] & 15 | 0) < 1)break;
	                                    if ((c[(c[p >> 2] | 0) + 12 >> 2] & 15 | 0) > 12)break;
	                                    if (((c[(c[p >> 2] | 0) + 8 >> 2] | 0) % 4 | 0 | 0) == 0 ? ((c[(c[p >> 2] | 0) + 8 >> 2] | 0) % 100 | 0 | 0) != 0 : 0)u = 112; else u = 111;
	                                    do if ((u | 0) == 111) {
	                                        if (!((c[(c[p >> 2] | 0) + 8 >> 2] | 0) % 400 | 0)) {
	                                            u = 112;
	                                            break
	                                        }
	                                        if (((c[(c[p >> 2] | 0) + 12 >> 2] | 0) >>> 4 & 31) >>> 0 > (c[171912 + ((c[(c[p >> 2] | 0) + 12 >> 2] & 15) - 1 << 2) >> 2] | 0) >>> 0)break c
	                                    } while (0);
	                                    if ((u | 0) == 112 ? ((c[(c[p >> 2] | 0) + 12 >> 2] | 0) >>> 4 & 31) >>> 0 > (c[171864 + ((c[(c[p >> 2] | 0) + 12 >> 2] & 15) - 1 << 2) >> 2] | 0) >>> 0 : 0)break;
	                                    if (((c[(c[p >> 2] | 0) + 12 >> 2] | 0) >>> 9 & 31 | 0) < 0)break;
	                                    if (((c[(c[p >> 2] | 0) + 12 >> 2] | 0) >>> 9 & 31 | 0) > 23)break;
	                                    if (((c[(c[p >> 2] | 0) + 12 >> 2] | 0) >>> 14 & 63 | 0) < 0)break;
	                                    if (((c[(c[p >> 2] | 0) + 12 >> 2] | 0) >>> 14 & 63 | 0) > 59)break;
	                                    if (!(+h[(c[p >> 2] | 0) + 16 >> 3] >= 0.0))break;
	                                    if (!(+h[(c[p >> 2] | 0) + 16 >> 3] < 60.0))break;
	                                    if (((b[(c[p >> 2] | 0) + 24 >> 1] << 3 & 65535) << 16 >> 16 >> 4 << 16 >> 16 | 0) <= -840)break;
	                                    if (((b[(c[p >> 2] | 0) + 24 >> 1] << 3 & 65535) << 16 >> 16 >> 4 << 16 >> 16 | 0) >= 840)break;
	                                    c[c[p >> 2] >> 2] = 11;
	                                    u = 123
	                                }
	                            }
	                        }
	                    }
	                } while (0);
	                do if ((u | 0) == 123) {
	                    if ((c[l >> 2] | 0) != 0 ? (c[l >> 2] | 0) != (c[c[p >> 2] >> 2] | 0) : 0)break;
	                    r = c[p >> 2] | 0;
	                    if (c[n >> 2] | 0)c[c[n >> 2] >> 2] = r; else PH(r);
	                    c[k >> 2] = 0;
	                    t = c[k >> 2] | 0;
	                    i = j;
	                    return t | 0
	                } while (0);
	                if (c[p >> 2] | 0)PH(c[p >> 2] | 0);
	                c[k >> 2] = 1;
	                t = c[k >> 2] | 0;
	                i = j;
	                return t | 0
	            }

	            function rI(a, b, e, f) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                g = i;
	                i = i + 64 | 0;
	                j = g + 52 | 0;
	                k = g + 44 | 0;
	                l = g + 40 | 0;
	                m = g + 36 | 0;
	                n = g + 32 | 0;
	                o = g + 28 | 0;
	                p = g + 24 | 0;
	                q = g + 20 | 0;
	                r = g + 8 | 0;
	                s = g + 16 | 0;
	                t = g;
	                c[g + 48 >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                c[n >> 2] = c[k >> 2];
	                c[p >> 2] = 0;
	                c[q >> 2] = 0;
	                c[s >> 2] = 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[j >> 2] = -1;
	                    u = c[j >> 2] | 0;
	                    i = g;
	                    return u | 0
	                }
	                a:do if (c[m >> 2] | 0)while (1) {
	                    do if ((d[c[n >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[n >> 2] >> 0] | 0 | 0) ? (d[c[n >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[n >> 2] >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    c[n >> 2] = (c[n >> 2] | 0) + 1
	                } while (0);
	                if ((d[c[n >> 2] >> 0] | 0 | 0) == 45) {
	                    c[p >> 2] = 1;
	                    c[n >> 2] = (c[n >> 2] | 0) + 1
	                }
	                k = c[n >> 2] | 0;
	                c[n >> 2] = k + 1;
	                if ((d[k >> 0] | 0 | 0) != 80) {
	                    c[j >> 2] = 1;
	                    u = c[j >> 2] | 0;
	                    i = g;
	                    return u | 0
	                }
	                if (!(d[c[n >> 2] >> 0] | 0)) {
	                    c[j >> 2] = 1;
	                    u = c[j >> 2] | 0;
	                    i = g;
	                    return u | 0
	                }
	                c[o >> 2] = hI(12) | 0;
	                if (!(c[o >> 2] | 0)) {
	                    c[j >> 2] = -1;
	                    u = c[j >> 2] | 0;
	                    i = g;
	                    return u | 0
	                }
	                b:while (1) {
	                    if (!(d[c[n >> 2] >> 0] | 0)) {
	                        v = 55;
	                        break
	                    }
	                    if ((c[q >> 2] | 0) >>> 0 >= 6) {
	                        v = 61;
	                        break
	                    }
	                    k = c[q >> 2] | 0;
	                    if ((d[c[n >> 2] >> 0] | 0 | 0) != 84) {
	                        if ((k | 0) == 3) {
	                            v = 61;
	                            break
	                        }
	                    } else {
	                        if (k >>> 0 > 3) {
	                            v = 22;
	                            break
	                        }
	                        c[q >> 2] = 3;
	                        c[n >> 2] = (c[n >> 2] | 0) + 1
	                    }
	                    h[r >> 3] = 0.0;
	                    c:do if ((d[c[n >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[n >> 2] >> 0] | 0 | 0) <= 57 : 0)while (1) {
	                        if ((d[c[n >> 2] >> 0] | 0 | 0) < 48)break c;
	                        if ((d[c[n >> 2] >> 0] | 0 | 0) > 57)break c;
	                        h[r >> 3] = +h[r >> 3] * 10.0 + +((d[c[n >> 2] >> 0] | 0) - 48 | 0);
	                        c[n >> 2] = (c[n >> 2] | 0) + 1
	                    } else v = 26; while (0);
	                    if ((v | 0) == 26) {
	                        v = 0;
	                        c[s >> 2] = -1
	                    }
	                    d:do if ((c[s >> 2] | 0) == 0 ? (d[c[n >> 2] >> 0] | 0 | 0) == 46 : 0) {
	                        h[t >> 3] = 1.0;
	                        c[n >> 2] = (c[n >> 2] | 0) + 1;
	                        if ((d[c[n >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[n >> 2] >> 0] | 0 | 0) <= 57 : 0)c[s >> 2] = 1; else c[s >> 2] = -1;
	                        while (1) {
	                            if ((d[c[n >> 2] >> 0] | 0 | 0) < 48)break d;
	                            if ((d[c[n >> 2] >> 0] | 0 | 0) > 57)break d;
	                            h[t >> 3] = +h[t >> 3] / 10.0;
	                            h[r >> 3] = +h[r >> 3] + +((d[c[n >> 2] >> 0] | 0) - 48 | 0) * +h[t >> 3];
	                            c[n >> 2] = (c[n >> 2] | 0) + 1
	                        }
	                    } while (0);
	                    if ((c[s >> 2] | 0) == -1) {
	                        v = 61;
	                        break
	                    }
	                    if (!(d[c[n >> 2] >> 0] | 0)) {
	                        v = 61;
	                        break
	                    }
	                    while (1) {
	                        if ((c[q >> 2] | 0) >>> 0 >= 6)break;
	                        if ((d[c[n >> 2] >> 0] | 0 | 0) == (d[172280 + (c[q >> 2] | 0) >> 0] | 0 | 0)) {
	                            v = 43;
	                            break
	                        }
	                        k = (c[q >> 2] | 0) + 1 | 0;
	                        c[q >> 2] = k;
	                        if ((k | 0) == 3 | (c[q >> 2] | 0) == 6) {
	                            v = 61;
	                            break b
	                        }
	                    }
	                    do if ((v | 0) == 43) {
	                        v = 0;
	                        if ((c[s >> 2] | 0) != 0 & (c[q >> 2] | 0) >>> 0 < 5) {
	                            v = 61;
	                            break b
	                        }
	                        k = c[q >> 2] | 0;
	                        if ((k | 0) == 1) {
	                            f = (c[o >> 2] | 0) + 8 | 0;
	                            c[f >> 2] = (c[f >> 2] | 0) + ~~+h[r >> 3];
	                            break
	                        } else if (!k) {
	                            c[(c[o >> 2] | 0) + 8 >> 2] = ~~+h[r >> 3] * 12;
	                            break
	                        } else {
	                            k = (c[o >> 2] | 0) + 16 | 0;
	                            h[k >> 3] = +h[k >> 3] + +h[r >> 3] * +h[172288 + (c[q >> 2] << 3) >> 3];
	                            c[q >> 2] = (c[q >> 2] | 0) + 1;
	                            break
	                        }
	                    } while (0);
	                    c[n >> 2] = (c[n >> 2] | 0) + 1;
	                    if (!(c[m >> 2] | 0))continue;
	                    while (1) {
	                        do if ((d[c[n >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[n >> 2] >> 0] | 0 | 0) ? (d[c[n >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[n >> 2] >> 0] | 0 | 0) != 13)continue b
	                        } while (0);
	                        c[n >> 2] = (c[n >> 2] | 0) + 1
	                    }
	                }
	                if ((v | 0) == 22) {
	                    c[j >> 2] = 1;
	                    u = c[j >> 2] | 0;
	                    i = g;
	                    return u | 0
	                } else if ((v | 0) == 55) {
	                    if (c[p >> 2] | 0) {
	                        c[(c[o >> 2] | 0) + 8 >> 2] = 0 - (c[(c[o >> 2] | 0) + 8 >> 2] | 0);
	                        c[(c[o >> 2] | 0) + 12 >> 2] = 0 - (c[(c[o >> 2] | 0) + 12 >> 2] | 0);
	                        h[(c[o >> 2] | 0) + 16 >> 3] = -+h[(c[o >> 2] | 0) + 16 >> 3]
	                    }
	                    p = c[o >> 2] | 0;
	                    if (c[l >> 2] | 0)c[c[l >> 2] >> 2] = p; else PH(p);
	                    c[j >> 2] = 0;
	                    u = c[j >> 2] | 0;
	                    i = g;
	                    return u | 0
	                } else if ((v | 0) == 61) {
	                    if (c[o >> 2] | 0)PH(c[o >> 2] | 0);
	                    c[j >> 2] = 1;
	                    u = c[j >> 2] | 0;
	                    i = g;
	                    return u | 0
	                }
	                return 0
	            }

	            function sI(b, e, f, g) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h + 36 | 0;
	                k = h + 32 | 0;
	                l = h + 28 | 0;
	                m = h + 24 | 0;
	                n = h + 20 | 0;
	                o = h + 16 | 0;
	                p = h + 12 | 0;
	                q = h + 8 | 0;
	                r = h + 4 | 0;
	                s = h;
	                c[k >> 2] = b;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                c[n >> 2] = g;
	                c[r >> 2] = 0;
	                c[s >> 2] = 0;
	                if (!(c[l >> 2] | 0)) {
	                    c[j >> 2] = -1;
	                    t = c[j >> 2] | 0;
	                    i = h;
	                    return t | 0
	                }
	                c[o >> 2] = my(c[l >> 2] | 0) | 0;
	                if (!(c[o >> 2] | 0)) {
	                    c[j >> 2] = -1;
	                    t = c[j >> 2] | 0;
	                    i = h;
	                    return t | 0
	                }
	                if (c[m >> 2] | 0)c[c[m >> 2] >> 2] = 0;
	                c[p >> 2] = c[o >> 2];
	                a:while (1) {
	                    do if ((d[c[p >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[p >> 2] >> 0] | 0 | 0) ? (d[c[p >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[p >> 2] >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    m = c[p >> 2] | 0;
	                    c[p >> 2] = m + 1;
	                    a[m >> 0] = 0
	                }
	                b:while (1) {
	                    if (!(d[c[p >> 2] >> 0] | 0))break;
	                    do if ((d[c[p >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[p >> 2] >> 0] | 0 | 0) ? (d[c[p >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[p >> 2] >> 0] | 0 | 0) != 13) {
	                            c[r >> 2] = (c[r >> 2] | 0) + 1;
	                            c[p >> 2] = (c[p >> 2] | 0) + 1;
	                            while (1) {
	                                if (!(d[c[p >> 2] >> 0] | 0))continue b;
	                                do if ((d[c[p >> 2] >> 0] | 0 | 0) == 32)u = 1; else {
	                                    if (9 <= (d[c[p >> 2] >> 0] | 0 | 0) ? (d[c[p >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                        u = 1;
	                                        break
	                                    }
	                                    u = (d[c[p >> 2] >> 0] | 0 | 0) == 13
	                                } while (0);
	                                if (!(u ^ 1))continue b;
	                                c[p >> 2] = (c[p >> 2] | 0) + 1
	                            }
	                        }
	                    } while (0);
	                    a[c[p >> 2] >> 0] = 0;
	                    c[p >> 2] = (c[p >> 2] | 0) + 1;
	                    while (1) {
	                        do if ((d[c[p >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[p >> 2] >> 0] | 0 | 0) ? (d[c[p >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[p >> 2] >> 0] | 0 | 0) != 13)continue b
	                        } while (0);
	                        m = c[p >> 2] | 0;
	                        c[p >> 2] = m + 1;
	                        a[m >> 0] = 0
	                    }
	                }
	                if (!(c[r >> 2] | 0)) {
	                    zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                    c[j >> 2] = c[r >> 2];
	                    t = c[j >> 2] | 0;
	                    i = h;
	                    return t | 0
	                }
	                c[q >> 2] = c[p >> 2];
	                c[p >> 2] = c[o >> 2];
	                while (1) {
	                    if (d[c[p >> 2] >> 0] | 0)break;
	                    if ((c[p >> 2] | 0) == (c[q >> 2] | 0))break;
	                    c[p >> 2] = (c[p >> 2] | 0) + 1
	                }
	                c:while (1) {
	                    if ((c[p >> 2] | 0) == (c[q >> 2] | 0))break;
	                    c[s >> 2] = TH(c[k >> 2] | 0, c[p >> 2] | 0, 0, c[n >> 2] | 0) | 0;
	                    if (c[s >> 2] | 0)break;
	                    while (1) {
	                        if (!(d[c[p >> 2] >> 0] | 0))break;
	                        c[p >> 2] = (c[p >> 2] | 0) + 1
	                    }
	                    while (1) {
	                        if (d[c[p >> 2] >> 0] | 0)continue c;
	                        if ((c[p >> 2] | 0) == (c[q >> 2] | 0))continue c;
	                        c[p >> 2] = (c[p >> 2] | 0) + 1
	                    }
	                }
	                zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                if (!(c[s >> 2] | 0)) {
	                    c[j >> 2] = c[r >> 2];
	                    t = c[j >> 2] | 0;
	                    i = h;
	                    return t | 0
	                } else {
	                    c[j >> 2] = -1;
	                    t = c[j >> 2] | 0;
	                    i = h;
	                    return t | 0
	                }
	                return 0
	            }

	            function tI(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                b = i;
	                i = i + 32 | 0;
	                e = b + 16 | 0;
	                f = b + 12 | 0;
	                g = b + 8 | 0;
	                h = b + 4 | 0;
	                j = b;
	                c[f >> 2] = a;
	                c[g >> 2] = c[f >> 2];
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = b;
	                    return k | 0
	                }
	                while (1) {
	                    do if (d[c[g >> 2] >> 0] | 0)if ((d[c[g >> 2] >> 0] | 0 | 0) == 32)l = 1; else {
	                        if (9 <= (d[c[g >> 2] >> 0] | 0 | 0) ? (d[c[g >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            l = 1;
	                            break
	                        }
	                        l = (d[c[g >> 2] >> 0] | 0 | 0) == 13
	                    } else l = 0; while (0);
	                    m = c[g >> 2] | 0;
	                    if (!l)break;
	                    c[g >> 2] = m + 1
	                }
	                c[h >> 2] = m;
	                while (1) {
	                    n = c[h >> 2] | 0;
	                    if (!(d[c[h >> 2] >> 0] | 0))break;
	                    c[h >> 2] = n + 1
	                }
	                c[j >> 2] = n;
	                c[h >> 2] = (c[h >> 2] | 0) + -1;
	                while (1) {
	                    do if ((c[h >> 2] | 0) >>> 0 > (c[g >> 2] | 0) >>> 0)if ((d[c[h >> 2] >> 0] | 0 | 0) == 32)o = 1; else {
	                        if (9 <= (d[c[h >> 2] >> 0] | 0 | 0) ? (d[c[h >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            o = 1;
	                            break
	                        }
	                        o = (d[c[h >> 2] >> 0] | 0 | 0) == 13
	                    } else o = 0; while (0);
	                    p = c[h >> 2] | 0;
	                    if (!o)break;
	                    c[h >> 2] = p + -1
	                }
	                c[h >> 2] = p + 1;
	                if ((c[g >> 2] | 0) == (c[f >> 2] | 0) ? (c[j >> 2] | 0) == (c[h >> 2] | 0) : 0) {
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = b;
	                    return k | 0
	                }
	                c[e >> 2] = ly(c[g >> 2] | 0, (c[h >> 2] | 0) - (c[g >> 2] | 0) | 0) | 0;
	                k = c[e >> 2] | 0;
	                i = b;
	                return k | 0
	            }

	            function uI(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e;
	                g = e + 4 | 0;
	                a[g >> 0] = b;
	                if (65 <= (d[g >> 0] | 0 | 0) ? (d[g >> 0] | 0 | 0) <= 90 : 0)c[f >> 2] = (d[g >> 0] | 0) - 65; else h = 4;
	                do if ((h | 0) == 4) {
	                    if (97 <= (d[g >> 0] | 0 | 0) ? (d[g >> 0] | 0 | 0) <= 122 : 0) {
	                        c[f >> 2] = (d[g >> 0] | 0) - 97 + 26;
	                        break
	                    }
	                    if (48 <= (d[g >> 0] | 0 | 0) ? (d[g >> 0] | 0 | 0) <= 57 : 0) {
	                        c[f >> 2] = (d[g >> 0] | 0) - 48 + 52;
	                        break
	                    }
	                    if (43 == (d[g >> 0] | 0 | 0)) {
	                        c[f >> 2] = 62;
	                        break
	                    }
	                    if (47 == (d[g >> 0] | 0 | 0)) {
	                        c[f >> 2] = 63;
	                        break
	                    }
	                    if (61 == (d[g >> 0] | 0 | 0)) {
	                        c[f >> 2] = 64;
	                        break
	                    } else {
	                        c[f >> 2] = -1;
	                        break
	                    }
	                } while (0);
	                i = e;
	                return c[f >> 2] | 0
	            }

	            function vI(a, d) {
	                a = a | 0;
	                d = d | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0;
	                f = i;
	                i = i + 64 | 0;
	                g = f + 48 | 0;
	                h = f + 44 | 0;
	                j = f + 40 | 0;
	                k = f + 36 | 0;
	                l = f + 32 | 0;
	                m = f + 28 | 0;
	                n = f + 24 | 0;
	                o = f + 20 | 0;
	                p = f + 16 | 0;
	                q = f + 12 | 0;
	                r = f + 8 | 0;
	                s = f + 4 | 0;
	                t = f;
	                c[h >> 2] = a;
	                c[j >> 2] = d;
	                c[l >> 2] = 1;
	                a:do if (b[(c[h >> 2] | 0) + 24 >> 1] & 1) {
	                    if (((c[(c[h >> 2] | 0) + 8 >> 2] | 0) == 0 ? (c[(c[h >> 2] | 0) + 12 >> 2] | 0) == 0 : 0) ? (c[(c[h >> 2] | 0) + 16 >> 2] | 0) == 0 : 0) {
	                        u = 11;
	                        break
	                    }
	                    do if (b[(c[j >> 2] | 0) + 24 >> 1] & 1) {
	                        if (((c[(c[j >> 2] | 0) + 8 >> 2] | 0) == 0 ? (c[(c[j >> 2] | 0) + 12 >> 2] | 0) == 0 : 0) ? (c[(c[j >> 2] | 0) + 16 >> 2] | 0) == 0 : 0)break;
	                        c[l >> 2] = -1;
	                        break a
	                    } while (0);
	                    c[g >> 2] = -1;
	                    v = c[g >> 2] | 0;
	                    i = f;
	                    return v | 0
	                } else u = 11; while (0);
	                do if ((u | 0) == 11 ? (b[(c[j >> 2] | 0) + 24 >> 1] & 1 | 0) != 0 : 0) {
	                    if (((c[(c[j >> 2] | 0) + 8 >> 2] | 0) == 0 ? (c[(c[j >> 2] | 0) + 12 >> 2] | 0) == 0 : 0) ? (c[(c[j >> 2] | 0) + 16 >> 2] | 0) == 0 : 0)break;
	                    c[g >> 2] = 1;
	                    v = c[g >> 2] | 0;
	                    i = f;
	                    return v | 0
	                } while (0);
	                c[m >> 2] = ((e[(c[h >> 2] | 0) + 24 >> 1] | 0) >>> 8 & 65535) - ((e[(c[h >> 2] | 0) + 24 >> 1] | 0) >>> 1 & 127);
	                c[n >> 2] = ((e[(c[j >> 2] | 0) + 24 >> 1] | 0) >>> 8 & 65535) - ((e[(c[j >> 2] | 0) + 24 >> 1] | 0) >>> 1 & 127);
	                if ((c[m >> 2] | 0) == 1 ? (c[(c[h >> 2] | 0) + 8 >> 2] | 0) == 0 : 0) {
	                    if ((c[n >> 2] | 0) != 1) {
	                        c[g >> 2] = 0 - (c[l >> 2] | 0);
	                        v = c[g >> 2] | 0;
	                        i = f;
	                        return v | 0
	                    }
	                    if (c[(c[j >> 2] | 0) + 8 >> 2] | 0) {
	                        c[g >> 2] = 0 - (c[l >> 2] | 0);
	                        v = c[g >> 2] | 0;
	                        i = f;
	                        return v | 0
	                    } else {
	                        c[g >> 2] = 0;
	                        v = c[g >> 2] | 0;
	                        i = f;
	                        return v | 0
	                    }
	                }
	                if ((c[n >> 2] | 0) == 1 ? (c[(c[j >> 2] | 0) + 8 >> 2] | 0) == 0 : 0) {
	                    if ((c[m >> 2] | 0) != 1) {
	                        c[g >> 2] = c[l >> 2];
	                        v = c[g >> 2] | 0;
	                        i = f;
	                        return v | 0
	                    }
	                    if (c[(c[h >> 2] | 0) + 8 >> 2] | 0) {
	                        c[g >> 2] = c[l >> 2];
	                        v = c[g >> 2] | 0;
	                        i = f;
	                        return v | 0
	                    } else {
	                        c[g >> 2] = 0;
	                        v = c[g >> 2] | 0;
	                        i = f;
	                        return v | 0
	                    }
	                }
	                if ((c[m >> 2] | 0) > (c[n >> 2] | 0)) {
	                    c[g >> 2] = c[l >> 2];
	                    v = c[g >> 2] | 0;
	                    i = f;
	                    return v | 0
	                }
	                if ((c[n >> 2] | 0) > (c[m >> 2] | 0)) {
	                    c[g >> 2] = 0 - (c[l >> 2] | 0);
	                    v = c[g >> 2] | 0;
	                    i = f;
	                    return v | 0
	                }
	                c[o >> 2] = ((e[(c[h >> 2] | 0) + 24 >> 1] | 0) >>> 8 & 65535) - ((e[(c[j >> 2] | 0) + 24 >> 1] | 0) >>> 8 & 65535);
	                if ((c[o >> 2] | 0) < 0) {
	                    c[k >> 2] = c[h >> 2];
	                    c[p >> 2] = c[(c[j >> 2] | 0) + 16 >> 2];
	                    c[q >> 2] = c[(c[j >> 2] | 0) + 12 >> 2];
	                    c[r >> 2] = c[(c[j >> 2] | 0) + 8 >> 2];
	                    c[o >> 2] = 0 - (c[o >> 2] | 0);
	                    c[l >> 2] = 0 - (c[l >> 2] | 0)
	                } else {
	                    c[k >> 2] = c[j >> 2];
	                    c[p >> 2] = c[(c[h >> 2] | 0) + 16 >> 2];
	                    c[q >> 2] = c[(c[h >> 2] | 0) + 12 >> 2];
	                    c[r >> 2] = c[(c[h >> 2] | 0) + 8 >> 2]
	                }
	                while (1) {
	                    if ((c[o >> 2] | 0) <= 8)break;
	                    c[r >> 2] = c[q >> 2];
	                    c[q >> 2] = c[p >> 2];
	                    c[p >> 2] = 0;
	                    c[o >> 2] = (c[o >> 2] | 0) - 8
	                }
	                while (1) {
	                    w = c[p >> 2] | 0;
	                    if ((c[o >> 2] | 0) <= 0)break;
	                    c[s >> 2] = ca((w >>> 0) % 10 | 0, 1e8) | 0;
	                    c[p >> 2] = ((c[p >> 2] | 0) >>> 0) / 10 | 0;
	                    c[t >> 2] = ca(((c[q >> 2] | 0) >>> 0) % 10 | 0, 1e8) | 0;
	                    c[q >> 2] = (((c[q >> 2] | 0) + (c[s >> 2] | 0) | 0) >>> 0) / 10 | 0;
	                    c[r >> 2] = (((c[r >> 2] | 0) + (c[t >> 2] | 0) | 0) >>> 0) / 10 | 0;
	                    c[o >> 2] = (c[o >> 2] | 0) + -1
	                }
	                if (w >>> 0 > (c[(c[k >> 2] | 0) + 16 >> 2] | 0) >>> 0) {
	                    c[g >> 2] = c[l >> 2];
	                    v = c[g >> 2] | 0;
	                    i = f;
	                    return v | 0
	                }
	                if ((c[p >> 2] | 0) == (c[(c[k >> 2] | 0) + 16 >> 2] | 0)) {
	                    if ((c[q >> 2] | 0) >>> 0 > (c[(c[k >> 2] | 0) + 12 >> 2] | 0) >>> 0) {
	                        c[g >> 2] = c[l >> 2];
	                        v = c[g >> 2] | 0;
	                        i = f;
	                        return v | 0
	                    }
	                    if ((c[q >> 2] | 0) == (c[(c[k >> 2] | 0) + 12 >> 2] | 0)) {
	                        if ((c[r >> 2] | 0) >>> 0 > (c[(c[k >> 2] | 0) + 8 >> 2] | 0) >>> 0) {
	                            c[g >> 2] = c[l >> 2];
	                            v = c[g >> 2] | 0;
	                            i = f;
	                            return v | 0
	                        }
	                        if ((c[r >> 2] | 0) == (c[(c[k >> 2] | 0) + 8 >> 2] | 0))if (((e[(c[h >> 2] | 0) + 24 >> 1] | 0) >>> 8 & 65535 | 0) == ((e[(c[j >> 2] | 0) + 24 >> 1] | 0) >>> 8 & 65535 | 0)) {
	                            c[g >> 2] = 0;
	                            v = c[g >> 2] | 0;
	                            i = f;
	                            return v | 0
	                        } else {
	                            c[g >> 2] = c[l >> 2];
	                            v = c[g >> 2] | 0;
	                            i = f;
	                            return v | 0
	                        }
	                    }
	                }
	                c[g >> 2] = 0 - (c[l >> 2] | 0);
	                v = c[g >> 2] | 0;
	                i = f;
	                return v | 0
	            }

	            function wI(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                d = i;
	                i = i + 64 | 0;
	                e = d + 52 | 0;
	                f = d + 48 | 0;
	                g = d + 44 | 0;
	                j = d + 40 | 0;
	                k = d + 36 | 0;
	                l = d + 32 | 0;
	                m = d;
	                n = d + 28 | 0;
	                o = d + 24 | 0;
	                p = d + 20 | 0;
	                q = d + 16 | 0;
	                r = d + 12 | 0;
	                s = d + 8 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[n >> 2] = 1;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = -2;
	                    t = c[e >> 2] | 0;
	                    i = d;
	                    return t | 0
	                }
	                c[k >> 2] = (c[(c[f >> 2] | 0) + 8 >> 2] | 0) - (c[(c[g >> 2] | 0) + 8 >> 2] | 0);
	                h[m >> 3] = +h[(c[f >> 2] | 0) + 16 >> 3] - +h[(c[g >> 2] | 0) + 16 >> 3];
	                c[j >> 2] = ~~(+h[m >> 3] / 86400.0);
	                h[m >> 3] = +h[m >> 3] - +(c[j >> 2] | 0) * 86400.0;
	                c[l >> 2] = (c[(c[f >> 2] | 0) + 12 >> 2] | 0) - (c[(c[g >> 2] | 0) + 12 >> 2] | 0) + (c[j >> 2] | 0);
	                if (!(c[k >> 2] | 0)) {
	                    if (c[l >> 2] | 0)if ((c[l >> 2] | 0) < 0) {
	                        c[e >> 2] = -1;
	                        t = c[e >> 2] | 0;
	                        i = d;
	                        return t | 0
	                    } else {
	                        c[e >> 2] = 1;
	                        t = c[e >> 2] | 0;
	                        i = d;
	                        return t | 0
	                    }
	                    if (+h[m >> 3] == 0.0) {
	                        c[e >> 2] = 0;
	                        t = c[e >> 2] | 0;
	                        i = d;
	                        return t | 0
	                    }
	                    if (+h[m >> 3] < 0.0) {
	                        c[e >> 2] = -1;
	                        t = c[e >> 2] | 0;
	                        i = d;
	                        return t | 0
	                    } else {
	                        c[e >> 2] = 1;
	                        t = c[e >> 2] | 0;
	                        i = d;
	                        return t | 0
	                    }
	                }
	                j = c[l >> 2] | 0;
	                do if ((c[k >> 2] | 0) > 0) {
	                    if (!((j | 0) >= 0 & +h[m >> 3] >= 0.0)) {
	                        c[o >> 2] = c[k >> 2];
	                        c[p >> 2] = 0 - (c[l >> 2] | 0);
	                        break
	                    }
	                    c[e >> 2] = 1;
	                    t = c[e >> 2] | 0;
	                    i = d;
	                    return t | 0
	                } else {
	                    if (!((j | 0) <= 0 & +h[m >> 3] <= 0.0)) {
	                        c[n >> 2] = -1;
	                        c[o >> 2] = 0 - (c[k >> 2] | 0);
	                        c[p >> 2] = c[l >> 2];
	                        break
	                    }
	                    c[e >> 2] = -1;
	                    t = c[e >> 2] | 0;
	                    i = d;
	                    return t | 0
	                } while (0);
	                c[q >> 2] = (c[o >> 2] | 0) / 12 | 0;
	                if (!(c[q >> 2] | 0)) {
	                    c[r >> 2] = 0;
	                    c[s >> 2] = 0
	                } else {
	                    c[s >> 2] = ((((c[q >> 2] | 0) + 3 | 0) / 4 | 0) * 366 | 0) + ((((c[q >> 2] | 0) - 1 | 0) % 4 | 0) * 365 | 0);
	                    c[r >> 2] = (c[s >> 2] | 0) - 1
	                }
	                c[o >> 2] = (c[o >> 2] | 0) % 12 | 0;
	                c[r >> 2] = (c[r >> 2] | 0) + (c[172120 + (c[o >> 2] << 2) >> 2] | 0);
	                c[s >> 2] = (c[s >> 2] | 0) + (c[172168 + (c[o >> 2] << 2) >> 2] | 0);
	                if ((c[s >> 2] | 0) == (c[r >> 2] | 0) ? (c[s >> 2] | 0) == (c[p >> 2] | 0) : 0) {
	                    c[e >> 2] = 0;
	                    t = c[e >> 2] | 0;
	                    i = d;
	                    return t | 0
	                }
	                if ((c[s >> 2] | 0) < (c[p >> 2] | 0)) {
	                    c[e >> 2] = 0 - (c[n >> 2] | 0);
	                    t = c[e >> 2] | 0;
	                    i = d;
	                    return t | 0
	                }
	                if ((c[r >> 2] | 0) > (c[p >> 2] | 0)) {
	                    c[e >> 2] = c[n >> 2];
	                    t = c[e >> 2] | 0;
	                    i = d;
	                    return t | 0
	                } else {
	                    c[e >> 2] = 2;
	                    t = c[e >> 2] | 0;
	                    i = d;
	                    return t | 0
	                }
	                return 0
	            }

	            function xI(e, f) {
	                e = e | 0;
	                f = f | 0;
	                var g = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0;
	                g = i;
	                i = i + 96 | 0;
	                j = g + 76 | 0;
	                k = g + 72 | 0;
	                l = g + 68 | 0;
	                m = g + 83 | 0;
	                n = g + 82 | 0;
	                o = g + 81 | 0;
	                p = g + 80 | 0;
	                q = g + 64 | 0;
	                r = g + 60 | 0;
	                s = g + 56 | 0;
	                t = g + 52 | 0;
	                u = g + 48 | 0;
	                v = g + 44 | 0;
	                w = g + 40 | 0;
	                x = g + 36 | 0;
	                y = g + 16 | 0;
	                z = g + 32 | 0;
	                A = g + 8 | 0;
	                B = g + 28 | 0;
	                C = g + 24 | 0;
	                D = g;
	                c[k >> 2] = e;
	                c[l >> 2] = f;
	                if ((c[k >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0) {
	                    c[j >> 2] = -2;
	                    E = c[j >> 2] | 0;
	                    i = g;
	                    return E | 0
	                }
	                f = (b[(c[l >> 2] | 0) + 24 >> 1] & 1 | 0) != 0;
	                do if (b[(c[k >> 2] | 0) + 24 >> 1] & 1) {
	                    if (!f) {
	                        c[q >> 2] = nI(c[k >> 2] | 0, 0.0) | 0;
	                        e = MI(c[q >> 2] | 0) | 0;
	                        c[u >> 2] = e + ((c[(c[q >> 2] | 0) + 12 >> 2] | 0) >>> 4 & 31);
	                        c[s >> 2] = nI(c[l >> 2] | 0, 50400.0) | 0;
	                        e = MI(c[s >> 2] | 0) | 0;
	                        c[w >> 2] = e + ((c[(c[s >> 2] | 0) + 12 >> 2] | 0) >>> 4 & 31);
	                        if ((c[u >> 2] | 0) < (c[w >> 2] | 0)) {
	                            PH(c[q >> 2] | 0);
	                            PH(c[s >> 2] | 0);
	                            c[j >> 2] = -1;
	                            E = c[j >> 2] | 0;
	                            i = g;
	                            return E | 0
	                        }
	                        e = c[q >> 2] | 0;
	                        if ((c[u >> 2] | 0) != (c[w >> 2] | 0)) {
	                            PH(e);
	                            PH(c[s >> 2] | 0);
	                            break
	                        }
	                        h[y >> 3] = +((((c[e + 12 >> 2] | 0) >>> 9 & 31) * 3600 | 0) + (((c[(c[q >> 2] | 0) + 12 >> 2] | 0) >>> 14 & 63) * 60 | 0) + (((b[(c[q >> 2] | 0) + 24 >> 1] << 3 & 65535) << 16 >> 16 >> 4 << 16 >> 16) * 60 | 0) | 0) + +h[(c[q >> 2] | 0) + 16 >> 3] - (+((((c[(c[s >> 2] | 0) + 12 >> 2] | 0) >>> 9 & 31) * 3600 | 0) + (((c[(c[s >> 2] | 0) + 12 >> 2] | 0) >>> 14 & 63) * 60 | 0) + (((b[(c[s >> 2] | 0) + 24 >> 1] << 3 & 65535) << 16 >> 16 >> 4 << 16 >> 16) * 60 | 0) | 0) + +h[(c[s >> 2] | 0) + 16 >> 3]);
	                        if (+h[y >> 3] < 0.0) {
	                            PH(c[q >> 2] | 0);
	                            PH(c[s >> 2] | 0);
	                            c[j >> 2] = -1;
	                            E = c[j >> 2] | 0;
	                            i = g;
	                            return E | 0
	                        }
	                        c[z >> 2] = 0;
	                        c[t >> 2] = nI(c[l >> 2] | 0, -50400.0) | 0;
	                        e = MI(c[t >> 2] | 0) | 0;
	                        c[x >> 2] = e + ((c[(c[t >> 2] | 0) + 12 >> 2] | 0) >>> 4 & 31);
	                        do if ((c[u >> 2] | 0) <= (c[x >> 2] | 0)) {
	                            if ((c[u >> 2] | 0) == (c[x >> 2] | 0)) {
	                                h[y >> 3] = +((((c[(c[q >> 2] | 0) + 12 >> 2] | 0) >>> 9 & 31) * 3600 | 0) + (((c[(c[q >> 2] | 0) + 12 >> 2] | 0) >>> 14 & 63) * 60 | 0) + (((b[(c[q >> 2] | 0) + 24 >> 1] << 3 & 65535) << 16 >> 16 >> 4 << 16 >> 16) * 60 | 0) | 0) + +h[(c[q >> 2] | 0) + 16 >> 3] - (+((((c[(c[t >> 2] | 0) + 12 >> 2] | 0) >>> 9 & 31) * 3600 | 0) + (((c[(c[t >> 2] | 0) + 12 >> 2] | 0) >>> 14 & 63) * 60 | 0) + (((b[(c[t >> 2] | 0) + 24 >> 1] << 3 & 65535) << 16 >> 16 >> 4 << 16 >> 16) * 60 | 0) | 0) + +h[(c[t >> 2] | 0) + 16 >> 3]);
	                                if (+h[y >> 3] > 0.0) {
	                                    c[z >> 2] = 1;
	                                    break
	                                } else {
	                                    c[z >> 2] = 2;
	                                    break
	                                }
	                            }
	                        } else c[z >> 2] = 1; while (0);
	                        PH(c[q >> 2] | 0);
	                        PH(c[s >> 2] | 0);
	                        PH(c[t >> 2] | 0);
	                        if (c[z >> 2] | 0) {
	                            c[j >> 2] = c[z >> 2];
	                            E = c[j >> 2] | 0;
	                            i = g;
	                            return E | 0
	                        }
	                    }
	                } else if (f) {
	                    c[s >> 2] = nI(c[l >> 2] | 0, 0.0) | 0;
	                    e = MI(c[s >> 2] | 0) | 0;
	                    c[w >> 2] = e + ((c[(c[s >> 2] | 0) + 12 >> 2] | 0) >>> 4 & 31);
	                    c[q >> 2] = nI(c[k >> 2] | 0, -50400.0) | 0;
	                    e = MI(c[q >> 2] | 0) | 0;
	                    c[u >> 2] = e + ((c[(c[q >> 2] | 0) + 12 >> 2] | 0) >>> 4 & 31);
	                    if ((c[u >> 2] | 0) < (c[w >> 2] | 0)) {
	                        PH(c[q >> 2] | 0);
	                        PH(c[s >> 2] | 0);
	                        c[j >> 2] = -1;
	                        E = c[j >> 2] | 0;
	                        i = g;
	                        return E | 0
	                    }
	                    e = c[q >> 2] | 0;
	                    if ((c[u >> 2] | 0) != (c[w >> 2] | 0)) {
	                        PH(e);
	                        PH(c[s >> 2] | 0);
	                        break
	                    }
	                    h[A >> 3] = +((((c[e + 12 >> 2] | 0) >>> 9 & 31) * 3600 | 0) + (((c[(c[q >> 2] | 0) + 12 >> 2] | 0) >>> 14 & 63) * 60 | 0) + (((b[(c[q >> 2] | 0) + 24 >> 1] << 3 & 65535) << 16 >> 16 >> 4 << 16 >> 16) * 60 | 0) | 0) + +h[(c[q >> 2] | 0) + 16 >> 3] - (+((((c[(c[s >> 2] | 0) + 12 >> 2] | 0) >>> 9 & 31) * 3600 | 0) + (((c[(c[s >> 2] | 0) + 12 >> 2] | 0) >>> 14 & 63) * 60 | 0) + (((b[(c[s >> 2] | 0) + 24 >> 1] << 3 & 65535) << 16 >> 16 >> 4 << 16 >> 16) * 60 | 0) | 0) + +h[(c[s >> 2] | 0) + 16 >> 3]);
	                    if (+h[A >> 3] < 0.0) {
	                        PH(c[q >> 2] | 0);
	                        PH(c[s >> 2] | 0);
	                        c[j >> 2] = -1;
	                        E = c[j >> 2] | 0;
	                        i = g;
	                        return E | 0
	                    }
	                    c[B >> 2] = 0;
	                    c[r >> 2] = nI(c[k >> 2] | 0, 50400.0) | 0;
	                    e = MI(c[r >> 2] | 0) | 0;
	                    c[v >> 2] = e + ((c[(c[r >> 2] | 0) + 12 >> 2] | 0) >>> 4 & 31);
	                    do if ((c[v >> 2] | 0) <= (c[w >> 2] | 0)) {
	                        if ((c[v >> 2] | 0) == (c[w >> 2] | 0)) {
	                            h[A >> 3] = +((((c[(c[r >> 2] | 0) + 12 >> 2] | 0) >>> 9 & 31) * 3600 | 0) + (((c[(c[r >> 2] | 0) + 12 >> 2] | 0) >>> 14 & 63) * 60 | 0) + (((b[(c[r >> 2] | 0) + 24 >> 1] << 3 & 65535) << 16 >> 16 >> 4 << 16 >> 16) * 60 | 0) | 0) + +h[(c[r >> 2] | 0) + 16 >> 3] - (+((((c[(c[s >> 2] | 0) + 12 >> 2] | 0) >>> 9 & 31) * 3600 | 0) + (((c[(c[s >> 2] | 0) + 12 >> 2] | 0) >>> 14 & 63) * 60 | 0) + (((b[(c[s >> 2] | 0) + 24 >> 1] << 3 & 65535) << 16 >> 16 >> 4 << 16 >> 16) * 60 | 0) | 0) + +h[(c[s >> 2] | 0) + 16 >> 3]);
	                            if (+h[A >> 3] > 0.0) {
	                                c[B >> 2] = 1;
	                                break
	                            } else {
	                                c[B >> 2] = 2;
	                                break
	                            }
	                        }
	                    } else c[B >> 2] = 1; while (0);
	                    PH(c[q >> 2] | 0);
	                    PH(c[s >> 2] | 0);
	                    PH(c[r >> 2] | 0);
	                    if (c[B >> 2] | 0) {
	                        c[j >> 2] = c[B >> 2];
	                        E = c[j >> 2] | 0;
	                        i = g;
	                        return E | 0
	                    }
	                } while (0);
	                if ((c[c[k >> 2] >> 2] | 0) == (c[c[l >> 2] >> 2] | 0)) {
	                    c[C >> 2] = 0;
	                    c[s >> 2] = nI(c[l >> 2] | 0, 0.0) | 0;
	                    B = MI(c[s >> 2] | 0) | 0;
	                    c[w >> 2] = B + ((c[(c[s >> 2] | 0) + 12 >> 2] | 0) >>> 4 & 31);
	                    c[q >> 2] = nI(c[k >> 2] | 0, 0.0) | 0;
	                    B = MI(c[q >> 2] | 0) | 0;
	                    c[u >> 2] = B + ((c[(c[q >> 2] | 0) + 12 >> 2] | 0) >>> 4 & 31);
	                    do if ((c[u >> 2] | 0) >= (c[w >> 2] | 0)) {
	                        if ((c[u >> 2] | 0) > (c[w >> 2] | 0)) {
	                            c[C >> 2] = 1;
	                            break
	                        }
	                        h[D >> 3] = +((((c[(c[q >> 2] | 0) + 12 >> 2] | 0) >>> 9 & 31) * 3600 | 0) + (((c[(c[q >> 2] | 0) + 12 >> 2] | 0) >>> 14 & 63) * 60 | 0) + (((b[(c[q >> 2] | 0) + 24 >> 1] << 3 & 65535) << 16 >> 16 >> 4 << 16 >> 16) * 60 | 0) | 0) + +h[(c[q >> 2] | 0) + 16 >> 3] - (+((((c[(c[s >> 2] | 0) + 12 >> 2] | 0) >>> 9 & 31) * 3600 | 0) + (((c[(c[s >> 2] | 0) + 12 >> 2] | 0) >>> 14 & 63) * 60 | 0) + (((b[(c[s >> 2] | 0) + 24 >> 1] << 3 & 65535) << 16 >> 16 >> 4 << 16 >> 16) * 60 | 0) | 0) + +h[(c[s >> 2] | 0) + 16 >> 3]);
	                        if (+h[D >> 3] < 0.0) {
	                            c[C >> 2] = -1;
	                            break
	                        }
	                        if (+h[D >> 3] > 0.0)c[C >> 2] = 1
	                    } else c[C >> 2] = -1; while (0);
	                    PH(c[q >> 2] | 0);
	                    PH(c[s >> 2] | 0);
	                    c[j >> 2] = c[C >> 2];
	                    E = c[j >> 2] | 0;
	                    i = g;
	                    return E | 0
	                }
	                switch (c[c[k >> 2] >> 2] | 0) {
	                    case 6:
	                    {
	                        a[m >> 0] = 2;
	                        break
	                    }
	                    case 5:
	                    {
	                        a[m >> 0] = 3;
	                        break
	                    }
	                    case 9:
	                    {
	                        a[m >> 0] = 3;
	                        break
	                    }
	                    case 7:
	                    {
	                        a[m >> 0] = 6;
	                        break
	                    }
	                    case 4:
	                    {
	                        a[m >> 0] = 8;
	                        break
	                    }
	                    case 11:
	                    {
	                        a[m >> 0] = 15;
	                        break
	                    }
	                    case 10:
	                    {
	                        a[m >> 0] = 7;
	                        break
	                    }
	                    case 8:
	                    {
	                        a[m >> 0] = 1;
	                        break
	                    }
	                    default:
	                        a[m >> 0] = 0
	                }
	                switch (c[c[l >> 2] >> 2] | 0) {
	                    case 11:
	                    {
	                        a[n >> 0] = 15;
	                        break
	                    }
	                    case 10:
	                    {
	                        a[n >> 0] = 7;
	                        break
	                    }
	                    case 8:
	                    {
	                        a[n >> 0] = 1;
	                        break
	                    }
	                    case 6:
	                    {
	                        a[n >> 0] = 2;
	                        break
	                    }
	                    case 5:
	                    {
	                        a[n >> 0] = 3;
	                        break
	                    }
	                    case 9:
	                    {
	                        a[n >> 0] = 3;
	                        break
	                    }
	                    case 7:
	                    {
	                        a[n >> 0] = 6;
	                        break
	                    }
	                    case 4:
	                    {
	                        a[n >> 0] = 8;
	                        break
	                    }
	                    default:
	                        a[n >> 0] = 0
	                }
	                a[o >> 0] = (d[m >> 0] | 0) ^ (d[n >> 0] | 0);
	                a[p >> 0] = (d[m >> 0] | 0) & (d[n >> 0] | 0);
	                if ((d[o >> 0] | 0) & 1) {
	                    c[j >> 2] = 2;
	                    E = c[j >> 2] | 0;
	                    i = g;
	                    return E | 0
	                }
	                if ((d[p >> 0] | 0) & 1) {
	                    if ((c[(c[k >> 2] | 0) + 8 >> 2] | 0) < (c[(c[l >> 2] | 0) + 8 >> 2] | 0)) {
	                        c[j >> 2] = -1;
	                        E = c[j >> 2] | 0;
	                        i = g;
	                        return E | 0
	                    }
	                    if ((c[(c[k >> 2] | 0) + 8 >> 2] | 0) > (c[(c[l >> 2] | 0) + 8 >> 2] | 0)) {
	                        c[j >> 2] = 1;
	                        E = c[j >> 2] | 0;
	                        i = g;
	                        return E | 0
	                    }
	                }
	                if ((d[o >> 0] | 0) & 2) {
	                    c[j >> 2] = 2;
	                    E = c[j >> 2] | 0;
	                    i = g;
	                    return E | 0
	                }
	                if ((d[p >> 0] | 0) & 2) {
	                    if ((c[(c[k >> 2] | 0) + 12 >> 2] & 15 | 0) < (c[(c[l >> 2] | 0) + 12 >> 2] & 15 | 0)) {
	                        c[j >> 2] = -1;
	                        E = c[j >> 2] | 0;
	                        i = g;
	                        return E | 0
	                    }
	                    if ((c[(c[k >> 2] | 0) + 12 >> 2] & 15 | 0) > (c[(c[l >> 2] | 0) + 12 >> 2] & 15 | 0)) {
	                        c[j >> 2] = 1;
	                        E = c[j >> 2] | 0;
	                        i = g;
	                        return E | 0
	                    }
	                }
	                if ((d[o >> 0] | 0) & 4) {
	                    c[j >> 2] = 2;
	                    E = c[j >> 2] | 0;
	                    i = g;
	                    return E | 0
	                }
	                if ((d[p >> 0] | 0) & 4) {
	                    if (((c[(c[k >> 2] | 0) + 12 >> 2] | 0) >>> 4 & 31 | 0) < ((c[(c[l >> 2] | 0) + 12 >> 2] | 0) >>> 4 & 31 | 0)) {
	                        c[j >> 2] = -1;
	                        E = c[j >> 2] | 0;
	                        i = g;
	                        return E | 0
	                    }
	                    if (((c[(c[k >> 2] | 0) + 12 >> 2] | 0) >>> 4 & 31 | 0) > ((c[(c[l >> 2] | 0) + 12 >> 2] | 0) >>> 4 & 31 | 0)) {
	                        c[j >> 2] = 1;
	                        E = c[j >> 2] | 0;
	                        i = g;
	                        return E | 0
	                    }
	                }
	                if ((d[o >> 0] | 0) & 8) {
	                    c[j >> 2] = 2;
	                    E = c[j >> 2] | 0;
	                    i = g;
	                    return E | 0
	                }
	                if ((d[p >> 0] | 0) & 8) {
	                    if (((c[(c[k >> 2] | 0) + 12 >> 2] | 0) >>> 9 & 31 | 0) < ((c[(c[l >> 2] | 0) + 12 >> 2] | 0) >>> 9 & 31 | 0)) {
	                        c[j >> 2] = -1;
	                        E = c[j >> 2] | 0;
	                        i = g;
	                        return E | 0
	                    }
	                    if (((c[(c[k >> 2] | 0) + 12 >> 2] | 0) >>> 9 & 31 | 0) > ((c[(c[l >> 2] | 0) + 12 >> 2] | 0) >>> 9 & 31 | 0)) {
	                        c[j >> 2] = 1;
	                        E = c[j >> 2] | 0;
	                        i = g;
	                        return E | 0
	                    }
	                    if (((c[(c[k >> 2] | 0) + 12 >> 2] | 0) >>> 14 & 63 | 0) < ((c[(c[l >> 2] | 0) + 12 >> 2] | 0) >>> 14 & 63 | 0)) {
	                        c[j >> 2] = -1;
	                        E = c[j >> 2] | 0;
	                        i = g;
	                        return E | 0
	                    }
	                    if (((c[(c[k >> 2] | 0) + 12 >> 2] | 0) >>> 14 & 63 | 0) > ((c[(c[l >> 2] | 0) + 12 >> 2] | 0) >>> 14 & 63 | 0)) {
	                        c[j >> 2] = 1;
	                        E = c[j >> 2] | 0;
	                        i = g;
	                        return E | 0
	                    }
	                    if (+h[(c[k >> 2] | 0) + 16 >> 3] < +h[(c[l >> 2] | 0) + 16 >> 3]) {
	                        c[j >> 2] = -1;
	                        E = c[j >> 2] | 0;
	                        i = g;
	                        return E | 0
	                    }
	                    if (+h[(c[k >> 2] | 0) + 16 >> 3] > +h[(c[l >> 2] | 0) + 16 >> 3]) {
	                        c[j >> 2] = 1;
	                        E = c[j >> 2] | 0;
	                        i = g;
	                        return E | 0
	                    }
	                }
	                c[j >> 2] = 0;
	                E = c[j >> 2] | 0;
	                i = g;
	                return E | 0
	            }

	            function yI(a, b, e) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                while (1) {
	                    if (!(d[c[h >> 2] >> 0] | 0)) {
	                        m = 24;
	                        break
	                    }
	                    if (!(d[c[j >> 2] >> 0] | 0)) {
	                        m = 24;
	                        break
	                    }
	                    if (((d[c[j >> 2] >> 0] | 0 | 0) != 9 ? (d[c[j >> 2] >> 0] | 0 | 0) != 10 : 0) ? (d[c[j >> 2] >> 0] | 0 | 0) != 13 : 0) {
	                        c[l >> 2] = (d[c[h >> 2] >> 0] | 0) - (d[c[j >> 2] >> 0] | 0);
	                        if ((c[l >> 2] | 0) < 0) {
	                            m = 16;
	                            break
	                        }
	                        if ((c[l >> 2] | 0) > 0) {
	                            m = 20;
	                            break
	                        }
	                    } else m = 7;
	                    if ((m | 0) == 7 ? (m = 0, (d[c[h >> 2] >> 0] | 0 | 0) != 32) : 0) {
	                        m = 8;
	                        break
	                    }
	                    c[h >> 2] = (c[h >> 2] | 0) + 1;
	                    c[j >> 2] = (c[j >> 2] | 0) + 1
	                }
	                do if ((m | 0) == 8) {
	                    l = (c[k >> 2] | 0) != 0;
	                    if (((d[c[h >> 2] >> 0] | 0) - 32 | 0) < 0)if (l) {
	                        c[g >> 2] = 1;
	                        break
	                    } else {
	                        c[g >> 2] = -1;
	                        break
	                    } else if (l) {
	                        c[g >> 2] = -1;
	                        break
	                    } else {
	                        c[g >> 2] = 1;
	                        break
	                    }
	                } else if ((m | 0) == 16)if (c[k >> 2] | 0) {
	                    c[g >> 2] = 1;
	                    break
	                } else {
	                    c[g >> 2] = -1;
	                    break
	                } else if ((m | 0) == 20)if (c[k >> 2] | 0) {
	                    c[g >> 2] = -1;
	                    break
	                } else {
	                    c[g >> 2] = 1;
	                    break
	                } else if ((m | 0) == 24) {
	                    if (d[c[h >> 2] >> 0] | 0)if (c[k >> 2] | 0) {
	                        c[g >> 2] = -1;
	                        break
	                    } else {
	                        c[g >> 2] = 1;
	                        break
	                    }
	                    if (!(d[c[j >> 2] >> 0] | 0)) {
	                        c[g >> 2] = 0;
	                        break
	                    }
	                    if (c[k >> 2] | 0) {
	                        c[g >> 2] = 1;
	                        break
	                    } else {
	                        c[g >> 2] = -1;
	                        break
	                    }
	                } while (0);
	                i = f;
	                return c[g >> 2] | 0
	            }

	            function zI(a, b, e) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                a:while (1) {
	                    do if ((d[c[j >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[j >> 2] >> 0] | 0 | 0) ? (d[c[j >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[j >> 2] >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    c[j >> 2] = (c[j >> 2] | 0) + 1
	                }
	                b:while (1) {
	                    if (!(d[c[h >> 2] >> 0] | 0)) {
	                        m = 35;
	                        break
	                    }
	                    if (!(d[c[j >> 2] >> 0] | 0)) {
	                        m = 35;
	                        break
	                    }
	                    do if ((d[c[j >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[j >> 2] >> 0] | 0 | 0) ? (d[c[j >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[j >> 2] >> 0] | 0 | 0) != 13) {
	                            e = c[h >> 2] | 0;
	                            c[h >> 2] = e + 1;
	                            b = d[e >> 0] | 0;
	                            e = c[j >> 2] | 0;
	                            c[j >> 2] = e + 1;
	                            c[l >> 2] = b - (d[e >> 0] | 0);
	                            if ((c[l >> 2] | 0) < 0) {
	                                m = 28;
	                                break b
	                            }
	                            if ((c[l >> 2] | 0) > 0) {
	                                m = 32;
	                                break b
	                            } else continue b
	                        }
	                    } while (0);
	                    n = c[h >> 2] | 0;
	                    if ((d[c[h >> 2] >> 0] | 0 | 0) != 32) {
	                        m = 14;
	                        break
	                    }
	                    c[h >> 2] = n + 1;
	                    c[j >> 2] = (c[j >> 2] | 0) + 1;
	                    while (1) {
	                        do if ((d[c[j >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[j >> 2] >> 0] | 0 | 0) ? (d[c[j >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[j >> 2] >> 0] | 0 | 0) != 13)continue b
	                        } while (0);
	                        c[j >> 2] = (c[j >> 2] | 0) + 1
	                    }
	                }
	                do if ((m | 0) == 14) {
	                    l = (c[k >> 2] | 0) != 0;
	                    if (((d[n >> 0] | 0) - 32 | 0) < 0)if (l) {
	                        c[g >> 2] = 1;
	                        break
	                    } else {
	                        c[g >> 2] = -1;
	                        break
	                    } else if (l) {
	                        c[g >> 2] = -1;
	                        break
	                    } else {
	                        c[g >> 2] = 1;
	                        break
	                    }
	                } else if ((m | 0) == 28)if (c[k >> 2] | 0) {
	                    c[g >> 2] = 1;
	                    break
	                } else {
	                    c[g >> 2] = -1;
	                    break
	                } else if ((m | 0) == 32)if (c[k >> 2] | 0) {
	                    c[g >> 2] = -1;
	                    break
	                } else {
	                    c[g >> 2] = 1;
	                    break
	                } else if ((m | 0) == 35) {
	                    if (d[c[h >> 2] >> 0] | 0)if (c[k >> 2] | 0) {
	                        c[g >> 2] = -1;
	                        break
	                    } else {
	                        c[g >> 2] = 1;
	                        break
	                    }
	                    if (d[c[j >> 2] >> 0] | 0) {
	                        while (1) {
	                            do if ((d[c[j >> 2] >> 0] | 0 | 0) == 32)o = 1; else {
	                                if (9 <= (d[c[j >> 2] >> 0] | 0 | 0) ? (d[c[j >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                    o = 1;
	                                    break
	                                }
	                                o = (d[c[j >> 2] >> 0] | 0 | 0) == 13
	                            } while (0);
	                            p = c[j >> 2] | 0;
	                            if (!o)break;
	                            c[j >> 2] = p + 1
	                        }
	                        if (d[p >> 0] | 0)if (c[k >> 2] | 0) {
	                            c[g >> 2] = 1;
	                            break
	                        } else {
	                            c[g >> 2] = -1;
	                            break
	                        }
	                    }
	                    c[g >> 2] = 0
	                } while (0);
	                i = f;
	                return c[g >> 2] | 0
	            }

	            function AI(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                a:while (1) {
	                    if (!(d[c[g >> 2] >> 0] | 0)) {
	                        k = 27;
	                        break
	                    }
	                    if (!(d[c[h >> 2] >> 0] | 0)) {
	                        k = 27;
	                        break
	                    }
	                    do if ((d[c[h >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[h >> 2] >> 0] | 0 | 0) ? (d[c[h >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            k = 8;
	                            break
	                        }
	                        if ((d[c[h >> 2] >> 0] | 0 | 0) != 13) {
	                            if ((d[c[g >> 2] >> 0] | 0 | 0) == 32) {
	                                k = 19;
	                                break a
	                            }
	                            if (9 <= (d[c[g >> 2] >> 0] | 0 | 0) ? (d[c[g >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                k = 19;
	                                break a
	                            }
	                            if ((d[c[g >> 2] >> 0] | 0 | 0) == 13) {
	                                k = 19;
	                                break a
	                            }
	                            c[j >> 2] = (d[c[g >> 2] >> 0] | 0) - (d[c[h >> 2] >> 0] | 0);
	                            if ((c[j >> 2] | 0) < 0) {
	                                k = 23;
	                                break a
	                            }
	                            if ((c[j >> 2] | 0) > 0) {
	                                k = 25;
	                                break a
	                            }
	                        } else k = 8
	                    } else k = 8; while (0);
	                    do if ((k | 0) == 8 ? (k = 0, (d[c[g >> 2] >> 0] | 0 | 0) != 32) : 0) {
	                        if (9 <= (d[c[g >> 2] >> 0] | 0 | 0) ? (d[c[g >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[g >> 2] >> 0] | 0 | 0) != 13) {
	                            k = 12;
	                            break a
	                        }
	                    } while (0);
	                    c[g >> 2] = (c[g >> 2] | 0) + 1;
	                    c[h >> 2] = (c[h >> 2] | 0) + 1
	                }
	                if ((k | 0) == 12)if (((d[c[g >> 2] >> 0] | 0) - 32 | 0) < 0) {
	                    c[f >> 2] = -1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } else {
	                    c[f >> 2] = 1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } else if ((k | 0) == 19)if ((32 - (d[c[h >> 2] >> 0] | 0) | 0) < 0) {
	                    c[f >> 2] = -1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } else {
	                    c[f >> 2] = 1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } else if ((k | 0) == 23) {
	                    c[f >> 2] = -1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } else if ((k | 0) == 25) {
	                    c[f >> 2] = 1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } else if ((k | 0) == 27) {
	                    if (d[c[g >> 2] >> 0] | 0) {
	                        c[f >> 2] = 1;
	                        l = c[f >> 2] | 0;
	                        i = e;
	                        return l | 0
	                    }
	                    if (d[c[h >> 2] >> 0] | 0) {
	                        c[f >> 2] = -1;
	                        l = c[f >> 2] | 0;
	                        i = e;
	                        return l | 0
	                    } else {
	                        c[f >> 2] = 0;
	                        l = c[f >> 2] | 0;
	                        i = e;
	                        return l | 0
	                    }
	                }
	                return 0
	            }

	            function BI(a, b, e) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                a:while (1) {
	                    do if ((d[c[j >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[j >> 2] >> 0] | 0 | 0) ? (d[c[j >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[j >> 2] >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    c[j >> 2] = (c[j >> 2] | 0) + 1
	                }
	                b:while (1) {
	                    if (!(d[c[h >> 2] >> 0] | 0)) {
	                        m = 45;
	                        break
	                    }
	                    if (!(d[c[j >> 2] >> 0] | 0)) {
	                        m = 45;
	                        break
	                    }
	                    do if ((d[c[j >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[j >> 2] >> 0] | 0 | 0) ? (d[c[j >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[j >> 2] >> 0] | 0 | 0) != 13) {
	                            if ((d[c[h >> 2] >> 0] | 0 | 0) == 32) {
	                                m = 34;
	                                break b
	                            }
	                            if (9 <= (d[c[h >> 2] >> 0] | 0 | 0) ? (d[c[h >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                m = 34;
	                                break b
	                            }
	                            if ((d[c[h >> 2] >> 0] | 0 | 0) == 13) {
	                                m = 34;
	                                break b
	                            }
	                            e = c[h >> 2] | 0;
	                            c[h >> 2] = e + 1;
	                            b = d[e >> 0] | 0;
	                            e = c[j >> 2] | 0;
	                            c[j >> 2] = e + 1;
	                            c[l >> 2] = b - (d[e >> 0] | 0);
	                            if ((c[l >> 2] | 0) < 0) {
	                                m = 42;
	                                break b
	                            }
	                            if ((c[l >> 2] | 0) > 0) {
	                                m = 44;
	                                break b
	                            } else continue b
	                        }
	                    } while (0);
	                    do if ((d[c[h >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[h >> 2] >> 0] | 0 | 0) ? (d[c[h >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[h >> 2] >> 0] | 0 | 0) != 13) {
	                            m = 17;
	                            break b
	                        }
	                    } while (0);
	                    c[h >> 2] = (c[h >> 2] | 0) + 1;
	                    c[j >> 2] = (c[j >> 2] | 0) + 1;
	                    while (1) {
	                        do if ((d[c[j >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[j >> 2] >> 0] | 0 | 0) ? (d[c[j >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[j >> 2] >> 0] | 0 | 0) != 13)continue b
	                        } while (0);
	                        c[j >> 2] = (c[j >> 2] | 0) + 1
	                    }
	                }
	                if ((m | 0) == 17) {
	                    l = (c[k >> 2] | 0) != 0;
	                    if (((d[c[h >> 2] >> 0] | 0) - 32 | 0) < 0)if (l) {
	                        c[g >> 2] = 1;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    } else {
	                        c[g >> 2] = -1;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    } else if (l) {
	                        c[g >> 2] = -1;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    } else {
	                        c[g >> 2] = 1;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                } else if ((m | 0) == 34) {
	                    l = (c[k >> 2] | 0) != 0;
	                    if ((32 - (d[c[j >> 2] >> 0] | 0) | 0) < 0)if (l) {
	                        c[g >> 2] = 1;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    } else {
	                        c[g >> 2] = -1;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    } else if (l) {
	                        c[g >> 2] = -1;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    } else {
	                        c[g >> 2] = 1;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                } else if ((m | 0) == 42) {
	                    c[g >> 2] = -1;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                } else if ((m | 0) == 44) {
	                    c[g >> 2] = 1;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                } else if ((m | 0) == 45) {
	                    if (d[c[h >> 2] >> 0] | 0)if (c[k >> 2] | 0) {
	                        c[g >> 2] = -1;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    } else {
	                        c[g >> 2] = 1;
	                        n = c[g >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    if (d[c[j >> 2] >> 0] | 0) {
	                        while (1) {
	                            do if ((d[c[j >> 2] >> 0] | 0 | 0) == 32)o = 1; else {
	                                if (9 <= (d[c[j >> 2] >> 0] | 0 | 0) ? (d[c[j >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                    o = 1;
	                                    break
	                                }
	                                o = (d[c[j >> 2] >> 0] | 0 | 0) == 13
	                            } while (0);
	                            p = c[j >> 2] | 0;
	                            if (!o)break;
	                            c[j >> 2] = p + 1
	                        }
	                        if (d[p >> 0] | 0)if (c[k >> 2] | 0) {
	                            c[g >> 2] = 1;
	                            n = c[g >> 2] | 0;
	                            i = f;
	                            return n | 0
	                        } else {
	                            c[g >> 2] = -1;
	                            n = c[g >> 2] | 0;
	                            i = f;
	                            return n | 0
	                        }
	                    }
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                return 0
	            }

	            function CI(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                a:while (1) {
	                    do if ((d[c[g >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[g >> 2] >> 0] | 0 | 0) ? (d[c[g >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[g >> 2] >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    c[g >> 2] = (c[g >> 2] | 0) + 1
	                }
	                b:while (1) {
	                    do if ((d[c[h >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[h >> 2] >> 0] | 0 | 0) ? (d[c[h >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[h >> 2] >> 0] | 0 | 0) != 13)break b
	                    } while (0);
	                    c[h >> 2] = (c[h >> 2] | 0) + 1
	                }
	                c:while (1) {
	                    if (d[c[g >> 2] >> 0] | 0)k = (d[c[h >> 2] >> 0] | 0 | 0) != 0; else k = 0;
	                    l = d[c[g >> 2] >> 0] | 0;
	                    if (!k) {
	                        m = 38;
	                        break
	                    }
	                    do if ((l | 0) != 32) {
	                        if (9 <= (d[c[g >> 2] >> 0] | 0 | 0) ? (d[c[g >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[g >> 2] >> 0] | 0 | 0) != 13) {
	                            b = c[g >> 2] | 0;
	                            c[g >> 2] = b + 1;
	                            a = d[b >> 0] | 0;
	                            b = c[h >> 2] | 0;
	                            c[h >> 2] = b + 1;
	                            c[j >> 2] = a - (d[b >> 0] | 0);
	                            if ((c[j >> 2] | 0) < 0) {
	                                m = 35;
	                                break c
	                            }
	                            if ((c[j >> 2] | 0) > 0) {
	                                m = 37;
	                                break c
	                            } else continue c
	                        }
	                    } while (0);
	                    do if ((d[c[h >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[h >> 2] >> 0] | 0 | 0) ? (d[c[h >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[h >> 2] >> 0] | 0 | 0) != 13) {
	                            m = 23;
	                            break c
	                        }
	                    } while (0);
	                    d:while (1) {
	                        do if ((d[c[g >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[g >> 2] >> 0] | 0 | 0) ? (d[c[g >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[g >> 2] >> 0] | 0 | 0) != 13)break d
	                        } while (0);
	                        c[g >> 2] = (c[g >> 2] | 0) + 1
	                    }
	                    while (1) {
	                        do if ((d[c[h >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[h >> 2] >> 0] | 0 | 0) ? (d[c[h >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[h >> 2] >> 0] | 0 | 0) != 13)continue c
	                        } while (0);
	                        c[h >> 2] = (c[h >> 2] | 0) + 1
	                    }
	                }
	                if ((m | 0) == 23) {
	                    c[j >> 2] = (d[c[g >> 2] >> 0] | 0) - (d[c[h >> 2] >> 0] | 0);
	                    c[f >> 2] = c[j >> 2];
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                } else if ((m | 0) == 35) {
	                    c[f >> 2] = -1;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                } else if ((m | 0) == 37) {
	                    c[f >> 2] = 1;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                } else if ((m | 0) == 38) {
	                    if (l) {
	                        while (1) {
	                            do if ((d[c[g >> 2] >> 0] | 0 | 0) == 32)o = 1; else {
	                                if (9 <= (d[c[g >> 2] >> 0] | 0 | 0) ? (d[c[g >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                    o = 1;
	                                    break
	                                }
	                                o = (d[c[g >> 2] >> 0] | 0 | 0) == 13
	                            } while (0);
	                            p = c[g >> 2] | 0;
	                            if (!o)break;
	                            c[g >> 2] = p + 1
	                        }
	                        if (d[p >> 0] | 0) {
	                            c[f >> 2] = 1;
	                            n = c[f >> 2] | 0;
	                            i = e;
	                            return n | 0
	                        }
	                    }
	                    if (d[c[h >> 2] >> 0] | 0) {
	                        while (1) {
	                            do if ((d[c[h >> 2] >> 0] | 0 | 0) == 32)q = 1; else {
	                                if (9 <= (d[c[h >> 2] >> 0] | 0 | 0) ? (d[c[h >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                    q = 1;
	                                    break
	                                }
	                                q = (d[c[h >> 2] >> 0] | 0 | 0) == 13
	                            } while (0);
	                            r = c[h >> 2] | 0;
	                            if (!q)break;
	                            c[h >> 2] = r + 1
	                        }
	                        if (d[r >> 0] | 0) {
	                            c[f >> 2] = -1;
	                            n = c[f >> 2] | 0;
	                            i = e;
	                            return n | 0
	                        }
	                    }
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                return 0
	            }

	            function DI(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 24 | 0;
	                f = d + 20 | 0;
	                j = d + 16 | 0;
	                k = d + 8 | 0;
	                l = d;
	                c[f >> 2] = a;
	                c[j >> 2] = b;
	                a:do if (!((c[f >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0)) {
	                    b = c[f >> 2] | 0;
	                    do if ((c[c[f >> 2] >> 2] | 0) != 14)if ((c[b >> 2] | 0) == 13) {
	                        h[k >> 3] = +g[(c[f >> 2] | 0) + 8 >> 2];
	                        break
	                    } else {
	                        c[e >> 2] = -2;
	                        break a
	                    } else h[k >> 3] = +h[b + 8 >> 3]; while (0);
	                    b = c[j >> 2] | 0;
	                    do if ((c[c[j >> 2] >> 2] | 0) != 14)if ((c[b >> 2] | 0) == 13) {
	                        h[l >> 3] = +g[(c[j >> 2] | 0) + 8 >> 2];
	                        break
	                    } else {
	                        c[e >> 2] = -2;
	                        break a
	                    } else h[l >> 3] = +h[b + 8 >> 3]; while (0);
	                    b = (Lq(+h[k >> 3]) | 0) != 0;
	                    a = (Lq(+h[l >> 3]) | 0) != 0;
	                    if (b)if (a) {
	                        c[e >> 2] = 0;
	                        break
	                    } else {
	                        c[e >> 2] = 1;
	                        break
	                    }
	                    if (a) {
	                        c[e >> 2] = -1;
	                        break
	                    }
	                    a = +h[l >> 3] == +h[15985];
	                    if (+h[k >> 3] == +h[15985])if (a) {
	                        c[e >> 2] = 0;
	                        break
	                    } else {
	                        c[e >> 2] = 1;
	                        break
	                    }
	                    if (a) {
	                        c[e >> 2] = -1;
	                        break
	                    }
	                    a = +h[l >> 3] == +h[15986];
	                    if (+h[k >> 3] == +h[15986])if (a) {
	                        c[e >> 2] = 0;
	                        break
	                    } else {
	                        c[e >> 2] = -1;
	                        break
	                    }
	                    if (a) {
	                        c[e >> 2] = 1;
	                        break
	                    }
	                    if (+h[k >> 3] < +h[l >> 3]) {
	                        c[e >> 2] = -1;
	                        break
	                    }
	                    if (+h[k >> 3] > +h[l >> 3]) {
	                        c[e >> 2] = 1;
	                        break
	                    }
	                    if (+h[k >> 3] == +h[l >> 3]) {
	                        c[e >> 2] = 0;
	                        break
	                    } else {
	                        c[e >> 2] = 2;
	                        break
	                    }
	                } else c[e >> 2] = -2; while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function EI(a, b, d, e, f, g, h, j) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                var k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                k = i;
	                i = i + 32 | 0;
	                l = k + 28 | 0;
	                m = k + 24 | 0;
	                n = k + 20 | 0;
	                o = k + 16 | 0;
	                p = k + 12 | 0;
	                q = k + 8 | 0;
	                r = k + 4 | 0;
	                s = k;
	                c[l >> 2] = a;
	                c[m >> 2] = b;
	                c[n >> 2] = d;
	                c[o >> 2] = e;
	                c[p >> 2] = f;
	                c[q >> 2] = g;
	                c[r >> 2] = h;
	                c[s >> 2] = j;
	                j = kI(c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0, c[r >> 2] | 0, c[s >> 2] | 0) | 0;
	                i = k;
	                return j | 0
	            }

	            function FI(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                g = b + 4 | 0;
	                h = b;
	                c[f >> 2] = a;
	                c[h >> 2] = 0;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    j = c[e >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                c[g >> 2] = c[f >> 2];
	                a:while (1) {
	                    do if ((d[c[g >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[g >> 2] >> 0] | 0 | 0) ? (d[c[g >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[g >> 2] >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    c[g >> 2] = (c[g >> 2] | 0) + 1
	                }
	                b:while (1) {
	                    if (!(d[c[g >> 2] >> 0] | 0)) {
	                        k = 36;
	                        break
	                    }
	                    f = c[g >> 2] | 0;
	                    c:do if (!((d[c[g >> 2] >> 0] | 0) & 128)) {
	                        do if ((d[f >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[g >> 2] >> 0] | 0 | 0) ? (d[c[g >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[g >> 2] >> 0] | 0 | 0) != 13) {
	                                c[g >> 2] = (c[g >> 2] | 0) + 1;
	                                break c
	                            }
	                        } while (0);
	                        while (1) {
	                            do if ((d[c[g >> 2] >> 0] | 0 | 0) == 32)l = 1; else {
	                                if (9 <= (d[c[g >> 2] >> 0] | 0 | 0) ? (d[c[g >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                    l = 1;
	                                    break
	                                }
	                                l = (d[c[g >> 2] >> 0] | 0 | 0) == 13
	                            } while (0);
	                            m = c[g >> 2] | 0;
	                            if (!l)break;
	                            c[g >> 2] = m + 1
	                        }
	                        if (!(d[m >> 0] | 0)) {
	                            k = 36;
	                            break b
	                        }
	                    } else {
	                        if (((d[f + 1 >> 0] | 0) & 192 | 0) != 128) {
	                            k = 12;
	                            break b
	                        }
	                        a = (c[g >> 2] | 0) + 2 | 0;
	                        if (((d[c[g >> 2] >> 0] | 0) & 224 | 0) != 224) {
	                            c[g >> 2] = a;
	                            break
	                        }
	                        if (((d[a >> 0] | 0) & 192 | 0) != 128) {
	                            k = 15;
	                            break b
	                        }
	                        a = c[g >> 2] | 0;
	                        if (((d[c[g >> 2] >> 0] | 0) & 240 | 0) != 240) {
	                            c[g >> 2] = a + 3;
	                            break
	                        }
	                        if (((d[a >> 0] | 0) & 248 | 0) != 240) {
	                            k = 19;
	                            break b
	                        }
	                        if (((d[(c[g >> 2] | 0) + 3 >> 0] | 0) & 192 | 0) != 128) {
	                            k = 19;
	                            break b
	                        }
	                        c[g >> 2] = (c[g >> 2] | 0) + 4
	                    } while (0);
	                    c[h >> 2] = (c[h >> 2] | 0) + 1
	                }
	                if ((k | 0) == 12) {
	                    c[e >> 2] = -1;
	                    j = c[e >> 2] | 0;
	                    i = b;
	                    return j | 0
	                } else if ((k | 0) == 15) {
	                    c[e >> 2] = -1;
	                    j = c[e >> 2] | 0;
	                    i = b;
	                    return j | 0
	                } else if ((k | 0) == 19) {
	                    c[e >> 2] = -1;
	                    j = c[e >> 2] | 0;
	                    i = b;
	                    return j | 0
	                } else if ((k | 0) == 36) {
	                    c[e >> 2] = c[h >> 2];
	                    j = c[e >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                return 0
	            }

	            function GI(a, d) {
	                a = a | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0.0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0;
	                e = i;
	                i = i + 64 | 0;
	                f = e + 48 | 0;
	                g = e + 44 | 0;
	                j = e + 40 | 0;
	                k = e + 36 | 0;
	                l = e + 32 | 0;
	                m = e + 28 | 0;
	                n = e + 24 | 0;
	                o = e + 20 | 0;
	                p = e + 16 | 0;
	                q = e + 12 | 0;
	                r = e + 8 | 0;
	                s = e + 4 | 0;
	                t = e;
	                c[g >> 2] = a;
	                c[j >> 2] = d;
	                if ((c[g >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    u = c[f >> 2] | 0;
	                    i = e;
	                    return u | 0
	                }
	                c[k >> 2] = hI(c[c[g >> 2] >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    u = c[f >> 2] | 0;
	                    i = e;
	                    return u | 0
	                }
	                c[l >> 2] = jI(c[g >> 2] | 0) | 0;
	                g = c[k >> 2] | 0;
	                if (!(c[l >> 2] | 0)) {
	                    PH(g);
	                    c[f >> 2] = 0;
	                    u = c[f >> 2] | 0;
	                    i = e;
	                    return u | 0
	                }
	                c[p >> 2] = g + 8;
	                c[q >> 2] = (c[l >> 2] | 0) + 8;
	                c[r >> 2] = (c[j >> 2] | 0) + 8;
	                if (!(c[(c[q >> 2] | 0) + 4 >> 2] & 15)) {
	                    j = (c[q >> 2] | 0) + 4 | 0;
	                    c[j >> 2] = c[j >> 2] & -16 | 1
	                }
	                j = (c[r >> 2] | 0) + 8 | 0;
	                h[j >> 3] = +h[j >> 3] - +(((b[(c[q >> 2] | 0) + 16 >> 1] << 3 & 65535) << 16 >> 16 >> 4 << 16 >> 16) * 60 | 0);
	                j = (c[q >> 2] | 0) + 16 | 0;
	                b[j >> 1] = b[j >> 1] & -8191;
	                if (!((c[(c[q >> 2] | 0) + 4 >> 2] | 0) >>> 4 & 31)) {
	                    j = (c[q >> 2] | 0) + 4 | 0;
	                    c[j >> 2] = c[j >> 2] & -497 | 16
	                }
	                c[m >> 2] = (c[(c[q >> 2] | 0) + 4 >> 2] & 15) + (c[c[r >> 2] >> 2] | 0);
	                j = ~~(+((c[m >> 2] | 0) - 1 | 0) - +Q(+(+((c[m >> 2] | 0) - 1 | 0) / 12.0)) * 12.0 + 1.0) >>> 0;
	                g = (c[p >> 2] | 0) + 4 | 0;
	                c[g >> 2] = c[g >> 2] & -16 | j & 15;
	                c[m >> 2] = ~~+Q(+(+((c[m >> 2] | 0) - 1 | 0) / 12.0));
	                c[c[p >> 2] >> 2] = (c[c[q >> 2] >> 2] | 0) + (c[m >> 2] | 0);
	                do if (!(c[c[p >> 2] >> 2] | 0)) {
	                    j = c[p >> 2] | 0;
	                    g = c[j >> 2] | 0;
	                    if ((c[c[q >> 2] >> 2] | 0) > 0) {
	                        c[j >> 2] = g + -1;
	                        break
	                    } else {
	                        c[j >> 2] = g + 1;
	                        break
	                    }
	                } while (0);
	                g = (c[p >> 2] | 0) + 16 | 0;
	                b[g >> 1] = b[g >> 1] & -8191 | ((b[(c[q >> 2] | 0) + 16 >> 1] << 3 & 65535) << 16 >> 16 >> 4 << 16 >> 16 & 4095) << 1 & 65535;
	                g = (c[p >> 2] | 0) + 16 | 0;
	                b[g >> 1] = b[g >> 1] & -2 | b[(c[q >> 2] | 0) + 16 >> 1] & 1;
	                h[(c[p >> 2] | 0) + 8 >> 3] = +h[(c[q >> 2] | 0) + 8 >> 3] + +h[(c[r >> 2] | 0) + 8 >> 3];
	                c[m >> 2] = ~~+Q(+(+(~~+h[(c[p >> 2] | 0) + 8 >> 3] | 0) / 60.0));
	                if (+h[(c[p >> 2] | 0) + 8 >> 3] != 0.0) {
	                    v = +h[(c[p >> 2] | 0) + 8 >> 3] - +Q(+(+h[(c[p >> 2] | 0) + 8 >> 3] / 60.0)) * 60.0;
	                    h[(c[p >> 2] | 0) + 8 >> 3] = v
	                }
	                c[m >> 2] = (c[m >> 2] | 0) + ((c[(c[q >> 2] | 0) + 4 >> 2] | 0) >>> 14 & 63);
	                g = ~~(+(c[m >> 2] | 0) - +Q(+(+(c[m >> 2] | 0) / 60.0)) * 60.0) >>> 0;
	                j = (c[p >> 2] | 0) + 4 | 0;
	                c[j >> 2] = c[j >> 2] & -1032193 | (g & 63) << 14;
	                c[m >> 2] = ~~+Q(+(+(c[m >> 2] | 0) / 60.0));
	                c[m >> 2] = (c[m >> 2] | 0) + ((c[(c[q >> 2] | 0) + 4 >> 2] | 0) >>> 9 & 31);
	                g = ~~(+(c[m >> 2] | 0) - +Q(+(+(c[m >> 2] | 0) / 24.0)) * 24.0) >>> 0;
	                j = (c[p >> 2] | 0) + 4 | 0;
	                c[j >> 2] = c[j >> 2] & -15873 | (g & 31) << 9;
	                c[m >> 2] = ~~+Q(+(+(c[m >> 2] | 0) / 24.0));
	                if (((c[c[p >> 2] >> 2] | 0) != 0 ? (c[(c[p >> 2] | 0) + 4 >> 2] & 15 | 0) >= 1 : 0) ? (c[(c[p >> 2] | 0) + 4 >> 2] & 15 | 0) <= 12 : 0) {
	                    g = (c[(c[q >> 2] | 0) + 4 >> 2] | 0) >>> 4 & 31;
	                    if (((c[c[p >> 2] >> 2] | 0) % 4 | 0 | 0) == 0 ? ((c[c[p >> 2] >> 2] | 0) % 100 | 0 | 0) != 0 : 0)w = 23; else if (!((c[c[p >> 2] >> 2] | 0) % 400 | 0))w = 23; else x = c[171912 + ((c[(c[p >> 2] | 0) + 4 >> 2] & 15) - 1 << 2) >> 2] | 0;
	                    if ((w | 0) == 23)x = c[171864 + ((c[(c[p >> 2] | 0) + 4 >> 2] & 15) - 1 << 2) >> 2] | 0;
	                    if (g >>> 0 > x >>> 0) {
	                        if (((c[c[p >> 2] >> 2] | 0) % 4 | 0 | 0) == 0 ? ((c[c[p >> 2] >> 2] | 0) % 100 | 0 | 0) != 0 : 0)w = 29; else if (!((c[c[p >> 2] >> 2] | 0) % 400 | 0))w = 29; else y = c[171912 + ((c[(c[p >> 2] | 0) + 4 >> 2] & 15) - 1 << 2) >> 2] | 0;
	                        if ((w | 0) == 29)y = c[171864 + ((c[(c[p >> 2] | 0) + 4 >> 2] & 15) - 1 << 2) >> 2] | 0;
	                        c[n >> 2] = y
	                    } else w = 32
	                } else w = 32;
	                do if ((w | 0) == 32)if (((c[(c[q >> 2] | 0) + 4 >> 2] | 0) >>> 4 & 31 | 0) < 1) {
	                    c[n >> 2] = 1;
	                    break
	                } else {
	                    c[n >> 2] = (c[(c[q >> 2] | 0) + 4 >> 2] | 0) >>> 4 & 31;
	                    break
	                } while (0);
	                c[n >> 2] = (c[n >> 2] | 0) + ((c[(c[r >> 2] | 0) + 4 >> 2] | 0) + (c[m >> 2] | 0));
	                while (1) {
	                    r = c[p >> 2] | 0;
	                    if ((c[n >> 2] | 0) < 1) {
	                        c[s >> 2] = ~~(+((c[r + 4 >> 2] & 15) - 1 - 1 | 0) - +Q(+(+((c[(c[p >> 2] | 0) + 4 >> 2] & 15) - 1 - 1 | 0) / 12.0)) * 12.0 + 1.0);
	                        c[t >> 2] = (c[c[p >> 2] >> 2] | 0) + ~~+Q(+(+((c[(c[p >> 2] | 0) + 4 >> 2] & 15) - 1 - 1 | 0) / 12.0));
	                        if (!(c[t >> 2] | 0))c[t >> 2] = (c[t >> 2] | 0) + -1;
	                        if ((c[s >> 2] | 0) < 1)c[s >> 2] = 1;
	                        if ((c[s >> 2] | 0) > 12)c[s >> 2] = 12;
	                        if (((c[t >> 2] | 0) % 4 | 0 | 0) == 0 ? ((c[t >> 2] | 0) % 100 | 0 | 0) != 0 : 0)w = 46; else if (!((c[t >> 2] | 0) % 400 | 0))w = 46; else z = c[171912 + ((c[s >> 2] | 0) - 1 << 2) >> 2] | 0;
	                        if ((w | 0) == 46) {
	                            w = 0;
	                            z = c[171864 + ((c[s >> 2] | 0) - 1 << 2) >> 2] | 0
	                        }
	                        c[n >> 2] = (c[n >> 2] | 0) + z;
	                        c[m >> 2] = -1
	                    } else {
	                        if (!(c[r >> 2] | 0))break;
	                        if ((c[(c[p >> 2] | 0) + 4 >> 2] & 15 | 0) < 1)break;
	                        if ((c[(c[p >> 2] | 0) + 4 >> 2] & 15 | 0) > 12)break;
	                        r = c[n >> 2] | 0;
	                        if (((c[c[p >> 2] >> 2] | 0) % 4 | 0 | 0) == 0 ? ((c[c[p >> 2] >> 2] | 0) % 100 | 0 | 0) != 0 : 0)w = 55; else if (!((c[c[p >> 2] >> 2] | 0) % 400 | 0))w = 55; else A = c[171912 + ((c[(c[p >> 2] | 0) + 4 >> 2] & 15) - 1 << 2) >> 2] | 0;
	                        if ((w | 0) == 55) {
	                            w = 0;
	                            A = c[171864 + ((c[(c[p >> 2] | 0) + 4 >> 2] & 15) - 1 << 2) >> 2] | 0
	                        }
	                        if ((r | 0) <= (A | 0))break;
	                        r = c[n >> 2] | 0;
	                        if (((c[c[p >> 2] >> 2] | 0) % 4 | 0 | 0) == 0 ? ((c[c[p >> 2] >> 2] | 0) % 100 | 0 | 0) != 0 : 0)w = 61; else if (!((c[c[p >> 2] >> 2] | 0) % 400 | 0))w = 61; else B = c[171912 + ((c[(c[p >> 2] | 0) + 4 >> 2] & 15) - 1 << 2) >> 2] | 0;
	                        if ((w | 0) == 61) {
	                            w = 0;
	                            B = c[171864 + ((c[(c[p >> 2] | 0) + 4 >> 2] & 15) - 1 << 2) >> 2] | 0
	                        }
	                        c[n >> 2] = r - B;
	                        c[m >> 2] = 1
	                    }
	                    c[o >> 2] = (c[(c[p >> 2] | 0) + 4 >> 2] & 15) + (c[m >> 2] | 0);
	                    r = ~~(+((c[o >> 2] | 0) - 1 | 0) - +Q(+(+((c[o >> 2] | 0) - 1 | 0) / 12.0)) * 12.0 + 1.0) >>> 0;
	                    q = (c[p >> 2] | 0) + 4 | 0;
	                    c[q >> 2] = c[q >> 2] & -16 | r & 15;
	                    r = (c[c[p >> 2] >> 2] | 0) + (~~+Q(+(+((c[o >> 2] | 0) - 1 | 0) / 12.0)) >>> 0) | 0;
	                    c[c[p >> 2] >> 2] = r;
	                    if (c[c[p >> 2] >> 2] | 0)continue;
	                    r = c[p >> 2] | 0;
	                    q = c[r >> 2] | 0;
	                    if ((c[o >> 2] | 0) < 1) {
	                        c[r >> 2] = q + -1;
	                        continue
	                    } else {
	                        c[r >> 2] = q + 1;
	                        continue
	                    }
	                }
	                o = (c[p >> 2] | 0) + 4 | 0;
	                c[o >> 2] = c[o >> 2] & -497 | (c[n >> 2] & 31) << 4;
	                do if ((c[c[k >> 2] >> 2] | 0) != 11) {
	                    if ((((c[(c[p >> 2] | 0) + 4 >> 2] | 0) >>> 9 & 31 | 0) == 0 ? ((c[(c[p >> 2] | 0) + 4 >> 2] | 0) >>> 14 & 63 | 0) == 0 : 0) ? !(+h[(c[p >> 2] | 0) + 8 >> 3] != 0.0) : 0) {
	                        if ((c[c[k >> 2] >> 2] | 0) == 10)break;
	                        if ((c[(c[p >> 2] | 0) + 4 >> 2] & 15 | 0) != 1 ? ((c[(c[p >> 2] | 0) + 4 >> 2] | 0) >>> 4 & 31 | 0) != 1 : 0) {
	                            c[c[k >> 2] >> 2] = 10;
	                            break
	                        }
	                        if ((c[c[k >> 2] >> 2] | 0) == 9)break;
	                        if ((c[(c[p >> 2] | 0) + 4 >> 2] & 15 | 0) == 1)break;
	                        c[c[k >> 2] >> 2] = 9;
	                        break
	                    }
	                    c[c[k >> 2] >> 2] = 11
	                } while (0);
	                PH(c[l >> 2] | 0);
	                c[f >> 2] = c[k >> 2];
	                u = c[f >> 2] | 0;
	                i = e;
	                return u | 0
	            }

	            function HI(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = c[c[h >> 2] >> 2];
	                c[k >> 2] = 0;
	                c[l >> 2] = 0;
	                if ((((d[c[j >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[j >> 2] >> 0] | 0 | 0) <= 57 : 0) ? (d[(c[j >> 2] | 0) + 1 >> 0] | 0 | 0) >= 48 : 0) ? (d[(c[j >> 2] | 0) + 1 >> 0] | 0 | 0) <= 57 : 0)c[l >> 2] = (((d[c[j >> 2] >> 0] | 0) - 48 | 0) * 10 | 0) + ((d[(c[j >> 2] | 0) + 1 >> 0] | 0) - 48); else c[k >> 2] = 1;
	                c[j >> 2] = (c[j >> 2] | 0) + 2;
	                if (c[k >> 2] | 0) {
	                    c[f >> 2] = c[k >> 2];
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                if ((c[l >> 2] | 0) >>> 0 >= 1 & (c[l >> 2] | 0) >>> 0 <= 31) {
	                    k = (c[g >> 2] | 0) + 4 | 0;
	                    c[k >> 2] = c[k >> 2] & -497 | (c[l >> 2] & 31) << 4;
	                    c[c[h >> 2] >> 2] = c[j >> 2];
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                } else {
	                    c[f >> 2] = 2;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                return 0
	            }

	            function II(a, e) {
	                a = a | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 24 | 0;
	                h = f + 20 | 0;
	                j = f + 16 | 0;
	                k = f + 12 | 0;
	                l = f + 8 | 0;
	                m = f + 4 | 0;
	                n = f;
	                c[h >> 2] = a;
	                c[j >> 2] = e;
	                c[l >> 2] = 0;
	                if (!(c[j >> 2] | 0)) {
	                    c[g >> 2] = -1;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                c[k >> 2] = c[c[j >> 2] >> 2];
	                e = d[c[k >> 2] >> 0] | 0;
	                do if ((e | 0) == 45 | (e | 0) == 43) {
	                    c[m >> 2] = 0;
	                    c[n >> 2] = 0;
	                    c[m >> 2] = (d[c[k >> 2] >> 0] | 0 | 0) == 45 & 1;
	                    c[k >> 2] = (c[k >> 2] | 0) + 1;
	                    if ((((d[c[k >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[k >> 2] >> 0] | 0 | 0) <= 57 : 0) ? (d[(c[k >> 2] | 0) + 1 >> 0] | 0 | 0) >= 48 : 0) ? (d[(c[k >> 2] | 0) + 1 >> 0] | 0 | 0) <= 57 : 0)c[n >> 2] = (((d[c[k >> 2] >> 0] | 0) - 48 | 0) * 10 | 0) + ((d[(c[k >> 2] | 0) + 1 >> 0] | 0) - 48); else c[l >> 2] = 1;
	                    c[k >> 2] = (c[k >> 2] | 0) + 2;
	                    if (c[l >> 2] | 0) {
	                        c[g >> 2] = c[l >> 2];
	                        o = c[g >> 2] | 0;
	                        i = f;
	                        return o | 0
	                    }
	                    if (!((c[n >> 2] | 0) >= 0 & (c[n >> 2] | 0) <= 23)) {
	                        c[g >> 2] = 2;
	                        o = c[g >> 2] | 0;
	                        i = f;
	                        return o | 0
	                    }
	                    if ((d[c[k >> 2] >> 0] | 0 | 0) != 58) {
	                        c[g >> 2] = 1;
	                        o = c[g >> 2] | 0;
	                        i = f;
	                        return o | 0
	                    }
	                    c[k >> 2] = (c[k >> 2] | 0) + 1;
	                    a = (c[h >> 2] | 0) + 16 | 0;
	                    b[a >> 1] = b[a >> 1] & -8191 | ((c[n >> 2] | 0) * 60 & 4095) << 1 & 65535;
	                    if ((((d[c[k >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[k >> 2] >> 0] | 0 | 0) <= 57 : 0) ? (d[(c[k >> 2] | 0) + 1 >> 0] | 0 | 0) >= 48 : 0) ? (d[(c[k >> 2] | 0) + 1 >> 0] | 0 | 0) <= 57 : 0)c[n >> 2] = (((d[c[k >> 2] >> 0] | 0) - 48 | 0) * 10 | 0) + ((d[(c[k >> 2] | 0) + 1 >> 0] | 0) - 48); else c[l >> 2] = 1;
	                    c[k >> 2] = (c[k >> 2] | 0) + 2;
	                    if (c[l >> 2] | 0) {
	                        c[g >> 2] = c[l >> 2];
	                        o = c[g >> 2] | 0;
	                        i = f;
	                        return o | 0
	                    }
	                    if (!((c[n >> 2] | 0) >= 0 & (c[n >> 2] | 0) <= 59)) {
	                        c[g >> 2] = 2;
	                        o = c[g >> 2] | 0;
	                        i = f;
	                        return o | 0
	                    }
	                    a = (c[h >> 2] | 0) + 16 | 0;
	                    b[a >> 1] = b[a >> 1] & -8191 | (((b[a >> 1] << 3 & 65535) << 16 >> 16 >> 4 << 16 >> 16) + (c[n >> 2] | 0) & 4095) << 1 & 65535;
	                    if (c[m >> 2] | 0) {
	                        a = (c[h >> 2] | 0) + 16 | 0;
	                        b[a >> 1] = b[a >> 1] & -8191 | (0 - ((b[(c[h >> 2] | 0) + 16 >> 1] << 3 & 65535) << 16 >> 16 >> 4 << 16 >> 16) & 4095) << 1 & 65535
	                    }
	                    if (((b[(c[h >> 2] | 0) + 16 >> 1] << 3 & 65535) << 16 >> 16 >> 4 << 16 >> 16 | 0) > -840 ? ((b[(c[h >> 2] | 0) + 16 >> 1] << 3 & 65535) << 16 >> 16 >> 4 << 16 >> 16 | 0) < 840 : 0) {
	                        a = (c[h >> 2] | 0) + 16 | 0;
	                        b[a >> 1] = b[a >> 1] & -2 | 1;
	                        break
	                    }
	                    c[g >> 2] = 2;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                } else if (!e) {
	                    a = (c[h >> 2] | 0) + 16 | 0;
	                    b[a >> 1] = b[a >> 1] & -2;
	                    a = (c[h >> 2] | 0) + 16 | 0;
	                    b[a >> 1] = b[a >> 1] & -8191
	                } else if ((e | 0) == 90) {
	                    a = (c[h >> 2] | 0) + 16 | 0;
	                    b[a >> 1] = b[a >> 1] & -2 | 1;
	                    a = (c[h >> 2] | 0) + 16 | 0;
	                    b[a >> 1] = b[a >> 1] & -8191;
	                    c[k >> 2] = (c[k >> 2] | 0) + 1
	                } else {
	                    c[g >> 2] = 1;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                } while (0);
	                c[c[j >> 2] >> 2] = c[k >> 2];
	                c[g >> 2] = 0;
	                o = c[g >> 2] | 0;
	                i = f;
	                return o | 0
	            }

	            function JI(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = c[c[h >> 2] >> 2];
	                c[k >> 2] = 0;
	                c[l >> 2] = 0;
	                if ((((d[c[j >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[j >> 2] >> 0] | 0 | 0) <= 57 : 0) ? (d[(c[j >> 2] | 0) + 1 >> 0] | 0 | 0) >= 48 : 0) ? (d[(c[j >> 2] | 0) + 1 >> 0] | 0 | 0) <= 57 : 0)c[l >> 2] = (((d[c[j >> 2] >> 0] | 0) - 48 | 0) * 10 | 0) + ((d[(c[j >> 2] | 0) + 1 >> 0] | 0) - 48); else c[k >> 2] = 1;
	                c[j >> 2] = (c[j >> 2] | 0) + 2;
	                if (c[k >> 2] | 0) {
	                    c[f >> 2] = c[k >> 2];
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                if ((c[l >> 2] | 0) >>> 0 >= 1 & (c[l >> 2] | 0) >>> 0 <= 12) {
	                    k = (c[g >> 2] | 0) + 4 | 0;
	                    c[k >> 2] = c[k >> 2] & -16 | c[l >> 2] & 15;
	                    c[c[h >> 2] >> 2] = c[j >> 2];
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                } else {
	                    c[f >> 2] = 2;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                return 0
	            }

	            function KI(a, e) {
	                a = a | 0;
	                e = e | 0;
	                var f = 0, g = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 28 | 0;
	                j = f + 24 | 0;
	                k = f + 20 | 0;
	                l = f + 16 | 0;
	                m = f + 12 | 0;
	                n = f + 8 | 0;
	                o = f;
	                c[j >> 2] = a;
	                c[k >> 2] = e;
	                c[l >> 2] = c[c[k >> 2] >> 2];
	                c[m >> 2] = 0;
	                c[n >> 2] = 0;
	                if ((((d[c[l >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[l >> 2] >> 0] | 0 | 0) <= 57 : 0) ? (d[(c[l >> 2] | 0) + 1 >> 0] | 0 | 0) >= 48 : 0) ? (d[(c[l >> 2] | 0) + 1 >> 0] | 0 | 0) <= 57 : 0)c[n >> 2] = (((d[c[l >> 2] >> 0] | 0) - 48 | 0) * 10 | 0) + ((d[(c[l >> 2] | 0) + 1 >> 0] | 0) - 48); else c[m >> 2] = 1;
	                c[l >> 2] = (c[l >> 2] | 0) + 2;
	                if (c[m >> 2] | 0) {
	                    c[g >> 2] = c[m >> 2];
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                if ((d[c[l >> 2] >> 0] | 0 | 0) != 58) {
	                    c[g >> 2] = 1;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                if (!((c[n >> 2] | 0) >= 0 & (c[n >> 2] | 0) <= 23)) {
	                    c[g >> 2] = 2;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                c[l >> 2] = (c[l >> 2] | 0) + 1;
	                e = (c[j >> 2] | 0) + 4 | 0;
	                c[e >> 2] = c[e >> 2] & -15873 | (c[n >> 2] & 31) << 9;
	                if ((((d[c[l >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[l >> 2] >> 0] | 0 | 0) <= 57 : 0) ? (d[(c[l >> 2] | 0) + 1 >> 0] | 0 | 0) >= 48 : 0) ? (d[(c[l >> 2] | 0) + 1 >> 0] | 0 | 0) <= 57 : 0)c[n >> 2] = (((d[c[l >> 2] >> 0] | 0) - 48 | 0) * 10 | 0) + ((d[(c[l >> 2] | 0) + 1 >> 0] | 0) - 48); else c[m >> 2] = 1;
	                c[l >> 2] = (c[l >> 2] | 0) + 2;
	                if (c[m >> 2] | 0) {
	                    c[g >> 2] = c[m >> 2];
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                if (!((c[n >> 2] | 0) >= 0 & (c[n >> 2] | 0) <= 59)) {
	                    c[g >> 2] = 2;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                e = (c[j >> 2] | 0) + 4 | 0;
	                c[e >> 2] = c[e >> 2] & -1032193 | (c[n >> 2] & 63) << 14;
	                if ((d[c[l >> 2] >> 0] | 0 | 0) != 58) {
	                    c[g >> 2] = 1;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                c[l >> 2] = (c[l >> 2] | 0) + 1;
	                if ((((d[c[l >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[l >> 2] >> 0] | 0 | 0) <= 57 : 0) ? (d[(c[l >> 2] | 0) + 1 >> 0] | 0 | 0) >= 48 : 0) ? (d[(c[l >> 2] | 0) + 1 >> 0] | 0 | 0) <= 57 : 0)h[(c[j >> 2] | 0) + 8 >> 3] = +((((d[c[l >> 2] >> 0] | 0) - 48 | 0) * 10 | 0) + ((d[(c[l >> 2] | 0) + 1 >> 0] | 0) - 48) | 0); else c[m >> 2] = 1;
	                c[l >> 2] = (c[l >> 2] | 0) + 2;
	                a:do if ((c[m >> 2] | 0) == 0 ? (d[c[l >> 2] >> 0] | 0 | 0) == 46 : 0) {
	                    h[o >> 3] = 1.0;
	                    c[l >> 2] = (c[l >> 2] | 0) + 1;
	                    if (!((d[c[l >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[l >> 2] >> 0] | 0 | 0) <= 57 : 0))c[m >> 2] = 1;
	                    while (1) {
	                        if ((d[c[l >> 2] >> 0] | 0 | 0) < 48)break a;
	                        if ((d[c[l >> 2] >> 0] | 0 | 0) > 57)break a;
	                        h[o >> 3] = +h[o >> 3] / 10.0;
	                        n = (c[j >> 2] | 0) + 8 | 0;
	                        h[n >> 3] = +h[n >> 3] + +((d[c[l >> 2] >> 0] | 0) - 48 | 0) * +h[o >> 3];
	                        c[l >> 2] = (c[l >> 2] | 0) + 1
	                    }
	                } while (0);
	                if (c[m >> 2] | 0) {
	                    c[g >> 2] = c[m >> 2];
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                if (((+h[(c[j >> 2] | 0) + 8 >> 3] >= 0.0 ? +h[(c[j >> 2] | 0) + 8 >> 3] < 60.0 : 0) ? ((b[(c[j >> 2] | 0) + 16 >> 1] << 3 & 65535) << 16 >> 16 >> 4 << 16 >> 16 | 0) > -840 : 0) ? ((b[(c[j >> 2] | 0) + 16 >> 1] << 3 & 65535) << 16 >> 16 >> 4 << 16 >> 16 | 0) < 840 : 0) {
	                    c[c[k >> 2] >> 2] = c[l >> 2];
	                    c[g >> 2] = 0;
	                    p = c[g >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                c[g >> 2] = 2;
	                p = c[g >> 2] | 0;
	                i = f;
	                return p | 0
	            }

	            function LI(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 20 | 0;
	                h = e + 16 | 0;
	                j = e + 12 | 0;
	                k = e + 8 | 0;
	                l = e + 4 | 0;
	                m = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = c[c[h >> 2] >> 2];
	                c[l >> 2] = 0;
	                c[m >> 2] = 0;
	                if (!((d[c[j >> 2] >> 0] | 0 | 0) >= 48 ? (d[c[j >> 2] >> 0] | 0 | 0) <= 57 : 0))n = 3;
	                if (((n | 0) == 3 ? (d[c[j >> 2] >> 0] | 0 | 0) != 45 : 0) ? (d[c[j >> 2] >> 0] | 0 | 0) != 43 : 0) {
	                    c[f >> 2] = -1;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                if ((d[c[j >> 2] >> 0] | 0 | 0) == 45) {
	                    c[l >> 2] = 1;
	                    c[j >> 2] = (c[j >> 2] | 0) + 1
	                }
	                c[k >> 2] = c[j >> 2];
	                while (1) {
	                    if ((d[c[j >> 2] >> 0] | 0 | 0) < 48)break;
	                    if ((d[c[j >> 2] >> 0] | 0 | 0) > 57)break;
	                    c[c[g >> 2] >> 2] = ((c[c[g >> 2] >> 2] | 0) * 10 | 0) + ((d[c[j >> 2] >> 0] | 0) - 48);
	                    c[j >> 2] = (c[j >> 2] | 0) + 1;
	                    c[m >> 2] = (c[m >> 2] | 0) + 1
	                }
	                do if ((c[m >> 2] | 0) >= 4) {
	                    if ((c[m >> 2] | 0) > 4 ? (d[c[k >> 2] >> 0] | 0 | 0) == 48 : 0)break;
	                    if (c[l >> 2] | 0)c[c[g >> 2] >> 2] = 0 - (c[c[g >> 2] >> 2] | 0);
	                    if (c[c[g >> 2] >> 2] | 0) {
	                        c[c[h >> 2] >> 2] = c[j >> 2];
	                        c[f >> 2] = 0;
	                        o = c[f >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    } else {
	                        c[f >> 2] = 2;
	                        o = c[f >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    }
	                } while (0);
	                c[f >> 2] = 1;
	                o = c[f >> 2] | 0;
	                i = e;
	                return o | 0
	            }

	            function MI(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[d >> 2] = a;
	                a = c[(c[d >> 2] | 0) + 12 >> 2] & 15;
	                c[f >> 2] = a;
	                c[f >> 2] = (c[f >> 2] | 0) <= 0 ? 1 : a;
	                a = c[(c[d >> 2] | 0) + 8 >> 2] | 0;
	                if ((c[(c[d >> 2] | 0) + 8 >> 2] | 0) <= 0) {
	                    g = (a * 365 | 0) + ((((c[(c[d >> 2] | 0) + 8 >> 2] | 0) + 1 | 0) / 4 | 0) - (((c[(c[d >> 2] | 0) + 8 >> 2] | 0) + 1 | 0) / 100 | 0) + (((c[(c[d >> 2] | 0) + 8 >> 2] | 0) + 1 | 0) / 400 | 0)) | 0;
	                    if (((c[(c[d >> 2] | 0) + 8 >> 2] | 0) % 4 | 0 | 0) == 0 ? ((c[(c[d >> 2] | 0) + 8 >> 2] | 0) % 100 | 0 | 0) != 0 : 0)h = 5; else if (!((c[(c[d >> 2] | 0) + 8 >> 2] | 0) % 400 | 0))h = 5; else j = c[172072 + ((c[f >> 2] | 0) - 1 << 2) >> 2] | 0;
	                    if ((h | 0) == 5)j = c[172024 + ((c[f >> 2] | 0) - 1 << 2) >> 2] | 0;
	                    c[e >> 2] = g + (j + 0);
	                    k = c[e >> 2] | 0;
	                    i = b;
	                    return k | 0
	                } else {
	                    j = ((a - 1 | 0) * 365 | 0) + ((((c[(c[d >> 2] | 0) + 8 >> 2] | 0) - 1 | 0) / 4 | 0) - (((c[(c[d >> 2] | 0) + 8 >> 2] | 0) - 1 | 0) / 100 | 0) + (((c[(c[d >> 2] | 0) + 8 >> 2] | 0) - 1 | 0) / 400 | 0)) | 0;
	                    if (((c[(c[d >> 2] | 0) + 8 >> 2] | 0) % 4 | 0 | 0) == 0 ? ((c[(c[d >> 2] | 0) + 8 >> 2] | 0) % 100 | 0 | 0) != 0 : 0)h = 11; else if (!((c[(c[d >> 2] | 0) + 8 >> 2] | 0) % 400 | 0))h = 11; else l = c[172072 + ((c[f >> 2] | 0) - 1 << 2) >> 2] | 0;
	                    if ((h | 0) == 11)l = c[172024 + ((c[f >> 2] | 0) - 1 << 2) >> 2] | 0;
	                    c[e >> 2] = j + (l + 0);
	                    k = c[e >> 2] | 0;
	                    i = b;
	                    return k | 0
	                }
	                return 0
	            }

	            function NI(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 65792)e = (c[d >> 2] | 0) <= 65855; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function OI(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 64256)e = (c[d >> 2] | 0) <= 64335; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function PI(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 1536)e = (c[d >> 2] | 0) <= 1791; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function QI(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 64336)e = (c[d >> 2] | 0) <= 65023; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function RI(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 65136)e = (c[d >> 2] | 0) <= 65279; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function SI(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 1328)e = (c[d >> 2] | 0) <= 1423; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function TI(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 8592)e = (c[d >> 2] | 0) <= 8703; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function UI(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 0)e = (c[d >> 2] | 0) <= 127; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function VI(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 2432)e = (c[d >> 2] | 0) <= 2559; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function WI(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 9600)e = (c[d >> 2] | 0) <= 9631; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function XI(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 12544)e = (c[d >> 2] | 0) <= 12591; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function YI(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 12704)e = (c[d >> 2] | 0) <= 12735; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function ZI(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 9472)e = (c[d >> 2] | 0) <= 9599; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function _I(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 10240)e = (c[d >> 2] | 0) <= 10495; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function $I(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 5952)e = (c[d >> 2] | 0) <= 5983; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function aJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 118784)e = (c[d >> 2] | 0) <= 119039; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function bJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 13056)e = (c[d >> 2] | 0) <= 13311; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function cJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 65072)e = (c[d >> 2] | 0) <= 65103; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function dJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 63744)e = (c[d >> 2] | 0) <= 64255; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function eJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 194560)e = (c[d >> 2] | 0) <= 195103; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function fJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 11904)e = (c[d >> 2] | 0) <= 12031; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function gJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 12288)e = (c[d >> 2] | 0) <= 12351; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function hJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 19968)e = (c[d >> 2] | 0) <= 40959; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function iJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 13312)e = (c[d >> 2] | 0) <= 19903; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function jJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 131072)e = (c[d >> 2] | 0) <= 173791; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function kJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 5024)e = (c[d >> 2] | 0) <= 5119; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function lJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 768)e = (c[d >> 2] | 0) <= 879; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function mJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 8400)e = (c[d >> 2] | 0) <= 8447; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function nJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 65056)e = (c[d >> 2] | 0) <= 65071; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function oJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 8400)e = (c[d >> 2] | 0) <= 8447; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function pJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 9216)e = (c[d >> 2] | 0) <= 9279; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function qJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 8352)e = (c[d >> 2] | 0) <= 8399; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function rJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 67584)e = (c[d >> 2] | 0) <= 67647; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function sJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 1024)e = (c[d >> 2] | 0) <= 1279; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function tJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 1280)e = (c[d >> 2] | 0) <= 1327; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function uJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 66560)e = (c[d >> 2] | 0) <= 66639; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function vJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 2304)e = (c[d >> 2] | 0) <= 2431; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function wJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 9984)e = (c[d >> 2] | 0) <= 10175; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function xJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 9312)e = (c[d >> 2] | 0) <= 9471; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function yJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 12800)e = (c[d >> 2] | 0) <= 13055; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function zJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 4608)e = (c[d >> 2] | 0) <= 4991; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function AJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 8192)e = (c[d >> 2] | 0) <= 8303; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function BJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 9632)e = (c[d >> 2] | 0) <= 9727; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function CJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 4256)e = (c[d >> 2] | 0) <= 4351; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function DJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 66352)e = (c[d >> 2] | 0) <= 66383; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function EJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 880)e = (c[d >> 2] | 0) <= 1023; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function FJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 7936)e = (c[d >> 2] | 0) <= 8191; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function GJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 880)e = (c[d >> 2] | 0) <= 1023; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function HJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 2688)e = (c[d >> 2] | 0) <= 2815; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function IJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 2560)e = (c[d >> 2] | 0) <= 2687; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function JJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 65280)e = (c[d >> 2] | 0) <= 65519; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function KJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 12592)e = (c[d >> 2] | 0) <= 12687; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function LJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 4352)e = (c[d >> 2] | 0) <= 4607; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function MJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 44032)e = (c[d >> 2] | 0) <= 55215; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function NJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 5920)e = (c[d >> 2] | 0) <= 5951; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function OJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 1424)e = (c[d >> 2] | 0) <= 1535; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function PJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 56192)e = (c[d >> 2] | 0) <= 56319; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function QJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 55296)e = (c[d >> 2] | 0) <= 56191; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function RJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 12352)e = (c[d >> 2] | 0) <= 12447; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function SJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 592)e = (c[d >> 2] | 0) <= 687; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function TJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 12272)e = (c[d >> 2] | 0) <= 12287; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function UJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 12688)e = (c[d >> 2] | 0) <= 12703; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function VJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 12032)e = (c[d >> 2] | 0) <= 12255; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function WJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 3200)e = (c[d >> 2] | 0) <= 3327; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function XJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 12448)e = (c[d >> 2] | 0) <= 12543; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function YJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 12784)e = (c[d >> 2] | 0) <= 12799; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function ZJ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 6016)e = (c[d >> 2] | 0) <= 6143; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function _J(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 6624)e = (c[d >> 2] | 0) <= 6655; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function $J(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 3712)e = (c[d >> 2] | 0) <= 3839; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function aK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 128)e = (c[d >> 2] | 0) <= 255; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function bK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 256)e = (c[d >> 2] | 0) <= 383; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function cK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 384)e = (c[d >> 2] | 0) <= 591; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function dK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 7680)e = (c[d >> 2] | 0) <= 7935; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function eK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 8448)e = (c[d >> 2] | 0) <= 8527; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function fK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 6400)e = (c[d >> 2] | 0) <= 6479; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function gK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 65664)e = (c[d >> 2] | 0) <= 65791; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function hK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 65536)e = (c[d >> 2] | 0) <= 65663; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function iK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 56320)e = (c[d >> 2] | 0) <= 57343; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function jK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 3328)e = (c[d >> 2] | 0) <= 3455; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function kK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 119808)e = (c[d >> 2] | 0) <= 120831; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function lK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 8704)e = (c[d >> 2] | 0) <= 8959; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function mK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 10176)e = (c[d >> 2] | 0) <= 10223; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function nK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 10624)e = (c[d >> 2] | 0) <= 10751; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function oK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 9728)e = (c[d >> 2] | 0) <= 9983; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function pK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 11008)e = (c[d >> 2] | 0) <= 11263; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function qK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 8960)e = (c[d >> 2] | 0) <= 9215; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function rK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 6144)e = (c[d >> 2] | 0) <= 6319; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function sK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 119040)e = (c[d >> 2] | 0) <= 119295; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function tK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 4096)e = (c[d >> 2] | 0) <= 4255; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function uK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 8528)e = (c[d >> 2] | 0) <= 8591; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function vK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 5760)e = (c[d >> 2] | 0) <= 5791; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function wK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 66304)e = (c[d >> 2] | 0) <= 66351; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function xK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 9280)e = (c[d >> 2] | 0) <= 9311; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function yK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 2816)e = (c[d >> 2] | 0) <= 2943; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function zK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 66688)e = (c[d >> 2] | 0) <= 66735; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function AK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 7424)e = (c[d >> 2] | 0) <= 7551; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function BK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!((c[d >> 2] | 0) >= 57344 & (c[d >> 2] | 0) <= 63743) ? !((c[d >> 2] | 0) >= 983040 & (c[d >> 2] | 0) <= 1048575) : 0)if ((c[d >> 2] | 0) >= 1048576)e = (c[d >> 2] | 0) <= 1114111; else e = 0; else e = 1;
	                i = b;
	                return e & 1 | 0
	            }

	            function CK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 57344)e = (c[d >> 2] | 0) <= 63743; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function DK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 5792)e = (c[d >> 2] | 0) <= 5887; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function EK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 66640)e = (c[d >> 2] | 0) <= 66687; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function FK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 3456)e = (c[d >> 2] | 0) <= 3583; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function GK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 65104)e = (c[d >> 2] | 0) <= 65135; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function HK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 688)e = (c[d >> 2] | 0) <= 767; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function IK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 65520)e = (c[d >> 2] | 0) <= 65535; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function JK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 8304)e = (c[d >> 2] | 0) <= 8351; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function KK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 10224)e = (c[d >> 2] | 0) <= 10239; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function LK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 10496)e = (c[d >> 2] | 0) <= 10623; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function MK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 10752)e = (c[d >> 2] | 0) <= 11007; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function NK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 983040)e = (c[d >> 2] | 0) <= 1048575; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function OK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 1048576)e = (c[d >> 2] | 0) <= 1114111; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function PK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 1792)e = (c[d >> 2] | 0) <= 1871; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function QK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 5888)e = (c[d >> 2] | 0) <= 5919; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function RK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 5984)e = (c[d >> 2] | 0) <= 6015; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function SK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 917504)e = (c[d >> 2] | 0) <= 917631; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function TK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 6480)e = (c[d >> 2] | 0) <= 6527; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function UK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 119552)e = (c[d >> 2] | 0) <= 119647; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function VK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 2944)e = (c[d >> 2] | 0) <= 3071; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function WK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 3072)e = (c[d >> 2] | 0) <= 3199; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function XK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 1920)e = (c[d >> 2] | 0) <= 1983; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function YK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 3584)e = (c[d >> 2] | 0) <= 3711; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function ZK(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 3840)e = (c[d >> 2] | 0) <= 4095; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function _K(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 66432)e = (c[d >> 2] | 0) <= 66463; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function $K(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 5120)e = (c[d >> 2] | 0) <= 5759; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function aL(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 65024)e = (c[d >> 2] | 0) <= 65039; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function bL(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 917760)e = (c[d >> 2] | 0) <= 917999; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function cL(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 42128)e = (c[d >> 2] | 0) <= 42191; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function dL(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 40960)e = (c[d >> 2] | 0) <= 42127; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function eL(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) >= 19904)e = (c[d >> 2] | 0) <= 19967; else e = 0;
	                i = b;
	                return e & 1 | 0
	            }

	            function fL(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = PL(172456, c[g >> 2] | 0) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } else {
	                    c[e >> 2] = Cb[c[h >> 2] & 511](c[f >> 2] | 0) | 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                return 0
	            }

	            function gL(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = DQ(c[d >> 2] | 0, 172464) | 0;
	                i = b;
	                return a | 0
	            }

	            function hL(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!((c[d >> 2] | 0) >= 0 & (c[d >> 2] | 0) <= 31))if ((c[d >> 2] | 0) >= 127)e = (c[d >> 2] | 0) <= 159; else e = 0; else e = 1;
	                i = b;
	                return e & 1 | 0
	            }

	            function iL(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = DQ(c[d >> 2] | 0, 172480) | 0;
	                i = b;
	                return a | 0
	            }

	            function jL(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) == 57344 | (c[d >> 2] | 0) == 63743 | (c[d >> 2] | 0) == 983040 | (c[d >> 2] | 0) == 1048573 | (c[d >> 2] | 0) == 1048576) {
	                    e = 1;
	                    f = e & 1;
	                    i = b;
	                    return f | 0
	                }
	                e = (c[d >> 2] | 0) == 1114109;
	                f = e & 1;
	                i = b;
	                return f | 0
	            }

	            function kL(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = DQ(c[d >> 2] | 0, 172496) | 0;
	                i = b;
	                return a | 0
	            }

	            function lL(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = DQ(c[d >> 2] | 0, 172512) | 0;
	                i = b;
	                return a | 0
	            }

	            function mL(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = DQ(c[d >> 2] | 0, 172528) | 0;
	                i = b;
	                return a | 0
	            }

	            function nL(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = DQ(c[d >> 2] | 0, 172544) | 0;
	                i = b;
	                return a | 0
	            }

	            function oL(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = DQ(c[d >> 2] | 0, 172560) | 0;
	                i = b;
	                return a | 0
	            }

	            function pL(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = DQ(c[d >> 2] | 0, 172576) | 0;
	                i = b;
	                return a | 0
	            }

	            function qL(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = DQ(c[d >> 2] | 0, 172592) | 0;
	                i = b;
	                return a | 0
	            }

	            function rL(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = DQ(c[d >> 2] | 0, 172608) | 0;
	                i = b;
	                return a | 0
	            }

	            function sL(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!((c[d >> 2] | 0) >= 1160 & (c[d >> 2] | 0) <= 1161 | (c[d >> 2] | 0) == 1758) ? !((c[d >> 2] | 0) >= 8413 & (c[d >> 2] | 0) <= 8416) : 0)if ((c[d >> 2] | 0) >= 8418)e = (c[d >> 2] | 0) <= 8420; else e = 0; else e = 1;
	                i = b;
	                return e & 1 | 0
	            }

	            function tL(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = DQ(c[d >> 2] | 0, 172624) | 0;
	                i = b;
	                return a | 0
	            }

	            function uL(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = DQ(c[d >> 2] | 0, 172640) | 0;
	                i = b;
	                return a | 0
	            }

	            function vL(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = DQ(c[d >> 2] | 0, 172656) | 0;
	                i = b;
	                return a | 0
	            }

	            function wL(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (((!((c[d >> 2] | 0) >= 5870 & (c[d >> 2] | 0) <= 5872) ? !((c[d >> 2] | 0) >= 8544 & (c[d >> 2] | 0) <= 8579 | (c[d >> 2] | 0) == 12295) : 0) ? !((c[d >> 2] | 0) >= 12321 & (c[d >> 2] | 0) <= 12329) : 0) ? !((c[d >> 2] | 0) >= 12344 & (c[d >> 2] | 0) <= 12346) : 0)e = (c[d >> 2] | 0) == 66378; else e = 1;
	                i = b;
	                return e & 1 | 0
	            }

	            function xL(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = DQ(c[d >> 2] | 0, 172672) | 0;
	                i = b;
	                return a | 0
	            }

	            function yL(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = DQ(c[d >> 2] | 0, 172688) | 0;
	                i = b;
	                return a | 0
	            }

	            function zL(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((((c[d >> 2] | 0) != 95 ? !((c[d >> 2] | 0) >= 8255 & (c[d >> 2] | 0) <= 8256 | (c[d >> 2] | 0) == 8276 | (c[d >> 2] | 0) == 12539) : 0) ? !((c[d >> 2] | 0) >= 65075 & (c[d >> 2] | 0) <= 65076) : 0) ? !((c[d >> 2] | 0) >= 65101 & (c[d >> 2] | 0) <= 65103 | (c[d >> 2] | 0) == 65343) : 0)e = (c[d >> 2] | 0) == 65381; else e = 1;
	                i = b;
	                return e & 1 | 0
	            }

	            function AL(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = DQ(c[d >> 2] | 0, 172704) | 0;
	                i = b;
	                return a | 0
	            }

	            function BL(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = DQ(c[d >> 2] | 0, 172720) | 0;
	                i = b;
	                return a | 0
	            }

	            function CL(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) == 187 | (c[d >> 2] | 0) == 8217 | (c[d >> 2] | 0) == 8221) {
	                    e = 1;
	                    f = e & 1;
	                    i = b;
	                    return f | 0
	                }
	                e = (c[d >> 2] | 0) == 8250;
	                f = e & 1;
	                i = b;
	                return f | 0
	            }

	            function DL(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!((c[d >> 2] | 0) == 171 | (c[d >> 2] | 0) == 8216) ? !((c[d >> 2] | 0) >= 8219 & (c[d >> 2] | 0) <= 8220 | (c[d >> 2] | 0) == 8223) : 0)e = (c[d >> 2] | 0) == 8249; else e = 1;
	                i = b;
	                return e & 1 | 0
	            }

	            function EL(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = DQ(c[d >> 2] | 0, 172736) | 0;
	                i = b;
	                return a | 0
	            }

	            function FL(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = DQ(c[d >> 2] | 0, 172752) | 0;
	                i = b;
	                return a | 0
	            }

	            function GL(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = DQ(c[d >> 2] | 0, 172768) | 0;
	                i = b;
	                return a | 0
	            }

	            function HL(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = DQ(c[d >> 2] | 0, 172784) | 0;
	                i = b;
	                return a | 0
	            }

	            function IL(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = DQ(c[d >> 2] | 0, 172800) | 0;
	                i = b;
	                return a | 0
	            }

	            function JL(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = DQ(c[d >> 2] | 0, 172816) | 0;
	                i = b;
	                return a | 0
	            }

	            function KL(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = DQ(c[d >> 2] | 0, 172832) | 0;
	                i = b;
	                return a | 0
	            }

	            function LL(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                a = DQ(c[d >> 2] | 0, 172848) | 0;
	                i = b;
	                return a | 0
	            }

	            function ML(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                i = b;
	                return (c[d >> 2] | 0) == 8232 | 0
	            }

	            function NL(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                i = b;
	                return (c[d >> 2] | 0) == 8233 | 0
	            }

	            function OL(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if ((c[d >> 2] | 0) == 32 | (c[d >> 2] | 0) == 160 | (c[d >> 2] | 0) == 5760 | (c[d >> 2] | 0) == 6158) {
	                    e = 1;
	                    f = e & 1;
	                    i = b;
	                    return f | 0
	                }
	                if ((c[d >> 2] | 0) >= 8192 & (c[d >> 2] | 0) <= 8202 | (c[d >> 2] | 0) == 8239 | (c[d >> 2] | 0) == 8287) {
	                    e = 1;
	                    f = e & 1;
	                    i = b;
	                    return f | 0
	                }
	                e = (c[d >> 2] | 0) == 12288;
	                f = e & 1;
	                i = b;
	                return f | 0
	            }

	            function PL(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 28 | 0;
	                f = d + 24 | 0;
	                g = d + 20 | 0;
	                h = d + 16 | 0;
	                j = d + 12 | 0;
	                k = d + 8 | 0;
	                l = d + 4 | 0;
	                m = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = 0;
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                c[h >> 2] = 0;
	                c[j >> 2] = (c[(c[f >> 2] | 0) + 4 >> 2] | 0) - 1;
	                c[m >> 2] = c[c[f >> 2] >> 2];
	                while (1) {
	                    if ((c[h >> 2] | 0) > (c[j >> 2] | 0)) {
	                        o = 10;
	                        break
	                    }
	                    c[k >> 2] = ((c[h >> 2] | 0) + (c[j >> 2] | 0) | 0) / 2 | 0;
	                    f = PT(c[g >> 2] | 0, c[(c[m >> 2] | 0) + (c[k >> 2] << 3) >> 2] | 0) | 0;
	                    c[l >> 2] = f;
	                    if (!f) {
	                        o = 6;
	                        break
	                    }
	                    f = c[k >> 2] | 0;
	                    if ((c[l >> 2] | 0) < 0) {
	                        c[j >> 2] = f - 1;
	                        continue
	                    } else {
	                        c[h >> 2] = f + 1;
	                        continue
	                    }
	                }
	                if ((o | 0) == 6) {
	                    c[e >> 2] = c[(c[m >> 2] | 0) + (c[k >> 2] << 3) + 4 >> 2];
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                } else if ((o | 0) == 10) {
	                    c[e >> 2] = 0;
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                return 0
	            }

	            function QL(a) {
	                a = a | 0;
	                var b = 0, d = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                b = i;
	                i = i + 48 | 0;
	                d = b + 36 | 0;
	                f = b + 32 | 0;
	                g = b + 28 | 0;
	                h = b + 24 | 0;
	                j = b + 20 | 0;
	                k = b + 16 | 0;
	                l = b + 12 | 0;
	                m = b + 8 | 0;
	                n = b + 4 | 0;
	                o = b;
	                c[f >> 2] = a;
	                c[h >> 2] = 0;
	                c[j >> 2] = 0;
	                c[k >> 2] = 0;
	                if (!(c[f >> 2] | 0)) {
	                    c[d >> 2] = -1;
	                    p = c[d >> 2] | 0;
	                    i = b;
	                    return p | 0
	                }
	                c[(c[f >> 2] | 0) + 68 >> 2] = 0;
	                a = c[f >> 2] | 0;
	                if (c[(c[f >> 2] | 0) + 4 >> 2] | 0) {
	                    c[d >> 2] = mM(a) | 0;
	                    p = c[d >> 2] | 0;
	                    i = b;
	                    return p | 0
	                }
	                if (!(c[a + 20 >> 2] | 0)) {
	                    c[d >> 2] = -1;
	                    p = c[d >> 2] | 0;
	                    i = b;
	                    return p | 0
	                }
	                a = c[f >> 2] | 0;
	                if (!(c[c[f >> 2] >> 2] | 0)) {
	                    c[a >> 2] = 1;
	                    do {
	                        c[g >> 2] = nM(c[f >> 2] | 0) | 0;
	                        q = c[f >> 2] | 0;
	                        if ((c[g >> 2] | 0) < 0) {
	                            r = 10;
	                            break
	                        }
	                        if (c[(c[q + 20 >> 2] | 0) + 52 >> 2] | 0)break;
	                        if ((c[c[f >> 2] >> 2] | 0) == 3)break
	                    } while ((c[(c[f >> 2] | 0) + 16 >> 2] | 0) != 5);
	                    if ((r | 0) == 10) {
	                        c[q >> 2] = 2;
	                        c[(c[f >> 2] | 0) + 16 >> 2] = 6;
	                        c[d >> 2] = -1;
	                        p = c[d >> 2] | 0;
	                        i = b;
	                        return p | 0
	                    }
	                    q = (c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0) != 0;
	                    do if (!(c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 52 >> 2] | 0)) {
	                        if (q)c[(c[f >> 2] | 0) + 64 >> 2] = c[(c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0) + 12 >> 2];
	                        s = c[f >> 2] | 0;
	                        if (c[(c[f >> 2] | 0) + 64 >> 2] | 0) {
	                            c[s + 16 >> 2] = 1;
	                            break
	                        }
	                        c[s >> 2] = 2;
	                        c[(c[f >> 2] | 0) + 16 >> 2] = 6;
	                        c[d >> 2] = -1;
	                        p = c[d >> 2] | 0;
	                        i = b;
	                        return p | 0
	                    } else {
	                        if (q)c[(c[f >> 2] | 0) + 64 >> 2] = c[(c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0) + 12 >> 2];
	                        if (!(c[(c[f >> 2] | 0) + 64 >> 2] | 0))c[(c[f >> 2] | 0) + 64 >> 2] = c[c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 64 >> 2] >> 2];
	                        c[(c[f >> 2] | 0) + 16 >> 2] = 1
	                    } while (0);
	                    c[(c[f >> 2] | 0) + 72 >> 2] = 0;
	                    c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 436 >> 2] = 5;
	                    r = 108
	                } else {
	                    c[j >> 2] = c[a + 16 >> 2];
	                    c[h >> 2] = c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 56 >> 2];
	                    c[k >> 2] = c[(c[f >> 2] | 0) + 64 >> 2]
	                }
	                a:while (1) {
	                    if ((r | 0) == 108) {
	                        r = 0;
	                        do if ((c[(c[f >> 2] | 0) + 64 >> 2] | 0) != 0 ? (c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 24 >> 2] | 0) == 0 : 0) {
	                            if ((c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 4 >> 2] | 0) != 3 ? (c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 4 >> 2] | 0) != 4 : 0)break;
	                            if (!(RL(c[f >> 2] | 0) | 0)) {
	                                r = 113;
	                                break a
	                            }
	                        } while (0);
	                        do if ((((c[(c[f >> 2] | 0) + 156 >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 64 >> 2] | 0) != 0 : 0) ? (c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) {
	                            if ((qy(c[(c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, 187376) | 0) == 0 ? (qy(c[(c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, 187408) | 0) == 0 : 0)break;
	                            if (!(c[(c[f >> 2] | 0) + 164 >> 2] | 0)) {
	                                a = Qv(c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0) | 0;
	                                c[(c[f >> 2] | 0) + 164 >> 2] = a;
	                                Sv(c[(c[f >> 2] | 0) + 164 >> 2] | 0, c[(c[f >> 2] | 0) + 188 >> 2] & -32769) | 0
	                            }
	                            if (!(RL(c[f >> 2] | 0) | 0)) {
	                                r = 123;
	                                break a
	                            }
	                            Wv(c[(c[f >> 2] | 0) + 164 >> 2] | 0, c[(c[f >> 2] | 0) + 64 >> 2] | 0) | 0
	                        } while (0);
	                        if ((c[(c[f >> 2] | 0) + 64 >> 2] | 0) != 0 ? (c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 4 >> 2] | 0) == 19 : 0) {
	                            a = (c[f >> 2] | 0) + 168 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1;
	                            continue
	                        }
	                        if ((c[(c[f >> 2] | 0) + 64 >> 2] | 0) != 0 ? (c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 4 >> 2] | 0) == 20 : 0) {
	                            a = (c[f >> 2] | 0) + 168 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + -1;
	                            continue
	                        }
	                        if ((((c[(c[f >> 2] | 0) + 64 >> 2] | 0) != 0 ? (c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 4 >> 2] | 0) == 5 : 0) ? (c[(c[f >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) ? (c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 16 >> 2] | 0) == 1 : 0) {
	                            if (((c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 12 >> 2] | 0) == 0 ? (c[c[(c[f >> 2] | 0) + 20 >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[c[(c[f >> 2] | 0) + 20 >> 2] >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) {
	                                a = Hb[c[(c[c[(c[f >> 2] | 0) + 20 >> 2] >> 2] | 0) + 20 >> 2] & 511](c[(c[f >> 2] | 0) + 20 >> 2] | 0, c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] | 0) | 0;
	                                c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 12 >> 2] = a
	                            }
	                            if (((c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[(c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) == 17 : 0) ? (c[(c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                                qM(c[f >> 2] | 0, c[(c[f >> 2] | 0) + 64 >> 2] | 0) | 0;
	                                c[(c[f >> 2] | 0) + 64 >> 2] = c[(c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2]
	                            }
	                        } else r = 143;
	                        if (((((r | 0) == 143 ? (r = 0, (c[(c[f >> 2] | 0) + 64 >> 2] | 0) != 0) : 0) ? (c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 4 >> 2] | 0) == 5 : 0) ? (c[(c[f >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) ? (c[(c[f >> 2] | 0) + 8 >> 2] | 0) != 0 : 0)rM(c[f >> 2] | 0);
	                        if (!(c[(c[f >> 2] | 0) + 64 >> 2] | 0)) {
	                            r = 153;
	                            break
	                        }
	                        if ((c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 4 >> 2] | 0) != 17) {
	                            r = 153;
	                            break
	                        }
	                        if (!(c[(c[f >> 2] | 0) + 92 >> 2] | 0)) {
	                            r = 153;
	                            break
	                        }
	                        if ((c[(c[(c[f >> 2] | 0) + 92 >> 2] | 0) + 12 >> 2] | 0) != (c[(c[f >> 2] | 0) + 64 >> 2] | 0)) {
	                            r = 153;
	                            break
	                        }
	                        a = sM(c[f >> 2] | 0) | 0;
	                        c[(c[f >> 2] | 0) + 64 >> 2] = a;
	                        a = (c[f >> 2] | 0) + 72 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1
	                    }
	                    if (!(c[(c[f >> 2] | 0) + 64 >> 2] | 0)) {
	                        r = 28;
	                        break
	                    }
	                    b:while (1) {
	                        if (!(c[(c[f >> 2] | 0) + 64 >> 2] | 0))break;
	                        if (c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 24 >> 2] | 0)break;
	                        if ((c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 56 >> 2] | 0) != (c[h >> 2] | 0))break;
	                        do if (((c[j >> 2] | 0) != 4 ? (c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 4 >> 2] | 0) != 5 : 0) {
	                            if (((c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[(c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) == 3 : 0) ? (c[(c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 12 >> 2] | 0) + 24 >> 2] | 0) == 0 : 0)break;
	                            if (((c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 4 >> 2] | 0) != 14 ? (c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 4 >> 2] | 0) != 9 : 0) ? (c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 4 >> 2] | 0) != 13 : 0)break b
	                        } while (0);
	                        if (((c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 52 >> 2] | 0) != 0 ? (c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 52 >> 2] | 0) != (c[(c[f >> 2] | 0) + 64 >> 2] | 0) : 0) ? (c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 52 >> 2] | 0) != (c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 20 >> 2] | 0) : 0)break;
	                        if ((c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 172 >> 2] | 0) == -1)break;
	                        c[g >> 2] = nM(c[f >> 2] | 0) | 0;
	                        t = c[f >> 2] | 0;
	                        if ((c[g >> 2] | 0) < 0) {
	                            r = 48;
	                            break a
	                        }
	                        if (!(c[t + 64 >> 2] | 0))break a
	                    }
	                    if (((((c[j >> 2] | 0) != 4 ? (c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 4 >> 2] | 0) != 5 : 0) ? (c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 4 >> 2] | 0) != 19 : 0) ? (c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 4 >> 2] | 0) != 14 : 0) {
	                        c[(c[f >> 2] | 0) + 64 >> 2] = c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 12 >> 2];
	                        a = (c[f >> 2] | 0) + 72 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + 1;
	                        c[(c[f >> 2] | 0) + 16 >> 2] = 1;
	                        r = 108;
	                        continue
	                    }
	                    a = (c[j >> 2] | 0) == 1;
	                    if (c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 24 >> 2] | 0) {
	                        if ((((a ? (c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 12 >> 2] | 0) == 0 : 0) ? ((e[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 58 >> 1] | 0) & 1 | 0) == 0 : 0) ? (c[(c[f >> 2] | 0) + 168 >> 2] | 0) <= 0 : 0) {
	                            c[(c[f >> 2] | 0) + 16 >> 2] = 2;
	                            r = 108;
	                            continue
	                        }
	                        if ((c[(c[f >> 2] | 0) + 8 >> 2] | 0) != 0 ? (c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 4 >> 2] | 0) == 1 : 0)oM(c[f >> 2] | 0);
	                        if ((c[(c[f >> 2] | 0) + 184 >> 2] | 0) > 0 ? ((e[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 58 >> 1] | 0) & 4 | 0) != 0 : 0) {
	                            q = (c[f >> 2] | 0) + 184 | 0;
	                            c[q >> 2] = (c[q >> 2] | 0) + -1
	                        }
	                        c[(c[f >> 2] | 0) + 64 >> 2] = c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 24 >> 2];
	                        c[(c[f >> 2] | 0) + 16 >> 2] = 1;
	                        if (c[(c[f >> 2] | 0) + 184 >> 2] | 0) {
	                            r = 108;
	                            continue
	                        }
	                        if (c[(c[f >> 2] | 0) + 168 >> 2] | 0) {
	                            r = 108;
	                            continue
	                        }
	                        if (c[(c[f >> 2] | 0) + 96 >> 2] | 0) {
	                            r = 108;
	                            continue
	                        }
	                        if (!(c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 28 >> 2] | 0)) {
	                            r = 108;
	                            continue
	                        }
	                        if ((c[(c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 28 >> 2] | 0) + 4 >> 2] | 0) == 14) {
	                            r = 108;
	                            continue
	                        }
	                        c[l >> 2] = c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 28 >> 2];
	                        if ((e[(c[l >> 2] | 0) + 58 >> 1] | 0) & 2) {
	                            r = 108;
	                            continue
	                        }
	                        Qh(c[l >> 2] | 0);
	                        pM(c[f >> 2] | 0, c[l >> 2] | 0);
	                        r = 108;
	                        continue
	                    }
	                    if (((a ? (c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 12 >> 2] | 0) == 0 : 0) ? ((e[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 58 >> 1] | 0) & 1 | 0) == 0 : 0) {
	                        c[(c[f >> 2] | 0) + 16 >> 2] = 2;
	                        r = 108;
	                        continue
	                    }
	                    if ((c[(c[f >> 2] | 0) + 8 >> 2] | 0) != 0 ? (c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 4 >> 2] | 0) == 1 : 0)oM(c[f >> 2] | 0);
	                    if ((c[(c[f >> 2] | 0) + 184 >> 2] | 0) > 0 ? ((e[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 58 >> 1] | 0) & 4 | 0) != 0 : 0) {
	                        a = (c[f >> 2] | 0) + 184 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + -1
	                    }
	                    c[(c[f >> 2] | 0) + 64 >> 2] = c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 20 >> 2];
	                    if (!(c[(c[f >> 2] | 0) + 64 >> 2] | 0)) {
	                        r = 91;
	                        break
	                    }
	                    if ((c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 4 >> 2] | 0) == 9) {
	                        r = 91;
	                        break
	                    }
	                    if ((c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 4 >> 2] | 0) == 21) {
	                        r = 91;
	                        break
	                    }
	                    if ((c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 4 >> 2] | 0) == 13) {
	                        r = 91;
	                        break
	                    }
	                    do if ((((c[(c[f >> 2] | 0) + 184 >> 2] | 0) == 0 ? (c[(c[f >> 2] | 0) + 168 >> 2] | 0) == 0 : 0) ? (c[(c[f >> 2] | 0) + 96 >> 2] | 0) == 0 : 0) ? (c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 16 >> 2] | 0) != 0 : 0) {
	                        if ((e[(c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 16 >> 2] | 0) + 58 >> 1] | 0) & 2)break;
	                        c[m >> 2] = c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 16 >> 2];
	                        Qh(c[m >> 2] | 0);
	                        pM(c[f >> 2] | 0, c[m >> 2] | 0)
	                    } while (0);
	                    a = (c[f >> 2] | 0) + 72 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + -1;
	                    c[(c[f >> 2] | 0) + 16 >> 2] = 4;
	                    r = 108
	                }
	                if ((r | 0) == 28)if ((c[c[f >> 2] >> 2] | 0) == 3) {
	                    c[d >> 2] = 0;
	                    p = c[d >> 2] | 0;
	                    i = b;
	                    return p | 0
	                } else {
	                    c[d >> 2] = -1;
	                    p = c[d >> 2] | 0;
	                    i = b;
	                    return p | 0
	                } else if ((r | 0) == 48) {
	                    c[t >> 2] = 2;
	                    c[(c[f >> 2] | 0) + 16 >> 2] = 6;
	                    c[d >> 2] = -1;
	                    p = c[d >> 2] | 0;
	                    i = b;
	                    return p | 0
	                } else if ((r | 0) == 91) {
	                    if ((c[c[f >> 2] >> 2] | 0) != 3 ? (c[g >> 2] = Sf(c[(c[f >> 2] | 0) + 20 >> 2] | 0, 187368, 0, 1) | 0, c[(c[f >> 2] | 0) + 16 >> 2] = 5, (c[g >> 2] | 0) != 0) : 0) {
	                        c[d >> 2] = -1;
	                        p = c[d >> 2] | 0;
	                        i = b;
	                        return p | 0
	                    }
	                    c[(c[f >> 2] | 0) + 64 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 72 >> 2] = -1;
	                    if ((((((c[k >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 184 >> 2] | 0) == 0 : 0) ? (c[(c[f >> 2] | 0) + 168 >> 2] | 0) == 0 : 0) ? (c[(c[f >> 2] | 0) + 96 >> 2] | 0) == 0 : 0) ? (c[(c[k >> 2] | 0) + 4 >> 2] | 0) != 14 : 0) ? ((e[(c[k >> 2] | 0) + 58 >> 1] | 0) & 2 | 0) == 0 : 0) {
	                        Qh(c[k >> 2] | 0);
	                        pM(c[f >> 2] | 0, c[k >> 2] | 0)
	                    }
	                } else if ((r | 0) == 113) {
	                    c[d >> 2] = -1;
	                    p = c[d >> 2] | 0;
	                    i = b;
	                    return p | 0
	                } else if ((r | 0) == 123) {
	                    c[d >> 2] = -1;
	                    p = c[d >> 2] | 0;
	                    i = b;
	                    return p | 0
	                } else if ((r | 0) == 153) {
	                    do if ((c[(c[f >> 2] | 0) + 8 >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 64 >> 2] | 0) != 0 : 0) {
	                        c[n >> 2] = c[(c[f >> 2] | 0) + 64 >> 2];
	                        if (((c[(c[n >> 2] | 0) + 4 >> 2] | 0) == 1 ? (c[(c[f >> 2] | 0) + 16 >> 2] | 0) != 2 : 0) ? (c[(c[f >> 2] | 0) + 16 >> 2] | 0) != 4 : 0) {
	                            tM(c[f >> 2] | 0);
	                            break
	                        }
	                        if ((c[(c[n >> 2] | 0) + 4 >> 2] | 0) != 3 ? (c[(c[n >> 2] | 0) + 4 >> 2] | 0) != 4 : 0)break;
	                        r = c[f >> 2] | 0;
	                        k = c[(c[n >> 2] | 0) + 40 >> 2] | 0;
	                        uM(r, k, xy(c[(c[n >> 2] | 0) + 40 >> 2] | 0) | 0)
	                    } while (0);
	                    c:do if (((c[(c[f >> 2] | 0) + 172 >> 2] | 0) > 0 ? (c[(c[f >> 2] | 0) + 16 >> 2] | 0) != 2 : 0) ? (c[(c[f >> 2] | 0) + 16 >> 2] | 0) != 4 : 0) {
	                        c[o >> 2] = 0;
	                        while (1) {
	                            if ((c[o >> 2] | 0) >= (c[(c[f >> 2] | 0) + 172 >> 2] | 0))break c;
	                            if ((NQ(c[(c[(c[f >> 2] | 0) + 180 >> 2] | 0) + (c[o >> 2] << 2) >> 2] | 0, c[(c[f >> 2] | 0) + 64 >> 2] | 0) | 0) == 1)break;
	                            c[o >> 2] = (c[o >> 2] | 0) + 1
	                        }
	                        SL(c[f >> 2] | 0) | 0
	                    } while (0);
	                    if (((c[(c[f >> 2] | 0) + 8 >> 2] | 0) == 4 ? (c[(c[f >> 2] | 0) + 148 >> 2] | 0) == 0 : 0) ? (c[(c[f >> 2] | 0) + 140 >> 2] | 0) != 0 : 0) {
	                        o = ((gB(c[(c[f >> 2] | 0) + 140 >> 2] | 0) | 0) != 0 ^ 1) & 1;
	                        c[(c[f >> 2] | 0) + 148 >> 2] = o
	                    }
	                    c[d >> 2] = 1;
	                    p = c[d >> 2] | 0;
	                    i = b;
	                    return p | 0
	                }
	                c[(c[f >> 2] | 0) + 16 >> 2] = 5;
	                c[d >> 2] = 0;
	                p = c[d >> 2] | 0;
	                i = b;
	                return p | 0
	            }

	            function RL(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                do if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 64 >> 2] | 0) != 0 : 0) {
	                    a = c[e >> 2] | 0;
	                    if (c[(c[e >> 2] | 0) + 4 >> 2] | 0) {
	                        c[d >> 2] = c[a + 64 >> 2];
	                        break
	                    }
	                    if (!(c[a + 20 >> 2] | 0)) {
	                        c[d >> 2] = 0;
	                        break
	                    }
	                    if ((vM(c[e >> 2] | 0) | 0) < 0) {
	                        c[d >> 2] = 0;
	                        break
	                    } else {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 64 >> 2];
	                        break
	                    }
	                } else f = 3; while (0);
	                if ((f | 0) == 3)c[d >> 2] = 0;
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function SL(a) {
	                a = a | 0;
	                var d = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[g >> 2] = a;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                a = c[g >> 2] | 0;
	                if (c[(c[g >> 2] | 0) + 68 >> 2] | 0)c[h >> 2] = c[a + 68 >> 2]; else c[h >> 2] = c[a + 64 >> 2];
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 9 ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 14 : 0) {
	                    a = (c[h >> 2] | 0) + 58 | 0;
	                    b[a >> 1] = e[a >> 1] | 0 | 2;
	                    a = (c[h >> 2] | 0) + 58 | 0;
	                    b[a >> 1] = e[a >> 1] | 0 | 4
	                }
	                a = (c[g >> 2] | 0) + 184 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + 1;
	                c[j >> 2] = c[(c[h >> 2] | 0) + 20 >> 2];
	                while (1) {
	                    if (!(c[j >> 2] | 0))break;
	                    if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                        a = (c[j >> 2] | 0) + 58 | 0;
	                        b[a >> 1] = e[a >> 1] | 0 | 2
	                    }
	                    c[j >> 2] = c[(c[j >> 2] | 0) + 20 >> 2]
	                }
	                c[f >> 2] = c[h >> 2];
	                k = c[f >> 2] | 0;
	                i = d;
	                return k | 0
	            }

	            function TL(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                c[j >> 2] = Cb[c[135744 >> 2] & 511](196) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    Db[c[135904 >> 2] & 511](c[33980] | 0, 187440, e);
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                cU(c[j >> 2] | 0, 0, 196) | 0;
	                c[(c[j >> 2] | 0) + 4 >> 2] = 0;
	                c[(c[j >> 2] | 0) + 104 >> 2] = 0;
	                c[(c[j >> 2] | 0) + 100 >> 2] = 0;
	                c[(c[j >> 2] | 0) + 96 >> 2] = 0;
	                c[(c[j >> 2] | 0) + 28 >> 2] = c[g >> 2];
	                b = My(100) | 0;
	                c[(c[j >> 2] | 0) + 84 >> 2] = b;
	                if (!(c[(c[j >> 2] | 0) + 84 >> 2] | 0)) {
	                    zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                    Db[c[135904 >> 2] & 511](c[33980] | 0, 187440, e);
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                b = Cb[c[135744 >> 2] & 511](128) | 0;
	                c[(c[j >> 2] | 0) + 24 >> 2] = b;
	                b = c[j >> 2] | 0;
	                if (!(c[(c[j >> 2] | 0) + 24 >> 2] | 0)) {
	                    Ry(c[b + 84 >> 2] | 0);
	                    zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                    Db[c[135904 >> 2] & 511](c[33980] | 0, 187440, e);
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                oQ(c[b + 24 >> 2] | 0, 2) | 0;
	                c[(c[j >> 2] | 0) + 32 >> 2] = c[(c[(c[j >> 2] | 0) + 24 >> 2] | 0) + 56 >> 2];
	                c[(c[(c[j >> 2] | 0) + 24 >> 2] | 0) + 56 >> 2] = 361;
	                c[(c[j >> 2] | 0) + 36 >> 2] = c[(c[(c[j >> 2] | 0) + 24 >> 2] | 0) + 60 >> 2];
	                c[(c[(c[j >> 2] | 0) + 24 >> 2] | 0) + 60 >> 2] = 362;
	                b = c[j >> 2] | 0;
	                if ((c[(c[(c[j >> 2] | 0) + 24 >> 2] | 0) + 108 >> 2] | 0) == -554844497) {
	                    c[(c[j >> 2] | 0) + 40 >> 2] = c[(c[b + 24 >> 2] | 0) + 116 >> 2];
	                    c[(c[(c[j >> 2] | 0) + 24 >> 2] | 0) + 116 >> 2] = 363;
	                    c[(c[j >> 2] | 0) + 44 >> 2] = c[(c[(c[j >> 2] | 0) + 24 >> 2] | 0) + 120 >> 2];
	                    c[(c[(c[j >> 2] | 0) + 24 >> 2] | 0) + 120 >> 2] = 364
	                } else {
	                    c[b + 40 >> 2] = 0;
	                    c[(c[j >> 2] | 0) + 44 >> 2] = 0
	                }
	                c[(c[j >> 2] | 0) + 48 >> 2] = c[(c[(c[j >> 2] | 0) + 24 >> 2] | 0) + 68 >> 2];
	                c[(c[(c[j >> 2] | 0) + 24 >> 2] | 0) + 68 >> 2] = 365;
	                c[(c[(c[j >> 2] | 0) + 24 >> 2] | 0) + 72 >> 2] = 365;
	                c[(c[j >> 2] | 0) + 52 >> 2] = c[(c[(c[j >> 2] | 0) + 24 >> 2] | 0) + 100 >> 2];
	                c[(c[(c[j >> 2] | 0) + 24 >> 2] | 0) + 100 >> 2] = 366;
	                c[c[j >> 2] >> 2] = 0;
	                c[(c[j >> 2] | 0) + 64 >> 2] = 0;
	                c[(c[j >> 2] | 0) + 68 >> 2] = 0;
	                if ((_y(c[(c[(c[j >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] | 0) | 0) >>> 0 < 4)Nk(c[g >> 2] | 0, 4) | 0;
	                g = (_y(c[(c[(c[j >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] | 0) | 0) >>> 0 >= 4;
	                b = c[(c[j >> 2] | 0) + 24 >> 2] | 0;
	                if (g) {
	                    g = Vy(c[(c[(c[j >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] | 0) | 0;
	                    a = Tf(b, 0, g, 4, c[h >> 2] | 0) | 0;
	                    c[(c[j >> 2] | 0) + 20 >> 2] = a;
	                    c[(c[j >> 2] | 0) + 56 >> 2] = 0;
	                    c[(c[j >> 2] | 0) + 60 >> 2] = 4
	                } else {
	                    a = Tf(b, 0, 0, 0, c[h >> 2] | 0) | 0;
	                    c[(c[j >> 2] | 0) + 20 >> 2] = a;
	                    c[(c[j >> 2] | 0) + 56 >> 2] = 0;
	                    c[(c[j >> 2] | 0) + 60 >> 2] = 0
	                }
	                if (!(c[(c[j >> 2] | 0) + 20 >> 2] | 0)) {
	                    Db[c[135904 >> 2] & 511](c[33980] | 0, 187440, e);
	                    Ry(c[(c[j >> 2] | 0) + 84 >> 2] | 0);
	                    zb[c[135736 >> 2] & 511](c[(c[j >> 2] | 0) + 24 >> 2] | 0);
	                    zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = d;
	                    return k | 0
	                } else {
	                    c[(c[(c[j >> 2] | 0) + 20 >> 2] | 0) + 436 >> 2] = 5;
	                    c[(c[(c[j >> 2] | 0) + 20 >> 2] | 0) + 272 >> 2] = c[j >> 2];
	                    c[(c[(c[j >> 2] | 0) + 20 >> 2] | 0) + 280 >> 2] = 1;
	                    c[(c[(c[j >> 2] | 0) + 20 >> 2] | 0) + 364 >> 2] = 1;
	                    c[(c[j >> 2] | 0) + 12 >> 2] = 2;
	                    c[(c[(c[j >> 2] | 0) + 20 >> 2] | 0) + 308 >> 2] = 1;
	                    c[(c[j >> 2] | 0) + 88 >> 2] = c[(c[(c[j >> 2] | 0) + 20 >> 2] | 0) + 296 >> 2];
	                    c[(c[j >> 2] | 0) + 156 >> 2] = 0;
	                    c[(c[j >> 2] | 0) + 176 >> 2] = 0;
	                    c[(c[j >> 2] | 0) + 180 >> 2] = 0;
	                    c[f >> 2] = c[j >> 2];
	                    k = c[f >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                return 0
	            }

	            function UL(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 16 | 0;
	                e = b + 12 | 0;
	                f = b + 8 | 0;
	                g = b + 4 | 0;
	                h = b;
	                c[e >> 2] = a;
	                c[h >> 2] = 0;
	                c[f >> 2] = Ck(c[e >> 2] | 0, 0) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    j = c[d >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                c[g >> 2] = TL(c[f >> 2] | 0, c[e >> 2] | 0) | 0;
	                if (!(c[g >> 2] | 0)) {
	                    yk(c[f >> 2] | 0);
	                    c[d >> 2] = 0;
	                    j = c[d >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                f = (c[g >> 2] | 0) + 12 | 0;
	                c[f >> 2] = c[f >> 2] | 1;
	                if (!(c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 180 >> 2] | 0))c[h >> 2] = Rk(c[e >> 2] | 0) | 0;
	                if ((c[h >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 180 >> 2] | 0) == 0 : 0) {
	                    e = my(c[h >> 2] | 0) | 0;
	                    c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 180 >> 2] = e
	                }
	                if (c[h >> 2] | 0)zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                c[d >> 2] = c[g >> 2];
	                j = c[d >> 2] | 0;
	                i = b;
	                return j | 0
	            }

	            function VL(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 116 >> 2] | 0) {
	                    VM(c[(c[d >> 2] | 0) + 116 >> 2] | 0);
	                    c[(c[d >> 2] | 0) + 116 >> 2] = 0
	                }
	                if (c[(c[d >> 2] | 0) + 120 >> 2] | 0) {
	                    if (!(c[(c[d >> 2] | 0) + 124 >> 2] | 0))fN(c[(c[d >> 2] | 0) + 120 >> 2] | 0);
	                    c[(c[d >> 2] | 0) + 120 >> 2] = 0
	                }
	                if (c[(c[d >> 2] | 0) + 152 >> 2] | 0) {
	                    jB(c[(c[d >> 2] | 0) + 152 >> 2] | 0) | 0;
	                    c[(c[d >> 2] | 0) + 152 >> 2] = 0
	                }
	                if (c[(c[d >> 2] | 0) + 140 >> 2] | 0) {
	                    if (!(c[(c[d >> 2] | 0) + 144 >> 2] | 0))ZA(c[(c[d >> 2] | 0) + 140 >> 2] | 0);
	                    c[(c[d >> 2] | 0) + 140 >> 2] = 0
	                }
	                if (c[(c[d >> 2] | 0) + 136 >> 2] | 0) {
	                    WA(c[(c[d >> 2] | 0) + 136 >> 2] | 0);
	                    c[(c[d >> 2] | 0) + 136 >> 2] = 0
	                }
	                if (c[(c[d >> 2] | 0) + 164 >> 2] | 0)Rv(c[(c[d >> 2] | 0) + 164 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 180 >> 2] | 0) {
	                    c[e >> 2] = 0;
	                    while (1) {
	                        if ((c[e >> 2] | 0) >= (c[(c[d >> 2] | 0) + 172 >> 2] | 0))break;
	                        if (c[(c[(c[d >> 2] | 0) + 180 >> 2] | 0) + (c[e >> 2] << 2) >> 2] | 0)EQ(c[(c[(c[d >> 2] | 0) + 180 >> 2] | 0) + (c[e >> 2] << 2) >> 2] | 0);
	                        c[e >> 2] = (c[e >> 2] | 0) + 1
	                    }
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 180 >> 2] | 0)
	                }
	                if (c[(c[d >> 2] | 0) + 76 >> 2] | 0)Rh(c[(c[d >> 2] | 0) + 76 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 20 >> 2] | 0) {
	                    if ((c[(c[d >> 2] | 0) + 88 >> 2] | 0) == (c[(c[(c[d >> 2] | 0) + 20 >> 2] | 0) + 296 >> 2] | 0))c[(c[d >> 2] | 0) + 88 >> 2] = 0;
	                    if (c[(c[(c[d >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0) {
	                        if (!(c[(c[d >> 2] | 0) + 80 >> 2] | 0))CM(c[d >> 2] | 0, c[(c[(c[d >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0);
	                        c[(c[(c[d >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] = 0
	                    }
	                    if ((c[(c[(c[d >> 2] | 0) + 20 >> 2] | 0) + 160 >> 2] | 0) != 0 ? (c[(c[(c[d >> 2] | 0) + 20 >> 2] | 0) + 156 >> 2] | 0) > 0 : 0) {
	                        zb[c[135736 >> 2] & 511](c[(c[(c[d >> 2] | 0) + 20 >> 2] | 0) + 160 >> 2] | 0);
	                        c[(c[(c[d >> 2] | 0) + 20 >> 2] | 0) + 160 >> 2] = 0;
	                        c[(c[(c[d >> 2] | 0) + 20 >> 2] | 0) + 156 >> 2] = 0
	                    }
	                    if (c[(c[d >> 2] | 0) + 12 >> 2] & 2)Ae(c[(c[d >> 2] | 0) + 20 >> 2] | 0)
	                }
	                if (c[(c[d >> 2] | 0) + 24 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 24 >> 2] | 0);
	                if ((c[(c[d >> 2] | 0) + 28 >> 2] | 0) != 0 ? (c[(c[d >> 2] | 0) + 12 >> 2] & 1 | 0) != 0 : 0)yk(c[(c[d >> 2] | 0) + 28 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 84 >> 2] | 0)Ry(c[(c[d >> 2] | 0) + 84 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 104 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 104 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 88 >> 2] | 0)zP(c[(c[d >> 2] | 0) + 88 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function WL(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                do if (c[f >> 2] | 0) {
	                    if (!(c[(c[f >> 2] | 0) + 64 >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        break
	                    }
	                    c[h >> 2] = cj(c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 32 >> 2] | 0, c[(c[f >> 2] | 0) + 64 >> 2] | 0, c[g >> 2] | 0) | 0;
	                    if (!(c[h >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        break
	                    } else {
	                        c[e >> 2] = my(c[(c[h >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        break
	                    }
	                } else c[e >> 2] = 0; while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function XL(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                a:do if (!(c[e >> 2] | 0))c[d >> 2] = -1; else {
	                    if (!(c[(c[e >> 2] | 0) + 64 >> 2] | 0)) {
	                        c[d >> 2] = 0;
	                        break
	                    }
	                    a = c[e >> 2] | 0;
	                    if (c[(c[e >> 2] | 0) + 68 >> 2] | 0)c[f >> 2] = c[a + 68 >> 2]; else c[f >> 2] = c[a + 64 >> 2];
	                    do switch (c[(c[f >> 2] | 0) + 4 >> 2] | 0) {
	                        case 7:
	                        {
	                            c[d >> 2] = 7;
	                            break a;
	                            break
	                        }
	                        case 2:
	                        case 18:
	                        {
	                            c[d >> 2] = 2;
	                            break a;
	                            break
	                        }
	                        case 1:
	                        {
	                            if ((c[(c[e >> 2] | 0) + 16 >> 2] | 0) != 2 ? (c[(c[e >> 2] | 0) + 16 >> 2] | 0) != 4 : 0) {
	                                c[d >> 2] = 1;
	                                break a
	                            }
	                            c[d >> 2] = 15;
	                            break a;
	                            break
	                        }
	                        case 5:
	                        {
	                            c[d >> 2] = 5;
	                            break a;
	                            break
	                        }
	                        case 12:
	                        {
	                            c[d >> 2] = 12;
	                            break a;
	                            break
	                        }
	                        case 21:
	                        case 13:
	                        case 9:
	                        {
	                            c[d >> 2] = 9;
	                            break a;
	                            break
	                        }
	                        case 6:
	                        {
	                            c[d >> 2] = 6;
	                            break a;
	                            break
	                        }
	                        case 11:
	                        {
	                            c[d >> 2] = 11;
	                            break a;
	                            break
	                        }
	                        case 3:
	                        {
	                            if (!(ij(c[(c[e >> 2] | 0) + 64 >> 2] | 0) | 0)) {
	                                c[d >> 2] = 3;
	                                break a
	                            }
	                            if (Vi(c[(c[e >> 2] | 0) + 64 >> 2] | 0) | 0) {
	                                c[d >> 2] = 14;
	                                break a
	                            } else {
	                                c[d >> 2] = 13;
	                                break a
	                            }
	                            break
	                        }
	                        case 14:
	                        case 10:
	                        {
	                            c[d >> 2] = 10;
	                            break a;
	                            break
	                        }
	                        case 4:
	                        {
	                            c[d >> 2] = 4;
	                            break a;
	                            break
	                        }
	                        case 20:
	                        case 19:
	                        case 17:
	                        case 16:
	                        case 15:
	                        {
	                            c[d >> 2] = 0;
	                            break a;
	                            break
	                        }
	                        case 8:
	                        {
	                            c[d >> 2] = 8;
	                            break a;
	                            break
	                        }
	                        default:
	                        {
	                            c[d >> 2] = -1;
	                            break a
	                        }
	                    } while (0)
	                } while (0);
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function YL(a) {
	                a = a | 0;
	                var b = 0, d = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                f = b;
	                c[f >> 2] = a;
	                do if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 64 >> 2] | 0) != 0 : 0) {
	                    if ((c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 4 >> 2] | 0) != 1) {
	                        c[d >> 2] = 0;
	                        break
	                    }
	                    if (c[(c[f >> 2] | 0) + 68 >> 2] | 0) {
	                        c[d >> 2] = 0;
	                        break
	                    }
	                    if (c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 12 >> 2] | 0) {
	                        c[d >> 2] = 0;
	                        break
	                    }
	                    if ((c[(c[f >> 2] | 0) + 16 >> 2] | 0) == 2) {
	                        c[d >> 2] = 0;
	                        break
	                    }
	                    if (c[(c[f >> 2] | 0) + 4 >> 2] | 0) {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                    if ((c[(c[f >> 2] | 0) + 168 >> 2] | 0) > 0) {
	                        c[d >> 2] = 1;
	                        break
	                    } else {
	                        c[d >> 2] = ((e[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 58 >> 1] | 0) & 1 | 0) != 0 & 1;
	                        break
	                    }
	                } else g = 3; while (0);
	                if ((g | 0) == 3)c[d >> 2] = -1;
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function ZL(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 64 >> 2] | 0) != 0 : 0) {
	                    a = c[e >> 2] | 0;
	                    if (c[(c[e >> 2] | 0) + 68 >> 2] | 0)c[f >> 2] = c[a + 68 >> 2]; else c[f >> 2] = c[a + 64 >> 2];
	                    a = c[f >> 2] | 0;
	                    if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 18) {
	                        c[g >> 2] = a;
	                        if (!(c[(c[g >> 2] | 0) + 12 >> 2] | 0)) {
	                            c[d >> 2] = AP(c[(c[e >> 2] | 0) + 88 >> 2] | 0, 187480, -1) | 0;
	                            h = c[d >> 2] | 0;
	                            i = b;
	                            return h | 0
	                        } else {
	                            c[d >> 2] = c[(c[g >> 2] | 0) + 12 >> 2];
	                            h = c[d >> 2] | 0;
	                            i = b;
	                            return h | 0
	                        }
	                    }
	                    if ((c[a + 4 >> 2] | 0) != 1 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 2 : 0) {
	                        c[d >> 2] = _L(c[e >> 2] | 0) | 0;
	                        h = c[d >> 2] | 0;
	                        i = b;
	                        return h | 0
	                    }
	                    c[d >> 2] = c[(c[f >> 2] | 0) + 8 >> 2];
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                c[d >> 2] = 0;
	                h = c[d >> 2] | 0;
	                i = b;
	                return h | 0
	            }

	            function _L(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                a:do if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 64 >> 2] | 0) != 0 : 0) {
	                    a = c[e >> 2] | 0;
	                    if (c[(c[e >> 2] | 0) + 68 >> 2] | 0)c[f >> 2] = c[a + 68 >> 2]; else c[f >> 2] = c[a + 64 >> 2];
	                    do switch (c[(c[f >> 2] | 0) + 4 >> 2] | 0) {
	                        case 20:
	                        case 19:
	                        case 17:
	                        case 16:
	                        case 15:
	                        {
	                            c[d >> 2] = 0;
	                            break a;
	                            break
	                        }
	                        case 11:
	                        {
	                            c[d >> 2] = AP(c[(c[e >> 2] | 0) + 88 >> 2] | 0, 187584, -1) | 0;
	                            break a;
	                            break
	                        }
	                        case 18:
	                        {
	                            c[g >> 2] = c[f >> 2];
	                            a = c[(c[e >> 2] | 0) + 88 >> 2] | 0;
	                            if (!(c[(c[g >> 2] | 0) + 12 >> 2] | 0)) {
	                                c[d >> 2] = AP(a, 187480, -1) | 0;
	                                break a
	                            } else {
	                                c[d >> 2] = BP(a, 187480, c[(c[g >> 2] | 0) + 12 >> 2] | 0) | 0;
	                                break a
	                            }
	                            break
	                        }
	                        case 21:
	                        case 13:
	                        case 9:
	                        {
	                            c[d >> 2] = AP(c[(c[e >> 2] | 0) + 88 >> 2] | 0, 187568, -1) | 0;
	                            break a;
	                            break
	                        }
	                        case 4:
	                        {
	                            c[d >> 2] = AP(c[(c[e >> 2] | 0) + 88 >> 2] | 0, 187536, -1) | 0;
	                            break a;
	                            break
	                        }
	                        case 2:
	                        case 1:
	                        {
	                            if ((c[(c[f >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                                c[d >> 2] = BP(c[(c[e >> 2] | 0) + 88 >> 2] | 0, c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0) | 0;
	                                break a
	                            }
	                            c[d >> 2] = c[(c[f >> 2] | 0) + 8 >> 2];
	                            break a;
	                            break
	                        }
	                        case 12:
	                        {
	                            c[d >> 2] = AP(c[(c[e >> 2] | 0) + 88 >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0, -1) | 0;
	                            break a;
	                            break
	                        }
	                        case 5:
	                        case 6:
	                        {
	                            c[d >> 2] = AP(c[(c[e >> 2] | 0) + 88 >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0, -1) | 0;
	                            break a;
	                            break
	                        }
	                        case 3:
	                        {
	                            c[d >> 2] = AP(c[(c[e >> 2] | 0) + 88 >> 2] | 0, 187528, -1) | 0;
	                            break a;
	                            break
	                        }
	                        case 8:
	                        {
	                            c[d >> 2] = AP(c[(c[e >> 2] | 0) + 88 >> 2] | 0, 187552, -1) | 0;
	                            break a;
	                            break
	                        }
	                        case 7:
	                        {
	                            c[d >> 2] = AP(c[(c[e >> 2] | 0) + 88 >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0, -1) | 0;
	                            break a;
	                            break
	                        }
	                        case 14:
	                        case 10:
	                        {
	                            c[d >> 2] = AP(c[(c[e >> 2] | 0) + 88 >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0, -1) | 0;
	                            break a;
	                            break
	                        }
	                        default:
	                        {
	                            c[d >> 2] = 0;
	                            break a
	                        }
	                    } while (0)
	                } else h = 3; while (0);
	                if ((h | 0) == 3)c[d >> 2] = 0;
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function $L(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 64 >> 2] | 0) != 0 : 0) {
	                    a = c[e >> 2] | 0;
	                    if (c[(c[e >> 2] | 0) + 68 >> 2] | 0)c[f >> 2] = c[a + 68 >> 2]; else c[f >> 2] = c[a + 64 >> 2];
	                    if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 18) {
	                        c[d >> 2] = AP(c[(c[e >> 2] | 0) + 88 >> 2] | 0, 187488, -1) | 0;
	                        g = c[d >> 2] | 0;
	                        i = b;
	                        return g | 0
	                    }
	                    if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 2 : 0) {
	                        c[d >> 2] = 0;
	                        g = c[d >> 2] | 0;
	                        i = b;
	                        return g | 0
	                    }
	                    if (c[(c[f >> 2] | 0) + 36 >> 2] | 0) {
	                        c[d >> 2] = AP(c[(c[e >> 2] | 0) + 88 >> 2] | 0, c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, -1) | 0;
	                        g = c[d >> 2] | 0;
	                        i = b;
	                        return g | 0
	                    } else {
	                        c[d >> 2] = 0;
	                        g = c[d >> 2] | 0;
	                        i = b;
	                        return g | 0
	                    }
	                }
	                c[d >> 2] = 0;
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function aM(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                do if (!(c[e >> 2] | 0))c[d >> 2] = -1; else {
	                    if (!(c[(c[e >> 2] | 0) + 64 >> 2] | 0)) {
	                        c[d >> 2] = 0;
	                        break
	                    }
	                    a = c[e >> 2] | 0;
	                    if (!(c[(c[e >> 2] | 0) + 68 >> 2] | 0)) {
	                        c[d >> 2] = c[a + 72 >> 2];
	                        break
	                    }
	                    if ((c[(c[a + 68 >> 2] | 0) + 4 >> 2] | 0) != 2 ? (c[(c[(c[e >> 2] | 0) + 68 >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                        c[d >> 2] = (c[(c[e >> 2] | 0) + 72 >> 2] | 0) + 2;
	                        break
	                    }
	                    c[d >> 2] = (c[(c[e >> 2] | 0) + 72 >> 2] | 0) + 1
	                } while (0);
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function bM(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                a:do if (!(c[e >> 2] | 0))c[d >> 2] = -1; else {
	                    if (!(c[(c[e >> 2] | 0) + 64 >> 2] | 0)) {
	                        c[d >> 2] = 0;
	                        break
	                    }
	                    a = c[e >> 2] | 0;
	                    if (c[(c[e >> 2] | 0) + 68 >> 2] | 0)c[f >> 2] = c[a + 68 >> 2]; else c[f >> 2] = c[a + 64 >> 2];
	                    switch (c[(c[f >> 2] | 0) + 4 >> 2] | 0) {
	                        case 18:
	                        case 8:
	                        case 7:
	                        case 4:
	                        case 3:
	                        case 2:
	                        {
	                            c[d >> 2] = 1;
	                            break a;
	                            break
	                        }
	                        default:
	                        {
	                            c[d >> 2] = 0;
	                            break a
	                        }
	                    }
	                } while (0);
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function cM(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b;
	                e = b + 16 | 0;
	                f = b + 12 | 0;
	                g = b + 8 | 0;
	                h = b + 4 | 0;
	                c[f >> 2] = a;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                if (!(c[(c[f >> 2] | 0) + 64 >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = b;
	                    return j | 0
	                }
	                a = c[f >> 2] | 0;
	                if (c[(c[f >> 2] | 0) + 68 >> 2] | 0)c[g >> 2] = c[a + 68 >> 2]; else c[g >> 2] = c[a + 64 >> 2];
	                switch (c[(c[g >> 2] | 0) + 4 >> 2] | 0) {
	                    case 8:
	                    case 7:
	                    case 4:
	                    case 3:
	                    {
	                        c[e >> 2] = c[(c[g >> 2] | 0) + 40 >> 2];
	                        j = c[e >> 2] | 0;
	                        i = b;
	                        return j | 0
	                    }
	                    case 2:
	                    {
	                        c[h >> 2] = c[g >> 2];
	                        if (((c[(c[h >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[(c[(c[h >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) == 3 : 0) ? (c[(c[(c[h >> 2] | 0) + 12 >> 2] | 0) + 24 >> 2] | 0) == 0 : 0) {
	                            c[e >> 2] = c[(c[(c[h >> 2] | 0) + 12 >> 2] | 0) + 40 >> 2];
	                            j = c[e >> 2] | 0;
	                            i = b;
	                            return j | 0
	                        }
	                        if (!(c[(c[f >> 2] | 0) + 84 >> 2] | 0)) {
	                            h = My(100) | 0;
	                            c[(c[f >> 2] | 0) + 84 >> 2] = h;
	                            if (!(c[(c[f >> 2] | 0) + 84 >> 2] | 0)) {
	                                Db[c[135904 >> 2] & 511](c[33980] | 0, 187608, d);
	                                c[e >> 2] = 0;
	                                j = c[e >> 2] | 0;
	                                i = b;
	                                return j | 0
	                            }
	                        } else Sy(c[(c[f >> 2] | 0) + 84 >> 2] | 0);
	                        Zi(c[(c[f >> 2] | 0) + 84 >> 2] | 0, c[g >> 2] | 0) | 0;
	                        c[e >> 2] = Vy(c[(c[f >> 2] | 0) + 84 >> 2] | 0) | 0;
	                        j = c[e >> 2] | 0;
	                        i = b;
	                        return j | 0
	                    }
	                    case 18:
	                    {
	                        c[e >> 2] = c[(c[g >> 2] | 0) + 8 >> 2];
	                        j = c[e >> 2] | 0;
	                        i = b;
	                        return j | 0
	                    }
	                    default:
	                    {
	                        c[e >> 2] = 0;
	                        j = c[e >> 2] | 0;
	                        i = b;
	                        return j | 0
	                    }
	                }
	                return 0
	            }

	            function dM(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = c[h >> 2];
	                a:do if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) {
	                    c[l >> 2] = c[(c[g >> 2] | 0) + 20 >> 2];
	                    h = c[k >> 2] | 0;
	                    if ((h | 0) == 4) {
	                        d = (c[l >> 2] | 0) + 16 | 0;
	                        if (c[j >> 2] | 0)c[d >> 2] = 1; else c[d >> 2] = 0;
	                        c[f >> 2] = 0;
	                        break
	                    } else if ((h | 0) == 2) {
	                        d = (c[l >> 2] | 0) + 276 | 0;
	                        b = c[d >> 2] | 0;
	                        if (!(c[j >> 2] | 0)) {
	                            if (b & 4) {
	                                a = (c[l >> 2] | 0) + 276 | 0;
	                                c[a >> 2] = (c[a >> 2] | 0) - 4
	                            }
	                        } else c[d >> 2] = b | 4;
	                        c[f >> 2] = 0;
	                        break
	                    } else if ((h | 0) == 1) {
	                        b = (c[l >> 2] | 0) + 276 | 0;
	                        do if (c[j >> 2] | 0) {
	                            if (!(c[b >> 2] | 0))if (c[c[g >> 2] >> 2] | 0) {
	                                c[f >> 2] = -1;
	                                break a
	                            } else {
	                                c[(c[l >> 2] | 0) + 276 >> 2] = 2;
	                                break
	                            }
	                        } else c[b >> 2] = 0; while (0);
	                        c[f >> 2] = 0;
	                        break
	                    } else if ((h | 0) == 3) {
	                        b = (c[l >> 2] | 0) + 104 | 0;
	                        if (c[j >> 2] | 0) {
	                            c[b >> 2] = 1;
	                            c[(c[g >> 2] | 0) + 8 >> 2] = 1
	                        } else c[b >> 2] = 0;
	                        c[f >> 2] = 0;
	                        break
	                    } else {
	                        c[f >> 2] = -1;
	                        break
	                    }
	                } else m = 3; while (0);
	                if ((m | 0) == 3)c[f >> 2] = -1;
	                i = e;
	                return c[f >> 2] | 0
	            }

	            function eM(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                do if (c[e >> 2] | 0) {
	                    a = c[e >> 2] | 0;
	                    if (c[(c[e >> 2] | 0) + 68 >> 2] | 0) {
	                        c[d >> 2] = c[a + 68 >> 2];
	                        break
	                    } else {
	                        c[d >> 2] = c[a + 64 >> 2];
	                        break
	                    }
	                } else c[d >> 2] = 0; while (0);
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function fM(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                b = HM(c[e >> 2] | 0, c[f >> 2] | 0, 0, 0) | 0;
	                i = d;
	                return b | 0
	            }

	            function gM(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                b = IM(c[e >> 2] | 0, c[f >> 2] | 0, 0, 0) | 0;
	                i = d;
	                return b | 0
	            }

	            function hM(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                do if (!(c[e >> 2] | 0))c[d >> 2] = -1; else {
	                    a = c[e >> 2] | 0;
	                    if ((c[(c[e >> 2] | 0) + 8 >> 2] | 0) == 2) {
	                        c[d >> 2] = (c[a + 128 >> 2] | 0) == 0 & 1;
	                        break
	                    }
	                    f = c[e >> 2] | 0;
	                    if ((c[a + 8 >> 2] | 0) == 4) {
	                        c[d >> 2] = (c[f + 148 >> 2] | 0) == 0 & 1;
	                        break
	                    }
	                    if ((c[f + 20 >> 2] | 0) != 0 ? (c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 104 >> 2] | 0) == 1 : 0) {
	                        c[d >> 2] = c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 100 >> 2];
	                        break
	                    }
	                    c[d >> 2] = 0
	                } while (0);
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function iM(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                g = i;
	                i = i + 48 | 0;
	                h = g;
	                j = g + 40 | 0;
	                k = g + 36 | 0;
	                l = g + 32 | 0;
	                m = g + 28 | 0;
	                n = g + 24 | 0;
	                o = g + 20 | 0;
	                p = g + 16 | 0;
	                q = g + 12 | 0;
	                r = g + 8 | 0;
	                s = g + 4 | 0;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                if (!(c[k >> 2] | 0)) {
	                    if (c[l >> 2] | 0)yk(c[l >> 2] | 0);
	                    c[j >> 2] = -1;
	                    t = c[j >> 2] | 0;
	                    i = g;
	                    return t | 0
	                }
	                c[o >> 2] = c[o >> 2] | 65536;
	                c[(c[k >> 2] | 0) + 4 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 96 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 188 >> 2] = c[o >> 2];
	                c[(c[k >> 2] | 0) + 8 >> 2] = 0;
	                if (((c[l >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 28 >> 2] | 0) != 0 : 0) ? (c[(c[k >> 2] | 0) + 12 >> 2] & 1 | 0) != 0 : 0) {
	                    yk(c[(c[k >> 2] | 0) + 28 >> 2] | 0);
	                    c[(c[k >> 2] | 0) + 28 >> 2] = 0;
	                    f = (c[k >> 2] | 0) + 12 | 0;
	                    c[f >> 2] = (c[f >> 2] | 0) - 1
	                }
	                if (c[l >> 2] | 0) {
	                    c[(c[k >> 2] | 0) + 28 >> 2] = c[l >> 2];
	                    f = (c[k >> 2] | 0) + 12 | 0;
	                    c[f >> 2] = c[f >> 2] | 1
	                }
	                if (!(c[(c[k >> 2] | 0) + 84 >> 2] | 0)) {
	                    f = My(100) | 0;
	                    c[(c[k >> 2] | 0) + 84 >> 2] = f
	                }
	                if (!(c[(c[k >> 2] | 0) + 84 >> 2] | 0)) {
	                    Db[c[135904 >> 2] & 511](c[33980] | 0, 187608, h);
	                    c[j >> 2] = -1;
	                    t = c[j >> 2] | 0;
	                    i = g;
	                    return t | 0
	                }
	                if (!(c[(c[k >> 2] | 0) + 24 >> 2] | 0)) {
	                    f = Cb[c[135744 >> 2] & 511](128) | 0;
	                    c[(c[k >> 2] | 0) + 24 >> 2] = f
	                }
	                if (!(c[(c[k >> 2] | 0) + 24 >> 2] | 0)) {
	                    Db[c[135904 >> 2] & 511](c[33980] | 0, 187608, h);
	                    c[j >> 2] = -1;
	                    t = c[j >> 2] | 0;
	                    i = g;
	                    return t | 0
	                }
	                oQ(c[(c[k >> 2] | 0) + 24 >> 2] | 0, 2) | 0;
	                c[(c[k >> 2] | 0) + 32 >> 2] = c[(c[(c[k >> 2] | 0) + 24 >> 2] | 0) + 56 >> 2];
	                c[(c[(c[k >> 2] | 0) + 24 >> 2] | 0) + 56 >> 2] = 361;
	                c[(c[k >> 2] | 0) + 36 >> 2] = c[(c[(c[k >> 2] | 0) + 24 >> 2] | 0) + 60 >> 2];
	                c[(c[(c[k >> 2] | 0) + 24 >> 2] | 0) + 60 >> 2] = 362;
	                f = c[k >> 2] | 0;
	                if ((c[(c[(c[k >> 2] | 0) + 24 >> 2] | 0) + 108 >> 2] | 0) == -554844497) {
	                    c[(c[k >> 2] | 0) + 40 >> 2] = c[(c[f + 24 >> 2] | 0) + 116 >> 2];
	                    c[(c[(c[k >> 2] | 0) + 24 >> 2] | 0) + 116 >> 2] = 363;
	                    c[(c[k >> 2] | 0) + 44 >> 2] = c[(c[(c[k >> 2] | 0) + 24 >> 2] | 0) + 120 >> 2];
	                    c[(c[(c[k >> 2] | 0) + 24 >> 2] | 0) + 120 >> 2] = 364
	                } else {
	                    c[f + 40 >> 2] = 0;
	                    c[(c[k >> 2] | 0) + 44 >> 2] = 0
	                }
	                c[(c[k >> 2] | 0) + 48 >> 2] = c[(c[(c[k >> 2] | 0) + 24 >> 2] | 0) + 68 >> 2];
	                c[(c[(c[k >> 2] | 0) + 24 >> 2] | 0) + 68 >> 2] = 365;
	                c[(c[(c[k >> 2] | 0) + 24 >> 2] | 0) + 72 >> 2] = 365;
	                c[(c[k >> 2] | 0) + 52 >> 2] = c[(c[(c[k >> 2] | 0) + 24 >> 2] | 0) + 100 >> 2];
	                c[(c[(c[k >> 2] | 0) + 24 >> 2] | 0) + 100 >> 2] = 366;
	                c[c[k >> 2] >> 2] = 0;
	                c[(c[k >> 2] | 0) + 64 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 68 >> 2] = 0;
	                if (c[l >> 2] | 0) {
	                    if ((_y(c[(c[(c[k >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] | 0) | 0) >>> 0 < 4)Nk(c[l >> 2] | 0, 4) | 0;
	                    do if (!(c[(c[k >> 2] | 0) + 20 >> 2] | 0)) {
	                        l = (_y(c[(c[(c[k >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] | 0) | 0) >>> 0 >= 4;
	                        f = c[(c[k >> 2] | 0) + 24 >> 2] | 0;
	                        if (l) {
	                            l = Vy(c[(c[(c[k >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] | 0) | 0;
	                            e = Tf(f, 0, l, 4, c[m >> 2] | 0) | 0;
	                            c[(c[k >> 2] | 0) + 20 >> 2] = e;
	                            c[(c[k >> 2] | 0) + 56 >> 2] = 0;
	                            c[(c[k >> 2] | 0) + 60 >> 2] = 4;
	                            break
	                        } else {
	                            e = Tf(f, 0, 0, 0, c[m >> 2] | 0) | 0;
	                            c[(c[k >> 2] | 0) + 20 >> 2] = e;
	                            c[(c[k >> 2] | 0) + 56 >> 2] = 0;
	                            c[(c[k >> 2] | 0) + 60 >> 2] = 0;
	                            break
	                        }
	                    } else {
	                        c[r >> 2] = 0;
	                        eg(c[(c[k >> 2] | 0) + 20 >> 2] | 0);
	                        c[q >> 2] = vk(c[r >> 2] | 0) | 0;
	                        if (!(c[q >> 2] | 0)) {
	                            c[j >> 2] = -1;
	                            t = c[j >> 2] | 0;
	                            i = g;
	                            return t | 0
	                        }
	                        c[p >> 2] = ue(c[(c[k >> 2] | 0) + 20 >> 2] | 0) | 0;
	                        if (!(c[p >> 2] | 0)) {
	                            yk(c[q >> 2] | 0);
	                            c[j >> 2] = -1;
	                            t = c[j >> 2] | 0;
	                            i = g;
	                            return t | 0
	                        }
	                        if (!(c[m >> 2] | 0))c[(c[p >> 2] | 0) + 4 >> 2] = 0; else {
	                            e = Jl(c[m >> 2] | 0) | 0;
	                            c[(c[p >> 2] | 0) + 4 >> 2] = e
	                        }
	                        c[c[p >> 2] >> 2] = c[q >> 2];
	                        iz(c[(c[q >> 2] | 0) + 16 >> 2] | 0, c[p >> 2] | 0) | 0;
	                        Oe(c[(c[k >> 2] | 0) + 20 >> 2] | 0, c[p >> 2] | 0) | 0;
	                        c[(c[k >> 2] | 0) + 60 >> 2] = 0
	                    } while (0);
	                    if (!(c[(c[k >> 2] | 0) + 20 >> 2] | 0)) {
	                        Db[c[135904 >> 2] & 511](c[33980] | 0, 187608, h);
	                        c[j >> 2] = -1;
	                        t = c[j >> 2] | 0;
	                        i = g;
	                        return t | 0
	                    }
	                }
	                h = c[(c[(c[k >> 2] | 0) + 20 >> 2] | 0) + 296 >> 2] | 0;
	                do if (c[(c[k >> 2] | 0) + 88 >> 2] | 0) {
	                    p = c[(c[k >> 2] | 0) + 88 >> 2] | 0;
	                    q = (c[(c[k >> 2] | 0) + 20 >> 2] | 0) + 296 | 0;
	                    if (!h) {
	                        c[q >> 2] = p;
	                        break
	                    }
	                    if ((p | 0) != (c[q >> 2] | 0)) {
	                        zP(c[(c[k >> 2] | 0) + 88 >> 2] | 0);
	                        c[(c[k >> 2] | 0) + 88 >> 2] = c[(c[(c[k >> 2] | 0) + 20 >> 2] | 0) + 296 >> 2]
	                    }
	                } else {
	                    if (!h) {
	                        q = xP() | 0;
	                        c[(c[(c[k >> 2] | 0) + 20 >> 2] | 0) + 296 >> 2] = q
	                    }
	                    c[(c[k >> 2] | 0) + 88 >> 2] = c[(c[(c[k >> 2] | 0) + 20 >> 2] | 0) + 296 >> 2]
	                } while (0);
	                c[(c[(c[k >> 2] | 0) + 20 >> 2] | 0) + 272 >> 2] = c[k >> 2];
	                c[(c[(c[k >> 2] | 0) + 20 >> 2] | 0) + 280 >> 2] = 1;
	                c[(c[(c[k >> 2] | 0) + 20 >> 2] | 0) + 364 >> 2] = 1;
	                c[(c[(c[k >> 2] | 0) + 20 >> 2] | 0) + 308 >> 2] = 1;
	                c[(c[(c[k >> 2] | 0) + 20 >> 2] | 0) + 436 >> 2] = 5;
	                if (c[(c[k >> 2] | 0) + 164 >> 2] | 0) {
	                    Rv(c[(c[k >> 2] | 0) + 164 >> 2] | 0);
	                    c[(c[k >> 2] | 0) + 164 >> 2] = 0
	                }
	                h = (c[k >> 2] | 0) + 156 | 0;
	                if (c[o >> 2] & 1024) {
	                    c[h >> 2] = 1;
	                    q = AP(c[(c[k >> 2] | 0) + 88 >> 2] | 0, 187696, -1) | 0;
	                    c[(c[k >> 2] | 0) + 160 >> 2] = q;
	                    c[o >> 2] = (c[o >> 2] | 0) - 1024
	                } else c[h >> 2] = 0;
	                c[(c[k >> 2] | 0) + 168 >> 2] = 0;
	                if (!(c[(c[k >> 2] | 0) + 180 >> 2] | 0)) {
	                    c[(c[k >> 2] | 0) + 172 >> 2] = 0;
	                    c[(c[k >> 2] | 0) + 176 >> 2] = 0
	                }
	                while (1) {
	                    if ((c[(c[k >> 2] | 0) + 172 >> 2] | 0) <= 0)break;
	                    h = (c[k >> 2] | 0) + 172 | 0;
	                    c[h >> 2] = (c[h >> 2] | 0) + -1;
	                    if (!(c[(c[(c[k >> 2] | 0) + 180 >> 2] | 0) + (c[(c[k >> 2] | 0) + 172 >> 2] << 2) >> 2] | 0))continue;
	                    EQ(c[(c[(c[k >> 2] | 0) + 180 >> 2] | 0) + (c[(c[k >> 2] | 0) + 172 >> 2] << 2) >> 2] | 0);
	                    c[(c[(c[k >> 2] | 0) + 180 >> 2] | 0) + (c[(c[k >> 2] | 0) + 172 >> 2] << 2) >> 2] = 0
	                }
	                if (c[o >> 2] & 16)c[(c[k >> 2] | 0) + 8 >> 2] = 1;
	                fg(c[(c[k >> 2] | 0) + 20 >> 2] | 0, c[o >> 2] | 0) | 0;
	                if ((c[n >> 2] | 0) != 0 ? (c[s >> 2] = Dd(c[n >> 2] | 0) | 0, (c[s >> 2] | 0) != 0) : 0)se(c[(c[k >> 2] | 0) + 20 >> 2] | 0, c[s >> 2] | 0) | 0;
	                if (((c[m >> 2] | 0) != 0 ? (c[(c[(c[k >> 2] | 0) + 20 >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[(c[(c[k >> 2] | 0) + 20 >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) == 0 : 0) {
	                    s = my(c[m >> 2] | 0) | 0;
	                    c[(c[(c[(c[k >> 2] | 0) + 20 >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] = s
	                }
	                c[(c[k >> 2] | 0) + 4 >> 2] = 0;
	                c[j >> 2] = 0;
	                t = c[j >> 2] | 0;
	                i = g;
	                return t | 0
	            }

	            function jM(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](196) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    Db[c[135904 >> 2] & 511](c[33980] | 0, 187440, b);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    cU(c[f >> 2] | 0, 0, 196) | 0;
	                    c[(c[f >> 2] | 0) + 96 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 28 >> 2] = 0;
	                    c[c[f >> 2] >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 64 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 68 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 56 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 60 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 12 >> 2] = 2;
	                    c[(c[f >> 2] | 0) + 4 >> 2] = c[e >> 2];
	                    c[(c[f >> 2] | 0) + 16 >> 2] = 0;
	                    e = xP() | 0;
	                    c[(c[f >> 2] | 0) + 88 >> 2] = e;
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function kM(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 28 | 0;
	                j = g + 24 | 0;
	                k = g + 20 | 0;
	                l = g + 16 | 0;
	                m = g + 12 | 0;
	                n = g + 8 | 0;
	                o = g + 4 | 0;
	                p = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[p >> 2] = Ik(c[j >> 2] | 0, c[k >> 2] | 0, 0) | 0;
	                if (!(c[p >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    q = c[h >> 2] | 0;
	                    i = g;
	                    return q | 0
	                }
	                c[o >> 2] = TL(c[p >> 2] | 0, c[l >> 2] | 0) | 0;
	                if (!(c[o >> 2] | 0)) {
	                    yk(c[p >> 2] | 0);
	                    c[h >> 2] = 0;
	                    q = c[h >> 2] | 0;
	                    i = g;
	                    return q | 0
	                } else {
	                    p = (c[o >> 2] | 0) + 12 | 0;
	                    c[p >> 2] = c[p >> 2] | 1;
	                    iM(c[o >> 2] | 0, 0, c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0) | 0;
	                    c[h >> 2] = c[o >> 2];
	                    q = c[h >> 2] | 0;
	                    i = g;
	                    return q | 0
	                }
	                return 0
	            }

	            function lM(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = UL(c[g >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } else {
	                    iM(c[k >> 2] | 0, 0, 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                    c[f >> 2] = c[k >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                return 0
	            }

	            function mM(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                if ((c[(c[e >> 2] | 0) + 16 >> 2] | 0) == 2) {
	                    c[d >> 2] = 0;
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                }
	                a:while (1) {
	                    a = c[e >> 2] | 0;
	                    do if (!(c[(c[e >> 2] | 0) + 64 >> 2] | 0)) {
	                        g = c[e >> 2] | 0;
	                        if (!(c[(c[a + 4 >> 2] | 0) + 12 >> 2] | 0)) {
	                            h = 5;
	                            break a
	                        }
	                        c[(c[e >> 2] | 0) + 64 >> 2] = c[(c[g + 4 >> 2] | 0) + 12 >> 2];
	                        c[(c[e >> 2] | 0) + 16 >> 2] = 0
	                    } else {
	                        if ((((c[a + 16 >> 2] | 0) != 4 ? (c[(c[(c[e >> 2] | 0) + 64 >> 2] | 0) + 4 >> 2] | 0) != 14 : 0) ? (c[(c[(c[e >> 2] | 0) + 64 >> 2] | 0) + 4 >> 2] | 0) != 19 : 0) ? (c[(c[(c[e >> 2] | 0) + 64 >> 2] | 0) + 4 >> 2] | 0) != 5 : 0) {
	                            j = c[(c[e >> 2] | 0) + 64 >> 2] | 0;
	                            if (c[(c[(c[e >> 2] | 0) + 64 >> 2] | 0) + 12 >> 2] | 0) {
	                                c[(c[e >> 2] | 0) + 64 >> 2] = c[j + 12 >> 2];
	                                k = (c[e >> 2] | 0) + 72 | 0;
	                                c[k >> 2] = (c[k >> 2] | 0) + 1;
	                                c[(c[e >> 2] | 0) + 16 >> 2] = 0;
	                                break
	                            }
	                            if ((c[j + 4 >> 2] | 0) == 2) {
	                                c[(c[e >> 2] | 0) + 16 >> 2] = 4;
	                                break
	                            }
	                        }
	                        j = c[(c[e >> 2] | 0) + 64 >> 2] | 0;
	                        if (c[(c[(c[e >> 2] | 0) + 64 >> 2] | 0) + 24 >> 2] | 0) {
	                            c[(c[e >> 2] | 0) + 64 >> 2] = c[j + 24 >> 2];
	                            c[(c[e >> 2] | 0) + 16 >> 2] = 0;
	                            break
	                        }
	                        k = c[e >> 2] | 0;
	                        if (!(c[j + 20 >> 2] | 0)) {
	                            c[k + 16 >> 2] = 2;
	                            break
	                        }
	                        if ((c[(c[(c[k + 64 >> 2] | 0) + 20 >> 2] | 0) + 4 >> 2] | 0) == 9) {
	                            h = 20;
	                            break a
	                        }
	                        if ((c[(c[(c[(c[e >> 2] | 0) + 64 >> 2] | 0) + 20 >> 2] | 0) + 4 >> 2] | 0) == 13) {
	                            h = 20;
	                            break a
	                        }
	                        c[(c[e >> 2] | 0) + 64 >> 2] = c[(c[(c[e >> 2] | 0) + 64 >> 2] | 0) + 20 >> 2];
	                        k = (c[e >> 2] | 0) + 72 | 0;
	                        c[k >> 2] = (c[k >> 2] | 0) + -1;
	                        c[(c[e >> 2] | 0) + 16 >> 2] = 4
	                    } while (0);
	                    if ((c[(c[(c[e >> 2] | 0) + 64 >> 2] | 0) + 4 >> 2] | 0) == 19)continue;
	                    if ((c[(c[(c[e >> 2] | 0) + 64 >> 2] | 0) + 4 >> 2] | 0) != 20) {
	                        h = 25;
	                        break
	                    }
	                }
	                if ((h | 0) == 5) {
	                    c[g + 16 >> 2] = 2;
	                    c[d >> 2] = 0;
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                } else if ((h | 0) == 20) {
	                    c[(c[e >> 2] | 0) + 16 >> 2] = 2;
	                    c[d >> 2] = 0;
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                } else if ((h | 0) == 25) {
	                    c[d >> 2] = 1;
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                }
	                return 0
	            }

	            function nM(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 24 | 0;
	                e = b + 20 | 0;
	                f = b + 16 | 0;
	                g = b + 12 | 0;
	                h = b + 8 | 0;
	                j = b + 4 | 0;
	                k = b;
	                c[e >> 2] = a;
	                if ((c[(c[e >> 2] | 0) + 28 >> 2] | 0) != 0 ? (c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2] | 0) != 0 : 0) {
	                    c[j >> 2] = c[(c[e >> 2] | 0) + 16 >> 2];
	                    c[(c[e >> 2] | 0) + 16 >> 2] = -1;
	                    c[f >> 2] = c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + 16 >> 2];
	                    c[k >> 2] = Py(c[f >> 2] | 0) | 0;
	                    a:do {
	                        if ((c[(c[e >> 2] | 0) + 16 >> 2] | 0) != -1)break;
	                        a = _y(c[f >> 2] | 0) | 0;
	                        do if (a >>> 0 < ((c[(c[e >> 2] | 0) + 60 >> 2] | 0) + 512 | 0) >>> 0) {
	                            if ((c[c[e >> 2] >> 2] | 0) == 3)break a;
	                            c[g >> 2] = Nk(c[(c[e >> 2] | 0) + 28 >> 2] | 0, 4096) | 0;
	                            if ((c[g >> 2] | 0) == 0 & (c[k >> 2] | 0) == 2) {
	                                l = _y(c[f >> 2] | 0) | 0;
	                                if ((l | 0) != (c[(c[e >> 2] | 0) + 60 >> 2] | 0))break;
	                                c[c[e >> 2] >> 2] = 3;
	                                c[(c[e >> 2] | 0) + 16 >> 2] = c[j >> 2];
	                                break
	                            }
	                            if ((c[g >> 2] | 0) >= 0)if (!(c[g >> 2] | 0)) {
	                                m = 16;
	                                break a
	                            } else break;
	                            c[c[e >> 2] >> 2] = 3;
	                            c[(c[e >> 2] | 0) + 16 >> 2] = c[j >> 2];
	                            if (c[j >> 2] | 0) {
	                                m = 14;
	                                break a
	                            }
	                            if (c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0) {
	                                m = 14;
	                                break a
	                            }
	                        } while (0);
	                        a = _y(c[f >> 2] | 0) | 0;
	                        if (a >>> 0 < ((c[(c[e >> 2] | 0) + 60 >> 2] | 0) + 512 | 0) >>> 0) {
	                            m = 21;
	                            break
	                        }
	                        a = c[(c[e >> 2] | 0) + 20 >> 2] | 0;
	                        l = Vy(c[f >> 2] | 0) | 0;
	                        c[g >> 2] = Sf(a, l + (c[(c[e >> 2] | 0) + 60 >> 2] | 0) | 0, 512, 0) | 0;
	                        l = (c[e >> 2] | 0) + 60 | 0;
	                        c[l >> 2] = (c[l >> 2] | 0) + 512;
	                        if (c[g >> 2] | 0)c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 12 >> 2] = 0
	                    } while ((c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 12 >> 2] | 0) != 0);
	                    if ((m | 0) == 14) {
	                        c[d >> 2] = c[g >> 2];
	                        n = c[d >> 2] | 0;
	                        i = b;
	                        return n | 0
	                    } else if ((m | 0) == 16)c[c[e >> 2] >> 2] = 3; else if ((m | 0) == 21 ? (m = _y(c[f >> 2] | 0) | 0, c[h >> 2] = m - (c[(c[e >> 2] | 0) + 60 >> 2] | 0), m = c[(c[e >> 2] | 0) + 20 >> 2] | 0, l = Vy(c[f >> 2] | 0) | 0, c[g >> 2] = Sf(m, l + (c[(c[e >> 2] | 0) + 60 >> 2] | 0) | 0, c[h >> 2] | 0, 0) | 0, l = (c[e >> 2] | 0) + 60 | 0, c[l >> 2] = (c[l >> 2] | 0) + (c[h >> 2] | 0), (c[g >> 2] | 0) != 0) : 0)c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 12 >> 2] = 0;
	                    do if ((c[c[e >> 2] >> 2] | 0) == 1) {
	                        if ((((c[k >> 2] | 0) != 2 ? (c[(c[e >> 2] | 0) + 60 >> 2] | 0) >>> 0 >= 4096 : 0) ? (l = _y(c[f >> 2] | 0) | 0, (l - (c[(c[e >> 2] | 0) + 60 >> 2] | 0) | 0) >>> 0 <= 512) : 0) ? (c[g >> 2] = Ty(c[f >> 2] | 0, c[(c[e >> 2] | 0) + 60 >> 2] | 0) | 0, (c[g >> 2] | 0) >= 0) : 0) {
	                            l = (c[e >> 2] | 0) + 60 | 0;
	                            c[l >> 2] = (c[l >> 2] | 0) - (c[g >> 2] | 0)
	                        }
	                    } else if (((c[c[e >> 2] >> 2] | 0) == 3 ? (c[(c[e >> 2] | 0) + 16 >> 2] | 0) != 5 : 0) ? (l = _y(c[f >> 2] | 0) | 0, c[h >> 2] = l - (c[(c[e >> 2] | 0) + 60 >> 2] | 0), l = c[(c[e >> 2] | 0) + 20 >> 2] | 0, m = Vy(c[f >> 2] | 0) | 0, c[g >> 2] = Sf(l, m + (c[(c[e >> 2] | 0) + 60 >> 2] | 0) | 0, c[h >> 2] | 0, 1) | 0, m = _y(c[f >> 2] | 0) | 0, c[(c[e >> 2] | 0) + 60 >> 2] = m, c[(c[e >> 2] | 0) + 16 >> 2] = 5, (c[g >> 2] | 0) != 0) : 0) {
	                        if (c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 12 >> 2] | 0) {
	                            c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 12 >> 2] = 0;
	                            break
	                        }
	                        c[d >> 2] = -1;
	                        n = c[d >> 2] | 0;
	                        i = b;
	                        return n | 0
	                    } while (0);
	                    c[(c[e >> 2] | 0) + 16 >> 2] = c[j >> 2];
	                    if (!(c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 12 >> 2] | 0)) {
	                        c[c[e >> 2] >> 2] = 3;
	                        c[d >> 2] = -1;
	                        n = c[d >> 2] | 0;
	                        i = b;
	                        return n | 0
	                    } else {
	                        c[d >> 2] = 0;
	                        n = c[d >> 2] | 0;
	                        i = b;
	                        return n | 0
	                    }
	                }
	                c[d >> 2] = -1;
	                n = c[d >> 2] | 0;
	                i = b;
	                return n | 0
	            }

	            function oM(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[d >> 2] = a;
	                c[e >> 2] = c[(c[d >> 2] | 0) + 64 >> 2];
	                do if (((c[(c[d >> 2] | 0) + 8 >> 2] | 0) == 1 ? (c[(c[d >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) ? (c[(c[(c[d >> 2] | 0) + 20 >> 2] | 0) + 104 >> 2] | 0) == 1 : 0) {
	                    if ((c[(c[e >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                        c[f >> 2] = my(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0;
	                        c[f >> 2] = By(c[f >> 2] | 0, 187520) | 0;
	                        c[f >> 2] = By(c[f >> 2] | 0, c[(c[e >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        a = _m((c[(c[d >> 2] | 0) + 20 >> 2] | 0) + 108 | 0, c[(c[(c[d >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0, c[e >> 2] | 0, c[f >> 2] | 0) | 0;
	                        h = (c[(c[d >> 2] | 0) + 20 >> 2] | 0) + 100 | 0;
	                        c[h >> 2] = c[h >> 2] & a;
	                        if (!(c[f >> 2] | 0))break;
	                        zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                        break
	                    }
	                    a = _m((c[(c[d >> 2] | 0) + 20 >> 2] | 0) + 108 | 0, c[(c[(c[d >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0, c[e >> 2] | 0, c[(c[e >> 2] | 0) + 8 >> 2] | 0) | 0;
	                    h = (c[(c[d >> 2] | 0) + 20 >> 2] | 0) + 100 | 0;
	                    c[h >> 2] = c[h >> 2] & a
	                } while (0);
	                if ((c[(c[d >> 2] | 0) + 8 >> 2] | 0) != 2) {
	                    i = b;
	                    return
	                }
	                if (!(c[(c[d >> 2] | 0) + 120 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 132 >> 2] | 0) {
	                    if ((c[e >> 2] | 0) != (c[(c[d >> 2] | 0) + 132 >> 2] | 0)) {
	                        i = b;
	                        return
	                    }
	                    c[(c[d >> 2] | 0) + 132 >> 2] = 0;
	                    i = b;
	                    return
	                } else {
	                    c[g >> 2] = cN(c[(c[d >> 2] | 0) + 120 >> 2] | 0, c[(c[(c[d >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0, c[e >> 2] | 0) | 0;
	                    if ((c[g >> 2] | 0) == 1) {
	                        i = b;
	                        return
	                    }
	                    g = (c[d >> 2] | 0) + 128 | 0;
	                    c[g >> 2] = (c[g >> 2] | 0) + 1;
	                    i = b;
	                    return
	                }
	            }

	            function pM(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 20 >> 2] | 0) != 0 : 0)c[g >> 2] = c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 296 >> 2]; else c[g >> 2] = 0;
	                b = c[f >> 2] | 0;
	                if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 14) {
	                    Ph(b);
	                    i = d;
	                    return
	                }
	                a = c[f >> 2] | 0;
	                if ((c[b + 4 >> 2] | 0) == 18) {
	                    Jh(a);
	                    i = d;
	                    return
	                }
	                if ((c[a + 4 >> 2] | 0) == 2) {
	                    MM(c[e >> 2] | 0, c[f >> 2] | 0);
	                    i = d;
	                    return
	                }
	                if ((c[(c[f >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 5 : 0) {
	                    if ((c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 20 >> 2] | 0) == (c[f >> 2] | 0))NM(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 12 >> 2] | 0);
	                    c[(c[f >> 2] | 0) + 12 >> 2] = 0
	                }
	                if ((c[18774] | 0) != 0 & (c[33970] | 0) != 0)zb[c[135880 >> 2] & 511](c[f >> 2] | 0);
	                if (!(((c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 19 : 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 20 : 0))h = 21;
	                if ((h | 0) == 21 ? (c[(c[f >> 2] | 0) + 44 >> 2] | 0) != 0 : 0)OM(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 44 >> 2] | 0);
	                do if ((((((c[(c[f >> 2] | 0) + 40 >> 2] | 0) != ((c[f >> 2] | 0) + 44 | 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 1 : 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 19 : 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 20 : 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 5 : 0) ? (c[(c[f >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) {
	                    if ((c[g >> 2] | 0) != 0 ? (CP(c[g >> 2] | 0, c[(c[f >> 2] | 0) + 40 >> 2] | 0) | 0) != 0 : 0)break;
	                    zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 40 >> 2] | 0)
	                } while (0);
	                if (!(((c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 19 : 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 20 : 0))h = 35;
	                if ((h | 0) == 35 ? (c[(c[f >> 2] | 0) + 48 >> 2] | 0) != 0 : 0)Lh(c[(c[f >> 2] | 0) + 48 >> 2] | 0);
	                do if (((c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 3 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 8 : 0) ? (c[(c[f >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                    if ((c[g >> 2] | 0) != 0 ? (CP(c[g >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0) | 0) != 0 : 0)break;
	                    zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 8 >> 2] | 0)
	                } while (0);
	                if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                    if (c[e >> 2] | 0)h = 46
	                } else if ((c[e >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 3 : 0)h = 46;
	                if (((h | 0) == 46 ? (c[(c[e >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) ? (c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 368 >> 2] | 0) < 100 : 0) {
	                    c[(c[f >> 2] | 0) + 24 >> 2] = c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 372 >> 2];
	                    c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 372 >> 2] = c[f >> 2];
	                    h = (c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 368 | 0;
	                    c[h >> 2] = (c[h >> 2] | 0) + 1;
	                    i = d;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                i = d;
	                return
	            }

	            function qM(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                if ((c[(c[g >> 2] | 0) + 100 >> 2] | 0) <= 0 ? (c[(c[g >> 2] | 0) + 100 >> 2] = 10, b = Cb[c[135744 >> 2] & 511](c[(c[g >> 2] | 0) + 100 >> 2] << 2) | 0, c[(c[g >> 2] | 0) + 104 >> 2] = b, (c[(c[g >> 2] | 0) + 104 >> 2] | 0) == 0) : 0) {
	                    Db[c[135904 >> 2] & 511](c[33980] | 0, 187648, e);
	                    c[f >> 2] = 0;
	                    j = c[f >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                if ((c[(c[g >> 2] | 0) + 96 >> 2] | 0) >= (c[(c[g >> 2] | 0) + 100 >> 2] | 0) ? (b = (c[g >> 2] | 0) + 100 | 0, c[b >> 2] = c[b >> 2] << 1, b = Hb[c[135760 >> 2] & 511](c[(c[g >> 2] | 0) + 104 >> 2] | 0, c[(c[g >> 2] | 0) + 100 >> 2] << 2) | 0, c[(c[g >> 2] | 0) + 104 >> 2] = b, (c[(c[g >> 2] | 0) + 104 >> 2] | 0) == 0) : 0) {
	                    Db[c[135904 >> 2] & 511](c[33980] | 0, 187672, e);
	                    c[f >> 2] = 0;
	                    j = c[f >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[(c[(c[g >> 2] | 0) + 104 >> 2] | 0) + (c[(c[g >> 2] | 0) + 96 >> 2] << 2) >> 2] = c[h >> 2];
	                c[(c[g >> 2] | 0) + 92 >> 2] = c[h >> 2];
	                h = (c[g >> 2] | 0) + 96 | 0;
	                g = c[h >> 2] | 0;
	                c[h >> 2] = g + 1;
	                c[f >> 2] = g;
	                j = c[f >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function rM(a) {
	                a = a | 0;
	                var b = 0, d = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 16 | 0;
	                f = b + 12 | 0;
	                g = b + 8 | 0;
	                h = b + 4 | 0;
	                j = b;
	                c[d >> 2] = a;
	                c[f >> 2] = c[(c[d >> 2] | 0) + 64 >> 2];
	                c[g >> 2] = c[(c[d >> 2] | 0) + 64 >> 2];
	                c[h >> 2] = c[(c[d >> 2] | 0) + 20 >> 2];
	                a:while (1) {
	                    a = c[g >> 2] | 0;
	                    do if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 5) {
	                        if (((c[a + 12 >> 2] | 0) == 0 ? (c[c[h >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[c[h >> 2] >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) {
	                            k = Hb[c[(c[c[h >> 2] >> 2] | 0) + 20 >> 2] & 511](c[h >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0) | 0;
	                            c[(c[g >> 2] | 0) + 12 >> 2] = k
	                        }
	                        if (((c[(c[g >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) == 17 : 0) ? (c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                            qM(c[d >> 2] | 0, c[g >> 2] | 0) | 0;
	                            c[g >> 2] = c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2];
	                            break
	                        }
	                        if ((c[g >> 2] | 0) == (c[f >> 2] | 0)) {
	                            l = 41;
	                            break a
	                        }
	                        c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                        l = 18
	                    } else {
	                        k = c[g >> 2] | 0;
	                        if ((c[a + 4 >> 2] | 0) == 1) {
	                            c[(c[d >> 2] | 0) + 64 >> 2] = k;
	                            tM(c[d >> 2] | 0);
	                            l = 18;
	                            break
	                        }
	                        if ((c[k + 4 >> 2] | 0) != 3 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 4 : 0) {
	                            l = 18;
	                            break
	                        }
	                        k = c[d >> 2] | 0;
	                        m = c[(c[g >> 2] | 0) + 40 >> 2] | 0;
	                        uM(k, m, xy(c[(c[g >> 2] | 0) + 40 >> 2] | 0) | 0);
	                        l = 18
	                    } while (0);
	                    b:do if ((l | 0) == 18) {
	                        l = 0;
	                        a = c[g >> 2] | 0;
	                        if (c[(c[g >> 2] | 0) + 12 >> 2] | 0) {
	                            c[g >> 2] = c[a + 12 >> 2];
	                            break
	                        }
	                        if ((c[a + 4 >> 2] | 0) == 1)oM(c[d >> 2] | 0);
	                        if (c[(c[g >> 2] | 0) + 24 >> 2] | 0) {
	                            c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                            break
	                        }
	                        while (1) {
	                            c[g >> 2] = c[(c[g >> 2] | 0) + 20 >> 2];
	                            if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                                c:do if (!(c[(c[d >> 2] | 0) + 96 >> 2] | 0))while (1) {
	                                    a = c[(c[g >> 2] | 0) + 16 >> 2] | 0;
	                                    c[j >> 2] = a;
	                                    if (!a)break c;
	                                    if ((e[(c[j >> 2] | 0) + 58 >> 1] | 0) & 2)break c;
	                                    Qh(c[j >> 2] | 0);
	                                    pM(c[d >> 2] | 0, c[j >> 2] | 0)
	                                } while (0);
	                                c[(c[d >> 2] | 0) + 64 >> 2] = c[g >> 2];
	                                oM(c[d >> 2] | 0)
	                            }
	                            if (((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 17 ? (c[(c[d >> 2] | 0) + 92 >> 2] | 0) != 0 : 0) ? (c[(c[(c[d >> 2] | 0) + 92 >> 2] | 0) + 12 >> 2] | 0) == (c[g >> 2] | 0) : 0)c[g >> 2] = sM(c[d >> 2] | 0) | 0;
	                            if ((c[g >> 2] | 0) == (c[f >> 2] | 0))break b;
	                            n = c[g >> 2] | 0;
	                            if (c[(c[g >> 2] | 0) + 24 >> 2] | 0)break;
	                            if (!n)break b;
	                            if ((c[g >> 2] | 0) == (c[f >> 2] | 0))break b
	                        }
	                        c[g >> 2] = c[n + 24 >> 2]
	                    } while (0);
	                    if (!(c[g >> 2] | 0)) {
	                        l = 41;
	                        break
	                    }
	                    if ((c[g >> 2] | 0) == (c[f >> 2] | 0)) {
	                        l = 41;
	                        break
	                    }
	                }
	                if ((l | 0) == 41) {
	                    c[(c[d >> 2] | 0) + 64 >> 2] = c[f >> 2];
	                    i = b;
	                    return
	                }
	            }

	            function sM(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if ((c[(c[e >> 2] | 0) + 96 >> 2] | 0) <= 0) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = (c[e >> 2] | 0) + 96 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + -1;
	                a = c[e >> 2] | 0;
	                if ((c[(c[e >> 2] | 0) + 96 >> 2] | 0) > 0)c[(c[e >> 2] | 0) + 92 >> 2] = c[(c[(c[e >> 2] | 0) + 104 >> 2] | 0) + ((c[a + 96 >> 2] | 0) - 1 << 2) >> 2]; else c[a + 92 >> 2] = 0;
	                c[f >> 2] = c[(c[(c[e >> 2] | 0) + 104 >> 2] | 0) + (c[(c[e >> 2] | 0) + 96 >> 2] << 2) >> 2];
	                c[(c[(c[e >> 2] | 0) + 104 >> 2] | 0) + (c[(c[e >> 2] | 0) + 96 >> 2] << 2) >> 2] = 0;
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function tM(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b;
	                e = b + 16 | 0;
	                f = b + 12 | 0;
	                g = b + 8 | 0;
	                h = b + 4 | 0;
	                c[e >> 2] = a;
	                c[f >> 2] = c[(c[e >> 2] | 0) + 64 >> 2];
	                do if (((c[(c[e >> 2] | 0) + 8 >> 2] | 0) == 1 ? (c[(c[e >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) ? (c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 104 >> 2] | 0) == 1 : 0) {
	                    if ((c[(c[f >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                        c[g >> 2] = my(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0;
	                        c[g >> 2] = By(c[g >> 2] | 0, 187520) | 0;
	                        c[g >> 2] = By(c[g >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        a = Ym((c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 108 | 0, c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0, c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                        j = (c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 100 | 0;
	                        c[j >> 2] = c[j >> 2] & a;
	                        if (!(c[g >> 2] | 0))break;
	                        zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                        break
	                    }
	                    a = Ym((c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 108 | 0, c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0, c[f >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0) | 0;
	                    j = (c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 100 | 0;
	                    c[j >> 2] = c[j >> 2] & a
	                } while (0);
	                if ((c[(c[e >> 2] | 0) + 8 >> 2] | 0) != 2) {
	                    i = b;
	                    return
	                }
	                if (!(c[(c[e >> 2] | 0) + 120 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[e >> 2] | 0) + 132 >> 2] | 0) {
	                    i = b;
	                    return
	                }
	                c[h >> 2] = aN(c[(c[e >> 2] | 0) + 120 >> 2] | 0, c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0, c[f >> 2] | 0) | 0;
	                do if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = RL(c[e >> 2] | 0) | 0;
	                    if (!(c[f >> 2] | 0)) {
	                        Wa(187736, d | 0) | 0;
	                        c[h >> 2] = -1;
	                        break
	                    } else {
	                        c[h >> 2] = dN(c[(c[e >> 2] | 0) + 120 >> 2] | 0, c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0, c[f >> 2] | 0) | 0;
	                        c[(c[e >> 2] | 0) + 132 >> 2] = c[f >> 2];
	                        break
	                    }
	                } while (0);
	                if ((c[h >> 2] | 0) == 1) {
	                    i = b;
	                    return
	                }
	                h = (c[e >> 2] | 0) + 128 | 0;
	                c[h >> 2] = (c[h >> 2] | 0) + 1;
	                i = b;
	                return
	            }

	            function uM(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if (((c[(c[f >> 2] | 0) + 8 >> 2] | 0) == 1 ? (c[(c[f >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) ? (c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 104 >> 2] | 0) == 1 : 0) {
	                    d = Zm((c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 108 | 0, c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                    b = (c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 100 | 0;
	                    c[b >> 2] = c[b >> 2] & d
	                }
	                if ((c[(c[f >> 2] | 0) + 8 >> 2] | 0) != 2) {
	                    i = e;
	                    return
	                }
	                if (!(c[(c[f >> 2] | 0) + 120 >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                if (c[(c[f >> 2] | 0) + 132 >> 2] | 0) {
	                    i = e;
	                    return
	                }
	                c[j >> 2] = bN(c[(c[f >> 2] | 0) + 120 >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                if ((c[j >> 2] | 0) == 1) {
	                    i = e;
	                    return
	                }
	                j = (c[f >> 2] | 0) + 128 | 0;
	                c[j >> 2] = (c[j >> 2] | 0) + 1;
	                i = e;
	                return
	            }

	            function vM(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                do if (((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 64 >> 2] | 0) != 0 : 0) ? (c[(c[e >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) {
	                    while (1) {
	                        if ((c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 172 >> 2] | 0) == -1) {
	                            g = 6;
	                            break
	                        }
	                        if (PM(c[(c[e >> 2] | 0) + 64 >> 2] | 0) | 0) {
	                            g = 8;
	                            break
	                        }
	                        if ((c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 56 >> 2] | 0) < (c[(c[e >> 2] | 0) + 72 >> 2] | 0)) {
	                            g = 10;
	                            break
	                        }
	                        if ((c[c[e >> 2] >> 2] | 0) == 3) {
	                            g = 12;
	                            break
	                        }
	                        c[f >> 2] = nM(c[e >> 2] | 0) | 0;
	                        h = c[e >> 2] | 0;
	                        if ((c[f >> 2] | 0) < 0) {
	                            g = 14;
	                            break
	                        }
	                        if ((c[h >> 2] | 0) == 3) {
	                            g = 16;
	                            break
	                        }
	                    }
	                    if ((g | 0) == 6) {
	                        c[d >> 2] = 1;
	                        break
	                    } else if ((g | 0) == 8) {
	                        c[d >> 2] = 1;
	                        break
	                    } else if ((g | 0) == 10) {
	                        c[d >> 2] = 1;
	                        break
	                    } else if ((g | 0) == 12) {
	                        c[d >> 2] = 1;
	                        break
	                    } else if ((g | 0) == 14) {
	                        c[h >> 2] = 2;
	                        c[d >> 2] = -1;
	                        break
	                    } else if ((g | 0) == 16) {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                } else g = 4; while (0);
	                if ((g | 0) == 4)c[d >> 2] = -1;
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function wM(a, e, f) {
	                a = a | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 16 | 0;
	                j = g + 12 | 0;
	                k = g + 8 | 0;
	                l = g + 4 | 0;
	                m = g;
	                c[h >> 2] = a;
	                c[j >> 2] = e;
	                c[k >> 2] = f;
	                c[l >> 2] = c[h >> 2];
	                c[m >> 2] = c[(c[l >> 2] | 0) + 272 >> 2];
	                if (((((((c[m >> 2] | 0) != 0 ? (c[(c[m >> 2] | 0) + 32 >> 2] | 0) != 0 : 0) ? (Db[c[(c[m >> 2] | 0) + 32 >> 2] & 511](c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0), (c[(c[l >> 2] | 0) + 52 >> 2] | 0) != 0) : 0) ? (c[(c[l >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) != 0 : 0) ? (d[c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 47 : 0) ? (d[(c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 62 : 0)b[(c[(c[l >> 2] | 0) + 52 >> 2] | 0) + 58 >> 1] = 1;
	                if (!(c[m >> 2] | 0)) {
	                    i = g;
	                    return
	                }
	                c[(c[m >> 2] | 0) + 16 >> 2] = 1;
	                i = g;
	                return
	            }

	            function xM(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[g >> 2] = c[e >> 2];
	                c[h >> 2] = c[(c[g >> 2] | 0) + 272 >> 2];
	                if (!(c[h >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if (!(c[(c[h >> 2] | 0) + 36 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                Ab[c[(c[h >> 2] | 0) + 36 >> 2] & 511](c[e >> 2] | 0, c[f >> 2] | 0);
	                i = d;
	                return
	            }

	            function yM(a, e, f, g, h, j, k, l, m) {
	                a = a | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                k = k | 0;
	                l = l | 0;
	                m = m | 0;
	                var n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0;
	                n = i;
	                i = i + 48 | 0;
	                o = n + 40 | 0;
	                p = n + 36 | 0;
	                q = n + 32 | 0;
	                r = n + 28 | 0;
	                s = n + 24 | 0;
	                t = n + 20 | 0;
	                u = n + 16 | 0;
	                v = n + 12 | 0;
	                w = n + 8 | 0;
	                x = n + 4 | 0;
	                y = n;
	                c[o >> 2] = a;
	                c[p >> 2] = e;
	                c[q >> 2] = f;
	                c[r >> 2] = g;
	                c[s >> 2] = h;
	                c[t >> 2] = j;
	                c[u >> 2] = k;
	                c[v >> 2] = l;
	                c[w >> 2] = m;
	                c[x >> 2] = c[o >> 2];
	                c[y >> 2] = c[(c[x >> 2] | 0) + 272 >> 2];
	                if (((((((c[y >> 2] | 0) != 0 ? (c[(c[y >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) ? (Eb[c[(c[y >> 2] | 0) + 40 >> 2] & 511](c[o >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0, c[r >> 2] | 0, c[s >> 2] | 0, c[t >> 2] | 0, c[u >> 2] | 0, c[v >> 2] | 0, c[w >> 2] | 0), (c[(c[x >> 2] | 0) + 52 >> 2] | 0) != 0) : 0) ? (c[(c[x >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[(c[x >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) != 0 : 0) ? (d[c[(c[(c[x >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] >> 0] | 0 | 0) == 47 : 0) ? (d[(c[(c[(c[x >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) + 1 >> 0] | 0 | 0) == 62 : 0)b[(c[(c[x >> 2] | 0) + 52 >> 2] | 0) + 58 >> 1] = 1;
	                if (!(c[y >> 2] | 0)) {
	                    i = n;
	                    return
	                }
	                c[(c[y >> 2] | 0) + 16 >> 2] = 1;
	                i = n;
	                return
	            }

	            function zM(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[l >> 2] = c[g >> 2];
	                c[m >> 2] = c[(c[l >> 2] | 0) + 272 >> 2];
	                if (!(c[m >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                if (!(c[(c[m >> 2] | 0) + 44 >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                Jb[c[(c[m >> 2] | 0) + 44 >> 2] & 511](c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0);
	                i = f;
	                return
	            }

	            function AM(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = c[f >> 2];
	                c[k >> 2] = c[(c[j >> 2] | 0) + 272 >> 2];
	                if (!(c[k >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                if (!(c[(c[k >> 2] | 0) + 48 >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                Db[c[(c[k >> 2] | 0) + 48 >> 2] & 511](c[f >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0);
	                i = e;
	                return
	            }

	            function BM(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = c[f >> 2];
	                c[k >> 2] = c[(c[j >> 2] | 0) + 272 >> 2];
	                if (!(c[k >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                if (!(c[(c[k >> 2] | 0) + 52 >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                Db[c[(c[k >> 2] | 0) + 52 >> 2] & 511](c[f >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0);
	                i = e;
	                return
	            }

	            function CM(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if ((c[18774] | 0) != 0 & (c[33970] | 0) != 0)zb[c[135880 >> 2] & 511](c[f >> 2] | 0);
	                if (c[(c[f >> 2] | 0) + 64 >> 2] | 0)QM(c[(c[f >> 2] | 0) + 64 >> 2] | 0);
	                c[(c[f >> 2] | 0) + 64 >> 2] = 0;
	                if (c[(c[f >> 2] | 0) + 68 >> 2] | 0)Jm(c[(c[f >> 2] | 0) + 68 >> 2] | 0);
	                c[(c[f >> 2] | 0) + 68 >> 2] = 0;
	                c[g >> 2] = c[(c[f >> 2] | 0) + 48 >> 2];
	                c[h >> 2] = c[(c[f >> 2] | 0) + 44 >> 2];
	                if ((c[h >> 2] | 0) == (c[g >> 2] | 0))c[g >> 2] = 0;
	                if (c[g >> 2] | 0) {
	                    Qh(c[(c[f >> 2] | 0) + 48 >> 2] | 0);
	                    c[(c[f >> 2] | 0) + 48 >> 2] = 0;
	                    Ph(c[g >> 2] | 0)
	                }
	                if (c[h >> 2] | 0) {
	                    Qh(c[(c[f >> 2] | 0) + 44 >> 2] | 0);
	                    c[(c[f >> 2] | 0) + 44 >> 2] = 0;
	                    Ph(c[h >> 2] | 0)
	                }
	                if (c[(c[f >> 2] | 0) + 12 >> 2] | 0)NM(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 12 >> 2] | 0);
	                if (c[(c[f >> 2] | 0) + 56 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 56 >> 2] | 0);
	                if (c[(c[f >> 2] | 0) + 8 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 8 >> 2] | 0);
	                if (c[(c[f >> 2] | 0) + 60 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 60 >> 2] | 0);
	                if (c[(c[f >> 2] | 0) + 52 >> 2] | 0)Lh(c[(c[f >> 2] | 0) + 52 >> 2] | 0);
	                if (c[(c[f >> 2] | 0) + 72 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 72 >> 2] | 0);
	                if (c[(c[f >> 2] | 0) + 80 >> 2] | 0)zP(c[(c[f >> 2] | 0) + 80 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                i = d;
	                return
	            }

	            function DM(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e;
	                g = e + 36 | 0;
	                h = e + 32 | 0;
	                j = e + 28 | 0;
	                k = e + 24 | 0;
	                l = e + 8 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = c[g >> 2];
	                c[l >> 2] = d;
	                c[k >> 2] = RM(c[h >> 2] | 0, l) | 0;
	                if (c[(c[j >> 2] | 0) + 108 >> 2] | 0)Jb[c[(c[j >> 2] | 0) + 108 >> 2] & 511](c[(c[j >> 2] | 0) + 112 >> 2] | 0, c[k >> 2] | 0, 2, 0); else {
	                    j = c[g >> 2] | 0;
	                    c[f >> 2] = c[k >> 2];
	                    JM(j, 187728, f)
	                }
	                if (!(c[k >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                i = e;
	                return
	            }

	            function EM(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e;
	                g = e + 36 | 0;
	                h = e + 32 | 0;
	                j = e + 28 | 0;
	                k = e + 24 | 0;
	                l = e + 8 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = c[g >> 2];
	                c[l >> 2] = d;
	                c[k >> 2] = RM(c[h >> 2] | 0, l) | 0;
	                if (c[(c[j >> 2] | 0) + 108 >> 2] | 0)Jb[c[(c[j >> 2] | 0) + 108 >> 2] & 511](c[(c[j >> 2] | 0) + 112 >> 2] | 0, c[k >> 2] | 0, 1, 0); else {
	                    j = c[g >> 2] | 0;
	                    c[f >> 2] = c[k >> 2];
	                    KM(j, 187728, f)
	                }
	                if (!(c[k >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                i = e;
	                return
	            }

	            function FM(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[g >> 2] = c[e >> 2];
	                e = c[g >> 2] | 0;
	                if (c[(c[g >> 2] | 0) + 192 >> 2] | 0) {
	                    Ab[c[e + 192 >> 2] & 511](c[(c[g >> 2] | 0) + 112 >> 2] | 0, c[f >> 2] | 0);
	                    i = d;
	                    return
	                } else {
	                    LM(e, c[f >> 2] | 0);
	                    i = d;
	                    return
	                }
	            }

	            function GM(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 28 | 0;
	                g = e + 24 | 0;
	                h = e + 20 | 0;
	                j = e + 16 | 0;
	                k = e + 12 | 0;
	                l = e + 8 | 0;
	                m = e + 4 | 0;
	                n = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if ((c[g >> 2] | 0) != 0 ? !((c[h >> 2] | 0) == 0 & (c[j >> 2] | 0) == 0) : 0) {
	                    if (c[h >> 2] | 0)c[c[h >> 2] >> 2] = 0;
	                    if (c[j >> 2] | 0)c[c[j >> 2] >> 2] = 0;
	                    c[k >> 2] = c[g >> 2];
	                    if ((c[(c[k >> 2] | 0) + 20 >> 2] | 0) != 0 ? (c[(c[(c[k >> 2] | 0) + 20 >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) {
	                        if (c[h >> 2] | 0)c[c[h >> 2] >> 2] = c[(c[(c[(c[k >> 2] | 0) + 20 >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2];
	                        if (c[j >> 2] | 0)c[c[j >> 2] >> 2] = c[(c[(c[(c[k >> 2] | 0) + 20 >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2];
	                        c[f >> 2] = 0;
	                        o = c[f >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    }
	                    if (!(c[(c[k >> 2] | 0) + 64 >> 2] | 0)) {
	                        c[f >> 2] = -1;
	                        o = c[f >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    }
	                    c[m >> 2] = 0;
	                    do if (c[j >> 2] | 0) {
	                        c[l >> 2] = Ni(c[(c[k >> 2] | 0) + 64 >> 2] | 0) | 0;
	                        if ((c[l >> 2] | 0) > 0) {
	                            c[c[j >> 2] >> 2] = c[l >> 2];
	                            break
	                        } else {
	                            c[m >> 2] = -1;
	                            break
	                        }
	                    } while (0);
	                    do if (c[h >> 2] | 0) {
	                        c[n >> 2] = c[(c[(c[k >> 2] | 0) + 64 >> 2] | 0) + 32 >> 2];
	                        if ((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 72 >> 2] | 0) != 0 : 0) {
	                            c[c[h >> 2] >> 2] = c[(c[n >> 2] | 0) + 72 >> 2];
	                            break
	                        }
	                        c[m >> 2] = -1
	                    } while (0);
	                    c[f >> 2] = c[m >> 2];
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                c[f >> 2] = -1;
	                o = c[f >> 2] | 0;
	                i = e;
	                return o | 0
	            }

	            function HM(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[f + 4 >> 2] = e;
	                if (!(c[h >> 2] | 0)) {
	                    c[g >> 2] = -1;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                if ((c[j >> 2] | 0) != 0 & (c[k >> 2] | 0) != 0) {
	                    c[g >> 2] = -1;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                do if ((c[j >> 2] | 0) != 0 | (c[k >> 2] | 0) != 0) {
	                    if ((c[c[h >> 2] >> 2] | 0) == 0 ? (c[(c[h >> 2] | 0) + 20 >> 2] | 0) != 0 : 0)break;
	                    c[g >> 2] = -1;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                } while (0);
	                if (c[(c[h >> 2] | 0) + 152 >> 2] | 0) {
	                    jB(c[(c[h >> 2] | 0) + 152 >> 2] | 0) | 0;
	                    c[(c[h >> 2] | 0) + 152 >> 2] = 0
	                }
	                if (c[(c[h >> 2] | 0) + 140 >> 2] | 0) {
	                    if (!(c[(c[h >> 2] | 0) + 144 >> 2] | 0))ZA(c[(c[h >> 2] | 0) + 140 >> 2] | 0);
	                    c[(c[h >> 2] | 0) + 140 >> 2] = 0
	                }
	                c[(c[h >> 2] | 0) + 144 >> 2] = 0;
	                if (c[(c[h >> 2] | 0) + 136 >> 2] | 0) {
	                    WA(c[(c[h >> 2] | 0) + 136 >> 2] | 0);
	                    c[(c[h >> 2] | 0) + 136 >> 2] = 0
	                }
	                if ((c[j >> 2] | 0) == 0 & (c[k >> 2] | 0) == 0) {
	                    c[g >> 2] = 0;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                if (c[j >> 2] | 0) {
	                    c[l >> 2] = XA(c[j >> 2] | 0) | 0;
	                    if (c[(c[h >> 2] | 0) + 108 >> 2] | 0)aB(c[l >> 2] | 0, 367, 368, c[h >> 2] | 0);
	                    j = $A(c[l >> 2] | 0) | 0;
	                    c[(c[h >> 2] | 0) + 136 >> 2] = j;
	                    YA(c[l >> 2] | 0);
	                    if (!(c[(c[h >> 2] | 0) + 136 >> 2] | 0)) {
	                        c[g >> 2] = -1;
	                        m = c[g >> 2] | 0;
	                        i = f;
	                        return m | 0
	                    }
	                    l = eB(c[(c[h >> 2] | 0) + 136 >> 2] | 0) | 0;
	                    c[(c[h >> 2] | 0) + 140 >> 2] = l;
	                    l = c[h >> 2] | 0;
	                    if (!(c[(c[h >> 2] | 0) + 140 >> 2] | 0)) {
	                        WA(c[l + 136 >> 2] | 0);
	                        c[(c[h >> 2] | 0) + 136 >> 2] = 0;
	                        c[g >> 2] = -1;
	                        m = c[g >> 2] | 0;
	                        i = f;
	                        return m | 0
	                    }
	                    j = iB(c[l + 140 >> 2] | 0, c[(c[h >> 2] | 0) + 20 >> 2] | 0, (c[(c[h >> 2] | 0) + 20 >> 2] | 0) + 4 | 0) | 0;
	                    c[(c[h >> 2] | 0) + 152 >> 2] = j;
	                    if (!(c[(c[h >> 2] | 0) + 152 >> 2] | 0)) {
	                        WA(c[(c[h >> 2] | 0) + 136 >> 2] | 0);
	                        c[(c[h >> 2] | 0) + 136 >> 2] = 0;
	                        ZA(c[(c[h >> 2] | 0) + 140 >> 2] | 0);
	                        c[(c[h >> 2] | 0) + 140 >> 2] = 0;
	                        c[g >> 2] = -1;
	                        m = c[g >> 2] | 0;
	                        i = f;
	                        return m | 0
	                    }
	                } else {
	                    c[(c[h >> 2] | 0) + 140 >> 2] = c[k >> 2];
	                    c[(c[h >> 2] | 0) + 144 >> 2] = 1;
	                    k = iB(c[(c[h >> 2] | 0) + 140 >> 2] | 0, c[(c[h >> 2] | 0) + 20 >> 2] | 0, (c[(c[h >> 2] | 0) + 20 >> 2] | 0) + 4 | 0) | 0;
	                    c[(c[h >> 2] | 0) + 152 >> 2] = k;
	                    if (!(c[(c[h >> 2] | 0) + 152 >> 2] | 0)) {
	                        c[(c[h >> 2] | 0) + 140 >> 2] = 0;
	                        c[(c[h >> 2] | 0) + 144 >> 2] = 0;
	                        c[g >> 2] = -1;
	                        m = c[g >> 2] | 0;
	                        i = f;
	                        return m | 0
	                    }
	                }
	                kB(c[(c[h >> 2] | 0) + 140 >> 2] | 0, 369, c[h >> 2] | 0);
	                if (c[(c[h >> 2] | 0) + 108 >> 2] | 0)bB(c[(c[h >> 2] | 0) + 140 >> 2] | 0, 367, 368, c[h >> 2] | 0);
	                if (c[(c[h >> 2] | 0) + 192 >> 2] | 0)dB(c[(c[h >> 2] | 0) + 140 >> 2] | 0, 370, c[h >> 2] | 0);
	                c[(c[h >> 2] | 0) + 148 >> 2] = 0;
	                c[(c[h >> 2] | 0) + 8 >> 2] = 4;
	                c[g >> 2] = 0;
	                m = c[g >> 2] | 0;
	                i = f;
	                return m | 0
	            }

	            function IM(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[f + 4 >> 2] = e;
	                if (!(c[h >> 2] | 0)) {
	                    c[g >> 2] = -1;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                if ((c[j >> 2] | 0) != 0 & (c[k >> 2] | 0) != 0) {
	                    c[g >> 2] = -1;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                do if ((c[j >> 2] | 0) != 0 | (c[k >> 2] | 0) != 0) {
	                    if ((c[c[h >> 2] >> 2] | 0) == 0 ? (c[(c[h >> 2] | 0) + 20 >> 2] | 0) != 0 : 0)break;
	                    c[g >> 2] = -1;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                } while (0);
	                if (c[(c[h >> 2] | 0) + 120 >> 2] | 0) {
	                    if (!(c[(c[h >> 2] | 0) + 124 >> 2] | 0))fN(c[(c[h >> 2] | 0) + 120 >> 2] | 0);
	                    c[(c[h >> 2] | 0) + 120 >> 2] = 0
	                }
	                c[(c[h >> 2] | 0) + 124 >> 2] = 0;
	                if (c[(c[h >> 2] | 0) + 116 >> 2] | 0) {
	                    VM(c[(c[h >> 2] | 0) + 116 >> 2] | 0);
	                    c[(c[h >> 2] | 0) + 116 >> 2] = 0
	                }
	                if ((c[j >> 2] | 0) == 0 & (c[k >> 2] | 0) == 0) {
	                    c[g >> 2] = 0;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                if (c[j >> 2] | 0) {
	                    c[l >> 2] = YM(c[j >> 2] | 0) | 0;
	                    if (c[(c[h >> 2] | 0) + 108 >> 2] | 0)$M(c[l >> 2] | 0, 367, 368, c[h >> 2] | 0);
	                    if (c[(c[h >> 2] | 0) + 192 >> 2] | 0)hN(c[(c[h >> 2] | 0) + 120 >> 2] | 0, 370, c[h >> 2] | 0);
	                    j = _M(c[l >> 2] | 0) | 0;
	                    c[(c[h >> 2] | 0) + 116 >> 2] = j;
	                    ZM(c[l >> 2] | 0);
	                    if (!(c[(c[h >> 2] | 0) + 116 >> 2] | 0)) {
	                        c[g >> 2] = -1;
	                        m = c[g >> 2] | 0;
	                        i = f;
	                        return m | 0
	                    }
	                    l = eN(c[(c[h >> 2] | 0) + 116 >> 2] | 0) | 0;
	                    c[(c[h >> 2] | 0) + 120 >> 2] = l;
	                    if (!(c[(c[h >> 2] | 0) + 120 >> 2] | 0)) {
	                        VM(c[(c[h >> 2] | 0) + 116 >> 2] | 0);
	                        c[(c[h >> 2] | 0) + 116 >> 2] = 0;
	                        c[g >> 2] = -1;
	                        m = c[g >> 2] | 0;
	                        i = f;
	                        return m | 0
	                    }
	                } else {
	                    c[(c[h >> 2] | 0) + 120 >> 2] = c[k >> 2];
	                    c[(c[h >> 2] | 0) + 124 >> 2] = 1
	                }
	                if (c[(c[h >> 2] | 0) + 108 >> 2] | 0)gN(c[(c[h >> 2] | 0) + 120 >> 2] | 0, 367, 368, c[h >> 2] | 0);
	                if (c[(c[h >> 2] | 0) + 192 >> 2] | 0)hN(c[(c[h >> 2] | 0) + 120 >> 2] | 0, 370, c[h >> 2] | 0);
	                c[(c[h >> 2] | 0) + 128 >> 2] = 0;
	                c[(c[h >> 2] | 0) + 132 >> 2] = 0;
	                c[(c[h >> 2] | 0) + 8 >> 2] = 2;
	                c[g >> 2] = 0;
	                m = c[g >> 2] | 0;
	                i = f;
	                return m | 0
	            }

	            function JM(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 28 | 0;
	                h = f + 24 | 0;
	                j = f + 8 | 0;
	                k = f;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[k >> 2] = xy(c[h >> 2] | 0) | 0;
	                if ((c[k >> 2] | 0) <= 1) {
	                    i = f;
	                    return
	                }
	                if ((a[(c[h >> 2] | 0) + ((c[k >> 2] | 0) - 2) >> 0] | 0) == 58) {
	                    i = f;
	                    return
	                }
	                c[j >> 2] = e;
	                e = c[g >> 2] | 0;
	                SM(e, 2, RM(c[h >> 2] | 0, j) | 0);
	                i = f;
	                return
	            }

	            function KM(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 28 | 0;
	                h = f + 24 | 0;
	                j = f + 8 | 0;
	                k = f;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[k >> 2] = xy(c[h >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                if ((a[(c[h >> 2] | 0) + ((c[k >> 2] | 0) - 1) >> 0] | 0) == 58) {
	                    i = f;
	                    return
	                }
	                c[j >> 2] = e;
	                e = c[g >> 2] | 0;
	                SM(e, 1, RM(c[h >> 2] | 0, j) | 0);
	                i = f;
	                return
	            }

	            function LM(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[g >> 2] = c[e >> 2];
	                c[h >> 2] = c[(c[g >> 2] | 0) + 272 >> 2];
	                if (!(c[f >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if (!(c[(c[h >> 2] | 0) + 192 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                Ab[c[(c[h >> 2] | 0) + 192 >> 2] & 511](c[(c[h >> 2] | 0) + 112 >> 2] | 0, c[f >> 2] | 0);
	                i = d;
	                return
	            }

	            function MM(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 20 >> 2] | 0) != 0 : 0)c[g >> 2] = c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 296 >> 2]; else c[g >> 2] = 0;
	                if (!(c[f >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if ((c[18774] | 0) != 0 & (c[33970] | 0) != 0)zb[c[135880 >> 2] & 511](c[f >> 2] | 0);
	                do if ((c[(c[f >> 2] | 0) + 20 >> 2] | 0) != 0 ? (c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 32 >> 2] | 0) != 0 : 0) {
	                    if ((c[(c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 32 >> 2] | 0) + 44 >> 2] | 0) == 0 ? (c[(c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 32 >> 2] | 0) + 48 >> 2] | 0) == 0 : 0)break;
	                    if (Em(c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 32 >> 2] | 0, c[(c[f >> 2] | 0) + 20 >> 2] | 0, c[f >> 2] | 0) | 0)TM(c[(c[(c[f >> 2] | 0) + 20 >> 2] | 0) + 32 >> 2] | 0, c[f >> 2] | 0) | 0
	                } while (0);
	                if (c[(c[f >> 2] | 0) + 12 >> 2] | 0)NM(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 12 >> 2] | 0);
	                do if (c[(c[f >> 2] | 0) + 8 >> 2] | 0) {
	                    if ((c[g >> 2] | 0) != 0 ? (CP(c[g >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0) | 0) != 0 : 0)break;
	                    zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 8 >> 2] | 0)
	                } while (0);
	                if (((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) ? (c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 376 >> 2] | 0) < 100 : 0) {
	                    c[(c[f >> 2] | 0) + 24 >> 2] = c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 380 >> 2];
	                    c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 380 >> 2] = c[f >> 2];
	                    g = (c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 376 | 0;
	                    c[g >> 2] = (c[g >> 2] | 0) + 1;
	                    i = d;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                i = d;
	                return
	            }

	            function NM(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 20 >> 2] | 0) != 0 : 0)c[h >> 2] = c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 296 >> 2]; else c[h >> 2] = 0;
	                if (!(c[f >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                b = c[f >> 2] | 0;
	                if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 18) {
	                    Lh(b);
	                    i = d;
	                    return
	                }
	                if ((c[b + 4 >> 2] | 0) != 9 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 13 : 0) {
	                    while (1) {
	                        if (!(c[f >> 2] | 0))break;
	                        c[g >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                        do if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 14) {
	                            if ((c[(c[f >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 5 : 0) {
	                                if ((c[(c[(c[f >> 2] | 0) + 12 >> 2] | 0) + 20 >> 2] | 0) == (c[f >> 2] | 0))NM(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 12 >> 2] | 0);
	                                c[(c[f >> 2] | 0) + 12 >> 2] = 0
	                            }
	                            if ((c[18774] | 0) != 0 & (c[33970] | 0) != 0)zb[c[135880 >> 2] & 511](c[f >> 2] | 0);
	                            if (!(((c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 19 : 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 20 : 0))j = 23;
	                            if ((j | 0) == 23 ? (j = 0, (c[(c[f >> 2] | 0) + 44 >> 2] | 0) != 0) : 0)OM(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 44 >> 2] | 0);
	                            do if ((((((c[(c[f >> 2] | 0) + 40 >> 2] | 0) != ((c[f >> 2] | 0) + 44 | 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 1 : 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 19 : 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 20 : 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 5 : 0) ? (c[(c[f >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) {
	                                if ((c[h >> 2] | 0) != 0 ? (CP(c[h >> 2] | 0, c[(c[f >> 2] | 0) + 40 >> 2] | 0) | 0) != 0 : 0)break;
	                                zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 40 >> 2] | 0)
	                            } while (0);
	                            if (!(((c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 19 : 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 20 : 0))j = 37;
	                            if ((j | 0) == 37 ? (j = 0, (c[(c[f >> 2] | 0) + 48 >> 2] | 0) != 0) : 0)Lh(c[(c[f >> 2] | 0) + 48 >> 2] | 0);
	                            do if (((c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 3 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 8 : 0) ? (c[(c[f >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                                if ((c[h >> 2] | 0) != 0 ? (CP(c[h >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0) | 0) != 0 : 0)break;
	                                zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 8 >> 2] | 0)
	                            } while (0);
	                            if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                                if (c[e >> 2] | 0)j = 48
	                            } else if ((c[e >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 3 : 0)j = 48;
	                            if (((j | 0) == 48 ? (j = 0, (c[(c[e >> 2] | 0) + 20 >> 2] | 0) != 0) : 0) ? (c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 368 >> 2] | 0) < 100 : 0) {
	                                c[(c[f >> 2] | 0) + 24 >> 2] = c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 372 >> 2];
	                                c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 372 >> 2] = c[f >> 2];
	                                b = (c[(c[e >> 2] | 0) + 20 >> 2] | 0) + 368 | 0;
	                                c[b >> 2] = (c[b >> 2] | 0) + 1;
	                                break
	                            }
	                            zb[c[135736 >> 2] & 511](c[f >> 2] | 0)
	                        } while (0);
	                        c[f >> 2] = c[g >> 2]
	                    }
	                    i = d;
	                    return
	                }
	                Th(c[f >> 2] | 0);
	                i = d;
	                return
	            }

	            function OM(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                while (1) {
	                    if (!(c[f >> 2] | 0))break;
	                    c[g >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                    MM(c[e >> 2] | 0, c[f >> 2] | 0);
	                    c[f >> 2] = c[g >> 2]
	                }
	                i = d;
	                return
	            }

	            function PM(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                do if (c[e >> 2] | 0) {
	                    if (c[(c[e >> 2] | 0) + 24 >> 2] | 0) {
	                        c[d >> 2] = c[(c[e >> 2] | 0) + 24 >> 2];
	                        break
	                    }
	                    while (1) {
	                        c[e >> 2] = c[(c[e >> 2] | 0) + 20 >> 2];
	                        if (!(c[e >> 2] | 0)) {
	                            f = 9;
	                            break
	                        }
	                        g = c[e >> 2] | 0;
	                        if (c[(c[e >> 2] | 0) + 24 >> 2] | 0) {
	                            f = 7;
	                            break
	                        }
	                        if (!g) {
	                            f = 9;
	                            break
	                        }
	                    }
	                    if ((f | 0) == 7) {
	                        c[d >> 2] = c[g + 24 >> 2];
	                        break
	                    } else if ((f | 0) == 9) {
	                        c[d >> 2] = c[e >> 2];
	                        break
	                    }
	                } else c[d >> 2] = 0; while (0);
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function QM(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                Kj(c[d >> 2] | 0, 371);
	                i = b;
	                return
	            }

	            function RM(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                d = i;
	                i = i + 64 | 0;
	                e = d;
	                f = d + 48 | 0;
	                g = d + 44 | 0;
	                h = d + 40 | 0;
	                j = d + 36 | 0;
	                k = d + 32 | 0;
	                l = d + 28 | 0;
	                m = d + 24 | 0;
	                n = d + 8 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = 0;
	                c[m >> 2] = 0;
	                while (1) {
	                    c[n >> 2] = c[c[h >> 2] >> 2];
	                    c[k >> 2] = LT(c[m >> 2] | 0, c[j >> 2] | 0, c[g >> 2] | 0, n) | 0;
	                    if ((c[k >> 2] | 0) < 0) {
	                        o = 3;
	                        break
	                    }
	                    if ((c[j >> 2] | 0) == 64e3 ? 1 : (c[k >> 2] | 0) < (c[j >> 2] | 0)) {
	                        o = 15;
	                        break
	                    }
	                    if ((c[k >> 2] | 0) < 64e3)c[j >> 2] = (c[k >> 2] | 0) + 1; else c[j >> 2] = 64e3;
	                    b = Hb[c[135760 >> 2] & 511](c[m >> 2] | 0, c[j >> 2] | 0) | 0;
	                    c[l >> 2] = b;
	                    if (!b) {
	                        o = 11;
	                        break
	                    }
	                    c[m >> 2] = c[l >> 2]
	                }
	                if ((o | 0) == 3) {
	                    Db[c[135904 >> 2] & 511](c[33980] | 0, 187704, e);
	                    if (c[m >> 2] | 0)zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                    c[f >> 2] = 0;
	                    p = c[f >> 2] | 0;
	                    i = d;
	                    return p | 0
	                } else if ((o | 0) == 11) {
	                    Db[c[135904 >> 2] & 511](c[33980] | 0, 187672, e);
	                    if (c[m >> 2] | 0)zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                    c[f >> 2] = 0;
	                    p = c[f >> 2] | 0;
	                    i = d;
	                    return p | 0
	                } else if ((o | 0) == 15) {
	                    c[f >> 2] = c[m >> 2];
	                    p = c[f >> 2] | 0;
	                    i = d;
	                    return p | 0
	                }
	                return 0
	            }

	            function SM(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = c[f >> 2];
	                c[k >> 2] = c[(c[j >> 2] | 0) + 272 >> 2];
	                if (!(c[h >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                if (c[(c[k >> 2] | 0) + 108 >> 2] | 0)Jb[c[(c[k >> 2] | 0) + 108 >> 2] & 511](c[(c[k >> 2] | 0) + 112 >> 2] | 0, c[h >> 2] | 0, c[g >> 2] | 0, c[j >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                i = e;
	                return
	            }

	            function TM(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                do if (!(c[f >> 2] | 0))c[e >> 2] = -1; else {
	                    if (!(c[g >> 2] | 0)) {
	                        c[e >> 2] = -1;
	                        break
	                    }
	                    c[h >> 2] = c[(c[f >> 2] | 0) + 64 >> 2];
	                    if (!(c[h >> 2] | 0)) {
	                        c[e >> 2] = -1;
	                        break
	                    }
	                    c[k >> 2] = _h(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] | 0, 1) | 0;
	                    if (!(c[k >> 2] | 0)) {
	                        c[e >> 2] = -1;
	                        break
	                    }
	                    c[j >> 2] = Rj(c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                    zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    if ((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 8 >> 2] | 0) == (c[g >> 2] | 0) : 0) {
	                        c[(c[j >> 2] | 0) + 12 >> 2] = c[(c[g >> 2] | 0) + 8 >> 2];
	                        c[(c[j >> 2] | 0) + 8 >> 2] = 0;
	                        c[e >> 2] = 0;
	                        break
	                    }
	                    c[e >> 2] = -1
	                } while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function UM(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                c[e >> 2] = 0;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 20 >> 2] | 0)c[e >> 2] = c[(c[(c[d >> 2] | 0) + 20 >> 2] | 0) + 80 >> 2];
	                do if ((c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 0 ? (c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                    if ((c[e >> 2] | 0) != 0 ? (CP(c[e >> 2] | 0, c[(c[d >> 2] | 0) + 4 >> 2] | 0) | 0) != 0 : 0)break;
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 4 >> 2] | 0)
	                } while (0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function VM(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 4 >> 2] | 0)jN(c[(c[d >> 2] | 0) + 4 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 8 >> 2] | 0)Th(c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 24 >> 2] | 0)kN(c[(c[d >> 2] | 0) + 24 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 28 >> 2] | 0)lN(c[(c[d >> 2] | 0) + 28 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 36 >> 2] | 0) {
	                    c[e >> 2] = 0;
	                    while (1) {
	                        if ((c[e >> 2] | 0) >= (c[(c[d >> 2] | 0) + 32 >> 2] | 0))break;
	                        mN(c[(c[(c[d >> 2] | 0) + 36 >> 2] | 0) + (c[e >> 2] << 2) >> 2] | 0);
	                        c[e >> 2] = (c[e >> 2] | 0) + 1
	                    }
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 36 >> 2] | 0)
	                }
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function WM() {
	                var a = 0, b = 0, d = 0;
	                a = i;
	                i = i + 16 | 0;
	                b = a + 4 | 0;
	                if (c[46940] | 0) {
	                    c[b >> 2] = 0;
	                    d = c[b >> 2] | 0;
	                    i = a;
	                    return d | 0
	                }
	                c[46942] = Ij(10) | 0;
	                if (!(c[46942] | 0)) {
	                    Db[c[135904 >> 2] & 511](c[33980] | 0, 187776, a);
	                    c[b >> 2] = -1;
	                    d = c[b >> 2] | 0;
	                    i = a;
	                    return d | 0
	                } else {
	                    sN(187824, 0, 372, 373, 374, 375, 376) | 0;
	                    sN(c[46968] | 0, 0, 377, 378, 379, 0, 0) | 0;
	                    c[46940] = 1;
	                    c[b >> 2] = 0;
	                    d = c[b >> 2] | 0;
	                    i = a;
	                    return d | 0
	                }
	                return 0
	            }

	            function XM() {
	                var a = 0;
	                a = i;
	                GH();
	                if (!(c[46940] | 0)) {
	                    i = a;
	                    return
	                }
	                Kj(c[46942] | 0, 380);
	                c[46940] = 0;
	                i = a;
	                return
	            }

	            function YM(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](148) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    xN(0, 187880);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    cU(c[f >> 2] | 0, 0, 148) | 0;
	                    a = my(c[e >> 2] | 0) | 0;
	                    c[(c[f >> 2] | 0) + 68 >> 2] = a;
	                    c[(c[f >> 2] | 0) + 4 >> 2] = c[33976];
	                    c[c[f >> 2] >> 2] = c[33980];
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function ZM(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 68 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 68 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 96 >> 2] | 0)yN(c[(c[d >> 2] | 0) + 96 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 56 >> 2] | 0)Kj(c[(c[d >> 2] | 0) + 56 >> 2] | 0, 0);
	                if (c[(c[d >> 2] | 0) + 60 >> 2] | 0)kN(c[(c[d >> 2] | 0) + 60 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 64 >> 2] | 0)lN(c[(c[d >> 2] | 0) + 64 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 108 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 108 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 124 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 124 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 84 >> 2] | 0) {
	                    c[e >> 2] = 0;
	                    while (1) {
	                        if ((c[e >> 2] | 0) >= (c[(c[d >> 2] | 0) + 76 >> 2] | 0))break;
	                        mN(c[(c[(c[d >> 2] | 0) + 84 >> 2] | 0) + (c[e >> 2] << 2) >> 2] | 0);
	                        c[e >> 2] = (c[e >> 2] | 0) + 1
	                    }
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 84 >> 2] | 0)
	                }
	                if ((c[(c[d >> 2] | 0) + 72 >> 2] | 0) != 0 ? (c[(c[d >> 2] | 0) + 144 >> 2] | 0) != 0 : 0)Th(c[(c[d >> 2] | 0) + 72 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function _M(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 20 | 0;
	                e = b + 16 | 0;
	                f = b + 12 | 0;
	                g = b + 8 | 0;
	                h = b + 4 | 0;
	                j = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                WM() | 0;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    k = c[d >> 2] | 0;
	                    i = b;
	                    return k | 0
	                }
	                a = c[e >> 2] | 0;
	                do if (c[(c[e >> 2] | 0) + 68 >> 2] | 0) {
	                    c[g >> 2] = gg(c[a + 68 >> 2] | 0, 0, 0) | 0;
	                    if (!(c[g >> 2] | 0)) {
	                        zN(c[e >> 2] | 0, 0, 1065, 187904, c[(c[e >> 2] | 0) + 68 >> 2] | 0, 0);
	                        c[d >> 2] = 0;
	                        k = c[d >> 2] | 0;
	                        i = b;
	                        return k | 0
	                    }
	                } else {
	                    l = c[e >> 2] | 0;
	                    if (c[a + 88 >> 2] | 0) {
	                        c[g >> 2] = hg(c[l + 88 >> 2] | 0, c[(c[e >> 2] | 0) + 92 >> 2] | 0, 0, 0, 0) | 0;
	                        if (c[g >> 2] | 0) {
	                            m = my(187992) | 0;
	                            c[(c[g >> 2] | 0) + 72 >> 2] = m;
	                            m = my(187992) | 0;
	                            c[(c[e >> 2] | 0) + 68 >> 2] = m;
	                            break
	                        }
	                        zN(c[e >> 2] | 0, 0, 1065, 187944, 0, 0);
	                        c[d >> 2] = 0;
	                        k = c[d >> 2] | 0;
	                        i = b;
	                        return k | 0
	                    } else {
	                        m = c[e >> 2] | 0;
	                        if (c[l + 72 >> 2] | 0) {
	                            c[g >> 2] = c[m + 72 >> 2];
	                            break
	                        }
	                        zN(m, 0, 1022, 188016, 0, 0);
	                        c[d >> 2] = 0;
	                        k = c[d >> 2] | 0;
	                        i = b;
	                        return k | 0
	                    }
	                } while (0);
	                c[(c[e >> 2] | 0) + 72 >> 2] = c[g >> 2];
	                c[g >> 2] = AN(c[e >> 2] | 0, c[g >> 2] | 0) | 0;
	                if (!(c[g >> 2] | 0)) {
	                    Th(c[(c[e >> 2] | 0) + 72 >> 2] | 0);
	                    c[(c[e >> 2] | 0) + 72 >> 2] = 0;
	                    c[d >> 2] = 0;
	                    k = c[d >> 2] | 0;
	                    i = b;
	                    return k | 0
	                }
	                c[h >> 2] = Pi(c[g >> 2] | 0) | 0;
	                a = c[e >> 2] | 0;
	                if (!(c[h >> 2] | 0)) {
	                    if (c[(c[e >> 2] | 0) + 68 >> 2] | 0)n = c[(c[e >> 2] | 0) + 68 >> 2] | 0; else n = 188088;
	                    zN(a, c[g >> 2] | 0, 1022, 188056, n, 0);
	                    Th(c[(c[e >> 2] | 0) + 72 >> 2] | 0);
	                    c[(c[e >> 2] | 0) + 72 >> 2] = 0;
	                    c[d >> 2] = 0;
	                    k = c[d >> 2] | 0;
	                    i = b;
	                    return k | 0
	                }
	                c[f >> 2] = BN(a, c[h >> 2] | 0) | 0;
	                h = c[e >> 2] | 0;
	                if (!(c[f >> 2] | 0)) {
	                    Th(c[h + 72 >> 2] | 0);
	                    c[(c[e >> 2] | 0) + 72 >> 2] = 0;
	                    c[d >> 2] = 0;
	                    k = c[d >> 2] | 0;
	                    i = b;
	                    return k | 0
	                }
	                if (c[h + 56 >> 2] | 0)Wj(c[(c[e >> 2] | 0) + 56 >> 2] | 0, 381, c[e >> 2] | 0);
	                h = c[f >> 2] | 0;
	                if ((c[(c[e >> 2] | 0) + 36 >> 2] | 0) > 0) {
	                    VM(h);
	                    c[(c[e >> 2] | 0) + 72 >> 2] = 0;
	                    Th(c[g >> 2] | 0);
	                    c[d >> 2] = 0;
	                    k = c[d >> 2] | 0;
	                    i = b;
	                    return k | 0
	                }
	                if ((c[h + 4 >> 2] | 0) != 0 ? (c[(c[(c[f >> 2] | 0) + 4 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                    if ((c[c[(c[(c[f >> 2] | 0) + 4 >> 2] | 0) + 12 >> 2] >> 2] | 0) != 20 ? (c[j >> 2] = DN(c[e >> 2] | 0, 0) | 0, (c[j >> 2] | 0) != 0) : 0) {
	                        c[c[j >> 2] >> 2] = 20;
	                        c[(c[j >> 2] | 0) + 24 >> 2] = c[(c[(c[f >> 2] | 0) + 4 >> 2] | 0) + 12 >> 2];
	                        c[(c[(c[f >> 2] | 0) + 4 >> 2] | 0) + 12 >> 2] = c[j >> 2]
	                    }
	                    EN(c[e >> 2] | 0, c[(c[(c[f >> 2] | 0) + 4 >> 2] | 0) + 12 >> 2] | 0) | 0
	                }
	                c[(c[f >> 2] | 0) + 8 >> 2] = c[g >> 2];
	                c[(c[e >> 2] | 0) + 72 >> 2] = 0;
	                c[(c[f >> 2] | 0) + 24 >> 2] = c[(c[e >> 2] | 0) + 60 >> 2];
	                c[(c[e >> 2] | 0) + 60 >> 2] = 0;
	                c[(c[f >> 2] | 0) + 28 >> 2] = c[(c[e >> 2] | 0) + 64 >> 2];
	                c[(c[e >> 2] | 0) + 64 >> 2] = 0;
	                c[(c[f >> 2] | 0) + 32 >> 2] = c[(c[e >> 2] | 0) + 76 >> 2];
	                c[(c[f >> 2] | 0) + 36 >> 2] = c[(c[e >> 2] | 0) + 84 >> 2];
	                c[(c[e >> 2] | 0) + 84 >> 2] = 0;
	                if ((c[(c[e >> 2] | 0) + 128 >> 2] | 0) == 1)c[(c[f >> 2] | 0) + 12 >> 2] = 1;
	                c[d >> 2] = c[f >> 2];
	                k = c[d >> 2] | 0;
	                i = b;
	                return k | 0
	            }

	            function $M(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 12 | 0;
	                h = f + 8 | 0;
	                j = f + 4 | 0;
	                k = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                if (!(c[g >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                c[(c[g >> 2] | 0) + 4 >> 2] = c[h >> 2];
	                c[(c[g >> 2] | 0) + 8 >> 2] = c[j >> 2];
	                c[(c[g >> 2] | 0) + 12 >> 2] = 0;
	                c[c[g >> 2] >> 2] = c[k >> 2];
	                i = f;
	                return
	            }

	            function aN(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 32 | 0;
	                g = e + 28 | 0;
	                h = e + 20 | 0;
	                j = e + 16 | 0;
	                k = e + 12 | 0;
	                l = e + 8 | 0;
	                m = e + 4 | 0;
	                n = e;
	                c[g >> 2] = a;
	                c[e + 24 >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = 1;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) {
	                    c[f >> 2] = -1;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                do if (!(c[(c[g >> 2] | 0) + 84 >> 2] | 0)) {
	                    c[k >> 2] = c[(c[g >> 2] | 0) + 20 >> 2];
	                    if (!(c[k >> 2] | 0)) {
	                        FN(c[g >> 2] | 0, 34, 0, 0, 0);
	                        c[f >> 2] = -1;
	                        o = c[f >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    }
	                    c[l >> 2] = c[(c[k >> 2] | 0) + 4 >> 2];
	                    if ((c[l >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                        c[n >> 2] = c[(c[l >> 2] | 0) + 12 >> 2];
	                        d = c[n >> 2] | 0;
	                        if (!(c[(c[n >> 2] | 0) + 52 >> 2] | 0)) {
	                            c[(c[g >> 2] | 0) + 108 >> 2] = d;
	                            c[f >> 2] = 0;
	                            o = c[f >> 2] | 0;
	                            i = e;
	                            return o | 0
	                        }
	                        c[m >> 2] = oz(c[d + 52 >> 2] | 0, 382, c[g >> 2] | 0) | 0;
	                        if (c[m >> 2] | 0) {
	                            HN(c[g >> 2] | 0, c[m >> 2] | 0) | 0;
	                            break
	                        }
	                        c[f >> 2] = -1;
	                        o = c[f >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    }
	                    FN(c[g >> 2] | 0, 34, 0, 0, 0);
	                    c[f >> 2] = -1;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                } while (0);
	                c[(c[g >> 2] | 0) + 104 >> 2] = c[h >> 2];
	                c[(c[g >> 2] | 0) + 100 >> 2] = 0;
	                m = c[(c[g >> 2] | 0) + 84 >> 2] | 0;
	                n = c[(c[h >> 2] | 0) + 8 >> 2] | 0;
	                if (c[(c[h >> 2] | 0) + 36 >> 2] | 0)c[j >> 2] = rz(m, n, c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[g >> 2] | 0) | 0; else c[j >> 2] = qz(m, n, c[g >> 2] | 0) | 0;
	                n = c[g >> 2] | 0;
	                do if ((c[j >> 2] | 0) >= 0) {
	                    if (!(c[n + 100 >> 2] | 0)) {
	                        c[j >> 2] = 0;
	                        break
	                    }
	                    if ((c[(c[g >> 2] | 0) + 100 >> 2] | 0) < 0) {
	                        c[j >> 2] = -1;
	                        break
	                    } else {
	                        c[j >> 2] = 1;
	                        break
	                    }
	                } else FN(n, 38, c[(c[h >> 2] | 0) + 8 >> 2] | 0, 0, 0); while (0);
	                c[f >> 2] = c[j >> 2];
	                o = c[f >> 2] | 0;
	                i = e;
	                return o | 0
	            }

	            function bN(a, b, e) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[f + 4 >> 2] = e;
	                c[k >> 2] = 1;
	                if ((c[h >> 2] | 0) != 0 ? !((c[j >> 2] | 0) == 0 ? 1 : (c[(c[h >> 2] | 0) + 84 >> 2] | 0) == 0) : 0) {
	                    a:while (1) {
	                        if (!(d[c[j >> 2] >> 0] | 0))break;
	                        do if ((d[c[j >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[j >> 2] >> 0] | 0 | 0) ? (d[c[j >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[j >> 2] >> 0] | 0 | 0) != 13)break a
	                        } while (0);
	                        c[j >> 2] = (c[j >> 2] | 0) + 1
	                    }
	                    if (!(d[c[j >> 2] >> 0] | 0)) {
	                        c[g >> 2] = 1;
	                        l = c[g >> 2] | 0;
	                        i = f;
	                        return l | 0
	                    }
	                    c[k >> 2] = qz(c[(c[h >> 2] | 0) + 84 >> 2] | 0, 188096, c[h >> 2] | 0) | 0;
	                    if ((c[k >> 2] | 0) < 0) {
	                        FN(c[h >> 2] | 0, 39, 188104, 0, 0);
	                        c[g >> 2] = -1;
	                        l = c[g >> 2] | 0;
	                        i = f;
	                        return l | 0
	                    } else {
	                        c[g >> 2] = 1;
	                        l = c[g >> 2] | 0;
	                        i = f;
	                        return l | 0
	                    }
	                }
	                c[g >> 2] = -1;
	                l = c[g >> 2] | 0;
	                i = f;
	                return l | 0
	            }

	            function cN(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[e + 12 >> 2] = b;
	                c[h >> 2] = d;
	                if ((c[g >> 2] | 0) != 0 ? !((c[h >> 2] | 0) == 0 ? 1 : (c[(c[g >> 2] | 0) + 84 >> 2] | 0) == 0) : 0) {
	                    c[k >> 2] = IN(c[g >> 2] | 0) | 0;
	                    c[j >> 2] = qz(c[k >> 2] | 0, 0, 0) | 0;
	                    do if (c[j >> 2] | 0)if ((c[j >> 2] | 0) < 0) {
	                        c[j >> 2] = -1;
	                        break
	                    } else {
	                        c[j >> 2] = 1;
	                        break
	                    } else {
	                        FN(c[g >> 2] | 0, 22, 188112, 0, 0);
	                        c[j >> 2] = -1
	                    } while (0);
	                    pz(c[k >> 2] | 0);
	                    c[f >> 2] = c[j >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[f >> 2] = -1;
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function dN(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[e + 12 >> 2] = b;
	                c[h >> 2] = d;
	                if ((c[g >> 2] | 0) != 0 ? !((c[h >> 2] | 0) == 0 ? 1 : (c[(c[g >> 2] | 0) + 108 >> 2] | 0) == 0) : 0) {
	                    c[k >> 2] = JN(c[g >> 2] | 0, c[(c[h >> 2] | 0) + 20 >> 2] | 0) | 0;
	                    if (!(c[k >> 2] | 0)) {
	                        c[f >> 2] = -1;
	                        l = c[f >> 2] | 0;
	                        i = e;
	                        return l | 0
	                    }
	                    c[(c[k >> 2] | 0) + 4 >> 2] = c[h >> 2];
	                    c[(c[g >> 2] | 0) + 60 >> 2] = c[k >> 2];
	                    c[(c[g >> 2] | 0) + 40 >> 2] = 0;
	                    c[j >> 2] = KN(c[g >> 2] | 0, c[(c[g >> 2] | 0) + 108 >> 2] | 0) | 0;
	                    if ((c[j >> 2] | 0) == 0 ? (c[(c[g >> 2] | 0) + 40 >> 2] | 0) == 0 : 0)c[j >> 2] = 1; else c[j >> 2] = -1;
	                    LN(c[g >> 2] | 0, c[(c[g >> 2] | 0) + 60 >> 2] | 0);
	                    c[(c[g >> 2] | 0) + 60 >> 2] = 0;
	                    c[f >> 2] = c[j >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                c[f >> 2] = -1;
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function eN(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](116) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    MN(0, 188120);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = (c[f >> 2] | 0) + 0 | 0;
	                h = a + 116 | 0;
	                do {
	                    c[a >> 2] = 0;
	                    a = a + 4 | 0
	                } while ((a | 0) < (h | 0));
	                c[(c[f >> 2] | 0) + 20 >> 2] = c[e >> 2];
	                c[(c[f >> 2] | 0) + 4 >> 2] = c[33976];
	                c[c[f >> 2] >> 2] = c[33980];
	                c[(c[f >> 2] | 0) + 48 >> 2] = 0;
	                c[(c[f >> 2] | 0) + 52 >> 2] = 0;
	                c[(c[f >> 2] | 0) + 44 >> 2] = 0;
	                c[(c[f >> 2] | 0) + 56 >> 2] = 0;
	                if (c[e >> 2] | 0)c[(c[f >> 2] | 0) + 36 >> 2] = c[(c[e >> 2] | 0) + 12 >> 2];
	                c[(c[f >> 2] | 0) + 64 >> 2] = 0;
	                c[(c[f >> 2] | 0) + 68 >> 2] = 0;
	                c[(c[f >> 2] | 0) + 80 >> 2] = 0;
	                c[(c[f >> 2] | 0) + 40 >> 2] = 0;
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function fN(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 64 >> 2] | 0)NN(0, c[(c[d >> 2] | 0) + 64 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 68 >> 2] | 0) {
	                    c[e >> 2] = 0;
	                    while (1) {
	                        if ((c[e >> 2] | 0) >= (c[c[(c[d >> 2] | 0) + 68 >> 2] >> 2] | 0))break;
	                        LN(0, c[(c[(c[(c[d >> 2] | 0) + 68 >> 2] | 0) + 8 >> 2] | 0) + (c[e >> 2] << 2) >> 2] | 0);
	                        c[e >> 2] = (c[e >> 2] | 0) + 1
	                    }
	                    NN(0, c[(c[d >> 2] | 0) + 68 >> 2] | 0)
	                }
	                if (c[(c[d >> 2] | 0) + 80 >> 2] | 0) {
	                    c[e >> 2] = 0;
	                    while (1) {
	                        if ((c[e >> 2] | 0) >= (c[(c[d >> 2] | 0) + 72 >> 2] | 0))break;
	                        NN(0, c[(c[(c[d >> 2] | 0) + 80 >> 2] | 0) + (c[e >> 2] << 2) >> 2] | 0);
	                        c[e >> 2] = (c[e >> 2] | 0) + 1
	                    }
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 80 >> 2] | 0)
	                }
	                if (c[(c[d >> 2] | 0) + 56 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 56 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 96 >> 2] | 0) {
	                    c[f >> 2] = IN(c[d >> 2] | 0) | 0;
	                    while (1) {
	                        if (!(c[f >> 2] | 0))break;
	                        pz(c[f >> 2] | 0);
	                        c[f >> 2] = IN(c[d >> 2] | 0) | 0
	                    }
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 96 >> 2] | 0)
	                }
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function gN(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 12 | 0;
	                h = f + 8 | 0;
	                j = f + 4 | 0;
	                k = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                if (!(c[g >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                c[(c[g >> 2] | 0) + 4 >> 2] = c[h >> 2];
	                c[(c[g >> 2] | 0) + 8 >> 2] = c[j >> 2];
	                c[c[g >> 2] >> 2] = c[k >> 2];
	                c[(c[g >> 2] | 0) + 12 >> 2] = 0;
	                i = f;
	                return
	            }

	            function hN(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if (!(c[f >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                c[(c[f >> 2] | 0) + 12 >> 2] = c[g >> 2];
	                c[(c[f >> 2] | 0) + 4 >> 2] = 0;
	                c[(c[f >> 2] | 0) + 8 >> 2] = 0;
	                c[c[f >> 2] >> 2] = c[h >> 2];
	                i = e;
	                return
	            }

	            function iN(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = -1;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[(c[f >> 2] | 0) + 24 >> 2] = c[g >> 2];
	                c[h >> 2] = ON(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                PN(c[g >> 2] | 0);
	                if ((c[h >> 2] | 0) == -1) {
	                    c[e >> 2] = 1;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } else {
	                    c[e >> 2] = c[h >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                return 0
	            }

	            function jN(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 4 >> 2] | 0)jN(c[(c[d >> 2] | 0) + 4 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 8 >> 2] | 0)jN(c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 28 >> 2] | 0)Kj(c[(c[d >> 2] | 0) + 28 >> 2] | 0, 0);
	                if (c[(c[d >> 2] | 0) + 24 >> 2] | 0)Kj(c[(c[d >> 2] | 0) + 24 >> 2] | 0, 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function kN(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                while (1) {
	                    if (!(c[d >> 2] | 0))break;
	                    c[e >> 2] = c[c[d >> 2] >> 2];
	                    yN(c[d >> 2] | 0);
	                    c[d >> 2] = c[e >> 2]
	                }
	                i = b;
	                return
	            }

	            function lN(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                while (1) {
	                    if (!(c[d >> 2] | 0))break;
	                    c[e >> 2] = c[c[d >> 2] >> 2];
	                    QN(c[d >> 2] | 0);
	                    c[d >> 2] = c[e >> 2]
	                }
	                i = b;
	                return
	            }

	            function mN(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if ((((c[c[d >> 2] >> 2] | 0) == 7 ? (c[(c[d >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[e >> 2] = c[(c[d >> 2] | 0) + 20 >> 2], (c[e >> 2] | 0) != 0) : 0) ? (c[(c[e >> 2] | 0) + 24 >> 2] | 0) != 0 : 0)Ab[c[(c[e >> 2] | 0) + 24 >> 2] & 511](c[(c[e >> 2] | 0) + 4 >> 2] | 0, c[(c[d >> 2] | 0) + 36 >> 2] | 0);
	                if ((c[(c[d >> 2] | 0) + 20 >> 2] | 0) != 0 ? (c[c[d >> 2] >> 2] | 0) == 19 : 0)RN(c[(c[d >> 2] | 0) + 20 >> 2] | 0);
	                if ((c[(c[d >> 2] | 0) + 20 >> 2] | 0) != 0 ? (c[c[d >> 2] >> 2] | 0) == 17 : 0)Kj(c[(c[d >> 2] | 0) + 20 >> 2] | 0, 0);
	                if (c[(c[d >> 2] | 0) + 8 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 12 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 12 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 16 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 16 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 52 >> 2] | 0)zz(c[(c[d >> 2] | 0) + 52 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function nN(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[d + 8 >> 2] = a;
	                c[f >> 2] = b;
	                do if (c[f >> 2] | 0) {
	                    c[g >> 2] = QH(c[f >> 2] | 0, 196728) | 0;
	                    if (!(c[g >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        break
	                    } else {
	                        c[e >> 2] = 1;
	                        break
	                    }
	                } else c[e >> 2] = -1; while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function oN(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 28 | 0;
	                j = g + 20 | 0;
	                k = g + 16 | 0;
	                l = g + 12 | 0;
	                m = g + 8 | 0;
	                n = g + 4 | 0;
	                o = g;
	                c[g + 24 >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                do if (!((c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0)) {
	                    c[n >> 2] = QH(c[j >> 2] | 0, 196728) | 0;
	                    if (!(c[n >> 2] | 0)) {
	                        c[h >> 2] = -1;
	                        break
	                    }
	                    c[o >> 2] = TH(c[n >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0) | 0;
	                    if ((c[o >> 2] | 0) == 2) {
	                        c[h >> 2] = 2;
	                        break
	                    }
	                    if (!(c[o >> 2] | 0)) {
	                        c[h >> 2] = 1;
	                        break
	                    }
	                    if ((c[o >> 2] | 0) > 0) {
	                        c[h >> 2] = 0;
	                        break
	                    } else {
	                        c[h >> 2] = -1;
	                        break
	                    }
	                } else c[h >> 2] = -1; while (0);
	                i = g;
	                return c[h >> 2] | 0
	            }

	            function pN(a, b, d, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                j = i;
	                i = i + 48 | 0;
	                k = j + 44 | 0;
	                l = j + 36 | 0;
	                m = j + 32 | 0;
	                n = j + 28 | 0;
	                o = j + 24 | 0;
	                p = j + 20 | 0;
	                q = j + 16 | 0;
	                r = j + 12 | 0;
	                s = j + 8 | 0;
	                t = j + 4 | 0;
	                u = j;
	                c[j + 40 >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                c[q >> 2] = h;
	                c[t >> 2] = 0;
	                c[u >> 2] = 0;
	                if ((c[l >> 2] | 0) == 0 | (c[m >> 2] | 0) == 0 | (c[p >> 2] | 0) == 0) {
	                    c[k >> 2] = -1;
	                    v = c[k >> 2] | 0;
	                    i = j;
	                    return v | 0
	                }
	                c[s >> 2] = QH(c[l >> 2] | 0, 196728) | 0;
	                if (!(c[s >> 2] | 0)) {
	                    c[k >> 2] = -1;
	                    v = c[k >> 2] | 0;
	                    i = j;
	                    return v | 0
	                }
	                if (!(c[o >> 2] | 0)) {
	                    c[r >> 2] = TH(c[s >> 2] | 0, c[m >> 2] | 0, t, c[n >> 2] | 0) | 0;
	                    if (c[r >> 2] | 0) {
	                        c[k >> 2] = -1;
	                        v = c[k >> 2] | 0;
	                        i = j;
	                        return v | 0
	                    }
	                    if (!(c[t >> 2] | 0)) {
	                        c[k >> 2] = -1;
	                        v = c[k >> 2] | 0;
	                        i = j;
	                        return v | 0
	                    }
	                } else c[t >> 2] = c[o >> 2];
	                c[r >> 2] = TH(c[s >> 2] | 0, c[p >> 2] | 0, u, c[q >> 2] | 0) | 0;
	                q = c[t >> 2] | 0;
	                if (c[r >> 2] | 0) {
	                    if ((q | 0) != (c[o >> 2] | 0))PH(c[t >> 2] | 0);
	                    c[k >> 2] = -1;
	                    v = c[k >> 2] | 0;
	                    i = j;
	                    return v | 0
	                }
	                c[r >> 2] = XH(q, c[u >> 2] | 0) | 0;
	                if ((c[t >> 2] | 0) != (c[o >> 2] | 0))PH(c[t >> 2] | 0);
	                PH(c[u >> 2] | 0);
	                if ((c[r >> 2] | 0) == -2) {
	                    c[k >> 2] = -1;
	                    v = c[k >> 2] | 0;
	                    i = j;
	                    return v | 0
	                }
	                if (!(c[r >> 2] | 0)) {
	                    c[k >> 2] = 1;
	                    v = c[k >> 2] | 0;
	                    i = j;
	                    return v | 0
	                } else {
	                    c[k >> 2] = 0;
	                    v = c[k >> 2] | 0;
	                    i = j;
	                    return v | 0
	                }
	                return 0
	            }

	            function qN(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h + 36 | 0;
	                k = h + 28 | 0;
	                l = h + 24 | 0;
	                m = h + 20 | 0;
	                n = h + 16 | 0;
	                o = h + 12 | 0;
	                p = h + 8 | 0;
	                q = h + 4 | 0;
	                r = h;
	                c[h + 32 >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                if ((c[k >> 2] | 0) == 0 | (c[n >> 2] | 0) == 0) {
	                    c[j >> 2] = -1;
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                }
	                c[q >> 2] = QH(c[k >> 2] | 0, 196728) | 0;
	                if (!(c[q >> 2] | 0)) {
	                    c[j >> 2] = -1;
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                }
	                c[p >> 2] = SA() | 0;
	                if (!(c[p >> 2] | 0)) {
	                    c[j >> 2] = -1;
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                }
	                do if (qy(c[l >> 2] | 0, 196768) | 0)c[c[p >> 2] >> 2] = 1e3; else {
	                    if (qy(c[l >> 2] | 0, 196784) | 0) {
	                        c[c[p >> 2] >> 2] = 1001;
	                        break
	                    }
	                    if (qy(c[l >> 2] | 0, 196800) | 0) {
	                        c[c[p >> 2] >> 2] = 1002;
	                        break
	                    }
	                    if (qy(c[l >> 2] | 0, 196816) | 0) {
	                        c[c[p >> 2] >> 2] = 1003;
	                        break
	                    }
	                    if (qy(c[l >> 2] | 0, 196832) | 0) {
	                        c[c[p >> 2] >> 2] = 1004;
	                        break
	                    }
	                    if (qy(c[l >> 2] | 0, 196848) | 0) {
	                        c[c[p >> 2] >> 2] = 1005;
	                        break
	                    }
	                    if (qy(c[l >> 2] | 0, 196864) | 0) {
	                        c[c[p >> 2] >> 2] = 1006;
	                        break
	                    }
	                    if (qy(c[l >> 2] | 0, 196872) | 0) {
	                        c[c[p >> 2] >> 2] = 1007;
	                        break
	                    }
	                    if (qy(c[l >> 2] | 0, 196888) | 0) {
	                        c[c[p >> 2] >> 2] = 1008;
	                        break
	                    }
	                    if (qy(c[l >> 2] | 0, 196904) | 0) {
	                        c[c[p >> 2] >> 2] = 1009;
	                        break
	                    }
	                    if (qy(c[l >> 2] | 0, 196912) | 0) {
	                        c[c[p >> 2] >> 2] = 1010;
	                        break
	                    }
	                    g = (qy(c[l >> 2] | 0, 196928) | 0) != 0;
	                    f = c[p >> 2] | 0;
	                    if (g) {
	                        c[f >> 2] = 1011;
	                        break
	                    }
	                    UA(f);
	                    c[j >> 2] = -1;
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                } while (0);
	                c[(c[p >> 2] | 0) + 8 >> 2] = c[m >> 2];
	                c[r >> 2] = _A(c[p >> 2] | 0, c[q >> 2] | 0, 0, c[k >> 2] | 0) | 0;
	                if (c[r >> 2] | 0) {
	                    UA(c[p >> 2] | 0);
	                    c[j >> 2] = -1;
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                }
	                c[r >> 2] = $H(c[q >> 2] | 0, c[p >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0) | 0;
	                UA(c[p >> 2] | 0);
	                if (c[r >> 2] | 0) {
	                    c[j >> 2] = -1;
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                } else {
	                    c[j >> 2] = 0;
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                }
	                return 0
	            }

	            function rN(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d;
	                c[d + 4 >> 2] = a;
	                c[e >> 2] = b;
	                PH(c[e >> 2] | 0);
	                i = d;
	                return
	            }

	            function sN(a, b, d, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                j = i;
	                i = i + 48 | 0;
	                k = j;
	                l = j + 40 | 0;
	                m = j + 36 | 0;
	                n = j + 32 | 0;
	                o = j + 28 | 0;
	                p = j + 24 | 0;
	                q = j + 20 | 0;
	                r = j + 16 | 0;
	                s = j + 12 | 0;
	                t = j + 8 | 0;
	                u = j + 4 | 0;
	                c[m >> 2] = a;
	                c[n >> 2] = b;
	                c[o >> 2] = d;
	                c[p >> 2] = e;
	                c[q >> 2] = f;
	                c[r >> 2] = g;
	                c[s >> 2] = h;
	                if ((c[46942] | 0) == 0 | (c[m >> 2] | 0) == 0 | (c[p >> 2] | 0) == 0 | (c[q >> 2] | 0) == 0) {
	                    c[l >> 2] = -1;
	                    v = c[l >> 2] | 0;
	                    i = j;
	                    return v | 0
	                }
	                if (Rj(c[46942] | 0, c[m >> 2] | 0) | 0) {
	                    h = c[33976] | 0;
	                    g = c[33980] | 0;
	                    c[k >> 2] = c[m >> 2];
	                    Db[h & 511](g, 196944, k);
	                    c[l >> 2] = -1;
	                    v = c[l >> 2] | 0;
	                    i = j;
	                    return v | 0
	                }
	                c[t >> 2] = Cb[c[135744 >> 2] & 511](28) | 0;
	                if (!(c[t >> 2] | 0)) {
	                    MN(0, 196992);
	                    c[l >> 2] = -1;
	                    v = c[l >> 2] | 0;
	                    i = j;
	                    return v | 0
	                }
	                g = c[t >> 2] | 0;
	                c[g + 0 >> 2] = 0;
	                c[g + 4 >> 2] = 0;
	                c[g + 8 >> 2] = 0;
	                c[g + 12 >> 2] = 0;
	                c[g + 16 >> 2] = 0;
	                c[g + 20 >> 2] = 0;
	                c[g + 24 >> 2] = 0;
	                g = my(c[m >> 2] | 0) | 0;
	                c[c[t >> 2] >> 2] = g;
	                c[(c[t >> 2] | 0) + 4 >> 2] = c[n >> 2];
	                c[(c[t >> 2] | 0) + 8 >> 2] = c[o >> 2];
	                c[(c[t >> 2] | 0) + 16 >> 2] = c[q >> 2];
	                c[(c[t >> 2] | 0) + 12 >> 2] = c[p >> 2];
	                c[(c[t >> 2] | 0) + 20 >> 2] = c[r >> 2];
	                c[(c[t >> 2] | 0) + 24 >> 2] = c[s >> 2];
	                c[u >> 2] = Lj(c[46942] | 0, c[m >> 2] | 0, c[t >> 2] | 0) | 0;
	                if ((c[u >> 2] | 0) < 0) {
	                    u = c[33976] | 0;
	                    s = c[33980] | 0;
	                    c[k >> 2] = c[m >> 2];
	                    Db[u & 511](s, 197016, k);
	                    wN(c[t >> 2] | 0, c[m >> 2] | 0);
	                    c[l >> 2] = -1;
	                    v = c[l >> 2] | 0;
	                    i = j;
	                    return v | 0
	                } else {
	                    c[l >> 2] = 0;
	                    v = c[l >> 2] | 0;
	                    i = j;
	                    return v | 0
	                }
	                return 0
	            }

	            function tN(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d;
	                c[d + 4 >> 2] = a;
	                c[f >> 2] = b;
	                do if (c[f >> 2] | 0) {
	                    if (qy(c[f >> 2] | 0, 196712) | 0) {
	                        c[e >> 2] = 1;
	                        break
	                    }
	                    if (qy(c[f >> 2] | 0, 196720) | 0) {
	                        c[e >> 2] = 1;
	                        break
	                    } else {
	                        c[e >> 2] = 0;
	                        break
	                    }
	                } else c[e >> 2] = -1; while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function uN(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 20 | 0;
	                j = g + 12 | 0;
	                k = g + 8 | 0;
	                c[g + 16 >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[g + 4 >> 2] = e;
	                c[g >> 2] = f;
	                do if (c[k >> 2] | 0) {
	                    if (qy(c[j >> 2] | 0, 196712) | 0) {
	                        c[h >> 2] = 1;
	                        break
	                    }
	                    if (qy(c[j >> 2] | 0, 196720) | 0) {
	                        c[h >> 2] = 1;
	                        break
	                    } else {
	                        c[h >> 2] = 0;
	                        break
	                    }
	                } else c[h >> 2] = -1; while (0);
	                i = g;
	                return c[h >> 2] | 0
	            }

	            function vN(a, b, d, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                j = i;
	                i = i + 48 | 0;
	                k = j + 32 | 0;
	                l = j + 28 | 0;
	                m = j + 16 | 0;
	                n = j + 8 | 0;
	                o = j + 4 | 0;
	                p = j;
	                c[j + 36 >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[j + 24 >> 2] = e;
	                c[j + 20 >> 2] = f;
	                c[m >> 2] = g;
	                c[j + 12 >> 2] = h;
	                c[n >> 2] = -1;
	                if (qy(c[k >> 2] | 0, 196712) | 0) {
	                    c[n >> 2] = qy(c[l >> 2] | 0, c[m >> 2] | 0) | 0;
	                    q = c[n >> 2] | 0;
	                    i = j;
	                    return q | 0
	                }
	                if (!(qy(c[k >> 2] | 0, 196720) | 0)) {
	                    q = c[n >> 2] | 0;
	                    i = j;
	                    return q | 0
	                }
	                if (qy(c[l >> 2] | 0, c[m >> 2] | 0) | 0) {
	                    c[n >> 2] = 1;
	                    q = c[n >> 2] | 0;
	                    i = j;
	                    return q | 0
	                }
	                c[o >> 2] = SN(0, c[l >> 2] | 0) | 0;
	                c[p >> 2] = SN(0, c[m >> 2] | 0) | 0;
	                do if (!((c[o >> 2] | 0) == 0 | (c[p >> 2] | 0) == 0))if (qy(c[o >> 2] | 0, c[p >> 2] | 0) | 0) {
	                    c[n >> 2] = 1;
	                    break
	                } else {
	                    c[n >> 2] = 0;
	                    break
	                } else c[n >> 2] = -1; while (0);
	                if (c[o >> 2] | 0)zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                if (!(c[p >> 2] | 0)) {
	                    q = c[n >> 2] | 0;
	                    i = j;
	                    return q | 0
	                }
	                zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                q = c[n >> 2] | 0;
	                i = j;
	                return q | 0
	            }

	            function wN(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                c[e >> 2] = a;
	                c[d >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if (c[c[e >> 2] >> 2] | 0)zb[c[135736 >> 2] & 511](c[c[e >> 2] >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[e >> 2] | 0);
	                i = d;
	                return
	            }

	            function xN(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                c[j >> 2] = 0;
	                c[k >> 2] = 0;
	                if (c[f >> 2] | 0) {
	                    b = c[f >> 2] | 0;
	                    if (c[(c[f >> 2] | 0) + 12 >> 2] | 0)c[h >> 2] = c[b + 12 >> 2]; else c[j >> 2] = c[b + 4 >> 2];
	                    c[k >> 2] = c[c[f >> 2] >> 2];
	                    b = (c[f >> 2] | 0) + 36 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 1
	                }
	                b = c[h >> 2] | 0;
	                h = c[j >> 2] | 0;
	                j = c[k >> 2] | 0;
	                if (c[g >> 2] | 0) {
	                    k = c[g >> 2] | 0;
	                    c[e >> 2] = c[g >> 2];
	                    Xd(b, h, j, 0, 0, 18, 2, 3, 0, 0, k, 0, 0, 0, 0, 189400, e);
	                    i = d;
	                    return
	                } else {
	                    Xd(b, h, j, 0, 0, 18, 2, 3, 0, 0, 0, 0, 0, 0, 0, 189432, e);
	                    i = d;
	                    return
	                }
	            }

	            function yN(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 4 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 4 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 8 >> 2] | 0)Th(c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 16 >> 2] | 0)TN(c[(c[d >> 2] | 0) + 16 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function zN(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h;
	                k = h + 40 | 0;
	                l = h + 36 | 0;
	                m = h + 32 | 0;
	                n = h + 28 | 0;
	                o = h + 24 | 0;
	                p = h + 20 | 0;
	                q = h + 16 | 0;
	                r = h + 12 | 0;
	                s = h + 8 | 0;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                c[q >> 2] = 0;
	                c[r >> 2] = 0;
	                c[s >> 2] = 0;
	                if (c[k >> 2] | 0) {
	                    g = c[k >> 2] | 0;
	                    if (c[(c[k >> 2] | 0) + 12 >> 2] | 0)c[q >> 2] = c[g + 12 >> 2]; else c[r >> 2] = c[g + 4 >> 2];
	                    c[s >> 2] = c[c[k >> 2] >> 2];
	                    g = (c[k >> 2] | 0) + 36 | 0;
	                    c[g >> 2] = (c[g >> 2] | 0) + 1
	                }
	                g = c[q >> 2] | 0;
	                q = c[r >> 2] | 0;
	                r = c[s >> 2] | 0;
	                s = c[l >> 2] | 0;
	                l = c[m >> 2] | 0;
	                m = c[o >> 2] | 0;
	                k = c[p >> 2] | 0;
	                f = c[n >> 2] | 0;
	                n = c[p >> 2] | 0;
	                c[j >> 2] = c[o >> 2];
	                c[j + 4 >> 2] = n;
	                Xd(g, q, r, 0, s, 18, l, 2, 0, 0, m, k, 0, 0, 0, f, j);
	                i = h;
	                return
	            }

	            function AN(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = Pi(c[g >> 2] | 0) | 0;
	                b = c[f >> 2] | 0;
	                if (!(c[h >> 2] | 0)) {
	                    zN(b, c[g >> 2] | 0, 1022, 188056, c[(c[f >> 2] | 0) + 68 >> 2] | 0, 0);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } else {
	                    UN(b, c[h >> 2] | 0);
	                    c[e >> 2] = c[g >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                return 0
	            }

	            function BN(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 28 | 0;
	                f = d + 24 | 0;
	                g = d + 20 | 0;
	                h = d + 16 | 0;
	                j = d + 12 | 0;
	                k = d + 8 | 0;
	                l = d + 4 | 0;
	                m = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = 0;
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                c[h >> 2] = VN(c[f >> 2] | 0) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                c[j >> 2] = c[(c[f >> 2] | 0) + 44 >> 2];
	                c[(c[f >> 2] | 0) + 44 >> 2] = 0;
	                if (((((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 190264) | 0) != 0 : 0) ? (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                    b = WN(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] | 0) | 0;
	                    c[(c[h >> 2] | 0) + 4 >> 2] = b;
	                    if (!(c[(c[h >> 2] | 0) + 4 >> 2] | 0)) {
	                        VM(c[h >> 2] | 0);
	                        c[e >> 2] = 0;
	                        n = c[e >> 2] | 0;
	                        i = d;
	                        return n | 0
	                    }
	                } else {
	                    b = XN(c[f >> 2] | 0) | 0;
	                    c[m >> 2] = b;
	                    c[(c[h >> 2] | 0) + 4 >> 2] = b;
	                    if (!(c[(c[h >> 2] | 0) + 4 >> 2] | 0)) {
	                        VM(c[h >> 2] | 0);
	                        c[e >> 2] = 0;
	                        n = c[e >> 2] | 0;
	                        i = d;
	                        return n | 0
	                    }
	                    c[c[m >> 2] >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                    do if (c[(c[f >> 2] | 0) + 24 >> 2] | 0) {
	                        c[l >> 2] = c[(c[(c[f >> 2] | 0) + 24 >> 2] | 0) + 4 >> 2];
	                        if (!(c[l >> 2] | 0)) {
	                            c[(c[(c[f >> 2] | 0) + 24 >> 2] | 0) + 4 >> 2] = c[m >> 2];
	                            break
	                        }
	                        while (1) {
	                            if (!(c[(c[l >> 2] | 0) + 8 >> 2] | 0))break;
	                            c[l >> 2] = c[(c[l >> 2] | 0) + 8 >> 2]
	                        }
	                        c[(c[l >> 2] | 0) + 8 >> 2] = c[m >> 2]
	                    } while (0);
	                    c[k >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                    c[(c[f >> 2] | 0) + 24 >> 2] = c[m >> 2];
	                    YN(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                    if (c[k >> 2] | 0)c[(c[f >> 2] | 0) + 24 >> 2] = c[k >> 2]
	                }
	                c[(c[f >> 2] | 0) + 44 >> 2] = c[j >> 2];
	                if ((c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 12 >> 2] | 0) != 0 ? (ZN(c[f >> 2] | 0, c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 12 >> 2] | 0, 0) | 0, (c[(c[f >> 2] | 0) + 32 >> 2] & 128 | 0) == 0) : 0) {
	                    _N(c[f >> 2] | 0, c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 12 >> 2] | 0, 0);
	                    while (1) {
	                        if (!(c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 12 >> 2] | 0))break;
	                        if ((c[c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 12 >> 2] >> 2] | 0) != -1)break;
	                        if (!(c[(c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 12 >> 2] | 0) + 32 >> 2] | 0))break;
	                        c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 12 >> 2] = c[(c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 12 >> 2] | 0) + 24 >> 2]
	                    }
	                    $N(c[f >> 2] | 0, c[(c[(c[h >> 2] | 0) + 4 >> 2] | 0) + 12 >> 2] | 0, 16, -1) | 0
	                }
	                c[e >> 2] = c[h >> 2];
	                n = c[e >> 2] | 0;
	                i = d;
	                return n | 0
	            }

	            function CN(a, e, f) {
	                a = a | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0;
	                g = i;
	                i = i + 64 | 0;
	                h = g + 60 | 0;
	                j = g + 56 | 0;
	                k = g + 48 | 0;
	                l = g + 44 | 0;
	                m = g + 40 | 0;
	                n = g + 36 | 0;
	                o = g + 32 | 0;
	                p = g + 28 | 0;
	                q = g + 24 | 0;
	                r = g + 20 | 0;
	                s = g + 16 | 0;
	                t = g + 12 | 0;
	                u = g + 8 | 0;
	                v = g + 4 | 0;
	                w = g;
	                c[h >> 2] = a;
	                c[j >> 2] = e;
	                c[g + 52 >> 2] = f;
	                c[m >> 2] = 0;
	                c[n >> 2] = 0;
	                c[t >> 2] = 0;
	                c[u >> 2] = 0;
	                c[v >> 2] = 0;
	                c[w >> 2] = 1;
	                if (c[(c[j >> 2] | 0) + 36 >> 2] | 0) {
	                    i = g;
	                    return
	                }
	                c[k >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                while (1) {
	                    if (!(c[k >> 2] | 0))break;
	                    c[u >> 2] = (c[u >> 2] | 0) + 1;
	                    c[k >> 2] = c[(c[k >> 2] | 0) + 32 >> 2]
	                }
	                c[n >> 2] = Cb[c[135744 >> 2] & 511](c[u >> 2] << 2) | 0;
	                a:do if (c[n >> 2] | 0) {
	                    c[k >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                    while (1) {
	                        x = c[33936] | 0;
	                        if (!(c[k >> 2] | 0))break;
	                        u = Cb[x & 511](12) | 0;
	                        c[(c[n >> 2] | 0) + (c[t >> 2] << 2) >> 2] = u;
	                        if (!(c[(c[n >> 2] | 0) + (c[t >> 2] << 2) >> 2] | 0))break a;
	                        if ((c[c[k >> 2] >> 2] | 0) == 3)c[v >> 2] = (c[v >> 2] | 0) + 1;
	                        c[c[(c[n >> 2] | 0) + (c[t >> 2] << 2) >> 2] >> 2] = c[k >> 2];
	                        u = aO(c[j >> 2] | 0, c[k >> 2] | 0, 0) | 0;
	                        c[(c[(c[n >> 2] | 0) + (c[t >> 2] << 2) >> 2] | 0) + 4 >> 2] = u;
	                        u = aO(c[j >> 2] | 0, c[k >> 2] | 0, 1) | 0;
	                        c[(c[(c[n >> 2] | 0) + (c[t >> 2] << 2) >> 2] | 0) + 8 >> 2] = u;
	                        c[t >> 2] = (c[t >> 2] | 0) + 1;
	                        c[k >> 2] = c[(c[k >> 2] | 0) + 32 >> 2]
	                    }
	                    c[m >> 2] = Cb[x & 511](16) | 0;
	                    if (c[m >> 2] | 0) {
	                        u = c[m >> 2] | 0;
	                        c[u + 0 >> 2] = 0;
	                        c[u + 4 >> 2] = 0;
	                        c[u + 8 >> 2] = 0;
	                        c[u + 12 >> 2] = 0;
	                        c[c[m >> 2] >> 2] = c[t >> 2];
	                        u = Ij(c[t >> 2] | 0) | 0;
	                        c[(c[m >> 2] | 0) + 4 >> 2] = u;
	                        c[p >> 2] = 0;
	                        while (1) {
	                            if ((c[p >> 2] | 0) >= (c[t >> 2] | 0))break;
	                            c[o >> 2] = c[(c[n >> 2] | 0) + (c[p >> 2] << 2) >> 2];
	                            c[q >> 2] = (c[p >> 2] | 0) + 1;
	                            while (1) {
	                                if ((c[q >> 2] | 0) >= (c[t >> 2] | 0))break;
	                                if (c[(c[n >> 2] | 0) + (c[q >> 2] << 2) >> 2] | 0) {
	                                    c[r >> 2] = bO(c[j >> 2] | 0, c[(c[o >> 2] | 0) + 4 >> 2] | 0, c[(c[(c[n >> 2] | 0) + (c[q >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0) | 0;
	                                    if (!(c[r >> 2] | 0))zN(c[j >> 2] | 0, c[(c[h >> 2] | 0) + 4 >> 2] | 0, 1021, 190104, 0, 0);
	                                    c[r >> 2] = bO(c[j >> 2] | 0, c[(c[o >> 2] | 0) + 8 >> 2] | 0, c[(c[(c[n >> 2] | 0) + (c[q >> 2] << 2) >> 2] | 0) + 8 >> 2] | 0) | 0;
	                                    if (!(c[r >> 2] | 0))zN(c[j >> 2] | 0, c[(c[h >> 2] | 0) + 4 >> 2] | 0, 1001, 190152, 0, 0)
	                                }
	                                c[q >> 2] = (c[q >> 2] | 0) + 1
	                            }
	                            c[l >> 2] = c[(c[o >> 2] | 0) + 4 >> 2];
	                            b:do if ((c[l >> 2] | 0) != 0 ? (c[c[l >> 2] >> 2] | 0) != 0 : 0)while (1) {
	                                if (!(c[c[l >> 2] >> 2] | 0))break b;
	                                do if ((c[c[c[l >> 2] >> 2] >> 2] | 0) == 3) {
	                                    c[s >> 2] = Nj(c[(c[m >> 2] | 0) + 4 >> 2] | 0, 188096, 0, (c[p >> 2] | 0) + 1 | 0) | 0;
	                                    if (c[s >> 2] | 0)c[w >> 2] = -1
	                                } else {
	                                    if ((c[c[c[l >> 2] >> 2] >> 2] | 0) == 4 ? (c[(c[c[l >> 2] >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                                        if ((c[(c[c[l >> 2] >> 2] | 0) + 12 >> 2] | 0) != 0 ? (d[c[(c[c[l >> 2] >> 2] | 0) + 12 >> 2] >> 0] | 0) != 0 : 0)c[s >> 2] = Nj(c[(c[m >> 2] | 0) + 4 >> 2] | 0, c[(c[c[l >> 2] >> 2] | 0) + 8 >> 2] | 0, c[(c[c[l >> 2] >> 2] | 0) + 12 >> 2] | 0, (c[p >> 2] | 0) + 1 | 0) | 0; else c[s >> 2] = Nj(c[(c[m >> 2] | 0) + 4 >> 2] | 0, c[(c[c[l >> 2] >> 2] | 0) + 8 >> 2] | 0, 0, (c[p >> 2] | 0) + 1 | 0) | 0;
	                                        if (!(c[s >> 2] | 0))break;
	                                        c[w >> 2] = -1;
	                                        break
	                                    }
	                                    if ((c[c[c[l >> 2] >> 2] >> 2] | 0) != 4) {
	                                        c[w >> 2] = -1;
	                                        break
	                                    }
	                                    if ((c[(c[c[l >> 2] >> 2] | 0) + 12 >> 2] | 0) != 0 ? (d[c[(c[c[l >> 2] >> 2] | 0) + 12 >> 2] >> 0] | 0) != 0 : 0)c[s >> 2] = Nj(c[(c[m >> 2] | 0) + 4 >> 2] | 0, 189536, c[(c[c[l >> 2] >> 2] | 0) + 12 >> 2] | 0, (c[p >> 2] | 0) + 1 | 0) | 0; else c[s >> 2] = Nj(c[(c[m >> 2] | 0) + 4 >> 2] | 0, 189536, 0, (c[p >> 2] | 0) + 1 | 0) | 0;
	                                    if (c[(c[c[l >> 2] >> 2] | 0) + 40 >> 2] | 0)c[w >> 2] = 2;
	                                    if (c[s >> 2] | 0)c[w >> 2] = -1
	                                } while (0);
	                                c[l >> 2] = (c[l >> 2] | 0) + 4
	                            } else y = 48; while (0);
	                            if ((y | 0) == 48) {
	                                y = 0;
	                                c[w >> 2] = 0
	                            }
	                            c[p >> 2] = (c[p >> 2] | 0) + 1
	                        }
	                        c[(c[m >> 2] | 0) + 12 >> 2] = c[n >> 2];
	                        c[(c[h >> 2] | 0) + 20 >> 2] = c[m >> 2];
	                        if (c[v >> 2] | 0) {
	                            u = (c[h >> 2] | 0) + 50 | 0;
	                            b[u >> 1] = b[u >> 1] | 8
	                        }
	                        if ((c[w >> 2] | 0) == 1)c[(c[m >> 2] | 0) + 8 >> 2] = 1;
	                        if ((c[w >> 2] | 0) != 2) {
	                            i = g;
	                            return
	                        }
	                        c[(c[m >> 2] | 0) + 8 >> 2] = 3;
	                        i = g;
	                        return
	                    }
	                } while (0);
	                xN(c[j >> 2] | 0, 190192);
	                if (c[n >> 2] | 0) {
	                    c[p >> 2] = 0;
	                    while (1) {
	                        if ((c[p >> 2] | 0) >= (c[t >> 2] | 0))break;
	                        if (c[(c[n >> 2] | 0) + (c[p >> 2] << 2) >> 2] | 0) {
	                            if (c[(c[(c[n >> 2] | 0) + (c[p >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[(c[n >> 2] | 0) + (c[p >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0);
	                            zb[c[135736 >> 2] & 511](c[(c[n >> 2] | 0) + (c[p >> 2] << 2) >> 2] | 0)
	                        }
	                        c[p >> 2] = (c[p >> 2] | 0) + 1
	                    }
	                    zb[c[135736 >> 2] & 511](c[n >> 2] | 0)
	                }
	                RN(c[m >> 2] | 0);
	                i = g;
	                return
	            }

	            function DN(a, d) {
	                a = a | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = d;
	                d = (c[g >> 2] | 0) + 80 | 0;
	                do if (!(c[(c[g >> 2] | 0) + 80 >> 2] | 0)) {
	                    c[d >> 2] = 16;
	                    c[(c[g >> 2] | 0) + 76 >> 2] = 0;
	                    a = Cb[c[135744 >> 2] & 511](c[(c[g >> 2] | 0) + 80 >> 2] << 2) | 0;
	                    c[(c[g >> 2] | 0) + 84 >> 2] = a;
	                    if (!(c[(c[g >> 2] | 0) + 84 >> 2] | 0)) {
	                        xN(c[g >> 2] | 0, 190080);
	                        c[f >> 2] = 0;
	                        l = c[f >> 2] | 0;
	                        i = e;
	                        return l | 0
	                    }
	                } else if ((c[d >> 2] | 0) <= (c[(c[g >> 2] | 0) + 76 >> 2] | 0)) {
	                    a = (c[g >> 2] | 0) + 80 | 0;
	                    c[a >> 2] = c[a >> 2] << 1;
	                    c[k >> 2] = Hb[c[135760 >> 2] & 511](c[(c[g >> 2] | 0) + 84 >> 2] | 0, c[(c[g >> 2] | 0) + 80 >> 2] << 2) | 0;
	                    if (c[k >> 2] | 0) {
	                        c[(c[g >> 2] | 0) + 84 >> 2] = c[k >> 2];
	                        break
	                    }
	                    xN(c[g >> 2] | 0, 190080);
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } while (0);
	                c[j >> 2] = Cb[c[135744 >> 2] & 511](56) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    xN(c[g >> 2] | 0, 190080);
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } else {
	                    k = (c[j >> 2] | 0) + 0 | 0;
	                    d = k + 56 | 0;
	                    do {
	                        c[k >> 2] = 0;
	                        k = k + 4 | 0
	                    } while ((k | 0) < (d | 0));
	                    k = c[j >> 2] | 0;
	                    d = (c[g >> 2] | 0) + 76 | 0;
	                    a = c[d >> 2] | 0;
	                    c[d >> 2] = a + 1;
	                    c[(c[(c[g >> 2] | 0) + 84 >> 2] | 0) + (a << 2) >> 2] = k;
	                    c[(c[j >> 2] | 0) + 4 >> 2] = c[h >> 2];
	                    b[(c[j >> 2] | 0) + 48 >> 1] = -1;
	                    c[f >> 2] = c[j >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                return 0
	            }

	            function EN(a, d) {
	                a = a | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = d;
	                c[j >> 2] = 0;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) {
	                    c[f >> 2] = -1;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                if (!((c[c[h >> 2] >> 2] | 0) != 20 ? (c[c[h >> 2] >> 2] | 0) != 4 : 0))m = 5;
	                if (((m | 0) == 5 ? (c[j >> 2] = cO(c[h >> 2] | 0) | 0, (b[(c[h >> 2] | 0) + 50 >> 1] & 64 | 0) != 0) : 0) ? (b[(c[h >> 2] | 0) + 48 >> 1] | 0) != -25 : 0) {
	                    c[(c[g >> 2] | 0) + 132 >> 2] = 0;
	                    c[j >> 2] = dO(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                    c[f >> 2] = c[j >> 2];
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                a:do switch (c[c[h >> 2] >> 2] | 0) {
	                    case 4:
	                    case 0:
	                    case 7:
	                    case 6:
	                    case 8:
	                    case 5:
	                    case 3:
	                    {
	                        c[j >> 2] = 0;
	                        break
	                    }
	                    case 13:
	                    case 12:
	                    case 11:
	                    case 20:
	                    case 10:
	                    case 18:
	                    case 17:
	                    case 16:
	                    case 15:
	                    case 14:
	                    {
	                        c[k >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                        while (1) {
	                            if (!(c[k >> 2] | 0))break a;
	                            c[j >> 2] = EN(c[g >> 2] | 0, c[k >> 2] | 0) | 0;
	                            if (c[j >> 2] | 0)break a;
	                            c[k >> 2] = c[(c[k >> 2] | 0) + 32 >> 2]
	                        }
	                        break
	                    }
	                    case -1:
	                    {
	                        c[j >> 2] = EN(c[g >> 2] | 0, c[(c[h >> 2] | 0) + 24 >> 2] | 0) | 0;
	                        break
	                    }
	                    case 1:
	                    case 19:
	                    case 9:
	                    case 2:
	                    {
	                        c[j >> 2] = 0;
	                        break
	                    }
	                    default:
	                    {
	                    }
	                } while (0);
	                c[f >> 2] = c[j >> 2];
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function FN(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 24 | 0;
	                j = g + 20 | 0;
	                k = g + 16 | 0;
	                l = g + 12 | 0;
	                m = g + 8 | 0;
	                n = g + 4 | 0;
	                o = g;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                if (!(c[h >> 2] | 0)) {
	                    i = g;
	                    return
	                }
	                if (c[(c[h >> 2] | 0) + 28 >> 2] & 8) {
	                    i = g;
	                    return
	                }
	                if ((c[(c[h >> 2] | 0) + 28 >> 2] & 1 | 0) != 0 ? (c[(c[h >> 2] | 0) + 28 >> 2] & 2 | 0) == 0 : 0) {
	                    gO(c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0) | 0;
	                    i = g;
	                    return
	                }
	                if (c[(c[h >> 2] | 0) + 48 >> 2] | 0)eO(c[h >> 2] | 0);
	                if (c[(c[h >> 2] | 0) + 60 >> 2] | 0) {
	                    c[n >> 2] = c[c[(c[h >> 2] | 0) + 60 >> 2] >> 2];
	                    c[o >> 2] = c[(c[(c[h >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2]
	                } else {
	                    c[o >> 2] = 0;
	                    c[n >> 2] = 0
	                }
	                if ((c[n >> 2] | 0) == 0 & (c[o >> 2] | 0) == 0)c[n >> 2] = c[(c[h >> 2] | 0) + 104 >> 2];
	                fO(c[h >> 2] | 0, c[j >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0);
	                i = g;
	                return
	            }

	            function GN(a, b, e, f) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0;
	                g = i;
	                i = i + 64 | 0;
	                h = g;
	                j = g + 52 | 0;
	                k = g + 48 | 0;
	                l = g + 44 | 0;
	                m = g + 40 | 0;
	                n = g + 36 | 0;
	                p = g + 32 | 0;
	                q = g + 28 | 0;
	                r = g + 24 | 0;
	                s = g + 20 | 0;
	                t = g + 16 | 0;
	                u = g + 12 | 0;
	                v = g + 8 | 0;
	                w = g + 4 | 0;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                c[n >> 2] = c[m >> 2];
	                c[p >> 2] = c[l >> 2];
	                c[t >> 2] = 0;
	                if (!(c[n >> 2] | 0)) {
	                    l = c[o >> 2] | 0;
	                    c[h >> 2] = c[k >> 2];
	                    Ka(l | 0, 189616, h | 0) | 0;
	                    i = g;
	                    return
	                }
	                c[s >> 2] = c[(c[n >> 2] | 0) + 104 >> 2];
	                c[(c[n >> 2] | 0) + 100 >> 2] = 1;
	                if (!(c[p >> 2] | 0)) {
	                    if ((d[c[k >> 2] >> 0] | 0 | 0) == 35) {
	                        i = g;
	                        return
	                    }
	                    l = c[o >> 2] | 0;
	                    c[h >> 2] = c[k >> 2];
	                    Ka(l | 0, 189648, h | 0) | 0;
	                    if ((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 40 >> 2] | 0) == 0 : 0)c[(c[n >> 2] | 0) + 40 >> 2] = 37;
	                    c[(c[n >> 2] | 0) + 100 >> 2] = -1;
	                    i = g;
	                    return
	                }
	                if ((c[n >> 2] | 0) == 0 | (c[p >> 2] | 0) == 0) {
	                    l = c[o >> 2] | 0;
	                    c[h >> 2] = c[k >> 2];
	                    Ka(l | 0, 189680, h | 0) | 0;
	                    if ((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 40 >> 2] | 0) == 0 : 0)c[(c[n >> 2] | 0) + 40 >> 2] = 37;
	                    c[(c[n >> 2] | 0) + 100 >> 2] = -1;
	                    i = g;
	                    return
	                }
	                if ((c[c[p >> 2] >> 2] | 0) != 4) {
	                    l = c[o >> 2] | 0;
	                    c[h >> 2] = c[k >> 2];
	                    Ka(l | 0, 189712, h | 0) | 0;
	                    if (!(c[(c[n >> 2] | 0) + 40 >> 2] | 0))c[(c[n >> 2] | 0) + 40 >> 2] = 37;
	                    c[(c[n >> 2] | 0) + 100 >> 2] = -1;
	                    i = g;
	                    return
	                }
	                if ((c[(c[s >> 2] | 0) + 4 >> 2] | 0) != 1) {
	                    FN(c[n >> 2] | 0, 23, 0, 0, 0);
	                    if (!(c[(c[n >> 2] | 0) + 28 >> 2] & 1))eO(c[n >> 2] | 0);
	                    c[(c[n >> 2] | 0) + 100 >> 2] = -1;
	                    i = g;
	                    return
	                }
	                if (!(c[(c[p >> 2] | 0) + 52 >> 2] | 0)) {
	                    c[(c[n >> 2] | 0) + 100 >> 2] = 0;
	                    c[(c[n >> 2] | 0) + 108 >> 2] = c[p >> 2];
	                    i = g;
	                    return
	                }
	                c[j >> 2] = oz(c[(c[p >> 2] | 0) + 52 >> 2] | 0, 382, c[n >> 2] | 0) | 0;
	                h = c[n >> 2] | 0;
	                if (!(c[j >> 2] | 0)) {
	                    c[h + 100 >> 2] = -1;
	                    i = g;
	                    return
	                }
	                HN(h, c[j >> 2] | 0) | 0;
	                c[q >> 2] = JN(c[n >> 2] | 0, c[s >> 2] | 0) | 0;
	                j = c[n >> 2] | 0;
	                if (!(c[q >> 2] | 0)) {
	                    c[j + 100 >> 2] = -1;
	                    i = g;
	                    return
	                }
	                c[r >> 2] = c[j + 60 >> 2];
	                c[(c[n >> 2] | 0) + 60 >> 2] = c[q >> 2];
	                if ((c[(c[p >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[t >> 2] = hO(c[n >> 2] | 0, c[(c[p >> 2] | 0) + 36 >> 2] | 0) | 0, (c[t >> 2] | 0) != 0) : 0) {
	                    c[(c[n >> 2] | 0) + 100 >> 2] = -1;
	                    FN(c[n >> 2] | 0, 24, c[(c[s >> 2] | 0) + 8 >> 2] | 0, 0, 0)
	                }
	                s = c[n >> 2] | 0;
	                if (!(c[(c[n >> 2] | 0) + 60 >> 2] | 0)) {
	                    if (c[s + 64 >> 2] | 0) {
	                        c[v >> 2] = -1;
	                        c[u >> 2] = c[(c[n >> 2] | 0) + 28 >> 2];
	                        c[w >> 2] = 0;
	                        while (1) {
	                            if ((c[w >> 2] | 0) >= (c[c[(c[n >> 2] | 0) + 64 >> 2] >> 2] | 0))break;
	                            c[q >> 2] = c[(c[(c[(c[n >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] | 0) + (c[w >> 2] << 2) >> 2];
	                            c[(c[n >> 2] | 0) + 60 >> 2] = c[q >> 2];
	                            c[(c[(c[n >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2] = 0;
	                            if (!(iO(c[n >> 2] | 0, 0) | 0)) {
	                                x = 39;
	                                break
	                            }
	                            c[w >> 2] = (c[w >> 2] | 0) + 1
	                        }
	                        if ((x | 0) == 39)c[v >> 2] = 0;
	                        if (c[v >> 2] | 0) {
	                            x = (c[n >> 2] | 0) + 28 | 0;
	                            c[x >> 2] = c[x >> 2] | 1;
	                            jO(c[n >> 2] | 0)
	                        }
	                        c[w >> 2] = 0;
	                        while (1) {
	                            y = c[n >> 2] | 0;
	                            if ((c[w >> 2] | 0) >= (c[c[(c[n >> 2] | 0) + 64 >> 2] >> 2] | 0))break;
	                            LN(y, c[(c[(c[(c[n >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] | 0) + (c[w >> 2] << 2) >> 2] | 0);
	                            c[w >> 2] = (c[w >> 2] | 0) + 1
	                        }
	                        NN(y, c[(c[n >> 2] | 0) + 64 >> 2] | 0);
	                        c[(c[n >> 2] | 0) + 64 >> 2] = 0;
	                        if ((c[t >> 2] | 0) == 0 & (c[v >> 2] | 0) == -1)c[(c[n >> 2] | 0) + 100 >> 2] = -1;
	                        c[(c[n >> 2] | 0) + 28 >> 2] = c[u >> 2]
	                    }
	                } else {
	                    c[(c[s + 60 >> 2] | 0) + 4 >> 2] = 0;
	                    c[t >> 2] = iO(c[n >> 2] | 0, 1) | 0;
	                    if (c[t >> 2] | 0)c[(c[n >> 2] | 0) + 100 >> 2] = -1;
	                    LN(c[n >> 2] | 0, c[(c[n >> 2] | 0) + 60 >> 2] | 0)
	                }
	                if ((c[(c[n >> 2] | 0) + 100 >> 2] | 0) == -1 ? (c[(c[n >> 2] | 0) + 28 >> 2] & 1 | 0) == 0 : 0)eO(c[n >> 2] | 0);
	                c[(c[n >> 2] | 0) + 60 >> 2] = c[r >> 2];
	                i = g;
	                return
	            }

	            function HN(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[(c[f >> 2] | 0) + 96 >> 2] | 0) == 0 ? (c[(c[f >> 2] | 0) + 92 >> 2] = 10, b = Cb[c[135744 >> 2] & 511](c[(c[f >> 2] | 0) + 92 >> 2] << 2) | 0, c[(c[f >> 2] | 0) + 96 >> 2] = b, (c[(c[f >> 2] | 0) + 96 >> 2] | 0) == 0) : 0) {
	                    MN(c[f >> 2] | 0, 189544);
	                    c[e >> 2] = -1;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                if ((c[(c[f >> 2] | 0) + 88 >> 2] | 0) >= (c[(c[f >> 2] | 0) + 92 >> 2] | 0) ? (b = (c[f >> 2] | 0) + 92 | 0, c[b >> 2] = c[b >> 2] << 1, b = Hb[c[135760 >> 2] & 511](c[(c[f >> 2] | 0) + 96 >> 2] | 0, c[(c[f >> 2] | 0) + 92 >> 2] << 2) | 0, c[(c[f >> 2] | 0) + 96 >> 2] = b, (c[(c[f >> 2] | 0) + 96 >> 2] | 0) == 0) : 0) {
	                    MN(c[f >> 2] | 0, 189544);
	                    c[e >> 2] = -1;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                b = c[g >> 2] | 0;
	                a = (c[f >> 2] | 0) + 88 | 0;
	                j = c[a >> 2] | 0;
	                c[a >> 2] = j + 1;
	                c[(c[(c[f >> 2] | 0) + 96 >> 2] | 0) + (j << 2) >> 2] = b;
	                c[(c[f >> 2] | 0) + 84 >> 2] = c[g >> 2];
	                c[e >> 2] = 0;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function IN(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if ((c[(c[e >> 2] | 0) + 88 >> 2] | 0) <= 0) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = (c[e >> 2] | 0) + 88 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + -1;
	                c[f >> 2] = c[(c[(c[e >> 2] | 0) + 96 >> 2] | 0) + (c[(c[e >> 2] | 0) + 88 >> 2] << 2) >> 2];
	                c[(c[(c[e >> 2] | 0) + 96 >> 2] | 0) + (c[(c[e >> 2] | 0) + 88 >> 2] << 2) >> 2] = 0;
	                a = c[e >> 2] | 0;
	                if ((c[(c[e >> 2] | 0) + 88 >> 2] | 0) > 0)c[(c[e >> 2] | 0) + 84 >> 2] = c[(c[(c[e >> 2] | 0) + 96 >> 2] | 0) + ((c[a + 88 >> 2] | 0) - 1 << 2) >> 2]; else c[a + 84 >> 2] = 0;
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function JN(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                d = i;
	                i = i + 128 | 0;
	                e = d + 112 | 0;
	                f = d + 108 | 0;
	                g = d + 104 | 0;
	                h = d + 100 | 0;
	                j = d + 96 | 0;
	                k = d + 16 | 0;
	                l = d + 8 | 0;
	                m = d + 4 | 0;
	                n = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[l >> 2] = 0;
	                c[m >> 2] = 0;
	                a:do if (!(c[g >> 2] | 0)) {
	                    c[m >> 2] = Pi(c[(c[f >> 2] | 0) + 24 >> 2] | 0) | 0;
	                    if (!(c[m >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        o = c[e >> 2] | 0;
	                        i = d;
	                        return o | 0
	                    }
	                } else {
	                    c[j >> 2] = c[(c[g >> 2] | 0) + 44 >> 2];
	                    while (1) {
	                        if (!(c[j >> 2] | 0))break a;
	                        if ((c[l >> 2] | 0) < 20) {
	                            b = c[j >> 2] | 0;
	                            a = c[l >> 2] | 0;
	                            c[l >> 2] = a + 1;
	                            c[k + (a << 2) >> 2] = b
	                        } else c[l >> 2] = (c[l >> 2] | 0) + 1;
	                        c[j >> 2] = c[(c[j >> 2] | 0) + 24 >> 2]
	                    }
	                } while (0);
	                if ((c[(c[f >> 2] | 0) + 68 >> 2] | 0) != 0 ? (c[c[(c[f >> 2] | 0) + 68 >> 2] >> 2] | 0) > 0 : 0) {
	                    b = c[(c[f >> 2] | 0) + 68 >> 2] | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + -1;
	                    c[h >> 2] = c[(c[(c[(c[f >> 2] | 0) + 68 >> 2] | 0) + 8 >> 2] | 0) + (c[c[(c[f >> 2] | 0) + 68 >> 2] >> 2] << 2) >> 2]
	                } else p = 13;
	                do if ((p | 0) == 13) {
	                    c[h >> 2] = Cb[c[135744 >> 2] & 511](32) | 0;
	                    if (c[h >> 2] | 0) {
	                        b = c[h >> 2] | 0;
	                        c[b + 0 >> 2] = 0;
	                        c[b + 4 >> 2] = 0;
	                        c[b + 8 >> 2] = 0;
	                        c[b + 12 >> 2] = 0;
	                        c[b + 16 >> 2] = 0;
	                        c[b + 20 >> 2] = 0;
	                        c[b + 24 >> 2] = 0;
	                        c[b + 28 >> 2] = 0;
	                        break
	                    }
	                    MN(c[f >> 2] | 0, 189568);
	                    c[e >> 2] = 0;
	                    o = c[e >> 2] | 0;
	                    i = d;
	                    return o | 0
	                } while (0);
	                c[(c[h >> 2] | 0) + 20 >> 2] = 0;
	                c[(c[h >> 2] | 0) + 24 >> 2] = 0;
	                if (!(c[g >> 2] | 0)) {
	                    c[c[h >> 2] >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                    c[(c[h >> 2] | 0) + 4 >> 2] = c[m >> 2]
	                } else {
	                    c[c[h >> 2] >> 2] = c[g >> 2];
	                    c[(c[h >> 2] | 0) + 4 >> 2] = c[(c[g >> 2] | 0) + 12 >> 2]
	                }
	                c[(c[h >> 2] | 0) + 8 >> 2] = 0;
	                b:do if ((c[l >> 2] | 0) > 0) {
	                    do if (!(c[(c[h >> 2] | 0) + 28 >> 2] | 0)) {
	                        if ((c[l >> 2] | 0) < 4)c[(c[h >> 2] | 0) + 12 >> 2] = 4; else c[(c[h >> 2] | 0) + 12 >> 2] = c[l >> 2];
	                        m = Cb[c[135744 >> 2] & 511](c[(c[h >> 2] | 0) + 12 >> 2] << 2) | 0;
	                        c[(c[h >> 2] | 0) + 28 >> 2] = m;
	                        if (!(c[(c[h >> 2] | 0) + 28 >> 2] | 0)) {
	                            MN(c[f >> 2] | 0, 189568);
	                            c[e >> 2] = c[h >> 2];
	                            o = c[e >> 2] | 0;
	                            i = d;
	                            return o | 0
	                        }
	                    } else if ((c[(c[h >> 2] | 0) + 12 >> 2] | 0) < (c[l >> 2] | 0)) {
	                        c[n >> 2] = Hb[c[135760 >> 2] & 511](c[(c[h >> 2] | 0) + 28 >> 2] | 0, c[l >> 2] << 2) | 0;
	                        if (c[n >> 2] | 0) {
	                            c[(c[h >> 2] | 0) + 28 >> 2] = c[n >> 2];
	                            c[(c[h >> 2] | 0) + 12 >> 2] = c[l >> 2];
	                            break
	                        }
	                        MN(c[f >> 2] | 0, 189568);
	                        c[e >> 2] = c[h >> 2];
	                        o = c[e >> 2] | 0;
	                        i = d;
	                        return o | 0
	                    } while (0);
	                    c[(c[h >> 2] | 0) + 8 >> 2] = c[l >> 2];
	                    if ((c[l >> 2] | 0) < 20) {
	                        eU(c[(c[h >> 2] | 0) + 28 >> 2] | 0, k | 0, c[l >> 2] << 2 | 0) | 0;
	                        break
	                    }
	                    c[j >> 2] = c[(c[g >> 2] | 0) + 44 >> 2];
	                    c[l >> 2] = 0;
	                    while (1) {
	                        if (!(c[j >> 2] | 0))break b;
	                        m = c[j >> 2] | 0;
	                        p = c[l >> 2] | 0;
	                        c[l >> 2] = p + 1;
	                        c[(c[(c[h >> 2] | 0) + 28 >> 2] | 0) + (p << 2) >> 2] = m;
	                        c[j >> 2] = c[(c[j >> 2] | 0) + 24 >> 2]
	                    }
	                } while (0);
	                c[(c[h >> 2] | 0) + 16 >> 2] = c[(c[h >> 2] | 0) + 8 >> 2];
	                c[e >> 2] = c[h >> 2];
	                o = c[e >> 2] | 0;
	                i = d;
	                return o | 0
	            }

	            function KN(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                d = i;
	                i = i + 48 | 0;
	                e = d;
	                f = d + 44 | 0;
	                g = d + 40 | 0;
	                h = d + 36 | 0;
	                j = d + 32 | 0;
	                k = d + 28 | 0;
	                l = d + 24 | 0;
	                m = d + 20 | 0;
	                n = d + 16 | 0;
	                o = d + 12 | 0;
	                p = d + 8 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                if ((c[(c[g >> 2] | 0) + 60 >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 64 >> 2] | 0) != 0 : 0) {
	                    b = c[33976] | 0;
	                    a = c[33980] | 0;
	                    c[e >> 2] = 189496;
	                    c[e + 4 >> 2] = 10608;
	                    Db[b & 511](a, 189464, e);
	                    LN(c[g >> 2] | 0, c[(c[g >> 2] | 0) + 60 >> 2] | 0);
	                    c[(c[g >> 2] | 0) + 60 >> 2] = 0
	                }
	                if ((c[(c[g >> 2] | 0) + 64 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 64 >> 2] >> 2] | 0) != 1 : 0) {
	                    c[j >> 2] = c[(c[g >> 2] | 0) + 64 >> 2];
	                    c[(c[g >> 2] | 0) + 64 >> 2] = 0;
	                    c[k >> 2] = 0;
	                    c[m >> 2] = 0;
	                    c[p >> 2] = c[(c[g >> 2] | 0) + 28 >> 2];
	                    a = (c[g >> 2] | 0) + 28 | 0;
	                    c[a >> 2] = c[a >> 2] | 1;
	                    c[l >> 2] = 0;
	                    while (1) {
	                        if ((c[l >> 2] | 0) >= (c[c[j >> 2] >> 2] | 0))break;
	                        c[(c[g >> 2] | 0) + 60 >> 2] = c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + (c[l >> 2] << 2) >> 2];
	                        c[(c[g >> 2] | 0) + 64 >> 2] = 0;
	                        c[o >> 2] = kO(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                        if ((c[(c[g >> 2] | 0) + 60 >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 64 >> 2] | 0) != 0 : 0) {
	                            a = c[33976] | 0;
	                            b = c[33980] | 0;
	                            c[e >> 2] = 189496;
	                            c[e + 4 >> 2] = 10645;
	                            Db[a & 511](b, 189464, e);
	                            LN(c[g >> 2] | 0, c[(c[g >> 2] | 0) + 60 >> 2] | 0);
	                            c[(c[g >> 2] | 0) + 60 >> 2] = 0
	                        }
	                        b = c[g >> 2] | 0;
	                        a:do if (c[o >> 2] | 0) {
	                            a = c[g >> 2] | 0;
	                            if (c[b + 60 >> 2] | 0) {
	                                LN(a, c[(c[g >> 2] | 0) + 60 >> 2] | 0);
	                                c[(c[g >> 2] | 0) + 60 >> 2] = 0;
	                                break
	                            }
	                            if (c[a + 64 >> 2] | 0) {
	                                c[n >> 2] = 0;
	                                while (1) {
	                                    q = c[g >> 2] | 0;
	                                    if ((c[n >> 2] | 0) >= (c[c[(c[g >> 2] | 0) + 64 >> 2] >> 2] | 0))break;
	                                    LN(q, c[(c[(c[(c[g >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] | 0) + (c[n >> 2] << 2) >> 2] | 0);
	                                    c[n >> 2] = (c[n >> 2] | 0) + 1
	                                }
	                                NN(q, c[(c[g >> 2] | 0) + 64 >> 2] | 0);
	                                c[(c[g >> 2] | 0) + 64 >> 2] = 0
	                            }
	                        } else {
	                            a = c[k >> 2] | 0;
	                            if (!(c[b + 64 >> 2] | 0)) {
	                                r = c[g >> 2] | 0;
	                                if (a) {
	                                    lO(r, c[k >> 2] | 0, c[(c[g >> 2] | 0) + 60 >> 2] | 0) | 0;
	                                    c[(c[g >> 2] | 0) + 60 >> 2] = 0;
	                                    break
	                                } else {
	                                    s = c[r + 60 >> 2] | 0;
	                                    r = c[m >> 2] | 0;
	                                    c[m >> 2] = r + 1;
	                                    c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + (r << 2) >> 2] = s;
	                                    c[(c[g >> 2] | 0) + 60 >> 2] = 0;
	                                    break
	                                }
	                            }
	                            if (!a) {
	                                c[k >> 2] = c[(c[g >> 2] | 0) + 64 >> 2];
	                                c[(c[g >> 2] | 0) + 64 >> 2] = 0;
	                                c[n >> 2] = 0;
	                                while (1) {
	                                    if ((c[n >> 2] | 0) >= (c[m >> 2] | 0))break a;
	                                    lO(c[g >> 2] | 0, c[k >> 2] | 0, c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + (c[n >> 2] << 2) >> 2] | 0) | 0;
	                                    c[n >> 2] = (c[n >> 2] | 0) + 1
	                                }
	                            }
	                            c[n >> 2] = 0;
	                            while (1) {
	                                t = c[g >> 2] | 0;
	                                if ((c[n >> 2] | 0) >= (c[c[(c[g >> 2] | 0) + 64 >> 2] >> 2] | 0))break;
	                                lO(t, c[k >> 2] | 0, c[(c[(c[(c[g >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] | 0) + (c[n >> 2] << 2) >> 2] | 0) | 0;
	                                c[n >> 2] = (c[n >> 2] | 0) + 1
	                            }
	                            NN(t, c[(c[g >> 2] | 0) + 64 >> 2] | 0);
	                            c[(c[g >> 2] | 0) + 64 >> 2] = 0
	                        } while (0);
	                        c[l >> 2] = (c[l >> 2] | 0) + 1
	                    }
	                    c[(c[g >> 2] | 0) + 28 >> 2] = c[p >> 2];
	                    do if (!(c[k >> 2] | 0)) {
	                        p = c[m >> 2] | 0;
	                        if ((c[m >> 2] | 0) > 1) {
	                            c[c[j >> 2] >> 2] = p;
	                            c[(c[g >> 2] | 0) + 64 >> 2] = c[j >> 2];
	                            c[o >> 2] = 0;
	                            break
	                        }
	                        if ((p | 0) == 1) {
	                            c[(c[g >> 2] | 0) + 60 >> 2] = c[c[(c[j >> 2] | 0) + 8 >> 2] >> 2];
	                            NN(c[g >> 2] | 0, c[j >> 2] | 0);
	                            c[o >> 2] = 0;
	                            break
	                        }
	                        c[o >> 2] = -1;
	                        NN(c[g >> 2] | 0, c[j >> 2] | 0);
	                        if (c[(c[g >> 2] | 0) + 64 >> 2] | 0) {
	                            NN(c[g >> 2] | 0, c[(c[g >> 2] | 0) + 64 >> 2] | 0);
	                            c[(c[g >> 2] | 0) + 64 >> 2] = 0
	                        }
	                    } else {
	                        NN(c[g >> 2] | 0, c[j >> 2] | 0);
	                        c[(c[g >> 2] | 0) + 64 >> 2] = c[k >> 2];
	                        c[o >> 2] = 0
	                    } while (0);
	                    if ((c[(c[g >> 2] | 0) + 60 >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 64 >> 2] | 0) != 0 : 0) {
	                        k = c[33976] | 0;
	                        j = c[33980] | 0;
	                        c[e >> 2] = 189496;
	                        c[e + 4 >> 2] = 10711;
	                        Db[k & 511](j, 189464, e);
	                        LN(c[g >> 2] | 0, c[(c[g >> 2] | 0) + 60 >> 2] | 0);
	                        c[(c[g >> 2] | 0) + 60 >> 2] = 0
	                    }
	                    c[f >> 2] = c[o >> 2];
	                    u = c[f >> 2] | 0;
	                    i = d;
	                    return u | 0
	                }
	                if (c[(c[g >> 2] | 0) + 64 >> 2] | 0) {
	                    c[(c[g >> 2] | 0) + 60 >> 2] = c[c[(c[(c[g >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] >> 2];
	                    NN(c[g >> 2] | 0, c[(c[g >> 2] | 0) + 64 >> 2] | 0);
	                    c[(c[g >> 2] | 0) + 64 >> 2] = 0
	                }
	                c[o >> 2] = kO(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                if ((c[(c[g >> 2] | 0) + 60 >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 64 >> 2] | 0) != 0 : 0) {
	                    h = c[33976] | 0;
	                    j = c[33980] | 0;
	                    c[e >> 2] = 189496;
	                    c[e + 4 >> 2] = 10620;
	                    Db[h & 511](j, 189464, e);
	                    LN(c[g >> 2] | 0, c[(c[g >> 2] | 0) + 60 >> 2] | 0);
	                    c[(c[g >> 2] | 0) + 60 >> 2] = 0
	                }
	                if ((c[(c[g >> 2] | 0) + 64 >> 2] | 0) != 0 ? (c[c[(c[g >> 2] | 0) + 64 >> 2] >> 2] | 0) == 1 : 0) {
	                    c[(c[g >> 2] | 0) + 60 >> 2] = c[c[(c[(c[g >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] >> 2];
	                    NN(c[g >> 2] | 0, c[(c[g >> 2] | 0) + 64 >> 2] | 0);
	                    c[(c[g >> 2] | 0) + 64 >> 2] = 0
	                }
	                c[f >> 2] = c[o >> 2];
	                u = c[f >> 2] | 0;
	                i = d;
	                return u | 0
	            }

	            function LN(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 68 >> 2] | 0) == 0 : 0) {
	                    b = mO(c[e >> 2] | 0, 40) | 0;
	                    c[(c[e >> 2] | 0) + 68 >> 2] = b
	                }
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 68 >> 2] | 0) != 0 : 0) {
	                    nO(c[e >> 2] | 0, c[(c[e >> 2] | 0) + 68 >> 2] | 0, c[f >> 2] | 0) | 0;
	                    i = d;
	                    return
	                }
	                if (c[(c[f >> 2] | 0) + 28 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 28 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                i = d;
	                return
	            }

	            function MN(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                c[j >> 2] = 0;
	                c[k >> 2] = 0;
	                if (c[f >> 2] | 0) {
	                    b = c[f >> 2] | 0;
	                    if (c[(c[f >> 2] | 0) + 12 >> 2] | 0)c[h >> 2] = c[b + 12 >> 2]; else c[j >> 2] = c[b + 4 >> 2];
	                    c[k >> 2] = c[c[f >> 2] >> 2];
	                    b = (c[f >> 2] | 0) + 16 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + 1
	                }
	                b = c[h >> 2] | 0;
	                h = c[j >> 2] | 0;
	                j = c[k >> 2] | 0;
	                if (c[g >> 2] | 0) {
	                    k = c[g >> 2] | 0;
	                    c[e >> 2] = c[g >> 2];
	                    Xd(b, h, j, 0, 0, 19, 2, 3, 0, 0, k, 0, 0, 0, 0, 189400, e);
	                    i = d;
	                    return
	                } else {
	                    Xd(b, h, j, 0, 0, 19, 2, 3, 0, 0, 0, 0, 0, 0, 0, 189432, e);
	                    i = d;
	                    return
	                }
	            }

	            function NN(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 80 >> 2] | 0) == 0 : 0) {
	                    c[(c[e >> 2] | 0) + 76 >> 2] = 40;
	                    c[(c[e >> 2] | 0) + 72 >> 2] = 0;
	                    b = Cb[c[135744 >> 2] & 511](c[(c[e >> 2] | 0) + 76 >> 2] << 2) | 0;
	                    c[(c[e >> 2] | 0) + 80 >> 2] = b;
	                    if (!(c[(c[e >> 2] | 0) + 80 >> 2] | 0))MN(c[e >> 2] | 0, 189384)
	                } else h = 6;
	                do if (((h | 0) == 6 ? (c[e >> 2] | 0) != 0 : 0) ? (c[(c[e >> 2] | 0) + 72 >> 2] | 0) >= (c[(c[e >> 2] | 0) + 76 >> 2] | 0) : 0) {
	                    c[g >> 2] = Hb[c[135760 >> 2] & 511](c[(c[e >> 2] | 0) + 80 >> 2] | 0, c[(c[e >> 2] | 0) + 76 >> 2] << 1 << 2) | 0;
	                    if (c[g >> 2] | 0) {
	                        c[(c[e >> 2] | 0) + 80 >> 2] = c[g >> 2];
	                        b = (c[e >> 2] | 0) + 76 | 0;
	                        c[b >> 2] = c[b >> 2] << 1;
	                        break
	                    }
	                    MN(c[e >> 2] | 0, 189384);
	                    zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 8 >> 2] | 0);
	                    zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                    i = d;
	                    return
	                } while (0);
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 80 >> 2] | 0) != 0 : 0) {
	                    g = c[f >> 2] | 0;
	                    h = (c[e >> 2] | 0) + 72 | 0;
	                    b = c[h >> 2] | 0;
	                    c[h >> 2] = b + 1;
	                    c[(c[(c[e >> 2] | 0) + 80 >> 2] | 0) + (b << 2) >> 2] = g;
	                    i = d;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[(c[f >> 2] | 0) + 8 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                i = d;
	                return
	            }

	            function ON(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                d = i;
	                i = i + 112 | 0;
	                e = d + 100 | 0;
	                f = d + 96 | 0;
	                g = d + 92 | 0;
	                h = d + 88 | 0;
	                j = d + 84 | 0;
	                k = d + 80 | 0;
	                l = d + 76 | 0;
	                m = d + 72 | 0;
	                n = d + 68 | 0;
	                o = d + 64 | 0;
	                p = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) != 0 ? !((c[g >> 2] | 0) == 0 ? 1 : (c[(c[f >> 2] | 0) + 20 >> 2] | 0) == 0) : 0) {
	                    c[(c[f >> 2] | 0) + 40 >> 2] = 0;
	                    c[j >> 2] = c[(c[f >> 2] | 0) + 20 >> 2];
	                    c[k >> 2] = c[(c[j >> 2] | 0) + 4 >> 2];
	                    j = c[f >> 2] | 0;
	                    if (!(c[k >> 2] | 0)) {
	                        FN(j, 34, 0, 0, 0);
	                        c[e >> 2] = -1;
	                        q = c[e >> 2] | 0;
	                        i = d;
	                        return q | 0
	                    }
	                    c[l >> 2] = JN(j, 0) | 0;
	                    c[(c[f >> 2] | 0) + 60 >> 2] = c[l >> 2];
	                    c[h >> 2] = KN(c[f >> 2] | 0, c[(c[k >> 2] | 0) + 12 >> 2] | 0) | 0;
	                    if ((c[(c[f >> 2] | 0) + 60 >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                        c[l >> 2] = c[(c[f >> 2] | 0) + 60 >> 2];
	                        c[m >> 2] = c[(c[l >> 2] | 0) + 4 >> 2];
	                        c[m >> 2] = oO(c[f >> 2] | 0, c[m >> 2] | 0) | 0;
	                        if ((c[m >> 2] | 0) != 0 & (c[h >> 2] | 0) != -1) {
	                            FN(c[f >> 2] | 0, 35, 0, 0, 0);
	                            c[h >> 2] = -1
	                        }
	                    } else r = 10;
	                    if ((r | 0) == 10 ? (c[(c[f >> 2] | 0) + 64 >> 2] | 0) != 0 : 0) {
	                        c[o >> 2] = -1;
	                        c[n >> 2] = 0;
	                        while (1) {
	                            if ((c[n >> 2] | 0) >= (c[c[(c[f >> 2] | 0) + 64 >> 2] >> 2] | 0))break;
	                            c[l >> 2] = c[(c[(c[(c[f >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] | 0) + (c[n >> 2] << 2) >> 2];
	                            c[m >> 2] = c[(c[l >> 2] | 0) + 4 >> 2];
	                            c[m >> 2] = oO(c[f >> 2] | 0, c[m >> 2] | 0) | 0;
	                            if (!(c[m >> 2] | 0))c[o >> 2] = 0;
	                            LN(c[f >> 2] | 0, c[l >> 2] | 0);
	                            c[n >> 2] = (c[n >> 2] | 0) + 1
	                        }
	                        if ((c[o >> 2] | 0) == -1 & (c[h >> 2] | 0) != -1) {
	                            FN(c[f >> 2] | 0, 35, 0, 0, 0);
	                            c[h >> 2] = -1
	                        }
	                    }
	                    if (c[(c[f >> 2] | 0) + 60 >> 2] | 0) {
	                        LN(c[f >> 2] | 0, c[(c[f >> 2] | 0) + 60 >> 2] | 0);
	                        c[(c[f >> 2] | 0) + 60 >> 2] = 0
	                    }
	                    if (c[h >> 2] | 0)eO(c[f >> 2] | 0);
	                    if ((c[(c[f >> 2] | 0) + 36 >> 2] | 0) == 1) {
	                        o = p + 0 | 0;
	                        n = o + 64 | 0;
	                        do {
	                            c[o >> 2] = 0;
	                            o = o + 4 | 0
	                        } while ((o | 0) < (n | 0));
	                        c[p + 36 >> 2] = 1;
	                        c[p + 4 >> 2] = c[(c[f >> 2] | 0) + 4 >> 2];
	                        c[p + 8 >> 2] = c[(c[f >> 2] | 0) + 8 >> 2];
	                        c[p >> 2] = c[c[f >> 2] >> 2];
	                        if ((cn(p, c[g >> 2] | 0) | 0) != 1)c[h >> 2] = -1
	                    }
	                    if ((c[h >> 2] | 0) == 0 ? (c[(c[f >> 2] | 0) + 40 >> 2] | 0) != 0 : 0)c[h >> 2] = -1;
	                    c[e >> 2] = c[h >> 2];
	                    q = c[e >> 2] | 0;
	                    i = d;
	                    return q | 0
	                }
	                c[e >> 2] = -1;
	                q = c[e >> 2] | 0;
	                i = d;
	                return q | 0
	            }

	            function PN(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (((c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 9 : 0) ? (c[(c[d >> 2] | 0) + 4 >> 2] | 0) != 13 : 0) {
	                    i = b;
	                    return
	                }
	                if ((c[(c[d >> 2] | 0) + 4 >> 2] | 0) == 1)c[(c[d >> 2] | 0) + 52 >> 2] = 0;
	                c[e >> 2] = c[(c[d >> 2] | 0) + 12 >> 2];
	                a:while (1) {
	                    if (!(c[e >> 2] | 0))break;
	                    if ((c[(c[e >> 2] | 0) + 4 >> 2] | 0) == 1 ? (c[(c[e >> 2] | 0) + 52 >> 2] = 0, (c[(c[e >> 2] | 0) + 12 >> 2] | 0) != 0) : 0) {
	                        c[e >> 2] = c[(c[e >> 2] | 0) + 12 >> 2];
	                        continue
	                    }
	                    if (c[(c[e >> 2] | 0) + 24 >> 2] | 0) {
	                        c[e >> 2] = c[(c[e >> 2] | 0) + 24 >> 2];
	                        continue
	                    }
	                    while (1) {
	                        c[e >> 2] = c[(c[e >> 2] | 0) + 20 >> 2];
	                        if (!(c[e >> 2] | 0))continue a;
	                        if ((c[e >> 2] | 0) == (c[d >> 2] | 0)) {
	                            f = 16;
	                            break
	                        }
	                        g = c[e >> 2] | 0;
	                        if (c[(c[e >> 2] | 0) + 24 >> 2] | 0) {
	                            f = 18;
	                            break
	                        }
	                        if (!g)continue a
	                    }
	                    if ((f | 0) == 16) {
	                        f = 0;
	                        c[e >> 2] = 0;
	                        continue
	                    } else if ((f | 0) == 18) {
	                        f = 0;
	                        c[e >> 2] = c[g + 24 >> 2];
	                        continue
	                    }
	                }
	                i = b;
	                return
	            }

	            function QN(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 4 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 4 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 8 >> 2] | 0)Th(c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 16 >> 2] | 0)VM(c[(c[d >> 2] | 0) + 16 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function RN(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 12 >> 2] | 0) {
	                    c[f >> 2] = 0;
	                    while (1) {
	                        if ((c[f >> 2] | 0) >= (c[c[d >> 2] >> 2] | 0))break;
	                        c[e >> 2] = c[(c[(c[d >> 2] | 0) + 12 >> 2] | 0) + (c[f >> 2] << 2) >> 2];
	                        if (c[e >> 2] | 0) {
	                            if (c[(c[e >> 2] | 0) + 4 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[e >> 2] | 0) + 4 >> 2] | 0);
	                            if (c[(c[e >> 2] | 0) + 8 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[e >> 2] | 0) + 8 >> 2] | 0);
	                            zb[c[135736 >> 2] & 511](c[e >> 2] | 0)
	                        }
	                        c[f >> 2] = (c[f >> 2] | 0) + 1
	                    }
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 12 >> 2] | 0)
	                }
	                if (c[(c[d >> 2] | 0) + 4 >> 2] | 0)Kj(c[(c[d >> 2] | 0) + 4 >> 2] | 0, 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function SN(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 24 | 0;
	                h = f + 20 | 0;
	                j = f + 16 | 0;
	                k = f + 12 | 0;
	                l = f + 8 | 0;
	                m = f + 4 | 0;
	                n = f;
	                c[h >> 2] = b;
	                c[j >> 2] = e;
	                if (!(c[j >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                c[m >> 2] = c[j >> 2];
	                while (1) {
	                    p = c[m >> 2] | 0;
	                    if (!(d[c[m >> 2] >> 0] | 0))break;
	                    c[m >> 2] = p + 1
	                }
	                c[n >> 2] = p - (c[j >> 2] | 0);
	                c[k >> 2] = Cb[c[135752 >> 2] & 511]((c[n >> 2] | 0) + 1 | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    MN(c[h >> 2] | 0, 189544);
	                    c[g >> 2] = 0;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                c[l >> 2] = c[k >> 2];
	                a:while (1) {
	                    do if ((d[c[j >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[j >> 2] >> 0] | 0 | 0) ? (d[c[j >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[j >> 2] >> 0] | 0 | 0) != 13)break a
	                    } while (0);
	                    c[j >> 2] = (c[j >> 2] | 0) + 1
	                }
	                b:while (1) {
	                    if (!(d[c[j >> 2] >> 0] | 0))break;
	                    do if ((d[c[j >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[j >> 2] >> 0] | 0 | 0) ? (d[c[j >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[j >> 2] >> 0] | 0 | 0) != 13) {
	                            h = c[j >> 2] | 0;
	                            c[j >> 2] = h + 1;
	                            n = a[h >> 0] | 0;
	                            h = c[l >> 2] | 0;
	                            c[l >> 2] = h + 1;
	                            a[h >> 0] = n;
	                            continue b
	                        }
	                    } while (0);
	                    while (1) {
	                        do if ((d[c[j >> 2] >> 0] | 0 | 0) == 32)q = 1; else {
	                            if (9 <= (d[c[j >> 2] >> 0] | 0 | 0) ? (d[c[j >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                q = 1;
	                                break
	                            }
	                            q = (d[c[j >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        r = c[j >> 2] | 0;
	                        if (!q)break;
	                        c[j >> 2] = r + 1
	                    }
	                    if (!(d[r >> 0] | 0))break;
	                    n = c[l >> 2] | 0;
	                    c[l >> 2] = n + 1;
	                    a[n >> 0] = 32
	                }
	                a[c[l >> 2] >> 0] = 0;
	                c[g >> 2] = c[k >> 2];
	                o = c[g >> 2] | 0;
	                i = f;
	                return o | 0
	            }

	            function TN(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 8 >> 2] | 0)Th(c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 36 >> 2] | 0) {
	                    c[e >> 2] = 0;
	                    while (1) {
	                        if ((c[e >> 2] | 0) >= (c[(c[d >> 2] | 0) + 32 >> 2] | 0))break;
	                        mN(c[(c[(c[d >> 2] | 0) + 36 >> 2] | 0) + (c[e >> 2] << 2) >> 2] | 0);
	                        c[e >> 2] = (c[e >> 2] | 0) + 1
	                    }
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 36 >> 2] | 0)
	                }
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function UN(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0, J = 0, K = 0, L = 0, M = 0, N = 0, O = 0, P = 0, Q = 0, R = 0, S = 0;
	                d = i;
	                i = i + 144 | 0;
	                e = d + 128 | 0;
	                f = d + 124 | 0;
	                g = d + 120 | 0;
	                h = d + 116 | 0;
	                j = d + 112 | 0;
	                k = d + 108 | 0;
	                l = d + 104 | 0;
	                m = d + 100 | 0;
	                n = d + 96 | 0;
	                o = d + 92 | 0;
	                p = d + 88 | 0;
	                q = d + 84 | 0;
	                r = d + 80 | 0;
	                s = d + 76 | 0;
	                t = d + 72 | 0;
	                u = d + 68 | 0;
	                v = d + 64 | 0;
	                w = d + 60 | 0;
	                x = d + 56 | 0;
	                y = d + 52 | 0;
	                z = d + 48 | 0;
	                A = d + 44 | 0;
	                B = d + 40 | 0;
	                C = d + 36 | 0;
	                D = d + 32 | 0;
	                E = d + 28 | 0;
	                F = d + 24 | 0;
	                G = d + 20 | 0;
	                H = d + 16 | 0;
	                I = d + 12 | 0;
	                J = d + 8 | 0;
	                K = d + 4 | 0;
	                L = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[h >> 2] = 0;
	                c[g >> 2] = c[f >> 2];
	                a:while (1) {
	                    M = (c[h >> 2] | 0) != 0;
	                    if (!(c[g >> 2] | 0))break;
	                    if (M) {
	                        Qh(c[h >> 2] | 0);
	                        Rh(c[h >> 2] | 0);
	                        c[h >> 2] = 0
	                    }
	                    b = c[g >> 2] | 0;
	                    b:do if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 1) {
	                        if ((c[b + 4 >> 2] | 0) != 3 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 4 : 0) {
	                            c[h >> 2] = c[g >> 2];
	                            break
	                        }
	                        if (sO(c[(c[g >> 2] | 0) + 40 >> 2] | 0) | 0) {
	                            if ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) {
	                                if (qy(c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0, 189888) | 0) {
	                                    N = 158;
	                                    break
	                                }
	                                if (qy(c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0, 190064) | 0) {
	                                    N = 158;
	                                    break
	                                }
	                                c[h >> 2] = c[g >> 2];
	                                N = 158;
	                                break
	                            }
	                            c[h >> 2] = c[g >> 2]
	                        } else N = 158
	                    } else {
	                        if ((c[b + 36 >> 2] | 0) != 0 ? (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                            pO(c[e >> 2] | 0, c[g >> 2] | 0);
	                            a = (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 189936) | 0) != 0;
	                            O = c[g >> 2] | 0;
	                            c:do if (a) {
	                                c[k >> 2] = Yi(O, 192672) | 0;
	                                d:do if (!(c[k >> 2] | 0)) {
	                                    c[o >> 2] = c[(c[g >> 2] | 0) + 20 >> 2];
	                                    while (1) {
	                                        if (!(c[o >> 2] | 0))break d;
	                                        if ((c[(c[o >> 2] | 0) + 4 >> 2] | 0) != 1)break d;
	                                        c[k >> 2] = Yi(c[o >> 2] | 0, 192672) | 0;
	                                        if (c[k >> 2] | 0)break d;
	                                        c[o >> 2] = c[(c[o >> 2] | 0) + 20 >> 2]
	                                    }
	                                } while (0);
	                                c[j >> 2] = Yi(c[g >> 2] | 0, 195400) | 0;
	                                if (!(c[j >> 2] | 0)) {
	                                    zN(c[e >> 2] | 0, c[g >> 2] | 0, 1052, 195408, 0, 0);
	                                    if (c[k >> 2] | 0)zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                                    c[h >> 2] = c[g >> 2];
	                                    break b
	                                }
	                                c[p >> 2] = yl(c[j >> 2] | 0) | 0;
	                                if (!(c[p >> 2] | 0)) {
	                                    zN(c[e >> 2] | 0, c[g >> 2] | 0, 1041, 195464, c[j >> 2] | 0, 0);
	                                    if (c[k >> 2] | 0)zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                                    if (c[j >> 2] | 0)zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                                    c[h >> 2] = c[g >> 2];
	                                    break b
	                                }
	                                if (c[(c[p >> 2] | 0) + 32 >> 2] | 0) {
	                                    zN(c[e >> 2] | 0, c[g >> 2] | 0, 1041, 195504, c[j >> 2] | 0, 0);
	                                    if (c[k >> 2] | 0)zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                                    Al(c[p >> 2] | 0);
	                                    if (c[j >> 2] | 0)zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                                    c[h >> 2] = c[g >> 2];
	                                    break b
	                                }
	                                Al(c[p >> 2] | 0);
	                                c[l >> 2] = Xi(c[(c[g >> 2] | 0) + 32 >> 2] | 0, c[g >> 2] | 0) | 0;
	                                c[m >> 2] = Hl(c[j >> 2] | 0, c[l >> 2] | 0) | 0;
	                                if (!(c[m >> 2] | 0)) {
	                                    zN(c[e >> 2] | 0, c[g >> 2] | 0, 1041, 195552, c[j >> 2] | 0, 0);
	                                    if (c[k >> 2] | 0)zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                                    if (c[j >> 2] | 0)zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                                    if (c[l >> 2] | 0)zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                                    c[h >> 2] = c[g >> 2];
	                                    break b
	                                }
	                                if (c[j >> 2] | 0)zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                                if (c[l >> 2] | 0)zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                                c[n >> 2] = qO(c[e >> 2] | 0, c[m >> 2] | 0, c[k >> 2] | 0) | 0;
	                                if (!(c[n >> 2] | 0)) {
	                                    zN(c[e >> 2] | 0, c[g >> 2] | 0, 1032, 195600, c[m >> 2] | 0, 0);
	                                    if (c[k >> 2] | 0)zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                                    zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                                    c[h >> 2] = c[g >> 2];
	                                    break b
	                                } else {
	                                    if (c[k >> 2] | 0)zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                                    zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                                    c[(c[g >> 2] | 0) + 52 >> 2] = c[n >> 2];
	                                    break
	                                }
	                            } else {
	                                P = (qy(c[O + 8 >> 2] | 0, 195024) | 0) != 0;
	                                Q = c[g >> 2] | 0;
	                                if (P) {
	                                    c[q >> 2] = Yi(Q, 195400) | 0;
	                                    if (!(c[q >> 2] | 0)) {
	                                        zN(c[e >> 2] | 0, c[g >> 2] | 0, 1052, 195632, 0, 0);
	                                        c[h >> 2] = c[g >> 2];
	                                        break b
	                                    }
	                                    c[s >> 2] = Xi(c[(c[g >> 2] | 0) + 32 >> 2] | 0, c[g >> 2] | 0) | 0;
	                                    c[t >> 2] = Hl(c[q >> 2] | 0, c[s >> 2] | 0) | 0;
	                                    if (!(c[t >> 2] | 0)) {
	                                        zN(c[e >> 2] | 0, c[g >> 2] | 0, 1041, 195680, c[q >> 2] | 0, 0);
	                                        if (c[q >> 2] | 0)zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                                        if (c[s >> 2] | 0)zb[c[135736 >> 2] & 511](c[s >> 2] | 0);
	                                        c[h >> 2] = c[g >> 2];
	                                        break b
	                                    }
	                                    if (c[q >> 2] | 0)zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                                    if (c[s >> 2] | 0)zb[c[135736 >> 2] & 511](c[s >> 2] | 0);
	                                    c[r >> 2] = Yi(c[g >> 2] | 0, 192672) | 0;
	                                    e:do if (!(c[r >> 2] | 0)) {
	                                        c[v >> 2] = c[(c[g >> 2] | 0) + 20 >> 2];
	                                        while (1) {
	                                            if (!(c[v >> 2] | 0))break e;
	                                            if ((c[(c[v >> 2] | 0) + 4 >> 2] | 0) != 1)break e;
	                                            c[r >> 2] = Yi(c[v >> 2] | 0, 192672) | 0;
	                                            if (c[r >> 2] | 0)break e;
	                                            c[v >> 2] = c[(c[v >> 2] | 0) + 20 >> 2]
	                                        }
	                                    } while (0);
	                                    c[u >> 2] = rO(c[e >> 2] | 0, c[t >> 2] | 0, c[g >> 2] | 0, c[r >> 2] | 0) | 0;
	                                    if (c[r >> 2] | 0)zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                                    if (!(c[u >> 2] | 0)) {
	                                        zN(c[e >> 2] | 0, c[g >> 2] | 0, 1043, 195720, c[t >> 2] | 0, 0);
	                                        zb[c[135736 >> 2] & 511](c[t >> 2] | 0);
	                                        c[h >> 2] = c[g >> 2];
	                                        break b
	                                    } else {
	                                        zb[c[135736 >> 2] & 511](c[t >> 2] | 0);
	                                        c[(c[g >> 2] | 0) + 52 >> 2] = c[u >> 2];
	                                        break
	                                    }
	                                }
	                                if ((qy(c[Q + 8 >> 2] | 0, 189864) | 0) == 0 ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 189904) | 0) == 0 : 0) {
	                                    if (((qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 192176) | 0) == 0 ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 193592) | 0) == 0 : 0) ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 189888) | 0) == 0 : 0) {
	                                        do if (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 189848) | 0) {
	                                            if ((c[g >> 2] | 0) == (c[f >> 2] | 0))break;
	                                            c[G >> 2] = c[(c[e >> 2] | 0) + 32 >> 2];
	                                            do if (c[(c[g >> 2] | 0) + 20 >> 2] | 0) {
	                                                if (!(qy(c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0, 193584) | 0))break;
	                                                P = (c[e >> 2] | 0) + 32 | 0;
	                                                c[P >> 2] = c[P >> 2] | 256;
	                                                UN(c[e >> 2] | 0, c[g >> 2] | 0);
	                                                c[(c[e >> 2] | 0) + 32 >> 2] = c[G >> 2];
	                                                break b
	                                            } while (0);
	                                            if (!(c[(c[g >> 2] | 0) + 20 >> 2] | 0))break c;
	                                            if (!(qy(c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0, 193592) | 0))break c;
	                                            P = (c[e >> 2] | 0) + 32 | 0;
	                                            c[P >> 2] = c[P >> 2] | 512;
	                                            UN(c[e >> 2] | 0, c[g >> 2] | 0);
	                                            c[(c[e >> 2] | 0) + 32 >> 2] = c[G >> 2];
	                                            break b
	                                        } while (0);
	                                        if (!(qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 193584) | 0))break;
	                                        Q = c[e >> 2] | 0;
	                                        if (c[(c[e >> 2] | 0) + 32 >> 2] & 256) {
	                                            zN(Q, c[g >> 2] | 0, 1066, 195896, 0, 0);
	                                            break
	                                        }
	                                        if (!(c[Q + 32 >> 2] & 512))break;
	                                        zN(c[e >> 2] | 0, c[g >> 2] | 0, 1084, 195952, 0, 0);
	                                        break
	                                    }
	                                    do if (!(dj(c[g >> 2] | 0, 192672) | 0)) {
	                                        c[B >> 2] = 0;
	                                        c[A >> 2] = c[(c[g >> 2] | 0) + 20 >> 2];
	                                        while (1) {
	                                            if (!(c[A >> 2] | 0))break;
	                                            if ((c[(c[A >> 2] | 0) + 4 >> 2] | 0) != 1)break;
	                                            c[B >> 2] = Yi(c[A >> 2] | 0, 192672) | 0;
	                                            if (c[B >> 2] | 0)break;
	                                            c[A >> 2] = c[(c[A >> 2] | 0) + 20 >> 2]
	                                        }
	                                        Q = c[g >> 2] | 0;
	                                        if (!(c[B >> 2] | 0)) {
	                                            gj(Q, 192672, 188112) | 0;
	                                            break
	                                        } else {
	                                            gj(Q, 192672, c[B >> 2] | 0) | 0;
	                                            zb[c[135736 >> 2] & 511](c[B >> 2] | 0);
	                                            break
	                                        }
	                                    } while (0);
	                                    if ((qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 192176) | 0) != 0 ? (c[C >> 2] = _i(c[g >> 2] | 0) | 0, (c[C >> 2] | 0) != 0) : 0) {
	                                        c[D >> 2] = Ch(c[C >> 2] | 0, E) | 0;
	                                        if (c[D >> 2] | 0) {
	                                            c[F >> 2] = cj(c[(c[g >> 2] | 0) + 32 >> 2] | 0, c[g >> 2] | 0, c[E >> 2] | 0) | 0;
	                                            if (!(c[F >> 2] | 0))zN(c[e >> 2] | 0, c[g >> 2] | 0, 1097, 195792, c[E >> 2] | 0, 0); else {
	                                                gj(c[g >> 2] | 0, 192672, c[(c[F >> 2] | 0) + 8 >> 2] | 0) | 0;
	                                                vi(c[g >> 2] | 0, c[D >> 2] | 0)
	                                            }
	                                            zb[c[135736 >> 2] & 511](c[D >> 2] | 0);
	                                            zb[c[135736 >> 2] & 511](c[E >> 2] | 0)
	                                        }
	                                        zb[c[135736 >> 2] & 511](c[C >> 2] | 0)
	                                    }
	                                    if (!(qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 193592) | 0))break;
	                                    if (!(c[(c[e >> 2] | 0) + 32 >> 2] & 512))break;
	                                    zN(c[e >> 2] | 0, c[g >> 2] | 0, 1085, 195840, 0, 0);
	                                    break
	                                }
	                                c[y >> 2] = 0;
	                                c[w >> 2] = Yi(c[g >> 2] | 0, 192176) | 0;
	                                if (c[w >> 2] | 0) {
	                                    Q = c[g >> 2] | 0;
	                                    if (c[(c[g >> 2] | 0) + 12 >> 2] | 0) {
	                                        c[z >> 2] = ji(c[Q + 32 >> 2] | 0, c[(c[g >> 2] | 0) + 36 >> 2] | 0, 192176, 0) | 0;
	                                        if (c[z >> 2] | 0) {
	                                            wi(c[(c[g >> 2] | 0) + 12 >> 2] | 0, c[z >> 2] | 0) | 0;
	                                            c[y >> 2] = li(c[w >> 2] | 0) | 0;
	                                            zi(c[z >> 2] | 0, c[y >> 2] | 0) | 0;
	                                            c[y >> 2] = c[z >> 2]
	                                        }
	                                    } else c[y >> 2] = ti(Q, c[(c[g >> 2] | 0) + 36 >> 2] | 0, 192176, c[w >> 2] | 0) | 0;
	                                    if (!(c[y >> 2] | 0))zN(c[e >> 2] | 0, c[g >> 2] | 0, 1008, 195752, c[w >> 2] | 0, 0);
	                                    fj(c[g >> 2] | 0, 192176) | 0;
	                                    zb[c[135736 >> 2] & 511](c[w >> 2] | 0);
	                                    c[x >> 2] = Yi(c[g >> 2] | 0, 192672) | 0;
	                                    if (!(c[x >> 2] | 0)) {
	                                        if (!(qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 189904) | 0))break;
	                                        gj(c[y >> 2] | 0, 192672, 188112) | 0;
	                                        break
	                                    }
	                                    if (c[y >> 2] | 0)gj(c[y >> 2] | 0, 192672, c[x >> 2] | 0) | 0;
	                                    zb[c[135736 >> 2] & 511](c[x >> 2] | 0)
	                                }
	                            } while (0);
	                            if (!(qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 196008) | 0)) {
	                                N = 158;
	                                break
	                            }
	                            c[H >> 2] = Yi(c[g >> 2] | 0, 192672) | 0;
	                            c[I >> 2] = c[(c[g >> 2] | 0) + 12 >> 2];
	                            c[J >> 2] = c[g >> 2];
	                            while (1) {
	                                R = (c[H >> 2] | 0) != 0;
	                                if (!(c[I >> 2] | 0))break;
	                                if (R ? (dj(c[I >> 2] | 0, 192672) | 0) == 0 : 0)gj(c[I >> 2] | 0, 192672, c[H >> 2] | 0) | 0;
	                                c[K >> 2] = c[(c[I >> 2] | 0) + 24 >> 2];
	                                Qh(c[I >> 2] | 0);
	                                c[J >> 2] = Xh(c[J >> 2] | 0, c[I >> 2] | 0) | 0;
	                                c[I >> 2] = c[K >> 2]
	                            }
	                            if (R)zb[c[135736 >> 2] & 511](c[H >> 2] | 0);
	                            if ((c[(c[g >> 2] | 0) + 48 >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) {
	                                c[L >> 2] = (c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 48;
	                                while (1) {
	                                    if (!(c[c[L >> 2] >> 2] | 0))break;
	                                    c[L >> 2] = c[c[L >> 2] >> 2]
	                                }
	                                c[c[L >> 2] >> 2] = c[(c[g >> 2] | 0) + 48 >> 2];
	                                c[(c[g >> 2] | 0) + 48 >> 2] = 0
	                            }
	                            c[h >> 2] = c[g >> 2];
	                            break
	                        }
	                        do if ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) {
	                            if (((qy(c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0, 192176) | 0) == 0 ? (qy(c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0, 189888) | 0) == 0 : 0) ? (qy(c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0, 190064) | 0) == 0 : 0)break;
	                            zN(c[e >> 2] | 0, c[g >> 2] | 0, 1035, 195352, c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0, 0)
	                        } while (0);
	                        c[h >> 2] = c[g >> 2]
	                    } while (0);
	                    if (((((N | 0) == 158 ? (N = 0, (c[(c[g >> 2] | 0) + 12 >> 2] | 0) != 0) : 0) ? (c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) != 17 : 0) ? (c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) != 5 : 0) ? (c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) != 6 : 0) {
	                        c[g >> 2] = c[(c[g >> 2] | 0) + 12 >> 2];
	                        continue
	                    }
	                    if (c[(c[g >> 2] | 0) + 24 >> 2] | 0) {
	                        c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                        continue
	                    }
	                    while (1) {
	                        c[g >> 2] = c[(c[g >> 2] | 0) + 20 >> 2];
	                        if (!(c[g >> 2] | 0))continue a;
	                        if ((c[g >> 2] | 0) == (c[f >> 2] | 0)) {
	                            N = 167;
	                            break
	                        }
	                        S = c[g >> 2] | 0;
	                        if (c[(c[g >> 2] | 0) + 24 >> 2] | 0) {
	                            N = 169;
	                            break
	                        }
	                        if (!S)continue a
	                    }
	                    if ((N | 0) == 167) {
	                        N = 0;
	                        c[g >> 2] = 0;
	                        continue
	                    } else if ((N | 0) == 169) {
	                        N = 0;
	                        c[g >> 2] = c[S + 24 >> 2];
	                        continue
	                    }
	                }
	                if (!M) {
	                    i = d;
	                    return
	                }
	                Qh(c[h >> 2] | 0);
	                Rh(c[h >> 2] | 0);
	                c[h >> 2] = 0;
	                i = d;
	                return
	            }

	            function VN(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](40) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    xN(c[e >> 2] | 0, 0);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    e = (c[f >> 2] | 0) + 0 | 0;
	                    a = e + 40 | 0;
	                    do {
	                        c[e >> 2] = 0;
	                        e = e + 4 | 0
	                    } while ((e | 0) < (a | 0));
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function WN(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = XN(c[f >> 2] | 0) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                c[c[h >> 2] >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                do if (c[(c[f >> 2] | 0) + 24 >> 2] | 0) {
	                    c[j >> 2] = c[(c[(c[f >> 2] | 0) + 24 >> 2] | 0) + 4 >> 2];
	                    if (!(c[j >> 2] | 0)) {
	                        c[(c[(c[f >> 2] | 0) + 24 >> 2] | 0) + 4 >> 2] = c[h >> 2];
	                        break
	                    }
	                    while (1) {
	                        if (!(c[(c[j >> 2] | 0) + 8 >> 2] | 0))break;
	                        c[j >> 2] = c[(c[j >> 2] | 0) + 8 >> 2]
	                    }
	                    c[(c[j >> 2] | 0) + 8 >> 2] = c[h >> 2]
	                } while (0);
	                c[k >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                c[(c[f >> 2] | 0) + 24 >> 2] = c[h >> 2];
	                tO(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                c[(c[f >> 2] | 0) + 24 >> 2] = c[h >> 2];
	                j = c[f >> 2] | 0;
	                if (c[(c[f >> 2] | 0) + 24 >> 2] | 0) {
	                    if (!(c[(c[j + 24 >> 2] | 0) + 12 >> 2] | 0))zN(c[f >> 2] | 0, c[g >> 2] | 0, 1039, 194360, 0, 0)
	                } else zN(j, c[g >> 2] | 0, 1036, 194320, 0, 0);
	                uO(c[f >> 2] | 0, c[h >> 2] | 0);
	                if (c[(c[h >> 2] | 0) + 24 >> 2] | 0)Wj(c[(c[h >> 2] | 0) + 24 >> 2] | 0, 383, c[f >> 2] | 0);
	                if (c[(c[h >> 2] | 0) + 28 >> 2] | 0)Wj(c[(c[h >> 2] | 0) + 28 >> 2] | 0, 384, c[f >> 2] | 0);
	                c[(c[f >> 2] | 0) + 24 >> 2] = c[k >> 2];
	                c[e >> 2] = c[h >> 2];
	                l = c[e >> 2] | 0;
	                i = d;
	                return l | 0
	            }

	            function XN(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](32) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    xN(c[e >> 2] | 0, 0);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    e = c[f >> 2] | 0;
	                    c[e + 0 >> 2] = 0;
	                    c[e + 4 >> 2] = 0;
	                    c[e + 8 >> 2] = 0;
	                    c[e + 12 >> 2] = 0;
	                    c[e + 16 >> 2] = 0;
	                    c[e + 20 >> 2] = 0;
	                    c[e + 24 >> 2] = 0;
	                    c[e + 28 >> 2] = 0;
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function YN(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                c[j >> 2] = 0;
	                if (!(c[g >> 2] | 0)) {
	                    zN(c[f >> 2] | 0, c[g >> 2] | 0, 1106, 191968, 0, 0);
	                    c[e >> 2] = -1;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                do if (((((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 189824) | 0) != 0 : 0) ? (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                    c[j >> 2] = DN(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                    if (!(c[j >> 2] | 0)) {
	                        c[e >> 2] = -1;
	                        l = c[e >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    } else {
	                        c[c[j >> 2] >> 2] = 0;
	                        if (!(c[(c[g >> 2] | 0) + 12 >> 2] | 0))break;
	                        zN(c[f >> 2] | 0, c[g >> 2] | 0, 1024, 191992, 0, 0);
	                        break
	                    }
	                } else m = 12; while (0);
	                do if ((m | 0) == 12) {
	                    if (((((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 189832) | 0) != 0 : 0) ? (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                        c[j >> 2] = DN(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                        if (!(c[j >> 2] | 0)) {
	                            c[e >> 2] = -1;
	                            l = c[e >> 2] | 0;
	                            i = d;
	                            return l | 0
	                        } else {
	                            c[c[j >> 2] >> 2] = 1;
	                            if (!(c[(c[g >> 2] | 0) + 12 >> 2] | 0))break;
	                            zN(c[f >> 2] | 0, c[g >> 2] | 0, 1055, 192024, 0, 0);
	                            break
	                        }
	                    }
	                    c[j >> 2] = xO(c[f >> 2] | 0, c[g >> 2] | 0, 1) | 0
	                } while (0);
	                if (c[(c[(c[f >> 2] | 0) + 24 >> 2] | 0) + 12 >> 2] | 0) {
	                    c[k >> 2] = c[(c[(c[f >> 2] | 0) + 24 >> 2] | 0) + 12 >> 2];
	                    while (1) {
	                        if (!(c[(c[k >> 2] | 0) + 32 >> 2] | 0))break;
	                        c[k >> 2] = c[(c[k >> 2] | 0) + 32 >> 2]
	                    }
	                    c[(c[k >> 2] | 0) + 32 >> 2] = c[j >> 2]
	                } else c[(c[(c[f >> 2] | 0) + 24 >> 2] | 0) + 12 >> 2] = c[j >> 2];
	                c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                if (c[g >> 2] | 0) {
	                    zN(c[f >> 2] | 0, c[g >> 2] | 0, 1105, 192064, 0, 0);
	                    c[e >> 2] = -1;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                } else {
	                    c[e >> 2] = c[h >> 2];
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                return 0
	            }

	            function ZN(a, d, e) {
	                a = a | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[h >> 2] = a;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[l >> 2] = 0;
	                a:while (1) {
	                    if (!((c[l >> 2] | 0) == 0 & (c[j >> 2] | 0) != 0)) {
	                        m = 13;
	                        break
	                    }
	                    do if ((c[c[j >> 2] >> 2] | 0) != 11 ? (c[c[j >> 2] >> 2] | 0) != 13 : 0) {
	                        e = c[h >> 2] | 0;
	                        d = c[(c[j >> 2] | 0) + 24 >> 2] | 0;
	                        a = c[k >> 2] | 0;
	                        if ((c[c[j >> 2] >> 2] | 0) == 4) {
	                            c[l >> 2] = ZN(e, d, a + 1 | 0) | 0;
	                            break
	                        } else {
	                            c[l >> 2] = ZN(e, d, a) | 0;
	                            break
	                        }
	                    } else m = 5; while (0);
	                    do if ((m | 0) == 5) {
	                        m = 0;
	                        a = c[k >> 2] | 0;
	                        if ((b[(c[j >> 2] | 0) + 48 >> 1] | 0) != -1)if ((a | 0) == (b[(c[j >> 2] | 0) + 48 >> 1] | 0)) {
	                            m = 8;
	                            break a
	                        } else break; else {
	                            b[(c[j >> 2] | 0) + 48 >> 1] = a;
	                            c[l >> 2] = ZN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 24 >> 2] | 0, c[k >> 2] | 0) | 0;
	                            b[(c[j >> 2] | 0) + 48 >> 1] = -2;
	                            break
	                        }
	                    } while (0);
	                    c[j >> 2] = c[(c[j >> 2] | 0) + 32 >> 2]
	                }
	                if ((m | 0) == 8) {
	                    zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1099, 191928, c[(c[j >> 2] | 0) + 8 >> 2] | 0, 0);
	                    c[g >> 2] = -1;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                } else if ((m | 0) == 13) {
	                    c[g >> 2] = c[l >> 2];
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                return 0
	            }

	            function _N(a, d, e) {
	                a = a | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 24 | 0;
	                h = f + 20 | 0;
	                j = f + 16 | 0;
	                k = f + 12 | 0;
	                l = f + 8 | 0;
	                m = f + 4 | 0;
	                n = f;
	                c[g >> 2] = a;
	                c[h >> 2] = d;
	                c[j >> 2] = e;
	                c[k >> 2] = 0;
	                a:while (1) {
	                    if (!(c[h >> 2] | 0)) {
	                        o = 87;
	                        break
	                    }
	                    b:do if ((c[c[h >> 2] >> 2] | 0) != 11 ? (c[c[h >> 2] >> 2] | 0) != 13 : 0) {
	                        if ((c[c[h >> 2] >> 2] | 0) == 1) {
	                            c[(c[h >> 2] | 0) + 28 >> 2] = c[j >> 2];
	                            if (c[j >> 2] | 0) {
	                                if ((c[c[j >> 2] >> 2] | 0) == 9) {
	                                    o = 15;
	                                    break a
	                                }
	                                if ((c[c[j >> 2] >> 2] | 0) == 8) {
	                                    o = 15;
	                                    break a
	                                }
	                                if ((c[c[j >> 2] >> 2] | 0) == 18) {
	                                    o = 15;
	                                    break a
	                                }
	                                if ((c[c[j >> 2] >> 2] | 0) == 19) {
	                                    o = 15;
	                                    break a
	                                }
	                                if ((c[c[j >> 2] >> 2] | 0) == 16) {
	                                    o = 15;
	                                    break a
	                                }
	                                if ((c[c[j >> 2] >> 2] | 0) == 15) {
	                                    o = 15;
	                                    break a
	                                }
	                            }
	                            if ((c[j >> 2] | 0) != 0 ? (c[c[j >> 2] >> 2] | 0) == 17 : 0) {
	                                c[k >> 2] = yO(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                                break
	                            }
	                            c[k >> 2] = c[h >> 2];
	                            break
	                        }
	                        e = (c[c[h >> 2] >> 2] | 0) == 0;
	                        c[(c[h >> 2] | 0) + 28 >> 2] = c[j >> 2];
	                        if (e) {
	                            if (c[j >> 2] | 0) {
	                                if ((c[c[j >> 2] >> 2] | 0) == 16) {
	                                    o = 24;
	                                    break a
	                                }
	                                if ((c[c[j >> 2] >> 2] | 0) == 15) {
	                                    o = 24;
	                                    break a
	                                }
	                            }
	                            do if (c[j >> 2] | 0) {
	                                if ((c[c[j >> 2] >> 2] | 0) != 18 ? (c[c[j >> 2] >> 2] | 0) != 19 : 0)break;
	                                c[k >> 2] = yO(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                                break b
	                            } while (0);
	                            c[k >> 2] = c[h >> 2];
	                            break
	                        }
	                        if (c[(c[h >> 2] | 0) + 24 >> 2] | 0)_N(c[g >> 2] | 0, c[(c[h >> 2] | 0) + 24 >> 2] | 0, c[h >> 2] | 0);
	                        if ((c[c[h >> 2] >> 2] | 0) != 7 ? (c[(c[h >> 2] | 0) + 36 >> 2] | 0) != 0 : 0)_N(c[g >> 2] | 0, c[(c[h >> 2] | 0) + 36 >> 2] | 0, c[h >> 2] | 0);
	                        if (c[(c[h >> 2] | 0) + 40 >> 2] | 0)_N(c[g >> 2] | 0, c[(c[h >> 2] | 0) + 40 >> 2] | 0, c[h >> 2] | 0);
	                        c:do if ((c[c[h >> 2] >> 2] | 0) == 4) {
	                            while (1) {
	                                if (!(c[(c[h >> 2] | 0) + 24 >> 2] | 0))break;
	                                c[l >> 2] = zO(c[g >> 2] | 0, c[(c[h >> 2] | 0) + 24 >> 2] | 0) | 0;
	                                if ((c[l >> 2] | 0) != 1)break;
	                                c[m >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                                c[(c[h >> 2] | 0) + 24 >> 2] = c[(c[m >> 2] | 0) + 32 >> 2];
	                                c[(c[m >> 2] | 0) + 32 >> 2] = c[(c[h >> 2] | 0) + 36 >> 2];
	                                c[(c[h >> 2] | 0) + 36 >> 2] = c[m >> 2]
	                            }
	                            c[n >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                            while (1) {
	                                if (!(c[n >> 2] | 0))break c;
	                                if (!(c[(c[n >> 2] | 0) + 32 >> 2] | 0))break c;
	                                c[m >> 2] = c[(c[n >> 2] | 0) + 32 >> 2];
	                                c[l >> 2] = zO(c[g >> 2] | 0, c[m >> 2] | 0) | 0;
	                                e = c[m >> 2] | 0;
	                                if ((c[l >> 2] | 0) == 1) {
	                                    c[(c[n >> 2] | 0) + 32 >> 2] = c[e + 32 >> 2];
	                                    c[(c[m >> 2] | 0) + 32 >> 2] = c[(c[h >> 2] | 0) + 36 >> 2];
	                                    c[(c[h >> 2] | 0) + 36 >> 2] = c[m >> 2];
	                                    continue
	                                } else {
	                                    c[n >> 2] = e;
	                                    continue
	                                }
	                            }
	                        } while (0);
	                        if (!((c[c[h >> 2] >> 2] | 0) != 18 ? (c[c[h >> 2] >> 2] | 0) != 19 : 0))o = 49;
	                        do if ((o | 0) == 49) {
	                            o = 0;
	                            e = c[h >> 2] | 0;
	                            if (!(c[(c[h >> 2] | 0) + 24 >> 2] | 0)) {
	                                c[e >> 2] = 0;
	                                break
	                            }
	                            if (!(c[(c[e + 24 >> 2] | 0) + 32 >> 2] | 0)) {
	                                if ((c[j >> 2] | 0) == 0 & (c[k >> 2] | 0) == 0) {
	                                    c[c[h >> 2] >> 2] = -1;
	                                    break
	                                }
	                                e = c[h >> 2] | 0;
	                                if (!(c[k >> 2] | 0)) {
	                                    c[(c[j >> 2] | 0) + 24 >> 2] = c[e + 24 >> 2];
	                                    c[(c[(c[h >> 2] | 0) + 24 >> 2] | 0) + 32 >> 2] = c[(c[h >> 2] | 0) + 32 >> 2];
	                                    c[h >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                                    break
	                                } else {
	                                    c[(c[(c[h >> 2] | 0) + 24 >> 2] | 0) + 32 >> 2] = c[e + 32 >> 2];
	                                    c[(c[k >> 2] | 0) + 32 >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                                    c[h >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                                    break
	                                }
	                            }
	                        } while (0);
	                        if (((c[c[h >> 2] >> 2] | 0) == 2 ? (c[(c[h >> 2] | 0) + 24 >> 2] | 0) != 0 : 0) ? (c[c[(c[h >> 2] | 0) + 24 >> 2] >> 2] | 0) == 1 : 0) {
	                            c[k >> 2] = yO(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                            break
	                        }
	                        if ((c[c[h >> 2] >> 2] | 0) == 1) {
	                            if (c[j >> 2] | 0) {
	                                if ((c[c[j >> 2] >> 2] | 0) == 9) {
	                                    o = 69;
	                                    break a
	                                }
	                                if ((c[c[j >> 2] >> 2] | 0) == 8) {
	                                    o = 69;
	                                    break a
	                                }
	                                if ((c[c[j >> 2] >> 2] | 0) == 18) {
	                                    o = 69;
	                                    break a
	                                }
	                                if ((c[c[j >> 2] >> 2] | 0) == 19) {
	                                    o = 69;
	                                    break a
	                                }
	                                if ((c[c[j >> 2] >> 2] | 0) == 16) {
	                                    o = 69;
	                                    break a
	                                }
	                                if ((c[c[j >> 2] >> 2] | 0) == 15) {
	                                    o = 69;
	                                    break a
	                                }
	                            }
	                            if ((c[j >> 2] | 0) != 0 ? (c[c[j >> 2] >> 2] | 0) == 17 : 0) {
	                                c[k >> 2] = yO(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                                break
	                            }
	                            c[k >> 2] = c[h >> 2];
	                            break
	                        } else {
	                            if (c[c[h >> 2] >> 2] | 0) {
	                                c[k >> 2] = c[h >> 2];
	                                break
	                            }
	                            if (c[j >> 2] | 0) {
	                                if ((c[c[j >> 2] >> 2] | 0) == 16) {
	                                    o = 78;
	                                    break a
	                                }
	                                if ((c[c[j >> 2] >> 2] | 0) == 15) {
	                                    o = 78;
	                                    break a
	                                }
	                            }
	                            d:do if (c[j >> 2] | 0) {
	                                do if ((c[c[j >> 2] >> 2] | 0) != 18) {
	                                    if ((c[c[j >> 2] >> 2] | 0) == 19)break;
	                                    if ((c[c[j >> 2] >> 2] | 0) != 17)break d
	                                } while (0);
	                                c[k >> 2] = yO(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                                break b
	                            } while (0);
	                            c[k >> 2] = c[h >> 2];
	                            break
	                        }
	                    } else o = 5; while (0);
	                    if ((o | 0) == 5 ? (o = 0, (b[(c[h >> 2] | 0) + 48 >> 1] | 0) != -3) : 0) {
	                        b[(c[h >> 2] | 0) + 48 >> 1] = -3;
	                        _N(c[g >> 2] | 0, c[(c[h >> 2] | 0) + 24 >> 2] | 0, c[h >> 2] | 0)
	                    }
	                    c[h >> 2] = c[(c[h >> 2] | 0) + 32 >> 2]
	                }
	                if ((o | 0) == 15) {
	                    c[c[j >> 2] >> 2] = 1;
	                    i = f;
	                    return
	                } else if ((o | 0) == 24) {
	                    c[c[j >> 2] >> 2] = 0;
	                    i = f;
	                    return
	                } else if ((o | 0) == 69) {
	                    c[c[j >> 2] >> 2] = 1;
	                    i = f;
	                    return
	                } else if ((o | 0) == 78) {
	                    c[c[j >> 2] >> 2] = 0;
	                    i = f;
	                    return
	                } else if ((o | 0) == 87) {
	                    i = f;
	                    return
	                }
	            }

	            function $N(a, d, e, f) {
	                a = a | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 28 | 0;
	                j = g + 24 | 0;
	                k = g + 20 | 0;
	                l = g + 16 | 0;
	                m = g + 12 | 0;
	                n = g + 8 | 0;
	                o = g + 4 | 0;
	                p = g;
	                c[h >> 2] = a;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[l >> 2] = f;
	                c[p >> 2] = 0;
	                while (1) {
	                    if (!(c[j >> 2] | 0))break;
	                    c[n >> 2] = 0;
	                    do if ((c[c[j >> 2] >> 2] | 0) != 11 ? (c[c[j >> 2] >> 2] | 0) != 13 : 0) {
	                        if ((c[c[j >> 2] >> 2] | 0) == 4) {
	                            AO(c[h >> 2] | 0, c[j >> 2] | 0);
	                            if (c[k >> 2] & 8)zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1070, 190416, 0, 0);
	                            if (c[k >> 2] & 4)zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1079, 190472, 0, 0);
	                            if (c[k >> 2] & 1)zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1068, 190520, 0, 0);
	                            if (c[k >> 2] & 1)zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1068, 190520, 0, 0);
	                            c[m >> 2] = 0;
	                            c[n >> 2] = $N(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 36 >> 2] | 0, c[m >> 2] | 0, c[c[j >> 2] >> 2] | 0) | 0;
	                            if (c[n >> 2] | 0)zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1015, 190576, c[(c[j >> 2] | 0) + 8 >> 2] | 0, 0);
	                            c[n >> 2] = $N(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 24 >> 2] | 0, c[m >> 2] | 0, c[c[j >> 2] >> 2] | 0) | 0;
	                            if ((c[n >> 2] | 0) == -1) {
	                                zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1016, 190632, c[(c[j >> 2] | 0) + 8 >> 2] | 0, 0);
	                                break
	                            } else {
	                                c[n >> 2] = 2;
	                                break
	                            }
	                        }
	                        if ((c[c[j >> 2] >> 2] | 0) == 9) {
	                            if (c[k >> 2] & 1)zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1067, 190672, 0, 0);
	                            if (c[k >> 2] & 4)zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1078, 190720, 0, 0);
	                            if (c[k >> 2] & 32)zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1086, 190768, 0, 0);
	                            if (c[k >> 2] & 64)zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1087, 190824, 0, 0);
	                            if (c[k >> 2] & 8)zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1069, 190888, 0, 0);
	                            if (c[k >> 2] & 16)zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1088, 190936, 0, 0);
	                            do if ((c[k >> 2] & 2 | 0) == 0 ? (c[(c[j >> 2] | 0) + 8 >> 2] | 0) == 0 : 0) {
	                                f = c[h >> 2] | 0;
	                                e = c[(c[j >> 2] | 0) + 4 >> 2] | 0;
	                                if (!(c[(c[j >> 2] | 0) + 12 >> 2] | 0)) {
	                                    zN(f, e, 1e3, 190984, 0, 0);
	                                    break
	                                } else {
	                                    zN(f, e, 1056, 191040, 0, 0);
	                                    break
	                                }
	                            } while (0);
	                            c[m >> 2] = c[k >> 2] | 1;
	                            $N(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 24 >> 2] | 0, c[m >> 2] | 0, c[c[j >> 2] >> 2] | 0) | 0;
	                            c[n >> 2] = 0;
	                            break
	                        }
	                        if ((c[c[j >> 2] >> 2] | 0) != 16 ? (c[c[j >> 2] >> 2] | 0) != 15 : 0) {
	                            if ((c[c[j >> 2] >> 2] | 0) == 8) {
	                                if (c[k >> 2] & 4)zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1081, 191192, 0, 0);
	                                if (c[k >> 2] & 8)zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1074, 191232, 0, 0);
	                                if (c[k >> 2] & 16)zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1093, 191280, 0, 0);
	                                c[m >> 2] = c[k >> 2] | 4;
	                                c[n >> 2] = $N(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 24 >> 2] | 0, c[m >> 2] | 0, c[c[j >> 2] >> 2] | 0) | 0;
	                                break
	                            }
	                            if ((c[c[j >> 2] >> 2] | 0) == 18) {
	                                if (c[k >> 2] & 8)zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1072, 191320, 0, 0);
	                                if (c[k >> 2] & 16)zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1091, 191368, 0, 0);
	                                e = c[k >> 2] | 0;
	                                if (c[k >> 2] & 2)c[m >> 2] = e | 32; else c[m >> 2] = e;
	                                c[n >> 2] = $N(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 24 >> 2] | 0, c[m >> 2] | 0, c[c[j >> 2] >> 2] | 0) | 0;
	                                AO(c[h >> 2] | 0, c[j >> 2] | 0);
	                                break
	                            }
	                            if ((c[c[j >> 2] >> 2] | 0) == 19) {
	                                if (c[k >> 2] & 4)zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1080, 191408, 0, 0);
	                                if (c[k >> 2] & 8)zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1073, 191456, 0, 0);
	                                if (c[k >> 2] & 16)zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1073, 191512, 0, 0);
	                                e = c[k >> 2] | 0;
	                                if (c[k >> 2] & 2)c[m >> 2] = e | 64; else c[m >> 2] = e;
	                                c[n >> 2] = $N(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 24 >> 2] | 0, c[m >> 2] | 0, c[c[j >> 2] >> 2] | 0) | 0;
	                                break
	                            }
	                            e = c[j >> 2] | 0;
	                            if ((c[c[j >> 2] >> 2] | 0) == 2) {
	                                if ((c[e + 28 >> 2] | 0) != 0 ? (c[c[(c[j >> 2] | 0) + 28 >> 2] >> 2] | 0) == 5 : 0)c[m >> 2] = c[k >> 2] | 8; else c[m >> 2] = c[k >> 2];
	                                c[n >> 2] = $N(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 24 >> 2] | 0, c[m >> 2] | 0, c[c[j >> 2] >> 2] | 0) | 0;
	                                break
	                            }
	                            if ((c[e >> 2] | 0) == 5) {
	                                if (c[k >> 2] & 16)zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1089, 191560, 0, 0);
	                                $N(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 24 >> 2] | 0, c[k >> 2] | 0, c[c[j >> 2] >> 2] | 0) | 0;
	                                c[n >> 2] = 1;
	                                break
	                            }
	                            if ((c[c[j >> 2] >> 2] | 0) == 7) {
	                                if (c[k >> 2] & 16)zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1096, 191600, 0, 0);
	                                $N(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 24 >> 2] | 0, c[k >> 2] | 0, c[c[j >> 2] >> 2] | 0) | 0;
	                                c[n >> 2] = 1;
	                                break
	                            }
	                            if ((c[c[j >> 2] >> 2] | 0) == 3) {
	                                if (c[k >> 2] & 4)zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1083, 191640, 0, 0);
	                                if (c[k >> 2] & 8)zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1077, 191680, 0, 0);
	                                if (c[k >> 2] & 16)zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1095, 191728, 0, 0);
	                                c[n >> 2] = 2;
	                                break
	                            }
	                            if (c[c[j >> 2] >> 2] | 0) {
	                                e = c[h >> 2] | 0;
	                                f = c[j >> 2] | 0;
	                                if ((c[c[j >> 2] >> 2] | 0) == 17) {
	                                    CO(e, f);
	                                    c[n >> 2] = $N(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 24 >> 2] | 0, c[k >> 2] | 0, c[c[j >> 2] >> 2] | 0) | 0;
	                                    break
	                                } else {
	                                    c[n >> 2] = $N(e, c[f + 24 >> 2] | 0, c[k >> 2] | 0, c[c[j >> 2] >> 2] | 0) | 0;
	                                    break
	                                }
	                            }
	                            if (c[k >> 2] & 8)zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1071, 191768, 0, 0);
	                            if (c[k >> 2] & 16)zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1090, 191816, 0, 0);
	                            c[n >> 2] = 0;
	                            break
	                        }
	                        if (c[k >> 2] & 8)zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1075, 191096, 0, 0);
	                        if (c[k >> 2] & 16)zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1094, 191144, 0, 0);
	                        c[m >> 2] = c[k >> 2] | 2;
	                        c[n >> 2] = $N(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 24 >> 2] | 0, c[m >> 2] | 0, c[c[j >> 2] >> 2] | 0) | 0;
	                        c[n >> 2] = BO(c[n >> 2] | 0, c[n >> 2] | 0) | 0
	                    } else q = 5; while (0);
	                    do if ((q | 0) == 5) {
	                        q = 0;
	                        if (c[k >> 2] & 8)zN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0, 1076, 190272, 0, 0);
	                        do if (!(c[(c[j >> 2] | 0) + 24 >> 2] | 0)) {
	                            f = c[h >> 2] | 0;
	                            e = c[(c[j >> 2] | 0) + 4 >> 2] | 0;
	                            if ((c[c[j >> 2] >> 2] | 0) == 13) {
	                                zN(f, e, 1101, 190320, 0, 0);
	                                break
	                            }
	                            if (c[(c[j >> 2] | 0) + 8 >> 2] | 0)r = c[(c[j >> 2] | 0) + 8 >> 2] | 0; else r = 190408;
	                            zN(f, e, 1101, 190368, r, 0)
	                        } while (0);
	                        e = (c[j >> 2] | 0) + 48 | 0;
	                        if ((b[(c[j >> 2] | 0) + 48 >> 1] | 0) > -4) {
	                            b[e >> 1] = -4;
	                            c[n >> 2] = $N(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 24 >> 2] | 0, c[k >> 2] | 0, c[c[j >> 2] >> 2] | 0) | 0;
	                            b[(c[j >> 2] | 0) + 48 >> 1] = (c[n >> 2] | 0) - 15;
	                            break
	                        }
	                        if ((b[e >> 1] | 0) == -4) {
	                            c[n >> 2] = 2;
	                            break
	                        } else {
	                            c[n >> 2] = (b[(c[j >> 2] | 0) + 48 >> 1] | 0) + 15;
	                            break
	                        }
	                    } while (0);
	                    c[j >> 2] = c[(c[j >> 2] | 0) + 32 >> 2];
	                    if ((c[l >> 2] | 0) == 18) {
	                        c[p >> 2] = BO(c[p >> 2] | 0, c[n >> 2] | 0) | 0;
	                        continue
	                    }
	                    if ((c[l >> 2] | 0) == 19) {
	                        c[o >> 2] = BO(c[p >> 2] | 0, c[n >> 2] | 0) | 0;
	                        if ((c[o >> 2] | 0) == -1)continue;
	                        c[o >> 2] = DO(c[p >> 2] | 0, c[n >> 2] | 0) | 0;
	                        continue
	                    }
	                    if ((c[l >> 2] | 0) == 17) {
	                        c[p >> 2] = DO(c[p >> 2] | 0, c[n >> 2] | 0) | 0;
	                        continue
	                    }
	                    if ((c[l >> 2] | 0) == 8) {
	                        c[p >> 2] = 1;
	                        continue
	                    }
	                    if ((c[l >> 2] | 0) != 2) {
	                        c[p >> 2] = BO(c[p >> 2] | 0, c[n >> 2] | 0) | 0;
	                        continue
	                    }
	                    if ((c[n >> 2] | 0) == -1) {
	                        c[p >> 2] = -1;
	                        continue
	                    } else {
	                        c[p >> 2] = 1;
	                        continue
	                    }
	                }
	                i = g;
	                return c[p >> 2] | 0
	            }

	            function aO(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 40 | 0;
	                g = e + 36 | 0;
	                h = e + 32 | 0;
	                j = e + 28 | 0;
	                k = e + 24 | 0;
	                l = e + 20 | 0;
	                m = e + 16 | 0;
	                n = e + 12 | 0;
	                o = e + 8 | 0;
	                p = e + 4 | 0;
	                q = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 0;
	                c[o >> 2] = 0;
	                c[p >> 2] = 0;
	                if (c[(c[g >> 2] | 0) + 36 >> 2] | 0) {
	                    c[f >> 2] = 0;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                }
	                c[l >> 2] = 0;
	                c[m >> 2] = c[h >> 2];
	                a:while (1) {
	                    if (!(c[m >> 2] | 0)) {
	                        s = 41;
	                        break
	                    }
	                    if (!(c[j >> 2] | 0))if ((c[c[m >> 2] >> 2] | 0) != 4 ? (c[c[m >> 2] >> 2] | 0) != 3 : 0)s = 8; else s = 10; else s = 8;
	                    do if ((s | 0) == 8) {
	                        s = 0;
	                        if ((c[j >> 2] | 0) == 1 ? (c[c[m >> 2] >> 2] | 0) == 9 : 0) {
	                            s = 10;
	                            break
	                        }
	                        if ((((((((((c[c[m >> 2] >> 2] | 0) != 17 ? (c[c[m >> 2] >> 2] | 0) != 19 : 0) ? (c[c[m >> 2] >> 2] | 0) != 18 : 0) ? (c[c[m >> 2] >> 2] | 0) != 16 : 0) ? (c[c[m >> 2] >> 2] | 0) != 15 : 0) ? (c[c[m >> 2] >> 2] | 0) != 14 : 0) ? (c[c[m >> 2] >> 2] | 0) != 13 : 0) ? (c[c[m >> 2] >> 2] | 0) != 11 : 0) ? (c[c[m >> 2] >> 2] | 0) != 10 : 0) ? (c[c[m >> 2] >> 2] | 0) != 12 : 0)break;
	                        if (c[(c[m >> 2] | 0) + 24 >> 2] | 0) {
	                            c[l >> 2] = c[m >> 2];
	                            c[m >> 2] = c[(c[m >> 2] | 0) + 24 >> 2];
	                            c[n >> 2] = c[m >> 2];
	                            while (1) {
	                                if (!(c[n >> 2] | 0))continue a;
	                                c[(c[n >> 2] | 0) + 28 >> 2] = c[l >> 2];
	                                c[n >> 2] = c[(c[n >> 2] | 0) + 32 >> 2]
	                            }
	                        }
	                    } while (0);
	                    if ((s | 0) == 10) {
	                        s = 0;
	                        if (!(c[k >> 2] | 0)) {
	                            c[p >> 2] = 10;
	                            c[k >> 2] = Cb[c[135744 >> 2] & 511]((c[p >> 2] | 0) + 1 << 2) | 0;
	                            if (!(c[k >> 2] | 0)) {
	                                s = 12;
	                                break
	                            }
	                        } else if ((c[p >> 2] | 0) <= (c[o >> 2] | 0)) {
	                            c[p >> 2] = c[p >> 2] << 1;
	                            c[q >> 2] = Hb[c[135760 >> 2] & 511](c[k >> 2] | 0, (c[p >> 2] | 0) + 1 << 2) | 0;
	                            if (!(c[q >> 2] | 0)) {
	                                s = 15;
	                                break
	                            }
	                            c[k >> 2] = c[q >> 2]
	                        }
	                        d = c[m >> 2] | 0;
	                        b = c[o >> 2] | 0;
	                        c[o >> 2] = b + 1;
	                        c[(c[k >> 2] | 0) + (b << 2) >> 2] = d;
	                        c[(c[k >> 2] | 0) + (c[o >> 2] << 2) >> 2] = 0
	                    }
	                    if ((c[m >> 2] | 0) == (c[h >> 2] | 0)) {
	                        s = 41;
	                        break
	                    }
	                    if (c[(c[m >> 2] | 0) + 32 >> 2] | 0) {
	                        c[m >> 2] = c[(c[m >> 2] | 0) + 32 >> 2];
	                        continue
	                    }
	                    while (1) {
	                        c[m >> 2] = c[(c[m >> 2] | 0) + 28 >> 2];
	                        if (!(c[m >> 2] | 0))continue a;
	                        if ((c[m >> 2] | 0) == (c[h >> 2] | 0)) {
	                            s = 37;
	                            break a
	                        }
	                        t = c[m >> 2] | 0;
	                        if (c[(c[m >> 2] | 0) + 32 >> 2] | 0)break;
	                        if (!t)continue a
	                    }
	                    c[m >> 2] = c[t + 32 >> 2]
	                }
	                if ((s | 0) == 12) {
	                    xN(c[g >> 2] | 0, 190240);
	                    c[f >> 2] = 0;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                } else if ((s | 0) == 15) {
	                    xN(c[g >> 2] | 0, 190240);
	                    zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    c[f >> 2] = 0;
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                } else if ((s | 0) == 37) {
	                    c[f >> 2] = c[k >> 2];
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                } else if ((s | 0) == 41) {
	                    c[f >> 2] = c[k >> 2];
	                    r = c[f >> 2] | 0;
	                    i = e;
	                    return r | 0
	                }
	                return 0
	            }

	            function bO(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[e + 12 >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = c[h >> 2];
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) {
	                    c[f >> 2] = 1;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                if ((c[c[g >> 2] >> 2] | 0) != 0 ? (c[c[h >> 2] >> 2] | 0) != 0 : 0) {
	                    a:while (1) {
	                        if (!(c[c[g >> 2] >> 2] | 0)) {
	                            l = 12;
	                            break
	                        }
	                        while (1) {
	                            if (!(c[c[h >> 2] >> 2] | 0))break;
	                            if (!(EO(c[c[g >> 2] >> 2] | 0, c[c[h >> 2] >> 2] | 0) | 0)) {
	                                l = 9;
	                                break a
	                            }
	                            c[h >> 2] = (c[h >> 2] | 0) + 4
	                        }
	                        c[h >> 2] = c[j >> 2];
	                        c[g >> 2] = (c[g >> 2] | 0) + 4
	                    }
	                    if ((l | 0) == 9) {
	                        c[f >> 2] = 0;
	                        k = c[f >> 2] | 0;
	                        i = e;
	                        return k | 0
	                    } else if ((l | 0) == 12) {
	                        c[f >> 2] = 1;
	                        k = c[f >> 2] | 0;
	                        i = e;
	                        return k | 0
	                    }
	                }
	                c[f >> 2] = 1;
	                k = c[f >> 2] | 0;
	                i = e;
	                return k | 0
	            }

	            function cO(a) {
	                a = a | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = -1;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                if ((c[c[f >> 2] >> 2] | 0) != 4 ? (b[(c[f >> 2] | 0) + 50 >> 1] & 64 | 0) != 0 : 0) {
	                    c[e >> 2] = 1;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                if ((c[c[f >> 2] >> 2] | 0) != 4 ? (b[(c[f >> 2] | 0) + 50 >> 1] & 128 | 0) != 0 : 0) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                a:do switch (c[c[f >> 2] >> 2] | 0) {
	                    case 1:
	                    case 7:
	                    case 6:
	                    case 8:
	                    case 5:
	                    case 19:
	                    case 9:
	                    case 2:
	                    {
	                        c[g >> 2] = 0;
	                        break
	                    }
	                    case 13:
	                    case 12:
	                    case 11:
	                    {
	                        if ((b[(c[f >> 2] | 0) + 48 >> 1] | 0) == -20) {
	                            c[e >> 2] = 1;
	                            l = c[e >> 2] | 0;
	                            i = d;
	                            return l | 0
	                        }
	                        b[(c[f >> 2] | 0) + 48 >> 1] = -20;
	                        c[j >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                        while (1) {
	                            if (!(c[j >> 2] | 0))break a;
	                            c[g >> 2] = cO(c[j >> 2] | 0) | 0;
	                            if ((c[g >> 2] | 0) != 1)break a;
	                            c[j >> 2] = c[(c[j >> 2] | 0) + 32 >> 2]
	                        }
	                        break
	                    }
	                    case 4:
	                    {
	                        if ((b[(c[f >> 2] | 0) + 50 >> 1] & 128 | 0) == 0 ? (b[(c[f >> 2] | 0) + 50 >> 1] & 64 | 0) == 0 : 0) {
	                            c[h >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                            while (1) {
	                                if (!(c[h >> 2] | 0))break;
	                                c[g >> 2] = cO(c[h >> 2] | 0) | 0;
	                                if ((c[g >> 2] | 0) != 1)break;
	                                c[h >> 2] = c[(c[h >> 2] | 0) + 32 >> 2]
	                            }
	                            if (!(c[g >> 2] | 0)) {
	                                a = (c[f >> 2] | 0) + 50 | 0;
	                                b[a >> 1] = b[a >> 1] & -65;
	                                a = (c[f >> 2] | 0) + 50 | 0;
	                                b[a >> 1] = b[a >> 1] | 128
	                            }
	                            if ((c[g >> 2] | 0) == 1 ? (a = (c[f >> 2] | 0) + 50 | 0, m = b[a >> 1] & 128, b[a >> 1] = m, m << 16 >> 16 == 0) : 0) {
	                                m = (c[f >> 2] | 0) + 50 | 0;
	                                b[m >> 1] = b[m >> 1] | 64
	                            }
	                        }
	                        if ((c[(c[f >> 2] | 0) + 40 >> 2] | 0) == 0 ? (c[(c[f >> 2] | 0) + 8 >> 2] | 0) != 0 : 0)c[g >> 2] = 1; else c[g >> 2] = 0;
	                        c[e >> 2] = c[g >> 2];
	                        l = c[e >> 2] | 0;
	                        i = d;
	                        return l | 0
	                    }
	                    case 10:
	                    case 18:
	                    case 17:
	                    case 16:
	                    case 15:
	                    case 14:
	                    case 20:
	                    {
	                        c[k >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                        while (1) {
	                            if (!(c[k >> 2] | 0))break a;
	                            c[g >> 2] = cO(c[k >> 2] | 0) | 0;
	                            if ((c[g >> 2] | 0) != 1)break a;
	                            c[k >> 2] = c[(c[k >> 2] | 0) + 32 >> 2]
	                        }
	                        break
	                    }
	                    case -1:
	                    {
	                        c[g >> 2] = cO(c[(c[f >> 2] | 0) + 24 >> 2] | 0) | 0;
	                        break
	                    }
	                    case 0:
	                    case 3:
	                    {
	                        c[g >> 2] = 1;
	                        break
	                    }
	                    default:
	                    {
	                    }
	                } while (0);
	                if (!(c[g >> 2] | 0)) {
	                    k = (c[f >> 2] | 0) + 50 | 0;
	                    b[k >> 1] = b[k >> 1] | 128
	                }
	                if ((c[g >> 2] | 0) == 1) {
	                    k = (c[f >> 2] | 0) + 50 | 0;
	                    b[k >> 1] = b[k >> 1] | 64
	                }
	                c[e >> 2] = c[g >> 2];
	                l = c[e >> 2] | 0;
	                i = d;
	                return l | 0
	            }

	            function dO(a, d) {
	                a = a | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0;
	                e = i;
	                i = i + 80 | 0;
	                f = e;
	                g = e + 64 | 0;
	                h = e + 60 | 0;
	                j = e + 56 | 0;
	                k = e + 52 | 0;
	                l = e + 48 | 0;
	                m = e + 44 | 0;
	                n = e + 40 | 0;
	                p = e + 36 | 0;
	                q = e + 32 | 0;
	                r = e + 28 | 0;
	                s = e + 24 | 0;
	                t = e + 20 | 0;
	                u = e + 16 | 0;
	                v = e + 12 | 0;
	                w = e + 8 | 0;
	                x = e + 4 | 0;
	                c[h >> 2] = a;
	                c[j >> 2] = d;
	                c[k >> 2] = 0;
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    c[g >> 2] = -1;
	                    y = c[g >> 2] | 0;
	                    i = e;
	                    return y | 0
	                }
	                a:do switch (c[c[j >> 2] >> 2] | 0) {
	                    case -1:
	                    {
	                        c[k >> 2] = dO(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 24 >> 2] | 0) | 0;
	                        break
	                    }
	                    case 14:
	                    {
	                        c[s >> 2] = c[(c[h >> 2] | 0) + 136 >> 2];
	                        c[l >> 2] = c[(c[j >> 2] | 0) + 24 >> 2];
	                        while (1) {
	                            z = c[h >> 2] | 0;
	                            if (!(c[l >> 2] | 0))break;
	                            dO(z, c[l >> 2] | 0) | 0;
	                            c[l >> 2] = c[(c[l >> 2] | 0) + 32 >> 2]
	                        }
	                        Jz(c[z + 132 >> 2] | 0, c[s >> 2] | 0, c[(c[h >> 2] | 0) + 136 >> 2] | 0) | 0;
	                        break
	                    }
	                    case 17:
	                    {
	                        c[v >> 2] = 0;
	                        c[w >> 2] = c[(c[h >> 2] | 0) + 136 >> 2];
	                        c[l >> 2] = c[(c[j >> 2] | 0) + 24 >> 2];
	                        while (1) {
	                            if (!(c[l >> 2] | 0))break;
	                            c[(c[h >> 2] | 0) + 136 >> 2] = c[w >> 2];
	                            c[k >> 2] = dO(c[h >> 2] | 0, c[l >> 2] | 0) | 0;
	                            if (c[k >> 2] | 0)break;
	                            d = c[h >> 2] | 0;
	                            if (!(c[v >> 2] | 0))c[v >> 2] = c[d + 136 >> 2]; else Jz(c[d + 132 >> 2] | 0, c[(c[h >> 2] | 0) + 136 >> 2] | 0, c[v >> 2] | 0) | 0;
	                            c[l >> 2] = c[(c[l >> 2] | 0) + 32 >> 2]
	                        }
	                        c[(c[h >> 2] | 0) + 136 >> 2] = c[v >> 2];
	                        break
	                    }
	                    case 20:
	                    {
	                        if ((cO(c[j >> 2] | 0) | 0) == 1 ? (b[(c[j >> 2] | 0) + 48 >> 1] | 0) != -25 : 0) {
	                            c[m >> 2] = c[(c[h >> 2] | 0) + 132 >> 2];
	                            c[n >> 2] = c[(c[h >> 2] | 0) + 136 >> 2];
	                            b[(c[j >> 2] | 0) + 48 >> 1] = -25;
	                            c[l >> 2] = c[(c[j >> 2] | 0) + 24 >> 2];
	                            d = xz() | 0;
	                            c[(c[h >> 2] | 0) + 132 >> 2] = d;
	                            if (!(c[(c[h >> 2] | 0) + 132 >> 2] | 0)) {
	                                c[g >> 2] = -1;
	                                y = c[g >> 2] | 0;
	                                i = e;
	                                return y | 0
	                            }
	                            Az(c[(c[h >> 2] | 0) + 132 >> 2] | 0, 1);
	                            d = Bz(c[(c[h >> 2] | 0) + 132 >> 2] | 0) | 0;
	                            c[(c[h >> 2] | 0) + 136 >> 2] = d;
	                            while (1) {
	                                A = c[h >> 2] | 0;
	                                if (!(c[l >> 2] | 0))break;
	                                dO(A, c[l >> 2] | 0) | 0;
	                                c[l >> 2] = c[(c[l >> 2] | 0) + 32 >> 2]
	                            }
	                            Cz(c[A + 132 >> 2] | 0, c[(c[h >> 2] | 0) + 136 >> 2] | 0) | 0;
	                            if (Pz(c[(c[h >> 2] | 0) + 132 >> 2] | 0) | 0) {
	                                d = Oz(c[(c[h >> 2] | 0) + 132 >> 2] | 0) | 0;
	                                c[(c[j >> 2] | 0) + 52 >> 2] = d
	                            }
	                            yz(c[(c[h >> 2] | 0) + 132 >> 2] | 0);
	                            c[(c[h >> 2] | 0) + 136 >> 2] = c[n >> 2];
	                            c[(c[h >> 2] | 0) + 132 >> 2] = c[m >> 2]
	                        }
	                        break
	                    }
	                    case 3:
	                    {
	                        d = Jz(c[(c[h >> 2] | 0) + 132 >> 2] | 0, c[(c[h >> 2] | 0) + 136 >> 2] | 0, 0) | 0;
	                        c[(c[h >> 2] | 0) + 136 >> 2] = d;
	                        c[x >> 2] = c[(c[h >> 2] | 0) + 136 >> 2];
	                        dO(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 24 >> 2] | 0) | 0;
	                        Dz(c[(c[h >> 2] | 0) + 132 >> 2] | 0, c[(c[h >> 2] | 0) + 136 >> 2] | 0, c[(c[h >> 2] | 0) + 136 >> 2] | 0, 188096, 0) | 0;
	                        d = Jz(c[(c[h >> 2] | 0) + 132 >> 2] | 0, c[x >> 2] | 0, 0) | 0;
	                        c[(c[h >> 2] | 0) + 136 >> 2] = d;
	                        break
	                    }
	                    case 10:
	                    case 18:
	                    case 13:
	                    case 12:
	                    case 11:
	                    {
	                        c[l >> 2] = c[(c[j >> 2] | 0) + 24 >> 2];
	                        while (1) {
	                            if (!(c[l >> 2] | 0))break a;
	                            c[k >> 2] = dO(c[h >> 2] | 0, c[l >> 2] | 0) | 0;
	                            if (c[k >> 2] | 0)break a;
	                            c[l >> 2] = c[(c[l >> 2] | 0) + 32 >> 2]
	                        }
	                        break
	                    }
	                    case 0:
	                    {
	                        d = Jz(c[(c[h >> 2] | 0) + 132 >> 2] | 0, c[(c[h >> 2] | 0) + 136 >> 2] | 0, 0) | 0;
	                        c[(c[h >> 2] | 0) + 136 >> 2] = d;
	                        break
	                    }
	                    case 4:
	                    {
	                        if ((c[(c[h >> 2] | 0) + 132 >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                            d = Ez(c[(c[h >> 2] | 0) + 132 >> 2] | 0, c[(c[h >> 2] | 0) + 136 >> 2] | 0, 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[j >> 2] | 0) | 0;
	                            c[(c[h >> 2] | 0) + 136 >> 2] = d
	                        }
	                        if ((b[(c[j >> 2] | 0) + 50 >> 1] & 64 | 0) != 0 ? (b[(c[j >> 2] | 0) + 48 >> 1] | 0) != -25 : 0) {
	                            c[p >> 2] = c[(c[h >> 2] | 0) + 132 >> 2];
	                            c[q >> 2] = c[(c[h >> 2] | 0) + 136 >> 2];
	                            b[(c[j >> 2] | 0) + 48 >> 1] = -25;
	                            c[l >> 2] = c[(c[j >> 2] | 0) + 24 >> 2];
	                            d = xz() | 0;
	                            c[(c[h >> 2] | 0) + 132 >> 2] = d;
	                            if (!(c[(c[h >> 2] | 0) + 132 >> 2] | 0)) {
	                                c[g >> 2] = -1;
	                                y = c[g >> 2] | 0;
	                                i = e;
	                                return y | 0
	                            }
	                            Az(c[(c[h >> 2] | 0) + 132 >> 2] | 0, 1);
	                            d = Bz(c[(c[h >> 2] | 0) + 132 >> 2] | 0) | 0;
	                            c[(c[h >> 2] | 0) + 136 >> 2] = d;
	                            while (1) {
	                                B = c[h >> 2] | 0;
	                                if (!(c[l >> 2] | 0))break;
	                                dO(B, c[l >> 2] | 0) | 0;
	                                c[l >> 2] = c[(c[l >> 2] | 0) + 32 >> 2]
	                            }
	                            Cz(c[B + 132 >> 2] | 0, c[(c[h >> 2] | 0) + 136 >> 2] | 0) | 0;
	                            d = Oz(c[(c[h >> 2] | 0) + 132 >> 2] | 0) | 0;
	                            c[(c[j >> 2] | 0) + 52 >> 2] = d;
	                            if (!(wz(c[(c[j >> 2] | 0) + 52 >> 2] | 0) | 0)) {
	                                zz(c[(c[j >> 2] | 0) + 52 >> 2] | 0);
	                                c[(c[j >> 2] | 0) + 52 >> 2] = 0
	                            }
	                            yz(c[(c[h >> 2] | 0) + 132 >> 2] | 0);
	                            c[(c[h >> 2] | 0) + 136 >> 2] = c[q >> 2];
	                            c[(c[h >> 2] | 0) + 132 >> 2] = c[p >> 2];
	                            break a
	                        }
	                        c[r >> 2] = c[(c[h >> 2] | 0) + 132 >> 2];
	                        c[k >> 2] = EN(c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                        c[(c[h >> 2] | 0) + 132 >> 2] = c[r >> 2];
	                        break
	                    }
	                    case 7:
	                    case 6:
	                    case 8:
	                    case 5:
	                    case 1:
	                    case 19:
	                    case 9:
	                    case 2:
	                    {
	                        d = c[o >> 2] | 0;
	                        c[f >> 2] = FO(c[j >> 2] | 0) | 0;
	                        Ka(d | 0, 189768, f | 0) | 0;
	                        break
	                    }
	                    case 15:
	                    {
	                        d = Jz(c[(c[h >> 2] | 0) + 132 >> 2] | 0, c[(c[h >> 2] | 0) + 136 >> 2] | 0, 0) | 0;
	                        c[(c[h >> 2] | 0) + 136 >> 2] = d;
	                        c[t >> 2] = c[(c[h >> 2] | 0) + 136 >> 2];
	                        c[l >> 2] = c[(c[j >> 2] | 0) + 24 >> 2];
	                        while (1) {
	                            C = c[h >> 2] | 0;
	                            if (!(c[l >> 2] | 0))break;
	                            dO(C, c[l >> 2] | 0) | 0;
	                            c[l >> 2] = c[(c[l >> 2] | 0) + 32 >> 2]
	                        }
	                        Jz(c[C + 132 >> 2] | 0, c[(c[h >> 2] | 0) + 136 >> 2] | 0, c[t >> 2] | 0) | 0;
	                        d = Jz(c[(c[h >> 2] | 0) + 132 >> 2] | 0, c[t >> 2] | 0, 0) | 0;
	                        c[(c[h >> 2] | 0) + 136 >> 2] = d;
	                        break
	                    }
	                    case 16:
	                    {
	                        c[l >> 2] = c[(c[j >> 2] | 0) + 24 >> 2];
	                        while (1) {
	                            D = c[h >> 2] | 0;
	                            if (!(c[l >> 2] | 0))break;
	                            dO(D, c[l >> 2] | 0) | 0;
	                            c[l >> 2] = c[(c[l >> 2] | 0) + 32 >> 2]
	                        }
	                        c[u >> 2] = c[D + 136 >> 2];
	                        c[l >> 2] = c[(c[j >> 2] | 0) + 24 >> 2];
	                        while (1) {
	                            E = c[h >> 2] | 0;
	                            if (!(c[l >> 2] | 0))break;
	                            dO(E, c[l >> 2] | 0) | 0;
	                            c[l >> 2] = c[(c[l >> 2] | 0) + 32 >> 2]
	                        }
	                        Jz(c[E + 132 >> 2] | 0, c[(c[h >> 2] | 0) + 136 >> 2] | 0, c[u >> 2] | 0) | 0;
	                        d = Jz(c[(c[h >> 2] | 0) + 132 >> 2] | 0, c[u >> 2] | 0, 0) | 0;
	                        c[(c[h >> 2] | 0) + 136 >> 2] = d;
	                        break
	                    }
	                    default:
	                    {
	                    }
	                } while (0);
	                c[g >> 2] = c[k >> 2];
	                y = c[g >> 2] | 0;
	                i = e;
	                return y | 0
	            }

	            function eO(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 20 | 0;
	                e = b + 16 | 0;
	                f = b + 12 | 0;
	                g = b + 8 | 0;
	                h = b + 4 | 0;
	                j = b;
	                c[d >> 2] = a;
	                c[e >> 2] = 0;
	                c[g >> 2] = 0;
	                while (1) {
	                    if ((c[e >> 2] | 0) >= (c[(c[d >> 2] | 0) + 48 >> 2] | 0))break;
	                    c[h >> 2] = (c[(c[d >> 2] | 0) + 56 >> 2] | 0) + ((c[e >> 2] | 0) * 24 | 0);
	                    a:do if ((c[g >> 2] | 0) < 5) {
	                        c[f >> 2] = 0;
	                        while (1) {
	                            if ((c[f >> 2] | 0) >= (c[e >> 2] | 0))break;
	                            c[j >> 2] = (c[(c[d >> 2] | 0) + 56 >> 2] | 0) + ((c[f >> 2] | 0) * 24 | 0);
	                            if ((((c[c[h >> 2] >> 2] | 0) == (c[c[j >> 2] >> 2] | 0) ? (c[(c[h >> 2] | 0) + 8 >> 2] | 0) == (c[(c[j >> 2] | 0) + 8 >> 2] | 0) : 0) ? (qy(c[(c[h >> 2] | 0) + 16 >> 2] | 0, c[(c[j >> 2] | 0) + 16 >> 2] | 0) | 0) != 0 : 0) ? (qy(c[(c[h >> 2] | 0) + 20 >> 2] | 0, c[(c[j >> 2] | 0) + 20 >> 2] | 0) | 0) != 0 : 0)break a;
	                            c[f >> 2] = (c[f >> 2] | 0) + 1
	                        }
	                        fO(c[d >> 2] | 0, c[c[h >> 2] >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[(c[h >> 2] | 0) + 12 >> 2] | 0, c[(c[h >> 2] | 0) + 16 >> 2] | 0, c[(c[h >> 2] | 0) + 20 >> 2] | 0);
	                        c[g >> 2] = (c[g >> 2] | 0) + 1
	                    } while (0);
	                    if (c[(c[h >> 2] | 0) + 4 >> 2] & 1) {
	                        if (c[(c[h >> 2] | 0) + 16 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[h >> 2] | 0) + 16 >> 2] | 0);
	                        c[(c[h >> 2] | 0) + 16 >> 2] = 0;
	                        if (c[(c[h >> 2] | 0) + 20 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[h >> 2] | 0) + 20 >> 2] | 0);
	                        c[(c[h >> 2] | 0) + 20 >> 2] = 0;
	                        c[(c[h >> 2] | 0) + 4 >> 2] = 0
	                    }
	                    c[e >> 2] = (c[e >> 2] | 0) + 1
	                }
	                c[(c[d >> 2] | 0) + 48 >> 2] = 0;
	                i = b;
	                return
	            }

	            function fO(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                h = i;
	                i = i + 32 | 0;
	                j = h + 24 | 0;
	                k = h + 20 | 0;
	                l = h + 16 | 0;
	                m = h + 12 | 0;
	                n = h + 8 | 0;
	                o = h + 4 | 0;
	                p = h;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                if (c[(c[j >> 2] | 0) + 28 >> 2] & 8) {
	                    i = h;
	                    return
	                }
	                c[p >> 2] = GO(c[k >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0) | 0;
	                if (!(c[p >> 2] | 0)) {
	                    i = h;
	                    return
	                }
	                if (!(c[(c[j >> 2] | 0) + 40 >> 2] | 0))c[(c[j >> 2] | 0) + 40 >> 2] = c[k >> 2];
	                HO(c[j >> 2] | 0, (c[m >> 2] | 0) == 0 ? c[l >> 2] | 0 : c[m >> 2] | 0, c[k >> 2] | 0, c[p >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                i = h;
	                return
	            }

	            function gO(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 24 | 0;
	                j = g + 20 | 0;
	                k = g + 16 | 0;
	                l = g + 12 | 0;
	                m = g + 8 | 0;
	                n = g + 4 | 0;
	                o = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                do if (!(c[(c[j >> 2] | 0) + 56 >> 2] | 0)) {
	                    c[(c[j >> 2] | 0) + 52 >> 2] = 8;
	                    c[(c[j >> 2] | 0) + 48 >> 2] = 0;
	                    f = Cb[c[135744 >> 2] & 511]((c[(c[j >> 2] | 0) + 52 >> 2] | 0) * 24 | 0) | 0;
	                    c[(c[j >> 2] | 0) + 56 >> 2] = f;
	                    f = c[j >> 2] | 0;
	                    if (c[(c[j >> 2] | 0) + 56 >> 2] | 0) {
	                        c[f + 44 >> 2] = 0;
	                        break
	                    }
	                    MN(f, 189752);
	                    c[h >> 2] = 0;
	                    p = c[h >> 2] | 0;
	                    i = g;
	                    return p | 0
	                } while (0);
	                do if ((c[(c[j >> 2] | 0) + 48 >> 2] | 0) >= (c[(c[j >> 2] | 0) + 52 >> 2] | 0)) {
	                    f = (c[j >> 2] | 0) + 52 | 0;
	                    c[f >> 2] = c[f >> 2] << 1;
	                    f = Hb[c[135760 >> 2] & 511](c[(c[j >> 2] | 0) + 56 >> 2] | 0, (c[(c[j >> 2] | 0) + 52 >> 2] | 0) * 24 | 0) | 0;
	                    c[(c[j >> 2] | 0) + 56 >> 2] = f;
	                    f = c[j >> 2] | 0;
	                    if (c[(c[j >> 2] | 0) + 56 >> 2] | 0) {
	                        c[(c[j >> 2] | 0) + 44 >> 2] = (c[(c[j >> 2] | 0) + 56 >> 2] | 0) + (((c[f + 48 >> 2] | 0) - 1 | 0) * 24 | 0);
	                        break
	                    }
	                    MN(f, 189752);
	                    c[h >> 2] = 0;
	                    p = c[h >> 2] | 0;
	                    i = g;
	                    return p | 0
	                } while (0);
	                if ((((c[(c[j >> 2] | 0) + 44 >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 60 >> 2] | 0) != 0 : 0) ? (c[(c[(c[j >> 2] | 0) + 44 >> 2] | 0) + 8 >> 2] | 0) == (c[c[(c[j >> 2] | 0) + 60 >> 2] >> 2] | 0) : 0) ? (c[c[(c[j >> 2] | 0) + 44 >> 2] >> 2] | 0) == (c[k >> 2] | 0) : 0) {
	                    c[h >> 2] = c[(c[j >> 2] | 0) + 48 >> 2];
	                    p = c[h >> 2] | 0;
	                    i = g;
	                    return p | 0
	                }
	                c[o >> 2] = (c[(c[j >> 2] | 0) + 56 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 48 >> 2] | 0) * 24 | 0);
	                c[c[o >> 2] >> 2] = c[k >> 2];
	                k = c[l >> 2] | 0;
	                if (c[n >> 2] | 0) {
	                    n = my(k) | 0;
	                    c[(c[o >> 2] | 0) + 16 >> 2] = n;
	                    n = my(c[m >> 2] | 0) | 0;
	                    c[(c[o >> 2] | 0) + 20 >> 2] = n;
	                    c[(c[o >> 2] | 0) + 4 >> 2] = 1
	                } else {
	                    c[(c[o >> 2] | 0) + 16 >> 2] = k;
	                    c[(c[o >> 2] | 0) + 20 >> 2] = c[m >> 2];
	                    c[(c[o >> 2] | 0) + 4 >> 2] = 0
	                }
	                if (c[(c[j >> 2] | 0) + 60 >> 2] | 0) {
	                    c[(c[o >> 2] | 0) + 8 >> 2] = c[c[(c[j >> 2] | 0) + 60 >> 2] >> 2];
	                    c[(c[o >> 2] | 0) + 12 >> 2] = c[(c[(c[j >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2]
	                } else {
	                    c[(c[o >> 2] | 0) + 8 >> 2] = 0;
	                    c[(c[o >> 2] | 0) + 12 >> 2] = 0
	                }
	                c[(c[j >> 2] | 0) + 44 >> 2] = c[o >> 2];
	                o = (c[j >> 2] | 0) + 48 | 0;
	                j = c[o >> 2] | 0;
	                c[o >> 2] = j + 1;
	                c[h >> 2] = j;
	                p = c[h >> 2] | 0;
	                i = g;
	                return p | 0
	            }

	            function hO(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 24 | 0;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                l = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                c[k >> 2] = 0;
	                c[l >> 2] = c[g >> 2];
	                while (1) {
	                    if (!(c[l >> 2] | 0))break;
	                    if ((c[c[l >> 2] >> 2] | 0) == 9) {
	                        if (IO(c[f >> 2] | 0, c[l >> 2] | 0) | 0)c[h >> 2] = -1
	                    } else c[k >> 2] = 1;
	                    c[l >> 2] = c[(c[l >> 2] | 0) + 32 >> 2]
	                }
	                if (!(c[k >> 2] | 0)) {
	                    c[e >> 2] = c[h >> 2];
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                c[l >> 2] = c[g >> 2];
	                while (1) {
	                    if (!(c[l >> 2] | 0)) {
	                        n = 20;
	                        break
	                    }
	                    if ((c[c[l >> 2] >> 2] | 0) != 9) {
	                        if ((c[(c[f >> 2] | 0) + 60 >> 2] | 0) == 0 ? (c[(c[f >> 2] | 0) + 64 >> 2] | 0) == 0 : 0) {
	                            n = 17;
	                            break
	                        }
	                        c[j >> 2] = KN(c[f >> 2] | 0, c[l >> 2] | 0) | 0;
	                        if ((c[j >> 2] | 0) < 0)c[h >> 2] = -1;
	                        if ((c[j >> 2] | 0) == -1) {
	                            n = 20;
	                            break
	                        }
	                    }
	                    c[l >> 2] = c[(c[l >> 2] | 0) + 32 >> 2]
	                }
	                if ((n | 0) == 17) {
	                    FN(c[f >> 2] | 0, 6, 0, 0, 0);
	                    c[e >> 2] = -1;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                } else if ((n | 0) == 20) {
	                    c[e >> 2] = c[h >> 2];
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                return 0
	            }

	            function iO(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[j >> 2] = c[(c[f >> 2] | 0) + 60 >> 2];
	                if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 0 ? (b = oO(c[f >> 2] | 0, c[(c[j >> 2] | 0) + 4 >> 2] | 0) | 0, c[(c[j >> 2] | 0) + 4 >> 2] = b, (c[(c[j >> 2] | 0) + 4 >> 2] | 0) != 0) : 0) {
	                    if (c[g >> 2] | 0)FN(c[f >> 2] | 0, 26, c[(c[c[j >> 2] >> 2] | 0) + 8 >> 2] | 0, c[(c[(c[j >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] | 0, 0);
	                    c[e >> 2] = -1;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                c[h >> 2] = 0;
	                while (1) {
	                    if ((c[h >> 2] | 0) >= (c[(c[j >> 2] | 0) + 8 >> 2] | 0)) {
	                        l = 13;
	                        break
	                    }
	                    if (c[(c[(c[j >> 2] | 0) + 28 >> 2] | 0) + (c[h >> 2] << 2) >> 2] | 0)break;
	                    c[h >> 2] = (c[h >> 2] | 0) + 1
	                }
	                if ((l | 0) == 13) {
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                if (c[g >> 2] | 0)FN(c[f >> 2] | 0, 27, c[(c[(c[(c[j >> 2] | 0) + 28 >> 2] | 0) + (c[h >> 2] << 2) >> 2] | 0) + 8 >> 2] | 0, c[(c[c[j >> 2] >> 2] | 0) + 8 >> 2] | 0, 0);
	                c[e >> 2] = -1 - (c[h >> 2] | 0);
	                k = c[e >> 2] | 0;
	                i = d;
	                return k | 0
	            }

	            function jO(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (!(c[(c[d >> 2] | 0) + 64 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if ((c[c[(c[d >> 2] | 0) + 64 >> 2] >> 2] | 0) <= 0) {
	                    i = b;
	                    return
	                }
	                c[e >> 2] = JO(c[d >> 2] | 0) | 0;
	                if ((c[e >> 2] | 0) < 0) {
	                    i = b;
	                    return
	                }
	                if ((c[e >> 2] | 0) >= (c[c[(c[d >> 2] | 0) + 64 >> 2] >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                c[(c[d >> 2] | 0) + 60 >> 2] = c[(c[(c[(c[d >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] | 0) + (c[e >> 2] << 2) >> 2];
	                iO(c[d >> 2] | 0, 1) | 0;
	                i = b;
	                return
	            }

	            function kO(a, d) {
	                a = a | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0, J = 0, K = 0, L = 0, M = 0, N = 0, O = 0, P = 0, Q = 0, R = 0, S = 0, T = 0, U = 0, V = 0, W = 0;
	                e = i;
	                i = i + 144 | 0;
	                f = e;
	                g = e + 136 | 0;
	                h = e + 132 | 0;
	                j = e + 128 | 0;
	                k = e + 124 | 0;
	                l = e + 120 | 0;
	                m = e + 116 | 0;
	                n = e + 112 | 0;
	                o = e + 108 | 0;
	                p = e + 104 | 0;
	                q = e + 100 | 0;
	                r = e + 96 | 0;
	                s = e + 92 | 0;
	                t = e + 88 | 0;
	                u = e + 84 | 0;
	                v = e + 80 | 0;
	                w = e + 76 | 0;
	                x = e + 72 | 0;
	                y = e + 68 | 0;
	                z = e + 64 | 0;
	                A = e + 60 | 0;
	                B = e + 56 | 0;
	                C = e + 52 | 0;
	                D = e + 48 | 0;
	                E = e + 44 | 0;
	                F = e + 40 | 0;
	                G = e + 36 | 0;
	                H = e + 32 | 0;
	                I = e + 28 | 0;
	                J = e + 24 | 0;
	                K = e + 20 | 0;
	                L = e + 16 | 0;
	                M = e + 12 | 0;
	                N = e + 8 | 0;
	                c[h >> 2] = a;
	                c[j >> 2] = d;
	                c[l >> 2] = 0;
	                c[q >> 2] = 0;
	                d = c[h >> 2] | 0;
	                if (!(c[j >> 2] | 0)) {
	                    FN(d, 7, 0, 0, 0);
	                    c[g >> 2] = -1;
	                    O = c[g >> 2] | 0;
	                    i = e;
	                    return O | 0
	                }
	                if (c[d + 60 >> 2] | 0)c[k >> 2] = c[(c[(c[h >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2]; else c[k >> 2] = 0;
	                d = (c[h >> 2] | 0) + 32 | 0;
	                c[d >> 2] = (c[d >> 2] | 0) + 1;
	                a:do switch (c[c[j >> 2] >> 2] | 0) {
	                    case 1:
	                    {
	                        c[l >> 2] = -1;
	                        break
	                    }
	                    case 3:
	                    {
	                        while (1) {
	                            if (c[k >> 2] | 0)if (((c[(c[k >> 2] | 0) + 4 >> 2] | 0) != 3 ? (c[(c[k >> 2] | 0) + 4 >> 2] | 0) != 8 : 0) ? (c[(c[k >> 2] | 0) + 4 >> 2] | 0) != 7 : 0)P = (c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 4; else P = 1; else P = 0;
	                            Q = c[k >> 2] | 0;
	                            if (!P)break;
	                            c[k >> 2] = c[Q + 24 >> 2]
	                        }
	                        c[(c[(c[h >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2] = Q;
	                        break
	                    }
	                    case 0:
	                    {
	                        c[k >> 2] = oO(c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                        c[l >> 2] = 0;
	                        break
	                    }
	                    case 16:
	                    {
	                        c[p >> 2] = c[(c[h >> 2] | 0) + 48 >> 2];
	                        c[l >> 2] = OO(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 24 >> 2] | 0) | 0;
	                        if (!(c[l >> 2] | 0))if ((c[(c[h >> 2] | 0) + 48 >> 2] | 0) > (c[p >> 2] | 0)) {
	                            KO(c[h >> 2] | 0, c[p >> 2] | 0);
	                            R = 124
	                        } else R = 124;
	                        break
	                    }
	                    case 15:
	                    {
	                        R = 124;
	                        break
	                    }
	                    case 14:
	                    {
	                        c[p >> 2] = c[(c[h >> 2] | 0) + 48 >> 2];
	                        c[o >> 2] = c[(c[h >> 2] | 0) + 28 >> 2];
	                        d = (c[h >> 2] | 0) + 28 | 0;
	                        c[d >> 2] = c[d >> 2] | 1;
	                        c[q >> 2] = PO(c[h >> 2] | 0, c[(c[h >> 2] | 0) + 60 >> 2] | 0) | 0;
	                        c[l >> 2] = OO(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 24 >> 2] | 0) | 0;
	                        d = c[h >> 2] | 0;
	                        if (c[l >> 2] | 0) {
	                            if (c[d + 60 >> 2] | 0)LN(c[h >> 2] | 0, c[(c[h >> 2] | 0) + 60 >> 2] | 0);
	                            c[(c[h >> 2] | 0) + 60 >> 2] = c[q >> 2];
	                            c[(c[h >> 2] | 0) + 28 >> 2] = c[o >> 2];
	                            c[l >> 2] = 0;
	                            if ((c[(c[h >> 2] | 0) + 48 >> 2] | 0) <= (c[p >> 2] | 0))break a;
	                            KO(c[h >> 2] | 0, c[p >> 2] | 0);
	                            break a
	                        }
	                        a = c[h >> 2] | 0;
	                        do if (c[d + 64 >> 2] | 0)lO(a, c[(c[h >> 2] | 0) + 64 >> 2] | 0, c[q >> 2] | 0) | 0; else {
	                            S = mO(a, 1) | 0;
	                            c[(c[h >> 2] | 0) + 64 >> 2] = S;
	                            S = c[h >> 2] | 0;
	                            if (c[(c[h >> 2] | 0) + 64 >> 2] | 0) {
	                                lO(S, c[(c[h >> 2] | 0) + 64 >> 2] | 0, c[q >> 2] | 0) | 0;
	                                lO(c[h >> 2] | 0, c[(c[h >> 2] | 0) + 64 >> 2] | 0, c[(c[h >> 2] | 0) + 60 >> 2] | 0) | 0;
	                                c[(c[h >> 2] | 0) + 60 >> 2] = 0;
	                                break
	                            }
	                            LN(S, c[q >> 2] | 0);
	                            c[(c[h >> 2] | 0) + 28 >> 2] = c[o >> 2];
	                            c[l >> 2] = -1;
	                            if ((c[(c[h >> 2] | 0) + 48 >> 2] | 0) <= (c[p >> 2] | 0))break a;
	                            KO(c[h >> 2] | 0, c[p >> 2] | 0);
	                            break a
	                        } while (0);
	                        c[(c[h >> 2] | 0) + 28 >> 2] = c[o >> 2];
	                        c[l >> 2] = 0;
	                        if ((c[(c[h >> 2] | 0) + 48 >> 2] | 0) > (c[p >> 2] | 0))KO(c[h >> 2] | 0, c[p >> 2] | 0);
	                        break
	                    }
	                    case 4:
	                    {
	                        c[p >> 2] = c[(c[h >> 2] | 0) + 48 >> 2];
	                        c[k >> 2] = oO(c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                        if (!(c[k >> 2] | 0)) {
	                            FN(c[h >> 2] | 0, 22, c[(c[j >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                            c[l >> 2] = -1;
	                            if (c[(c[h >> 2] | 0) + 28 >> 2] & 1)break a;
	                            eO(c[h >> 2] | 0);
	                            break a
	                        }
	                        if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) != 1) {
	                            FN(c[h >> 2] | 0, 23, 0, 0, 0);
	                            c[l >> 2] = -1;
	                            if (c[(c[h >> 2] | 0) + 28 >> 2] & 1)break a;
	                            eO(c[h >> 2] | 0);
	                            break a
	                        }
	                        a = c[h >> 2] | 0;
	                        if ((c[(c[k >> 2] | 0) + 52 >> 2] | 0) == (c[j >> 2] | 0)) {
	                            d = oO(a, c[(c[k >> 2] | 0) + 24 >> 2] | 0) | 0;
	                            c[(c[(c[h >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2] = d;
	                            if ((c[(c[h >> 2] | 0) + 48 >> 2] | 0) > (c[p >> 2] | 0))KO(c[h >> 2] | 0, c[p >> 2] | 0);
	                            if (!(c[(c[h >> 2] | 0) + 48 >> 2] | 0))break a;
	                            while (1) {
	                                if (!(c[(c[h >> 2] | 0) + 44 >> 2] | 0))break a;
	                                if (!((c[c[(c[h >> 2] | 0) + 44 >> 2] >> 2] | 0) == 13 ? (qy(c[(c[(c[h >> 2] | 0) + 44 >> 2] | 0) + 20 >> 2] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0) | 0) != 0 : 0))R = 30;
	                                do if ((R | 0) == 30) {
	                                    R = 0;
	                                    if ((c[c[(c[h >> 2] | 0) + 44 >> 2] >> 2] | 0) == 19 ? (qy(c[(c[(c[h >> 2] | 0) + 44 >> 2] | 0) + 16 >> 2] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0) | 0) != 0 : 0)break;
	                                    if ((c[c[(c[h >> 2] | 0) + 44 >> 2] >> 2] | 0) != 22 ? (c[c[(c[h >> 2] | 0) + 44 >> 2] >> 2] | 0) != 23 : 0)break a
	                                } while (0);
	                                LO(c[h >> 2] | 0)
	                            }
	                        }
	                        c[l >> 2] = MO(a, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                        if ((c[l >> 2] | 0) <= 0) {
	                            c[l >> 2] = -1;
	                            if (c[(c[h >> 2] | 0) + 28 >> 2] & 1)break a;
	                            eO(c[h >> 2] | 0);
	                            break a
	                        }
	                        c[l >> 2] = 0;
	                        b:do if (c[(c[h >> 2] | 0) + 48 >> 2] | 0) {
	                            if ((c[(c[h >> 2] | 0) + 48 >> 2] | 0) > (c[p >> 2] | 0))KO(c[h >> 2] | 0, c[p >> 2] | 0);
	                            while (1) {
	                                if (!(c[(c[h >> 2] | 0) + 44 >> 2] | 0))break b;
	                                if (!((c[c[(c[h >> 2] | 0) + 44 >> 2] >> 2] | 0) == 13 ? (qy(c[(c[(c[h >> 2] | 0) + 44 >> 2] | 0) + 20 >> 2] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0) | 0) != 0 : 0))R = 44;
	                                do if ((R | 0) == 44) {
	                                    R = 0;
	                                    if ((c[c[(c[h >> 2] | 0) + 44 >> 2] >> 2] | 0) == 19 ? (qy(c[(c[(c[h >> 2] | 0) + 44 >> 2] | 0) + 16 >> 2] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0) | 0) != 0 : 0)break;
	                                    if ((c[c[(c[h >> 2] | 0) + 44 >> 2] >> 2] | 0) != 22 ? (c[c[(c[h >> 2] | 0) + 44 >> 2] >> 2] | 0) != 23 : 0)break b
	                                } while (0);
	                                LO(c[h >> 2] | 0)
	                            }
	                        } while (0);
	                        c[p >> 2] = c[(c[h >> 2] | 0) + 48 >> 2];
	                        c[o >> 2] = c[(c[h >> 2] | 0) + 28 >> 2];
	                        if (c[(c[h >> 2] | 0) + 28 >> 2] & 4) {
	                            a = (c[h >> 2] | 0) + 28 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) - 4
	                        }
	                        c[r >> 2] = JN(c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                        if (!(c[r >> 2] | 0)) {
	                            c[l >> 2] = -1;
	                            if (c[(c[h >> 2] | 0) + 28 >> 2] & 1)break a;
	                            eO(c[h >> 2] | 0);
	                            break a
	                        }
	                        c[q >> 2] = c[(c[h >> 2] | 0) + 60 >> 2];
	                        c[(c[h >> 2] | 0) + 60 >> 2] = c[r >> 2];
	                        if ((c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[n >> 2] = hO(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 36 >> 2] | 0) | 0, (c[n >> 2] | 0) != 0) : 0) {
	                            c[l >> 2] = -1;
	                            FN(c[h >> 2] | 0, 24, c[(c[k >> 2] | 0) + 8 >> 2] | 0, 0, 0)
	                        }
	                        do if (c[(c[j >> 2] | 0) + 52 >> 2] | 0) {
	                            c[t >> 2] = c[(c[h >> 2] | 0) + 60 >> 2];
	                            c[u >> 2] = c[(c[h >> 2] | 0) + 64 >> 2];
	                            c[s >> 2] = JN(c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                            c[(c[h >> 2] | 0) + 60 >> 2] = c[s >> 2];
	                            c[(c[h >> 2] | 0) + 64 >> 2] = 0;
	                            c[n >> 2] = NO(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 52 >> 2] | 0, c[(c[(c[h >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2] | 0) | 0;
	                            c[v >> 2] = c[(c[(c[h >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2];
	                            c[(c[h >> 2] | 0) + 60 >> 2] = c[t >> 2];
	                            c[(c[h >> 2] | 0) + 64 >> 2] = c[u >> 2];
	                            LN(c[h >> 2] | 0, c[s >> 2] | 0);
	                            if (c[n >> 2] | 0)c[l >> 2] = -1;
	                            if (!(c[(c[h >> 2] | 0) + 64 >> 2] | 0)) {
	                                c[r >> 2] = c[(c[h >> 2] | 0) + 60 >> 2];
	                                if (c[(c[h >> 2] | 0) + 60 >> 2] | 0)c[(c[(c[h >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2] = c[v >> 2];
	                                if (!(c[l >> 2] | 0))c[l >> 2] = iO(c[h >> 2] | 0, 1) | 0;
	                                LN(c[h >> 2] | 0, c[r >> 2] | 0);
	                                break
	                            }
	                            c[n >> 2] = -1;
	                            c[m >> 2] = 0;
	                            while (1) {
	                                if ((c[m >> 2] | 0) >= (c[c[(c[h >> 2] | 0) + 64 >> 2] >> 2] | 0))break;
	                                c[r >> 2] = c[(c[(c[(c[h >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] | 0) + (c[m >> 2] << 2) >> 2];
	                                c[(c[h >> 2] | 0) + 60 >> 2] = c[r >> 2];
	                                c[(c[(c[h >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2] = c[v >> 2];
	                                if (!(iO(c[h >> 2] | 0, 0) | 0)) {
	                                    R = 64;
	                                    break
	                                }
	                                c[m >> 2] = (c[m >> 2] | 0) + 1
	                            }
	                            if ((R | 0) == 64)c[n >> 2] = 0;
	                            if (c[n >> 2] | 0) {
	                                a = (c[h >> 2] | 0) + 28 | 0;
	                                c[a >> 2] = c[a >> 2] | 1;
	                                jO(c[h >> 2] | 0)
	                            }
	                            c[m >> 2] = 0;
	                            while (1) {
	                                T = c[h >> 2] | 0;
	                                if ((c[m >> 2] | 0) >= (c[c[(c[h >> 2] | 0) + 64 >> 2] >> 2] | 0))break;
	                                LN(T, c[(c[(c[(c[h >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] | 0) + (c[m >> 2] << 2) >> 2] | 0);
	                                c[m >> 2] = (c[m >> 2] | 0) + 1
	                            }
	                            NN(T, c[(c[h >> 2] | 0) + 64 >> 2] | 0);
	                            c[(c[h >> 2] | 0) + 28 >> 2] = c[o >> 2];
	                            c[(c[h >> 2] | 0) + 64 >> 2] = 0;
	                            if ((c[l >> 2] | 0) == 0 & (c[n >> 2] | 0) == -1)c[l >> 2] = -1
	                        } else {
	                            do if ((c[(c[j >> 2] | 0) + 24 >> 2] | 0) != 0 ? (c[n >> 2] = OO(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 24 >> 2] | 0) | 0, (c[n >> 2] | 0) != 0) : 0) {
	                                c[l >> 2] = -1;
	                                if (!(c[(c[h >> 2] | 0) + 60 >> 2] | 0)) {
	                                    c[(c[h >> 2] | 0) + 60 >> 2] = c[q >> 2];
	                                    FN(c[h >> 2] | 0, 25, c[(c[k >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                                    c[(c[h >> 2] | 0) + 60 >> 2] = 0;
	                                    break
	                                } else {
	                                    FN(c[h >> 2] | 0, 25, c[(c[k >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                                    break
	                                }
	                            } while (0);
	                            if (!(c[(c[h >> 2] | 0) + 64 >> 2] | 0)) {
	                                c[r >> 2] = c[(c[h >> 2] | 0) + 60 >> 2];
	                                if (!(c[l >> 2] | 0))c[l >> 2] = iO(c[h >> 2] | 0, 1) | 0;
	                                LN(c[h >> 2] | 0, c[r >> 2] | 0);
	                                break
	                            }
	                            c[n >> 2] = -1;
	                            c[m >> 2] = 0;
	                            while (1) {
	                                if ((c[m >> 2] | 0) >= (c[c[(c[h >> 2] | 0) + 64 >> 2] >> 2] | 0))break;
	                                c[r >> 2] = c[(c[(c[(c[h >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] | 0) + (c[m >> 2] << 2) >> 2];
	                                c[(c[h >> 2] | 0) + 60 >> 2] = c[r >> 2];
	                                if (!(iO(c[h >> 2] | 0, 0) | 0)) {
	                                    R = 87;
	                                    break
	                                }
	                                c[m >> 2] = (c[m >> 2] | 0) + 1
	                            }
	                            if ((R | 0) == 87)c[n >> 2] = 0;
	                            if (c[n >> 2] | 0) {
	                                a = (c[h >> 2] | 0) + 28 | 0;
	                                c[a >> 2] = c[a >> 2] | 1;
	                                jO(c[h >> 2] | 0)
	                            }
	                            c[m >> 2] = 0;
	                            while (1) {
	                                U = c[h >> 2] | 0;
	                                if ((c[m >> 2] | 0) >= (c[c[(c[h >> 2] | 0) + 64 >> 2] >> 2] | 0))break;
	                                LN(U, c[(c[(c[(c[h >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] | 0) + (c[m >> 2] << 2) >> 2] | 0);
	                                c[(c[(c[(c[h >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] | 0) + (c[m >> 2] << 2) >> 2] = 0;
	                                c[m >> 2] = (c[m >> 2] | 0) + 1
	                            }
	                            NN(U, c[(c[h >> 2] | 0) + 64 >> 2] | 0);
	                            c[(c[h >> 2] | 0) + 28 >> 2] = c[o >> 2];
	                            c[(c[h >> 2] | 0) + 64 >> 2] = 0;
	                            if ((c[l >> 2] | 0) == 0 & (c[n >> 2] | 0) == -1)c[l >> 2] = -1
	                        } while (0);
	                        if (!(c[l >> 2] | 0))c[(c[k >> 2] | 0) + 52 >> 2] = c[j >> 2];
	                        c[(c[h >> 2] | 0) + 28 >> 2] = c[o >> 2];
	                        c[(c[h >> 2] | 0) + 60 >> 2] = c[q >> 2];
	                        if (c[q >> 2] | 0) {
	                            a = oO(c[h >> 2] | 0, c[(c[k >> 2] | 0) + 24 >> 2] | 0) | 0;
	                            c[(c[q >> 2] | 0) + 4 >> 2] = a
	                        }
	                        a = c[h >> 2] | 0;
	                        if (c[l >> 2] | 0) {
	                            if (c[a + 28 >> 2] & 1)break a;
	                            eO(c[h >> 2] | 0);
	                            c[l >> 2] = 0;
	                            break a
	                        } else {
	                            if ((c[a + 48 >> 2] | 0) <= (c[p >> 2] | 0))break a;
	                            KO(c[h >> 2] | 0, c[p >> 2] | 0);
	                            break a
	                        }
	                        break
	                    }
	                    case 18:
	                    case 10:
	                    {
	                        c[l >> 2] = OO(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 24 >> 2] | 0) | 0;
	                        break
	                    }
	                    case 19:
	                    {
	                        c[l >> 2] = QO(c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                        break
	                    }
	                    case 9:
	                    {
	                        c[l >> 2] = IO(c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                        break
	                    }
	                    case 13:
	                    case 12:
	                    case 11:
	                    case -1:
	                    case 20:
	                    {
	                        c[l >> 2] = KN(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 24 >> 2] | 0) | 0;
	                        break
	                    }
	                    case 5:
	                    {
	                        c[F >> 2] = 0;
	                        c[E >> 2] = c[k >> 2];
	                        while (1) {
	                            if (!(c[E >> 2] | 0))break;
	                            if ((c[(c[E >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                                R = 222;
	                                break
	                            }
	                            if (!((c[(c[E >> 2] | 0) + 4 >> 2] | 0) != 3 ? (c[(c[E >> 2] | 0) + 4 >> 2] | 0) != 4 : 0))c[F >> 2] = By(c[F >> 2] | 0, c[(c[E >> 2] | 0) + 40 >> 2] | 0) | 0;
	                            c[E >> 2] = c[(c[E >> 2] | 0) + 24 >> 2]
	                        }
	                        if ((R | 0) == 222) {
	                            FN(c[h >> 2] | 0, 28, c[(c[(c[k >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                            c[l >> 2] = -1
	                        }
	                        a = c[F >> 2] | 0;
	                        if ((c[l >> 2] | 0) == -1) {
	                            if (!a)break a;
	                            zb[c[135736 >> 2] & 511](c[F >> 2] | 0);
	                            break a
	                        }
	                        if ((a | 0) == 0 ? (c[F >> 2] = my(188112) | 0, (c[F >> 2] | 0) == 0) : 0) {
	                            MN(c[h >> 2] | 0, 189544);
	                            c[l >> 2] = -1;
	                            break a
	                        }
	                        c[l >> 2] = RO(c[h >> 2] | 0, c[F >> 2] | 0, c[j >> 2] | 0, c[(c[(c[h >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2] | 0) | 0;
	                        if ((c[l >> 2] | 0) != -1) {
	                            if (!(c[l >> 2] | 0))c[(c[(c[h >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2] = 0
	                        } else FN(c[h >> 2] | 0, 31, c[(c[j >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                        if (c[F >> 2] | 0)zb[c[135736 >> 2] & 511](c[F >> 2] | 0);
	                        break
	                    }
	                    case 7:
	                    {
	                        c[G >> 2] = 0;
	                        c[I >> 2] = c[k >> 2];
	                        while (1) {
	                            if (!(c[I >> 2] | 0))break;
	                            if ((c[(c[I >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                                R = 242;
	                                break
	                            }
	                            if (!((c[(c[I >> 2] | 0) + 4 >> 2] | 0) != 3 ? (c[(c[I >> 2] | 0) + 4 >> 2] | 0) != 4 : 0))c[G >> 2] = By(c[G >> 2] | 0, c[(c[I >> 2] | 0) + 40 >> 2] | 0) | 0;
	                            c[I >> 2] = c[(c[I >> 2] | 0) + 24 >> 2]
	                        }
	                        if ((R | 0) == 242) {
	                            FN(c[h >> 2] | 0, 29, c[(c[(c[k >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                            c[l >> 2] = -1
	                        }
	                        a = c[G >> 2] | 0;
	                        if ((c[l >> 2] | 0) == -1) {
	                            if (!a)break a;
	                            zb[c[135736 >> 2] & 511](c[G >> 2] | 0);
	                            break a
	                        }
	                        if ((a | 0) == 0 ? (c[G >> 2] = my(188112) | 0, (c[G >> 2] | 0) == 0) : 0) {
	                            MN(c[h >> 2] | 0, 189544);
	                            c[l >> 2] = -1;
	                            break a
	                        }
	                        c[H >> 2] = c[(c[(c[h >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2];
	                        c[(c[(c[h >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2] = c[G >> 2];
	                        c[l >> 2] = SO(c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                        c[(c[(c[h >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2] = c[H >> 2];
	                        if ((c[l >> 2] | 0) != -1) {
	                            if (!(c[l >> 2] | 0))c[(c[(c[h >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2] = 0
	                        } else FN(c[h >> 2] | 0, 32, c[(c[j >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                        if (c[G >> 2] | 0)zb[c[135736 >> 2] & 511](c[G >> 2] | 0);
	                        break
	                    }
	                    case 8:
	                    {
	                        c[J >> 2] = 0;
	                        c[K >> 2] = c[k >> 2];
	                        while (1) {
	                            if (!(c[K >> 2] | 0))break;
	                            if ((c[(c[K >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                                R = 262;
	                                break
	                            }
	                            if (!((c[(c[K >> 2] | 0) + 4 >> 2] | 0) != 3 ? (c[(c[K >> 2] | 0) + 4 >> 2] | 0) != 4 : 0))c[J >> 2] = By(c[J >> 2] | 0, c[(c[K >> 2] | 0) + 40 >> 2] | 0) | 0;
	                            c[K >> 2] = c[(c[K >> 2] | 0) + 24 >> 2]
	                        }
	                        if ((R | 0) == 262) {
	                            FN(c[h >> 2] | 0, 30, c[(c[(c[k >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                            c[l >> 2] = -1
	                        }
	                        a = c[J >> 2] | 0;
	                        if ((c[l >> 2] | 0) == -1) {
	                            if (!a)break a;
	                            zb[c[135736 >> 2] & 511](c[J >> 2] | 0);
	                            break a
	                        }
	                        if ((a | 0) == 0 ? (c[J >> 2] = my(188112) | 0, (c[J >> 2] | 0) == 0) : 0) {
	                            MN(c[h >> 2] | 0, 189544);
	                            c[l >> 2] = -1;
	                            break a
	                        }
	                        c[N >> 2] = xy(c[J >> 2] | 0) | 0;
	                        c[L >> 2] = c[(c[(c[h >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2];
	                        c[M >> 2] = c[(c[(c[h >> 2] | 0) + 60 >> 2] | 0) + 24 >> 2];
	                        c[(c[(c[h >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2] = c[J >> 2];
	                        c[(c[(c[h >> 2] | 0) + 60 >> 2] | 0) + 24 >> 2] = (c[J >> 2] | 0) + (c[N >> 2] | 0);
	                        c[l >> 2] = SO(c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                        c[(c[(c[h >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2] = c[L >> 2];
	                        c[(c[(c[h >> 2] | 0) + 60 >> 2] | 0) + 24 >> 2] = c[M >> 2];
	                        if ((c[l >> 2] | 0) != -1) {
	                            if ((c[l >> 2] | 0) == 0 & (c[k >> 2] | 0) != 0)c[(c[(c[h >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                        } else FN(c[h >> 2] | 0, 33, 0, 0, 0);
	                        if (c[J >> 2] | 0)zb[c[135736 >> 2] & 511](c[J >> 2] | 0);
	                        break
	                    }
	                    case 6:
	                    case 2:
	                    {
	                        a = c[33976] | 0;
	                        d = c[33980] | 0;
	                        c[f >> 2] = 189496;
	                        c[f + 4 >> 2] = 10569;
	                        Db[a & 511](d, 189464, f);
	                        c[l >> 2] = -1;
	                        break
	                    }
	                    case 17:
	                    {
	                        c[B >> 2] = 0;
	                        c[C >> 2] = 0;
	                        c[k >> 2] = oO(c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                        c[p >> 2] = c[(c[h >> 2] | 0) + 48 >> 2];
	                        if ((b[(c[j >> 2] | 0) + 50 >> 1] & 16 | 0) != 0 ? ((c[k >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) : 0) {
	                            c[D >> 2] = c[(c[j >> 2] | 0) + 20 >> 2];
	                            if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) != 3 ? (c[(c[k >> 2] | 0) + 4 >> 2] | 0) != 4 : 0) {
	                                if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                                    d = c[D >> 2] | 0;
	                                    a = c[(c[k >> 2] | 0) + 8 >> 2] | 0;
	                                    if (c[(c[k >> 2] | 0) + 36 >> 2] | 0) {
	                                        c[B >> 2] = Tj(d, a, c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) | 0;
	                                        if (!(c[B >> 2] | 0))c[B >> 2] = Tj(c[D >> 2] | 0, 189536, c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) | 0
	                                    } else c[B >> 2] = Tj(d, a, 0) | 0;
	                                    if (!(c[B >> 2] | 0))c[B >> 2] = Tj(c[D >> 2] | 0, 189536, 0) | 0
	                                }
	                            } else c[B >> 2] = Tj(c[D >> 2] | 0, 188096, 0) | 0;
	                            if (!(c[B >> 2] | 0)) {
	                                c[l >> 2] = -1;
	                                FN(c[h >> 2] | 0, 38, c[(c[k >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                                break a
	                            } else {
	                                c[l >> 2] = KN(c[h >> 2] | 0, c[B >> 2] | 0) | 0;
	                                break a
	                            }
	                        }
	                        c[B >> 2] = c[(c[j >> 2] | 0) + 24 >> 2];
	                        c[o >> 2] = c[(c[h >> 2] | 0) + 28 >> 2];
	                        a = (c[h >> 2] | 0) + 28 | 0;
	                        c[a >> 2] = c[a >> 2] | 1;
	                        while (1) {
	                            if (!(c[B >> 2] | 0))break;
	                            c[q >> 2] = PO(c[h >> 2] | 0, c[(c[h >> 2] | 0) + 60 >> 2] | 0) | 0;
	                            c[l >> 2] = KN(c[h >> 2] | 0, c[B >> 2] | 0) | 0;
	                            do if (!(c[l >> 2] | 0)) {
	                                if (!(c[C >> 2] | 0))c[C >> 2] = mO(c[h >> 2] | 0, 1) | 0;
	                                a = c[h >> 2] | 0;
	                                if (c[(c[h >> 2] | 0) + 60 >> 2] | 0) {
	                                    lO(a, c[C >> 2] | 0, c[(c[h >> 2] | 0) + 60 >> 2] | 0) | 0;
	                                    break
	                                }
	                                if (c[a + 64 >> 2] | 0) {
	                                    c[m >> 2] = 0;
	                                    while (1) {
	                                        V = c[h >> 2] | 0;
	                                        if ((c[m >> 2] | 0) >= (c[c[(c[h >> 2] | 0) + 64 >> 2] >> 2] | 0))break;
	                                        lO(V, c[C >> 2] | 0, c[(c[(c[(c[h >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] | 0) + (c[m >> 2] << 2) >> 2] | 0) | 0;
	                                        c[m >> 2] = (c[m >> 2] | 0) + 1
	                                    }
	                                    NN(V, c[(c[h >> 2] | 0) + 64 >> 2] | 0);
	                                    c[(c[h >> 2] | 0) + 64 >> 2] = 0
	                                }
	                            } else LN(c[h >> 2] | 0, c[(c[h >> 2] | 0) + 60 >> 2] | 0); while (0);
	                            c[(c[h >> 2] | 0) + 60 >> 2] = c[q >> 2];
	                            c[B >> 2] = c[(c[B >> 2] | 0) + 32 >> 2]
	                        }
	                        a = c[h >> 2] | 0;
	                        if (c[C >> 2] | 0) {
	                            LN(a, c[q >> 2] | 0);
	                            c[(c[h >> 2] | 0) + 64 >> 2] = c[C >> 2];
	                            c[(c[h >> 2] | 0) + 60 >> 2] = 0;
	                            c[l >> 2] = 0
	                        } else c[a + 64 >> 2] = 0;
	                        c[(c[h >> 2] | 0) + 28 >> 2] = c[o >> 2];
	                        a = c[h >> 2] | 0;
	                        if (c[l >> 2] | 0) {
	                            if (c[a + 28 >> 2] & 1)break a;
	                            eO(c[h >> 2] | 0);
	                            break a
	                        } else {
	                            if ((c[a + 48 >> 2] | 0) <= (c[p >> 2] | 0))break a;
	                            KO(c[h >> 2] | 0, c[p >> 2] | 0);
	                            break a
	                        }
	                        break
	                    }
	                    default:
	                    {
	                    }
	                } while (0);
	                do if ((R | 0) == 124) {
	                    c[x >> 2] = 0;
	                    c[y >> 2] = 0;
	                    c[p >> 2] = c[(c[h >> 2] | 0) + 48 >> 2];
	                    c[y >> 2] = mO(c[h >> 2] | 0, 1) | 0;
	                    if (!(c[y >> 2] | 0)) {
	                        c[l >> 2] = -1;
	                        break
	                    }
	                    c:do if (c[(c[h >> 2] | 0) + 60 >> 2] | 0) {
	                        C = c[h >> 2] | 0;
	                        q = c[y >> 2] | 0;
	                        lO(C, q, PO(c[h >> 2] | 0, c[(c[h >> 2] | 0) + 60 >> 2] | 0) | 0) | 0
	                    } else {
	                        c[A >> 2] = 0;
	                        while (1) {
	                            if ((c[A >> 2] | 0) >= (c[c[(c[h >> 2] | 0) + 64 >> 2] >> 2] | 0))break c;
	                            q = c[h >> 2] | 0;
	                            C = c[y >> 2] | 0;
	                            lO(q, C, PO(c[h >> 2] | 0, c[(c[(c[(c[h >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] | 0) + (c[A >> 2] << 2) >> 2] | 0) | 0) | 0;
	                            c[A >> 2] = (c[A >> 2] | 0) + 1
	                        }
	                    } while (0);
	                    c[o >> 2] = c[(c[h >> 2] | 0) + 28 >> 2];
	                    C = (c[h >> 2] | 0) + 28 | 0;
	                    c[C >> 2] = c[C >> 2] | 1;
	                    d:do {
	                        c[w >> 2] = 0;
	                        c[z >> 2] = c[c[y >> 2] >> 2];
	                        C = c[h >> 2] | 0;
	                        e:do if (!(c[(c[h >> 2] | 0) + 64 >> 2] | 0)) {
	                            c[l >> 2] = OO(C, c[(c[j >> 2] | 0) + 24 >> 2] | 0) | 0;
	                            if (c[l >> 2] | 0) {
	                                LN(c[h >> 2] | 0, c[(c[h >> 2] | 0) + 60 >> 2] | 0);
	                                c[(c[h >> 2] | 0) + 60 >> 2] = 0;
	                                break
	                            }
	                            c[z >> 2] = c[c[y >> 2] >> 2];
	                            q = c[h >> 2] | 0;
	                            if (c[(c[h >> 2] | 0) + 60 >> 2] | 0) {
	                                c[n >> 2] = lO(q, c[y >> 2] | 0, c[(c[h >> 2] | 0) + 60 >> 2] | 0) | 0;
	                                c[(c[h >> 2] | 0) + 60 >> 2] = 0;
	                                if ((c[n >> 2] | 0) != 1)break;
	                                c[w >> 2] = 1;
	                                break
	                            }
	                            if (c[q + 64 >> 2] | 0) {
	                                c[A >> 2] = 0;
	                                while (1) {
	                                    if ((c[A >> 2] | 0) >= (c[c[(c[h >> 2] | 0) + 64 >> 2] >> 2] | 0))break;
	                                    c[n >> 2] = lO(c[h >> 2] | 0, c[y >> 2] | 0, c[(c[(c[(c[h >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] | 0) + (c[A >> 2] << 2) >> 2] | 0) | 0;
	                                    if ((c[n >> 2] | 0) == 1)c[w >> 2] = 1;
	                                    c[A >> 2] = (c[A >> 2] | 0) + 1
	                                }
	                                q = c[h >> 2] | 0;
	                                if (!(c[x >> 2] | 0))c[x >> 2] = c[q + 64 >> 2]; else NN(q, c[(c[h >> 2] | 0) + 64 >> 2] | 0);
	                                c[(c[h >> 2] | 0) + 64 >> 2] = 0
	                            }
	                        } else {
	                            c[x >> 2] = c[C + 64 >> 2];
	                            c[m >> 2] = 0;
	                            while (1) {
	                                if ((c[m >> 2] | 0) >= (c[c[x >> 2] >> 2] | 0))break e;
	                                c[(c[h >> 2] | 0) + 60 >> 2] = c[(c[(c[x >> 2] | 0) + 8 >> 2] | 0) + (c[m >> 2] << 2) >> 2];
	                                c[(c[h >> 2] | 0) + 64 >> 2] = 0;
	                                c[l >> 2] = OO(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 24 >> 2] | 0) | 0;
	                                q = (c[(c[h >> 2] | 0) + 60 >> 2] | 0) != 0;
	                                do if (!(c[l >> 2] | 0)) {
	                                    B = c[h >> 2] | 0;
	                                    if (q) {
	                                        c[n >> 2] = lO(B, c[y >> 2] | 0, c[(c[h >> 2] | 0) + 60 >> 2] | 0) | 0;
	                                        c[(c[h >> 2] | 0) + 60 >> 2] = 0;
	                                        if ((c[n >> 2] | 0) != 1)break;
	                                        c[w >> 2] = 1;
	                                        break
	                                    }
	                                    if (c[B + 64 >> 2] | 0) {
	                                        c[A >> 2] = 0;
	                                        while (1) {
	                                            W = c[h >> 2] | 0;
	                                            if ((c[A >> 2] | 0) >= (c[c[(c[h >> 2] | 0) + 64 >> 2] >> 2] | 0))break;
	                                            c[n >> 2] = lO(W, c[y >> 2] | 0, c[(c[(c[(c[h >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] | 0) + (c[A >> 2] << 2) >> 2] | 0) | 0;
	                                            if ((c[n >> 2] | 0) == 1)c[w >> 2] = 1;
	                                            c[A >> 2] = (c[A >> 2] | 0) + 1
	                                        }
	                                        NN(W, c[(c[h >> 2] | 0) + 64 >> 2] | 0);
	                                        c[(c[h >> 2] | 0) + 64 >> 2] = 0
	                                    }
	                                } else if (q) {
	                                    LN(c[h >> 2] | 0, c[(c[h >> 2] | 0) + 60 >> 2] | 0);
	                                    c[(c[h >> 2] | 0) + 60 >> 2] = 0
	                                } while (0);
	                                c[m >> 2] = (c[m >> 2] | 0) + 1
	                            }
	                        } while (0);
	                        do if (c[w >> 2] | 0) {
	                            if (((c[c[y >> 2] >> 2] | 0) - (c[z >> 2] | 0) | 0) == 1) {
	                                C = PO(c[h >> 2] | 0, c[(c[(c[y >> 2] | 0) + 8 >> 2] | 0) + (c[z >> 2] << 2) >> 2] | 0) | 0;
	                                c[(c[h >> 2] | 0) + 60 >> 2] = C;
	                                break
	                            }
	                            if ((c[x >> 2] | 0) == 0 ? (mO(c[h >> 2] | 0, (c[c[y >> 2] >> 2] | 0) - (c[z >> 2] | 0) | 0) | 0, c[x >> 2] = c[(c[h >> 2] | 0) + 64 >> 2], (c[x >> 2] | 0) == 0) : 0) {
	                                R = 169;
	                                break d
	                            }
	                            c[c[x >> 2] >> 2] = 0;
	                            c[m >> 2] = c[z >> 2];
	                            while (1) {
	                                if ((c[m >> 2] | 0) >= (c[c[y >> 2] >> 2] | 0))break;
	                                C = c[h >> 2] | 0;
	                                q = c[x >> 2] | 0;
	                                lO(C, q, PO(c[h >> 2] | 0, c[(c[(c[y >> 2] | 0) + 8 >> 2] | 0) + (c[m >> 2] << 2) >> 2] | 0) | 0) | 0;
	                                c[m >> 2] = (c[m >> 2] | 0) + 1
	                            }
	                            c[(c[h >> 2] | 0) + 64 >> 2] = c[x >> 2]
	                        } while (0)
	                    } while ((c[w >> 2] | 0) == 1);
	                    if ((R | 0) == 169)c[w >> 2] = 0;
	                    if (c[x >> 2] | 0)NN(c[h >> 2] | 0, c[x >> 2] | 0);
	                    c[(c[h >> 2] | 0) + 64 >> 2] = c[y >> 2];
	                    c[(c[h >> 2] | 0) + 28 >> 2] = c[o >> 2];
	                    c[l >> 2] = 0
	                } while (0);
	                o = (c[h >> 2] | 0) + 32 | 0;
	                c[o >> 2] = (c[o >> 2] | 0) + -1;
	                c[g >> 2] = c[l >> 2];
	                O = c[g >> 2] | 0;
	                i = e;
	                return O | 0
	            }

	            function lO(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 20 | 0;
	                h = e + 16 | 0;
	                j = e + 12 | 0;
	                k = e + 8 | 0;
	                l = e + 4 | 0;
	                m = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if ((c[j >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) {
	                    c[f >> 2] = -1;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                do if ((c[c[h >> 2] >> 2] | 0) >= (c[(c[h >> 2] | 0) + 4 >> 2] | 0)) {
	                    c[m >> 2] = c[(c[h >> 2] | 0) + 4 >> 2] << 1;
	                    c[l >> 2] = Hb[c[135760 >> 2] & 511](c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[m >> 2] << 2) | 0;
	                    if (c[l >> 2] | 0) {
	                        c[(c[h >> 2] | 0) + 8 >> 2] = c[l >> 2];
	                        c[(c[h >> 2] | 0) + 4 >> 2] = c[m >> 2];
	                        break
	                    }
	                    MN(c[g >> 2] | 0, 189520);
	                    c[f >> 2] = -1;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                } while (0);
	                c[k >> 2] = 0;
	                while (1) {
	                    if ((c[k >> 2] | 0) >= (c[c[h >> 2] >> 2] | 0)) {
	                        o = 12;
	                        break
	                    }
	                    if (TO(c[g >> 2] | 0, c[j >> 2] | 0, c[(c[(c[h >> 2] | 0) + 8 >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) | 0) {
	                        o = 10;
	                        break
	                    }
	                    c[k >> 2] = (c[k >> 2] | 0) + 1
	                }
	                if ((o | 0) == 10) {
	                    LN(c[g >> 2] | 0, c[j >> 2] | 0);
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                } else if ((o | 0) == 12) {
	                    o = c[j >> 2] | 0;
	                    j = c[h >> 2] | 0;
	                    g = c[j >> 2] | 0;
	                    c[j >> 2] = g + 1;
	                    c[(c[(c[h >> 2] | 0) + 8 >> 2] | 0) + (g << 2) >> 2] = o;
	                    c[f >> 2] = 1;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                return 0
	            }

	            function mO(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 80 >> 2] | 0) != 0 : 0) ? (c[(c[f >> 2] | 0) + 72 >> 2] | 0) > 0 : 0) {
	                    b = (c[f >> 2] | 0) + 72 | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + -1;
	                    c[h >> 2] = c[(c[(c[f >> 2] | 0) + 80 >> 2] | 0) + (c[(c[f >> 2] | 0) + 72 >> 2] << 2) >> 2];
	                    c[c[h >> 2] >> 2] = 0;
	                    c[e >> 2] = c[h >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                if ((c[g >> 2] | 0) < 16)c[g >> 2] = 16;
	                c[h >> 2] = Cb[c[135744 >> 2] & 511](12 + ((c[g >> 2] | 0) - 1 << 2) | 0) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    MN(c[f >> 2] | 0, 189568);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[c[h >> 2] >> 2] = 0;
	                c[(c[h >> 2] | 0) + 4 >> 2] = c[g >> 2];
	                b = Cb[c[135744 >> 2] & 511](c[g >> 2] << 2) | 0;
	                c[(c[h >> 2] | 0) + 8 >> 2] = b;
	                if (!(c[(c[h >> 2] | 0) + 8 >> 2] | 0)) {
	                    MN(c[f >> 2] | 0, 189568);
	                    zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } else {
	                    c[e >> 2] = c[h >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                return 0
	            }

	            function nO(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (!(c[j >> 2] | 0)) {
	                    c[f >> 2] = -1;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                do if ((c[c[h >> 2] >> 2] | 0) >= (c[(c[h >> 2] | 0) + 4 >> 2] | 0)) {
	                    c[l >> 2] = c[(c[h >> 2] | 0) + 4 >> 2] << 1;
	                    c[k >> 2] = Hb[c[135760 >> 2] & 511](c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[l >> 2] << 2) | 0;
	                    if (c[k >> 2] | 0) {
	                        c[(c[h >> 2] | 0) + 8 >> 2] = c[k >> 2];
	                        c[(c[h >> 2] | 0) + 4 >> 2] = c[l >> 2];
	                        break
	                    }
	                    MN(c[g >> 2] | 0, 189520);
	                    c[f >> 2] = -1;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                } while (0);
	                g = c[j >> 2] | 0;
	                j = c[h >> 2] | 0;
	                l = c[j >> 2] | 0;
	                c[j >> 2] = l + 1;
	                c[(c[(c[h >> 2] | 0) + 8 >> 2] | 0) + (l << 2) >> 2] = g;
	                c[f >> 2] = 1;
	                m = c[f >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function oO(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                while (1) {
	                    do if (c[f >> 2] | 0)if ((((c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 8 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 7 : 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 19 : 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 20 : 0) {
	                        if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 3 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 4 : 0) {
	                            g = 0;
	                            break
	                        }
	                        if (!(c[(c[e >> 2] | 0) + 28 >> 2] & 4))g = (sO(c[(c[f >> 2] | 0) + 40 >> 2] | 0) | 0) != 0; else g = 1
	                    } else g = 1; else g = 0; while (0);
	                    h = c[f >> 2] | 0;
	                    if (!g)break;
	                    c[f >> 2] = c[h + 24 >> 2]
	                }
	                i = d;
	                return h | 0
	            }

	            function pO(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = c[(c[g >> 2] | 0) + 44 >> 2];
	                while (1) {
	                    if (!(c[h >> 2] | 0))break;
	                    c[j >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                    if (!((c[(c[h >> 2] | 0) + 36 >> 2] | 0) != 0 ? (qy(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) == 0 : 0))m = 5;
	                    do if ((m | 0) == 5) {
	                        m = 0;
	                        if (qy(c[(c[h >> 2] | 0) + 8 >> 2] | 0, 192176) | 0) {
	                            if (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 189864) | 0)break;
	                            if (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 189904) | 0)break;
	                            if (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 189928) | 0)break;
	                            if (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 189952) | 0)break;
	                            if (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 190064) | 0)break;
	                            if (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 195016) | 0)break;
	                            zN(c[f >> 2] | 0, c[g >> 2] | 0, 1034, 196520, c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0);
	                            break
	                        }
	                        if (qy(c[(c[h >> 2] | 0) + 8 >> 2] | 0, 192784) | 0) {
	                            if (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 189888) | 0)break;
	                            if (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 192360) | 0)break;
	                            zN(c[f >> 2] | 0, c[g >> 2] | 0, 1034, 196520, c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0);
	                            break
	                        }
	                        if (qy(c[(c[h >> 2] | 0) + 8 >> 2] | 0, 195400) | 0) {
	                            if (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 189936) | 0)break;
	                            if (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 195024) | 0)break;
	                            zN(c[f >> 2] | 0, c[g >> 2] | 0, 1034, 196520, c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0);
	                            break
	                        }
	                        if (qy(c[(c[h >> 2] | 0) + 8 >> 2] | 0, 194568) | 0) {
	                            if (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 190048) | 0)break;
	                            if (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 195016) | 0)break;
	                            zN(c[f >> 2] | 0, c[g >> 2] | 0, 1034, 196520, c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0);
	                            break
	                        }
	                        if (!(qy(c[(c[h >> 2] | 0) + 8 >> 2] | 0, 193160) | 0)) {
	                            if (qy(c[(c[h >> 2] | 0) + 8 >> 2] | 0, 192672) | 0)break;
	                            zN(c[f >> 2] | 0, c[g >> 2] | 0, 1113, 196680, c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0);
	                            break
	                        }
	                        c[k >> 2] = _h(c[(c[g >> 2] | 0) + 32 >> 2] | 0, c[(c[h >> 2] | 0) + 12 >> 2] | 0, 1) | 0;
	                        if (c[k >> 2] | 0) {
	                            do if (d[c[k >> 2] >> 0] | 0) {
	                                c[l >> 2] = yl(c[k >> 2] | 0) | 0;
	                                if (!(c[l >> 2] | 0)) {
	                                    zN(c[f >> 2] | 0, c[g >> 2] | 0, 1050, 196560, c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[k >> 2] | 0);
	                                    break
	                                }
	                                if (!(c[c[l >> 2] >> 2] | 0))zN(c[f >> 2] | 0, c[g >> 2] | 0, 1118, 196600, c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[k >> 2] | 0);
	                                if (c[(c[l >> 2] | 0) + 32 >> 2] | 0)zN(c[f >> 2] | 0, c[g >> 2] | 0, 1117, 196640, c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[k >> 2] | 0);
	                                Al(c[l >> 2] | 0)
	                            } while (0);
	                            zb[c[135736 >> 2] & 511](c[k >> 2] | 0)
	                        }
	                    } while (0);
	                    c[h >> 2] = c[j >> 2]
	                }
	                i = e;
	                return
	            }

	            function qO(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 28 | 0;
	                g = e + 24 | 0;
	                h = e + 20 | 0;
	                j = e + 16 | 0;
	                k = e + 12 | 0;
	                l = e + 8 | 0;
	                m = e + 4 | 0;
	                n = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 0;
	                c[n >> 2] = 0;
	                while (1) {
	                    if ((c[n >> 2] | 0) >= (c[(c[g >> 2] | 0) + 100 >> 2] | 0))break;
	                    if (qy(c[(c[(c[(c[g >> 2] | 0) + 108 >> 2] | 0) + (c[n >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0, c[h >> 2] | 0) | 0) {
	                        o = 4;
	                        break
	                    }
	                    c[n >> 2] = (c[n >> 2] | 0) + 1
	                }
	                if ((o | 0) == 4) {
	                    zN(c[g >> 2] | 0, 0, 1033, 196408, c[h >> 2] | 0, 0);
	                    c[f >> 2] = 0;
	                    p = c[f >> 2] | 0;
	                    i = e;
	                    return p | 0
	                }
	                c[l >> 2] = gg(c[h >> 2] | 0, 0, 0) | 0;
	                if (!(c[l >> 2] | 0)) {
	                    zN(c[g >> 2] | 0, 0, 1065, 196056, c[h >> 2] | 0, 0);
	                    c[f >> 2] = 0;
	                    p = c[f >> 2] | 0;
	                    i = e;
	                    return p | 0
	                }
	                c[k >> 2] = Cb[c[135744 >> 2] & 511](24) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    zN(c[g >> 2] | 0, c[l >> 2] | 0, 2, 196456, c[h >> 2] | 0, 0);
	                    Th(c[l >> 2] | 0);
	                    c[f >> 2] = 0;
	                    p = c[f >> 2] | 0;
	                    i = e;
	                    return p | 0
	                }
	                o = c[k >> 2] | 0;
	                c[o + 0 >> 2] = 0;
	                c[o + 4 >> 2] = 0;
	                c[o + 8 >> 2] = 0;
	                c[o + 12 >> 2] = 0;
	                c[o + 16 >> 2] = 0;
	                c[o + 20 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 8 >> 2] = c[l >> 2];
	                o = my(c[h >> 2] | 0) | 0;
	                c[(c[k >> 2] | 0) + 4 >> 2] = o;
	                c[c[k >> 2] >> 2] = c[(c[g >> 2] | 0) + 60 >> 2];
	                c[(c[k >> 2] | 0) + 20 >> 2] = 1;
	                c[(c[g >> 2] | 0) + 60 >> 2] = c[k >> 2];
	                if (((c[j >> 2] | 0) != 0 ? (c[m >> 2] = Pi(c[l >> 2] | 0) | 0, (c[m >> 2] | 0) != 0) : 0) ? (dj(c[m >> 2] | 0, 192672) | 0) == 0 : 0)gj(c[m >> 2] | 0, 192672, c[j >> 2] | 0) | 0;
	                UO(c[g >> 2] | 0, c[k >> 2] | 0) | 0;
	                c[l >> 2] = AN(c[g >> 2] | 0, c[l >> 2] | 0) | 0;
	                j = c[g >> 2] | 0;
	                if (!(c[l >> 2] | 0)) {
	                    c[j + 96 >> 2] = 0;
	                    c[f >> 2] = 0;
	                    p = c[f >> 2] | 0;
	                    i = e;
	                    return p | 0
	                } else {
	                    VO(j) | 0;
	                    c[f >> 2] = c[k >> 2];
	                    p = c[f >> 2] | 0;
	                    i = e;
	                    return p | 0
	                }
	                return 0
	            }

	            function rO(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                f = i;
	                i = i + 64 | 0;
	                g = f + 48 | 0;
	                h = f + 44 | 0;
	                j = f + 40 | 0;
	                k = f + 36 | 0;
	                l = f + 32 | 0;
	                m = f + 28 | 0;
	                n = f + 24 | 0;
	                o = f + 20 | 0;
	                p = f + 16 | 0;
	                q = f + 12 | 0;
	                r = f + 8 | 0;
	                s = f + 4 | 0;
	                t = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = 0;
	                c[o >> 2] = 0;
	                while (1) {
	                    if ((c[o >> 2] | 0) >= (c[(c[h >> 2] | 0) + 116 >> 2] | 0))break;
	                    if (qy(c[(c[(c[(c[h >> 2] | 0) + 124 >> 2] | 0) + (c[o >> 2] << 2) >> 2] | 0) + 4 >> 2] | 0, c[j >> 2] | 0) | 0) {
	                        u = 4;
	                        break
	                    }
	                    c[o >> 2] = (c[o >> 2] | 0) + 1
	                }
	                if ((u | 0) == 4) {
	                    zN(c[h >> 2] | 0, 0, 1044, 196016, c[j >> 2] | 0, 0);
	                    c[g >> 2] = 0;
	                    v = c[g >> 2] | 0;
	                    i = f;
	                    return v | 0
	                }
	                c[n >> 2] = gg(c[j >> 2] | 0, 0, 0) | 0;
	                if (!(c[n >> 2] | 0)) {
	                    zN(c[h >> 2] | 0, c[k >> 2] | 0, 1065, 196056, c[j >> 2] | 0, 0);
	                    c[g >> 2] = 0;
	                    v = c[g >> 2] | 0;
	                    i = f;
	                    return v | 0
	                }
	                c[m >> 2] = Cb[c[135744 >> 2] & 511](20) | 0;
	                if (!(c[m >> 2] | 0)) {
	                    xN(c[h >> 2] | 0, 196088);
	                    Th(c[n >> 2] | 0);
	                    c[g >> 2] = 0;
	                    v = c[g >> 2] | 0;
	                    i = f;
	                    return v | 0
	                }
	                o = c[m >> 2] | 0;
	                c[o + 0 >> 2] = 0;
	                c[o + 4 >> 2] = 0;
	                c[o + 8 >> 2] = 0;
	                c[o + 12 >> 2] = 0;
	                c[o + 16 >> 2] = 0;
	                c[(c[m >> 2] | 0) + 8 >> 2] = c[n >> 2];
	                o = my(c[j >> 2] | 0) | 0;
	                c[(c[m >> 2] | 0) + 4 >> 2] = o;
	                c[c[m >> 2] >> 2] = c[(c[h >> 2] | 0) + 64 >> 2];
	                c[(c[h >> 2] | 0) + 64 >> 2] = c[m >> 2];
	                if (((c[l >> 2] | 0) != 0 ? (c[p >> 2] = Pi(c[n >> 2] | 0) | 0, (c[p >> 2] | 0) != 0) : 0) ? (dj(c[p >> 2] | 0, 192672) | 0) == 0 : 0)gj(c[p >> 2] | 0, 192672, c[l >> 2] | 0) | 0;
	                WO(c[h >> 2] | 0, c[m >> 2] | 0) | 0;
	                c[n >> 2] = AN(c[h >> 2] | 0, c[n >> 2] | 0) | 0;
	                l = c[h >> 2] | 0;
	                if (!(c[n >> 2] | 0)) {
	                    c[l + 112 >> 2] = 0;
	                    c[g >> 2] = 0;
	                    v = c[g >> 2] | 0;
	                    i = f;
	                    return v | 0
	                }
	                XO(l) | 0;
	                c[p >> 2] = Pi(c[n >> 2] | 0) | 0;
	                if (!(c[p >> 2] | 0)) {
	                    zN(c[h >> 2] | 0, c[k >> 2] | 0, 1022, 196112, c[j >> 2] | 0, 0);
	                    c[g >> 2] = 0;
	                    v = c[g >> 2] | 0;
	                    i = f;
	                    return v | 0
	                }
	                if (((((c[p >> 2] | 0) != 0 ? (c[(c[p >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[p >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[p >> 2] | 0) + 8 >> 2] | 0, 190264) | 0) != 0 : 0) ? (qy(c[(c[(c[p >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                    c[q >> 2] = c[(c[k >> 2] | 0) + 12 >> 2];
	                    while (1) {
	                        if (!(c[q >> 2] | 0))break;
	                        if (((((c[q >> 2] | 0) != 0 ? (c[(c[q >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[q >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[q >> 2] | 0) + 8 >> 2] | 0, 190048) | 0) != 0 : 0) ? (qy(c[(c[(c[q >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                            c[r >> 2] = 0;
	                            c[r >> 2] = YO(c[h >> 2] | 0, c[j >> 2] | 0, c[(c[p >> 2] | 0) + 12 >> 2] | 0, 0) | 0;
	                            if (!(c[r >> 2] | 0))zN(c[h >> 2] | 0, c[k >> 2] | 0, 1107, 196216, c[j >> 2] | 0, 0)
	                        } else u = 33;
	                        do if ((((((u | 0) == 33 ? (u = 0, (c[q >> 2] | 0) != 0) : 0) ? (c[(c[q >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[q >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[q >> 2] | 0) + 8 >> 2] | 0, 195016) | 0) != 0 : 0) ? (qy(c[(c[(c[q >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                            c[s >> 2] = Yi(c[q >> 2] | 0, 192176) | 0;
	                            if (!(c[s >> 2] | 0)) {
	                                zN(c[h >> 2] | 0, c[k >> 2] | 0, 1053, 196288, c[j >> 2] | 0, 0);
	                                break
	                            }
	                            ZO(c[s >> 2] | 0);
	                            c[t >> 2] = YO(c[h >> 2] | 0, c[j >> 2] | 0, c[(c[p >> 2] | 0) + 12 >> 2] | 0, c[s >> 2] | 0) | 0;
	                            if (!(c[t >> 2] | 0))zN(c[h >> 2] | 0, c[k >> 2] | 0, 1013, 196336, c[j >> 2] | 0, c[s >> 2] | 0);
	                            zb[c[135736 >> 2] & 511](c[s >> 2] | 0)
	                        } while (0);
	                        c[q >> 2] = c[(c[q >> 2] | 0) + 24 >> 2]
	                    }
	                    c[g >> 2] = c[m >> 2];
	                    v = c[g >> 2] | 0;
	                    i = f;
	                    return v | 0
	                }
	                zN(c[h >> 2] | 0, c[k >> 2] | 0, 1038, 196160, c[j >> 2] | 0, 0);
	                c[g >> 2] = 0;
	                v = c[g >> 2] | 0;
	                i = f;
	                return v | 0
	            }

	            function sO(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[f >> 2] = a;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 1;
	                    g = c[e >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a:while (1) {
	                    if (!(d[c[f >> 2] >> 0] | 0)) {
	                        h = 10;
	                        break
	                    }
	                    do if ((d[c[f >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[f >> 2] >> 0] | 0 | 0) ? (d[c[f >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[f >> 2] >> 0] | 0 | 0) != 13) {
	                            h = 8;
	                            break a
	                        }
	                    } while (0);
	                    c[f >> 2] = (c[f >> 2] | 0) + 1
	                }
	                if ((h | 0) == 8) {
	                    c[e >> 2] = 0;
	                    g = c[e >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else if ((h | 0) == 10) {
	                    c[e >> 2] = 1;
	                    g = c[e >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function tO(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                if (!(c[g >> 2] | 0)) {
	                    zN(c[f >> 2] | 0, c[g >> 2] | 0, 1037, 194984, 0, 0);
	                    c[e >> 2] = -1;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                while (1) {
	                    if (!(c[g >> 2] | 0))break;
	                    do if (((((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 190048) | 0) != 0 : 0) ? (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                        b = c[f >> 2] | 0;
	                        a = c[g >> 2] | 0;
	                        if (!(c[(c[g >> 2] | 0) + 12 >> 2] | 0)) {
	                            zN(b, a, 1106, 191968, 0, 0);
	                            break
	                        }
	                        c[j >> 2] = YN(b, c[a + 12 >> 2] | 0) | 0;
	                        if (c[j >> 2] | 0)c[h >> 2] = -1
	                    } else l = 13; while (0);
	                    do if ((l | 0) == 13) {
	                        l = 0;
	                        if (((((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 195016) | 0) != 0 : 0) ? (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                            c[j >> 2] = _O(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                            if (!(c[j >> 2] | 0))break;
	                            c[h >> 2] = -1;
	                            break
	                        }
	                        if (((((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 195024) | 0) != 0 : 0) ? (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                            c[j >> 2] = $O(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                            if (!(c[j >> 2] | 0))break;
	                            c[h >> 2] = -1;
	                            break
	                        }
	                        zN(c[f >> 2] | 0, c[g >> 2] | 0, 1036, 195032, c[(c[g >> 2] | 0) + 8 >> 2] | 0, 0);
	                        c[h >> 2] = -1
	                    } while (0);
	                    c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2]
	                }
	                c[e >> 2] = c[h >> 2];
	                k = c[e >> 2] | 0;
	                i = d;
	                return k | 0
	            }

	            function uO(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                d = i;
	                i = i + 64 | 0;
	                e = d;
	                f = d + 28 | 0;
	                g = d + 24 | 0;
	                h = d + 20 | 0;
	                j = d + 16 | 0;
	                k = d + 12 | 0;
	                l = d + 8 | 0;
	                m = d + 4 | 0;
	                n = d + 32 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[k >> 2] = -1;
	                c[l >> 2] = 0;
	                c[h >> 2] = c[(c[g >> 2] | 0) + 12 >> 2];
	                if (!(c[h >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if (!(c[(c[h >> 2] | 0) + 32 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                c[m >> 2] = c[h >> 2];
	                while (1) {
	                    if (!(c[m >> 2] | 0))break;
	                    if (((c[(c[m >> 2] | 0) + 4 >> 2] | 0) != 0 ? (c[(c[(c[m >> 2] | 0) + 4 >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) ? (qy(c[(c[(c[(c[m >> 2] | 0) + 4 >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0, 190048) | 0) != 0 : 0)c[j >> 2] = Yi(c[(c[(c[m >> 2] | 0) + 4 >> 2] | 0) + 20 >> 2] | 0, 194568) | 0; else {
	                        c[j >> 2] = 0;
	                        zN(c[f >> 2] | 0, c[(c[m >> 2] | 0) + 4 >> 2] | 0, 1107, 194784, 0, 0)
	                    }
	                    do if (!(c[j >> 2] | 0))if (!(c[l >> 2] | 0)) {
	                        c[l >> 2] = 1;
	                        break
	                    } else {
	                        zN(c[f >> 2] | 0, c[(c[m >> 2] | 0) + 4 >> 2] | 0, 1054, 194928, 0, 0);
	                        break
	                    } else {
	                        do if (qy(c[j >> 2] | 0, 190016) | 0) {
	                            if ((c[k >> 2] | 0) == -1) {
	                                c[k >> 2] = 1;
	                                break
	                            }
	                            if (!(c[k >> 2] | 0))zN(c[f >> 2] | 0, c[(c[m >> 2] | 0) + 4 >> 2] | 0, 1104, 194832, 0, 0)
	                        } else {
	                            if (!(qy(c[j >> 2] | 0, 190032) | 0)) {
	                                zN(c[f >> 2] | 0, c[(c[m >> 2] | 0) + 4 >> 2] | 0, 1114, 194880, c[j >> 2] | 0, 0);
	                                break
	                            }
	                            if ((c[k >> 2] | 0) == -1) {
	                                c[k >> 2] = 0;
	                                break
	                            }
	                            if ((c[k >> 2] | 0) == 1)zN(c[f >> 2] | 0, c[(c[m >> 2] | 0) + 4 >> 2] | 0, 1104, 194832, 0, 0)
	                        } while (0);
	                        zb[c[135736 >> 2] & 511](c[j >> 2] | 0)
	                    } while (0);
	                    c[m >> 2] = c[(c[m >> 2] | 0) + 32 >> 2]
	                }
	                if ((c[k >> 2] | 0) == -1)c[k >> 2] = 0;
	                c[m >> 2] = DN(c[f >> 2] | 0, c[(c[h >> 2] | 0) + 4 >> 2] | 0) | 0;
	                if (!(c[m >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                h = c[m >> 2] | 0;
	                if (!(c[k >> 2] | 0))c[h >> 2] = 19; else c[h >> 2] = 17;
	                c[(c[m >> 2] | 0) + 24 >> 2] = c[(c[g >> 2] | 0) + 12 >> 2];
	                c[(c[g >> 2] | 0) + 12 >> 2] = c[m >> 2];
	                if (c[k >> 2] | 0) {
	                    i = d;
	                    return
	                }
	                if (!(c[(c[f >> 2] | 0) + 56 >> 2] | 0)) {
	                    k = Ij(10) | 0;
	                    c[(c[f >> 2] | 0) + 56 >> 2] = k
	                }
	                if (!(c[(c[f >> 2] | 0) + 56 >> 2] | 0)) {
	                    zN(c[f >> 2] | 0, c[(c[m >> 2] | 0) + 4 >> 2] | 0, 1046, 194736, 0, 0);
	                    i = d;
	                    return
	                }
	                k = (c[f >> 2] | 0) + 52 | 0;
	                g = c[k >> 2] | 0;
	                c[k >> 2] = g + 1;
	                c[e >> 2] = g;
	                JT(n, 32, 192704, e) | 0;
	                if ((Lj(c[(c[f >> 2] | 0) + 56 >> 2] | 0, n, c[m >> 2] | 0) | 0) >= 0) {
	                    i = d;
	                    return
	                }
	                zN(c[f >> 2] | 0, c[(c[m >> 2] | 0) + 4 >> 2] | 0, 1046, 192720, n, 0);
	                i = d;
	                return
	            }

	            function vO(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                e = i;
	                i = i + 80 | 0;
	                f = e;
	                g = e + 40 | 0;
	                h = e + 36 | 0;
	                j = e + 32 | 0;
	                k = e + 28 | 0;
	                l = e + 24 | 0;
	                m = e + 20 | 0;
	                n = e + 16 | 0;
	                o = e + 12 | 0;
	                p = e + 8 | 0;
	                q = e + 4 | 0;
	                r = e + 48 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[l >> 2] = -1;
	                c[m >> 2] = 0;
	                if (!(c[(c[g >> 2] | 0) + 44 >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                c[n >> 2] = c[g >> 2];
	                while (1) {
	                    if (!(c[n >> 2] | 0))break;
	                    c[k >> 2] = Yi(c[(c[n >> 2] | 0) + 4 >> 2] | 0, 194568) | 0;
	                    do if (!(c[k >> 2] | 0))if (!(c[m >> 2] | 0)) {
	                        c[m >> 2] = 1;
	                        break
	                    } else {
	                        zN(c[h >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] | 0, 1054, 194680, c[j >> 2] | 0, 0);
	                        break
	                    } else {
	                        do if (qy(c[k >> 2] | 0, 190016) | 0) {
	                            if ((c[l >> 2] | 0) == -1) {
	                                c[l >> 2] = 1;
	                                break
	                            }
	                            if (!(c[l >> 2] | 0))zN(c[h >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] | 0, 1010, 194576, c[j >> 2] | 0, 0)
	                        } else {
	                            if (!(qy(c[k >> 2] | 0, 190032) | 0)) {
	                                zN(c[h >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] | 0, 1114, 194632, c[j >> 2] | 0, c[k >> 2] | 0);
	                                break
	                            }
	                            if ((c[l >> 2] | 0) == -1) {
	                                c[l >> 2] = 0;
	                                break
	                            }
	                            if ((c[l >> 2] | 0) == 1)zN(c[h >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] | 0, 1010, 194576, c[j >> 2] | 0, 0)
	                        } while (0);
	                        zb[c[135736 >> 2] & 511](c[k >> 2] | 0)
	                    } while (0);
	                    c[n >> 2] = c[(c[n >> 2] | 0) + 44 >> 2]
	                }
	                if ((c[l >> 2] | 0) == -1)c[l >> 2] = 0;
	                c[n >> 2] = DN(c[h >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] | 0) | 0;
	                if (!(c[n >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                k = c[n >> 2] | 0;
	                if (!(c[l >> 2] | 0))c[k >> 2] = 19; else c[k >> 2] = 17;
	                c[p >> 2] = c[g >> 2];
	                c[o >> 2] = 0;
	                while (1) {
	                    if (!(c[p >> 2] | 0))break;
	                    if (c[(c[p >> 2] | 0) + 24 >> 2] | 0) {
	                        if (c[(c[(c[p >> 2] | 0) + 24 >> 2] | 0) + 32 >> 2] | 0) {
	                            c[q >> 2] = DN(c[h >> 2] | 0, c[(c[(c[p >> 2] | 0) + 24 >> 2] | 0) + 4 >> 2] | 0) | 0;
	                            if (!(c[q >> 2] | 0))break;
	                            c[c[q >> 2] >> 2] = 18;
	                            c[(c[q >> 2] | 0) + 24 >> 2] = c[(c[p >> 2] | 0) + 24 >> 2]
	                        } else c[q >> 2] = c[(c[p >> 2] | 0) + 24 >> 2];
	                        k = c[q >> 2] | 0;
	                        if (!(c[o >> 2] | 0))c[(c[n >> 2] | 0) + 24 >> 2] = k; else c[(c[o >> 2] | 0) + 32 >> 2] = k;
	                        c[o >> 2] = c[q >> 2]
	                    }
	                    c[(c[p >> 2] | 0) + 24 >> 2] = c[n >> 2];
	                    c[p >> 2] = c[(c[p >> 2] | 0) + 44 >> 2]
	                }
	                c[(c[g >> 2] | 0) + 24 >> 2] = c[n >> 2];
	                if (c[l >> 2] | 0) {
	                    i = e;
	                    return
	                }
	                if (!(c[(c[h >> 2] | 0) + 56 >> 2] | 0)) {
	                    l = Ij(10) | 0;
	                    c[(c[h >> 2] | 0) + 56 >> 2] = l
	                }
	                if (!(c[(c[h >> 2] | 0) + 56 >> 2] | 0)) {
	                    zN(c[h >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] | 0, 1046, 194736, 0, 0);
	                    i = e;
	                    return
	                }
	                l = (c[h >> 2] | 0) + 52 | 0;
	                p = c[l >> 2] | 0;
	                c[l >> 2] = p + 1;
	                c[f >> 2] = p;
	                JT(r, 32, 192704, f) | 0;
	                if ((Lj(c[(c[h >> 2] | 0) + 56 >> 2] | 0, r, c[n >> 2] | 0) | 0) >= 0) {
	                    i = e;
	                    return
	                }
	                zN(c[h >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] | 0, 1046, 192720, r, 0);
	                i = e;
	                return
	            }

	            function wO(a, d, e) {
	                a = a | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[g >> 2] = a;
	                c[h >> 2] = d;
	                c[j >> 2] = e;
	                if (b[(c[g >> 2] | 0) + 50 >> 1] & 256) {
	                    i = f;
	                    return
	                }
	                c[k >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                if (!(c[k >> 2] | 0)) {
	                    zN(c[h >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] | 0, 1, 194400, c[j >> 2] | 0, 0);
	                    i = f;
	                    return
	                }
	                if (c[(c[g >> 2] | 0) + 24 >> 2] | 0) {
	                    zN(c[h >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] | 0, 1, 194456, c[j >> 2] | 0, 0);
	                    i = f;
	                    return
	                }
	                if (!(c[(c[k >> 2] | 0) + 24 >> 2] | 0)) {
	                    zN(c[h >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] | 0, 1101, 194520, c[j >> 2] | 0, 0);
	                    i = f;
	                    return
	                }
	                c[l >> 2] = Rj(c[(c[k >> 2] | 0) + 24 >> 2] | 0, c[j >> 2] | 0) | 0;
	                if (!(c[l >> 2] | 0)) {
	                    zN(c[h >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] | 0, 1101, 194520, c[j >> 2] | 0, 0);
	                    i = f;
	                    return
	                }
	                c[m >> 2] = c[g >> 2];
	                while (1) {
	                    if (!(c[m >> 2] | 0))break;
	                    c[(c[m >> 2] | 0) + 24 >> 2] = c[l >> 2];
	                    c[m >> 2] = c[(c[m >> 2] | 0) + 44 >> 2]
	                }
	                i = f;
	                return
	            }

	            function xO(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 20 | 0;
	                h = e + 16 | 0;
	                j = e + 12 | 0;
	                k = e + 8 | 0;
	                l = e + 4 | 0;
	                m = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = 0;
	                c[k >> 2] = 0;
	                c[m >> 2] = c[(c[f >> 2] | 0) + 48 >> 2];
	                while (1) {
	                    if (!(c[g >> 2] | 0))break;
	                    if (((((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 189864) | 0) != 0 : 0) ? (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                        c[l >> 2] = aP(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                        if (!(c[j >> 2] | 0)) {
	                            d = c[l >> 2] | 0;
	                            c[k >> 2] = d;
	                            c[j >> 2] = d
	                        } else {
	                            if (((c[h >> 2] | 0) == 1 ? (c[c[j >> 2] >> 2] | 0) == 4 : 0) ? (c[j >> 2] | 0) == (c[k >> 2] | 0) : 0) {
	                                c[j >> 2] = DN(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                                c[c[j >> 2] >> 2] = 18;
	                                c[(c[j >> 2] | 0) + 24 >> 2] = c[k >> 2]
	                            }
	                            c[(c[k >> 2] | 0) + 32 >> 2] = c[l >> 2];
	                            c[k >> 2] = c[l >> 2]
	                        }
	                        c[(c[l >> 2] | 0) + 28 >> 2] = c[m >> 2]
	                    } else n = 16;
	                    do if ((n | 0) == 16 ? (n = 0, c[l >> 2] = bP(c[f >> 2] | 0, c[g >> 2] | 0) | 0, (c[l >> 2] | 0) != 0) : 0) {
	                        d = c[l >> 2] | 0;
	                        if (!(c[j >> 2] | 0)) {
	                            c[k >> 2] = d;
	                            c[j >> 2] = d;
	                            break
	                        } else {
	                            c[(c[k >> 2] | 0) + 32 >> 2] = d;
	                            c[k >> 2] = c[l >> 2];
	                            break
	                        }
	                    } while (0);
	                    c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2]
	                }
	                i = e;
	                return c[j >> 2] | 0
	            }

	            function yO(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 8 | 0;
	                h = f + 4 | 0;
	                j = f;
	                c[f + 12 >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = e;
	                do if (!(c[j >> 2] | 0)) {
	                    if (!(c[h >> 2] | 0)) {
	                        c[c[g >> 2] >> 2] = -1;
	                        c[j >> 2] = c[g >> 2];
	                        break
	                    }
	                    if ((c[(c[h >> 2] | 0) + 24 >> 2] | 0) == (c[g >> 2] | 0)) {
	                        c[(c[h >> 2] | 0) + 24 >> 2] = c[(c[g >> 2] | 0) + 32 >> 2];
	                        break
	                    }
	                    if ((c[(c[h >> 2] | 0) + 36 >> 2] | 0) == (c[g >> 2] | 0)) {
	                        c[(c[h >> 2] | 0) + 36 >> 2] = c[(c[g >> 2] | 0) + 32 >> 2];
	                        break
	                    }
	                    if ((c[(c[h >> 2] | 0) + 40 >> 2] | 0) == (c[g >> 2] | 0))c[(c[h >> 2] | 0) + 40 >> 2] = c[(c[g >> 2] | 0) + 32 >> 2]
	                } else c[(c[j >> 2] | 0) + 32 >> 2] = c[(c[g >> 2] | 0) + 32 >> 2]; while (0);
	                i = f;
	                return c[j >> 2] | 0
	            }

	            function zO(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (c[(c[f >> 2] | 0) + 36 >> 2] | 0) {
	                    c[e >> 2] = -1;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                c[h >> 2] = 0;
	                c[j >> 2] = c[g >> 2];
	                a:while (1) {
	                    if (!(c[j >> 2] | 0)) {
	                        m = 36;
	                        break
	                    }
	                    if ((c[c[j >> 2] >> 2] | 0) == 4) {
	                        m = 12;
	                        break
	                    }
	                    if ((c[c[j >> 2] >> 2] | 0) == 3) {
	                        m = 12;
	                        break
	                    }
	                    if ((c[c[j >> 2] >> 2] | 0) == 5) {
	                        m = 12;
	                        break
	                    }
	                    if ((c[c[j >> 2] >> 2] | 0) == 6) {
	                        m = 12;
	                        break
	                    }
	                    if ((c[c[j >> 2] >> 2] | 0) == 8) {
	                        m = 12;
	                        break
	                    }
	                    if ((c[c[j >> 2] >> 2] | 0) == 7) {
	                        m = 12;
	                        break
	                    }
	                    if (!(c[c[j >> 2] >> 2] | 0)) {
	                        m = 12;
	                        break
	                    }
	                    if (!((((((((((c[c[j >> 2] >> 2] | 0) != 17 ? (c[c[j >> 2] >> 2] | 0) != 19 : 0) ? (c[c[j >> 2] >> 2] | 0) != 18 : 0) ? (c[c[j >> 2] >> 2] | 0) != 16 : 0) ? (c[c[j >> 2] >> 2] | 0) != 15 : 0) ? (c[c[j >> 2] >> 2] | 0) != 14 : 0) ? (c[c[j >> 2] >> 2] | 0) != 13 : 0) ? (c[c[j >> 2] >> 2] | 0) != 12 : 0) ? (c[c[j >> 2] >> 2] | 0) != 11 : 0) ? (c[c[j >> 2] >> 2] | 0) != 10 : 0))m = 23;
	                    if ((m | 0) == 23 ? (m = 0, (c[(c[j >> 2] | 0) + 24 >> 2] | 0) != 0) : 0) {
	                        c[h >> 2] = c[j >> 2];
	                        c[j >> 2] = c[(c[j >> 2] | 0) + 24 >> 2];
	                        c[k >> 2] = c[j >> 2];
	                        while (1) {
	                            if (!(c[k >> 2] | 0))continue a;
	                            c[(c[k >> 2] | 0) + 28 >> 2] = c[h >> 2];
	                            c[k >> 2] = c[(c[k >> 2] | 0) + 32 >> 2]
	                        }
	                    }
	                    if ((c[j >> 2] | 0) == (c[g >> 2] | 0)) {
	                        m = 36;
	                        break
	                    }
	                    if (c[(c[j >> 2] | 0) + 32 >> 2] | 0) {
	                        c[j >> 2] = c[(c[j >> 2] | 0) + 32 >> 2];
	                        continue
	                    }
	                    while (1) {
	                        c[j >> 2] = c[(c[j >> 2] | 0) + 28 >> 2];
	                        if (!(c[j >> 2] | 0))continue a;
	                        if ((c[j >> 2] | 0) == (c[g >> 2] | 0)) {
	                            m = 32;
	                            break a
	                        }
	                        n = c[j >> 2] | 0;
	                        if (c[(c[j >> 2] | 0) + 32 >> 2] | 0)break;
	                        if (!n)continue a
	                    }
	                    c[j >> 2] = c[n + 32 >> 2]
	                }
	                if ((m | 0) == 12) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                } else if ((m | 0) == 32) {
	                    c[e >> 2] = 1;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                } else if ((m | 0) == 36) {
	                    c[e >> 2] = 1;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                return 0
	            }

	            function AO(a, d) {
	                a = a | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 28 | 0;
	                g = e + 24 | 0;
	                h = e + 20 | 0;
	                j = e + 16 | 0;
	                k = e + 12 | 0;
	                l = e + 8 | 0;
	                m = e + 4 | 0;
	                n = e;
	                c[f >> 2] = a;
	                c[g >> 2] = d;
	                c[k >> 2] = 0;
	                if (!(c[g >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                if ((c[c[g >> 2] >> 2] | 0) != 18 ? (c[c[g >> 2] >> 2] | 0) != 4 : 0) {
	                    i = e;
	                    return
	                }
	                if (b[(c[g >> 2] | 0) + 50 >> 1] & 32) {
	                    i = e;
	                    return
	                }
	                if (c[(c[f >> 2] | 0) + 36 >> 2] | 0) {
	                    i = e;
	                    return
	                }
	                c[j >> 2] = c[(c[g >> 2] | 0) + 36 >> 2];
	                while (1) {
	                    if (!(c[j >> 2] | 0))break;
	                    c[k >> 2] = (c[k >> 2] | 0) + 1;
	                    c[j >> 2] = c[(c[j >> 2] | 0) + 32 >> 2]
	                }
	                c[j >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                while (1) {
	                    if (!(c[j >> 2] | 0))break;
	                    c[k >> 2] = (c[k >> 2] | 0) + 1;
	                    c[j >> 2] = c[(c[j >> 2] | 0) + 32 >> 2]
	                }
	                c[h >> 2] = Cb[c[135744 >> 2] & 511](c[k >> 2] << 2) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    xN(c[f >> 2] | 0, 191880);
	                    i = e;
	                    return
	                }
	                c[l >> 2] = 0;
	                c[j >> 2] = c[(c[g >> 2] | 0) + 36 >> 2];
	                while (1) {
	                    if (!(c[j >> 2] | 0))break;
	                    d = aO(c[f >> 2] | 0, c[j >> 2] | 0, 1) | 0;
	                    c[(c[h >> 2] | 0) + (c[l >> 2] << 2) >> 2] = d;
	                    c[l >> 2] = (c[l >> 2] | 0) + 1;
	                    c[j >> 2] = c[(c[j >> 2] | 0) + 32 >> 2]
	                }
	                c[j >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                while (1) {
	                    if (!(c[j >> 2] | 0))break;
	                    d = aO(c[f >> 2] | 0, c[j >> 2] | 0, 1) | 0;
	                    c[(c[h >> 2] | 0) + (c[l >> 2] << 2) >> 2] = d;
	                    c[l >> 2] = (c[l >> 2] | 0) + 1;
	                    c[j >> 2] = c[(c[j >> 2] | 0) + 32 >> 2]
	                }
	                c[l >> 2] = 0;
	                while (1) {
	                    if ((c[l >> 2] | 0) >= (c[k >> 2] | 0))break;
	                    a:do if (c[(c[h >> 2] | 0) + (c[l >> 2] << 2) >> 2] | 0) {
	                        c[m >> 2] = 0;
	                        while (1) {
	                            if ((c[m >> 2] | 0) >= (c[l >> 2] | 0))break a;
	                            if ((c[(c[h >> 2] | 0) + (c[m >> 2] << 2) >> 2] | 0) != 0 ? (c[n >> 2] = bO(c[f >> 2] | 0, c[(c[h >> 2] | 0) + (c[l >> 2] << 2) >> 2] | 0, c[(c[h >> 2] | 0) + (c[m >> 2] << 2) >> 2] | 0) | 0, (c[n >> 2] | 0) == 0) : 0)zN(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] | 0, 1040, 191896, 0, 0);
	                            c[m >> 2] = (c[m >> 2] | 0) + 1
	                        }
	                    } while (0);
	                    c[l >> 2] = (c[l >> 2] | 0) + 1
	                }
	                c[l >> 2] = 0;
	                while (1) {
	                    if ((c[l >> 2] | 0) >= (c[k >> 2] | 0))break;
	                    if (c[(c[h >> 2] | 0) + (c[l >> 2] << 2) >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[h >> 2] | 0) + (c[l >> 2] << 2) >> 2] | 0);
	                    c[l >> 2] = (c[l >> 2] | 0) + 1
	                }
	                zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                h = (c[g >> 2] | 0) + 50 | 0;
	                b[h >> 1] = b[h >> 1] | 32;
	                i = e;
	                return
	            }

	            function BO(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                do if (!((c[f >> 2] | 0) == -1 | (c[g >> 2] | 0) == -1)) {
	                    b = c[g >> 2] | 0;
	                    if (!(c[f >> 2] | 0)) {
	                        c[e >> 2] = b;
	                        break
	                    }
	                    a = c[f >> 2] | 0;
	                    if (!b) {
	                        c[e >> 2] = a;
	                        break
	                    }
	                    if ((a | 0) == 2 & (c[g >> 2] | 0) == 2) {
	                        c[e >> 2] = 2;
	                        break
	                    } else {
	                        c[e >> 2] = -1;
	                        break
	                    }
	                } else c[e >> 2] = -1; while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function CO(a, e) {
	                a = a | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                f = i;
	                i = i + 64 | 0;
	                g = f + 52 | 0;
	                h = f + 48 | 0;
	                j = f + 44 | 0;
	                k = f + 40 | 0;
	                l = f + 36 | 0;
	                m = f + 32 | 0;
	                n = f + 28 | 0;
	                o = f + 24 | 0;
	                p = f + 20 | 0;
	                q = f + 16 | 0;
	                r = f + 12 | 0;
	                s = f + 8 | 0;
	                t = f + 4 | 0;
	                u = f;
	                c[g >> 2] = a;
	                c[h >> 2] = e;
	                c[l >> 2] = 0;
	                c[p >> 2] = 0;
	                c[q >> 2] = 0;
	                c[r >> 2] = 0;
	                c[s >> 2] = 1;
	                if (!(c[h >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                if ((c[c[h >> 2] >> 2] | 0) != 17) {
	                    i = f;
	                    return
	                }
	                if (b[(c[h >> 2] | 0) + 50 >> 1] & 32) {
	                    i = f;
	                    return
	                }
	                if (c[(c[g >> 2] | 0) + 36 >> 2] | 0) {
	                    i = f;
	                    return
	                }
	                c[p >> 2] = cP(c[h >> 2] | 0) | 0;
	                c[k >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                while (1) {
	                    if (!(c[k >> 2] | 0))break;
	                    c[l >> 2] = (c[l >> 2] | 0) + 1;
	                    c[k >> 2] = c[(c[k >> 2] | 0) + 32 >> 2]
	                }
	                c[j >> 2] = Cb[c[135744 >> 2] & 511](c[l >> 2] << 2) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    xN(c[g >> 2] | 0, 191856);
	                    i = f;
	                    return
	                }
	                c[m >> 2] = 0;
	                if (!(c[p >> 2] | 0))c[r >> 2] = Ij(10) | 0; else c[s >> 2] = 0;
	                c[k >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                while (1) {
	                    if (!(c[k >> 2] | 0))break;
	                    p = aO(c[g >> 2] | 0, c[k >> 2] | 0, 0) | 0;
	                    c[(c[j >> 2] | 0) + (c[m >> 2] << 2) >> 2] = p;
	                    a:do if ((c[(c[j >> 2] | 0) + (c[m >> 2] << 2) >> 2] | 0) != 0 ? (c[c[(c[j >> 2] | 0) + (c[m >> 2] << 2) >> 2] >> 2] | 0) != 0 : 0) {
	                        if ((c[s >> 2] | 0) == 1) {
	                            c[t >> 2] = c[(c[j >> 2] | 0) + (c[m >> 2] << 2) >> 2];
	                            while (1) {
	                                if (!((c[s >> 2] | 0) == 1 ? (c[c[t >> 2] >> 2] | 0) != 0 : 0))break a;
	                                do if ((c[c[c[t >> 2] >> 2] >> 2] | 0) == 3) {
	                                    c[u >> 2] = Nj(c[r >> 2] | 0, 188096, 0, c[k >> 2] | 0) | 0;
	                                    if (c[u >> 2] | 0)c[s >> 2] = -1
	                                } else {
	                                    if ((c[c[c[t >> 2] >> 2] >> 2] | 0) == 4 ? (c[(c[c[t >> 2] >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                                        do if (!(c[(c[c[t >> 2] >> 2] | 0) + 12 >> 2] | 0))v = 28; else {
	                                            if (!(d[c[(c[c[t >> 2] >> 2] | 0) + 12 >> 2] >> 0] | 0)) {
	                                                v = 28;
	                                                break
	                                            }
	                                            c[u >> 2] = Nj(c[r >> 2] | 0, c[(c[c[t >> 2] >> 2] | 0) + 8 >> 2] | 0, c[(c[c[t >> 2] >> 2] | 0) + 12 >> 2] | 0, c[k >> 2] | 0) | 0
	                                        } while (0);
	                                        if ((v | 0) == 28) {
	                                            v = 0;
	                                            c[u >> 2] = Nj(c[r >> 2] | 0, c[(c[c[t >> 2] >> 2] | 0) + 8 >> 2] | 0, 0, c[k >> 2] | 0) | 0
	                                        }
	                                        if (!(c[u >> 2] | 0))break;
	                                        c[s >> 2] = -1;
	                                        break
	                                    }
	                                    if ((c[c[c[t >> 2] >> 2] >> 2] | 0) != 4) {
	                                        c[s >> 2] = -1;
	                                        break
	                                    }
	                                    do if (!(c[(c[c[t >> 2] >> 2] | 0) + 12 >> 2] | 0))v = 35; else {
	                                        if (!(d[c[(c[c[t >> 2] >> 2] | 0) + 12 >> 2] >> 0] | 0)) {
	                                            v = 35;
	                                            break
	                                        }
	                                        c[u >> 2] = Nj(c[r >> 2] | 0, 189536, c[(c[c[t >> 2] >> 2] | 0) + 12 >> 2] | 0, c[k >> 2] | 0) | 0
	                                    } while (0);
	                                    if ((v | 0) == 35) {
	                                        v = 0;
	                                        c[u >> 2] = Nj(c[r >> 2] | 0, 189536, 0, c[k >> 2] | 0) | 0
	                                    }
	                                    if (c[u >> 2] | 0)c[s >> 2] = -1
	                                } while (0);
	                                c[t >> 2] = (c[t >> 2] | 0) + 4
	                            }
	                        }
	                    } else v = 17; while (0);
	                    if ((v | 0) == 17) {
	                        v = 0;
	                        c[s >> 2] = 0
	                    }
	                    c[m >> 2] = (c[m >> 2] | 0) + 1;
	                    c[k >> 2] = c[(c[k >> 2] | 0) + 32 >> 2]
	                }
	                c[m >> 2] = 0;
	                while (1) {
	                    if ((c[m >> 2] | 0) >= (c[l >> 2] | 0))break;
	                    b:do if (c[(c[j >> 2] | 0) + (c[m >> 2] << 2) >> 2] | 0) {
	                        c[n >> 2] = 0;
	                        while (1) {
	                            if ((c[n >> 2] | 0) >= (c[m >> 2] | 0))break b;
	                            if ((c[(c[j >> 2] | 0) + (c[n >> 2] << 2) >> 2] | 0) != 0 ? (c[o >> 2] = bO(c[g >> 2] | 0, c[(c[j >> 2] | 0) + (c[m >> 2] << 2) >> 2] | 0, c[(c[j >> 2] | 0) + (c[n >> 2] << 2) >> 2] | 0) | 0, (c[o >> 2] | 0) == 0) : 0)c[q >> 2] = 1;
	                            c[n >> 2] = (c[n >> 2] | 0) + 1
	                        }
	                    } while (0);
	                    c[m >> 2] = (c[m >> 2] | 0) + 1
	                }
	                c[m >> 2] = 0;
	                while (1) {
	                    if ((c[m >> 2] | 0) >= (c[l >> 2] | 0))break;
	                    if (c[(c[j >> 2] | 0) + (c[m >> 2] << 2) >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[j >> 2] | 0) + (c[m >> 2] << 2) >> 2] | 0);
	                    c[m >> 2] = (c[m >> 2] | 0) + 1
	                }
	                zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                if (c[q >> 2] | 0) {
	                    q = (c[h >> 2] | 0) + 50 | 0;
	                    b[q >> 1] = b[q >> 1] | 4
	                }
	                if ((c[s >> 2] | 0) != 1) {
	                    if (c[r >> 2] | 0)Kj(c[r >> 2] | 0, 0)
	                } else {
	                    s = (c[h >> 2] | 0) + 50 | 0;
	                    b[s >> 1] = b[s >> 1] | 16;
	                    c[(c[h >> 2] | 0) + 20 >> 2] = c[r >> 2]
	                }
	                r = (c[h >> 2] | 0) + 50 | 0;
	                b[r >> 1] = b[r >> 1] | 32;
	                i = f;
	                return
	            }

	            function DO(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                do if (!((c[f >> 2] | 0) == -1 | (c[g >> 2] | 0) == -1)) {
	                    if ((c[f >> 2] | 0) == 1 | (c[g >> 2] | 0) == 1) {
	                        c[e >> 2] = 1;
	                        break
	                    }
	                    if ((c[f >> 2] | 0) == 2 | (c[g >> 2] | 0) == 2) {
	                        c[e >> 2] = 2;
	                        break
	                    } else {
	                        c[e >> 2] = 0;
	                        break
	                    }
	                } else c[e >> 2] = -1; while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function EO(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                e = i;
	                i = i + 240 | 0;
	                f = e;
	                g = e + 224 | 0;
	                h = e + 220 | 0;
	                j = e + 216 | 0;
	                k = e + 212 | 0;
	                l = e + 152 | 0;
	                m = e + 128 | 0;
	                n = e + 8 | 0;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = 1;
	                b = n + 0 | 0;
	                a = b + 116 | 0;
	                do {
	                    c[b >> 2] = 0;
	                    b = b + 4 | 0
	                } while ((b | 0) < (a | 0));
	                c[n + 28 >> 2] = 9;
	                do if ((c[c[h >> 2] >> 2] | 0) != 4 ? (c[c[h >> 2] >> 2] | 0) != 9 : 0) {
	                    if ((c[c[h >> 2] >> 2] | 0) != 3) {
	                        b = c[33976] | 0;
	                        a = c[33980] | 0;
	                        if ((c[c[h >> 2] >> 2] | 0) == 2) {
	                            c[f >> 2] = 189496;
	                            c[f + 4 >> 2] = 3822;
	                            Db[b & 511](a, 189464, f);
	                            c[k >> 2] = 0;
	                            break
	                        } else {
	                            c[f >> 2] = 189496;
	                            c[f + 4 >> 2] = 3824;
	                            Db[b & 511](a, 189464, f);
	                            c[k >> 2] = 0;
	                            break
	                        }
	                    }
	                    if ((c[c[j >> 2] >> 2] | 0) == 3) {
	                        c[g >> 2] = 0;
	                        o = c[g >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    } else {
	                        c[g >> 2] = 1;
	                        o = c[g >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    }
	                } else p = 3; while (0);
	                do if ((p | 0) == 3) {
	                    if ((c[c[j >> 2] >> 2] | 0) == 3) {
	                        c[g >> 2] = 1;
	                        o = c[g >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    }
	                    if (c[(c[h >> 2] | 0) + 8 >> 2] | 0)c[l + 8 >> 2] = c[(c[h >> 2] | 0) + 8 >> 2]; else c[l + 8 >> 2] = c[47556];
	                    do if (c[(c[h >> 2] | 0) + 12 >> 2] | 0) {
	                        a = l + 36 | 0;
	                        if (!(d[c[(c[h >> 2] | 0) + 12 >> 2] >> 0] | 0)) {
	                            c[a >> 2] = 0;
	                            break
	                        } else {
	                            c[a >> 2] = m;
	                            c[m + 8 >> 2] = c[(c[h >> 2] | 0) + 12 >> 2];
	                            break
	                        }
	                    } else c[l + 36 >> 2] = 0; while (0);
	                    if (!(MO(n, c[j >> 2] | 0, l) | 0)) {
	                        c[k >> 2] = 1;
	                        break
	                    }
	                    if (c[(c[h >> 2] | 0) + 40 >> 2] | 0) {
	                        c[k >> 2] = EO(c[(c[h >> 2] | 0) + 40 >> 2] | 0, c[j >> 2] | 0) | 0;
	                        break
	                    } else {
	                        c[k >> 2] = 0;
	                        break
	                    }
	                } while (0);
	                if (!(c[k >> 2] | 0)) {
	                    c[g >> 2] = c[k >> 2];
	                    o = c[g >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                if ((c[c[j >> 2] >> 2] | 0) != 4 ? (c[c[j >> 2] >> 2] | 0) != 9 : 0) {
	                    a = c[33976] | 0;
	                    b = c[33980] | 0;
	                    c[f >> 2] = 189496;
	                    c[f + 4 >> 2] = 3855;
	                    Db[a & 511](b, 189464, f);
	                    c[k >> 2] = 0
	                } else p = 29;
	                do if ((p | 0) == 29) {
	                    if (c[(c[j >> 2] | 0) + 8 >> 2] | 0)c[l + 8 >> 2] = c[(c[j >> 2] | 0) + 8 >> 2]; else c[l + 8 >> 2] = c[47556];
	                    c[l + 36 >> 2] = m;
	                    do if (c[(c[j >> 2] | 0) + 12 >> 2] | 0)if (!(d[c[(c[j >> 2] | 0) + 12 >> 2] >> 0] | 0)) {
	                        c[l + 36 >> 2] = 0;
	                        break
	                    } else {
	                        c[m + 8 >> 2] = c[(c[j >> 2] | 0) + 12 >> 2];
	                        break
	                    } else c[m + 8 >> 2] = c[47556]; while (0);
	                    if (!(MO(n, c[h >> 2] | 0, l) | 0)) {
	                        c[k >> 2] = 1;
	                        break
	                    }
	                    if (c[(c[j >> 2] | 0) + 40 >> 2] | 0) {
	                        c[k >> 2] = EO(c[(c[j >> 2] | 0) + 40 >> 2] | 0, c[h >> 2] | 0) | 0;
	                        break
	                    } else {
	                        c[k >> 2] = 0;
	                        break
	                    }
	                } while (0);
	                c[g >> 2] = c[k >> 2];
	                o = c[g >> 2] | 0;
	                i = e;
	                return o | 0
	            }

	            function FO(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                a:do if (!(c[e >> 2] | 0))c[d >> 2] = 189816; else do switch (c[c[e >> 2] >> 2] | 0) {
	                    case 10:
	                    {
	                        c[d >> 2] = 189920;
	                        break a;
	                        break
	                    }
	                    case 5:
	                    {
	                        c[d >> 2] = 189872;
	                        break a;
	                        break
	                    }
	                    case 17:
	                    {
	                        c[d >> 2] = 190016;
	                        break a;
	                        break
	                    }
	                    case 16:
	                    {
	                        c[d >> 2] = 19e4;
	                        break a;
	                        break
	                    }
	                    case 8:
	                    {
	                        c[d >> 2] = 189896;
	                        break a;
	                        break
	                    }
	                    case 13:
	                    {
	                        c[d >> 2] = 189952;
	                        break a;
	                        break
	                    }
	                    case 12:
	                    {
	                        c[d >> 2] = 189936;
	                        break a;
	                        break
	                    }
	                    case 6:
	                    {
	                        c[d >> 2] = 190064;
	                        break a;
	                        break
	                    }
	                    case 2:
	                    {
	                        c[d >> 2] = 189848;
	                        break a;
	                        break
	                    }
	                    case 19:
	                    {
	                        c[d >> 2] = 190032;
	                        break a;
	                        break
	                    }
	                    case 0:
	                    {
	                        c[d >> 2] = 189824;
	                        break a;
	                        break
	                    }
	                    case 15:
	                    {
	                        c[d >> 2] = 189984;
	                        break a;
	                        break
	                    }
	                    case 18:
	                    {
	                        c[d >> 2] = 190024;
	                        break a;
	                        break
	                    }
	                    case 11:
	                    {
	                        c[d >> 2] = 189928;
	                        break a;
	                        break
	                    }
	                    case 20:
	                    {
	                        c[d >> 2] = 190048;
	                        break a;
	                        break
	                    }
	                    case 9:
	                    {
	                        c[d >> 2] = 189904;
	                        break a;
	                        break
	                    }
	                    case -1:
	                    {
	                        c[d >> 2] = 190056;
	                        break a;
	                        break
	                    }
	                    case 3:
	                    {
	                        c[d >> 2] = 189856;
	                        break a;
	                        break
	                    }
	                    case 1:
	                    {
	                        c[d >> 2] = 189832;
	                        break a;
	                        break
	                    }
	                    case 14:
	                    {
	                        c[d >> 2] = 189968;
	                        break a;
	                        break
	                    }
	                    case 7:
	                    {
	                        c[d >> 2] = 189888;
	                        break a;
	                        break
	                    }
	                    case 4:
	                    {
	                        c[d >> 2] = 189864;
	                        break a;
	                        break
	                    }
	                    default:
	                    {
	                        c[d >> 2] = 190072;
	                        break a
	                    }
	                } while (0); while (0);
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function GO(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 1024 | 0;
	                g = f;
	                h = f + 20 | 0;
	                j = f + 16 | 0;
	                k = f + 12 | 0;
	                l = f + 8 | 0;
	                m = f + 24 | 0;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if (!(c[k >> 2] | 0))c[k >> 2] = 188112;
	                if (!(c[l >> 2] | 0))c[l >> 2] = 188112;
	                a[m >> 0] = 0;
	                do switch (c[j >> 2] | 0) {
	                    case 34:
	                    {
	                        c[h >> 2] = oy(189280) | 0;
	                        n = c[h >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    case 6:
	                    {
	                        c[h >> 2] = oy(188288) | 0;
	                        n = c[h >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    case 11:
	                    {
	                        c[h >> 2] = oy(188440) | 0;
	                        n = c[h >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    case 19:
	                    {
	                        c[g >> 2] = c[k >> 2];
	                        JT(m, 1e3, 188712, g) | 0;
	                        break
	                    }
	                    case 13:
	                    {
	                        e = c[l >> 2] | 0;
	                        c[g >> 2] = c[k >> 2];
	                        c[g + 4 >> 2] = e;
	                        JT(m, 1e3, 188504, g) | 0;
	                        break
	                    }
	                    case 12:
	                    {
	                        c[g >> 2] = c[k >> 2];
	                        JT(m, 1e3, 188472, g) | 0;
	                        break
	                    }
	                    case 27:
	                    {
	                        e = c[l >> 2] | 0;
	                        c[g >> 2] = c[k >> 2];
	                        c[g + 4 >> 2] = e;
	                        JT(m, 1e3, 188992, g) | 0;
	                        break
	                    }
	                    case 4:
	                    {
	                        c[g >> 2] = c[k >> 2];
	                        JT(m, 1e3, 188232, g) | 0;
	                        break
	                    }
	                    case 8:
	                    {
	                        c[g >> 2] = c[k >> 2];
	                        JT(m, 1e3, 188376, g) | 0;
	                        break
	                    }
	                    case 23:
	                    {
	                        c[h >> 2] = oy(188832) | 0;
	                        n = c[h >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    case 37:
	                    {
	                        c[g >> 2] = c[k >> 2];
	                        JT(m, 1e3, 188352, g) | 0;
	                        break
	                    }
	                    case 29:
	                    {
	                        c[g >> 2] = c[k >> 2];
	                        JT(m, 1e3, 189112, g) | 0;
	                        break
	                    }
	                    case 21:
	                    {
	                        c[g >> 2] = c[k >> 2];
	                        JT(m, 1e3, 188752, g) | 0;
	                        break
	                    }
	                    case 28:
	                    {
	                        c[g >> 2] = c[k >> 2];
	                        JT(m, 1e3, 189072, g) | 0;
	                        break
	                    }
	                    case 0:
	                    {
	                        c[h >> 2] = 0;
	                        n = c[h >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    case 17:
	                    {
	                        e = c[l >> 2] | 0;
	                        c[g >> 2] = c[k >> 2];
	                        c[g + 4 >> 2] = e;
	                        JT(m, 1e3, 188576, g) | 0;
	                        break
	                    }
	                    case 35:
	                    {
	                        c[h >> 2] = oy(189304) | 0;
	                        n = c[h >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    case 32:
	                    {
	                        c[g >> 2] = c[k >> 2];
	                        JT(m, 1e3, 189224, g) | 0;
	                        break
	                    }
	                    case 25:
	                    {
	                        c[g >> 2] = c[k >> 2];
	                        JT(m, 1e3, 188912, g) | 0;
	                        break
	                    }
	                    case 36:
	                    {
	                        c[g >> 2] = c[k >> 2];
	                        JT(m, 1e3, 189032, g) | 0;
	                        break
	                    }
	                    case 15:
	                    {
	                        c[g >> 2] = c[k >> 2];
	                        JT(m, 1e3, 188536, g) | 0;
	                        break
	                    }
	                    case 39:
	                    {
	                        c[g >> 2] = c[k >> 2];
	                        JT(m, 1e3, 188664, g) | 0;
	                        break
	                    }
	                    case 7:
	                    {
	                        c[h >> 2] = oy(188320) | 0;
	                        n = c[h >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    case 33:
	                    {
	                        c[h >> 2] = oy(189256) | 0;
	                        n = c[h >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    case 30:
	                    {
	                        c[g >> 2] = c[k >> 2];
	                        JT(m, 1e3, 189152, g) | 0;
	                        break
	                    }
	                    case 38:
	                    {
	                        c[g >> 2] = c[k >> 2];
	                        JT(m, 1e3, 188624, g) | 0;
	                        break
	                    }
	                    case 5:
	                    {
	                        c[g >> 2] = c[k >> 2];
	                        JT(m, 1e3, 188256, g) | 0;
	                        break
	                    }
	                    case 22:
	                    {
	                        c[g >> 2] = c[k >> 2];
	                        JT(m, 1e3, 188792, g) | 0;
	                        break
	                    }
	                    case 1:
	                    {
	                        c[h >> 2] = oy(188144) | 0;
	                        n = c[h >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    case 10:
	                    {
	                        c[h >> 2] = oy(188400) | 0;
	                        n = c[h >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                    case 31:
	                    {
	                        c[g >> 2] = c[k >> 2];
	                        JT(m, 1e3, 189192, g) | 0;
	                        break
	                    }
	                    case 3:
	                    {
	                        e = c[l >> 2] | 0;
	                        c[g >> 2] = c[k >> 2];
	                        c[g + 4 >> 2] = e;
	                        JT(m, 1e3, 188192, g) | 0;
	                        break
	                    }
	                    case 2:
	                    {
	                        c[g >> 2] = c[k >> 2];
	                        JT(m, 1e3, 188160, g) | 0;
	                        break
	                    }
	                    case 24:
	                    {
	                        c[g >> 2] = c[k >> 2];
	                        JT(m, 1e3, 188864, g) | 0;
	                        break
	                    }
	                    case 26:
	                    {
	                        e = c[l >> 2] | 0;
	                        c[g >> 2] = c[k >> 2];
	                        c[g + 4 >> 2] = e;
	                        JT(m, 1e3, 188952, g) | 0;
	                        break
	                    }
	                    default:
	                    {
	                        c[h >> 2] = oy(189336) | 0;
	                        n = c[h >> 2] | 0;
	                        i = f;
	                        return n | 0
	                    }
	                } while (0);
	                if (!(a[m >> 0] | 0)) {
	                    c[g >> 2] = c[j >> 2];
	                    JT(m, 1e3, 189360, g) | 0
	                }
	                a[m + 999 >> 0] = 0;
	                c[h >> 2] = my(m) | 0;
	                n = c[h >> 2] | 0;
	                i = f;
	                return n | 0
	            }

	            function HO(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h;
	                k = h + 40 | 0;
	                l = h + 36 | 0;
	                m = h + 32 | 0;
	                n = h + 28 | 0;
	                o = h + 24 | 0;
	                p = h + 20 | 0;
	                q = h + 16 | 0;
	                r = h + 12 | 0;
	                s = h + 8 | 0;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                c[q >> 2] = 0;
	                c[r >> 2] = 0;
	                c[s >> 2] = 0;
	                if (c[k >> 2] | 0) {
	                    g = c[k >> 2] | 0;
	                    if (c[(c[k >> 2] | 0) + 12 >> 2] | 0)c[q >> 2] = c[g + 12 >> 2]; else c[r >> 2] = c[g + 4 >> 2];
	                    c[s >> 2] = c[c[k >> 2] >> 2];
	                    g = (c[k >> 2] | 0) + 16 | 0;
	                    c[g >> 2] = (c[g >> 2] | 0) + 1
	                }
	                g = c[q >> 2] | 0;
	                q = c[r >> 2] | 0;
	                r = c[s >> 2] | 0;
	                s = c[l >> 2] | 0;
	                l = c[m >> 2] | 0;
	                m = c[o >> 2] | 0;
	                k = c[p >> 2] | 0;
	                f = c[n >> 2] | 0;
	                n = c[p >> 2] | 0;
	                c[j >> 2] = c[o >> 2];
	                c[j + 4 >> 2] = n;
	                Xd(g, q, r, 0, s, 19, l, 2, 0, 0, m, k, 0, 0, 0, f, j);
	                i = h;
	                return
	            }

	            function IO(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 36 | 0;
	                g = e + 32 | 0;
	                h = e + 28 | 0;
	                j = e + 24 | 0;
	                k = e + 20 | 0;
	                l = e + 16 | 0;
	                m = e + 12 | 0;
	                n = e + 8 | 0;
	                o = e + 4 | 0;
	                p = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = 0;
	                c[n >> 2] = 0;
	                if ((c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 16 >> 2] | 0) <= 0) {
	                    c[f >> 2] = -1;
	                    q = c[f >> 2] | 0;
	                    i = e;
	                    return q | 0
	                }
	                b = (c[(c[h >> 2] | 0) + 8 >> 2] | 0) != 0;
	                c[k >> 2] = 0;
	                do if (b) {
	                    while (1) {
	                        if ((c[k >> 2] | 0) >= (c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 8 >> 2] | 0))break;
	                        c[o >> 2] = c[(c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 28 >> 2] | 0) + (c[k >> 2] << 2) >> 2];
	                        if ((c[o >> 2] | 0) != 0 ? (qy(c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[(c[o >> 2] | 0) + 8 >> 2] | 0) | 0) != 0 : 0) {
	                            if (!((c[(c[h >> 2] | 0) + 12 >> 2] | 0) != 0 ? (d[c[(c[h >> 2] | 0) + 12 >> 2] >> 0] | 0 | 0) != 0 : 0))r = 9;
	                            if ((r | 0) == 9 ? (r = 0, (c[(c[o >> 2] | 0) + 36 >> 2] | 0) == 0) : 0) {
	                                r = 12;
	                                break
	                            }
	                            if ((c[(c[o >> 2] | 0) + 36 >> 2] | 0) != 0 ? (qy(c[(c[h >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) | 0) != 0 : 0) {
	                                r = 12;
	                                break
	                            }
	                        }
	                        c[k >> 2] = (c[k >> 2] | 0) + 1
	                    }
	                    if ((r | 0) == 12)c[n >> 2] = c[o >> 2];
	                    if (!(c[n >> 2] | 0)) {
	                        c[j >> 2] = -1;
	                        break
	                    }
	                    c[l >> 2] = _h(c[(c[n >> 2] | 0) + 32 >> 2] | 0, c[(c[n >> 2] | 0) + 12 >> 2] | 0, 1) | 0;
	                    c[m >> 2] = c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2];
	                    c[p >> 2] = c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2];
	                    c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2] = c[n >> 2];
	                    c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2] = c[l >> 2];
	                    c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 24 >> 2] = 0;
	                    c[j >> 2] = dP(c[g >> 2] | 0, c[(c[h >> 2] | 0) + 24 >> 2] | 0) | 0;
	                    if (c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2] | 0)c[l >> 2] = c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2];
	                    if (c[l >> 2] | 0)zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                    c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2] = c[m >> 2];
	                    c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2] = c[p >> 2];
	                    if (!(c[j >> 2] | 0)) {
	                        c[(c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 28 >> 2] | 0) + (c[k >> 2] << 2) >> 2] = 0;
	                        a = (c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 16 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + -1
	                    }
	                } else {
	                    while (1) {
	                        if ((c[k >> 2] | 0) >= (c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 8 >> 2] | 0))break;
	                        c[o >> 2] = c[(c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 28 >> 2] | 0) + (c[k >> 2] << 2) >> 2];
	                        if ((c[o >> 2] | 0) != 0 ? (eP(c[g >> 2] | 0, c[h >> 2] | 0, c[o >> 2] | 0) | 0) == 1 : 0) {
	                            r = 25;
	                            break
	                        }
	                        c[k >> 2] = (c[k >> 2] | 0) + 1
	                    }
	                    if ((r | 0) == 25)c[n >> 2] = c[o >> 2];
	                    if (!(c[n >> 2] | 0)) {
	                        c[j >> 2] = -1;
	                        break
	                    }
	                    c[l >> 2] = _h(c[(c[n >> 2] | 0) + 32 >> 2] | 0, c[(c[n >> 2] | 0) + 12 >> 2] | 0, 1) | 0;
	                    c[m >> 2] = c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2];
	                    c[p >> 2] = c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2];
	                    c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2] = c[n >> 2];
	                    c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2] = c[l >> 2];
	                    c[j >> 2] = dP(c[g >> 2] | 0, c[(c[h >> 2] | 0) + 24 >> 2] | 0) | 0;
	                    if (c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2] | 0)c[l >> 2] = c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2];
	                    if (c[l >> 2] | 0)zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                    c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2] = c[m >> 2];
	                    c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2] = c[p >> 2];
	                    if (!(c[j >> 2] | 0)) {
	                        c[(c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 28 >> 2] | 0) + (c[k >> 2] << 2) >> 2] = 0;
	                        a = (c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 16 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + -1
	                    }
	                } while (0);
	                c[f >> 2] = c[j >> 2];
	                q = c[f >> 2] | 0;
	                i = e;
	                return q | 0
	            }

	            function JO(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 24 | 0;
	                e = b + 20 | 0;
	                f = b + 16 | 0;
	                g = b + 12 | 0;
	                h = b + 8 | 0;
	                j = b + 4 | 0;
	                k = b;
	                c[e >> 2] = a;
	                c[j >> 2] = -1;
	                c[k >> 2] = 1e6;
	                if (((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 64 >> 2] | 0) != 0 : 0) ? (c[c[(c[e >> 2] | 0) + 64 >> 2] >> 2] | 0) > 0 : 0) {
	                    c[g >> 2] = 0;
	                    while (1) {
	                        if ((c[g >> 2] | 0) >= (c[c[(c[e >> 2] | 0) + 64 >> 2] >> 2] | 0))break;
	                        c[f >> 2] = c[(c[(c[(c[e >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] | 0) + (c[g >> 2] << 2) >> 2];
	                        do if (c[f >> 2] | 0) {
	                            if (c[(c[f >> 2] | 0) + 4 >> 2] | 0) {
	                                if (!((c[j >> 2] | 0) == -1 | (c[k >> 2] | 0) > 1e5))break;
	                                c[k >> 2] = 1e5;
	                                c[j >> 2] = c[g >> 2];
	                                break
	                            }
	                            c[h >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                            if ((c[j >> 2] | 0) != -1 ? (c[k >> 2] | 0) <= (c[h >> 2] | 0) : 0)break;
	                            c[k >> 2] = c[h >> 2];
	                            c[j >> 2] = c[g >> 2]
	                        } while (0);
	                        c[g >> 2] = (c[g >> 2] | 0) + 1
	                    }
	                    c[d >> 2] = c[j >> 2];
	                    l = c[d >> 2] | 0;
	                    i = b;
	                    return l | 0
	                }
	                c[d >> 2] = -1;
	                l = c[d >> 2] | 0;
	                i = b;
	                return l | 0
	            }

	            function KO(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[g >> 2] = c[f >> 2];
	                while (1) {
	                    if ((c[g >> 2] | 0) >= (c[(c[e >> 2] | 0) + 48 >> 2] | 0))break;
	                    c[h >> 2] = (c[(c[e >> 2] | 0) + 56 >> 2] | 0) + ((c[g >> 2] | 0) * 24 | 0);
	                    if (c[(c[h >> 2] | 0) + 4 >> 2] & 1) {
	                        if (c[(c[h >> 2] | 0) + 16 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[h >> 2] | 0) + 16 >> 2] | 0);
	                        c[(c[h >> 2] | 0) + 16 >> 2] = 0;
	                        if (c[(c[h >> 2] | 0) + 20 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[h >> 2] | 0) + 20 >> 2] | 0);
	                        c[(c[h >> 2] | 0) + 20 >> 2] = 0;
	                        c[(c[h >> 2] | 0) + 4 >> 2] = 0
	                    }
	                    c[g >> 2] = (c[g >> 2] | 0) + 1
	                }
	                c[(c[e >> 2] | 0) + 48 >> 2] = c[f >> 2];
	                if ((c[(c[e >> 2] | 0) + 48 >> 2] | 0) > 0) {
	                    i = d;
	                    return
	                }
	                c[(c[e >> 2] | 0) + 44 >> 2] = 0;
	                i = d;
	                return
	            }

	            function LO(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                a = c[d >> 2] | 0;
	                if ((c[(c[d >> 2] | 0) + 48 >> 2] | 0) <= 0) {
	                    c[a + 44 >> 2] = 0;
	                    i = b;
	                    return
	                }
	                f = a + 48 | 0;
	                c[f >> 2] = (c[f >> 2] | 0) + -1;
	                f = c[d >> 2] | 0;
	                if ((c[(c[d >> 2] | 0) + 48 >> 2] | 0) > 0)c[(c[d >> 2] | 0) + 44 >> 2] = (c[(c[d >> 2] | 0) + 56 >> 2] | 0) + (((c[f + 48 >> 2] | 0) - 1 | 0) * 24 | 0); else c[f + 44 >> 2] = 0;
	                c[e >> 2] = (c[(c[d >> 2] | 0) + 56 >> 2] | 0) + ((c[(c[d >> 2] | 0) + 48 >> 2] | 0) * 24 | 0);
	                if (!(c[(c[e >> 2] | 0) + 4 >> 2] & 1)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[e >> 2] | 0) + 16 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[e >> 2] | 0) + 16 >> 2] | 0);
	                c[(c[e >> 2] | 0) + 16 >> 2] = 0;
	                if (c[(c[e >> 2] | 0) + 20 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[e >> 2] | 0) + 20 >> 2] | 0);
	                c[(c[e >> 2] | 0) + 20 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 4 >> 2] = 0;
	                i = b;
	                return
	            }

	            function MO(a, b, e) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f;
	                h = f + 36 | 0;
	                j = f + 32 | 0;
	                k = f + 28 | 0;
	                l = f + 24 | 0;
	                m = f + 20 | 0;
	                n = f + 16 | 0;
	                o = f + 12 | 0;
	                p = f + 8 | 0;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = e;
	                c[m >> 2] = 0;
	                c[n >> 2] = 0;
	                if ((c[(c[k >> 2] | 0) + 8 >> 2] | 0) != 0 ? (qy(c[(c[l >> 2] | 0) + 8 >> 2] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0) | 0) == 0 : 0) {
	                    FN(c[j >> 2] | 0, 13, c[(c[k >> 2] | 0) + 8 >> 2] | 0, c[(c[l >> 2] | 0) + 8 >> 2] | 0, 0);
	                    c[h >> 2] = 0;
	                    q = c[h >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                if ((c[(c[k >> 2] | 0) + 12 >> 2] | 0) != 0 ? (d[c[(c[k >> 2] | 0) + 12 >> 2] >> 0] | 0 | 0) != 0 : 0) {
	                    if (!(c[(c[l >> 2] | 0) + 36 >> 2] | 0)) {
	                        FN(c[j >> 2] | 0, 15, c[(c[l >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                        c[h >> 2] = 0;
	                        q = c[h >> 2] | 0;
	                        i = f;
	                        return q | 0
	                    }
	                    if (!(qy(c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[(c[k >> 2] | 0) + 12 >> 2] | 0) | 0)) {
	                        FN(c[j >> 2] | 0, 17, c[(c[l >> 2] | 0) + 8 >> 2] | 0, c[(c[k >> 2] | 0) + 12 >> 2] | 0, 0);
	                        c[h >> 2] = 0;
	                        q = c[h >> 2] | 0;
	                        i = f;
	                        return q | 0
	                    }
	                } else {
	                    if (((c[(c[l >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[(c[k >> 2] | 0) + 8 >> 2] | 0) == 0 : 0) {
	                        FN(c[j >> 2] | 0, 19, c[(c[l >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                        c[h >> 2] = 0;
	                        q = c[h >> 2] | 0;
	                        i = f;
	                        return q | 0
	                    }
	                    if ((c[(c[l >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                        FN(c[j >> 2] | 0, 19, c[(c[k >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                        c[h >> 2] = 0;
	                        q = c[h >> 2] | 0;
	                        i = f;
	                        return q | 0
	                    }
	                }
	                if (!(c[(c[k >> 2] | 0) + 40 >> 2] | 0)) {
	                    c[h >> 2] = 1;
	                    q = c[h >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                c[k >> 2] = c[(c[k >> 2] | 0) + 40 >> 2];
	                do if ((c[c[k >> 2] >> 2] | 0) == 2) {
	                    if (c[j >> 2] | 0) {
	                        c[n >> 2] = c[(c[j >> 2] | 0) + 28 >> 2];
	                        e = (c[j >> 2] | 0) + 28 | 0;
	                        c[e >> 2] = c[e >> 2] | 1
	                    }
	                    c[o >> 2] = c[(c[k >> 2] | 0) + 24 >> 2];
	                    while (1) {
	                        if (!(c[o >> 2] | 0)) {
	                            r = 33;
	                            break
	                        }
	                        c[m >> 2] = MO(c[j >> 2] | 0, c[o >> 2] | 0, c[l >> 2] | 0) | 0;
	                        if ((c[m >> 2] | 0) == 1) {
	                            r = 25;
	                            break
	                        }
	                        if ((c[m >> 2] | 0) < 0) {
	                            r = 29;
	                            break
	                        }
	                        c[o >> 2] = c[(c[o >> 2] | 0) + 32 >> 2]
	                    }
	                    if ((r | 0) == 25) {
	                        if (c[j >> 2] | 0)c[(c[j >> 2] | 0) + 28 >> 2] = c[n >> 2];
	                        c[h >> 2] = 0;
	                        q = c[h >> 2] | 0;
	                        i = f;
	                        return q | 0
	                    } else if ((r | 0) == 29) {
	                        if (c[j >> 2] | 0)c[(c[j >> 2] | 0) + 28 >> 2] = c[n >> 2];
	                        c[h >> 2] = c[m >> 2];
	                        q = c[h >> 2] | 0;
	                        i = f;
	                        return q | 0
	                    } else if ((r | 0) == 33) {
	                        c[m >> 2] = 1;
	                        if (!(c[j >> 2] | 0))break;
	                        c[(c[j >> 2] | 0) + 28 >> 2] = c[n >> 2];
	                        break
	                    }
	                } else {
	                    if ((c[c[k >> 2] >> 2] | 0) != 17) {
	                        e = c[33976] | 0;
	                        b = c[33980] | 0;
	                        c[g >> 2] = 189496;
	                        c[g + 4 >> 2] = 9708;
	                        Db[e & 511](b, 189464, g);
	                        c[m >> 2] = -1;
	                        break
	                    }
	                    if (c[j >> 2] | 0) {
	                        c[n >> 2] = c[(c[j >> 2] | 0) + 28 >> 2];
	                        b = (c[j >> 2] | 0) + 28 | 0;
	                        c[b >> 2] = c[b >> 2] | 1
	                    }
	                    c[p >> 2] = c[(c[k >> 2] | 0) + 40 >> 2];
	                    while (1) {
	                        s = c[j >> 2] | 0;
	                        if (!(c[p >> 2] | 0)) {
	                            r = 49;
	                            break
	                        }
	                        c[m >> 2] = MO(s, c[p >> 2] | 0, c[l >> 2] | 0) | 0;
	                        if ((c[m >> 2] | 0) == 1) {
	                            r = 41;
	                            break
	                        }
	                        if ((c[m >> 2] | 0) < 0) {
	                            r = 45;
	                            break
	                        }
	                        c[p >> 2] = c[(c[p >> 2] | 0) + 32 >> 2]
	                    }
	                    if ((r | 0) == 41) {
	                        if (c[j >> 2] | 0)c[(c[j >> 2] | 0) + 28 >> 2] = c[n >> 2];
	                        c[h >> 2] = 1;
	                        q = c[h >> 2] | 0;
	                        i = f;
	                        return q | 0
	                    } else if ((r | 0) == 45) {
	                        if (c[j >> 2] | 0)c[(c[j >> 2] | 0) + 28 >> 2] = c[n >> 2];
	                        c[h >> 2] = c[m >> 2];
	                        q = c[h >> 2] | 0;
	                        i = f;
	                        return q | 0
	                    } else if ((r | 0) == 49) {
	                        do if (s) {
	                            b = c[j >> 2] | 0;
	                            if (c[m >> 2] | 0) {
	                                if (c[b + 28 >> 2] & 1)break;
	                                eO(c[j >> 2] | 0);
	                                break
	                            } else {
	                                if ((c[b + 48 >> 2] | 0) <= 0)break;
	                                KO(c[j >> 2] | 0, 0);
	                                break
	                            }
	                        } while (0);
	                        c[m >> 2] = 0;
	                        if (!(c[j >> 2] | 0))break;
	                        c[(c[j >> 2] | 0) + 28 >> 2] = c[n >> 2];
	                        break
	                    }
	                } while (0);
	                c[h >> 2] = c[m >> 2];
	                q = c[h >> 2] | 0;
	                i = f;
	                return q | 0
	            }

	            function NO(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 28 | 0;
	                g = e + 24 | 0;
	                h = e + 20 | 0;
	                j = e + 16 | 0;
	                k = e + 12 | 0;
	                l = e + 8 | 0;
	                m = e + 4 | 0;
	                n = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[m >> 2] = 0;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) {
	                    c[f >> 2] = -1;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                c[n >> 2] = c[(c[g >> 2] | 0) + 112 >> 2];
	                c[k >> 2] = oz(c[h >> 2] | 0, 385, c[g >> 2] | 0) | 0;
	                c[(c[g >> 2] | 0) + 112 >> 2] = 0;
	                c[l >> 2] = c[j >> 2];
	                while (1) {
	                    if (!(c[l >> 2] | 0))break;
	                    c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2] = c[l >> 2];
	                    j = c[(c[l >> 2] | 0) + 4 >> 2] | 0;
	                    if ((j | 0) == 1) {
	                        h = c[k >> 2] | 0;
	                        d = c[(c[l >> 2] | 0) + 8 >> 2] | 0;
	                        if (c[(c[l >> 2] | 0) + 36 >> 2] | 0)c[m >> 2] = rz(h, d, c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[g >> 2] | 0) | 0; else c[m >> 2] = qz(h, d, c[g >> 2] | 0) | 0;
	                        if ((c[m >> 2] | 0) < 0)FN(c[g >> 2] | 0, 38, c[(c[l >> 2] | 0) + 8 >> 2] | 0, 0, 0)
	                    } else if (((j | 0) == 4 | (j | 0) == 3 ? (ij(c[l >> 2] | 0) | 0) == 0 : 0) ? (c[m >> 2] = qz(c[k >> 2] | 0, 188096, c[g >> 2] | 0) | 0, (c[m >> 2] | 0) < 0) : 0)FN(c[g >> 2] | 0, 39, c[(c[(c[l >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                    if ((c[m >> 2] | 0) < 0)break;
	                    c[l >> 2] = c[(c[l >> 2] | 0) + 24 >> 2]
	                }
	                c[m >> 2] = qz(c[k >> 2] | 0, 0, 0) | 0;
	                do if ((c[m >> 2] | 0) != 1) {
	                    if (c[m >> 2] | 0) {
	                        c[m >> 2] = -1;
	                        break
	                    }
	                    FN(c[g >> 2] | 0, 22, 188112, 0, 0);
	                    c[m >> 2] = -1;
	                    if (!(c[(c[g >> 2] | 0) + 28 >> 2] & 1))eO(c[g >> 2] | 0)
	                } else {
	                    c[m >> 2] = 0;
	                    c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2] = 0
	                } while (0);
	                pz(c[k >> 2] | 0);
	                if ((c[m >> 2] | 0) == 0 ? (c[(c[g >> 2] | 0) + 112 >> 2] | 0) != 0 : 0)c[m >> 2] = c[(c[g >> 2] | 0) + 112 >> 2];
	                c[(c[g >> 2] | 0) + 112 >> 2] = c[n >> 2];
	                c[f >> 2] = c[m >> 2];
	                o = c[f >> 2] | 0;
	                i = e;
	                return o | 0
	            }

	            function OO(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                if (!(c[g >> 2] | 0)) {
	                    FN(c[f >> 2] | 0, 37, 189592, 0, 0);
	                    c[e >> 2] = -1;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                while (1) {
	                    if (!(c[g >> 2] | 0)) {
	                        l = 11;
	                        break
	                    }
	                    if ((c[(c[f >> 2] | 0) + 60 >> 2] | 0) == 0 ? (c[(c[f >> 2] | 0) + 64 >> 2] | 0) == 0 : 0) {
	                        l = 8;
	                        break
	                    }
	                    c[j >> 2] = KN(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                    if ((c[j >> 2] | 0) < 0)c[h >> 2] = -1;
	                    if ((c[j >> 2] | 0) == -1) {
	                        l = 11;
	                        break
	                    }
	                    c[g >> 2] = c[(c[g >> 2] | 0) + 32 >> 2]
	                }
	                if ((l | 0) == 8) {
	                    FN(c[f >> 2] | 0, 6, 0, 0, 0);
	                    c[e >> 2] = -1;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                } else if ((l | 0) == 11) {
	                    c[e >> 2] = c[h >> 2];
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                return 0
	            }

	            function PO(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 24 | 0;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                l = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                if ((c[(c[f >> 2] | 0) + 68 >> 2] | 0) != 0 ? (c[c[(c[f >> 2] | 0) + 68 >> 2] >> 2] | 0) > 0 : 0) {
	                    b = c[(c[f >> 2] | 0) + 68 >> 2] | 0;
	                    c[b >> 2] = (c[b >> 2] | 0) + -1;
	                    c[h >> 2] = c[(c[(c[(c[f >> 2] | 0) + 68 >> 2] | 0) + 8 >> 2] | 0) + (c[c[(c[f >> 2] | 0) + 68 >> 2] >> 2] << 2) >> 2]
	                } else n = 6;
	                do if ((n | 0) == 6) {
	                    c[h >> 2] = Cb[c[135744 >> 2] & 511](32) | 0;
	                    if (c[h >> 2] | 0) {
	                        b = c[h >> 2] | 0;
	                        c[b + 0 >> 2] = 0;
	                        c[b + 4 >> 2] = 0;
	                        c[b + 8 >> 2] = 0;
	                        c[b + 12 >> 2] = 0;
	                        c[b + 16 >> 2] = 0;
	                        c[b + 20 >> 2] = 0;
	                        c[b + 24 >> 2] = 0;
	                        c[b + 28 >> 2] = 0;
	                        break
	                    }
	                    MN(c[f >> 2] | 0, 189568);
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                } while (0);
	                c[k >> 2] = c[(c[h >> 2] | 0) + 28 >> 2];
	                c[j >> 2] = c[(c[h >> 2] | 0) + 12 >> 2];
	                n = c[h >> 2] | 0;
	                b = c[g >> 2] | 0;
	                c[n + 0 >> 2] = c[b + 0 >> 2];
	                c[n + 4 >> 2] = c[b + 4 >> 2];
	                c[n + 8 >> 2] = c[b + 8 >> 2];
	                c[n + 12 >> 2] = c[b + 12 >> 2];
	                c[n + 16 >> 2] = c[b + 16 >> 2];
	                c[n + 20 >> 2] = c[b + 20 >> 2];
	                c[n + 24 >> 2] = c[b + 24 >> 2];
	                c[n + 28 >> 2] = c[b + 28 >> 2];
	                c[(c[h >> 2] | 0) + 28 >> 2] = c[k >> 2];
	                c[(c[h >> 2] | 0) + 12 >> 2] = c[j >> 2];
	                if ((c[(c[g >> 2] | 0) + 8 >> 2] | 0) > 0) {
	                    do if (!(c[(c[h >> 2] | 0) + 28 >> 2] | 0)) {
	                        c[(c[h >> 2] | 0) + 12 >> 2] = c[(c[g >> 2] | 0) + 12 >> 2];
	                        j = Cb[c[135744 >> 2] & 511](c[(c[h >> 2] | 0) + 12 >> 2] << 2) | 0;
	                        c[(c[h >> 2] | 0) + 28 >> 2] = j;
	                        if (!(c[(c[h >> 2] | 0) + 28 >> 2] | 0)) {
	                            MN(c[f >> 2] | 0, 189568);
	                            c[(c[h >> 2] | 0) + 8 >> 2] = 0;
	                            c[e >> 2] = c[h >> 2];
	                            m = c[e >> 2] | 0;
	                            i = d;
	                            return m | 0
	                        }
	                    } else if ((c[(c[h >> 2] | 0) + 12 >> 2] | 0) < (c[(c[g >> 2] | 0) + 8 >> 2] | 0)) {
	                        c[l >> 2] = Hb[c[135760 >> 2] & 511](c[(c[h >> 2] | 0) + 28 >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] << 2) | 0;
	                        if (c[l >> 2] | 0) {
	                            c[(c[h >> 2] | 0) + 12 >> 2] = c[(c[g >> 2] | 0) + 12 >> 2];
	                            c[(c[h >> 2] | 0) + 28 >> 2] = c[l >> 2];
	                            break
	                        }
	                        MN(c[f >> 2] | 0, 189568);
	                        c[(c[h >> 2] | 0) + 8 >> 2] = 0;
	                        c[e >> 2] = c[h >> 2];
	                        m = c[e >> 2] | 0;
	                        i = d;
	                        return m | 0
	                    } while (0);
	                    eU(c[(c[h >> 2] | 0) + 28 >> 2] | 0, c[(c[g >> 2] | 0) + 28 >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] << 2 | 0) | 0
	                }
	                c[e >> 2] = c[h >> 2];
	                m = c[e >> 2] | 0;
	                i = d;
	                return m | 0
	            }

	            function QO(a, d) {
	                a = a | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0;
	                e = i;
	                i = i + 96 | 0;
	                f = e + 88 | 0;
	                g = e + 84 | 0;
	                h = e + 80 | 0;
	                j = e + 76 | 0;
	                k = e + 72 | 0;
	                l = e + 68 | 0;
	                m = e + 64 | 0;
	                n = e + 60 | 0;
	                o = e + 56 | 0;
	                p = e + 52 | 0;
	                q = e + 48 | 0;
	                r = e + 44 | 0;
	                s = e + 40 | 0;
	                t = e + 36 | 0;
	                u = e + 32 | 0;
	                v = e + 28 | 0;
	                w = e + 24 | 0;
	                x = e + 20 | 0;
	                y = e + 16 | 0;
	                z = e + 12 | 0;
	                A = e + 8 | 0;
	                B = e + 4 | 0;
	                C = e;
	                c[g >> 2] = a;
	                c[h >> 2] = d;
	                c[j >> 2] = 0;
	                c[m >> 2] = c[(c[g >> 2] | 0) + 48 >> 2];
	                c[q >> 2] = 0;
	                c[t >> 2] = 0;
	                c[u >> 2] = 0;
	                c[w >> 2] = 0;
	                c[x >> 2] = 0;
	                if (!(c[(c[h >> 2] | 0) + 20 >> 2] | 0)) {
	                    FN(c[g >> 2] | 0, 10, 0, 0, 0);
	                    c[f >> 2] = -1;
	                    D = c[f >> 2] | 0;
	                    i = e;
	                    return D | 0
	                }
	                c[p >> 2] = c[(c[h >> 2] | 0) + 20 >> 2];
	                c[l >> 2] = c[c[p >> 2] >> 2];
	                c[n >> 2] = c[(c[g >> 2] | 0) + 28 >> 2];
	                if ((b[(c[h >> 2] | 0) + 50 >> 1] & 8 | 0) != 0 ? (h = (c[g >> 2] | 0) + 28 | 0, c[h >> 2] = c[h >> 2] | 4, (c[l >> 2] | 0) == 2) : 0) {
	                    if (c[(c[g >> 2] | 0) + 60 >> 2] | 0) {
	                        h = oO(c[g >> 2] | 0, c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2] | 0) | 0;
	                        c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2] = h
	                    }
	                    h = c[g >> 2] | 0;
	                    d = c[(c[p >> 2] | 0) + 12 >> 2] | 0;
	                    if ((c[c[c[c[(c[p >> 2] | 0) + 12 >> 2] >> 2] >> 2] >> 2] | 0) == 3)c[j >> 2] = KN(h, c[c[d + 4 >> 2] >> 2] | 0) | 0; else c[j >> 2] = KN(h, c[c[d >> 2] >> 2] | 0) | 0;
	                    if ((c[j >> 2] | 0) == 0 ? (c[(c[g >> 2] | 0) + 60 >> 2] | 0) != 0 : 0) {
	                        d = oO(c[g >> 2] | 0, c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2] | 0) | 0;
	                        c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2] = d
	                    }
	                    c[(c[g >> 2] | 0) + 28 >> 2] = c[n >> 2];
	                    c[f >> 2] = c[j >> 2];
	                    D = c[f >> 2] | 0;
	                    i = e;
	                    return D | 0
	                }
	                c[w >> 2] = Cb[c[135744 >> 2] & 511](c[l >> 2] << 2) | 0;
	                if (!(c[w >> 2] | 0)) {
	                    MN(c[g >> 2] | 0, 189544);
	                    c[f >> 2] = -1;
	                    D = c[f >> 2] | 0;
	                    i = e;
	                    return D | 0
	                }
	                cU(c[w >> 2] | 0, 0, c[l >> 2] << 2 | 0) | 0;
	                c[x >> 2] = Cb[c[135744 >> 2] & 511](c[l >> 2] << 2) | 0;
	                if (!(c[x >> 2] | 0)) {
	                    MN(c[g >> 2] | 0, 189544);
	                    c[f >> 2] = -1;
	                    D = c[f >> 2] | 0;
	                    i = e;
	                    return D | 0
	                }
	                cU(c[x >> 2] | 0, 0, c[l >> 2] << 2 | 0) | 0;
	                c[r >> 2] = c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2];
	                c[r >> 2] = oO(c[g >> 2] | 0, c[r >> 2] | 0) | 0;
	                c[s >> 2] = c[r >> 2];
	                while (1) {
	                    if (!(c[r >> 2] | 0))break;
	                    c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2] = c[r >> 2];
	                    do if ((c[(c[p >> 2] | 0) + 4 >> 2] | 0) != 0 ? (c[(c[p >> 2] | 0) + 8 >> 2] & 1 | 0) != 0 : 0) {
	                        c[y >> 2] = 0;
	                        if ((c[(c[r >> 2] | 0) + 4 >> 2] | 0) != 3 ? (c[(c[r >> 2] | 0) + 4 >> 2] | 0) != 4 : 0) {
	                            if ((c[(c[r >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                                d = c[(c[p >> 2] | 0) + 4 >> 2] | 0;
	                                h = c[(c[r >> 2] | 0) + 8 >> 2] | 0;
	                                if (c[(c[r >> 2] | 0) + 36 >> 2] | 0) {
	                                    c[y >> 2] = Tj(d, h, c[(c[(c[r >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) | 0;
	                                    if (!(c[y >> 2] | 0))c[y >> 2] = Tj(c[(c[p >> 2] | 0) + 4 >> 2] | 0, 189536, c[(c[(c[r >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) | 0
	                                } else c[y >> 2] = Tj(d, h, 0) | 0;
	                                if (!(c[y >> 2] | 0))c[y >> 2] = Tj(c[(c[p >> 2] | 0) + 4 >> 2] | 0, 189536, 0) | 0
	                            }
	                        } else c[y >> 2] = Tj(c[(c[p >> 2] | 0) + 4 >> 2] | 0, 188096, 0) | 0;
	                        if (!(c[y >> 2] | 0)) {
	                            c[k >> 2] = c[l >> 2];
	                            break
	                        }
	                        c[k >> 2] = (c[y >> 2] | 0) - 1;
	                        if ((c[(c[p >> 2] | 0) + 8 >> 2] & 2 | 0) != 0 ? (c[q >> 2] = c[(c[(c[p >> 2] | 0) + 12 >> 2] | 0) + (c[k >> 2] << 2) >> 2], (gP(c[r >> 2] | 0, c[(c[q >> 2] | 0) + 4 >> 2] | 0) | 0) == 0) : 0)c[k >> 2] = c[l >> 2]
	                    } else E = 37; while (0);
	                    a:do if ((E | 0) == 37) {
	                        E = 0;
	                        c[k >> 2] = 0;
	                        while (1) {
	                            if ((c[k >> 2] | 0) >= (c[l >> 2] | 0))break a;
	                            c[q >> 2] = c[(c[(c[p >> 2] | 0) + 12 >> 2] | 0) + (c[k >> 2] << 2) >> 2];
	                            if ((c[q >> 2] | 0) != 0 ? (gP(c[r >> 2] | 0, c[(c[q >> 2] | 0) + 4 >> 2] | 0) | 0) != 0 : 0)break a;
	                            c[k >> 2] = (c[k >> 2] | 0) + 1
	                        }
	                    } while (0);
	                    if ((c[k >> 2] | 0) >= (c[l >> 2] | 0))break;
	                    h = c[r >> 2] | 0;
	                    d = c[k >> 2] | 0;
	                    if (c[(c[x >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) {
	                        c[(c[(c[x >> 2] | 0) + (d << 2) >> 2] | 0) + 24 >> 2] = h;
	                        c[(c[x >> 2] | 0) + (c[k >> 2] << 2) >> 2] = c[r >> 2]
	                    } else {
	                        c[(c[w >> 2] | 0) + (d << 2) >> 2] = h;
	                        c[(c[x >> 2] | 0) + (c[k >> 2] << 2) >> 2] = c[r >> 2]
	                    }
	                    h = c[r >> 2] | 0;
	                    if (c[(c[r >> 2] | 0) + 24 >> 2] | 0)c[u >> 2] = c[h + 24 >> 2]; else c[u >> 2] = h;
	                    c[r >> 2] = oO(c[g >> 2] | 0, c[(c[r >> 2] | 0) + 24 >> 2] | 0) | 0
	                }
	                do if (!(c[j >> 2] | 0)) {
	                    c[v >> 2] = c[r >> 2];
	                    c[o >> 2] = c[(c[g >> 2] | 0) + 60 >> 2];
	                    c[k >> 2] = 0;
	                    while (1) {
	                        if ((c[k >> 2] | 0) >= (c[l >> 2] | 0))break;
	                        y = PO(c[g >> 2] | 0, c[o >> 2] | 0) | 0;
	                        c[(c[g >> 2] | 0) + 60 >> 2] = y;
	                        if (!(c[(c[g >> 2] | 0) + 60 >> 2] | 0)) {
	                            E = 55;
	                            break
	                        }
	                        c[q >> 2] = c[(c[(c[p >> 2] | 0) + 12 >> 2] | 0) + (c[k >> 2] << 2) >> 2];
	                        if (c[(c[x >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) {
	                            c[t >> 2] = c[(c[(c[x >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 24 >> 2];
	                            c[(c[(c[x >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 24 >> 2] = 0
	                        }
	                        c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2] = c[(c[w >> 2] | 0) + (c[k >> 2] << 2) >> 2];
	                        c[j >> 2] = KN(c[g >> 2] | 0, c[c[q >> 2] >> 2] | 0) | 0;
	                        if (c[j >> 2] | 0)break;
	                        y = c[g >> 2] | 0;
	                        if (c[(c[g >> 2] | 0) + 60 >> 2] | 0) {
	                            c[r >> 2] = c[(c[y + 60 >> 2] | 0) + 4 >> 2];
	                            c[r >> 2] = oO(c[g >> 2] | 0, c[r >> 2] | 0) | 0;
	                            LN(c[g >> 2] | 0, c[o >> 2] | 0);
	                            c[o >> 2] = c[(c[g >> 2] | 0) + 60 >> 2];
	                            c[(c[g >> 2] | 0) + 60 >> 2] = 0;
	                            if (c[r >> 2] | 0) {
	                                E = 61;
	                                break
	                            }
	                        } else {
	                            if (!(c[y + 64 >> 2] | 0)) {
	                                E = 89;
	                                break
	                            }
	                            c[A >> 2] = 0;
	                            c[B >> 2] = -1;
	                            c[C >> 2] = -1;
	                            c[z >> 2] = 0;
	                            b:while (1) {
	                                if ((c[z >> 2] | 0) >= (c[c[(c[g >> 2] | 0) + 64 >> 2] >> 2] | 0))break;
	                                c[r >> 2] = c[(c[(c[(c[(c[g >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] | 0) + (c[z >> 2] << 2) >> 2] | 0) + 4 >> 2];
	                                c[r >> 2] = oO(c[g >> 2] | 0, c[r >> 2] | 0) | 0;
	                                y = (c[A >> 2] | 0) == 0;
	                                do if (!(c[r >> 2] | 0)) {
	                                    if (y) {
	                                        c[C >> 2] = c[(c[(c[(c[(c[g >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] | 0) + (c[z >> 2] << 2) >> 2] | 0) + 16 >> 2];
	                                        c[B >> 2] = c[z >> 2]
	                                    }
	                                    c[A >> 2] = 1;
	                                    if ((c[(c[(c[(c[(c[g >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] | 0) + (c[z >> 2] << 2) >> 2] | 0) + 16 >> 2] | 0) <= (c[C >> 2] | 0)) {
	                                        c[C >> 2] = c[(c[(c[(c[(c[g >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] | 0) + (c[z >> 2] << 2) >> 2] | 0) + 16 >> 2];
	                                        c[B >> 2] = c[z >> 2]
	                                    }
	                                    if (!(c[C >> 2] | 0))break b
	                                } else if (y) {
	                                    h = c[(c[(c[(c[(c[g >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] | 0) + (c[z >> 2] << 2) >> 2] | 0) + 16 >> 2] | 0;
	                                    if ((c[C >> 2] | 0) == -1) {
	                                        c[C >> 2] = h;
	                                        c[B >> 2] = c[z >> 2];
	                                        break
	                                    }
	                                    if ((h | 0) > (c[C >> 2] | 0))break;
	                                    c[C >> 2] = c[(c[(c[(c[(c[g >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] | 0) + (c[z >> 2] << 2) >> 2] | 0) + 16 >> 2];
	                                    c[B >> 2] = c[z >> 2]
	                                } while (0);
	                                c[z >> 2] = (c[z >> 2] | 0) + 1
	                            }
	                            do if ((c[c[(c[g >> 2] | 0) + 64 >> 2] >> 2] | 0) > 0) {
	                                LN(c[g >> 2] | 0, c[o >> 2] | 0);
	                                if ((c[B >> 2] | 0) != -1) {
	                                    c[o >> 2] = c[(c[(c[(c[g >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] | 0) + (c[B >> 2] << 2) >> 2];
	                                    c[(c[(c[(c[g >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] | 0) + (c[B >> 2] << 2) >> 2] = 0;
	                                    break
	                                } else {
	                                    c[o >> 2] = c[(c[(c[(c[g >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] | 0) + ((c[c[(c[g >> 2] | 0) + 64 >> 2] >> 2] | 0) - 1 << 2) >> 2];
	                                    c[(c[(c[(c[g >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] | 0) + ((c[c[(c[g >> 2] | 0) + 64 >> 2] >> 2] | 0) - 1 << 2) >> 2] = 0;
	                                    y = c[(c[g >> 2] | 0) + 64 >> 2] | 0;
	                                    c[y >> 2] = (c[y >> 2] | 0) + -1;
	                                    break
	                                }
	                            } while (0);
	                            c[z >> 2] = 0;
	                            while (1) {
	                                F = c[g >> 2] | 0;
	                                if ((c[z >> 2] | 0) >= (c[c[(c[g >> 2] | 0) + 64 >> 2] >> 2] | 0))break;
	                                LN(F, c[(c[(c[(c[g >> 2] | 0) + 64 >> 2] | 0) + 8 >> 2] | 0) + (c[z >> 2] << 2) >> 2] | 0);
	                                c[z >> 2] = (c[z >> 2] | 0) + 1
	                            }
	                            NN(F, c[(c[g >> 2] | 0) + 64 >> 2] | 0);
	                            c[(c[g >> 2] | 0) + 64 >> 2] = 0;
	                            if (!(c[A >> 2] | 0)) {
	                                E = 85;
	                                break
	                            }
	                        }
	                        if (c[(c[x >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0)c[(c[(c[x >> 2] | 0) + (c[k >> 2] << 2) >> 2] | 0) + 24 >> 2] = c[t >> 2];
	                        c[k >> 2] = (c[k >> 2] | 0) + 1
	                    }
	                    if ((E | 0) == 55)c[j >> 2] = -1; else if ((E | 0) == 61) {
	                        FN(c[g >> 2] | 0, 12, c[(c[r >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                        c[j >> 2] = -1;
	                        c[(c[g >> 2] | 0) + 60 >> 2] = c[o >> 2];
	                        break
	                    } else if ((E | 0) == 85) {
	                        y = c[g >> 2] | 0;
	                        if (!(c[r >> 2] | 0))FN(y, 12, 189560, 0, 0); else FN(y, 12, c[(c[r >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                        c[j >> 2] = -1;
	                        c[(c[g >> 2] | 0) + 60 >> 2] = c[o >> 2];
	                        break
	                    } else if ((E | 0) == 89)c[j >> 2] = -1;
	                    if (c[(c[g >> 2] | 0) + 60 >> 2] | 0)LN(c[g >> 2] | 0, c[(c[g >> 2] | 0) + 60 >> 2] | 0);
	                    c[(c[g >> 2] | 0) + 60 >> 2] = c[o >> 2];
	                    c[(c[(c[g >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2] = c[v >> 2];
	                    if (c[j >> 2] | 0) {
	                        FN(c[g >> 2] | 0, 11, 0, 0, 0);
	                        c[j >> 2] = -1
	                    }
	                } else {
	                    FN(c[g >> 2] | 0, 11, 0, 0, 0);
	                    c[j >> 2] = -1
	                } while (0);
	                c[(c[g >> 2] | 0) + 28 >> 2] = c[n >> 2];
	                c[r >> 2] = c[u >> 2];
	                while (1) {
	                    if (!(c[r >> 2] | 0))break;
	                    if ((c[r >> 2] | 0) == (c[s >> 2] | 0))break;
	                    if (!(c[(c[r >> 2] | 0) + 28 >> 2] | 0))break;
	                    c[(c[(c[r >> 2] | 0) + 28 >> 2] | 0) + 24 >> 2] = c[r >> 2];
	                    c[r >> 2] = c[(c[r >> 2] | 0) + 28 >> 2]
	                }
	                if ((c[j >> 2] | 0) == 0 ? (c[(c[g >> 2] | 0) + 48 >> 2] | 0) > (c[m >> 2] | 0) : 0)KO(c[g >> 2] | 0, c[m >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[w >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[x >> 2] | 0);
	                c[f >> 2] = c[j >> 2];
	                D = c[f >> 2] | 0;
	                i = e;
	                return D | 0
	            }

	            function RO(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f + 44 | 0;
	                h = f + 40 | 0;
	                j = f + 36 | 0;
	                k = f + 32 | 0;
	                l = f + 28 | 0;
	                m = f + 24 | 0;
	                n = f + 20 | 0;
	                o = f + 16 | 0;
	                p = f + 12 | 0;
	                q = f + 8 | 0;
	                r = f + 4 | 0;
	                s = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[p >> 2] = 0;
	                if ((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) {
	                    c[o >> 2] = c[(c[k >> 2] | 0) + 20 >> 2];
	                    do if (c[(c[o >> 2] | 0) + 12 >> 2] | 0) {
	                        if ((c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[c[(c[k >> 2] | 0) + 36 >> 2] >> 2] | 0) == 6 : 0) {
	                            c[m >> 2] = Ib[c[(c[o >> 2] | 0) + 12 >> 2] & 511](c[(c[o >> 2] | 0) + 4 >> 2] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0, c[j >> 2] | 0, p, c[l >> 2] | 0) | 0;
	                            break
	                        }
	                        c[m >> 2] = Ib[c[(c[o >> 2] | 0) + 12 >> 2] & 511](c[(c[o >> 2] | 0) + 4 >> 2] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0, c[j >> 2] | 0, 0, c[l >> 2] | 0) | 0
	                    } else c[m >> 2] = -1; while (0);
	                    if ((c[m >> 2] | 0) < 0) {
	                        FN(c[h >> 2] | 0, 2, c[(c[k >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                        if ((c[p >> 2] | 0) != 0 & (c[o >> 2] | 0) != 0 ? (c[(c[o >> 2] | 0) + 24 >> 2] | 0) != 0 : 0)Ab[c[(c[o >> 2] | 0) + 24 >> 2] & 511](c[(c[o >> 2] | 0) + 4 >> 2] | 0, c[p >> 2] | 0);
	                        c[g >> 2] = -1;
	                        t = c[g >> 2] | 0;
	                        i = f;
	                        return t | 0
	                    }
	                    do if ((c[m >> 2] | 0) != 1) {
	                        l = c[h >> 2] | 0;
	                        if ((c[m >> 2] | 0) == 2) {
	                            FN(l, 4, c[j >> 2] | 0, 0, 1);
	                            break
	                        } else {
	                            FN(l, 3, c[(c[k >> 2] | 0) + 8 >> 2] | 0, c[j >> 2] | 0, 1);
	                            c[m >> 2] = -1;
	                            break
	                        }
	                    } else c[m >> 2] = 0; while (0);
	                    c[q >> 2] = c[(c[k >> 2] | 0) + 36 >> 2];
	                    while (1) {
	                        if (!((c[m >> 2] | 0) == 0 & (c[q >> 2] | 0) != 0))break;
	                        if ((c[c[q >> 2] >> 2] | 0) != 6)break;
	                        if ((c[(c[o >> 2] | 0) + 20 >> 2] | 0) != 0 ? (c[n >> 2] = Bb[c[(c[o >> 2] | 0) + 20 >> 2] & 511](c[(c[o >> 2] | 0) + 4 >> 2] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0, c[(c[q >> 2] | 0) + 8 >> 2] | 0, c[(c[q >> 2] | 0) + 16 >> 2] | 0, c[j >> 2] | 0, c[p >> 2] | 0) | 0, (c[n >> 2] | 0) != 0) : 0)c[m >> 2] = -1;
	                        c[q >> 2] = c[(c[q >> 2] | 0) + 32 >> 2]
	                    }
	                    if ((c[m >> 2] | 0) == 0 ? (c[(c[k >> 2] | 0) + 24 >> 2] | 0) != 0 : 0) {
	                        c[r >> 2] = c[(c[(c[h >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2];
	                        c[s >> 2] = c[(c[(c[h >> 2] | 0) + 60 >> 2] | 0) + 24 >> 2];
	                        c[(c[(c[h >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2] = c[j >> 2];
	                        c[(c[(c[h >> 2] | 0) + 60 >> 2] | 0) + 24 >> 2] = 0;
	                        c[m >> 2] = SO(c[h >> 2] | 0, c[(c[k >> 2] | 0) + 24 >> 2] | 0) | 0;
	                        c[(c[(c[h >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2] = c[r >> 2];
	                        c[(c[(c[h >> 2] | 0) + 60 >> 2] | 0) + 24 >> 2] = c[s >> 2]
	                    }
	                    if ((c[p >> 2] | 0) != 0 & (c[o >> 2] | 0) != 0 ? (c[(c[o >> 2] | 0) + 24 >> 2] | 0) != 0 : 0)Ab[c[(c[o >> 2] | 0) + 24 >> 2] & 511](c[(c[o >> 2] | 0) + 4 >> 2] | 0, c[p >> 2] | 0);
	                    c[g >> 2] = c[m >> 2];
	                    t = c[g >> 2] | 0;
	                    i = f;
	                    return t | 0
	                }
	                c[g >> 2] = -1;
	                t = c[g >> 2] | 0;
	                i = f;
	                return t | 0
	            }

	            function SO(b, e) {
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0, J = 0, K = 0;
	                f = i;
	                i = i + 96 | 0;
	                g = f;
	                h = f + 92 | 0;
	                j = f + 88 | 0;
	                k = f + 84 | 0;
	                l = f + 80 | 0;
	                m = f + 76 | 0;
	                n = f + 72 | 0;
	                o = f + 68 | 0;
	                p = f + 64 | 0;
	                q = f + 60 | 0;
	                r = f + 56 | 0;
	                s = f + 52 | 0;
	                t = f + 48 | 0;
	                u = f + 44 | 0;
	                v = f + 40 | 0;
	                w = f + 36 | 0;
	                x = f + 32 | 0;
	                y = f + 28 | 0;
	                z = f + 24 | 0;
	                A = f + 20 | 0;
	                B = f + 16 | 0;
	                C = f + 12 | 0;
	                D = f + 8 | 0;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[l >> 2] = 0;
	                c[n >> 2] = c[(c[(c[j >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2];
	                a:do switch (c[c[k >> 2] >> 2] | 0) {
	                    case 17:
	                    {
	                        c[s >> 2] = c[(c[k >> 2] | 0) + 24 >> 2];
	                        c[m >> 2] = c[(c[j >> 2] | 0) + 28 >> 2];
	                        e = (c[j >> 2] | 0) + 28 | 0;
	                        c[e >> 2] = c[e >> 2] | 1;
	                        c[t >> 2] = c[(c[(c[j >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2];
	                        while (1) {
	                            if (!(c[s >> 2] | 0))break;
	                            c[l >> 2] = SO(c[j >> 2] | 0, c[s >> 2] | 0) | 0;
	                            if (!(c[l >> 2] | 0))break;
	                            c[(c[(c[j >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2] = c[t >> 2];
	                            c[s >> 2] = c[(c[s >> 2] | 0) + 32 >> 2]
	                        }
	                        c[(c[j >> 2] | 0) + 28 >> 2] = c[m >> 2];
	                        e = c[j >> 2] | 0;
	                        if (c[l >> 2] | 0) {
	                            if (c[e + 28 >> 2] & 1)break a;
	                            eO(c[j >> 2] | 0);
	                            break a
	                        } else {
	                            if ((c[e + 48 >> 2] | 0) <= 0)break a;
	                            KO(c[j >> 2] | 0, 0);
	                            break a
	                        }
	                        break
	                    }
	                    case 5:
	                    {
	                        c[l >> 2] = RO(c[j >> 2] | 0, c[n >> 2] | 0, c[k >> 2] | 0, c[(c[(c[j >> 2] | 0) + 60 >> 2] | 0) + 4 >> 2] | 0) | 0;
	                        if (!(c[l >> 2] | 0))hP(c[j >> 2] | 0) | 0;
	                        break
	                    }
	                    case 16:
	                    {
	                        c[l >> 2] = iP(c[j >> 2] | 0, c[(c[k >> 2] | 0) + 24 >> 2] | 0) | 0;
	                        if (!(c[l >> 2] | 0))E = 78;
	                        break
	                    }
	                    case 15:
	                    {
	                        E = 78;
	                        break
	                    }
	                    case 8:
	                    {
	                        c[u >> 2] = c[(c[k >> 2] | 0) + 24 >> 2];
	                        c[v >> 2] = c[(c[(c[j >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2];
	                        c[w >> 2] = c[(c[(c[j >> 2] | 0) + 60 >> 2] | 0) + 24 >> 2];
	                        c[x >> 2] = my(c[v >> 2] | 0) | 0;
	                        if (!(c[x >> 2] | 0))c[x >> 2] = my(188112) | 0;
	                        if (!(c[x >> 2] | 0)) {
	                            FN(c[j >> 2] | 0, 6, 0, 0, 0);
	                            c[h >> 2] = -1;
	                            F = c[h >> 2] | 0;
	                            i = f;
	                            return F | 0
	                        }
	                        c[y >> 2] = c[x >> 2];
	                        b:while (1) {
	                            G = c[y >> 2] | 0;
	                            if (!(d[c[y >> 2] >> 0] | 0))break;
	                            do if ((d[G >> 0] | 0 | 0) != 32) {
	                                if (9 <= (d[c[y >> 2] >> 0] | 0 | 0) ? (d[c[y >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                                if ((d[c[y >> 2] >> 0] | 0 | 0) != 13) {
	                                    c[y >> 2] = (c[y >> 2] | 0) + 1;
	                                    continue b
	                                }
	                            } while (0);
	                            a[c[y >> 2] >> 0] = 0;
	                            c[y >> 2] = (c[y >> 2] | 0) + 1;
	                            while (1) {
	                                do if ((d[c[y >> 2] >> 0] | 0 | 0) != 32) {
	                                    if (9 <= (d[c[y >> 2] >> 0] | 0 | 0) ? (d[c[y >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                                    if ((d[c[y >> 2] >> 0] | 0 | 0) != 13)continue b
	                                } while (0);
	                                e = c[y >> 2] | 0;
	                                c[y >> 2] = e + 1;
	                                a[e >> 0] = 0
	                            }
	                        }
	                        c[(c[(c[j >> 2] | 0) + 60 >> 2] | 0) + 24 >> 2] = G;
	                        c[y >> 2] = c[x >> 2];
	                        while (1) {
	                            if (!(d[c[y >> 2] >> 0] | 0))H = (c[y >> 2] | 0) != (c[(c[(c[j >> 2] | 0) + 60 >> 2] | 0) + 24 >> 2] | 0); else H = 0;
	                            I = c[y >> 2] | 0;
	                            if (!H)break;
	                            c[y >> 2] = I + 1
	                        }
	                        c[(c[(c[j >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2] = I;
	                        while (1) {
	                            if (!(c[u >> 2] | 0))break;
	                            if ((c[(c[(c[j >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2] | 0) == (c[(c[(c[j >> 2] | 0) + 60 >> 2] | 0) + 24 >> 2] | 0))c[(c[(c[j >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2] = 0;
	                            c[l >> 2] = SO(c[j >> 2] | 0, c[u >> 2] | 0) | 0;
	                            if (c[l >> 2] | 0)break;
	                            c[u >> 2] = c[(c[u >> 2] | 0) + 32 >> 2]
	                        }
	                        if (((c[l >> 2] | 0) == 0 ? (c[(c[(c[j >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) ? (c[(c[(c[j >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2] | 0) != (c[(c[(c[j >> 2] | 0) + 60 >> 2] | 0) + 24 >> 2] | 0) : 0) {
	                            FN(c[j >> 2] | 0, 8, c[(c[(c[j >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2] | 0, 0, 0);
	                            c[l >> 2] = -1
	                        }
	                        zb[c[135736 >> 2] & 511](c[x >> 2] | 0);
	                        c[(c[(c[j >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2] = c[v >> 2];
	                        c[(c[(c[j >> 2] | 0) + 60 >> 2] | 0) + 24 >> 2] = c[w >> 2];
	                        break
	                    }
	                    case 7:
	                    {
	                        do if (!(qy(c[n >> 2] | 0, c[(c[k >> 2] | 0) + 16 >> 2] | 0) | 0)) {
	                            if (!(c[(c[k >> 2] | 0) + 8 >> 2] | 0)) {
	                                c[q >> 2] = SN(c[j >> 2] | 0, c[(c[k >> 2] | 0) + 16 >> 2] | 0) | 0;
	                                c[r >> 2] = SN(c[j >> 2] | 0, c[n >> 2] | 0) | 0;
	                                if (!(!((c[q >> 2] | 0) == 0 | (c[r >> 2] | 0) == 0) ? (qy(c[q >> 2] | 0, c[r >> 2] | 0) | 0) != 0 : 0))c[l >> 2] = -1;
	                                if (c[q >> 2] | 0)zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                                if (!(c[r >> 2] | 0))break;
	                                zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                                break
	                            }
	                            c[p >> 2] = c[(c[k >> 2] | 0) + 20 >> 2];
	                            if ((c[p >> 2] | 0) != 0 ? (c[(c[p >> 2] | 0) + 16 >> 2] | 0) != 0 : 0)c[l >> 2] = ub[c[(c[p >> 2] | 0) + 16 >> 2] & 511](c[(c[p >> 2] | 0) + 4 >> 2] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0, c[(c[k >> 2] | 0) + 16 >> 2] | 0, c[(c[k >> 2] | 0) + 4 >> 2] | 0, c[(c[k >> 2] | 0) + 36 >> 2] | 0, c[n >> 2] | 0, c[c[(c[j >> 2] | 0) + 60 >> 2] >> 2] | 0) | 0; else c[l >> 2] = -1;
	                            if ((c[l >> 2] | 0) < 0) {
	                                FN(c[j >> 2] | 0, 5, c[(c[k >> 2] | 0) + 8 >> 2] | 0, 0, 0);
	                                c[h >> 2] = -1;
	                                F = c[h >> 2] | 0;
	                                i = f;
	                                return F | 0
	                            }
	                            if ((c[l >> 2] | 0) == 1) {
	                                c[l >> 2] = 0;
	                                break
	                            } else {
	                                c[l >> 2] = -1;
	                                break
	                            }
	                        } while (0);
	                        if (!(c[l >> 2] | 0))hP(c[j >> 2] | 0) | 0;
	                        break
	                    }
	                    case 0:
	                    {
	                        if ((c[n >> 2] | 0) != 0 ? (d[c[n >> 2] >> 0] | 0 | 0) != 0 : 0) {
	                            c[o >> 2] = 0;
	                            while (1) {
	                                do if ((d[(c[n >> 2] | 0) + (c[o >> 2] | 0) >> 0] | 0 | 0) == 32)J = 1; else {
	                                    if (9 <= (d[(c[n >> 2] | 0) + (c[o >> 2] | 0) >> 0] | 0 | 0) ? (d[(c[n >> 2] | 0) + (c[o >> 2] | 0) >> 0] | 0 | 0) <= 10 : 0) {
	                                        J = 1;
	                                        break
	                                    }
	                                    J = (d[(c[n >> 2] | 0) + (c[o >> 2] | 0) >> 0] | 0 | 0) == 13
	                                } while (0);
	                                K = c[o >> 2] | 0;
	                                if (!J)break;
	                                c[o >> 2] = K + 1
	                            }
	                            if (d[(c[n >> 2] | 0) + K >> 0] | 0)c[l >> 2] = -1
	                        }
	                        break
	                    }
	                    case 18:
	                    case 10:
	                    {
	                        c[D >> 2] = c[(c[k >> 2] | 0) + 24 >> 2];
	                        while (1) {
	                            if (!(c[D >> 2] | 0))break a;
	                            c[l >> 2] = SO(c[j >> 2] | 0, c[D >> 2] | 0) | 0;
	                            if (c[l >> 2] | 0)break;
	                            c[l >> 2] = 0;
	                            c[D >> 2] = c[(c[D >> 2] | 0) + 32 >> 2]
	                        }
	                        c[l >> 2] = -1;
	                        break
	                    }
	                    case 13:
	                    case 11:
	                    {
	                        e = c[j >> 2] | 0;
	                        if (!(c[(c[k >> 2] | 0) + 24 >> 2] | 0)) {
	                            FN(e, 7, 0, 0, 0);
	                            c[l >> 2] = -1;
	                            break a
	                        } else {
	                            c[l >> 2] = SO(e, c[(c[k >> 2] | 0) + 24 >> 2] | 0) | 0;
	                            break a
	                        }
	                        break
	                    }
	                    case 3:
	                        break;
	                    case 2:
	                    {
	                        c[C >> 2] = c[(c[k >> 2] | 0) + 24 >> 2];
	                        while (1) {
	                            if (!(c[C >> 2] | 0))break a;
	                            c[l >> 2] = SO(c[j >> 2] | 0, c[C >> 2] | 0) | 0;
	                            if (!(c[l >> 2] | 0))break;
	                            c[l >> 2] = 0;
	                            c[C >> 2] = c[(c[C >> 2] | 0) + 32 >> 2]
	                        }
	                        c[l >> 2] = -1;
	                        break
	                    }
	                    case 14:
	                    {
	                        if ((c[(c[(c[j >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2] | 0) != 0 ? (d[c[(c[(c[j >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2] >> 0] | 0 | 0) != 0 : 0) {
	                            c[m >> 2] = c[(c[j >> 2] | 0) + 28 >> 2];
	                            e = (c[j >> 2] | 0) + 28 | 0;
	                            c[e >> 2] = c[e >> 2] | 1;
	                            c[B >> 2] = c[(c[(c[j >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2];
	                            c[l >> 2] = SO(c[j >> 2] | 0, c[(c[k >> 2] | 0) + 24 >> 2] | 0) | 0;
	                            c[(c[j >> 2] | 0) + 28 >> 2] = c[m >> 2];
	                            if (!(c[l >> 2] | 0)) {
	                                if ((c[(c[j >> 2] | 0) + 48 >> 2] | 0) <= 0)break a;
	                                KO(c[j >> 2] | 0, 0);
	                                break a
	                            }
	                            c[(c[(c[j >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2] = c[B >> 2];
	                            if ((c[(c[j >> 2] | 0) + 48 >> 2] | 0) > 0)KO(c[j >> 2] | 0, 0);
	                            c[l >> 2] = 0;
	                            break a
	                        }
	                        c[l >> 2] = 0;
	                        break
	                    }
	                    default:
	                    {
	                        e = c[33976] | 0;
	                        b = c[33980] | 0;
	                        c[g >> 2] = 189496;
	                        c[g + 4 >> 2] = 8982;
	                        Db[e & 511](b, 189464, g);
	                        c[l >> 2] = -1
	                    }
	                } while (0);
	                do if ((E | 0) == 78) {
	                    if ((c[(c[(c[j >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2] | 0) != 0 ? (d[c[(c[(c[j >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2] >> 0] | 0 | 0) != 0 : 0) {
	                        c[m >> 2] = c[(c[j >> 2] | 0) + 28 >> 2];
	                        g = (c[j >> 2] | 0) + 28 | 0;
	                        c[g >> 2] = c[g >> 2] | 1;
	                        c[z >> 2] = c[(c[(c[j >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2];
	                        c[A >> 2] = 0;
	                        while (1) {
	                            if (!(c[z >> 2] | 0))break;
	                            if ((c[z >> 2] | 0) == (c[(c[(c[j >> 2] | 0) + 60 >> 2] | 0) + 24 >> 2] | 0))break;
	                            if ((c[A >> 2] | 0) == (c[z >> 2] | 0))break;
	                            c[A >> 2] = c[z >> 2];
	                            c[l >> 2] = iP(c[j >> 2] | 0, c[(c[k >> 2] | 0) + 24 >> 2] | 0) | 0;
	                            if (c[l >> 2] | 0) {
	                                E = 86;
	                                break
	                            }
	                            c[z >> 2] = c[(c[(c[j >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2]
	                        }
	                        if ((E | 0) == 86) {
	                            c[(c[(c[j >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2] = c[A >> 2];
	                            c[l >> 2] = 0
	                        }
	                        c[(c[j >> 2] | 0) + 28 >> 2] = c[m >> 2];
	                        if ((c[(c[j >> 2] | 0) + 48 >> 2] | 0) <= 0)break;
	                        KO(c[j >> 2] | 0, 0);
	                        break
	                    }
	                    c[l >> 2] = 0
	                } while (0);
	                c[h >> 2] = c[l >> 2];
	                F = c[h >> 2] | 0;
	                i = f;
	                return F | 0
	            }

	            function TO(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[e + 12 >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                do if (!((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0)) {
	                    if ((c[g >> 2] | 0) == (c[h >> 2] | 0)) {
	                        c[f >> 2] = 1;
	                        break
	                    }
	                    if ((c[c[g >> 2] >> 2] | 0) != (c[c[h >> 2] >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        break
	                    }
	                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != (c[(c[h >> 2] | 0) + 4 >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        break
	                    }
	                    if ((c[(c[g >> 2] | 0) + 16 >> 2] | 0) != (c[(c[h >> 2] | 0) + 16 >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        break
	                    }
	                    if ((c[(c[g >> 2] | 0) + 8 >> 2] | 0) != (c[(c[h >> 2] | 0) + 8 >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        break
	                    }
	                    if ((c[(c[g >> 2] | 0) + 24 >> 2] | 0) != (c[(c[h >> 2] | 0) + 24 >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        break
	                    }
	                    if ((c[(c[g >> 2] | 0) + 20 >> 2] | 0) != (c[(c[h >> 2] | 0) + 20 >> 2] | 0) ? (qy(c[(c[g >> 2] | 0) + 20 >> 2] | 0, c[(c[h >> 2] | 0) + 20 >> 2] | 0) | 0) == 0 : 0) {
	                        c[f >> 2] = 0;
	                        break
	                    }
	                    c[j >> 2] = 0;
	                    while (1) {
	                        if ((c[j >> 2] | 0) >= (c[(c[g >> 2] | 0) + 8 >> 2] | 0)) {
	                            k = 23;
	                            break
	                        }
	                        if ((c[(c[(c[g >> 2] | 0) + 28 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0) != (c[(c[(c[h >> 2] | 0) + 28 >> 2] | 0) + (c[j >> 2] << 2) >> 2] | 0)) {
	                            k = 21;
	                            break
	                        }
	                        c[j >> 2] = (c[j >> 2] | 0) + 1
	                    }
	                    if ((k | 0) == 21) {
	                        c[f >> 2] = 0;
	                        break
	                    } else if ((k | 0) == 23) {
	                        c[f >> 2] = 1;
	                        break
	                    }
	                } else c[f >> 2] = 0; while (0);
	                i = e;
	                return c[f >> 2] | 0
	            }

	            function UO(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[(c[f >> 2] | 0) + 108 >> 2] | 0) == 0 ? (c[(c[f >> 2] | 0) + 104 >> 2] = 4, c[(c[f >> 2] | 0) + 100 >> 2] = 0, b = Cb[c[135744 >> 2] & 511](c[(c[f >> 2] | 0) + 104 >> 2] << 2) | 0, c[(c[f >> 2] | 0) + 108 >> 2] = b, (c[(c[f >> 2] | 0) + 108 >> 2] | 0) == 0) : 0) {
	                    xN(c[f >> 2] | 0, 196496);
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                if ((c[(c[f >> 2] | 0) + 100 >> 2] | 0) >= (c[(c[f >> 2] | 0) + 104 >> 2] | 0) ? (b = (c[f >> 2] | 0) + 104 | 0, c[b >> 2] = c[b >> 2] << 1, b = Hb[c[135760 >> 2] & 511](c[(c[f >> 2] | 0) + 108 >> 2] | 0, c[(c[f >> 2] | 0) + 104 >> 2] << 2) | 0, c[(c[f >> 2] | 0) + 108 >> 2] = b, (c[(c[f >> 2] | 0) + 108 >> 2] | 0) == 0) : 0) {
	                    xN(c[f >> 2] | 0, 196496);
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                c[(c[(c[f >> 2] | 0) + 108 >> 2] | 0) + (c[(c[f >> 2] | 0) + 100 >> 2] << 2) >> 2] = c[g >> 2];
	                c[(c[f >> 2] | 0) + 96 >> 2] = c[g >> 2];
	                g = (c[f >> 2] | 0) + 100 | 0;
	                f = c[g >> 2] | 0;
	                c[g >> 2] = f + 1;
	                c[e >> 2] = f;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function VO(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if ((c[(c[e >> 2] | 0) + 100 >> 2] | 0) <= 0) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = (c[e >> 2] | 0) + 100 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + -1;
	                a = c[e >> 2] | 0;
	                if ((c[(c[e >> 2] | 0) + 100 >> 2] | 0) > 0)c[(c[e >> 2] | 0) + 96 >> 2] = c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + ((c[a + 100 >> 2] | 0) - 1 << 2) >> 2]; else c[a + 96 >> 2] = 0;
	                c[f >> 2] = c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + (c[(c[e >> 2] | 0) + 100 >> 2] << 2) >> 2];
	                c[(c[(c[e >> 2] | 0) + 108 >> 2] | 0) + (c[(c[e >> 2] | 0) + 100 >> 2] << 2) >> 2] = 0;
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function WO(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[(c[f >> 2] | 0) + 124 >> 2] | 0) == 0 ? (c[(c[f >> 2] | 0) + 120 >> 2] = 4, c[(c[f >> 2] | 0) + 116 >> 2] = 0, b = Cb[c[135744 >> 2] & 511](c[(c[f >> 2] | 0) + 120 >> 2] << 2) | 0, c[(c[f >> 2] | 0) + 124 >> 2] = b, (c[(c[f >> 2] | 0) + 124 >> 2] | 0) == 0) : 0) {
	                    xN(c[f >> 2] | 0, 196088);
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                if ((c[(c[f >> 2] | 0) + 116 >> 2] | 0) >= (c[(c[f >> 2] | 0) + 120 >> 2] | 0) ? (b = (c[f >> 2] | 0) + 120 | 0, c[b >> 2] = c[b >> 2] << 1, b = Hb[c[135760 >> 2] & 511](c[(c[f >> 2] | 0) + 124 >> 2] | 0, c[(c[f >> 2] | 0) + 120 >> 2] << 2) | 0, c[(c[f >> 2] | 0) + 124 >> 2] = b, (c[(c[f >> 2] | 0) + 124 >> 2] | 0) == 0) : 0) {
	                    xN(c[f >> 2] | 0, 196088);
	                    c[e >> 2] = 0;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                c[(c[(c[f >> 2] | 0) + 124 >> 2] | 0) + (c[(c[f >> 2] | 0) + 116 >> 2] << 2) >> 2] = c[g >> 2];
	                c[(c[f >> 2] | 0) + 112 >> 2] = c[g >> 2];
	                g = (c[f >> 2] | 0) + 116 | 0;
	                f = c[g >> 2] | 0;
	                c[g >> 2] = f + 1;
	                c[e >> 2] = f;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function XO(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if ((c[(c[e >> 2] | 0) + 116 >> 2] | 0) <= 0) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = (c[e >> 2] | 0) + 116 | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + -1;
	                a = c[e >> 2] | 0;
	                if ((c[(c[e >> 2] | 0) + 116 >> 2] | 0) > 0)c[(c[e >> 2] | 0) + 112 >> 2] = c[(c[(c[e >> 2] | 0) + 124 >> 2] | 0) + ((c[a + 116 >> 2] | 0) - 1 << 2) >> 2]; else c[a + 112 >> 2] = 0;
	                c[f >> 2] = c[(c[(c[e >> 2] | 0) + 124 >> 2] | 0) + (c[(c[e >> 2] | 0) + 116 >> 2] << 2) >> 2];
	                c[(c[(c[e >> 2] | 0) + 124 >> 2] | 0) + (c[(c[e >> 2] | 0) + 116 >> 2] << 2) >> 2] = 0;
	                c[d >> 2] = c[f >> 2];
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function YO(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f + 36 | 0;
	                h = f + 28 | 0;
	                j = f + 24 | 0;
	                k = f + 20 | 0;
	                l = f + 16 | 0;
	                m = f + 12 | 0;
	                n = f + 8 | 0;
	                o = f + 4 | 0;
	                p = f;
	                c[g >> 2] = a;
	                c[f + 32 >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = e;
	                c[k >> 2] = 0;
	                c[l >> 2] = c[h >> 2];
	                while (1) {
	                    if (!(c[l >> 2] | 0))break;
	                    c[m >> 2] = c[(c[l >> 2] | 0) + 24 >> 2];
	                    if (((((c[j >> 2] | 0) == 0 & (c[l >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[l >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[l >> 2] | 0) + 8 >> 2] | 0, 190048) | 0) != 0 : 0) ? (qy(c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                        c[k >> 2] = 1;
	                        Qh(c[l >> 2] | 0);
	                        Rh(c[l >> 2] | 0)
	                    } else q = 9;
	                    do if ((q | 0) == 9) {
	                        q = 0;
	                        if (((((c[j >> 2] | 0) != 0 & (c[l >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[l >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[l >> 2] | 0) + 8 >> 2] | 0, 195016) | 0) != 0 : 0) ? (qy(c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                            c[n >> 2] = Yi(c[l >> 2] | 0, 192176) | 0;
	                            ZO(c[n >> 2] | 0);
	                            if (!(c[n >> 2] | 0))break;
	                            if (qy(c[j >> 2] | 0, c[n >> 2] | 0) | 0) {
	                                c[k >> 2] = 1;
	                                Qh(c[l >> 2] | 0);
	                                Rh(c[l >> 2] | 0)
	                            }
	                            zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                            break
	                        }
	                        if ((((((((((c[l >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[l >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[l >> 2] | 0) + 8 >> 2] | 0, 195024) | 0) != 0 : 0) ? (qy(c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) ? (c[o >> 2] = 0, c[p >> 2] = c[(c[l >> 2] | 0) + 52 >> 2], (c[p >> 2] | 0) != 0) : 0) ? (c[(c[p >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (c[(c[(c[p >> 2] | 0) + 8 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (qy(c[(c[(c[(c[p >> 2] | 0) + 8 >> 2] | 0) + 12 >> 2] | 0) + 8 >> 2] | 0, 190264) | 0) != 0 : 0) ? (h = c[g >> 2] | 0, e = c[o >> 2] | 0, d = c[(Pi(c[(c[p >> 2] | 0) + 8 >> 2] | 0) | 0) + 12 >> 2] | 0, (YO(h, e, d, c[j >> 2] | 0) | 0) == 1) : 0)c[k >> 2] = 1
	                    } while (0);
	                    c[l >> 2] = c[m >> 2]
	                }
	                i = f;
	                return c[k >> 2] | 0
	            }

	            function ZO(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = b;
	                c[g >> 2] = c[f >> 2];
	                c[h >> 2] = c[f >> 2];
	                if (!(c[f >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                while (1) {
	                    do if ((d[c[h >> 2] >> 0] | 0 | 0) == 32)j = 1; else {
	                        if (9 <= (d[c[h >> 2] >> 0] | 0 | 0) ? (d[c[h >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            j = 1;
	                            break
	                        }
	                        j = (d[c[h >> 2] >> 0] | 0 | 0) == 13
	                    } while (0);
	                    k = c[h >> 2] | 0;
	                    if (!j)break;
	                    c[h >> 2] = k + 1
	                }
	                if ((k | 0) == (c[g >> 2] | 0)) {
	                    while (1) {
	                        if (d[c[h >> 2] >> 0] | 0) {
	                            do if ((d[c[h >> 2] >> 0] | 0 | 0) == 32)l = 1; else {
	                                if (9 <= (d[c[h >> 2] >> 0] | 0 | 0) ? (d[c[h >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                    l = 1;
	                                    break
	                                }
	                                l = (d[c[h >> 2] >> 0] | 0 | 0) == 13
	                            } while (0);
	                            m = l ^ 1
	                        } else m = 0;
	                        k = c[h >> 2] | 0;
	                        if (m) {
	                            c[h >> 2] = k + 1;
	                            continue
	                        }
	                        if (!(d[k >> 0] | 0)) {
	                            n = 46;
	                            break
	                        }
	                        c[g >> 2] = c[h >> 2];
	                        while (1) {
	                            do if ((d[c[h >> 2] >> 0] | 0 | 0) == 32)o = 1; else {
	                                if (9 <= (d[c[h >> 2] >> 0] | 0 | 0) ? (d[c[h >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                    o = 1;
	                                    break
	                                }
	                                o = (d[c[h >> 2] >> 0] | 0 | 0) == 13
	                            } while (0);
	                            p = c[h >> 2] | 0;
	                            if (!o)break;
	                            c[h >> 2] = p + 1
	                        }
	                        if (!(d[p >> 0] | 0))break
	                    }
	                    if ((n | 0) == 46) {
	                        i = e;
	                        return
	                    }
	                    a[c[g >> 2] >> 0] = 0;
	                    i = e;
	                    return
	                }
	                while (1) {
	                    if (d[c[h >> 2] >> 0] | 0) {
	                        do if ((d[c[h >> 2] >> 0] | 0 | 0) == 32)q = 1; else {
	                            if (9 <= (d[c[h >> 2] >> 0] | 0 | 0) ? (d[c[h >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                q = 1;
	                                break
	                            }
	                            q = (d[c[h >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        r = q ^ 1
	                    } else r = 0;
	                    p = c[h >> 2] | 0;
	                    if (r) {
	                        c[h >> 2] = p + 1;
	                        o = a[p >> 0] | 0;
	                        m = c[g >> 2] | 0;
	                        c[g >> 2] = m + 1;
	                        a[m >> 0] = o;
	                        continue
	                    }
	                    if (!(d[p >> 0] | 0)) {
	                        n = 36;
	                        break
	                    }
	                    while (1) {
	                        do if ((d[c[h >> 2] >> 0] | 0 | 0) == 32)s = 1; else {
	                            if (9 <= (d[c[h >> 2] >> 0] | 0 | 0) ? (d[c[h >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                s = 1;
	                                break
	                            }
	                            s = (d[c[h >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        t = c[h >> 2] | 0;
	                        if (!s)break;
	                        c[h >> 2] = t + 1
	                    }
	                    if (!(d[t >> 0] | 0)) {
	                        n = 44;
	                        break
	                    }
	                    p = c[h >> 2] | 0;
	                    c[h >> 2] = p + 1;
	                    o = a[p >> 0] | 0;
	                    p = c[g >> 2] | 0;
	                    c[g >> 2] = p + 1;
	                    a[p >> 0] = o
	                }
	                if ((n | 0) == 36) {
	                    a[c[g >> 2] >> 0] = 0;
	                    i = e;
	                    return
	                } else if ((n | 0) == 44) {
	                    a[c[g >> 2] >> 0] = 0;
	                    i = e;
	                    return
	                }
	            }

	            function _O(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                d = i;
	                i = i + 48 | 0;
	                e = d + 32 | 0;
	                f = d + 28 | 0;
	                g = d + 24 | 0;
	                h = d + 20 | 0;
	                j = d + 16 | 0;
	                k = d + 12 | 0;
	                l = d + 8 | 0;
	                m = d + 4 | 0;
	                n = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[j >> 2] = 0;
	                c[h >> 2] = Yi(c[g >> 2] | 0, 192176) | 0;
	                do if (c[h >> 2] | 0) {
	                    ZO(c[h >> 2] | 0);
	                    if (Eh(c[h >> 2] | 0, 0) | 0)zN(c[f >> 2] | 0, c[g >> 2] | 0, 1049, 195200, c[h >> 2] | 0, 0);
	                    c[l >> 2] = DN(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                    if (!(c[l >> 2] | 0)) {
	                        zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                        c[e >> 2] = -1;
	                        o = c[e >> 2] | 0;
	                        i = d;
	                        return o | 0
	                    }
	                    c[c[l >> 2] >> 2] = 10;
	                    c[(c[l >> 2] | 0) + 8 >> 2] = c[h >> 2];
	                    b = c[f >> 2] | 0;
	                    if (!(c[(c[g >> 2] | 0) + 12 >> 2] | 0))zN(b, c[g >> 2] | 0, 1012, 195240, 0, 0); else {
	                        c[m >> 2] = c[b + 44 >> 2];
	                        c[(c[f >> 2] | 0) + 44 >> 2] = c[h >> 2];
	                        b = xO(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] | 0, 0) | 0;
	                        c[(c[l >> 2] | 0) + 24 >> 2] = b;
	                        c[(c[f >> 2] | 0) + 44 >> 2] = c[m >> 2]
	                    }
	                    if (!(c[(c[(c[f >> 2] | 0) + 24 >> 2] | 0) + 24 >> 2] | 0)) {
	                        b = Ij(10) | 0;
	                        c[(c[(c[f >> 2] | 0) + 24 >> 2] | 0) + 24 >> 2] = b
	                    }
	                    b = c[f >> 2] | 0;
	                    if (!(c[(c[(c[f >> 2] | 0) + 24 >> 2] | 0) + 24 >> 2] | 0)) {
	                        zN(b, c[g >> 2] | 0, 1011, 195264, 0, 0);
	                        c[j >> 2] = -1;
	                        break
	                    }
	                    c[k >> 2] = Lj(c[(c[b + 24 >> 2] | 0) + 24 >> 2] | 0, c[h >> 2] | 0, c[l >> 2] | 0) | 0;
	                    if ((c[k >> 2] | 0) < 0) {
	                        c[n >> 2] = Rj(c[(c[(c[f >> 2] | 0) + 24 >> 2] | 0) + 24 >> 2] | 0, c[h >> 2] | 0) | 0;
	                        if (!(c[n >> 2] | 0)) {
	                            zN(c[f >> 2] | 0, c[g >> 2] | 0, 1011, 195304, c[h >> 2] | 0, 0);
	                            c[j >> 2] = -1;
	                            break
	                        }
	                        while (1) {
	                            if (!(c[(c[n >> 2] | 0) + 44 >> 2] | 0))break;
	                            c[n >> 2] = c[(c[n >> 2] | 0) + 44 >> 2]
	                        }
	                        c[(c[n >> 2] | 0) + 44 >> 2] = c[l >> 2]
	                    }
	                } else zN(c[f >> 2] | 0, c[g >> 2] | 0, 1014, 195176, 0, 0); while (0);
	                c[e >> 2] = c[j >> 2];
	                o = c[e >> 2] | 0;
	                i = d;
	                return o | 0
	            }

	            function $O(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 24 | 0;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                l = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[k >> 2] = 0;
	                c[h >> 2] = c[(c[g >> 2] | 0) + 52 >> 2];
	                if (!(c[h >> 2] | 0)) {
	                    zN(c[f >> 2] | 0, c[g >> 2] | 0, 1042, 195072, 0, 0);
	                    c[e >> 2] = -1;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                c[j >> 2] = Pi(c[(c[h >> 2] | 0) + 8 >> 2] | 0) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    zN(c[f >> 2] | 0, c[g >> 2] | 0, 1022, 195104, 0, 0);
	                    c[e >> 2] = -1;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                if (!(qy(c[(c[j >> 2] | 0) + 8 >> 2] | 0, 190264) | 0)) {
	                    zN(c[f >> 2] | 0, c[g >> 2] | 0, 1038, 195136, 0, 0);
	                    c[e >> 2] = -1;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                if ((c[(c[j >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[l >> 2] = tO(c[f >> 2] | 0, c[(c[j >> 2] | 0) + 12 >> 2] | 0) | 0, (c[l >> 2] | 0) != 0) : 0)c[k >> 2] = -1;
	                if ((c[(c[g >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[l >> 2] = tO(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] | 0) | 0, (c[l >> 2] | 0) != 0) : 0)c[k >> 2] = -1;
	                c[e >> 2] = c[k >> 2];
	                m = c[e >> 2] | 0;
	                i = d;
	                return m | 0
	            }

	            function aP(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 28 | 0;
	                f = d + 24 | 0;
	                g = d + 20 | 0;
	                h = d + 16 | 0;
	                j = d + 12 | 0;
	                k = d + 8 | 0;
	                l = d + 4 | 0;
	                m = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = DN(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                c[c[h >> 2] >> 2] = 4;
	                c[(c[h >> 2] | 0) + 28 >> 2] = c[(c[f >> 2] | 0) + 48 >> 2];
	                c[l >> 2] = c[(c[g >> 2] | 0) + 12 >> 2];
	                b = c[f >> 2] | 0;
	                if (!(c[l >> 2] | 0)) {
	                    zN(b, c[g >> 2] | 0, 1017, 194024, 0, 0);
	                    c[e >> 2] = c[h >> 2];
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                c[j >> 2] = jP(b, c[l >> 2] | 0, c[h >> 2] | 0) | 0;
	                if (c[j >> 2] | 0)c[l >> 2] = c[(c[l >> 2] | 0) + 24 >> 2];
	                b = c[f >> 2] | 0;
	                if (!(c[l >> 2] | 0)) {
	                    zN(b, c[g >> 2] | 0, 1020, 194080, 0, 0);
	                    c[e >> 2] = c[h >> 2];
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                c[m >> 2] = c[b + 44 >> 2];
	                c[(c[f >> 2] | 0) + 44 >> 2] = 0;
	                c[k >> 2] = 0;
	                while (1) {
	                    if (!(c[l >> 2] | 0))break;
	                    c[j >> 2] = bP(c[f >> 2] | 0, c[l >> 2] | 0) | 0;
	                    a:do if (c[j >> 2] | 0) {
	                        c[(c[j >> 2] | 0) + 28 >> 2] = c[h >> 2];
	                        switch (c[c[j >> 2] >> 2] | 0) {
	                            case 20:
	                            {
	                                zN(c[f >> 2] | 0, c[g >> 2] | 0, 1018, 194128, 0, 0);
	                                break a;
	                                break
	                            }
	                            case 9:
	                            {
	                                c[(c[j >> 2] | 0) + 32 >> 2] = c[(c[h >> 2] | 0) + 36 >> 2];
	                                c[(c[h >> 2] | 0) + 36 >> 2] = c[j >> 2];
	                                break a;
	                                break
	                            }
	                            case 19:
	                            case 18:
	                            case 17:
	                            case 14:
	                            case 16:
	                            case 15:
	                            case 10:
	                            case 12:
	                            case 13:
	                            case 11:
	                            case 8:
	                            case 7:
	                            case 5:
	                            case 4:
	                            case 3:
	                            case 1:
	                            case 0:
	                            {
	                                if (!(c[k >> 2] | 0)) {
	                                    b = c[j >> 2] | 0;
	                                    c[k >> 2] = b;
	                                    c[(c[h >> 2] | 0) + 24 >> 2] = b;
	                                    break a
	                                }
	                                do if ((c[c[k >> 2] >> 2] | 0) == 4 ? (c[(c[h >> 2] | 0) + 24 >> 2] | 0) == (c[k >> 2] | 0) : 0) {
	                                    b = DN(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                                    c[(c[h >> 2] | 0) + 24 >> 2] = b;
	                                    if (c[(c[h >> 2] | 0) + 24 >> 2] | 0) {
	                                        c[c[(c[h >> 2] | 0) + 24 >> 2] >> 2] = 18;
	                                        c[(c[(c[h >> 2] | 0) + 24 >> 2] | 0) + 24 >> 2] = c[k >> 2];
	                                        break
	                                    } else {
	                                        c[(c[h >> 2] | 0) + 24 >> 2] = c[k >> 2];
	                                        break
	                                    }
	                                } while (0);
	                                c[(c[k >> 2] | 0) + 32 >> 2] = c[j >> 2];
	                                c[k >> 2] = c[j >> 2];
	                                break a;
	                                break
	                            }
	                            case -1:
	                            {
	                                zN(c[f >> 2] | 0, c[g >> 2] | 0, 1018, 194272, 0, 0);
	                                break a;
	                                break
	                            }
	                            case 6:
	                            {
	                                zN(c[f >> 2] | 0, c[g >> 2] | 0, 1018, 194176, 0, 0);
	                                break a;
	                                break
	                            }
	                            case 2:
	                            {
	                                zN(c[f >> 2] | 0, c[g >> 2] | 0, 1018, 194224, 0, 0);
	                                break a;
	                                break
	                            }
	                            default:
	                                break a
	                        }
	                    } while (0);
	                    c[l >> 2] = c[(c[l >> 2] | 0) + 24 >> 2]
	                }
	                c[(c[f >> 2] | 0) + 44 >> 2] = c[m >> 2];
	                c[e >> 2] = c[h >> 2];
	                n = c[e >> 2] | 0;
	                i = d;
	                return n | 0
	            }

	            function bP(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                d = i;
	                i = i + 48 | 0;
	                e = d + 44 | 0;
	                f = d + 40 | 0;
	                g = d + 36 | 0;
	                h = d + 32 | 0;
	                j = d + 28 | 0;
	                k = d + 24 | 0;
	                l = d + 20 | 0;
	                m = d + 16 | 0;
	                n = d + 12 | 0;
	                o = d + 8 | 0;
	                p = d + 4 | 0;
	                q = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                if (!(c[g >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    r = c[e >> 2] | 0;
	                    i = d;
	                    return r | 0
	                }
	                if (((((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 189864) | 0) != 0 : 0) ? (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0)c[h >> 2] = aP(c[f >> 2] | 0, c[g >> 2] | 0) | 0; else s = 9;
	                a:do if ((s | 0) == 9) {
	                    if (((((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 189904) | 0) != 0 : 0) ? (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                        c[h >> 2] = kP(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                        break
	                    }
	                    if (((((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 189824) | 0) != 0 : 0) ? (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                        c[h >> 2] = DN(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                        if (!(c[h >> 2] | 0)) {
	                            c[e >> 2] = 0;
	                            r = c[e >> 2] | 0;
	                            i = d;
	                            return r | 0
	                        } else {
	                            c[c[h >> 2] >> 2] = 0;
	                            if (!(c[(c[g >> 2] | 0) + 12 >> 2] | 0))break;
	                            zN(c[f >> 2] | 0, c[g >> 2] | 0, 1025, 192096, 0, 0);
	                            break
	                        }
	                    }
	                    if (((((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 189856) | 0) != 0 : 0) ? (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                        c[h >> 2] = DN(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                        if (!(c[h >> 2] | 0)) {
	                            c[e >> 2] = 0;
	                            r = c[e >> 2] | 0;
	                            i = d;
	                            return r | 0
	                        } else {
	                            c[c[h >> 2] >> 2] = 3;
	                            if (!(c[(c[g >> 2] | 0) + 12 >> 2] | 0))break;
	                            zN(c[f >> 2] | 0, c[g >> 2] | 0, 1109, 192128, 0, 0);
	                            break
	                        }
	                    }
	                    if (((((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 189984) | 0) != 0 : 0) ? (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                        c[h >> 2] = DN(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                        if (!(c[h >> 2] | 0)) {
	                            c[e >> 2] = 0;
	                            r = c[e >> 2] | 0;
	                            i = d;
	                            return r | 0
	                        }
	                        c[c[h >> 2] >> 2] = 15;
	                        b = c[f >> 2] | 0;
	                        a = c[g >> 2] | 0;
	                        if (!(c[(c[g >> 2] | 0) + 12 >> 2] | 0)) {
	                            zN(b, a, 1023, 192152, c[(c[g >> 2] | 0) + 8 >> 2] | 0, 0);
	                            break
	                        } else {
	                            t = xO(b, c[a + 12 >> 2] | 0, 1) | 0;
	                            c[(c[h >> 2] | 0) + 24 >> 2] = t;
	                            break
	                        }
	                    }
	                    if (((((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 19e4) | 0) != 0 : 0) ? (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                        c[h >> 2] = DN(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                        if (!(c[h >> 2] | 0)) {
	                            c[e >> 2] = 0;
	                            r = c[e >> 2] | 0;
	                            i = d;
	                            return r | 0
	                        }
	                        c[c[h >> 2] >> 2] = 16;
	                        t = c[f >> 2] | 0;
	                        a = c[g >> 2] | 0;
	                        if (!(c[(c[g >> 2] | 0) + 12 >> 2] | 0)) {
	                            zN(t, a, 1023, 192152, c[(c[g >> 2] | 0) + 8 >> 2] | 0, 0);
	                            break
	                        } else {
	                            b = xO(t, c[a + 12 >> 2] | 0, 1) | 0;
	                            c[(c[h >> 2] | 0) + 24 >> 2] = b;
	                            break
	                        }
	                    }
	                    if (((((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 189968) | 0) != 0 : 0) ? (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                        c[h >> 2] = DN(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                        if (!(c[h >> 2] | 0)) {
	                            c[e >> 2] = 0;
	                            r = c[e >> 2] | 0;
	                            i = d;
	                            return r | 0
	                        }
	                        c[c[h >> 2] >> 2] = 14;
	                        b = c[f >> 2] | 0;
	                        a = c[g >> 2] | 0;
	                        if (!(c[(c[g >> 2] | 0) + 12 >> 2] | 0)) {
	                            zN(b, a, 1023, 192152, c[(c[g >> 2] | 0) + 8 >> 2] | 0, 0);
	                            break
	                        } else {
	                            t = xO(b, c[a + 12 >> 2] | 0, 1) | 0;
	                            c[(c[h >> 2] | 0) + 24 >> 2] = t;
	                            break
	                        }
	                    }
	                    if (((((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 190016) | 0) != 0 : 0) ? (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                        c[h >> 2] = DN(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                        if (!(c[h >> 2] | 0)) {
	                            c[e >> 2] = 0;
	                            r = c[e >> 2] | 0;
	                            i = d;
	                            return r | 0
	                        }
	                        c[c[h >> 2] >> 2] = 17;
	                        t = c[f >> 2] | 0;
	                        a = c[g >> 2] | 0;
	                        if (!(c[(c[g >> 2] | 0) + 12 >> 2] | 0)) {
	                            zN(t, a, 1023, 192152, c[(c[g >> 2] | 0) + 8 >> 2] | 0, 0);
	                            break
	                        } else {
	                            b = xO(t, c[a + 12 >> 2] | 0, 0) | 0;
	                            c[(c[h >> 2] | 0) + 24 >> 2] = b;
	                            break
	                        }
	                    }
	                    if (((((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 190024) | 0) != 0 : 0) ? (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                        c[h >> 2] = DN(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                        if (!(c[h >> 2] | 0)) {
	                            c[e >> 2] = 0;
	                            r = c[e >> 2] | 0;
	                            i = d;
	                            return r | 0
	                        }
	                        c[c[h >> 2] >> 2] = 18;
	                        b = c[f >> 2] | 0;
	                        a = c[g >> 2] | 0;
	                        if (!(c[(c[g >> 2] | 0) + 12 >> 2] | 0)) {
	                            zN(b, a, 1023, 192152, c[(c[g >> 2] | 0) + 8 >> 2] | 0, 0);
	                            break
	                        } else {
	                            t = xO(b, c[a + 12 >> 2] | 0, 0) | 0;
	                            c[(c[h >> 2] | 0) + 24 >> 2] = t;
	                            break
	                        }
	                    }
	                    if (((((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 189928) | 0) != 0 : 0) ? (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                        c[h >> 2] = DN(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                        if (!(c[h >> 2] | 0)) {
	                            c[e >> 2] = 0;
	                            r = c[e >> 2] | 0;
	                            i = d;
	                            return r | 0
	                        }
	                        c[c[h >> 2] >> 2] = 11;
	                        t = Yi(c[g >> 2] | 0, 192176) | 0;
	                        c[(c[h >> 2] | 0) + 8 >> 2] = t;
	                        do if (!(c[(c[h >> 2] | 0) + 8 >> 2] | 0))zN(c[f >> 2] | 0, c[g >> 2] | 0, 1102, 192184, 0, 0); else {
	                            ZO(c[(c[h >> 2] | 0) + 8 >> 2] | 0);
	                            if (!(Eh(c[(c[h >> 2] | 0) + 8 >> 2] | 0, 0) | 0))break;
	                            zN(c[f >> 2] | 0, c[g >> 2] | 0, 1100, 192208, c[(c[h >> 2] | 0) + 8 >> 2] | 0, 0)
	                        } while (0);
	                        if (c[(c[g >> 2] | 0) + 12 >> 2] | 0)zN(c[f >> 2] | 0, c[g >> 2] | 0, 1103, 192240, 0, 0);
	                        if (!(c[(c[(c[f >> 2] | 0) + 24 >> 2] | 0) + 28 >> 2] | 0)) {
	                            t = Ij(10) | 0;
	                            c[(c[(c[f >> 2] | 0) + 24 >> 2] | 0) + 28 >> 2] = t
	                        }
	                        t = c[f >> 2] | 0;
	                        if (!(c[(c[(c[f >> 2] | 0) + 24 >> 2] | 0) + 28 >> 2] | 0)) {
	                            zN(t, c[g >> 2] | 0, 1098, 192264, 0, 0);
	                            c[h >> 2] = 0;
	                            break
	                        }
	                        c[j >> 2] = Lj(c[(c[t + 24 >> 2] | 0) + 28 >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[h >> 2] | 0) | 0;
	                        if ((c[j >> 2] | 0) >= 0)break;
	                        c[k >> 2] = Rj(c[(c[(c[f >> 2] | 0) + 24 >> 2] | 0) + 28 >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        if (c[k >> 2] | 0) {
	                            c[(c[h >> 2] | 0) + 44 >> 2] = c[(c[k >> 2] | 0) + 44 >> 2];
	                            c[(c[k >> 2] | 0) + 44 >> 2] = c[h >> 2];
	                            break
	                        }
	                        t = c[f >> 2] | 0;
	                        a = c[g >> 2] | 0;
	                        if (c[(c[h >> 2] | 0) + 8 >> 2] | 0)zN(t, a, 1098, 192304, c[(c[h >> 2] | 0) + 8 >> 2] | 0, 0); else zN(t, a, 1098, 192336, 0, 0);
	                        c[h >> 2] = 0;
	                        break
	                    }
	                    if (((((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 192360) | 0) != 0 : 0) ? (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                        c[h >> 2] = lP(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                        break
	                    }
	                    if (((((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 189888) | 0) != 0 : 0) ? (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                        c[h >> 2] = mP(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                        break
	                    }
	                    if (((((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 189896) | 0) != 0 : 0) ? (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                        c[h >> 2] = DN(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                        if (!(c[h >> 2] | 0)) {
	                            c[e >> 2] = 0;
	                            r = c[e >> 2] | 0;
	                            i = d;
	                            return r | 0
	                        }
	                        c[c[h >> 2] >> 2] = 8;
	                        a = c[f >> 2] | 0;
	                        t = c[g >> 2] | 0;
	                        if (!(c[(c[g >> 2] | 0) + 12 >> 2] | 0)) {
	                            zN(a, t, 1023, 192152, c[(c[g >> 2] | 0) + 8 >> 2] | 0, 0);
	                            break
	                        } else {
	                            b = xO(a, c[t + 12 >> 2] | 0, 0) | 0;
	                            c[(c[h >> 2] | 0) + 24 >> 2] = b;
	                            break
	                        }
	                    }
	                    do if ((((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 190032) | 0) != 0 : 0) {
	                        if (!(qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0))break;
	                        c[h >> 2] = nP(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                        break a
	                    } while (0);
	                    do if (((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) {
	                        if (!(qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 189936) | 0))break;
	                        if (!(qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0))break;
	                        c[h >> 2] = oP(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                        break a
	                    } while (0);
	                    do if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) {
	                        if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 1)break;
	                        if (!(qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 189832) | 0))break;
	                        if (!(qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0))break;
	                        c[h >> 2] = DN(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                        if (!(c[h >> 2] | 0)) {
	                            c[e >> 2] = 0;
	                            r = c[e >> 2] | 0;
	                            i = d;
	                            return r | 0
	                        } else {
	                            c[c[h >> 2] >> 2] = 1;
	                            if (!(c[(c[g >> 2] | 0) + 12 >> 2] | 0))break a;
	                            zN(c[f >> 2] | 0, c[g >> 2] | 0, 1055, 192368, 0, 0);
	                            break a
	                        }
	                    } while (0);
	                    do if (c[g >> 2] | 0) {
	                        if (!(c[(c[g >> 2] | 0) + 36 >> 2] | 0))break;
	                        if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 1)break;
	                        if (!(qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 190264) | 0))break;
	                        if (!(qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0))break;
	                        c[n >> 2] = c[(c[f >> 2] | 0) + 28 >> 2];
	                        c[m >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                        c[(c[f >> 2] | 0) + 28 >> 2] = c[m >> 2];
	                        c[l >> 2] = WN(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] | 0) | 0;
	                        if (c[m >> 2] | 0) {
	                            c[(c[f >> 2] | 0) + 24 >> 2] = c[m >> 2];
	                            c[(c[f >> 2] | 0) + 28 >> 2] = c[n >> 2]
	                        }
	                        if (c[l >> 2] | 0) {
	                            c[h >> 2] = c[(c[l >> 2] | 0) + 12 >> 2];
	                            break a
	                        } else {
	                            c[h >> 2] = 0;
	                            break a
	                        }
	                    } while (0);
	                    do if (c[g >> 2] | 0) {
	                        if (!(c[(c[g >> 2] | 0) + 36 >> 2] | 0))break;
	                        if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 1)break;
	                        if (!(qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 189952) | 0))break;
	                        if (!(qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0))break;
	                        b = c[f >> 2] | 0;
	                        t = c[g >> 2] | 0;
	                        if (!(c[(c[f >> 2] | 0) + 28 >> 2] | 0)) {
	                            zN(b, t, 1063, 192424, 0, 0);
	                            c[e >> 2] = 0;
	                            r = c[e >> 2] | 0;
	                            i = d;
	                            return r | 0
	                        }
	                        c[h >> 2] = DN(b, t) | 0;
	                        if (!(c[h >> 2] | 0)) {
	                            c[e >> 2] = 0;
	                            r = c[e >> 2] | 0;
	                            i = d;
	                            return r | 0
	                        }
	                        c[c[h >> 2] >> 2] = 13;
	                        t = Yi(c[g >> 2] | 0, 192176) | 0;
	                        c[(c[h >> 2] | 0) + 8 >> 2] = t;
	                        do if (!(c[(c[h >> 2] | 0) + 8 >> 2] | 0))zN(c[f >> 2] | 0, c[g >> 2] | 0, 1062, 192472, 0, 0); else {
	                            ZO(c[(c[h >> 2] | 0) + 8 >> 2] | 0);
	                            if (!(Eh(c[(c[h >> 2] | 0) + 8 >> 2] | 0, 0) | 0))break;
	                            zN(c[f >> 2] | 0, c[g >> 2] | 0, 1061, 192496, c[(c[h >> 2] | 0) + 8 >> 2] | 0, 0)
	                        } while (0);
	                        if (c[(c[g >> 2] | 0) + 12 >> 2] | 0)zN(c[f >> 2] | 0, c[g >> 2] | 0, 1064, 192536, 0, 0);
	                        if (!(c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 28 >> 2] | 0)) {
	                            t = Ij(10) | 0;
	                            c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 28 >> 2] = t
	                        }
	                        if (!(c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 28 >> 2] | 0)) {
	                            zN(c[f >> 2] | 0, c[g >> 2] | 0, 1060, 192264, 0, 0);
	                            c[h >> 2] = 0;
	                            break a
	                        }
	                        if (!(c[(c[h >> 2] | 0) + 8 >> 2] | 0))break a;
	                        c[o >> 2] = Lj(c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 28 >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[h >> 2] | 0) | 0;
	                        if ((c[o >> 2] | 0) >= 0)break a;
	                        c[p >> 2] = Rj(c[(c[(c[f >> 2] | 0) + 28 >> 2] | 0) + 28 >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        if (!(c[p >> 2] | 0)) {
	                            zN(c[f >> 2] | 0, c[g >> 2] | 0, 1060, 192560, c[(c[h >> 2] | 0) + 8 >> 2] | 0, 0);
	                            c[h >> 2] = 0;
	                            break a
	                        } else {
	                            c[(c[h >> 2] | 0) + 44 >> 2] = c[(c[p >> 2] | 0) + 44 >> 2];
	                            c[(c[p >> 2] | 0) + 44 >> 2] = c[h >> 2];
	                            break a
	                        }
	                    } while (0);
	                    do if (c[g >> 2] | 0) {
	                        if (!(c[(c[g >> 2] | 0) + 36 >> 2] | 0))break;
	                        if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 1)break;
	                        if (!(qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 192608) | 0))break;
	                        if (!(qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0))break;
	                        t = c[f >> 2] | 0;
	                        b = c[g >> 2] | 0;
	                        if (!(c[(c[g >> 2] | 0) + 12 >> 2] | 0)) {
	                            zN(t, b, 1023, 192616, 0, 0);
	                            c[h >> 2] = 0;
	                            break a
	                        }
	                        c[h >> 2] = nP(t, b) | 0;
	                        if (!(c[h >> 2] | 0))break a;
	                        do if (c[(c[h >> 2] | 0) + 24 >> 2] | 0) {
	                            if (!(c[(c[(c[h >> 2] | 0) + 24 >> 2] | 0) + 32 >> 2] | 0))break;
	                            c[q >> 2] = DN(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                            if (!(c[q >> 2] | 0))break;
	                            c[c[q >> 2] >> 2] = 18;
	                            c[(c[q >> 2] | 0) + 24 >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                            c[(c[h >> 2] | 0) + 24 >> 2] = c[q >> 2]
	                        } while (0);
	                        c[q >> 2] = DN(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                        if (c[q >> 2] | 0) {
	                            c[c[q >> 2] >> 2] = 3;
	                            c[(c[q >> 2] | 0) + 32 >> 2] = c[(c[h >> 2] | 0) + 24 >> 2];
	                            c[(c[h >> 2] | 0) + 24 >> 2] = c[q >> 2];
	                            break a
	                        }
	                        c[e >> 2] = c[h >> 2];
	                        r = c[e >> 2] | 0;
	                        i = d;
	                        return r | 0
	                    } while (0);
	                    zN(c[f >> 2] | 0, c[g >> 2] | 0, 1115, 192632, c[(c[g >> 2] | 0) + 8 >> 2] | 0, 0);
	                    c[h >> 2] = 0
	                } while (0);
	                c[e >> 2] = c[h >> 2];
	                r = c[e >> 2] | 0;
	                i = d;
	                return r | 0
	            }

	            function cP(a) {
	                a = a | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[f >> 2] = a;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                if (b[(c[f >> 2] | 0) + 50 >> 1] & 1) {
	                    c[e >> 2] = 1;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                if (b[(c[f >> 2] | 0) + 50 >> 1] & 2) {
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                a:do switch (c[c[f >> 2] >> 2] | 0) {
	                    case 16:
	                    case 13:
	                    case 12:
	                    case 11:
	                    case 10:
	                    case -1:
	                    {
	                        c[g >> 2] = cP(c[(c[f >> 2] | 0) + 24 >> 2] | 0) | 0;
	                        break
	                    }
	                    case 9:
	                    case 8:
	                    case 7:
	                    case 6:
	                    case 5:
	                    case 4:
	                    case 1:
	                    case 2:
	                    {
	                        c[g >> 2] = 0;
	                        break
	                    }
	                    case 3:
	                    case 0:
	                    {
	                        c[g >> 2] = 1;
	                        break
	                    }
	                    case 18:
	                    case 19:
	                    case 20:
	                    {
	                        c[j >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                        while (1) {
	                            if (!(c[j >> 2] | 0))break;
	                            c[g >> 2] = cP(c[j >> 2] | 0) | 0;
	                            if ((c[g >> 2] | 0) != 1)break a;
	                            c[j >> 2] = c[(c[j >> 2] | 0) + 32 >> 2]
	                        }
	                        c[e >> 2] = 1;
	                        k = c[e >> 2] | 0;
	                        i = d;
	                        return k | 0
	                    }
	                    case 17:
	                    {
	                        c[h >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                        while (1) {
	                            if (!(c[h >> 2] | 0))break;
	                            c[g >> 2] = cP(c[h >> 2] | 0) | 0;
	                            if (c[g >> 2] | 0)break a;
	                            c[h >> 2] = c[(c[h >> 2] | 0) + 32 >> 2]
	                        }
	                        c[g >> 2] = 0;
	                        break
	                    }
	                    default:
	                    {
	                        c[e >> 2] = -1;
	                        k = c[e >> 2] | 0;
	                        i = d;
	                        return k | 0
	                    }
	                } while (0);
	                if (!(c[g >> 2] | 0)) {
	                    h = (c[f >> 2] | 0) + 50 | 0;
	                    b[h >> 1] = b[h >> 1] | 2
	                }
	                if ((c[g >> 2] | 0) == 1) {
	                    h = (c[f >> 2] | 0) + 50 | 0;
	                    b[h >> 1] = b[h >> 1] | 1
	                }
	                c[e >> 2] = c[g >> 2];
	                k = c[e >> 2] | 0;
	                i = d;
	                return k | 0
	            }

	            function dP(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[g >> 2] = 0;
	                while (1) {
	                    if (!(c[f >> 2] | 0)) {
	                        h = 5;
	                        break
	                    }
	                    c[g >> 2] = SO(c[e >> 2] | 0, c[f >> 2] | 0) | 0;
	                    if (c[g >> 2] | 0) {
	                        h = 5;
	                        break
	                    }
	                    c[f >> 2] = c[(c[f >> 2] | 0) + 32 >> 2]
	                }
	                if ((h | 0) == 5) {
	                    i = d;
	                    return c[g >> 2] | 0
	                }
	                return 0
	            }

	            function eP(a, b, e) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f;
	                h = f + 32 | 0;
	                j = f + 28 | 0;
	                k = f + 24 | 0;
	                l = f + 20 | 0;
	                m = f + 16 | 0;
	                n = f + 12 | 0;
	                o = f + 8 | 0;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = e;
	                if ((c[(c[k >> 2] | 0) + 8 >> 2] | 0) != 0 ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, c[(c[l >> 2] | 0) + 8 >> 2] | 0) | 0) == 0 : 0) {
	                    c[h >> 2] = 0;
	                    p = c[h >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                do if (c[(c[k >> 2] | 0) + 12 >> 2] | 0) {
	                    e = c[(c[l >> 2] | 0) + 36 >> 2] | 0;
	                    if (!(d[c[(c[k >> 2] | 0) + 12 >> 2] >> 0] | 0)) {
	                        if (!e)break;
	                        c[h >> 2] = 0;
	                        p = c[h >> 2] | 0;
	                        i = f;
	                        return p | 0
	                    }
	                    if ((e | 0) != 0 ? (qy(c[(c[k >> 2] | 0) + 12 >> 2] | 0, c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) | 0) != 0 : 0)break;
	                    c[h >> 2] = 0;
	                    p = c[h >> 2] | 0;
	                    i = f;
	                    return p | 0
	                } while (0);
	                if (!(c[(c[k >> 2] | 0) + 40 >> 2] | 0)) {
	                    c[h >> 2] = 1;
	                    p = c[h >> 2] | 0;
	                    i = f;
	                    return p | 0
	                }
	                c[k >> 2] = c[(c[k >> 2] | 0) + 40 >> 2];
	                e = c[k >> 2] | 0;
	                a:do if ((c[c[k >> 2] >> 2] | 0) == 2) {
	                    c[n >> 2] = c[e + 24 >> 2];
	                    while (1) {
	                        if (!(c[n >> 2] | 0))break a;
	                        c[m >> 2] = eP(c[j >> 2] | 0, c[n >> 2] | 0, c[l >> 2] | 0) | 0;
	                        if ((c[m >> 2] | 0) == 1) {
	                            q = 17;
	                            break
	                        }
	                        if ((c[m >> 2] | 0) < 0) {
	                            q = 19;
	                            break
	                        }
	                        c[n >> 2] = c[(c[n >> 2] | 0) + 32 >> 2]
	                    }
	                    if ((q | 0) == 17) {
	                        c[h >> 2] = 0;
	                        p = c[h >> 2] | 0;
	                        i = f;
	                        return p | 0
	                    } else if ((q | 0) == 19) {
	                        c[h >> 2] = c[m >> 2];
	                        p = c[h >> 2] | 0;
	                        i = f;
	                        return p | 0
	                    }
	                } else {
	                    if ((c[e >> 2] | 0) != 17) {
	                        b = c[33976] | 0;
	                        a = c[33980] | 0;
	                        c[g >> 2] = 189496;
	                        c[g + 4 >> 2] = 9070;
	                        Db[b & 511](a, 189464, g);
	                        break
	                    }
	                    c[o >> 2] = c[(c[k >> 2] | 0) + 40 >> 2];
	                    while (1) {
	                        if (!(c[o >> 2] | 0)) {
	                            q = 29;
	                            break
	                        }
	                        c[m >> 2] = eP(c[j >> 2] | 0, c[o >> 2] | 0, c[l >> 2] | 0) | 0;
	                        if ((c[m >> 2] | 0) == 1) {
	                            q = 25;
	                            break
	                        }
	                        if ((c[m >> 2] | 0) < 0) {
	                            q = 27;
	                            break
	                        }
	                        c[o >> 2] = c[(c[o >> 2] | 0) + 32 >> 2]
	                    }
	                    if ((q | 0) == 25) {
	                        c[h >> 2] = 1;
	                        p = c[h >> 2] | 0;
	                        i = f;
	                        return p | 0
	                    } else if ((q | 0) == 27) {
	                        c[h >> 2] = c[m >> 2];
	                        p = c[h >> 2] | 0;
	                        i = f;
	                        return p | 0
	                    } else if ((q | 0) == 29) {
	                        c[h >> 2] = 0;
	                        p = c[h >> 2] | 0;
	                        i = f;
	                        return p | 0
	                    }
	                } while (0);
	                c[h >> 2] = 1;
	                p = c[h >> 2] | 0;
	                i = f;
	                return p | 0
	            }

	            function fP(a, b, e, f) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, p = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g;
	                j = g + 24 | 0;
	                k = g + 20 | 0;
	                l = g + 16 | 0;
	                m = g + 12 | 0;
	                n = g + 8 | 0;
	                p = g + 4 | 0;
	                c[g + 28 >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[l >> 2] = f;
	                c[m >> 2] = c[l >> 2];
	                c[n >> 2] = c[k >> 2];
	                if (!(c[m >> 2] | 0)) {
	                    k = c[o >> 2] | 0;
	                    c[h >> 2] = c[j >> 2];
	                    Ka(k | 0, 189616, h | 0) | 0;
	                    i = g;
	                    return
	                }
	                if (!(c[n >> 2] | 0)) {
	                    if ((d[c[j >> 2] >> 0] | 0 | 0) == 35) {
	                        i = g;
	                        return
	                    }
	                    k = c[o >> 2] | 0;
	                    c[h >> 2] = c[j >> 2];
	                    Ka(k | 0, 189648, h | 0) | 0;
	                    if (!(c[m >> 2] | 0)) {
	                        i = g;
	                        return
	                    }
	                    if (c[(c[m >> 2] | 0) + 40 >> 2] | 0) {
	                        i = g;
	                        return
	                    }
	                    c[(c[m >> 2] | 0) + 40 >> 2] = 37;
	                    i = g;
	                    return
	                }
	                if ((c[m >> 2] | 0) == 0 | (c[n >> 2] | 0) == 0) {
	                    k = c[o >> 2] | 0;
	                    c[h >> 2] = c[j >> 2];
	                    Ka(k | 0, 189680, h | 0) | 0;
	                    if (!(c[m >> 2] | 0)) {
	                        i = g;
	                        return
	                    }
	                    if (c[(c[m >> 2] | 0) + 40 >> 2] | 0) {
	                        i = g;
	                        return
	                    }
	                    c[(c[m >> 2] | 0) + 40 >> 2] = 37;
	                    i = g;
	                    return
	                }
	                if ((c[c[n >> 2] >> 2] | 0) != 4) {
	                    k = c[o >> 2] | 0;
	                    c[h >> 2] = c[j >> 2];
	                    Ka(k | 0, 189712, h | 0) | 0;
	                    if (c[(c[m >> 2] | 0) + 40 >> 2] | 0) {
	                        i = g;
	                        return
	                    }
	                    c[(c[m >> 2] | 0) + 40 >> 2] = 37;
	                    i = g;
	                    return
	                } else {
	                    c[p >> 2] = KN(c[m >> 2] | 0, c[n >> 2] | 0) | 0;
	                    if (!(c[p >> 2] | 0)) {
	                        i = g;
	                        return
	                    }
	                    c[(c[m >> 2] | 0) + 112 >> 2] = c[p >> 2];
	                    i = g;
	                    return
	                }
	            }

	            function gP(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[j >> 2] = 0;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                b = c[j >> 2] | 0;
	                c[j >> 2] = b + 1;
	                c[h >> 2] = c[(c[g >> 2] | 0) + (b << 2) >> 2];
	                a:while (1) {
	                    if (!(c[h >> 2] | 0)) {
	                        m = 14;
	                        break
	                    }
	                    if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 1 ? (c[c[h >> 2] >> 2] | 0) == 4 : 0) {
	                        c[k >> 2] = MO(0, c[h >> 2] | 0, c[f >> 2] | 0) | 0;
	                        if ((c[k >> 2] | 0) == 1) {
	                            m = 8;
	                            break
	                        }
	                    } else m = 9;
	                    do if ((m | 0) == 9) {
	                        m = 0;
	                        if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 3 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 4 : 0)break;
	                        if ((c[c[h >> 2] >> 2] | 0) == 3) {
	                            m = 12;
	                            break a
	                        }
	                    } while (0);
	                    b = c[j >> 2] | 0;
	                    c[j >> 2] = b + 1;
	                    c[h >> 2] = c[(c[g >> 2] | 0) + (b << 2) >> 2]
	                }
	                if ((m | 0) == 8) {
	                    c[e >> 2] = 1;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                } else if ((m | 0) == 12) {
	                    c[e >> 2] = 1;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                } else if ((m | 0) == 14) {
	                    c[e >> 2] = 0;
	                    l = c[e >> 2] | 0;
	                    i = d;
	                    return l | 0
	                }
	                return 0
	            }

	            function hP(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[f >> 2] = a;
	                c[g >> 2] = c[(c[(c[f >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2];
	                if ((c[g >> 2] | 0) != 0 ? (c[(c[(c[f >> 2] | 0) + 60 >> 2] | 0) + 24 >> 2] | 0) != 0 : 0) {
	                    while (1) {
	                        if (!(d[c[g >> 2] >> 0] | 0))break;
	                        c[g >> 2] = (c[g >> 2] | 0) + 1
	                    }
	                    while (1) {
	                        if ((c[g >> 2] | 0) != (c[(c[(c[f >> 2] | 0) + 60 >> 2] | 0) + 24 >> 2] | 0))h = (d[c[g >> 2] >> 0] | 0 | 0) == 0; else h = 0;
	                        j = c[g >> 2] | 0;
	                        if (!h)break;
	                        c[g >> 2] = j + 1
	                    }
	                    if ((j | 0) == (c[(c[(c[f >> 2] | 0) + 60 >> 2] | 0) + 24 >> 2] | 0))c[(c[(c[f >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2] = 0; else c[(c[(c[f >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2] = c[g >> 2];
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = b;
	                    return k | 0
	                }
	                c[(c[(c[f >> 2] | 0) + 60 >> 2] | 0) + 20 >> 2] = 0;
	                c[(c[(c[f >> 2] | 0) + 60 >> 2] | 0) + 24 >> 2] = 0;
	                c[e >> 2] = 0;
	                k = c[e >> 2] | 0;
	                i = b;
	                return k | 0
	            }

	            function iP(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[g >> 2] = 0;
	                while (1) {
	                    if (!(c[f >> 2] | 0)) {
	                        h = 5;
	                        break
	                    }
	                    c[g >> 2] = SO(c[e >> 2] | 0, c[f >> 2] | 0) | 0;
	                    if (c[g >> 2] | 0) {
	                        h = 5;
	                        break
	                    }
	                    c[f >> 2] = c[(c[f >> 2] | 0) + 32 >> 2]
	                }
	                if ((h | 0) == 5) {
	                    i = d;
	                    return c[g >> 2] | 0
	                }
	                return 0
	            }

	            function jP(a, b, e) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f + 32 | 0;
	                h = f + 28 | 0;
	                j = f + 24 | 0;
	                k = f + 20 | 0;
	                l = f + 16 | 0;
	                m = f + 12 | 0;
	                n = f + 8 | 0;
	                o = f + 4 | 0;
	                p = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[l >> 2] = c[k >> 2];
	                if (((((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[j >> 2] | 0) + 8 >> 2] | 0, 192176) | 0) != 0 : 0) ? (qy(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0)q = 16; else q = 6;
	                do if ((q | 0) == 6) {
	                    if (((((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[j >> 2] | 0) + 8 >> 2] | 0, 193584) | 0) != 0 : 0) ? (qy(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                        q = 16;
	                        break
	                    }
	                    if (((((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[j >> 2] | 0) + 8 >> 2] | 0, 193592) | 0) != 0 : 0) ? (qy(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0)q = 16
	                } while (0);
	                do if (((q | 0) == 16 ? (c[c[k >> 2] >> 2] | 0) != 4 : 0) ? (c[c[k >> 2] >> 2] | 0) != 9 : 0) {
	                    c[l >> 2] = DN(c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                    if (!(c[l >> 2] | 0)) {
	                        c[g >> 2] = 0;
	                        r = c[g >> 2] | 0;
	                        i = f;
	                        return r | 0
	                    }
	                    c[(c[l >> 2] | 0) + 28 >> 2] = c[k >> 2];
	                    e = c[l >> 2] | 0;
	                    if (c[(c[h >> 2] | 0) + 32 >> 2] & 1) {
	                        c[e >> 2] = 9;
	                        break
	                    } else {
	                        c[e >> 2] = 4;
	                        break
	                    }
	                } while (0);
	                if (((((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[j >> 2] | 0) + 8 >> 2] | 0, 192176) | 0) != 0 : 0) ? (qy(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                    c[n >> 2] = _i(c[j >> 2] | 0) | 0;
	                    ZO(c[n >> 2] | 0);
	                    do if (Eh(c[n >> 2] | 0, 0) | 0) {
	                        e = c[h >> 2] | 0;
	                        b = c[j >> 2] | 0;
	                        if (c[(c[j >> 2] | 0) + 20 >> 2] | 0) {
	                            zN(e, b, 1019, 193600, c[(c[(c[j >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0, c[n >> 2] | 0);
	                            break
	                        } else {
	                            zN(e, b, 1019, 193640, c[n >> 2] | 0, 0);
	                            break
	                        }
	                    } while (0);
	                    c[(c[l >> 2] | 0) + 8 >> 2] = c[n >> 2];
	                    c[n >> 2] = Yi(c[j >> 2] | 0, 192672) | 0;
	                    c[(c[l >> 2] | 0) + 12 >> 2] = c[n >> 2];
	                    if (((c[n >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 32 >> 2] & 1 | 0) != 0 : 0) ? (qy(c[n >> 2] | 0, 193672) | 0) != 0 : 0)zN(c[h >> 2] | 0, c[j >> 2] | 0, 1122, 193704, c[n >> 2] | 0, 0);
	                    if ((((c[n >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 32 >> 2] & 1 | 0) != 0 : 0) ? (d[c[n >> 2] >> 0] | 0 | 0) == 0 : 0) ? (qy(c[(c[l >> 2] | 0) + 8 >> 2] | 0, 193752) | 0) != 0 : 0)zN(c[h >> 2] | 0, c[j >> 2] | 0, 1121, 193760, c[n >> 2] | 0, 0)
	                } else q = 39;
	                a:do if ((q | 0) == 39) {
	                    if (((((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[j >> 2] | 0) + 8 >> 2] | 0, 193584) | 0) != 0 : 0) ? (qy(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                        c[(c[l >> 2] | 0) + 8 >> 2] = 0;
	                        c[(c[l >> 2] | 0) + 12 >> 2] = 0;
	                        if (!(c[(c[j >> 2] | 0) + 12 >> 2] | 0))break;
	                        n = pP(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 12 >> 2] | 0, (c[c[k >> 2] >> 2] | 0) == 9 & 1) | 0;
	                        c[(c[l >> 2] | 0) + 40 >> 2] = n;
	                        break
	                    }
	                    if (((((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[j >> 2] | 0) + 8 >> 2] | 0, 193592) | 0) != 0 : 0) ? (qy(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                        c[(c[l >> 2] | 0) + 8 >> 2] = 0;
	                        n = Yi(c[j >> 2] | 0, 192672) | 0;
	                        c[(c[l >> 2] | 0) + 12 >> 2] = n;
	                        if (!(c[(c[l >> 2] | 0) + 12 >> 2] | 0))zN(c[h >> 2] | 0, c[j >> 2] | 0, 1057, 193808, 0, 0);
	                        if (((c[(c[h >> 2] | 0) + 32 >> 2] & 1 | 0) != 0 ? (c[(c[l >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (qy(c[(c[l >> 2] | 0) + 12 >> 2] | 0, 193672) | 0) != 0 : 0)zN(c[h >> 2] | 0, c[j >> 2] | 0, 1122, 193704, c[(c[l >> 2] | 0) + 12 >> 2] | 0, 0);
	                        if (!(c[(c[j >> 2] | 0) + 12 >> 2] | 0))break;
	                        n = pP(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 12 >> 2] | 0, (c[c[k >> 2] >> 2] | 0) == 9 & 1) | 0;
	                        c[(c[l >> 2] | 0) + 40 >> 2] = n;
	                        break
	                    }
	                    if (((((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[j >> 2] | 0) + 8 >> 2] | 0, 190016) | 0) != 0 : 0) ? (qy(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                        c[p >> 2] = 0;
	                        c[l >> 2] = DN(c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                        if (!(c[l >> 2] | 0)) {
	                            c[g >> 2] = 0;
	                            r = c[g >> 2] | 0;
	                            i = f;
	                            return r | 0
	                        }
	                        c[(c[l >> 2] | 0) + 28 >> 2] = c[k >> 2];
	                        c[c[l >> 2] >> 2] = 17;
	                        if (!(c[(c[j >> 2] | 0) + 12 >> 2] | 0)) {
	                            zN(c[h >> 2] | 0, c[j >> 2] | 0, 1007, 193840, 0, 0);
	                            break
	                        }
	                        c[o >> 2] = c[(c[j >> 2] | 0) + 12 >> 2];
	                        while (1) {
	                            if (!(c[o >> 2] | 0))break a;
	                            c[m >> 2] = jP(c[h >> 2] | 0, c[o >> 2] | 0, c[l >> 2] | 0) | 0;
	                            do if (c[m >> 2] | 0) {
	                                n = c[m >> 2] | 0;
	                                if (!(c[p >> 2] | 0)) {
	                                    c[(c[l >> 2] | 0) + 40 >> 2] = n;
	                                    c[p >> 2] = n;
	                                    break
	                                } else {
	                                    c[(c[p >> 2] | 0) + 32 >> 2] = n;
	                                    c[p >> 2] = c[m >> 2];
	                                    break
	                                }
	                            } while (0);
	                            c[o >> 2] = c[(c[o >> 2] | 0) + 24 >> 2]
	                        }
	                    }
	                    if (!(c[j >> 2] | 0))s = 193928; else s = c[(c[j >> 2] | 0) + 8 >> 2] | 0;
	                    zN(c[h >> 2] | 0, c[j >> 2] | 0, 1006, 193872, s, 0);
	                    c[g >> 2] = 0;
	                    r = c[g >> 2] | 0;
	                    i = f;
	                    return r | 0
	                } while (0);
	                do if ((c[l >> 2] | 0) != (c[k >> 2] | 0)) {
	                    if (!(c[(c[k >> 2] | 0) + 40 >> 2] | 0)) {
	                        c[(c[k >> 2] | 0) + 40 >> 2] = c[l >> 2];
	                        break
	                    }
	                    c[m >> 2] = c[(c[k >> 2] | 0) + 40 >> 2];
	                    while (1) {
	                        if (!(c[(c[m >> 2] | 0) + 32 >> 2] | 0))break;
	                        c[m >> 2] = c[(c[m >> 2] | 0) + 32 >> 2]
	                    }
	                    c[(c[m >> 2] | 0) + 32 >> 2] = c[l >> 2]
	                } while (0);
	                c[g >> 2] = c[l >> 2];
	                r = c[g >> 2] | 0;
	                i = f;
	                return r | 0
	            }

	            function kP(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 24 | 0;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                k = d + 4 | 0;
	                l = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = DN(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                c[c[h >> 2] >> 2] = 9;
	                c[(c[h >> 2] | 0) + 28 >> 2] = c[(c[f >> 2] | 0) + 48 >> 2];
	                c[k >> 2] = c[(c[g >> 2] | 0) + 12 >> 2];
	                b = c[f >> 2] | 0;
	                if (!(c[k >> 2] | 0)) {
	                    zN(b, c[g >> 2] | 0, 1004, 193408, 0, 0);
	                    c[e >> 2] = c[h >> 2];
	                    m = c[e >> 2] | 0;
	                    i = d;
	                    return m | 0
	                }
	                c[l >> 2] = c[b + 32 >> 2];
	                b = (c[f >> 2] | 0) + 32 | 0;
	                c[b >> 2] = c[b >> 2] | 1;
	                c[j >> 2] = jP(c[f >> 2] | 0, c[k >> 2] | 0, c[h >> 2] | 0) | 0;
	                if (c[j >> 2] | 0)c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2];
	                if (c[k >> 2] | 0) {
	                    c[j >> 2] = bP(c[f >> 2] | 0, c[k >> 2] | 0) | 0;
	                    a:do if (c[j >> 2] | 0)switch (c[c[j >> 2] >> 2] | 0) {
	                        case -1:
	                        {
	                            zN(c[f >> 2] | 0, c[g >> 2] | 0, 1005, 193496, 0, 0);
	                            break a;
	                            break
	                        }
	                        case 2:
	                        case 6:
	                        case 20:
	                        {
	                            zN(c[f >> 2] | 0, c[g >> 2] | 0, 1003, 193464, 0, 0);
	                            break a;
	                            break
	                        }
	                        case 9:
	                        case 19:
	                        case 18:
	                        case 17:
	                        case 14:
	                        case 15:
	                        case 16:
	                        case 10:
	                        case 12:
	                        case 13:
	                        case 11:
	                        case 8:
	                        case 7:
	                        case 5:
	                        case 4:
	                        case 3:
	                        case 1:
	                        case 0:
	                        {
	                            c[(c[h >> 2] | 0) + 24 >> 2] = c[j >> 2];
	                            c[(c[j >> 2] | 0) + 28 >> 2] = c[h >> 2];
	                            break a;
	                            break
	                        }
	                        default:
	                            break a
	                    } while (0);
	                    c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                }
	                if (c[k >> 2] | 0)zN(c[f >> 2] | 0, c[g >> 2] | 0, 1002, 193544, 0, 0);
	                c[(c[f >> 2] | 0) + 32 >> 2] = c[l >> 2];
	                c[e >> 2] = c[h >> 2];
	                m = c[e >> 2] | 0;
	                i = d;
	                return m | 0
	            }

	            function lP(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                d = i;
	                i = i + 64 | 0;
	                e = d + 56 | 0;
	                f = d + 52 | 0;
	                g = d + 48 | 0;
	                h = d + 44 | 0;
	                j = d + 40 | 0;
	                k = d + 36 | 0;
	                l = d + 32 | 0;
	                m = d + 28 | 0;
	                n = d + 24 | 0;
	                o = d + 20 | 0;
	                p = d + 16 | 0;
	                q = d + 12 | 0;
	                r = d + 8 | 0;
	                s = d + 4 | 0;
	                t = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                c[l >> 2] = 0;
	                c[n >> 2] = Yi(c[g >> 2] | 0, 192784) | 0;
	                if (!(c[n >> 2] | 0)) {
	                    zN(c[f >> 2] | 0, c[g >> 2] | 0, 1110, 193184, 0, 0);
	                    c[e >> 2] = 0;
	                    u = c[e >> 2] | 0;
	                    i = d;
	                    return u | 0
	                }
	                ZO(c[n >> 2] | 0);
	                if (Eh(c[n >> 2] | 0, 0) | 0)zN(c[f >> 2] | 0, c[g >> 2] | 0, 1112, 193208, c[n >> 2] | 0, 0);
	                c[o >> 2] = qP(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                if (!(c[o >> 2] | 0))c[o >> 2] = my(192832) | 0;
	                c[h >> 2] = DN(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                    c[e >> 2] = 0;
	                    u = c[e >> 2] | 0;
	                    i = d;
	                    return u | 0
	                }
	                c[c[h >> 2] >> 2] = 5;
	                c[(c[h >> 2] | 0) + 8 >> 2] = c[n >> 2];
	                c[(c[h >> 2] | 0) + 12 >> 2] = c[o >> 2];
	                c[m >> 2] = Rj(c[46942] | 0, c[o >> 2] | 0) | 0;
	                do if (c[m >> 2] | 0) {
	                    c[(c[h >> 2] | 0) + 20 >> 2] = c[m >> 2];
	                    if (!(c[(c[m >> 2] | 0) + 8 >> 2] | 0)) {
	                        zN(c[f >> 2] | 0, c[g >> 2] | 0, 1026, 192912, c[o >> 2] | 0, 0);
	                        break
	                    }
	                    c[q >> 2] = Hb[c[(c[m >> 2] | 0) + 8 >> 2] & 511](c[(c[m >> 2] | 0) + 4 >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0) | 0;
	                    if ((c[q >> 2] | 0) != 1) {
	                        zN(c[f >> 2] | 0, c[g >> 2] | 0, 1111, 192968, c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[o >> 2] | 0);
	                        break
	                    }
	                    if (qy(c[o >> 2] | 0, 187824) | 0) {
	                        if ((qy(c[(c[h >> 2] | 0) + 8 >> 2] | 0, 193248) | 0) == 0 ? (qy(c[(c[h >> 2] | 0) + 8 >> 2] | 0, 193256) | 0) == 0 : 0)break;
	                        c[(c[f >> 2] | 0) + 128 >> 2] = 1
	                    }
	                } else {
	                    zN(c[f >> 2] | 0, c[g >> 2] | 0, 1116, 192872, c[o >> 2] | 0, 0);
	                    c[(c[h >> 2] | 0) + 20 >> 2] = 0
	                } while (0);
	                c[p >> 2] = c[(c[g >> 2] | 0) + 12 >> 2];
	                a:while (1) {
	                    if (!(c[p >> 2] | 0))break;
	                    if (!(qy(c[(c[p >> 2] | 0) + 8 >> 2] | 0, 190064) | 0))break;
	                    q = (qy(c[o >> 2] | 0, 192832) | 0) != 0;
	                    m = c[f >> 2] | 0;
	                    n = c[g >> 2] | 0;
	                    if (q) {
	                        zN(m, n, 1058, 193264, c[o >> 2] | 0, 0);
	                        c[p >> 2] = c[(c[p >> 2] | 0) + 24 >> 2];
	                        while (1) {
	                            if (!(c[p >> 2] | 0))continue a;
	                            if (!(qy(c[(c[p >> 2] | 0) + 8 >> 2] | 0, 190064) | 0))continue a;
	                            c[p >> 2] = c[(c[p >> 2] | 0) + 24 >> 2]
	                        }
	                    }
	                    c[k >> 2] = DN(m, n) | 0;
	                    if (c[k >> 2] | 0) {
	                        c[c[k >> 2] >> 2] = 6;
	                        q = Yi(c[p >> 2] | 0, 192176) | 0;
	                        c[(c[k >> 2] | 0) + 8 >> 2] = q;
	                        if (!(c[(c[k >> 2] | 0) + 8 >> 2] | 0))zN(c[f >> 2] | 0, c[g >> 2] | 0, 1059, 193320, 0, 0);
	                        q = _i(c[p >> 2] | 0) | 0;
	                        c[(c[k >> 2] | 0) + 16 >> 2] = q;
	                        q = c[k >> 2] | 0;
	                        if (!(c[l >> 2] | 0)) {
	                            c[l >> 2] = q;
	                            c[(c[h >> 2] | 0) + 36 >> 2] = q
	                        } else {
	                            c[(c[l >> 2] | 0) + 32 >> 2] = q;
	                            c[l >> 2] = c[k >> 2]
	                        }
	                    }
	                    c[p >> 2] = c[(c[p >> 2] | 0) + 24 >> 2]
	                }
	                if ((c[p >> 2] | 0) != 0 ? (qy(c[(c[p >> 2] | 0) + 8 >> 2] | 0, 189848) | 0) != 0 : 0) {
	                    c[t >> 2] = 0;
	                    c[j >> 2] = DN(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                    if (!(c[j >> 2] | 0)) {
	                        c[e >> 2] = c[h >> 2];
	                        u = c[e >> 2] | 0;
	                        i = d;
	                        return u | 0
	                    }
	                    c[c[j >> 2] >> 2] = 2;
	                    c[r >> 2] = c[(c[p >> 2] | 0) + 12 >> 2];
	                    c[(c[h >> 2] | 0) + 24 >> 2] = c[j >> 2];
	                    if (!(c[r >> 2] | 0))zN(c[f >> 2] | 0, c[p >> 2] | 0, 1030, 193344, 0, 0);
	                    while (1) {
	                        if (!(c[r >> 2] | 0))break;
	                        c[s >> 2] = bP(c[f >> 2] | 0, c[r >> 2] | 0) | 0;
	                        do if (c[s >> 2] | 0) {
	                            g = c[s >> 2] | 0;
	                            if (!(c[t >> 2] | 0)) {
	                                c[t >> 2] = g;
	                                c[(c[j >> 2] | 0) + 24 >> 2] = g;
	                                break
	                            } else {
	                                c[(c[t >> 2] | 0) + 32 >> 2] = g;
	                                c[t >> 2] = c[s >> 2];
	                                break
	                            }
	                        } while (0);
	                        c[r >> 2] = c[(c[r >> 2] | 0) + 24 >> 2]
	                    }
	                    c[p >> 2] = c[(c[p >> 2] | 0) + 24 >> 2]
	                }
	                if (c[p >> 2] | 0)zN(c[f >> 2] | 0, c[p >> 2] | 0, 1009, 193368, c[(c[p >> 2] | 0) + 8 >> 2] | 0, 0);
	                c[e >> 2] = c[h >> 2];
	                u = c[e >> 2] | 0;
	                i = d;
	                return u | 0
	            }

	            function mP(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                d = i;
	                i = i + 48 | 0;
	                e = d + 32 | 0;
	                f = d + 28 | 0;
	                g = d + 24 | 0;
	                h = d + 20 | 0;
	                j = d + 16 | 0;
	                k = d + 12 | 0;
	                l = d + 8 | 0;
	                m = d + 4 | 0;
	                n = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                c[j >> 2] = 0;
	                c[m >> 2] = 0;
	                c[h >> 2] = DN(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    o = c[e >> 2] | 0;
	                    i = d;
	                    return o | 0
	                }
	                c[c[h >> 2] >> 2] = 7;
	                c[k >> 2] = Yi(c[g >> 2] | 0, 192784) | 0;
	                do if (c[k >> 2] | 0) {
	                    ZO(c[k >> 2] | 0);
	                    if (Eh(c[k >> 2] | 0, 0) | 0)zN(c[f >> 2] | 0, c[g >> 2] | 0, 1112, 192792, c[k >> 2] | 0, 0);
	                    c[l >> 2] = qP(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                    if (!(c[l >> 2] | 0))c[l >> 2] = my(192832) | 0;
	                    c[(c[h >> 2] | 0) + 8 >> 2] = c[k >> 2];
	                    c[(c[h >> 2] | 0) + 12 >> 2] = c[l >> 2];
	                    c[j >> 2] = Rj(c[46942] | 0, c[l >> 2] | 0) | 0;
	                    if (!(c[j >> 2] | 0)) {
	                        zN(c[f >> 2] | 0, c[g >> 2] | 0, 1116, 192872, c[l >> 2] | 0, 0);
	                        c[(c[h >> 2] | 0) + 20 >> 2] = 0;
	                        break
	                    }
	                    c[(c[h >> 2] | 0) + 20 >> 2] = c[j >> 2];
	                    if (!(c[(c[j >> 2] | 0) + 8 >> 2] | 0)) {
	                        zN(c[f >> 2] | 0, c[g >> 2] | 0, 1026, 192912, c[l >> 2] | 0, 0);
	                        break
	                    }
	                    c[m >> 2] = Hb[c[(c[j >> 2] | 0) + 8 >> 2] & 511](c[(c[j >> 2] | 0) + 4 >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0) | 0;
	                    if ((c[m >> 2] | 0) != 1)zN(c[f >> 2] | 0, c[g >> 2] | 0, 1111, 192968, c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[l >> 2] | 0)
	                } while (0);
	                do if (!(c[(c[g >> 2] | 0) + 12 >> 2] | 0)) {
	                    l = my(188112) | 0;
	                    c[(c[h >> 2] | 0) + 16 >> 2] = l
	                } else {
	                    if (!((c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) != 3 ? (c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) != 4 : 0))p = 18;
	                    if ((p | 0) == 18 ? (c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 24 >> 2] | 0) == 0 : 0) {
	                        if (!(c[h >> 2] | 0))break;
	                        l = _i(c[g >> 2] | 0) | 0;
	                        c[(c[h >> 2] | 0) + 16 >> 2] = l;
	                        if (!(c[(c[h >> 2] | 0) + 16 >> 2] | 0)) {
	                            zN(c[f >> 2] | 0, c[g >> 2] | 0, 1120, 193080, 0, 0);
	                            break
	                        }
	                        if (!(c[j >> 2] | 0))break;
	                        if (!((c[m >> 2] | 0) == 1 ? (c[(c[j >> 2] | 0) + 12 >> 2] | 0) != 0 : 0))break;
	                        c[n >> 2] = 0;
	                        c[m >> 2] = Ib[c[(c[j >> 2] | 0) + 12 >> 2] & 511](c[(c[j >> 2] | 0) + 4 >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[(c[h >> 2] | 0) + 16 >> 2] | 0, n, c[g >> 2] | 0) | 0;
	                        if ((c[m >> 2] | 0) != 1) {
	                            zN(c[f >> 2] | 0, c[g >> 2] | 0, 1051, 193112, c[(c[h >> 2] | 0) + 16 >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0);
	                            break
	                        }
	                        if (!(c[n >> 2] | 0))break;
	                        c[(c[h >> 2] | 0) + 36 >> 2] = c[n >> 2];
	                        break
	                    }
	                    zN(c[f >> 2] | 0, c[g >> 2] | 0, 1108, 193024, 0, 0)
	                } while (0);
	                c[e >> 2] = c[h >> 2];
	                o = c[e >> 2] | 0;
	                i = d;
	                return o | 0
	            }

	            function nP(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                d = i;
	                i = i + 64 | 0;
	                e = d;
	                f = d + 28 | 0;
	                g = d + 24 | 0;
	                h = d + 20 | 0;
	                j = d + 16 | 0;
	                k = d + 12 | 0;
	                l = d + 8 | 0;
	                m = d + 4 | 0;
	                n = d + 32 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = 0;
	                c[k >> 2] = 0;
	                c[j >> 2] = DN(c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = d;
	                    return o | 0
	                }
	                c[c[j >> 2] >> 2] = 19;
	                if (!(c[(c[g >> 2] | 0) + 56 >> 2] | 0)) {
	                    b = Ij(10) | 0;
	                    c[(c[g >> 2] | 0) + 56 >> 2] = b
	                }
	                if (c[(c[g >> 2] | 0) + 56 >> 2] | 0) {
	                    b = (c[g >> 2] | 0) + 52 | 0;
	                    a = c[b >> 2] | 0;
	                    c[b >> 2] = a + 1;
	                    c[e >> 2] = a;
	                    JT(n, 32, 192704, e) | 0;
	                    if ((Lj(c[(c[g >> 2] | 0) + 56 >> 2] | 0, n, c[j >> 2] | 0) | 0) < 0)zN(c[g >> 2] | 0, c[h >> 2] | 0, 1045, 192720, n, 0)
	                } else xN(c[g >> 2] | 0, 192680);
	                c[m >> 2] = c[(c[h >> 2] | 0) + 12 >> 2];
	                if (!(c[m >> 2] | 0))zN(c[g >> 2] | 0, c[h >> 2] | 0, 1048, 192752, 0, 0);
	                while (1) {
	                    if (!(c[m >> 2] | 0))break;
	                    if (((((c[m >> 2] | 0) != 0 ? (c[(c[m >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[m >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 189864) | 0) != 0 : 0) ? (qy(c[(c[(c[m >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0)c[l >> 2] = aP(c[g >> 2] | 0, c[m >> 2] | 0) | 0; else c[l >> 2] = bP(c[g >> 2] | 0, c[m >> 2] | 0) | 0;
	                    do if (c[l >> 2] | 0) {
	                        c[(c[l >> 2] | 0) + 28 >> 2] = c[j >> 2];
	                        h = c[l >> 2] | 0;
	                        if (!(c[k >> 2] | 0)) {
	                            c[k >> 2] = h;
	                            c[(c[j >> 2] | 0) + 24 >> 2] = h;
	                            break
	                        } else {
	                            c[(c[k >> 2] | 0) + 32 >> 2] = h;
	                            c[k >> 2] = c[l >> 2];
	                            break
	                        }
	                    } while (0);
	                    c[m >> 2] = c[(c[m >> 2] | 0) + 24 >> 2]
	                }
	                c[f >> 2] = c[j >> 2];
	                o = c[f >> 2] | 0;
	                i = d;
	                return o | 0
	            }

	            function oP(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                d = i;
	                i = i + 48 | 0;
	                e = d + 36 | 0;
	                f = d + 32 | 0;
	                g = d + 28 | 0;
	                h = d + 24 | 0;
	                j = d + 20 | 0;
	                k = d + 16 | 0;
	                l = d + 12 | 0;
	                m = d + 8 | 0;
	                n = d + 4 | 0;
	                o = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[m >> 2] = 0;
	                c[h >> 2] = c[(c[g >> 2] | 0) + 52 >> 2];
	                if (c[h >> 2] | 0) {
	                    c[o >> 2] = DN(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                    if (!(c[o >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        p = c[e >> 2] | 0;
	                        i = d;
	                        return p | 0
	                    }
	                    c[c[o >> 2] >> 2] = 12;
	                    if (!(c[(c[h >> 2] | 0) + 12 >> 2] | 0)) {
	                        c[j >> 2] = Pi(c[(c[h >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        if (!(c[j >> 2] | 0)) {
	                            zN(c[f >> 2] | 0, c[g >> 2] | 0, 1031, 188056, c[(c[f >> 2] | 0) + 68 >> 2] | 0, 0);
	                            c[e >> 2] = 0;
	                            p = c[e >> 2] | 0;
	                            i = d;
	                            return p | 0
	                        }
	                        c[l >> 2] = Yi(c[j >> 2] | 0, 192672) | 0;
	                        if (!(c[l >> 2] | 0)) {
	                            c[k >> 2] = c[g >> 2];
	                            while (1) {
	                                if (!(c[k >> 2] | 0))break;
	                                if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) != 1)break;
	                                c[l >> 2] = Yi(c[k >> 2] | 0, 192672) | 0;
	                                if (c[l >> 2] | 0)break;
	                                c[k >> 2] = c[(c[k >> 2] | 0) + 20 >> 2]
	                            }
	                            if (c[l >> 2] | 0) {
	                                gj(c[j >> 2] | 0, 192672, c[l >> 2] | 0) | 0;
	                                c[m >> 2] = 1;
	                                zb[c[135736 >> 2] & 511](c[l >> 2] | 0)
	                            }
	                        } else zb[c[135736 >> 2] & 511](c[l >> 2] | 0);
	                        c[n >> 2] = c[(c[f >> 2] | 0) + 32 >> 2];
	                        l = (c[f >> 2] | 0) + 32 | 0;
	                        c[l >> 2] = c[l >> 2] | 128;
	                        l = BN(c[f >> 2] | 0, c[j >> 2] | 0) | 0;
	                        c[(c[h >> 2] | 0) + 16 >> 2] = l;
	                        c[(c[f >> 2] | 0) + 32 >> 2] = c[n >> 2];
	                        if (((c[(c[h >> 2] | 0) + 16 >> 2] | 0) != 0 ? (c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) ? (c[(c[h >> 2] | 0) + 12 >> 2] = c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) + 12 >> 2], (c[(c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) + 28 >> 2] | 0) != 0) : 0)rP(c[f >> 2] | 0, c[(c[(c[h >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) | 0;
	                        if ((c[m >> 2] | 0) == 1)fj(c[j >> 2] | 0, 192672) | 0
	                    }
	                    c[(c[o >> 2] | 0) + 24 >> 2] = c[(c[h >> 2] | 0) + 12 >> 2]
	                } else c[o >> 2] = 0;
	                c[e >> 2] = c[o >> 2];
	                p = c[e >> 2] | 0;
	                i = d;
	                return p | 0
	            }

	            function pP(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 28 | 0;
	                g = e + 24 | 0;
	                h = e + 20 | 0;
	                j = e + 16 | 0;
	                k = e + 12 | 0;
	                l = e + 8 | 0;
	                m = e + 4 | 0;
	                n = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[m >> 2] = 0;
	                if (((((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[h >> 2] | 0) + 8 >> 2] | 0, 189848) | 0) != 0 : 0) ? (qy(c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0) {
	                    if (c[(c[h >> 2] | 0) + 24 >> 2] | 0)zN(c[g >> 2] | 0, c[h >> 2] | 0, 1029, 193968, 0, 0);
	                    d = c[g >> 2] | 0;
	                    b = c[h >> 2] | 0;
	                    if (!(c[(c[h >> 2] | 0) + 12 >> 2] | 0)) {
	                        zN(d, b, 1027, 193344, 0, 0);
	                        c[f >> 2] = 0;
	                        o = c[f >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    }
	                    c[k >> 2] = DN(d, b) | 0;
	                    if (!(c[k >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        o = c[f >> 2] | 0;
	                        i = e;
	                        return o | 0
	                    }
	                    c[c[k >> 2] >> 2] = 2;
	                    c[n >> 2] = c[(c[h >> 2] | 0) + 12 >> 2];
	                    while (1) {
	                        if (!(c[n >> 2] | 0))break;
	                        c[l >> 2] = DN(c[g >> 2] | 0, c[n >> 2] | 0) | 0;
	                        if (!(c[l >> 2] | 0))break;
	                        b = c[l >> 2] | 0;
	                        if (c[j >> 2] | 0)c[b >> 2] = 9; else c[b >> 2] = 4;
	                        if (jP(c[g >> 2] | 0, c[n >> 2] | 0, c[l >> 2] | 0) | 0) {
	                            b = c[l >> 2] | 0;
	                            if (!(c[m >> 2] | 0))c[(c[k >> 2] | 0) + 24 >> 2] = b; else c[(c[m >> 2] | 0) + 32 >> 2] = b;
	                            c[m >> 2] = c[l >> 2]
	                        }
	                        c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2]
	                    }
	                    c[f >> 2] = c[k >> 2];
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                zN(c[g >> 2] | 0, c[h >> 2] | 0, 1028, 193936, 0, 0);
	                c[f >> 2] = 0;
	                o = c[f >> 2] | 0;
	                i = e;
	                return o | 0
	            }

	            function qP(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[e + 12 >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                if (((((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 192360) | 0) != 0 : 0) ? (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0)l = 13; else l = 8;
	                if ((((((l | 0) == 8 ? (c[g >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 189888) | 0) != 0 : 0) ? (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[46968] | 0) | 0) != 0 : 0)l = 13;
	                if ((l | 0) == 13 ? (c[h >> 2] = Yi(c[g >> 2] | 0, 193160) | 0, (c[h >> 2] | 0) != 0) : 0) {
	                    if (!(d[c[h >> 2] >> 0] | 0)) {
	                        zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                        c[f >> 2] = 0;
	                        k = c[f >> 2] | 0;
	                        i = e;
	                        return k | 0
	                    }
	                    c[j >> 2] = Fl(c[h >> 2] | 0, 193176) | 0;
	                    if (!(c[j >> 2] | 0)) {
	                        c[f >> 2] = c[h >> 2];
	                        k = c[f >> 2] | 0;
	                        i = e;
	                        return k | 0
	                    } else {
	                        zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                        c[f >> 2] = c[j >> 2];
	                        k = c[f >> 2] | 0;
	                        i = e;
	                        return k | 0
	                    }
	                }
	                c[g >> 2] = c[(c[g >> 2] | 0) + 20 >> 2];
	                while (1) {
	                    if (!(c[g >> 2] | 0)) {
	                        l = 29;
	                        break
	                    }
	                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 1) {
	                        l = 29;
	                        break
	                    }
	                    c[h >> 2] = Yi(c[g >> 2] | 0, 193160) | 0;
	                    if (c[h >> 2] | 0)break;
	                    c[g >> 2] = c[(c[g >> 2] | 0) + 20 >> 2]
	                }
	                if ((l | 0) == 29) {
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                if (!(d[c[h >> 2] >> 0] | 0)) {
	                    zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                c[j >> 2] = Fl(c[h >> 2] | 0, 193176) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    c[f >> 2] = c[h >> 2];
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                } else {
	                    zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                    c[f >> 2] = c[j >> 2];
	                    k = c[f >> 2] | 0;
	                    i = e;
	                    return k | 0
	                }
	                return 0
	            }

	            function rP(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) ? (c[(c[f >> 2] | 0) + 24 >> 2] | 0) != 0 : 0) {
	                    if (!(c[(c[g >> 2] | 0) + 28 >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                    if (!(c[(c[(c[f >> 2] | 0) + 24 >> 2] | 0) + 28 >> 2] | 0)) {
	                        b = Ij(10) | 0;
	                        c[(c[(c[f >> 2] | 0) + 24 >> 2] | 0) + 28 >> 2] = b
	                    }
	                    if (!(c[(c[(c[f >> 2] | 0) + 24 >> 2] | 0) + 28 >> 2] | 0)) {
	                        zN(c[f >> 2] | 0, 0, 1098, 192264, 0, 0);
	                        c[e >> 2] = -1;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    } else {
	                        Wj(c[(c[g >> 2] | 0) + 28 >> 2] | 0, 386, c[f >> 2] | 0);
	                        c[e >> 2] = 0;
	                        h = c[e >> 2] | 0;
	                        i = d;
	                        return h | 0
	                    }
	                }
	                c[e >> 2] = -1;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function sP(a, d, e) {
	                a = a | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 24 | 0;
	                h = f + 20 | 0;
	                j = f + 16 | 0;
	                k = f + 12 | 0;
	                l = f + 8 | 0;
	                m = f + 4 | 0;
	                n = f;
	                c[g >> 2] = a;
	                c[h >> 2] = d;
	                c[j >> 2] = e;
	                c[k >> 2] = c[h >> 2];
	                c[l >> 2] = c[g >> 2];
	                g = (c[l >> 2] | 0) + 50 | 0;
	                b[g >> 1] = b[g >> 1] | 256;
	                c[m >> 2] = Lj(c[(c[(c[k >> 2] | 0) + 24 >> 2] | 0) + 28 >> 2] | 0, c[j >> 2] | 0, c[l >> 2] | 0) | 0;
	                if ((c[m >> 2] | 0) >= 0) {
	                    i = f;
	                    return
	                }
	                c[n >> 2] = Rj(c[(c[(c[k >> 2] | 0) + 24 >> 2] | 0) + 28 >> 2] | 0, c[(c[l >> 2] | 0) + 8 >> 2] | 0) | 0;
	                if (c[n >> 2] | 0) {
	                    c[(c[l >> 2] | 0) + 44 >> 2] = c[(c[n >> 2] | 0) + 44 >> 2];
	                    c[(c[n >> 2] | 0) + 44 >> 2] = c[l >> 2];
	                    i = f;
	                    return
	                }
	                n = c[k >> 2] | 0;
	                if (c[(c[l >> 2] | 0) + 8 >> 2] | 0) {
	                    zN(n, 0, 1098, 192304, c[(c[l >> 2] | 0) + 8 >> 2] | 0, 0);
	                    i = f;
	                    return
	                } else {
	                    zN(n, 0, 1098, 192336, 0, 0);
	                    i = f;
	                    return
	                }
	            }

	            function tP() {
	                return 0
	            }

	            function uP() {
	                var a = 0, b = 0, d = 0;
	                a = i;
	                i = i + 16 | 0;
	                b = a;
	                do if (!(c[49266] | 0)) {
	                    d = tx() | 0;
	                    c[49268] = d;
	                    if (!d) {
	                        c[b >> 2] = 0;
	                        break
	                    } else {
	                        vx(c[49268] | 0);
	                        c[49270] = jb(0) | 0;
	                        ET(197080) | 0;
	                        c[49266] = 1;
	                        wx(c[49268] | 0);
	                        c[b >> 2] = 1;
	                        break
	                    }
	                } else c[b >> 2] = 1; while (0);
	                i = a;
	                return c[b >> 2] | 0
	            }

	            function vP() {
	                var a = 0, b = 0;
	                a = i;
	                i = i + 16 | 0;
	                b = a;
	                if (!(c[49266] | 0))uP() | 0;
	                vx(c[49268] | 0);
	                c[b >> 2] = ET(197080) | 0;
	                wx(c[49268] | 0);
	                i = a;
	                return c[b >> 2] | 0
	            }

	            function wP() {
	                var a = 0;
	                a = i;
	                if (!(c[49266] | 0)) {
	                    i = a;
	                    return
	                }
	                ux(c[49268] | 0);
	                c[49266] = 0;
	                i = a;
	                return
	            }

	            function xP() {
	                var a = 0, b = 0, d = 0, e = 0, f = 0;
	                a = i;
	                i = i + 16 | 0;
	                b = a + 4 | 0;
	                d = a;
	                if ((c[49266] | 0) == 0 ? (uP() | 0) == 0 : 0) {
	                    c[b >> 2] = 0;
	                    e = c[b >> 2] | 0;
	                    i = a;
	                    return e | 0
	                }
	                c[d >> 2] = Cb[c[135744 >> 2] & 511](32) | 0;
	                do if (c[d >> 2] | 0) {
	                    c[c[d >> 2] >> 2] = 1;
	                    c[(c[d >> 2] | 0) + 28 >> 2] = 0;
	                    c[(c[d >> 2] | 0) + 8 >> 2] = 128;
	                    c[(c[d >> 2] | 0) + 12 >> 2] = 0;
	                    f = Cb[c[135744 >> 2] & 511](2560) | 0;
	                    c[(c[d >> 2] | 0) + 4 >> 2] = f;
	                    c[(c[d >> 2] | 0) + 16 >> 2] = 0;
	                    c[(c[d >> 2] | 0) + 20 >> 2] = 0;
	                    if (!(c[(c[d >> 2] | 0) + 4 >> 2] | 0)) {
	                        zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                        break
	                    }
	                    cU(c[(c[d >> 2] | 0) + 4 >> 2] | 0, 0, 2560) | 0;
	                    f = vP() | 0;
	                    c[(c[d >> 2] | 0) + 24 >> 2] = f;
	                    c[b >> 2] = c[d >> 2];
	                    e = c[b >> 2] | 0;
	                    i = a;
	                    return e | 0
	                } while (0);
	                c[b >> 2] = 0;
	                e = c[b >> 2] | 0;
	                i = a;
	                return e | 0
	            }

	            function yP(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                if ((c[49266] | 0) == 0 ? (uP() | 0) == 0 : 0)c[d >> 2] = -1; else f = 4;
	                do if ((f | 0) == 4)if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = -1;
	                    break
	                } else {
	                    vx(c[49268] | 0);
	                    a = c[e >> 2] | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1;
	                    wx(c[49268] | 0);
	                    c[d >> 2] = 0;
	                    break
	                } while (0);
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function zP(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 24 | 0;
	                e = b + 20 | 0;
	                f = b + 16 | 0;
	                g = b + 12 | 0;
	                h = b + 8 | 0;
	                j = b + 4 | 0;
	                k = b;
	                c[d >> 2] = a;
	                c[h >> 2] = 0;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if ((c[49266] | 0) == 0 ? (uP() | 0) == 0 : 0) {
	                    i = b;
	                    return
	                }
	                vx(c[49268] | 0);
	                a = c[d >> 2] | 0;
	                c[a >> 2] = (c[a >> 2] | 0) + -1;
	                a = (c[c[d >> 2] >> 2] | 0) > 0;
	                wx(c[49268] | 0);
	                if (a) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 20 >> 2] | 0)zP(c[(c[d >> 2] | 0) + 20 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 4 >> 2] | 0) {
	                    c[e >> 2] = 0;
	                    while (1) {
	                        if ((c[e >> 2] | 0) >>> 0 >= (c[(c[d >> 2] | 0) + 8 >> 2] | 0) >>> 0)break;
	                        if ((c[(c[d >> 2] | 0) + 12 >> 2] | 0) >>> 0 <= 0)break;
	                        c[f >> 2] = (c[(c[d >> 2] | 0) + 4 >> 2] | 0) + ((c[e >> 2] | 0) * 20 | 0);
	                        a:do if (c[(c[f >> 2] | 0) + 12 >> 2] | 0) {
	                            c[h >> 2] = 1;
	                            while (1) {
	                                if (!(c[f >> 2] | 0))break a;
	                                c[g >> 2] = c[c[f >> 2] >> 2];
	                                if (!(c[h >> 2] | 0))zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                                a = (c[d >> 2] | 0) + 12 | 0;
	                                c[a >> 2] = (c[a >> 2] | 0) + -1;
	                                c[h >> 2] = 0;
	                                c[f >> 2] = c[g >> 2]
	                            }
	                        } while (0);
	                        c[e >> 2] = (c[e >> 2] | 0) + 1
	                    }
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 4 >> 2] | 0)
	                }
	                c[j >> 2] = c[(c[d >> 2] | 0) + 16 >> 2];
	                while (1) {
	                    if (!(c[j >> 2] | 0))break;
	                    c[k >> 2] = c[c[j >> 2] >> 2];
	                    zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                    c[j >> 2] = c[k >> 2]
	                }
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function AP(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0;
	                e = i;
	                i = i + 64 | 0;
	                f = e + 48 | 0;
	                g = e + 44 | 0;
	                h = e + 40 | 0;
	                j = e + 36 | 0;
	                k = e + 32 | 0;
	                l = e + 28 | 0;
	                m = e + 24 | 0;
	                n = e + 20 | 0;
	                o = e + 16 | 0;
	                p = e + 12 | 0;
	                q = e + 8 | 0;
	                r = e + 4 | 0;
	                s = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[m >> 2] = 0;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    t = c[f >> 2] | 0;
	                    i = e;
	                    return t | 0
	                }
	                if ((c[j >> 2] | 0) < 0)c[q >> 2] = ZT(c[h >> 2] | 0) | 0; else c[q >> 2] = c[j >> 2];
	                j = c[q >> 2] | 0;
	                if ((c[(c[g >> 2] | 0) + 28 >> 2] | 0) >>> 0 > 0) {
	                    if ((c[q >> 2] | 0) >>> 0 > 1073741823 ? 1 : j >>> 0 >= (c[(c[g >> 2] | 0) + 28 >> 2] | 0) >>> 0)u = 9
	                } else if (j >>> 0 > 1073741823)u = 9;
	                if ((u | 0) == 9) {
	                    c[f >> 2] = 0;
	                    t = c[f >> 2] | 0;
	                    i = e;
	                    return t | 0
	                }
	                j = c[h >> 2] | 0;
	                d = c[q >> 2] | 0;
	                b = c[(c[g >> 2] | 0) + 24 >> 2] | 0;
	                if ((c[(c[g >> 2] | 0) + 8 >> 2] | 0) == 128)v = EP(j, d, b) | 0; else v = FP(j, d, b) | 0;
	                c[l >> 2] = v;
	                c[k >> 2] = ((c[l >> 2] | 0) >>> 0) % ((c[(c[g >> 2] | 0) + 8 >> 2] | 0) >>> 0) | 0;
	                if (c[(c[(c[g >> 2] | 0) + 4 >> 2] | 0) + ((c[k >> 2] | 0) * 20 | 0) + 12 >> 2] | 0) {
	                    c[o >> 2] = (c[(c[g >> 2] | 0) + 4 >> 2] | 0) + ((c[k >> 2] | 0) * 20 | 0);
	                    while (1) {
	                        w = (c[(c[o >> 2] | 0) + 16 >> 2] | 0) == (c[l >> 2] | 0);
	                        if (!(c[c[o >> 2] >> 2] | 0))break;
	                        if ((w ? (c[(c[o >> 2] | 0) + 8 >> 2] | 0) == (c[q >> 2] | 0) : 0) ? (OT(c[(c[o >> 2] | 0) + 4 >> 2] | 0, c[h >> 2] | 0, c[q >> 2] | 0) | 0) == 0 : 0) {
	                            u = 20;
	                            break
	                        }
	                        c[m >> 2] = (c[m >> 2] | 0) + 1;
	                        c[o >> 2] = c[c[o >> 2] >> 2]
	                    }
	                    if ((u | 0) == 20) {
	                        c[f >> 2] = c[(c[o >> 2] | 0) + 4 >> 2];
	                        t = c[f >> 2] | 0;
	                        i = e;
	                        return t | 0
	                    }
	                    if ((w ? (c[(c[o >> 2] | 0) + 8 >> 2] | 0) == (c[q >> 2] | 0) : 0) ? (OT(c[(c[o >> 2] | 0) + 4 >> 2] | 0, c[h >> 2] | 0, c[q >> 2] | 0) | 0) == 0 : 0) {
	                        c[f >> 2] = c[(c[o >> 2] | 0) + 4 >> 2];
	                        t = c[f >> 2] | 0;
	                        i = e;
	                        return t | 0
	                    }
	                } else c[o >> 2] = 0;
	                if (c[(c[g >> 2] | 0) + 20 >> 2] | 0) {
	                    if ((c[(c[g >> 2] | 0) + 8 >> 2] | 0) == 128 ? (c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0) != 128 : 0)u = 31; else u = 29;
	                    do if ((u | 0) == 29) {
	                        if ((c[(c[g >> 2] | 0) + 8 >> 2] | 0) != 128 ? (c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0) == 128 : 0) {
	                            u = 31;
	                            break
	                        }
	                        c[r >> 2] = c[l >> 2]
	                    } while (0);
	                    if ((u | 0) == 31) {
	                        w = c[h >> 2] | 0;
	                        v = c[q >> 2] | 0;
	                        b = c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 24 >> 2] | 0;
	                        if ((c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0) == 128)x = EP(w, v, b) | 0; else x = FP(w, v, b) | 0;
	                        c[r >> 2] = x
	                    }
	                    c[k >> 2] = ((c[r >> 2] | 0) >>> 0) % ((c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0) >>> 0) | 0;
	                    if (c[(c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 4 >> 2] | 0) + ((c[k >> 2] | 0) * 20 | 0) + 12 >> 2] | 0) {
	                        c[s >> 2] = (c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 4 >> 2] | 0) + ((c[k >> 2] | 0) * 20 | 0);
	                        while (1) {
	                            y = (c[(c[s >> 2] | 0) + 16 >> 2] | 0) == (c[r >> 2] | 0);
	                            if (!(c[c[s >> 2] >> 2] | 0))break;
	                            if ((y ? (c[(c[s >> 2] | 0) + 8 >> 2] | 0) == (c[q >> 2] | 0) : 0) ? (OT(c[(c[s >> 2] | 0) + 4 >> 2] | 0, c[h >> 2] | 0, c[q >> 2] | 0) | 0) == 0 : 0) {
	                                u = 42;
	                                break
	                            }
	                            c[m >> 2] = (c[m >> 2] | 0) + 1;
	                            c[s >> 2] = c[c[s >> 2] >> 2]
	                        }
	                        if ((u | 0) == 42) {
	                            c[f >> 2] = c[(c[s >> 2] | 0) + 4 >> 2];
	                            t = c[f >> 2] | 0;
	                            i = e;
	                            return t | 0
	                        }
	                        if ((y ? (c[(c[s >> 2] | 0) + 8 >> 2] | 0) == (c[q >> 2] | 0) : 0) ? (OT(c[(c[s >> 2] | 0) + 4 >> 2] | 0, c[h >> 2] | 0, c[q >> 2] | 0) | 0) == 0 : 0) {
	                            c[f >> 2] = c[(c[s >> 2] | 0) + 4 >> 2];
	                            t = c[f >> 2] | 0;
	                            i = e;
	                            return t | 0
	                        }
	                    }
	                    c[k >> 2] = ((c[l >> 2] | 0) >>> 0) % ((c[(c[g >> 2] | 0) + 8 >> 2] | 0) >>> 0) | 0
	                }
	                c[p >> 2] = GP(c[g >> 2] | 0, c[h >> 2] | 0, c[q >> 2] | 0) | 0;
	                if (!(c[p >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    t = c[f >> 2] | 0;
	                    i = e;
	                    return t | 0
	                }
	                if (c[o >> 2] | 0) {
	                    c[n >> 2] = Cb[c[135744 >> 2] & 511](20) | 0;
	                    if (!(c[n >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        t = c[f >> 2] | 0;
	                        i = e;
	                        return t | 0
	                    }
	                } else c[n >> 2] = (c[(c[g >> 2] | 0) + 4 >> 2] | 0) + ((c[k >> 2] | 0) * 20 | 0);
	                c[(c[n >> 2] | 0) + 4 >> 2] = c[p >> 2];
	                c[(c[n >> 2] | 0) + 8 >> 2] = c[q >> 2];
	                c[c[n >> 2] >> 2] = 0;
	                c[(c[n >> 2] | 0) + 12 >> 2] = 1;
	                c[(c[n >> 2] | 0) + 16 >> 2] = c[l >> 2];
	                if (c[o >> 2] | 0)c[c[o >> 2] >> 2] = c[n >> 2];
	                n = (c[g >> 2] | 0) + 12 | 0;
	                c[n >> 2] = (c[n >> 2] | 0) + 1;
	                if (((c[m >> 2] | 0) >>> 0 > 3 ? (c[(c[g >> 2] | 0) + 8 >> 2] | 0) >>> 0 <= 2730 : 0) ? (HP(c[g >> 2] | 0, (c[(c[g >> 2] | 0) + 8 >> 2] | 0) * 6 | 0) | 0) != 0 : 0) {
	                    c[f >> 2] = 0;
	                    t = c[f >> 2] | 0;
	                    i = e;
	                    return t | 0
	                }
	                c[f >> 2] = c[p >> 2];
	                t = c[f >> 2] | 0;
	                i = e;
	                return t | 0
	            }

	            function BP(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0;
	                e = i;
	                i = i + 64 | 0;
	                f = e + 56 | 0;
	                g = e + 52 | 0;
	                h = e + 48 | 0;
	                j = e + 44 | 0;
	                k = e + 40 | 0;
	                l = e + 36 | 0;
	                m = e + 32 | 0;
	                n = e + 28 | 0;
	                o = e + 24 | 0;
	                p = e + 20 | 0;
	                q = e + 16 | 0;
	                r = e + 12 | 0;
	                s = e + 8 | 0;
	                t = e + 4 | 0;
	                u = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[m >> 2] = 0;
	                if ((c[g >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    v = c[f >> 2] | 0;
	                    i = e;
	                    return v | 0
	                }
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = AP(c[g >> 2] | 0, c[j >> 2] | 0, -1) | 0;
	                    v = c[f >> 2] | 0;
	                    i = e;
	                    return v | 0
	                }
	                d = ZT(c[j >> 2] | 0) | 0;
	                c[q >> 2] = d;
	                c[s >> 2] = d;
	                c[r >> 2] = ZT(c[h >> 2] | 0) | 0;
	                c[q >> 2] = (c[q >> 2] | 0) + (1 + (c[r >> 2] | 0));
	                d = (c[(c[g >> 2] | 0) + 8 >> 2] | 0) == 128;
	                do if (!(c[h >> 2] | 0)) {
	                    b = c[j >> 2] | 0;
	                    a = c[s >> 2] | 0;
	                    w = c[(c[g >> 2] | 0) + 24 >> 2] | 0;
	                    if (d) {
	                        x = EP(b, a, w) | 0;
	                        break
	                    } else {
	                        x = FP(b, a, w) | 0;
	                        break
	                    }
	                } else {
	                    w = c[h >> 2] | 0;
	                    a = c[r >> 2] | 0;
	                    b = c[j >> 2] | 0;
	                    y = c[s >> 2] | 0;
	                    z = c[(c[g >> 2] | 0) + 24 >> 2] | 0;
	                    if (d) {
	                        x = IP(w, a, b, y, z) | 0;
	                        break
	                    } else {
	                        x = JP(w, a, b, y, z) | 0;
	                        break
	                    }
	                } while (0);
	                c[k >> 2] = x;
	                c[l >> 2] = ((c[k >> 2] | 0) >>> 0) % ((c[(c[g >> 2] | 0) + 8 >> 2] | 0) >>> 0) | 0;
	                if (c[(c[(c[g >> 2] | 0) + 4 >> 2] | 0) + ((c[l >> 2] | 0) * 20 | 0) + 12 >> 2] | 0) {
	                    c[o >> 2] = (c[(c[g >> 2] | 0) + 4 >> 2] | 0) + ((c[l >> 2] | 0) * 20 | 0);
	                    while (1) {
	                        A = (c[(c[o >> 2] | 0) + 16 >> 2] | 0) == (c[k >> 2] | 0);
	                        if (!(c[c[o >> 2] >> 2] | 0))break;
	                        if ((A ? (c[(c[o >> 2] | 0) + 8 >> 2] | 0) == (c[q >> 2] | 0) : 0) ? (ry(c[h >> 2] | 0, c[j >> 2] | 0, c[(c[o >> 2] | 0) + 4 >> 2] | 0) | 0) != 0 : 0) {
	                            B = 19;
	                            break
	                        }
	                        c[m >> 2] = (c[m >> 2] | 0) + 1;
	                        c[o >> 2] = c[c[o >> 2] >> 2]
	                    }
	                    if ((B | 0) == 19) {
	                        c[f >> 2] = c[(c[o >> 2] | 0) + 4 >> 2];
	                        v = c[f >> 2] | 0;
	                        i = e;
	                        return v | 0
	                    }
	                    if ((A ? (c[(c[o >> 2] | 0) + 8 >> 2] | 0) == (c[q >> 2] | 0) : 0) ? (ry(c[h >> 2] | 0, c[j >> 2] | 0, c[(c[o >> 2] | 0) + 4 >> 2] | 0) | 0) != 0 : 0) {
	                        c[f >> 2] = c[(c[o >> 2] | 0) + 4 >> 2];
	                        v = c[f >> 2] | 0;
	                        i = e;
	                        return v | 0
	                    }
	                } else c[o >> 2] = 0;
	                if (c[(c[g >> 2] | 0) + 20 >> 2] | 0) {
	                    if ((c[(c[g >> 2] | 0) + 8 >> 2] | 0) == 128 ? (c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0) != 128 : 0)B = 30; else B = 28;
	                    do if ((B | 0) == 28) {
	                        if ((c[(c[g >> 2] | 0) + 8 >> 2] | 0) != 128 ? (c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0) == 128 : 0) {
	                            B = 30;
	                            break
	                        }
	                        c[t >> 2] = c[k >> 2]
	                    } while (0);
	                    if ((B | 0) == 30) {
	                        A = (c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0) == 128;
	                        do if (!(c[h >> 2] | 0)) {
	                            x = c[j >> 2] | 0;
	                            d = c[s >> 2] | 0;
	                            z = c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 24 >> 2] | 0;
	                            if (A) {
	                                C = EP(x, d, z) | 0;
	                                break
	                            } else {
	                                C = FP(x, d, z) | 0;
	                                break
	                            }
	                        } else {
	                            z = c[h >> 2] | 0;
	                            d = c[r >> 2] | 0;
	                            x = c[j >> 2] | 0;
	                            y = c[s >> 2] | 0;
	                            b = c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 24 >> 2] | 0;
	                            if (A) {
	                                C = IP(z, d, x, y, b) | 0;
	                                break
	                            } else {
	                                C = JP(z, d, x, y, b) | 0;
	                                break
	                            }
	                        } while (0);
	                        c[t >> 2] = C
	                    }
	                    c[l >> 2] = ((c[t >> 2] | 0) >>> 0) % ((c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0) >>> 0) | 0;
	                    if (c[(c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 4 >> 2] | 0) + ((c[l >> 2] | 0) * 20 | 0) + 12 >> 2] | 0) {
	                        c[u >> 2] = (c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 4 >> 2] | 0) + ((c[l >> 2] | 0) * 20 | 0);
	                        while (1) {
	                            D = (c[(c[u >> 2] | 0) + 16 >> 2] | 0) == (c[t >> 2] | 0);
	                            if (!(c[c[u >> 2] >> 2] | 0))break;
	                            if ((D ? (c[(c[u >> 2] | 0) + 8 >> 2] | 0) == (c[q >> 2] | 0) : 0) ? (ry(c[h >> 2] | 0, c[j >> 2] | 0, c[(c[u >> 2] | 0) + 4 >> 2] | 0) | 0) != 0 : 0) {
	                                B = 45;
	                                break
	                            }
	                            c[m >> 2] = (c[m >> 2] | 0) + 1;
	                            c[u >> 2] = c[c[u >> 2] >> 2]
	                        }
	                        if ((B | 0) == 45) {
	                            c[f >> 2] = c[(c[u >> 2] | 0) + 4 >> 2];
	                            v = c[f >> 2] | 0;
	                            i = e;
	                            return v | 0
	                        }
	                        if ((D ? (c[(c[u >> 2] | 0) + 8 >> 2] | 0) == (c[q >> 2] | 0) : 0) ? (ry(c[h >> 2] | 0, c[j >> 2] | 0, c[(c[u >> 2] | 0) + 4 >> 2] | 0) | 0) != 0 : 0) {
	                            c[f >> 2] = c[(c[u >> 2] | 0) + 4 >> 2];
	                            v = c[f >> 2] | 0;
	                            i = e;
	                            return v | 0
	                        }
	                    }
	                    c[l >> 2] = ((c[k >> 2] | 0) >>> 0) % ((c[(c[g >> 2] | 0) + 8 >> 2] | 0) >>> 0) | 0
	                }
	                c[p >> 2] = KP(c[g >> 2] | 0, c[h >> 2] | 0, c[r >> 2] | 0, c[j >> 2] | 0, c[s >> 2] | 0) | 0;
	                if (!(c[p >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    v = c[f >> 2] | 0;
	                    i = e;
	                    return v | 0
	                }
	                if (c[o >> 2] | 0) {
	                    c[n >> 2] = Cb[c[135744 >> 2] & 511](20) | 0;
	                    if (!(c[n >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        v = c[f >> 2] | 0;
	                        i = e;
	                        return v | 0
	                    }
	                } else c[n >> 2] = (c[(c[g >> 2] | 0) + 4 >> 2] | 0) + ((c[l >> 2] | 0) * 20 | 0);
	                c[(c[n >> 2] | 0) + 4 >> 2] = c[p >> 2];
	                c[(c[n >> 2] | 0) + 8 >> 2] = c[q >> 2];
	                c[c[n >> 2] >> 2] = 0;
	                c[(c[n >> 2] | 0) + 12 >> 2] = 1;
	                c[(c[n >> 2] | 0) + 16 >> 2] = c[k >> 2];
	                if (c[o >> 2] | 0)c[c[o >> 2] >> 2] = c[n >> 2];
	                n = (c[g >> 2] | 0) + 12 | 0;
	                c[n >> 2] = (c[n >> 2] | 0) + 1;
	                if ((c[m >> 2] | 0) >>> 0 > 3 ? (c[(c[g >> 2] | 0) + 8 >> 2] | 0) >>> 0 <= 2730 : 0)HP(c[g >> 2] | 0, (c[(c[g >> 2] | 0) + 8 >> 2] | 0) * 6 | 0) | 0;
	                c[f >> 2] = c[p >> 2];
	                v = c[f >> 2] | 0;
	                i = e;
	                return v | 0
	            }

	            function CP(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = -1;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[h >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                while (1) {
	                    if (!(c[h >> 2] | 0))break;
	                    if ((c[g >> 2] | 0) >>> 0 >= ((c[h >> 2] | 0) + 20 | 0) >>> 0 ? (c[g >> 2] | 0) >>> 0 <= (c[(c[h >> 2] | 0) + 4 >> 2] | 0) >>> 0 : 0) {
	                        k = 7;
	                        break
	                    }
	                    c[h >> 2] = c[c[h >> 2] >> 2]
	                }
	                if ((k | 0) == 7) {
	                    c[e >> 2] = 1;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                if (c[(c[f >> 2] | 0) + 20 >> 2] | 0) {
	                    c[e >> 2] = CP(c[(c[f >> 2] | 0) + 20 >> 2] | 0, c[g >> 2] | 0) | 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } else {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                return 0
	            }

	            function DP(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } else {
	                    c[h >> 2] = c[(c[f >> 2] | 0) + 28 >> 2];
	                    c[(c[f >> 2] | 0) + 28 >> 2] = c[g >> 2];
	                    c[e >> 2] = c[h >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                return 0
	            }

	            function EP(a, b, e) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 16 | 0;
	                h = f + 12 | 0;
	                j = f + 8 | 0;
	                k = f + 4 | 0;
	                l = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[l >> 2] = c[k >> 2];
	                if (!(c[h >> 2] | 0)) {
	                    c[g >> 2] = 0;
	                    m = c[g >> 2] | 0;
	                    i = f;
	                    return m | 0
	                }
	                c[l >> 2] = d[c[h >> 2] >> 0];
	                c[l >> 2] = c[l >> 2] << 5;
	                if ((c[j >> 2] | 0) > 10) {
	                    c[l >> 2] = (c[l >> 2] | 0) + (d[(c[h >> 2] | 0) + ((c[j >> 2] | 0) - 1) >> 0] | 0);
	                    c[j >> 2] = 10
	                }
	                switch (c[j >> 2] | 0) {
	                    case 7:
	                    {
	                        n = 9;
	                        break
	                    }
	                    case 6:
	                    {
	                        n = 10;
	                        break
	                    }
	                    case 9:
	                    {
	                        n = 7;
	                        break
	                    }
	                    case 3:
	                    {
	                        n = 13;
	                        break
	                    }
	                    case 8:
	                    {
	                        n = 8;
	                        break
	                    }
	                    case 10:
	                    {
	                        c[l >> 2] = (c[l >> 2] | 0) + (d[(c[h >> 2] | 0) + 9 >> 0] | 0);
	                        n = 7;
	                        break
	                    }
	                    case 2:
	                    {
	                        n = 14;
	                        break
	                    }
	                    case 4:
	                    {
	                        n = 12;
	                        break
	                    }
	                    case 5:
	                    {
	                        n = 11;
	                        break
	                    }
	                    default:
	                    {
	                    }
	                }
	                if ((n | 0) == 7) {
	                    c[l >> 2] = (c[l >> 2] | 0) + (d[(c[h >> 2] | 0) + 8 >> 0] | 0);
	                    n = 8
	                }
	                if ((n | 0) == 8) {
	                    c[l >> 2] = (c[l >> 2] | 0) + (d[(c[h >> 2] | 0) + 7 >> 0] | 0);
	                    n = 9
	                }
	                if ((n | 0) == 9) {
	                    c[l >> 2] = (c[l >> 2] | 0) + (d[(c[h >> 2] | 0) + 6 >> 0] | 0);
	                    n = 10
	                }
	                if ((n | 0) == 10) {
	                    c[l >> 2] = (c[l >> 2] | 0) + (d[(c[h >> 2] | 0) + 5 >> 0] | 0);
	                    n = 11
	                }
	                if ((n | 0) == 11) {
	                    c[l >> 2] = (c[l >> 2] | 0) + (d[(c[h >> 2] | 0) + 4 >> 0] | 0);
	                    n = 12
	                }
	                if ((n | 0) == 12) {
	                    c[l >> 2] = (c[l >> 2] | 0) + (d[(c[h >> 2] | 0) + 3 >> 0] | 0);
	                    n = 13
	                }
	                if ((n | 0) == 13) {
	                    c[l >> 2] = (c[l >> 2] | 0) + (d[(c[h >> 2] | 0) + 2 >> 0] | 0);
	                    n = 14
	                }
	                if ((n | 0) == 14)c[l >> 2] = (c[l >> 2] | 0) + (d[(c[h >> 2] | 0) + 1 >> 0] | 0);
	                c[g >> 2] = c[l >> 2];
	                m = c[g >> 2] | 0;
	                i = f;
	                return m | 0
	            }

	            function FP(a, b, e) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                if ((c[j >> 2] | 0) <= 0 | (c[h >> 2] | 0) == 0) {
	                    c[g >> 2] = 0;
	                    n = c[g >> 2] | 0;
	                    i = f;
	                    return n | 0
	                }
	                c[l >> 2] = c[k >> 2];
	                c[m >> 2] = 0;
	                while (1) {
	                    if ((c[m >> 2] | 0) >= (c[j >> 2] | 0))break;
	                    c[l >> 2] = (c[l >> 2] | 0) + (d[(c[h >> 2] | 0) + (c[m >> 2] | 0) >> 0] | 0);
	                    c[l >> 2] = (c[l >> 2] | 0) + (c[l >> 2] << 10);
	                    c[l >> 2] = c[l >> 2] ^ (c[l >> 2] | 0) >>> 6;
	                    c[m >> 2] = (c[m >> 2] | 0) + 1
	                }
	                c[l >> 2] = (c[l >> 2] | 0) + (c[l >> 2] << 3);
	                c[l >> 2] = c[l >> 2] ^ (c[l >> 2] | 0) >>> 11;
	                c[l >> 2] = (c[l >> 2] | 0) + (c[l >> 2] << 15);
	                c[g >> 2] = c[l >> 2];
	                n = c[g >> 2] | 0;
	                i = f;
	                return n | 0
	            }

	            function GP(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 28 | 0;
	                h = f + 24 | 0;
	                j = f + 20 | 0;
	                k = f + 16 | 0;
	                l = f + 12 | 0;
	                m = f + 8 | 0;
	                n = f + 4 | 0;
	                o = f;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[n >> 2] = 0;
	                c[o >> 2] = 0;
	                c[l >> 2] = c[(c[h >> 2] | 0) + 16 >> 2];
	                while (1) {
	                    p = c[l >> 2] | 0;
	                    if (!(c[l >> 2] | 0)) {
	                        q = 7;
	                        break
	                    }
	                    if (((c[p + 8 >> 2] | 0) - (c[(c[l >> 2] | 0) + 4 >> 2] | 0) | 0) >>> 0 > (c[k >> 2] | 0) >>> 0)break;
	                    if ((c[(c[l >> 2] | 0) + 12 >> 2] | 0) >>> 0 > (c[n >> 2] | 0) >>> 0)c[n >> 2] = c[(c[l >> 2] | 0) + 12 >> 2];
	                    c[o >> 2] = (c[o >> 2] | 0) + (c[(c[l >> 2] | 0) + 12 >> 2] | 0);
	                    c[l >> 2] = c[c[l >> 2] >> 2]
	                }
	                do if ((q | 0) == 7 ? (p | 0) == 0 : 0) {
	                    if ((c[(c[h >> 2] | 0) + 28 >> 2] | 0) >>> 0 > 0 ? (c[o >> 2] | 0) >>> 0 > (c[(c[h >> 2] | 0) + 28 >> 2] | 0) >>> 0 : 0) {
	                        c[g >> 2] = 0;
	                        r = c[g >> 2] | 0;
	                        i = f;
	                        return r | 0
	                    }
	                    if (!(c[n >> 2] | 0))c[n >> 2] = 1e3; else c[n >> 2] = c[n >> 2] << 2;
	                    if ((c[n >> 2] | 0) >>> 0 < c[k >> 2] << 2 >>> 0)c[n >> 2] = c[k >> 2] << 2;
	                    c[l >> 2] = Cb[c[135744 >> 2] & 511](24 + (c[n >> 2] | 0) | 0) | 0;
	                    if (c[l >> 2] | 0) {
	                        c[(c[l >> 2] | 0) + 12 >> 2] = c[n >> 2];
	                        c[(c[l >> 2] | 0) + 16 >> 2] = 0;
	                        c[(c[l >> 2] | 0) + 4 >> 2] = (c[l >> 2] | 0) + 20;
	                        c[(c[l >> 2] | 0) + 8 >> 2] = (c[l >> 2] | 0) + 20 + (c[n >> 2] | 0);
	                        c[c[l >> 2] >> 2] = c[(c[h >> 2] | 0) + 16 >> 2];
	                        c[(c[h >> 2] | 0) + 16 >> 2] = c[l >> 2];
	                        break
	                    }
	                    c[g >> 2] = 0;
	                    r = c[g >> 2] | 0;
	                    i = f;
	                    return r | 0
	                } while (0);
	                c[m >> 2] = c[(c[l >> 2] | 0) + 4 >> 2];
	                eU(c[(c[l >> 2] | 0) + 4 >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                j = (c[l >> 2] | 0) + 4 | 0;
	                c[j >> 2] = (c[j >> 2] | 0) + (c[k >> 2] | 0);
	                k = (c[l >> 2] | 0) + 4 | 0;
	                j = c[k >> 2] | 0;
	                c[k >> 2] = j + 1;
	                a[j >> 0] = 0;
	                j = (c[l >> 2] | 0) + 16 | 0;
	                c[j >> 2] = (c[j >> 2] | 0) + 1;
	                c[g >> 2] = c[m >> 2];
	                r = c[g >> 2] | 0;
	                i = f;
	                return r | 0
	            }

	            function HP(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                d = i;
	                i = i + 64 | 0;
	                e = d + 48 | 0;
	                f = d + 44 | 0;
	                g = d + 40 | 0;
	                h = d + 36 | 0;
	                j = d + 32 | 0;
	                k = d + 28 | 0;
	                l = d + 24 | 0;
	                m = d + 20 | 0;
	                n = d + 16 | 0;
	                o = d + 12 | 0;
	                p = d + 8 | 0;
	                q = d + 4 | 0;
	                r = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[p >> 2] = 0;
	                c[q >> 2] = 1;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    s = c[e >> 2] | 0;
	                    i = d;
	                    return s | 0
	                }
	                if ((c[g >> 2] | 0) >>> 0 < 8) {
	                    c[e >> 2] = -1;
	                    s = c[e >> 2] | 0;
	                    i = d;
	                    return s | 0
	                }
	                if ((c[g >> 2] | 0) >>> 0 > 16384) {
	                    c[e >> 2] = -1;
	                    s = c[e >> 2] | 0;
	                    i = d;
	                    return s | 0
	                }
	                c[k >> 2] = c[(c[f >> 2] | 0) + 8 >> 2];
	                c[o >> 2] = c[(c[f >> 2] | 0) + 4 >> 2];
	                if (!(c[o >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    s = c[e >> 2] | 0;
	                    i = d;
	                    return s | 0
	                }
	                if ((c[k >> 2] | 0) == 128)c[q >> 2] = 0;
	                b = Cb[c[135744 >> 2] & 511]((c[g >> 2] | 0) * 20 | 0) | 0;
	                c[(c[f >> 2] | 0) + 4 >> 2] = b;
	                if (!(c[(c[f >> 2] | 0) + 4 >> 2] | 0)) {
	                    c[(c[f >> 2] | 0) + 4 >> 2] = c[o >> 2];
	                    c[e >> 2] = -1;
	                    s = c[e >> 2] | 0;
	                    i = d;
	                    return s | 0
	                }
	                cU(c[(c[f >> 2] | 0) + 4 >> 2] | 0, 0, (c[g >> 2] | 0) * 20 | 0) | 0;
	                c[(c[f >> 2] | 0) + 8 >> 2] = c[g >> 2];
	                c[l >> 2] = 0;
	                while (1) {
	                    if ((c[l >> 2] | 0) >>> 0 >= (c[k >> 2] | 0) >>> 0)break;
	                    do if (c[(c[o >> 2] | 0) + ((c[l >> 2] | 0) * 20 | 0) + 12 >> 2] | 0) {
	                        if (c[q >> 2] | 0)c[j >> 2] = c[(c[o >> 2] | 0) + ((c[l >> 2] | 0) * 20 | 0) + 16 >> 2]; else {
	                            g = c[(c[o >> 2] | 0) + ((c[l >> 2] | 0) * 20 | 0) + 4 >> 2] | 0;
	                            b = c[(c[o >> 2] | 0) + ((c[l >> 2] | 0) * 20 | 0) + 8 >> 2] | 0;
	                            a = c[(c[f >> 2] | 0) + 24 >> 2] | 0;
	                            if ((c[(c[f >> 2] | 0) + 8 >> 2] | 0) == 128)t = EP(g, b, a) | 0; else t = FP(g, b, a) | 0;
	                            c[j >> 2] = t
	                        }
	                        c[h >> 2] = ((c[j >> 2] | 0) >>> 0) % ((c[(c[f >> 2] | 0) + 8 >> 2] | 0) >>> 0) | 0;
	                        if (!(c[(c[(c[f >> 2] | 0) + 4 >> 2] | 0) + ((c[h >> 2] | 0) * 20 | 0) + 12 >> 2] | 0)) {
	                            a = (c[(c[f >> 2] | 0) + 4 >> 2] | 0) + ((c[h >> 2] | 0) * 20 | 0) | 0;
	                            b = (c[o >> 2] | 0) + ((c[l >> 2] | 0) * 20 | 0) | 0;
	                            c[a + 0 >> 2] = c[b + 0 >> 2];
	                            c[a + 4 >> 2] = c[b + 4 >> 2];
	                            c[a + 8 >> 2] = c[b + 8 >> 2];
	                            c[a + 12 >> 2] = c[b + 12 >> 2];
	                            c[a + 16 >> 2] = c[b + 16 >> 2];
	                            c[(c[(c[f >> 2] | 0) + 4 >> 2] | 0) + ((c[h >> 2] | 0) * 20 | 0) >> 2] = 0;
	                            c[(c[(c[f >> 2] | 0) + 4 >> 2] | 0) + ((c[h >> 2] | 0) * 20 | 0) + 16 >> 2] = c[j >> 2];
	                            break
	                        }
	                        c[r >> 2] = Cb[c[135744 >> 2] & 511](20) | 0;
	                        if (c[r >> 2] | 0) {
	                            c[(c[r >> 2] | 0) + 4 >> 2] = c[(c[o >> 2] | 0) + ((c[l >> 2] | 0) * 20 | 0) + 4 >> 2];
	                            c[(c[r >> 2] | 0) + 8 >> 2] = c[(c[o >> 2] | 0) + ((c[l >> 2] | 0) * 20 | 0) + 8 >> 2];
	                            c[(c[r >> 2] | 0) + 16 >> 2] = c[j >> 2];
	                            c[c[r >> 2] >> 2] = c[(c[(c[f >> 2] | 0) + 4 >> 2] | 0) + ((c[h >> 2] | 0) * 20 | 0) >> 2];
	                            c[(c[r >> 2] | 0) + 12 >> 2] = 1;
	                            c[(c[(c[f >> 2] | 0) + 4 >> 2] | 0) + ((c[h >> 2] | 0) * 20 | 0) >> 2] = c[r >> 2];
	                            break
	                        } else {
	                            c[p >> 2] = -1;
	                            break
	                        }
	                    } while (0);
	                    c[l >> 2] = (c[l >> 2] | 0) + 1
	                }
	                c[l >> 2] = 0;
	                while (1) {
	                    if ((c[l >> 2] | 0) >>> 0 >= (c[k >> 2] | 0) >>> 0)break;
	                    c[m >> 2] = c[(c[o >> 2] | 0) + ((c[l >> 2] | 0) * 20 | 0) >> 2];
	                    while (1) {
	                        if (!(c[m >> 2] | 0))break;
	                        c[n >> 2] = c[c[m >> 2] >> 2];
	                        if (c[q >> 2] | 0)c[j >> 2] = c[(c[m >> 2] | 0) + 16 >> 2]; else {
	                            r = c[(c[m >> 2] | 0) + 4 >> 2] | 0;
	                            t = c[(c[m >> 2] | 0) + 8 >> 2] | 0;
	                            b = c[(c[f >> 2] | 0) + 24 >> 2] | 0;
	                            if ((c[(c[f >> 2] | 0) + 8 >> 2] | 0) == 128)u = EP(r, t, b) | 0; else u = FP(r, t, b) | 0;
	                            c[j >> 2] = u
	                        }
	                        c[h >> 2] = ((c[j >> 2] | 0) >>> 0) % ((c[(c[f >> 2] | 0) + 8 >> 2] | 0) >>> 0) | 0;
	                        b = (c[(c[f >> 2] | 0) + 4 >> 2] | 0) + ((c[h >> 2] | 0) * 20 | 0) | 0;
	                        if (!(c[(c[(c[f >> 2] | 0) + 4 >> 2] | 0) + ((c[h >> 2] | 0) * 20 | 0) + 12 >> 2] | 0)) {
	                            t = c[m >> 2] | 0;
	                            c[b + 0 >> 2] = c[t + 0 >> 2];
	                            c[b + 4 >> 2] = c[t + 4 >> 2];
	                            c[b + 8 >> 2] = c[t + 8 >> 2];
	                            c[b + 12 >> 2] = c[t + 12 >> 2];
	                            c[b + 16 >> 2] = c[t + 16 >> 2];
	                            c[(c[(c[f >> 2] | 0) + 4 >> 2] | 0) + ((c[h >> 2] | 0) * 20 | 0) >> 2] = 0;
	                            c[(c[(c[f >> 2] | 0) + 4 >> 2] | 0) + ((c[h >> 2] | 0) * 20 | 0) + 12 >> 2] = 1;
	                            c[(c[(c[f >> 2] | 0) + 4 >> 2] | 0) + ((c[h >> 2] | 0) * 20 | 0) + 16 >> 2] = c[j >> 2];
	                            zb[c[135736 >> 2] & 511](c[m >> 2] | 0)
	                        } else {
	                            c[c[m >> 2] >> 2] = c[b >> 2];
	                            c[(c[m >> 2] | 0) + 16 >> 2] = c[j >> 2];
	                            c[(c[(c[f >> 2] | 0) + 4 >> 2] | 0) + ((c[h >> 2] | 0) * 20 | 0) >> 2] = c[m >> 2]
	                        }
	                        c[m >> 2] = c[n >> 2]
	                    }
	                    c[l >> 2] = (c[l >> 2] | 0) + 1
	                }
	                zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                c[e >> 2] = c[p >> 2];
	                s = c[e >> 2] | 0;
	                i = d;
	                return s | 0
	            }

	            function IP(a, b, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                h = i;
	                i = i + 32 | 0;
	                j = h + 20 | 0;
	                k = h + 16 | 0;
	                l = h + 12 | 0;
	                m = h + 8 | 0;
	                n = h + 4 | 0;
	                o = h;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                c[n >> 2] = g;
	                c[o >> 2] = c[n >> 2];
	                if (!(c[k >> 2] | 0))c[o >> 2] = (c[o >> 2] | 0) + 1740; else c[o >> 2] = (c[o >> 2] | 0) + ((d[c[j >> 2] >> 0] | 0) * 30 | 0);
	                if ((c[m >> 2] | 0) > 10 ? (c[o >> 2] = (c[o >> 2] | 0) + (d[(c[l >> 2] | 0) + ((c[m >> 2] | 0) - ((c[k >> 2] | 0) + 2)) >> 0] | 0), c[m >> 2] = 10, (c[k >> 2] | 0) > 10) : 0)c[k >> 2] = 10;
	                switch (c[k >> 2] | 0) {
	                    case 9:
	                    {
	                        p = 9;
	                        break
	                    }
	                    case 10:
	                    {
	                        c[o >> 2] = (c[o >> 2] | 0) + (d[(c[j >> 2] | 0) + 9 >> 0] | 0);
	                        p = 9;
	                        break
	                    }
	                    case 5:
	                    {
	                        p = 13;
	                        break
	                    }
	                    case 1:
	                    {
	                        p = 17;
	                        break
	                    }
	                    case 2:
	                    {
	                        p = 16;
	                        break
	                    }
	                    case 8:
	                    {
	                        p = 10;
	                        break
	                    }
	                    case 4:
	                    {
	                        p = 14;
	                        break
	                    }
	                    case 3:
	                    {
	                        p = 15;
	                        break
	                    }
	                    case 7:
	                    {
	                        p = 11;
	                        break
	                    }
	                    case 6:
	                    {
	                        p = 12;
	                        break
	                    }
	                    default:
	                    {
	                    }
	                }
	                if ((p | 0) == 9) {
	                    c[o >> 2] = (c[o >> 2] | 0) + (d[(c[j >> 2] | 0) + 8 >> 0] | 0);
	                    p = 10
	                }
	                if ((p | 0) == 10) {
	                    c[o >> 2] = (c[o >> 2] | 0) + (d[(c[j >> 2] | 0) + 7 >> 0] | 0);
	                    p = 11
	                }
	                if ((p | 0) == 11) {
	                    c[o >> 2] = (c[o >> 2] | 0) + (d[(c[j >> 2] | 0) + 6 >> 0] | 0);
	                    p = 12
	                }
	                if ((p | 0) == 12) {
	                    c[o >> 2] = (c[o >> 2] | 0) + (d[(c[j >> 2] | 0) + 5 >> 0] | 0);
	                    p = 13
	                }
	                if ((p | 0) == 13) {
	                    c[o >> 2] = (c[o >> 2] | 0) + (d[(c[j >> 2] | 0) + 4 >> 0] | 0);
	                    p = 14
	                }
	                if ((p | 0) == 14) {
	                    c[o >> 2] = (c[o >> 2] | 0) + (d[(c[j >> 2] | 0) + 3 >> 0] | 0);
	                    p = 15
	                }
	                if ((p | 0) == 15) {
	                    c[o >> 2] = (c[o >> 2] | 0) + (d[(c[j >> 2] | 0) + 2 >> 0] | 0);
	                    p = 16
	                }
	                if ((p | 0) == 16) {
	                    c[o >> 2] = (c[o >> 2] | 0) + (d[(c[j >> 2] | 0) + 1 >> 0] | 0);
	                    p = 17
	                }
	                if ((p | 0) == 17)c[o >> 2] = (c[o >> 2] | 0) + (d[c[j >> 2] >> 0] | 0);
	                c[m >> 2] = (c[m >> 2] | 0) - (c[k >> 2] | 0);
	                if ((c[m >> 2] | 0) > 0) {
	                    c[o >> 2] = (c[o >> 2] | 0) + 58;
	                    c[m >> 2] = (c[m >> 2] | 0) + -1
	                }
	                switch (c[m >> 2] | 0) {
	                    case 10:
	                    {
	                        c[o >> 2] = (c[o >> 2] | 0) + (d[(c[l >> 2] | 0) + 9 >> 0] | 0);
	                        p = 22;
	                        break
	                    }
	                    case 3:
	                    {
	                        p = 28;
	                        break
	                    }
	                    case 1:
	                        break;
	                    case 9:
	                    {
	                        p = 22;
	                        break
	                    }
	                    case 5:
	                    {
	                        p = 26;
	                        break
	                    }
	                    case 8:
	                    {
	                        p = 23;
	                        break
	                    }
	                    case 6:
	                    {
	                        p = 25;
	                        break
	                    }
	                    case 7:
	                    {
	                        p = 24;
	                        break
	                    }
	                    case 2:
	                    {
	                        p = 29;
	                        break
	                    }
	                    case 4:
	                    {
	                        p = 27;
	                        break
	                    }
	                    default:
	                    {
	                        q = c[o >> 2] | 0;
	                        i = h;
	                        return q | 0
	                    }
	                }
	                if ((p | 0) == 22) {
	                    c[o >> 2] = (c[o >> 2] | 0) + (d[(c[l >> 2] | 0) + 8 >> 0] | 0);
	                    p = 23
	                }
	                if ((p | 0) == 23) {
	                    c[o >> 2] = (c[o >> 2] | 0) + (d[(c[l >> 2] | 0) + 7 >> 0] | 0);
	                    p = 24
	                }
	                if ((p | 0) == 24) {
	                    c[o >> 2] = (c[o >> 2] | 0) + (d[(c[l >> 2] | 0) + 6 >> 0] | 0);
	                    p = 25
	                }
	                if ((p | 0) == 25) {
	                    c[o >> 2] = (c[o >> 2] | 0) + (d[(c[l >> 2] | 0) + 5 >> 0] | 0);
	                    p = 26
	                }
	                if ((p | 0) == 26) {
	                    c[o >> 2] = (c[o >> 2] | 0) + (d[(c[l >> 2] | 0) + 4 >> 0] | 0);
	                    p = 27
	                }
	                if ((p | 0) == 27) {
	                    c[o >> 2] = (c[o >> 2] | 0) + (d[(c[l >> 2] | 0) + 3 >> 0] | 0);
	                    p = 28
	                }
	                if ((p | 0) == 28) {
	                    c[o >> 2] = (c[o >> 2] | 0) + (d[(c[l >> 2] | 0) + 2 >> 0] | 0);
	                    p = 29
	                }
	                if ((p | 0) == 29)c[o >> 2] = (c[o >> 2] | 0) + (d[(c[l >> 2] | 0) + 1 >> 0] | 0);
	                c[o >> 2] = (c[o >> 2] | 0) + (d[c[l >> 2] >> 0] | 0);
	                q = c[o >> 2] | 0;
	                i = h;
	                return q | 0
	            }

	            function JP(a, b, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                h = i;
	                i = i + 32 | 0;
	                j = h + 24 | 0;
	                k = h + 20 | 0;
	                l = h + 16 | 0;
	                m = h + 12 | 0;
	                n = h + 8 | 0;
	                o = h + 4 | 0;
	                p = h;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                c[n >> 2] = g;
	                c[o >> 2] = c[n >> 2];
	                c[p >> 2] = 0;
	                while (1) {
	                    if ((c[p >> 2] | 0) >= (c[k >> 2] | 0))break;
	                    c[o >> 2] = (c[o >> 2] | 0) + (d[(c[j >> 2] | 0) + (c[p >> 2] | 0) >> 0] | 0);
	                    c[o >> 2] = (c[o >> 2] | 0) + (c[o >> 2] << 10);
	                    c[o >> 2] = c[o >> 2] ^ (c[o >> 2] | 0) >>> 6;
	                    c[p >> 2] = (c[p >> 2] | 0) + 1
	                }
	                c[o >> 2] = (c[o >> 2] | 0) + 58;
	                c[o >> 2] = (c[o >> 2] | 0) + (c[o >> 2] << 10);
	                c[o >> 2] = c[o >> 2] ^ (c[o >> 2] | 0) >>> 6;
	                c[p >> 2] = 0;
	                while (1) {
	                    if ((c[p >> 2] | 0) >= (c[m >> 2] | 0))break;
	                    c[o >> 2] = (c[o >> 2] | 0) + (d[(c[l >> 2] | 0) + (c[p >> 2] | 0) >> 0] | 0);
	                    c[o >> 2] = (c[o >> 2] | 0) + (c[o >> 2] << 10);
	                    c[o >> 2] = c[o >> 2] ^ (c[o >> 2] | 0) >>> 6;
	                    c[p >> 2] = (c[p >> 2] | 0) + 1
	                }
	                c[o >> 2] = (c[o >> 2] | 0) + (c[o >> 2] << 3);
	                c[o >> 2] = c[o >> 2] ^ (c[o >> 2] | 0) >>> 11;
	                c[o >> 2] = (c[o >> 2] | 0) + (c[o >> 2] << 15);
	                i = h;
	                return c[o >> 2] | 0
	            }

	            function KP(b, d, e, f, g) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h + 36 | 0;
	                k = h + 32 | 0;
	                l = h + 28 | 0;
	                m = h + 24 | 0;
	                n = h + 20 | 0;
	                o = h + 16 | 0;
	                p = h + 12 | 0;
	                q = h + 8 | 0;
	                r = h + 4 | 0;
	                s = h;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                c[r >> 2] = 0;
	                c[s >> 2] = 0;
	                g = c[k >> 2] | 0;
	                if (!(c[l >> 2] | 0)) {
	                    c[j >> 2] = GP(g, c[n >> 2] | 0, c[o >> 2] | 0) | 0;
	                    t = c[j >> 2] | 0;
	                    i = h;
	                    return t | 0
	                }
	                c[p >> 2] = c[g + 16 >> 2];
	                while (1) {
	                    u = c[p >> 2] | 0;
	                    if (!(c[p >> 2] | 0)) {
	                        v = 9;
	                        break
	                    }
	                    if (((c[u + 8 >> 2] | 0) - (c[(c[p >> 2] | 0) + 4 >> 2] | 0) | 0) >>> 0 > ((c[o >> 2] | 0) + (c[m >> 2] | 0) + 1 | 0) >>> 0)break;
	                    if ((c[(c[p >> 2] | 0) + 12 >> 2] | 0) >>> 0 > (c[r >> 2] | 0) >>> 0)c[r >> 2] = c[(c[p >> 2] | 0) + 12 >> 2];
	                    c[s >> 2] = (c[s >> 2] | 0) + (c[(c[p >> 2] | 0) + 12 >> 2] | 0);
	                    c[p >> 2] = c[c[p >> 2] >> 2]
	                }
	                do if ((v | 0) == 9 ? (u | 0) == 0 : 0) {
	                    if ((c[(c[k >> 2] | 0) + 28 >> 2] | 0) >>> 0 > 0 ? (c[s >> 2] | 0) >>> 0 > (c[(c[k >> 2] | 0) + 28 >> 2] | 0) >>> 0 : 0) {
	                        c[j >> 2] = 0;
	                        t = c[j >> 2] | 0;
	                        i = h;
	                        return t | 0
	                    }
	                    if (!(c[r >> 2] | 0))c[r >> 2] = 1e3; else c[r >> 2] = c[r >> 2] << 2;
	                    if ((c[r >> 2] | 0) >>> 0 < (c[o >> 2] | 0) + (c[m >> 2] | 0) + 1 << 2 >>> 0)c[r >> 2] = (c[o >> 2] | 0) + (c[m >> 2] | 0) + 1 << 2;
	                    c[p >> 2] = Cb[c[135744 >> 2] & 511](24 + (c[r >> 2] | 0) | 0) | 0;
	                    if (c[p >> 2] | 0) {
	                        c[(c[p >> 2] | 0) + 12 >> 2] = c[r >> 2];
	                        c[(c[p >> 2] | 0) + 16 >> 2] = 0;
	                        c[(c[p >> 2] | 0) + 4 >> 2] = (c[p >> 2] | 0) + 20;
	                        c[(c[p >> 2] | 0) + 8 >> 2] = (c[p >> 2] | 0) + 20 + (c[r >> 2] | 0);
	                        c[c[p >> 2] >> 2] = c[(c[k >> 2] | 0) + 16 >> 2];
	                        c[(c[k >> 2] | 0) + 16 >> 2] = c[p >> 2];
	                        break
	                    }
	                    c[j >> 2] = 0;
	                    t = c[j >> 2] | 0;
	                    i = h;
	                    return t | 0
	                } while (0);
	                c[q >> 2] = c[(c[p >> 2] | 0) + 4 >> 2];
	                eU(c[(c[p >> 2] | 0) + 4 >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0) | 0;
	                l = (c[p >> 2] | 0) + 4 | 0;
	                c[l >> 2] = (c[l >> 2] | 0) + (c[m >> 2] | 0);
	                m = (c[p >> 2] | 0) + 4 | 0;
	                l = c[m >> 2] | 0;
	                c[m >> 2] = l + 1;
	                a[l >> 0] = 58;
	                eU(c[(c[p >> 2] | 0) + 4 >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0) | 0;
	                n = (c[p >> 2] | 0) + 4 | 0;
	                c[n >> 2] = (c[n >> 2] | 0) + (c[o >> 2] | 0);
	                o = (c[p >> 2] | 0) + 4 | 0;
	                n = c[o >> 2] | 0;
	                c[o >> 2] = n + 1;
	                a[n >> 0] = 0;
	                n = (c[p >> 2] | 0) + 16 | 0;
	                c[n >> 2] = (c[n >> 2] | 0) + 1;
	                c[j >> 2] = c[q >> 2];
	                t = c[j >> 2] | 0;
	                i = h;
	                return t | 0
	            }

	            function LP(a) {
	                a = a | 0;
	                var b = 0;
	                b = i;
	                i = i + 16 | 0;
	                c[b >> 2] = a;
	                i = b;
	                return 0
	            }

	            function MP(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = c[e >> 2];
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) {
	                    c[d >> 2] = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[d >> 2] = 0;
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function NP(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = c[e >> 2];
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) {
	                    c[d >> 2] = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[d >> 2] = 0;
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function OP(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = c[e >> 2];
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) {
	                    c[d >> 2] = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 32 >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[d >> 2] = 0;
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function PP(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = c[e >> 2];
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                    c[d >> 2] = (c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + 40 >> 2] | 0) == 1 & 1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[d >> 2] = 0;
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function QP(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = c[e >> 2];
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                    c[d >> 2] = (c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0) != 0 & 1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[d >> 2] = 0;
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function RP(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = c[e >> 2];
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                    c[d >> 2] = (c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + 48 >> 2] | 0) != 0 & 1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[d >> 2] = 0;
	                g = c[d >> 2] | 0;
	                i = b;
	                return g | 0
	            }

	            function SP(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[l >> 2] = c[g >> 2];
	                if (!(c[g >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                if (!(c[(c[l >> 2] | 0) + 8 >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                c[m >> 2] = Nh(c[(c[l >> 2] | 0) + 8 >> 2] | 0) | 0;
	                do if (c[m >> 2] | 0)if (c[(c[l >> 2] | 0) + 32 >> 2] | 0) {
	                    i = f;
	                    return
	                } else {
	                    Qh(c[m >> 2] | 0);
	                    Ph(c[m >> 2] | 0);
	                    c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] = 0;
	                    break
	                } while (0);
	                m = Oh(c[(c[l >> 2] | 0) + 8 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] = m;
	                if (c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0) {
	                    i = f;
	                    return
	                }
	                sQ(c[l >> 2] | 0, 197088);
	                i = f;
	                return
	            }

	            function TP(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                f = i;
	                i = i + 64 | 0;
	                g = f + 48 | 0;
	                h = f + 44 | 0;
	                j = f + 40 | 0;
	                k = f + 36 | 0;
	                l = f + 32 | 0;
	                m = f + 28 | 0;
	                n = f + 24 | 0;
	                o = f + 20 | 0;
	                p = f + 16 | 0;
	                q = f + 12 | 0;
	                r = f + 8 | 0;
	                s = f + 4 | 0;
	                t = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[l >> 2] = c[g >> 2];
	                if (!(c[g >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                if (!((c[j >> 2] | 0) != 0 | (c[k >> 2] | 0) != 0)) {
	                    i = f;
	                    return
	                }
	                if ((c[(c[l >> 2] | 0) + 104 >> 2] | 0) == 0 ? (c[(c[l >> 2] | 0) + 276 >> 2] | 0) == 0 : 0) {
	                    i = f;
	                    return
	                }
	                if (!(c[(c[l >> 2] | 0) + 12 >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                if (!(c[(c[l >> 2] | 0) + 8 >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                c[q >> 2] = 0;
	                if ((c[c[l >> 2] >> 2] | 0) != 0 ? (c[(c[c[l >> 2] >> 2] | 0) + 16 >> 2] | 0) != 0 : 0)c[q >> 2] = vb[c[(c[c[l >> 2] >> 2] | 0) + 16 >> 2] & 511](c[(c[l >> 2] | 0) + 4 >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                if (!(c[q >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                Mh(c[(c[l >> 2] | 0) + 8 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                c[m >> 2] = c[(c[l >> 2] | 0) + 36 >> 2];
	                c[n >> 2] = c[(c[l >> 2] | 0) + 40 >> 2];
	                c[o >> 2] = c[(c[l >> 2] | 0) + 44 >> 2];
	                c[p >> 2] = c[(c[l >> 2] | 0) + 48 >> 2];
	                c[s >> 2] = c[(c[l >> 2] | 0) + 256 >> 2];
	                c[t >> 2] = c[(c[l >> 2] | 0) + 24 >> 2];
	                c[(c[l >> 2] | 0) + 24 >> 2] = 0;
	                h = Cb[c[135744 >> 2] & 511](20) | 0;
	                c[(c[l >> 2] | 0) + 48 >> 2] = h;
	                h = c[l >> 2] | 0;
	                if (!(c[(c[l >> 2] | 0) + 48 >> 2] | 0)) {
	                    sQ(h, 197112);
	                    c[(c[l >> 2] | 0) + 36 >> 2] = c[m >> 2];
	                    c[(c[l >> 2] | 0) + 40 >> 2] = c[n >> 2];
	                    c[(c[l >> 2] | 0) + 44 >> 2] = c[o >> 2];
	                    c[(c[l >> 2] | 0) + 48 >> 2] = c[p >> 2];
	                    c[(c[l >> 2] | 0) + 256 >> 2] = c[s >> 2];
	                    c[(c[l >> 2] | 0) + 24 >> 2] = c[t >> 2];
	                    i = f;
	                    return
	                }
	                c[h + 40 >> 2] = 0;
	                c[(c[l >> 2] | 0) + 44 >> 2] = 5;
	                c[(c[l >> 2] | 0) + 36 >> 2] = 0;
	                Xe(c[l >> 2] | 0, c[q >> 2] | 0) | 0;
	                if ((c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 24 >> 2] | 0) >= 4) {
	                    c[r >> 2] = sd(c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0, 4) | 0;
	                    re(c[l >> 2] | 0, c[r >> 2] | 0) | 0
	                }
	                if (!(c[(c[q >> 2] | 0) + 4 >> 2] | 0)) {
	                    r = Jl(c[k >> 2] | 0) | 0;
	                    c[(c[q >> 2] | 0) + 4 >> 2] = r
	                }
	                c[(c[q >> 2] | 0) + 28 >> 2] = 1;
	                c[(c[q >> 2] | 0) + 32 >> 2] = 1;
	                c[(c[q >> 2] | 0) + 12 >> 2] = c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                c[(c[q >> 2] | 0) + 16 >> 2] = c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2];
	                c[(c[q >> 2] | 0) + 40 >> 2] = 0;
	                Cf(c[l >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0);
	                while (1) {
	                    u = c[l >> 2] | 0;
	                    if ((c[(c[l >> 2] | 0) + 40 >> 2] | 0) <= 1)break;
	                    Ve(u) | 0
	                }
	                te(c[u + 36 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[(c[l >> 2] | 0) + 48 >> 2] | 0);
	                c[(c[l >> 2] | 0) + 36 >> 2] = c[m >> 2];
	                c[(c[l >> 2] | 0) + 40 >> 2] = c[n >> 2];
	                c[(c[l >> 2] | 0) + 44 >> 2] = c[o >> 2];
	                c[(c[l >> 2] | 0) + 48 >> 2] = c[p >> 2];
	                c[(c[l >> 2] | 0) + 256 >> 2] = c[s >> 2];
	                do if (c[(c[l >> 2] | 0) + 24 >> 2] | 0) {
	                    if ((c[(c[l >> 2] | 0) + 296 >> 2] | 0) != 0 ? (CP(c[(c[l >> 2] | 0) + 296 >> 2] | 0, c[(c[l >> 2] | 0) + 24 >> 2] | 0) | 0) != 0 : 0)break;
	                    zb[c[135736 >> 2] & 511](c[(c[l >> 2] | 0) + 24 >> 2] | 0)
	                } while (0);
	                c[(c[l >> 2] | 0) + 24 >> 2] = c[t >> 2];
	                i = f;
	                return
	            }

	            function UP(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 28 | 0;
	                g = e + 24 | 0;
	                h = e + 20 | 0;
	                j = e + 16 | 0;
	                k = e + 12 | 0;
	                l = e + 8 | 0;
	                m = e + 4 | 0;
	                n = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = c[g >> 2];
	                c[n >> 2] = 0;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = e;
	                    return o | 0
	                }
	                if (c[(c[k >> 2] | 0) + 36 >> 2] | 0)c[n >> 2] = c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2];
	                if (!(c[n >> 2] | 0))c[n >> 2] = c[(c[k >> 2] | 0) + 180 >> 2];
	                c[m >> 2] = Hl(c[j >> 2] | 0, c[n >> 2] | 0) | 0;
	                c[l >> 2] = Vk(c[m >> 2] | 0, c[h >> 2] | 0, c[k >> 2] | 0) | 0;
	                if (c[m >> 2] | 0)zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                c[f >> 2] = c[l >> 2];
	                o = c[f >> 2] | 0;
	                i = e;
	                return o | 0
	            }

	            function VP(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 28 | 0;
	                f = d + 24 | 0;
	                g = d + 20 | 0;
	                h = d + 16 | 0;
	                j = d + 12 | 0;
	                k = d + 8 | 0;
	                l = d + 4 | 0;
	                m = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = c[f >> 2];
	                c[j >> 2] = 0;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                if ((c[(c[h >> 2] | 0) + 216 >> 2] | 0) == 0 ? (c[j >> 2] = Yc(c[g >> 2] | 0) | 0, (c[j >> 2] | 0) != 0) : 0) {
	                    c[e >> 2] = c[j >> 2];
	                    n = c[e >> 2] | 0;
	                    i = d;
	                    return n | 0
	                }
	                do if ((c[(c[h >> 2] | 0) + 8 >> 2] | 0) != 0 ? (c[(c[(c[h >> 2] | 0) + 8 >> 2] | 0) + 40 >> 2] | 0) == 1 : 0) {
	                    f = c[(c[h >> 2] | 0) + 8 >> 2] | 0;
	                    if ((c[(c[h >> 2] | 0) + 216 >> 2] | 0) == 2) {
	                        c[f + 40 >> 2] = 0;
	                        c[j >> 2] = ad(c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[g >> 2] | 0) | 0;
	                        c[(c[(c[h >> 2] | 0) + 8 >> 2] | 0) + 40 >> 2] = 1;
	                        break
	                    }
	                    c[j >> 2] = ad(f, c[g >> 2] | 0) | 0;
	                    if (!(c[j >> 2] | 0)) {
	                        c[(c[(c[h >> 2] | 0) + 8 >> 2] | 0) + 40 >> 2] = 0;
	                        c[j >> 2] = ad(c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[g >> 2] | 0) | 0;
	                        if (c[j >> 2] | 0)tQ(c[h >> 2] | 0, 103, 197136, c[g >> 2] | 0, 0);
	                        c[(c[(c[h >> 2] | 0) + 8 >> 2] | 0) + 40 >> 2] = 1
	                    }
	                } else o = 14; while (0);
	                if ((o | 0) == 14)c[j >> 2] = ad(c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[g >> 2] | 0) | 0;
	                do if (c[j >> 2] | 0) {
	                    if ((c[(c[h >> 2] | 0) + 104 >> 2] | 0) == 0 ? (c[(c[h >> 2] | 0) + 16 >> 2] | 0) == 0 : 0)break;
	                    if ((c[(c[j >> 2] | 0) + 12 >> 2] | 0) == 0 ? (c[(c[j >> 2] | 0) + 48 >> 2] | 0) == 2 : 0) {
	                        c[m >> 2] = c[(c[h >> 2] | 0) + 440 >> 2];
	                        c[k >> 2] = Xf(c[h >> 2] | 0, c[(c[j >> 2] | 0) + 64 >> 2] | 0, c[(c[j >> 2] | 0) + 52 >> 2] | 0, l) | 0;
	                        if (c[k >> 2] | 0) {
	                            tQ(c[h >> 2] | 0, 104, 197208, c[g >> 2] | 0, 0);
	                            c[(c[h >> 2] | 0) + 104 >> 2] = 0;
	                            c[e >> 2] = 0;
	                            n = c[e >> 2] | 0;
	                            i = d;
	                            return n | 0
	                        }
	                        yi(c[j >> 2] | 0, c[l >> 2] | 0) | 0;
	                        c[(c[j >> 2] | 0) + 68 >> 2] = 1;
	                        if (((c[(c[j >> 2] | 0) + 72 >> 2] | 0) == 0 ? (c[(c[j >> 2] | 0) + 72 >> 2] = (c[(c[h >> 2] | 0) + 440 >> 2] | 0) - (c[m >> 2] | 0) + 1 << 1, (c[(c[j >> 2] | 0) + 40 >> 2] | 0) != 0) : 0) ? (vy(c[(c[j >> 2] | 0) + 40 >> 2] | 0, 60) | 0) != 0 : 0) {
	                            o = (c[j >> 2] | 0) + 72 | 0;
	                            c[o >> 2] = c[o >> 2] | 1
	                        }
	                    }
	                } while (0);
	                c[e >> 2] = c[j >> 2];
	                n = c[e >> 2] | 0;
	                i = d;
	                return n | 0
	            }

	            function WP(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = c[f >> 2];
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                } else {
	                    c[j >> 2] = $c(c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[g >> 2] | 0) | 0;
	                    c[e >> 2] = c[j >> 2];
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                return 0
	            }

	            function XP(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                h = i;
	                i = i + 64 | 0;
	                j = h;
	                k = h + 48 | 0;
	                l = h + 44 | 0;
	                m = h + 40 | 0;
	                n = h + 36 | 0;
	                o = h + 32 | 0;
	                p = h + 28 | 0;
	                q = h + 24 | 0;
	                r = h + 20 | 0;
	                s = h + 16 | 0;
	                t = h + 12 | 0;
	                u = h + 8 | 0;
	                v = h + 4 | 0;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                c[r >> 2] = c[k >> 2];
	                if (!(c[k >> 2] | 0)) {
	                    i = h;
	                    return
	                }
	                k = c[r >> 2] | 0;
	                if ((c[(c[r >> 2] | 0) + 216 >> 2] | 0) == 1) {
	                    c[q >> 2] = _c(c[k + 8 >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0) | 0;
	                    if ((c[q >> 2] | 0) == 0 ? (c[(c[r >> 2] | 0) + 268 >> 2] | 0) != 0 : 0)uQ(c[r >> 2] | 0, 107, 197240, c[l >> 2] | 0);
	                    if (!(c[q >> 2] | 0)) {
	                        i = h;
	                        return
	                    }
	                    if (!((c[o >> 2] | 0) != 0 ? (c[(c[q >> 2] | 0) + 64 >> 2] | 0) == 0 : 0)) {
	                        i = h;
	                        return
	                    }
	                    c[t >> 2] = 0;
	                    if (c[(c[r >> 2] | 0) + 36 >> 2] | 0)c[t >> 2] = c[(c[(c[r >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2];
	                    if (!(c[t >> 2] | 0))c[t >> 2] = c[(c[r >> 2] | 0) + 180 >> 2];
	                    c[s >> 2] = Hl(c[o >> 2] | 0, c[t >> 2] | 0) | 0;
	                    c[(c[q >> 2] | 0) + 64 >> 2] = c[s >> 2];
	                    i = h;
	                    return
	                }
	                s = c[r >> 2] | 0;
	                if ((c[k + 216 >> 2] | 0) != 2) {
	                    tQ(s, 104, 197352, c[l >> 2] | 0, 0);
	                    i = h;
	                    return
	                }
	                c[q >> 2] = Zc(c[s + 8 >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0) | 0;
	                if ((((c[q >> 2] | 0) == 0 ? (c[(c[r >> 2] | 0) + 268 >> 2] | 0) != 0 : 0) ? (c[c[r >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[c[r >> 2] >> 2] | 0) + 84 >> 2] | 0) != 0 : 0) {
	                    p = c[(c[c[r >> 2] >> 2] | 0) + 84 >> 2] | 0;
	                    n = c[(c[r >> 2] | 0) + 4 >> 2] | 0;
	                    c[j >> 2] = c[l >> 2];
	                    Db[p & 511](n, 197296, j)
	                }
	                if (!(c[q >> 2] | 0)) {
	                    i = h;
	                    return
	                }
	                if (!((c[o >> 2] | 0) != 0 ? (c[(c[q >> 2] | 0) + 64 >> 2] | 0) == 0 : 0)) {
	                    i = h;
	                    return
	                }
	                c[v >> 2] = 0;
	                if (c[(c[r >> 2] | 0) + 36 >> 2] | 0)c[v >> 2] = c[(c[(c[r >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2];
	                if (!(c[v >> 2] | 0))c[v >> 2] = c[(c[r >> 2] | 0) + 180 >> 2];
	                c[u >> 2] = Hl(c[o >> 2] | 0, c[v >> 2] | 0) | 0;
	                c[(c[q >> 2] | 0) + 64 >> 2] = c[u >> 2];
	                i = h;
	                return
	            }

	            function YP(a, b, d, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                j = i;
	                i = i + 48 | 0;
	                k = j + 44 | 0;
	                l = j + 40 | 0;
	                m = j + 36 | 0;
	                n = j + 32 | 0;
	                o = j + 28 | 0;
	                p = j + 24 | 0;
	                q = j + 20 | 0;
	                r = j + 16 | 0;
	                s = j + 12 | 0;
	                t = j + 8 | 0;
	                u = j + 4 | 0;
	                v = j;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                c[q >> 2] = h;
	                c[r >> 2] = c[k >> 2];
	                c[t >> 2] = 0;
	                c[u >> 2] = 0;
	                if (!(c[r >> 2] | 0)) {
	                    i = j;
	                    return
	                }
	                if (!(c[(c[r >> 2] | 0) + 8 >> 2] | 0)) {
	                    i = j;
	                    return
	                }
	                k = (qy(c[m >> 2] | 0, 197408) | 0) != 0;
	                if (k & (c[n >> 2] | 0) != 2) {
	                    c[v >> 2] = c[(c[r >> 2] | 0) + 100 >> 2];
	                    vQ(c[r >> 2] | 0, 540, 197416, 0, 0);
	                    c[(c[r >> 2] | 0) + 100 >> 2] = c[v >> 2]
	                }
	                c[t >> 2] = bf(c[r >> 2] | 0, c[m >> 2] | 0, u) | 0;
	                c[(c[r >> 2] | 0) + 144 >> 2] = 1;
	                m = c[r >> 2] | 0;
	                do if ((c[(c[r >> 2] | 0) + 216 >> 2] | 0) == 1)c[s >> 2] = tm(m + 108 | 0, c[(c[(c[r >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0, c[l >> 2] | 0, c[t >> 2] | 0, c[u >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0) | 0; else {
	                    v = c[r >> 2] | 0;
	                    if ((c[m + 216 >> 2] | 0) == 2) {
	                        c[s >> 2] = tm(v + 108 | 0, c[(c[(c[r >> 2] | 0) + 8 >> 2] | 0) + 48 >> 2] | 0, c[l >> 2] | 0, c[t >> 2] | 0, c[u >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0) | 0;
	                        break
	                    }
	                    tQ(v, 1, 197456, c[t >> 2] | 0, 0);
	                    rm(c[q >> 2] | 0);
	                    i = j;
	                    return
	                } while (0);
	                if (!(c[(c[r >> 2] | 0) + 144 >> 2] | 0))c[(c[r >> 2] | 0) + 100 >> 2] = 0;
	                if ((((c[s >> 2] | 0) != 0 ? (c[(c[r >> 2] | 0) + 104 >> 2] | 0) != 0 : 0) ? (c[(c[r >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[(c[(c[r >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0) != 0 : 0) {
	                    q = Um((c[r >> 2] | 0) + 108 | 0, c[(c[r >> 2] | 0) + 8 >> 2] | 0, c[s >> 2] | 0) | 0;
	                    s = (c[r >> 2] | 0) + 100 | 0;
	                    c[s >> 2] = c[s >> 2] & q
	                }
	                if (c[u >> 2] | 0)zb[c[135736 >> 2] & 511](c[u >> 2] | 0);
	                if (!(c[t >> 2] | 0)) {
	                    i = j;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[t >> 2] | 0);
	                i = j;
	                return
	            }

	            function ZP(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[l >> 2] = c[g >> 2];
	                c[m >> 2] = 0;
	                if (!(c[l >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                if (!(c[(c[l >> 2] | 0) + 8 >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                g = c[l >> 2] | 0;
	                do if ((c[(c[l >> 2] | 0) + 216 >> 2] | 0) == 1)c[m >> 2] = mm(g + 108 | 0, c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0; else {
	                    e = c[l >> 2] | 0;
	                    if ((c[g + 216 >> 2] | 0) == 2) {
	                        c[m >> 2] = mm(e + 108 | 0, c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 48 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                        break
	                    }
	                    tQ(e, 1, 197520, c[h >> 2] | 0, 0);
	                    i = f;
	                    return
	                } while (0);
	                if (!(c[m >> 2] | 0))c[(c[l >> 2] | 0) + 100 >> 2] = 0;
	                if (!(c[(c[l >> 2] | 0) + 104 >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                if (!(c[(c[l >> 2] | 0) + 12 >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                if (!(c[(c[l >> 2] | 0) + 8 >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                if (!(c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                h = Vm((c[l >> 2] | 0) + 108 | 0, c[(c[l >> 2] | 0) + 8 >> 2] | 0, c[m >> 2] | 0) | 0;
	                m = (c[l >> 2] | 0) + 100 | 0;
	                c[m >> 2] = c[m >> 2] & h;
	                i = f;
	                return
	            }

	            function _P(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[l >> 2] = c[g >> 2];
	                c[m >> 2] = 0;
	                if (!(c[l >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                if (!(c[(c[l >> 2] | 0) + 8 >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                g = c[l >> 2] | 0;
	                if ((c[j >> 2] | 0) == 0 & (c[k >> 2] | 0) == 0) {
	                    tQ(g, 105, 197576, c[h >> 2] | 0, 0);
	                    i = f;
	                    return
	                }
	                e = c[l >> 2] | 0;
	                do if ((c[g + 216 >> 2] | 0) == 1)c[m >> 2] = xm(e + 108 | 0, c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0; else {
	                    d = c[l >> 2] | 0;
	                    if ((c[e + 216 >> 2] | 0) == 2) {
	                        c[m >> 2] = xm(d + 108 | 0, c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 48 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                        break
	                    }
	                    tQ(d, 105, 197640, c[h >> 2] | 0, 0);
	                    i = f;
	                    return
	                } while (0);
	                if (!(c[m >> 2] | 0))c[(c[l >> 2] | 0) + 100 >> 2] = 0;
	                if (!(c[(c[l >> 2] | 0) + 104 >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                if (!(c[(c[l >> 2] | 0) + 12 >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                if (!(c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                h = Rm((c[l >> 2] | 0) + 108 | 0, c[(c[l >> 2] | 0) + 8 >> 2] | 0, c[m >> 2] | 0) | 0;
	                m = (c[l >> 2] | 0) + 100 | 0;
	                c[m >> 2] = c[m >> 2] & h;
	                i = f;
	                return
	            }

	            function $P(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                g = i;
	                i = i + 48 | 0;
	                h = g;
	                j = g + 44 | 0;
	                k = g + 40 | 0;
	                l = g + 36 | 0;
	                m = g + 32 | 0;
	                n = g + 28 | 0;
	                o = g + 24 | 0;
	                p = g + 20 | 0;
	                q = g + 16 | 0;
	                r = g + 12 | 0;
	                s = g + 8 | 0;
	                t = g + 4 | 0;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[p >> 2] = c[j >> 2];
	                if (!(c[j >> 2] | 0)) {
	                    i = g;
	                    return
	                }
	                j = c[p >> 2] | 0;
	                if ((c[(c[p >> 2] | 0) + 216 >> 2] | 0) == 1) {
	                    c[o >> 2] = _c(c[j + 8 >> 2] | 0, c[k >> 2] | 0, 3, c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0) | 0;
	                    if ((((c[o >> 2] | 0) == 0 ? (c[(c[p >> 2] | 0) + 268 >> 2] | 0) != 0 : 0) ? (c[c[p >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[c[p >> 2] >> 2] | 0) + 84 >> 2] | 0) != 0 : 0) {
	                        f = c[(c[c[p >> 2] >> 2] | 0) + 84 >> 2] | 0;
	                        e = c[(c[p >> 2] | 0) + 4 >> 2] | 0;
	                        c[h >> 2] = c[k >> 2];
	                        Db[f & 511](e, 197240, h)
	                    }
	                    if (!(c[o >> 2] | 0)) {
	                        i = g;
	                        return
	                    }
	                    if (!((c[m >> 2] | 0) != 0 ? (c[(c[o >> 2] | 0) + 64 >> 2] | 0) == 0 : 0)) {
	                        i = g;
	                        return
	                    }
	                    c[r >> 2] = 0;
	                    if (c[(c[p >> 2] | 0) + 36 >> 2] | 0)c[r >> 2] = c[(c[(c[p >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2];
	                    if (!(c[r >> 2] | 0))c[r >> 2] = c[(c[p >> 2] | 0) + 180 >> 2];
	                    c[q >> 2] = Hl(c[m >> 2] | 0, c[r >> 2] | 0) | 0;
	                    c[(c[o >> 2] | 0) + 64 >> 2] = c[q >> 2];
	                    i = g;
	                    return
	                }
	                q = c[p >> 2] | 0;
	                if ((c[j + 216 >> 2] | 0) != 2) {
	                    tQ(q, 1, 197696, c[k >> 2] | 0, 0);
	                    i = g;
	                    return
	                }
	                c[o >> 2] = Zc(c[q + 8 >> 2] | 0, c[k >> 2] | 0, 3, c[l >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0) | 0;
	                if ((((c[o >> 2] | 0) == 0 ? (c[(c[p >> 2] | 0) + 268 >> 2] | 0) != 0 : 0) ? (c[c[p >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[c[p >> 2] >> 2] | 0) + 84 >> 2] | 0) != 0 : 0) {
	                    n = c[(c[c[p >> 2] >> 2] | 0) + 84 >> 2] | 0;
	                    l = c[(c[p >> 2] | 0) + 4 >> 2] | 0;
	                    c[h >> 2] = c[k >> 2];
	                    Db[n & 511](l, 197296, h)
	                }
	                if (!(c[o >> 2] | 0)) {
	                    i = g;
	                    return
	                }
	                if (!((c[m >> 2] | 0) != 0 ? (c[(c[o >> 2] | 0) + 64 >> 2] | 0) == 0 : 0)) {
	                    i = g;
	                    return
	                }
	                c[t >> 2] = 0;
	                if (c[(c[p >> 2] | 0) + 36 >> 2] | 0)c[t >> 2] = c[(c[(c[p >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2];
	                if (!(c[t >> 2] | 0))c[t >> 2] = c[(c[p >> 2] | 0) + 180 >> 2];
	                c[s >> 2] = Hl(c[m >> 2] | 0, c[t >> 2] | 0) | 0;
	                c[(c[o >> 2] | 0) + 64 >> 2] = c[s >> 2];
	                i = g;
	                return
	            }

	            function aQ(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0;
	                d = i;
	                i = i + 16 | 0;
	                c[d + 4 >> 2] = a;
	                c[d >> 2] = b;
	                i = d;
	                return
	            }

	            function bQ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[d >> 2] = a;
	                c[e >> 2] = c[d >> 2];
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                d = c[e >> 2] | 0;
	                do if (!(c[(c[e >> 2] | 0) + 32 >> 2] | 0)) {
	                    a = Sh(c[d + 20 >> 2] | 0) | 0;
	                    c[(c[e >> 2] | 0) + 8 >> 2] = a;
	                    c[f >> 2] = a;
	                    if (!(c[f >> 2] | 0)) {
	                        sQ(c[e >> 2] | 0, 197760);
	                        i = b;
	                        return
	                    }
	                    c[(c[f >> 2] | 0) + 92 >> 2] = 0;
	                    if (c[(c[e >> 2] | 0) + 360 >> 2] & 131072) {
	                        a = (c[f >> 2] | 0) + 92 | 0;
	                        c[a >> 2] = c[a >> 2] | 4
	                    }
	                    c[(c[f >> 2] | 0) + 88 >> 2] = c[(c[e >> 2] | 0) + 360 >> 2];
	                    if (c[(c[e >> 2] | 0) + 24 >> 2] | 0) {
	                        a = my(c[(c[e >> 2] | 0) + 24 >> 2] | 0) | 0;
	                        c[(c[f >> 2] | 0) + 60 >> 2] = a
	                    } else c[(c[f >> 2] | 0) + 60 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 40 >> 2] = c[(c[e >> 2] | 0) + 28 >> 2];
	                    if ((c[f >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 364 >> 2] | 0) != 0 : 0) {
	                        c[(c[f >> 2] | 0) + 80 >> 2] = c[(c[e >> 2] | 0) + 296 >> 2];
	                        yP(c[(c[f >> 2] | 0) + 80 >> 2] | 0) | 0
	                    }
	                } else {
	                    if (!(c[d + 8 >> 2] | 0)) {
	                        a = go(0, 0) | 0;
	                        c[(c[e >> 2] | 0) + 8 >> 2] = a
	                    }
	                    a = c[e >> 2] | 0;
	                    if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                        c[(c[a + 8 >> 2] | 0) + 92 >> 2] = 128;
	                        c[(c[(c[e >> 2] | 0) + 8 >> 2] | 0) + 88 >> 2] = c[(c[e >> 2] | 0) + 360 >> 2];
	                        break
	                    }
	                    sQ(a, 197760);
	                    i = b;
	                    return
	                } while (0);
	                if (!(c[(c[e >> 2] | 0) + 8 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[(c[e >> 2] | 0) + 8 >> 2] | 0) + 72 >> 2] | 0) {
	                    i = b;
	                    return
	                }
	                if (!(c[(c[e >> 2] | 0) + 36 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (!(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                d = Kl(c[(c[(c[e >> 2] | 0) + 36 >> 2] | 0) + 4 >> 2] | 0) | 0;
	                c[(c[(c[e >> 2] | 0) + 8 >> 2] | 0) + 72 >> 2] = d;
	                if (c[(c[(c[e >> 2] | 0) + 8 >> 2] | 0) + 72 >> 2] | 0) {
	                    i = b;
	                    return
	                }
	                sQ(c[e >> 2] | 0, 197760);
	                i = b;
	                return
	            }

	            function cQ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                c[e >> 2] = c[d >> 2];
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if ((((c[(c[e >> 2] | 0) + 104 >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[(c[e >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (c[(c[(c[e >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0) != 0 : 0) {
	                    d = cn((c[e >> 2] | 0) + 108 | 0, c[(c[e >> 2] | 0) + 8 >> 2] | 0) | 0;
	                    a = (c[e >> 2] | 0) + 100 | 0;
	                    c[a >> 2] = c[a >> 2] & d
	                }
	                if (((c[(c[e >> 2] | 0) + 24 >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (c[(c[(c[e >> 2] | 0) + 8 >> 2] | 0) + 60 >> 2] | 0) == 0 : 0) {
	                    c[(c[(c[e >> 2] | 0) + 8 >> 2] | 0) + 60 >> 2] = c[(c[e >> 2] | 0) + 24 >> 2];
	                    c[(c[e >> 2] | 0) + 24 >> 2] = 0
	                }
	                if ((((((c[(c[e >> 2] | 0) + 48 >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 40 >> 2] | 0) > 0 : 0) ? (c[c[(c[e >> 2] | 0) + 48 >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[c[(c[e >> 2] | 0) + 48 >> 2] >> 2] | 0) + 44 >> 2] | 0) != 0 : 0) ? (c[(c[e >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (c[(c[(c[e >> 2] | 0) + 8 >> 2] | 0) + 60 >> 2] | 0) == 0 : 0) {
	                    d = my(c[(c[c[(c[e >> 2] | 0) + 48 >> 2] >> 2] | 0) + 44 >> 2] | 0) | 0;
	                    c[(c[(c[e >> 2] | 0) + 8 >> 2] | 0) + 60 >> 2] = d
	                }
	                if (!(c[(c[e >> 2] | 0) + 256 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (!(c[(c[e >> 2] | 0) + 8 >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[(c[e >> 2] | 0) + 8 >> 2] | 0) + 76 >> 2] | 0) {
	                    i = b;
	                    return
	                }
	                c[(c[(c[e >> 2] | 0) + 8 >> 2] | 0) + 76 >> 2] = c[(c[e >> 2] | 0) + 256 >> 2];
	                i = b;
	                return
	            }

	            function dQ(a, e, f) {
	                a = a | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                g = i;
	                i = i + 64 | 0;
	                h = g + 48 | 0;
	                j = g + 44 | 0;
	                k = g + 40 | 0;
	                l = g + 36 | 0;
	                m = g + 32 | 0;
	                n = g + 28 | 0;
	                o = g + 24 | 0;
	                p = g + 20 | 0;
	                q = g + 16 | 0;
	                r = g + 12 | 0;
	                s = g + 8 | 0;
	                t = g + 4 | 0;
	                u = g;
	                c[h >> 2] = a;
	                c[j >> 2] = e;
	                c[k >> 2] = f;
	                c[l >> 2] = c[h >> 2];
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    i = g;
	                    return
	                }
	                if (!(c[(c[l >> 2] | 0) + 8 >> 2] | 0)) {
	                    i = g;
	                    return
	                }
	                c[n >> 2] = c[(c[l >> 2] | 0) + 52 >> 2];
	                do if ((c[(c[l >> 2] | 0) + 104 >> 2] | 0) != 0 ? (c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 48 >> 2] | 0) == 0 : 0) {
	                    if (c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0) {
	                        if (c[(c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0) + 36 >> 2] | 0)break;
	                        if (c[(c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0) + 40 >> 2] | 0)break;
	                        if (c[(c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0) + 44 >> 2] | 0)break;
	                        if (c[(c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0) + 48 >> 2] | 0)break
	                    }
	                    vQ(c[l >> 2] | 0, 94, 197784, 0, 0);
	                    c[(c[l >> 2] | 0) + 104 >> 2] = 0
	                } while (0);
	                c[p >> 2] = bf(c[l >> 2] | 0, c[j >> 2] | 0, q) | 0;
	                c[m >> 2] = ki(c[(c[l >> 2] | 0) + 8 >> 2] | 0, 0, c[p >> 2] | 0, 0) | 0;
	                if (!(c[m >> 2] | 0)) {
	                    if (c[q >> 2] | 0)zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                    sQ(c[l >> 2] | 0, 197824);
	                    i = g;
	                    return
	                }
	                if (c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 12 >> 2] | 0) {
	                    if (!(c[n >> 2] | 0))c[n >> 2] = c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 12 >> 2]
	                } else zi(c[(c[l >> 2] | 0) + 8 >> 2] | 0, c[m >> 2] | 0) | 0;
	                c[(c[l >> 2] | 0) + 264 >> 2] = -1;
	                do if ((c[(c[l >> 2] | 0) + 280 >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 36 >> 2] | 0) != 0 : 0)if ((c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2] | 0) < 65535) {
	                    b[(c[m >> 2] | 0) + 56 >> 1] = c[(c[(c[l >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2];
	                    break
	                } else {
	                    b[(c[m >> 2] | 0) + 56 >> 1] = -1;
	                    break
	                } while (0);
	                Qe(c[l >> 2] | 0, c[m >> 2] | 0) | 0;
	                do if (c[n >> 2] | 0) {
	                    j = c[n >> 2] | 0;
	                    h = c[m >> 2] | 0;
	                    if ((c[(c[n >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                        zi(j, h) | 0;
	                        break
	                    } else {
	                        xi(j, h) | 0;
	                        break
	                    }
	                } while (0);
	                do if (!(c[(c[l >> 2] | 0) + 32 >> 2] | 0)) {
	                    if ((c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0) == 0 ? (c[(c[(c[l >> 2] | 0) + 8 >> 2] | 0) + 48 >> 2] | 0) == 0 : 0)break;
	                    wQ(c[l >> 2] | 0, c[p >> 2] | 0, c[q >> 2] | 0, c[k >> 2] | 0)
	                } while (0);
	                if ((c[k >> 2] | 0) != 0 ? (c[t >> 2] = 0, p = c[t >> 2] | 0, c[t >> 2] = p + 1, c[r >> 2] = c[(c[k >> 2] | 0) + (p << 2) >> 2], p = c[t >> 2] | 0, c[t >> 2] = p + 1, c[s >> 2] = c[(c[k >> 2] | 0) + (p << 2) >> 2], ((c[r >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 32 >> 2] | 0) == 0 : 0) & (c[s >> 2] | 0) != 0) : 0)do {
	                    if (((((d[c[r >> 2] >> 0] | 0 | 0) == 120 ? (d[(c[r >> 2] | 0) + 1 >> 0] | 0 | 0) == 109 : 0) ? (d[(c[r >> 2] | 0) + 2 >> 0] | 0 | 0) == 108 : 0) ? (d[(c[r >> 2] | 0) + 3 >> 0] | 0 | 0) == 110 : 0) ? (d[(c[r >> 2] | 0) + 4 >> 0] | 0 | 0) == 115 : 0)xQ(c[l >> 2] | 0, c[r >> 2] | 0, c[s >> 2] | 0, c[q >> 2] | 0);
	                    p = c[t >> 2] | 0;
	                    c[t >> 2] = p + 1;
	                    c[r >> 2] = c[(c[k >> 2] | 0) + (p << 2) >> 2];
	                    p = c[t >> 2] | 0;
	                    c[t >> 2] = p + 1;
	                    c[s >> 2] = c[(c[k >> 2] | 0) + (p << 2) >> 2]
	                } while ((c[r >> 2] | 0) != 0 & (c[s >> 2] | 0) != 0);
	                c[o >> 2] = cj(c[(c[l >> 2] | 0) + 8 >> 2] | 0, c[m >> 2] | 0, c[q >> 2] | 0) | 0;
	                if ((c[o >> 2] | 0) == 0 & (c[n >> 2] | 0) != 0)c[o >> 2] = cj(c[(c[l >> 2] | 0) + 8 >> 2] | 0, c[n >> 2] | 0, c[q >> 2] | 0) | 0;
	                if ((c[q >> 2] | 0) != 0 & (c[o >> 2] | 0) == 0) {
	                    c[o >> 2] = Ih(c[m >> 2] | 0, 0, c[q >> 2] | 0) | 0;
	                    yQ(c[l >> 2] | 0, 201, 197848, c[q >> 2] | 0, 0)
	                }
	                do if ((c[o >> 2] | 0) != 0 ? (c[(c[o >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                    if ((d[c[(c[o >> 2] | 0) + 8 >> 2] >> 0] | 0 | 0) == 0 ? (c[(c[o >> 2] | 0) + 12 >> 2] | 0) == 0 : 0)break;
	                    Kh(c[m >> 2] | 0, c[o >> 2] | 0)
	                } while (0);
	                a:do if (c[k >> 2] | 0) {
	                    c[t >> 2] = 0;
	                    o = c[t >> 2] | 0;
	                    c[t >> 2] = o + 1;
	                    c[r >> 2] = c[(c[k >> 2] | 0) + (o << 2) >> 2];
	                    o = c[t >> 2] | 0;
	                    c[t >> 2] = o + 1;
	                    c[s >> 2] = c[(c[k >> 2] | 0) + (o << 2) >> 2];
	                    if (c[(c[l >> 2] | 0) + 32 >> 2] | 0)while (1) {
	                        if (!(c[r >> 2] | 0))break a;
	                        xQ(c[l >> 2] | 0, c[r >> 2] | 0, c[s >> 2] | 0, 0);
	                        o = c[t >> 2] | 0;
	                        c[t >> 2] = o + 1;
	                        c[r >> 2] = c[(c[k >> 2] | 0) + (o << 2) >> 2];
	                        o = c[t >> 2] | 0;
	                        c[t >> 2] = o + 1;
	                        c[s >> 2] = c[(c[k >> 2] | 0) + (o << 2) >> 2]
	                    }
	                    while (1) {
	                        if (!((c[r >> 2] | 0) != 0 & (c[s >> 2] | 0) != 0))break a;
	                        do if ((d[c[r >> 2] >> 0] | 0 | 0) == 120 ? (d[(c[r >> 2] | 0) + 1 >> 0] | 0 | 0) == 109 : 0) {
	                            if ((d[(c[r >> 2] | 0) + 2 >> 0] | 0 | 0) != 108) {
	                                v = 60;
	                                break
	                            }
	                            if ((d[(c[r >> 2] | 0) + 3 >> 0] | 0 | 0) != 110) {
	                                v = 60;
	                                break
	                            }
	                            if ((d[(c[r >> 2] | 0) + 4 >> 0] | 0 | 0) != 115)v = 60
	                        } else v = 60; while (0);
	                        if ((v | 0) == 60) {
	                            v = 0;
	                            xQ(c[l >> 2] | 0, c[r >> 2] | 0, c[s >> 2] | 0, 0)
	                        }
	                        o = c[t >> 2] | 0;
	                        c[t >> 2] = o + 1;
	                        c[r >> 2] = c[(c[k >> 2] | 0) + (o << 2) >> 2];
	                        o = c[t >> 2] | 0;
	                        c[t >> 2] = o + 1;
	                        c[s >> 2] = c[(c[k >> 2] | 0) + (o << 2) >> 2]
	                    }
	                } while (0);
	                if ((c[(c[l >> 2] | 0) + 104 >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 136 >> 2] | 0) == -1412623820 : 0) {
	                    c[u >> 2] = en((c[l >> 2] | 0) + 108 | 0, c[(c[l >> 2] | 0) + 8 >> 2] | 0) | 0;
	                    if ((c[u >> 2] | 0) <= 0)c[(c[l >> 2] | 0) + 100 >> 2] = 0;
	                    if ((c[u >> 2] | 0) < 0)c[(c[l >> 2] | 0) + 12 >> 2] = 0;
	                    u = an((c[l >> 2] | 0) + 108 | 0, c[(c[l >> 2] | 0) + 8 >> 2] | 0) | 0;
	                    k = (c[l >> 2] | 0) + 100 | 0;
	                    c[k >> 2] = c[k >> 2] & u;
	                    c[(c[l >> 2] | 0) + 136 >> 2] = -1412623819
	                }
	                if (!(c[q >> 2] | 0)) {
	                    i = g;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                i = g;
	                return
	            }

	            function eQ(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[d + 8 >> 2] = b;
	                c[f >> 2] = c[e >> 2];
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                c[g >> 2] = c[(c[f >> 2] | 0) + 52 >> 2];
	                if ((c[g >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 68 >> 2] | 0) != 0 : 0) {
	                    c[(c[(c[f >> 2] | 0) + 448 >> 2] | 0) + 12 >> 2] = (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0);
	                    c[(c[(c[f >> 2] | 0) + 448 >> 2] | 0) + 16 >> 2] = c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2];
	                    c[c[(c[f >> 2] | 0) + 448 >> 2] >> 2] = c[g >> 2];
	                    De(c[f >> 2] | 0, c[(c[f >> 2] | 0) + 448 >> 2] | 0)
	                }
	                c[(c[f >> 2] | 0) + 264 >> 2] = -1;
	                if ((((c[(c[f >> 2] | 0) + 104 >> 2] | 0) != 0 ? (c[(c[f >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[(c[f >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (c[(c[(c[f >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0) != 0 : 0) {
	                    e = $m((c[f >> 2] | 0) + 108 | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0, c[g >> 2] | 0) | 0;
	                    g = (c[f >> 2] | 0) + 100 | 0;
	                    c[g >> 2] = c[g >> 2] & e
	                }
	                Re(c[f >> 2] | 0) | 0;
	                i = d;
	                return
	            }

	            function fQ(a, d, e, f, g, h, j, k, l) {
	                a = a | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                k = k | 0;
	                l = l | 0;
	                var m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0, J = 0;
	                m = i;
	                i = i + 96 | 0;
	                n = m + 84 | 0;
	                o = m + 80 | 0;
	                p = m + 76 | 0;
	                q = m + 72 | 0;
	                r = m + 68 | 0;
	                s = m + 64 | 0;
	                t = m + 60 | 0;
	                u = m + 56 | 0;
	                v = m + 52 | 0;
	                w = m + 48 | 0;
	                x = m + 44 | 0;
	                y = m + 40 | 0;
	                z = m + 36 | 0;
	                A = m + 32 | 0;
	                B = m + 28 | 0;
	                C = m + 24 | 0;
	                D = m + 20 | 0;
	                E = m + 16 | 0;
	                F = m + 12 | 0;
	                G = m + 8 | 0;
	                H = m + 4 | 0;
	                I = m;
	                c[n >> 2] = a;
	                c[o >> 2] = d;
	                c[p >> 2] = e;
	                c[q >> 2] = f;
	                c[r >> 2] = g;
	                c[s >> 2] = h;
	                c[t >> 2] = j;
	                c[u >> 2] = k;
	                c[v >> 2] = l;
	                c[w >> 2] = c[n >> 2];
	                c[z >> 2] = 0;
	                c[D >> 2] = 0;
	                if (!(c[n >> 2] | 0)) {
	                    i = m;
	                    return
	                }
	                c[y >> 2] = c[(c[w >> 2] | 0) + 52 >> 2];
	                do if ((c[(c[w >> 2] | 0) + 104 >> 2] | 0) != 0 ? (c[(c[(c[w >> 2] | 0) + 8 >> 2] | 0) + 48 >> 2] | 0) == 0 : 0) {
	                    if (c[(c[(c[w >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0) {
	                        if (c[(c[(c[(c[w >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0) + 36 >> 2] | 0)break;
	                        if (c[(c[(c[(c[w >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0) + 40 >> 2] | 0)break;
	                        if (c[(c[(c[(c[w >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0) + 44 >> 2] | 0)break;
	                        if (c[(c[(c[(c[w >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0) + 48 >> 2] | 0)break
	                    }
	                    vQ(c[w >> 2] | 0, 522, 197784, 0, 0);
	                    c[(c[w >> 2] | 0) + 104 >> 2] = 0
	                } while (0);
	                do if ((c[p >> 2] | 0) != 0 & (c[q >> 2] | 0) == 0) {
	                    if (!(c[(c[w >> 2] | 0) + 364 >> 2] | 0)) {
	                        c[D >> 2] = Bh(c[o >> 2] | 0, c[p >> 2] | 0, 0, 0) | 0;
	                        break
	                    }
	                    c[G >> 2] = BP(c[(c[w >> 2] | 0) + 296 >> 2] | 0, c[p >> 2] | 0, c[o >> 2] | 0) | 0;
	                    if (c[G >> 2] | 0)c[o >> 2] = c[G >> 2]
	                } while (0);
	                G = c[w >> 2] | 0;
	                if (c[(c[w >> 2] | 0) + 372 >> 2] | 0) {
	                    c[x >> 2] = c[G + 372 >> 2];
	                    c[(c[w >> 2] | 0) + 372 >> 2] = c[(c[x >> 2] | 0) + 24 >> 2];
	                    n = (c[w >> 2] | 0) + 368 | 0;
	                    c[n >> 2] = (c[n >> 2] | 0) + -1;
	                    n = (c[x >> 2] | 0) + 0 | 0;
	                    l = n + 60 | 0;
	                    do {
	                        c[n >> 2] = 0;
	                        n = n + 4 | 0
	                    } while ((n | 0) < (l | 0));
	                    c[(c[x >> 2] | 0) + 4 >> 2] = 1;
	                    if (!(c[(c[w >> 2] | 0) + 364 >> 2] | 0)) {
	                        if (!(c[D >> 2] | 0)) {
	                            n = my(c[o >> 2] | 0) | 0;
	                            c[(c[x >> 2] | 0) + 8 >> 2] = n
	                        } else c[(c[x >> 2] | 0) + 8 >> 2] = c[D >> 2];
	                        if (!(c[(c[x >> 2] | 0) + 8 >> 2] | 0)) {
	                            sQ(c[w >> 2] | 0, 197888);
	                            i = m;
	                            return
	                        }
	                    } else c[(c[x >> 2] | 0) + 8 >> 2] = c[o >> 2];
	                    if ((c[18774] | 0) != 0 & (c[33968] | 0) != 0)zb[c[135872 >> 2] & 511](c[x >> 2] | 0)
	                } else {
	                    do if (!(c[G + 364 >> 2] | 0)) {
	                        n = c[(c[w >> 2] | 0) + 8 >> 2] | 0;
	                        if (!(c[D >> 2] | 0)) {
	                            c[x >> 2] = ji(n, 0, c[o >> 2] | 0, 0) | 0;
	                            break
	                        } else {
	                            c[x >> 2] = ki(n, 0, c[D >> 2] | 0, 0) | 0;
	                            break
	                        }
	                    } else c[x >> 2] = ki(c[(c[w >> 2] | 0) + 8 >> 2] | 0, 0, c[o >> 2] | 0, 0) | 0; while (0);
	                    if (!(c[x >> 2] | 0)) {
	                        sQ(c[w >> 2] | 0, 197888);
	                        i = m;
	                        return
	                    }
	                }
	                do if ((c[(c[w >> 2] | 0) + 280 >> 2] | 0) != 0 ? (c[(c[w >> 2] | 0) + 36 >> 2] | 0) != 0 : 0)if ((c[(c[(c[w >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2] | 0) < 65535) {
	                    b[(c[x >> 2] | 0) + 56 >> 1] = c[(c[(c[w >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2];
	                    break
	                } else {
	                    b[(c[x >> 2] | 0) + 56 >> 1] = -1;
	                    break
	                } while (0);
	                if (!(c[y >> 2] | 0))zi(c[(c[w >> 2] | 0) + 8 >> 2] | 0, c[x >> 2] | 0) | 0;
	                c[E >> 2] = 0;
	                c[F >> 2] = 0;
	                while (1) {
	                    if ((c[F >> 2] | 0) >= (c[r >> 2] | 0))break;
	                    o = c[E >> 2] | 0;
	                    c[E >> 2] = o + 1;
	                    c[C >> 2] = c[(c[s >> 2] | 0) + (o << 2) >> 2];
	                    o = c[E >> 2] | 0;
	                    c[E >> 2] = o + 1;
	                    c[B >> 2] = c[(c[s >> 2] | 0) + (o << 2) >> 2];
	                    c[A >> 2] = Ih(0, c[B >> 2] | 0, c[C >> 2] | 0) | 0;
	                    if (c[A >> 2] | 0) {
	                        o = c[A >> 2] | 0;
	                        if (!(c[z >> 2] | 0)) {
	                            c[z >> 2] = o;
	                            c[(c[x >> 2] | 0) + 48 >> 2] = o
	                        } else {
	                            c[c[z >> 2] >> 2] = o;
	                            c[z >> 2] = c[A >> 2]
	                        }
	                        if ((c[q >> 2] | 0) != 0 ? (c[p >> 2] | 0) == (c[C >> 2] | 0) : 0)c[(c[x >> 2] | 0) + 36 >> 2] = c[A >> 2];
	                        if (((((c[(c[w >> 2] | 0) + 32 >> 2] | 0) == 0 ? (c[(c[w >> 2] | 0) + 104 >> 2] | 0) != 0 : 0) ? (c[(c[w >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[(c[w >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (c[(c[(c[w >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0) != 0 : 0) {
	                            o = Xm((c[w >> 2] | 0) + 108 | 0, c[(c[w >> 2] | 0) + 8 >> 2] | 0, c[x >> 2] | 0, c[p >> 2] | 0, c[A >> 2] | 0, c[B >> 2] | 0) | 0;
	                            G = (c[w >> 2] | 0) + 100 | 0;
	                            c[G >> 2] = c[G >> 2] & o
	                        }
	                    }
	                    c[F >> 2] = (c[F >> 2] | 0) + 1
	                }
	                c[(c[w >> 2] | 0) + 264 >> 2] = -1;
	                Qe(c[w >> 2] | 0, c[x >> 2] | 0) | 0;
	                do if (c[y >> 2] | 0) {
	                    B = c[y >> 2] | 0;
	                    C = c[x >> 2] | 0;
	                    if ((c[(c[y >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                        zi(B, C) | 0;
	                        break
	                    } else {
	                        xi(B, C) | 0;
	                        break
	                    }
	                } while (0);
	                if ((c[u >> 2] | 0) != 0 ? (c[(c[w >> 2] | 0) + 276 >> 2] & 4 | 0) == 0 : 0)c[t >> 2] = (c[t >> 2] | 0) - (c[u >> 2] | 0);
	                do if ((c[q >> 2] | 0) != 0 ? (c[(c[x >> 2] | 0) + 36 >> 2] | 0) == 0 : 0) {
	                    u = cj(c[(c[w >> 2] | 0) + 8 >> 2] | 0, c[y >> 2] | 0, c[p >> 2] | 0) | 0;
	                    c[(c[x >> 2] | 0) + 36 >> 2] = u;
	                    if ((c[(c[x >> 2] | 0) + 36 >> 2] | 0) == 0 ? (qy(c[p >> 2] | 0, 197912) | 0) != 0 : 0) {
	                        u = cj(c[(c[w >> 2] | 0) + 8 >> 2] | 0, c[x >> 2] | 0, c[p >> 2] | 0) | 0;
	                        c[(c[x >> 2] | 0) + 36 >> 2] = u
	                    }
	                    if (!(c[(c[x >> 2] | 0) + 36 >> 2] | 0)) {
	                        c[A >> 2] = Ih(c[x >> 2] | 0, 0, c[p >> 2] | 0) | 0;
	                        if (!(c[A >> 2] | 0)) {
	                            sQ(c[w >> 2] | 0, 197888);
	                            i = m;
	                            return
	                        }
	                        u = c[w >> 2] | 0;
	                        if (c[p >> 2] | 0) {
	                            yQ(u, 201, 197920, c[p >> 2] | 0, 0);
	                            break
	                        } else {
	                            yQ(u, 201, 197960, 0, 0);
	                            break
	                        }
	                    }
	                } while (0);
	                a:do if ((c[t >> 2] | 0) > 0) {
	                    c[F >> 2] = 0;
	                    c[E >> 2] = 0;
	                    while (1) {
	                        if ((c[E >> 2] | 0) >= (c[t >> 2] | 0))break a;
	                        do if ((c[(c[v >> 2] | 0) + ((c[F >> 2] | 0) + 1 << 2) >> 2] | 0) != 0 ? (c[(c[v >> 2] | 0) + ((c[F >> 2] | 0) + 2 << 2) >> 2] | 0) == 0 : 0)if (c[(c[w >> 2] | 0) + 364 >> 2] | 0) {
	                            c[H >> 2] = BP(c[(c[w >> 2] | 0) + 296 >> 2] | 0, c[(c[v >> 2] | 0) + ((c[F >> 2] | 0) + 1 << 2) >> 2] | 0, c[(c[v >> 2] | 0) + (c[F >> 2] << 2) >> 2] | 0) | 0;
	                            if (!(c[H >> 2] | 0)) {
	                                J = 83;
	                                break
	                            }
	                            zQ(c[w >> 2] | 0, c[H >> 2] | 0, 0, c[(c[v >> 2] | 0) + ((c[F >> 2] | 0) + 3 << 2) >> 2] | 0, c[(c[v >> 2] | 0) + ((c[F >> 2] | 0) + 4 << 2) >> 2] | 0);
	                            break
	                        } else {
	                            c[D >> 2] = Bh(c[(c[v >> 2] | 0) + (c[F >> 2] << 2) >> 2] | 0, c[(c[v >> 2] | 0) + ((c[F >> 2] | 0) + 1 << 2) >> 2] | 0, 0, 0) | 0;
	                            if (!(c[D >> 2] | 0)) {
	                                J = 83;
	                                break
	                            }
	                            zQ(c[w >> 2] | 0, c[D >> 2] | 0, 0, c[(c[v >> 2] | 0) + ((c[F >> 2] | 0) + 3 << 2) >> 2] | 0, c[(c[v >> 2] | 0) + ((c[F >> 2] | 0) + 4 << 2) >> 2] | 0);
	                            zb[c[135736 >> 2] & 511](c[D >> 2] | 0);
	                            break
	                        } else J = 83; while (0);
	                        if ((J | 0) == 83) {
	                            J = 0;
	                            zQ(c[w >> 2] | 0, c[(c[v >> 2] | 0) + (c[F >> 2] << 2) >> 2] | 0, c[(c[v >> 2] | 0) + ((c[F >> 2] | 0) + 1 << 2) >> 2] | 0, c[(c[v >> 2] | 0) + ((c[F >> 2] | 0) + 3 << 2) >> 2] | 0, c[(c[v >> 2] | 0) + ((c[F >> 2] | 0) + 4 << 2) >> 2] | 0)
	                        }
	                        c[E >> 2] = (c[E >> 2] | 0) + 1;
	                        c[F >> 2] = (c[F >> 2] | 0) + 5
	                    }
	                } while (0);
	                if (!(c[(c[w >> 2] | 0) + 104 >> 2] | 0)) {
	                    i = m;
	                    return
	                }
	                if ((c[(c[w >> 2] | 0) + 136 >> 2] | 0) != -1412623820) {
	                    i = m;
	                    return
	                }
	                c[I >> 2] = en((c[w >> 2] | 0) + 108 | 0, c[(c[w >> 2] | 0) + 8 >> 2] | 0) | 0;
	                if ((c[I >> 2] | 0) <= 0)c[(c[w >> 2] | 0) + 100 >> 2] = 0;
	                if ((c[I >> 2] | 0) < 0)c[(c[w >> 2] | 0) + 12 >> 2] = 0;
	                I = an((c[w >> 2] | 0) + 108 | 0, c[(c[w >> 2] | 0) + 8 >> 2] | 0) | 0;
	                F = (c[w >> 2] | 0) + 100 | 0;
	                c[F >> 2] = c[F >> 2] & I;
	                c[(c[w >> 2] | 0) + 136 >> 2] = -1412623819;
	                i = m;
	                return
	            }

	            function gQ(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f + 40 | 0;
	                h = f + 24 | 0;
	                j = f + 4 | 0;
	                k = f;
	                c[g >> 2] = a;
	                c[f + 36 >> 2] = b;
	                c[f + 32 >> 2] = d;
	                c[f + 28 >> 2] = e;
	                c[h >> 2] = c[g >> 2];
	                if (!(c[g >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                c[k >> 2] = c[(c[h >> 2] | 0) + 52 >> 2];
	                if ((c[k >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 68 >> 2] | 0) != 0 : 0) {
	                    c[j + 12 >> 2] = (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 16 >> 2] | 0) - (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0);
	                    c[j + 16 >> 2] = c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2];
	                    c[j >> 2] = c[k >> 2];
	                    De(c[h >> 2] | 0, j)
	                }
	                c[(c[h >> 2] | 0) + 264 >> 2] = -1;
	                if ((((c[(c[h >> 2] | 0) + 104 >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[(c[h >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (c[(c[(c[h >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0) != 0 : 0) {
	                    j = $m((c[h >> 2] | 0) + 108 | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[k >> 2] | 0) | 0;
	                    k = (c[h >> 2] | 0) + 100 | 0;
	                    c[k >> 2] = c[k >> 2] & j
	                }
	                Re(c[h >> 2] | 0) | 0;
	                i = f;
	                return
	            }

	            function hQ(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = c[f >> 2];
	                if (!(c[f >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                f = c[(c[h >> 2] | 0) + 8 >> 2] | 0;
	                b = c[g >> 2] | 0;
	                if ((d[c[g >> 2] >> 0] | 0 | 0) == 35)c[j >> 2] = mi(f, b) | 0; else c[j >> 2] = Yh(f, b) | 0;
	                if (zi(c[(c[h >> 2] | 0) + 52 >> 2] | 0, c[j >> 2] | 0) | 0) {
	                    i = e;
	                    return
	                }
	                Rh(c[j >> 2] | 0);
	                i = e;
	                return
	            }

	            function iQ(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 28 | 0;
	                h = f + 24 | 0;
	                j = f + 20 | 0;
	                k = f + 16 | 0;
	                l = f + 12 | 0;
	                m = f + 8 | 0;
	                n = f + 4 | 0;
	                o = f;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = e;
	                c[k >> 2] = c[g >> 2];
	                if (!(c[g >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                if (!(c[(c[k >> 2] | 0) + 52 >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                c[l >> 2] = c[(c[(c[k >> 2] | 0) + 52 >> 2] | 0) + 16 >> 2];
	                if (!(c[l >> 2] | 0)) {
	                    c[l >> 2] = AQ(c[k >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                    if (c[l >> 2] | 0) {
	                        c[(c[(c[k >> 2] | 0) + 52 >> 2] | 0) + 12 >> 2] = c[l >> 2];
	                        c[(c[(c[k >> 2] | 0) + 52 >> 2] | 0) + 16 >> 2] = c[l >> 2];
	                        c[(c[l >> 2] | 0) + 20 >> 2] = c[(c[k >> 2] | 0) + 52 >> 2];
	                        c[(c[l >> 2] | 0) + 32 >> 2] = c[(c[(c[k >> 2] | 0) + 52 >> 2] | 0) + 32 >> 2];
	                        c[(c[k >> 2] | 0) + 260 >> 2] = c[j >> 2];
	                        c[(c[k >> 2] | 0) + 264 >> 2] = (c[j >> 2] | 0) + 1;
	                        i = f;
	                        return
	                    } else {
	                        sQ(c[k >> 2] | 0, 198e3);
	                        i = f;
	                        return
	                    }
	                }
	                if ((c[l >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 4 >> 2] | 0) == 3 : 0)p = (c[(c[l >> 2] | 0) + 8 >> 2] | 0) == 75104; else p = 0;
	                c[m >> 2] = p & 1;
	                if ((c[m >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 264 >> 2] | 0) != 0 : 0) {
	                    if ((c[(c[l >> 2] | 0) + 40 >> 2] | 0) != ((c[l >> 2] | 0) + 44 | 0)) {
	                        if ((c[(c[k >> 2] | 0) + 264 >> 2] | 0) == ((c[(c[k >> 2] | 0) + 260 >> 2] | 0) + 1 | 0) ? (CP(c[(c[k >> 2] | 0) + 296 >> 2] | 0, c[(c[l >> 2] | 0) + 40 >> 2] | 0) | 0) != 0 : 0) {
	                            p = my(c[(c[l >> 2] | 0) + 40 >> 2] | 0) | 0;
	                            c[(c[l >> 2] | 0) + 40 >> 2] = p
	                        }
	                    } else {
	                        p = my(c[(c[l >> 2] | 0) + 40 >> 2] | 0) | 0;
	                        c[(c[l >> 2] | 0) + 40 >> 2] = p;
	                        c[(c[l >> 2] | 0) + 44 >> 2] = 0
	                    }
	                    p = c[k >> 2] | 0;
	                    if (!(c[(c[l >> 2] | 0) + 40 >> 2] | 0)) {
	                        sQ(p, 198024);
	                        i = f;
	                        return
	                    }
	                    if (((c[p + 260 >> 2] | 0) + (c[j >> 2] | 0) | 0) >>> 0 > 1e7 ? (c[(c[k >> 2] | 0) + 360 >> 2] & 524288 | 0) == 0 : 0) {
	                        sQ(c[k >> 2] | 0, 198072);
	                        i = f;
	                        return
	                    }
	                    if ((c[(c[k >> 2] | 0) + 260 >> 2] | 0) >>> 0 <= (-1 - (c[j >> 2] | 0) | 0) >>> 0 ? ((c[(c[k >> 2] | 0) + 264 >> 2] | 0) + (c[j >> 2] | 0) | 0) >>> 0 <= 2147483647 : 0) {
	                        do if (((c[(c[k >> 2] | 0) + 260 >> 2] | 0) + (c[j >> 2] | 0) | 0) >= (c[(c[k >> 2] | 0) + 264 >> 2] | 0)) {
	                            c[o >> 2] = (c[(c[k >> 2] | 0) + 264 >> 2] | 0) + (c[j >> 2] | 0);
	                            c[o >> 2] = c[o >> 2] << 1;
	                            c[n >> 2] = Hb[c[135760 >> 2] & 511](c[(c[l >> 2] | 0) + 40 >> 2] | 0, c[o >> 2] | 0) | 0;
	                            if (c[n >> 2] | 0) {
	                                c[(c[k >> 2] | 0) + 264 >> 2] = c[o >> 2];
	                                c[(c[l >> 2] | 0) + 40 >> 2] = c[n >> 2];
	                                break
	                            }
	                            sQ(c[k >> 2] | 0, 198e3);
	                            i = f;
	                            return
	                        } while (0);
	                        eU((c[(c[l >> 2] | 0) + 40 >> 2] | 0) + (c[(c[k >> 2] | 0) + 260 >> 2] | 0) | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                        n = (c[k >> 2] | 0) + 260 | 0;
	                        c[n >> 2] = (c[n >> 2] | 0) + (c[j >> 2] | 0);
	                        a[(c[(c[l >> 2] | 0) + 40 >> 2] | 0) + (c[(c[k >> 2] | 0) + 260 >> 2] | 0) >> 0] = 0;
	                        i = f;
	                        return
	                    }
	                    sQ(c[k >> 2] | 0, 198112);
	                    i = f;
	                    return
	                }
	                if (c[m >> 2] | 0) {
	                    if (jj(c[l >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0)sQ(c[k >> 2] | 0, 198e3);
	                    if (!(c[(c[(c[k >> 2] | 0) + 52 >> 2] | 0) + 12 >> 2] | 0)) {
	                        i = f;
	                        return
	                    }
	                    m = xy(c[(c[l >> 2] | 0) + 40 >> 2] | 0) | 0;
	                    c[(c[k >> 2] | 0) + 260 >> 2] = m;
	                    c[(c[k >> 2] | 0) + 264 >> 2] = (c[(c[k >> 2] | 0) + 260 >> 2] | 0) + 1;
	                    i = f;
	                    return
	                } else {
	                    c[l >> 2] = AQ(c[k >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                    if (!(c[l >> 2] | 0)) {
	                        i = f;
	                        return
	                    }
	                    zi(c[(c[k >> 2] | 0) + 52 >> 2] | 0, c[l >> 2] | 0) | 0;
	                    if (!(c[(c[(c[k >> 2] | 0) + 52 >> 2] | 0) + 12 >> 2] | 0)) {
	                        i = f;
	                        return
	                    }
	                    c[(c[k >> 2] | 0) + 260 >> 2] = c[j >> 2];
	                    c[(c[k >> 2] | 0) + 264 >> 2] = (c[j >> 2] | 0) + 1;
	                    i = f;
	                    return
	                }
	            }

	            function jQ(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0;
	                e = i;
	                i = i + 16 | 0;
	                c[e + 8 >> 2] = a;
	                c[e + 4 >> 2] = b;
	                c[e >> 2] = d;
	                i = e;
	                return
	            }

	            function kQ(a, d, e) {
	                a = a | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[g >> 2] = a;
	                c[h >> 2] = d;
	                c[j >> 2] = e;
	                c[k >> 2] = c[g >> 2];
	                if (!(c[g >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                c[m >> 2] = c[(c[k >> 2] | 0) + 52 >> 2];
	                c[l >> 2] = gi(c[(c[k >> 2] | 0) + 8 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                if (!(c[l >> 2] | 0)) {
	                    i = f;
	                    return
	                }
	                do if ((c[(c[k >> 2] | 0) + 280 >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0)if ((c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2] | 0) < 65535) {
	                    b[(c[l >> 2] | 0) + 56 >> 1] = c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2];
	                    break
	                } else {
	                    b[(c[l >> 2] | 0) + 56 >> 1] = -1;
	                    break
	                } while (0);
	                j = c[k >> 2] | 0;
	                if ((c[(c[k >> 2] | 0) + 216 >> 2] | 0) == 1) {
	                    zi(c[(c[j + 8 >> 2] | 0) + 44 >> 2] | 0, c[l >> 2] | 0) | 0;
	                    i = f;
	                    return
	                }
	                if ((c[j + 216 >> 2] | 0) == 2) {
	                    zi(c[(c[(c[k >> 2] | 0) + 8 >> 2] | 0) + 48 >> 2] | 0, c[l >> 2] | 0) | 0;
	                    i = f;
	                    return
	                }
	                if (!(c[m >> 2] | 0)) {
	                    zi(c[(c[k >> 2] | 0) + 8 >> 2] | 0, c[l >> 2] | 0) | 0;
	                    i = f;
	                    return
	                }
	                k = c[m >> 2] | 0;
	                j = c[l >> 2] | 0;
	                if ((c[(c[m >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                    zi(k, j) | 0;
	                    i = f;
	                    return
	                } else {
	                    xi(k, j) | 0;
	                    i = f;
	                    return
	                }
	            }

	            function lQ(a, d) {
	                a = a | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[f >> 2] = a;
	                c[g >> 2] = d;
	                c[h >> 2] = c[f >> 2];
	                if (!(c[f >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                c[k >> 2] = c[(c[h >> 2] | 0) + 52 >> 2];
	                c[j >> 2] = qi(c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[g >> 2] | 0) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                do if ((c[(c[h >> 2] | 0) + 280 >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 36 >> 2] | 0) != 0 : 0)if ((c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2] | 0) < 65535) {
	                    b[(c[j >> 2] | 0) + 56 >> 1] = c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2];
	                    break
	                } else {
	                    b[(c[j >> 2] | 0) + 56 >> 1] = -1;
	                    break
	                } while (0);
	                g = c[h >> 2] | 0;
	                if ((c[(c[h >> 2] | 0) + 216 >> 2] | 0) == 1) {
	                    zi(c[(c[g + 8 >> 2] | 0) + 44 >> 2] | 0, c[j >> 2] | 0) | 0;
	                    i = e;
	                    return
	                }
	                if ((c[g + 216 >> 2] | 0) == 2) {
	                    zi(c[(c[(c[h >> 2] | 0) + 8 >> 2] | 0) + 48 >> 2] | 0, c[j >> 2] | 0) | 0;
	                    i = e;
	                    return
	                }
	                if (!(c[k >> 2] | 0)) {
	                    zi(c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[j >> 2] | 0) | 0;
	                    i = e;
	                    return
	                }
	                h = c[k >> 2] | 0;
	                g = c[j >> 2] | 0;
	                if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                    zi(h, g) | 0;
	                    i = e;
	                    return
	                } else {
	                    xi(h, g) | 0;
	                    i = e;
	                    return
	                }
	            }

	            function mQ(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = c[f >> 2];
	                if (!(c[f >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                c[l >> 2] = Bi(c[(c[j >> 2] | 0) + 52 >> 2] | 0) | 0;
	                if ((c[l >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 4 >> 2] | 0) == 4 : 0) {
	                    jj(c[l >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                    i = e;
	                    return
	                }
	                c[k >> 2] = pi(c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0) | 0;
	                zi(c[(c[j >> 2] | 0) + 52 >> 2] | 0, c[k >> 2] | 0) | 0;
	                i = e;
	                return
	            }

	            function nQ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = c[49538];
	                if ((c[e >> 2] | 0) != 1 & (c[e >> 2] | 0) != 2) {
	                    c[d >> 2] = -1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    c[49538] = c[e >> 2];
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function oQ(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = -1;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                }
	                do if ((c[g >> 2] | 0) == 2) {
	                    c[(c[f >> 2] | 0) + 56 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 60 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 116 >> 2] = 387;
	                    c[(c[f >> 2] | 0) + 120 >> 2] = 388;
	                    c[(c[f >> 2] | 0) + 124 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 108 >> 2] = -554844497
	                } else {
	                    if ((c[g >> 2] | 0) == 1) {
	                        c[(c[f >> 2] | 0) + 56 >> 2] = 50;
	                        c[(c[f >> 2] | 0) + 60 >> 2] = 51;
	                        c[(c[f >> 2] | 0) + 108 >> 2] = 1;
	                        break
	                    }
	                    c[e >> 2] = -1;
	                    h = c[e >> 2] | 0;
	                    i = d;
	                    return h | 0
	                } while (0);
	                c[c[f >> 2] >> 2] = 36;
	                c[(c[f >> 2] | 0) + 104 >> 2] = 60;
	                c[(c[f >> 2] | 0) + 4 >> 2] = 37;
	                c[(c[f >> 2] | 0) + 8 >> 2] = 38;
	                c[(c[f >> 2] | 0) + 12 >> 2] = 39;
	                c[(c[f >> 2] | 0) + 16 >> 2] = 40;
	                c[(c[f >> 2] | 0) + 20 >> 2] = 41;
	                c[(c[f >> 2] | 0) + 96 >> 2] = 58;
	                c[(c[f >> 2] | 0) + 24 >> 2] = 42;
	                c[(c[f >> 2] | 0) + 32 >> 2] = 44;
	                c[(c[f >> 2] | 0) + 36 >> 2] = 45;
	                c[(c[f >> 2] | 0) + 28 >> 2] = 43;
	                c[(c[f >> 2] | 0) + 40 >> 2] = 46;
	                c[(c[f >> 2] | 0) + 44 >> 2] = 47;
	                c[(c[f >> 2] | 0) + 48 >> 2] = 48;
	                c[(c[f >> 2] | 0) + 52 >> 2] = 49;
	                c[(c[f >> 2] | 0) + 64 >> 2] = 52;
	                c[(c[f >> 2] | 0) + 68 >> 2] = 53;
	                c[(c[f >> 2] | 0) + 100 >> 2] = 59;
	                c[(c[f >> 2] | 0) + 72 >> 2] = 53;
	                c[(c[f >> 2] | 0) + 76 >> 2] = 54;
	                c[(c[f >> 2] | 0) + 80 >> 2] = 55;
	                c[(c[f >> 2] | 0) + 84 >> 2] = 56;
	                c[(c[f >> 2] | 0) + 88 >> 2] = 57;
	                c[(c[f >> 2] | 0) + 92 >> 2] = 57;
	                c[e >> 2] = 0;
	                h = c[e >> 2] | 0;
	                i = d;
	                return h | 0
	            }

	            function pQ() {
	                var a = 0;
	                a = i;
	                oQ(135968, 1) | 0;
	                i = a;
	                return
	            }

	            function qQ(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 108 >> 2] | 0) {
	                    i = b;
	                    return
	                }
	                c[c[d >> 2] >> 2] = 36;
	                c[(c[d >> 2] | 0) + 104 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 4 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 8 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 12 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 16 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 20 >> 2] = 41;
	                c[(c[d >> 2] | 0) + 96 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 24 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 32 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 36 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 28 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 40 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 44 >> 2] = 47;
	                c[(c[d >> 2] | 0) + 48 >> 2] = 48;
	                c[(c[d >> 2] | 0) + 52 >> 2] = 49;
	                c[(c[d >> 2] | 0) + 56 >> 2] = 50;
	                c[(c[d >> 2] | 0) + 60 >> 2] = 51;
	                c[(c[d >> 2] | 0) + 64 >> 2] = 0;
	                c[(c[d >> 2] | 0) + 68 >> 2] = 53;
	                c[(c[d >> 2] | 0) + 100 >> 2] = 59;
	                c[(c[d >> 2] | 0) + 72 >> 2] = 65;
	                c[(c[d >> 2] | 0) + 76 >> 2] = 54;
	                c[(c[d >> 2] | 0) + 80 >> 2] = 55;
	                c[(c[d >> 2] | 0) + 84 >> 2] = 56;
	                c[(c[d >> 2] | 0) + 88 >> 2] = 57;
	                c[(c[d >> 2] | 0) + 92 >> 2] = 57;
	                c[(c[d >> 2] | 0) + 108 >> 2] = 1;
	                i = b;
	                return
	            }

	            function rQ() {
	                var a = 0;
	                a = i;
	                qQ(136096);
	                i = a;
	                return
	            }

	            function sQ(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 20 | 0;
	                g = d + 16 | 0;
	                h = d + 12 | 0;
	                j = d + 8 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                c[j >> 2] = 198680;
	                if (!(c[f >> 2] | 0)) {
	                    b = c[h >> 2] | 0;
	                    a = c[f >> 2] | 0;
	                    k = c[j >> 2] | 0;
	                    l = c[g >> 2] | 0;
	                    c[e >> 2] = c[j >> 2];
	                    c[e + 4 >> 2] = 0;
	                    Xd(b, 0, 0, a, 0, 1, 2, 2, 0, 0, k, 0, 0, 0, 0, l, e);
	                    i = d;
	                    return
	                }
	                c[(c[f >> 2] | 0) + 84 >> 2] = 2;
	                if ((c[c[f >> 2] >> 2] | 0) != 0 ? (c[(c[c[f >> 2] >> 2] | 0) + 108 >> 2] | 0) == -554844497 : 0)c[h >> 2] = c[(c[c[f >> 2] >> 2] | 0) + 124 >> 2];
	                l = c[h >> 2] | 0;
	                h = c[(c[f >> 2] | 0) + 112 >> 2] | 0;
	                k = c[(c[f >> 2] | 0) + 108 >> 2] | 0;
	                a = c[f >> 2] | 0;
	                b = c[j >> 2] | 0;
	                m = c[g >> 2] | 0;
	                c[e >> 2] = c[j >> 2];
	                c[e + 4 >> 2] = 0;
	                Xd(l, h, k, a, 0, 1, 2, 2, 0, 0, b, 0, 0, 0, 0, m, e);
	                c[(c[f >> 2] | 0) + 84 >> 2] = 2;
	                c[(c[f >> 2] | 0) + 172 >> 2] = -1;
	                c[(c[f >> 2] | 0) + 212 >> 2] = 1;
	                i = d;
	                return
	            }

	            function tQ(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g;
	                j = g + 24 | 0;
	                k = g + 20 | 0;
	                l = g + 16 | 0;
	                m = g + 12 | 0;
	                n = g + 8 | 0;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                if (((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 212 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 172 >> 2] | 0) == -1 : 0) {
	                    i = g;
	                    return
	                }
	                if (c[j >> 2] | 0)c[(c[j >> 2] | 0) + 84 >> 2] = c[k >> 2];
	                f = c[j >> 2] | 0;
	                e = c[k >> 2] | 0;
	                k = c[m >> 2] | 0;
	                d = c[n >> 2] | 0;
	                b = c[l >> 2] | 0;
	                l = c[n >> 2] | 0;
	                c[h >> 2] = c[m >> 2];
	                c[h + 4 >> 2] = l;
	                Xd(0, 0, 0, f, 0, 1, e, 3, 0, 0, k, d, 0, 0, 0, b, h);
	                if (!(c[j >> 2] | 0)) {
	                    i = g;
	                    return
	                }
	                c[(c[j >> 2] | 0) + 12 >> 2] = 0;
	                c[(c[j >> 2] | 0) + 100 >> 2] = 0;
	                if (c[(c[j >> 2] | 0) + 288 >> 2] | 0) {
	                    i = g;
	                    return
	                }
	                c[(c[j >> 2] | 0) + 212 >> 2] = 1;
	                i = g;
	                return
	            }

	            function uQ(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if (((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 212 >> 2] | 0) != 0 : 0) ? (c[(c[h >> 2] | 0) + 172 >> 2] | 0) == -1 : 0) {
	                    i = f;
	                    return
	                }
	                if (c[h >> 2] | 0)c[(c[h >> 2] | 0) + 84 >> 2] = c[j >> 2];
	                e = c[h >> 2] | 0;
	                h = c[j >> 2] | 0;
	                j = c[l >> 2] | 0;
	                d = c[k >> 2] | 0;
	                c[g >> 2] = c[l >> 2];
	                Xd(0, 0, 0, e, 0, 1, h, 1, 0, 0, j, 0, 0, 0, 0, d, g);
	                i = f;
	                return
	            }

	            function vQ(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g;
	                j = g + 28 | 0;
	                k = g + 24 | 0;
	                l = g + 20 | 0;
	                m = g + 16 | 0;
	                n = g + 12 | 0;
	                o = g + 8 | 0;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = 0;
	                if (((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 212 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 172 >> 2] | 0) == -1 : 0) {
	                    i = g;
	                    return
	                }
	                if (!(c[j >> 2] | 0)) {
	                    f = c[o >> 2] | 0;
	                    e = c[j >> 2] | 0;
	                    d = c[k >> 2] | 0;
	                    b = c[m >> 2] | 0;
	                    a = c[n >> 2] | 0;
	                    p = c[l >> 2] | 0;
	                    q = c[n >> 2] | 0;
	                    c[h >> 2] = c[m >> 2];
	                    c[h + 4 >> 2] = q;
	                    Xd(f, 0, 0, e, 0, 4, d, 2, 0, 0, b, a, 0, 0, 0, p, h);
	                    i = g;
	                    return
	                }
	                c[(c[j >> 2] | 0) + 84 >> 2] = c[k >> 2];
	                if ((c[c[j >> 2] >> 2] | 0) != 0 ? (c[(c[c[j >> 2] >> 2] | 0) + 108 >> 2] | 0) == -554844497 : 0)c[o >> 2] = c[(c[c[j >> 2] >> 2] | 0) + 124 >> 2];
	                p = c[o >> 2] | 0;
	                o = c[(c[j >> 2] | 0) + 112 >> 2] | 0;
	                a = c[(c[j >> 2] | 0) + 108 >> 2] | 0;
	                b = c[j >> 2] | 0;
	                d = c[k >> 2] | 0;
	                k = c[m >> 2] | 0;
	                e = c[n >> 2] | 0;
	                f = c[l >> 2] | 0;
	                l = c[n >> 2] | 0;
	                c[h >> 2] = c[m >> 2];
	                c[h + 4 >> 2] = l;
	                Xd(p, o, a, b, 0, 4, d, 2, 0, 0, k, e, 0, 0, 0, f, h);
	                c[(c[j >> 2] | 0) + 100 >> 2] = 0;
	                i = g;
	                return
	            }

	            function wQ(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                f = i;
	                i = i + 112 | 0;
	                g = f + 44 | 0;
	                h = f + 40 | 0;
	                j = f + 36 | 0;
	                k = f + 32 | 0;
	                l = f + 28 | 0;
	                m = f + 24 | 0;
	                n = f + 20 | 0;
	                o = f + 16 | 0;
	                p = f + 12 | 0;
	                q = f + 8 | 0;
	                r = f + 4 | 0;
	                s = f + 48 | 0;
	                t = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                c[n >> 2] = 1;
	                c[l >> 2] = Mm(c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                if (!(c[l >> 2] | 0)) {
	                    c[l >> 2] = Mm(c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 48 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                    c[n >> 2] = 0
	                }
	                a:while (1) {
	                    if (!(c[l >> 2] | 0)) {
	                        u = 48;
	                        break
	                    }
	                    c[p >> 2] = c[(c[l >> 2] | 0) + 44 >> 2];
	                    b:do if (((c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 40 >> 2] | 0) == 1 ? (c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 48 >> 2] | 0) != 0 : 0) ? ((c[p >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 104 >> 2] | 0) != 0 : 0) : 0) {
	                        while (1) {
	                            if (((c[(c[p >> 2] | 0) + 48 >> 2] | 0) != 0 ? (e = Nm(c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 48 >> 2] | 0, c[(c[p >> 2] | 0) + 60 >> 2] | 0, c[(c[p >> 2] | 0) + 8 >> 2] | 0, c[(c[p >> 2] | 0) + 56 >> 2] | 0) | 0, (e | 0) == (c[p >> 2] | 0)) : 0) ? (Nm(c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0, c[(c[p >> 2] | 0) + 60 >> 2] | 0, c[(c[p >> 2] | 0) + 8 >> 2] | 0, c[(c[p >> 2] | 0) + 56 >> 2] | 0) | 0) == 0 : 0) {
	                                e = c[p >> 2] | 0;
	                                if (c[(c[p >> 2] | 0) + 56 >> 2] | 0) {
	                                    c[q >> 2] = my(c[e + 56 >> 2] | 0) | 0;
	                                    c[q >> 2] = By(c[q >> 2] | 0, 198608) | 0;
	                                    c[q >> 2] = By(c[q >> 2] | 0, c[(c[p >> 2] | 0) + 8 >> 2] | 0) | 0
	                                } else c[q >> 2] = my(c[e + 8 >> 2] | 0) | 0;
	                                if (!(c[q >> 2] | 0))break;
	                                c[m >> 2] = 0;
	                                c:do if (c[k >> 2] | 0) {
	                                    c[o >> 2] = 0;
	                                    c[m >> 2] = c[(c[k >> 2] | 0) + (c[o >> 2] << 2) >> 2];
	                                    while (1) {
	                                        if (!(c[m >> 2] | 0))break c;
	                                        if (qy(c[m >> 2] | 0, c[q >> 2] | 0) | 0)break c;
	                                        c[o >> 2] = (c[o >> 2] | 0) + 2;
	                                        c[m >> 2] = c[(c[k >> 2] | 0) + (c[o >> 2] << 2) >> 2]
	                                    }
	                                } while (0);
	                                if (!(c[m >> 2] | 0))vQ(c[g >> 2] | 0, 538, 198616, c[q >> 2] | 0, c[(c[p >> 2] | 0) + 60 >> 2] | 0);
	                                zb[c[135736 >> 2] & 511](c[q >> 2] | 0)
	                            }
	                            c[p >> 2] = c[(c[p >> 2] | 0) + 36 >> 2];
	                            if (!(c[p >> 2] | 0))break b
	                        }
	                        sQ(c[g >> 2] | 0, 197824)
	                    } while (0);
	                    c[p >> 2] = c[(c[l >> 2] | 0) + 44 >> 2];
	                    while (1) {
	                        if (!(c[p >> 2] | 0))break;
	                        d:do if (c[(c[p >> 2] | 0) + 48 >> 2] | 0) {
	                            if (!((c[(c[p >> 2] | 0) + 56 >> 2] | 0) != 0 ? (qy(c[(c[p >> 2] | 0) + 56 >> 2] | 0, 198248) | 0) != 0 : 0))u = 29;
	                            do if ((u | 0) == 29) {
	                                u = 0;
	                                if ((c[(c[p >> 2] | 0) + 56 >> 2] | 0) == 0 ? (qy(c[(c[p >> 2] | 0) + 8 >> 2] | 0, 198248) | 0) != 0 : 0)break;
	                                if (!(c[(c[g >> 2] | 0) + 276 >> 2] & 4))break d
	                            } while (0);
	                            c[r >> 2] = Nm(c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0, c[(c[p >> 2] | 0) + 60 >> 2] | 0, c[(c[p >> 2] | 0) + 8 >> 2] | 0, c[(c[p >> 2] | 0) + 56 >> 2] | 0) | 0;
	                            if ((c[r >> 2] | 0) == 0 ? 1 : (c[r >> 2] | 0) == (c[p >> 2] | 0)) {
	                                c[t >> 2] = Bh(c[(c[p >> 2] | 0) + 8 >> 2] | 0, c[(c[p >> 2] | 0) + 56 >> 2] | 0, s, 50) | 0;
	                                if (!(c[t >> 2] | 0)) {
	                                    u = 34;
	                                    break a
	                                }
	                                c[m >> 2] = 0;
	                                e:do if (c[k >> 2] | 0) {
	                                    c[o >> 2] = 0;
	                                    c[m >> 2] = c[(c[k >> 2] | 0) + (c[o >> 2] << 2) >> 2];
	                                    while (1) {
	                                        if (!(c[m >> 2] | 0))break e;
	                                        if (qy(c[m >> 2] | 0, c[t >> 2] | 0) | 0)break e;
	                                        c[o >> 2] = (c[o >> 2] | 0) + 2;
	                                        c[m >> 2] = c[(c[k >> 2] | 0) + (c[o >> 2] << 2) >> 2]
	                                    }
	                                } while (0);
	                                if (!(c[m >> 2] | 0))xQ(c[g >> 2] | 0, c[t >> 2] | 0, c[(c[p >> 2] | 0) + 48 >> 2] | 0, c[j >> 2] | 0);
	                                if ((c[t >> 2] | 0) != (s | 0) ? (c[t >> 2] | 0) != (c[(c[p >> 2] | 0) + 8 >> 2] | 0) : 0)zb[c[135736 >> 2] & 511](c[t >> 2] | 0)
	                            }
	                        } while (0);
	                        c[p >> 2] = c[(c[p >> 2] | 0) + 36 >> 2]
	                    }
	                    if ((c[n >> 2] | 0) != 1) {
	                        u = 48;
	                        break
	                    }
	                    c[l >> 2] = Mm(c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + 48 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                    c[n >> 2] = 0
	                }
	                if ((u | 0) == 34) {
	                    sQ(c[g >> 2] | 0, 197824);
	                    i = f;
	                    return
	                } else if ((u | 0) == 48) {
	                    i = f;
	                    return
	                }
	            }

	            function xQ(a, b, e, f) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0;
	                g = i;
	                i = i + 96 | 0;
	                h = g;
	                j = g + 80 | 0;
	                k = g + 76 | 0;
	                l = g + 72 | 0;
	                m = g + 68 | 0;
	                n = g + 64 | 0;
	                o = g + 60 | 0;
	                p = g + 56 | 0;
	                q = g + 52 | 0;
	                r = g + 48 | 0;
	                s = g + 44 | 0;
	                t = g + 40 | 0;
	                u = g + 36 | 0;
	                v = g + 32 | 0;
	                w = g + 28 | 0;
	                x = g + 24 | 0;
	                y = g + 20 | 0;
	                z = g + 16 | 0;
	                A = g + 12 | 0;
	                B = g + 8 | 0;
	                C = g + 4 | 0;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                c[n >> 2] = c[j >> 2];
	                if (!(c[(c[n >> 2] | 0) + 32 >> 2] | 0)) {
	                    c[p >> 2] = bf(c[n >> 2] | 0, c[k >> 2] | 0, q) | 0;
	                    if ((c[p >> 2] | 0) != 0 ? (d[c[p >> 2] >> 0] | 0 | 0) == 0 : 0) {
	                        j = (qy(c[q >> 2] | 0, 198248) | 0) != 0;
	                        f = c[n >> 2] | 0;
	                        e = c[k >> 2] | 0;
	                        if (j)BQ(f, 35, 198256, e, 0); else yQ(f, 106, 198296, e, 0);
	                        if (c[q >> 2] | 0)zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                        c[q >> 2] = 0;
	                        zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                        c[p >> 2] = my(c[k >> 2] | 0) | 0
	                    }
	                } else {
	                    c[p >> 2] = my(c[k >> 2] | 0) | 0;
	                    c[q >> 2] = 0;
	                    c[s >> 2] = 0
	                }
	                e = c[n >> 2] | 0;
	                if (!(c[p >> 2] | 0)) {
	                    sQ(e, 197824);
	                    if (!(c[q >> 2] | 0)) {
	                        i = g;
	                        return
	                    }
	                    zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                    i = g;
	                    return
	                }
	                if ((c[e + 32 >> 2] | 0) != 0 & (c[l >> 2] | 0) == 0 ? (sp(c[k >> 2] | 0) | 0) != 0 : 0) {
	                    c[r >> 2] = my(c[k >> 2] | 0) | 0;
	                    c[l >> 2] = c[r >> 2]
	                } else {
	                    c[(c[n >> 2] | 0) + 144 >> 2] = 1;
	                    c[r >> 2] = Sm((c[n >> 2] | 0) + 108 | 0, c[(c[n >> 2] | 0) + 8 >> 2] | 0, c[(c[n >> 2] | 0) + 52 >> 2] | 0, c[k >> 2] | 0, c[l >> 2] | 0) | 0;
	                    if ((c[(c[n >> 2] | 0) + 144 >> 2] | 0) != 1)c[(c[n >> 2] | 0) + 100 >> 2] = 0;
	                    if (c[r >> 2] | 0)c[l >> 2] = c[r >> 2]
	                }
	                if ((((((((c[q >> 2] | 0) == 0 ? (c[(c[n >> 2] | 0) + 32 >> 2] | 0) == 0 : 0) ? (d[c[p >> 2] >> 0] | 0 | 0) == 120 : 0) ? (d[(c[p >> 2] | 0) + 1 >> 0] | 0 | 0) == 109 : 0) ? (d[(c[p >> 2] | 0) + 2 >> 0] | 0 | 0) == 108 : 0) ? (d[(c[p >> 2] | 0) + 3 >> 0] | 0 | 0) == 110 : 0) ? (d[(c[p >> 2] | 0) + 4 >> 0] | 0 | 0) == 115 : 0) ? (d[(c[p >> 2] | 0) + 5 >> 0] | 0 | 0) == 0 : 0) {
	                    if (!(c[(c[n >> 2] | 0) + 16 >> 2] | 0)) {
	                        e = (c[n >> 2] | 0) + 248 | 0;
	                        c[e >> 2] = (c[e >> 2] | 0) + 1;
	                        c[u >> 2] = af(c[n >> 2] | 0, c[l >> 2] | 0, 1, 0, 0, 0) | 0;
	                        e = (c[n >> 2] | 0) + 248 | 0;
	                        c[e >> 2] = (c[e >> 2] | 0) + -1;
	                        if (!(c[u >> 2] | 0)) {
	                            sQ(c[n >> 2] | 0, 197824);
	                            if (!(c[p >> 2] | 0)) {
	                                i = g;
	                                return
	                            }
	                            zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                            i = g;
	                            return
	                        }
	                    } else c[u >> 2] = c[l >> 2];
	                    do if (d[c[u >> 2] >> 0] | 0) {
	                        c[v >> 2] = yl(c[u >> 2] | 0) | 0;
	                        if (!(c[v >> 2] | 0)) {
	                            if (!(c[c[n >> 2] >> 2] | 0))break;
	                            if (!(c[(c[c[n >> 2] >> 2] | 0) + 84 >> 2] | 0))break;
	                            e = c[(c[c[n >> 2] >> 2] | 0) + 84 >> 2] | 0;
	                            f = c[(c[n >> 2] | 0) + 4 >> 2] | 0;
	                            c[h >> 2] = c[u >> 2];
	                            Db[e & 511](f, 198344, h);
	                            break
	                        }
	                        if (((c[c[v >> 2] >> 2] | 0) == 0 ? (c[c[n >> 2] >> 2] | 0) != 0 : 0) ? (c[(c[c[n >> 2] >> 2] | 0) + 84 >> 2] | 0) != 0 : 0) {
	                            f = c[(c[c[n >> 2] >> 2] | 0) + 84 >> 2] | 0;
	                            e = c[(c[n >> 2] | 0) + 4 >> 2] | 0;
	                            c[h >> 2] = c[u >> 2];
	                            Db[f & 511](e, 198376, h)
	                        }
	                        Al(c[v >> 2] | 0)
	                    } while (0);
	                    c[t >> 2] = Ih(c[(c[n >> 2] | 0) + 52 >> 2] | 0, c[u >> 2] | 0, 0) | 0;
	                    if (((((c[t >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 104 >> 2] | 0) != 0 : 0) ? (c[(c[n >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[(c[n >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0) != 0 : 0) {
	                        v = Xm((c[n >> 2] | 0) + 108 | 0, c[(c[n >> 2] | 0) + 8 >> 2] | 0, c[(c[n >> 2] | 0) + 52 >> 2] | 0, c[m >> 2] | 0, c[t >> 2] | 0, c[u >> 2] | 0) | 0;
	                        t = (c[n >> 2] | 0) + 100 | 0;
	                        c[t >> 2] = c[t >> 2] & v
	                    }
	                    if (c[p >> 2] | 0)zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                    if (c[r >> 2] | 0)zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                    if ((c[u >> 2] | 0) == (c[l >> 2] | 0)) {
	                        i = g;
	                        return
	                    }
	                    zb[c[135736 >> 2] & 511](c[u >> 2] | 0);
	                    i = g;
	                    return
	                }
	                if ((((((((c[q >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 32 >> 2] | 0) == 0 : 0) ? (d[c[q >> 2] >> 0] | 0 | 0) == 120 : 0) ? (d[(c[q >> 2] | 0) + 1 >> 0] | 0 | 0) == 109 : 0) ? (d[(c[q >> 2] | 0) + 2 >> 0] | 0 | 0) == 108 : 0) ? (d[(c[q >> 2] | 0) + 3 >> 0] | 0 | 0) == 110 : 0) ? (d[(c[q >> 2] | 0) + 4 >> 0] | 0 | 0) == 115 : 0) ? (d[(c[q >> 2] | 0) + 5 >> 0] | 0 | 0) == 0 : 0) {
	                    if (!(c[(c[n >> 2] | 0) + 16 >> 2] | 0)) {
	                        u = (c[n >> 2] | 0) + 248 | 0;
	                        c[u >> 2] = (c[u >> 2] | 0) + 1;
	                        c[x >> 2] = af(c[n >> 2] | 0, c[l >> 2] | 0, 1, 0, 0, 0) | 0;
	                        u = (c[n >> 2] | 0) + 248 | 0;
	                        c[u >> 2] = (c[u >> 2] | 0) + -1;
	                        if (!(c[x >> 2] | 0)) {
	                            sQ(c[n >> 2] | 0, 197824);
	                            zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                            if (!(c[p >> 2] | 0)) {
	                                i = g;
	                                return
	                            }
	                            zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                            i = g;
	                            return
	                        }
	                    } else c[x >> 2] = c[l >> 2];
	                    if (!(d[c[x >> 2] >> 0] | 0))BQ(c[n >> 2] | 0, 204, 198408, c[p >> 2] | 0, 0);
	                    do if ((c[(c[n >> 2] | 0) + 268 >> 2] | 0) != 0 ? (d[c[x >> 2] >> 0] | 0 | 0) != 0 : 0) {
	                        c[y >> 2] = yl(c[x >> 2] | 0) | 0;
	                        if (!(c[y >> 2] | 0)) {
	                            yQ(c[n >> 2] | 0, 99, 198448, c[p >> 2] | 0, c[l >> 2] | 0);
	                            break
	                        }
	                        if (!(c[c[y >> 2] >> 2] | 0))yQ(c[n >> 2] | 0, 100, 198480, c[p >> 2] | 0, c[l >> 2] | 0);
	                        Al(c[y >> 2] | 0)
	                    } while (0);
	                    c[w >> 2] = Ih(c[(c[n >> 2] | 0) + 52 >> 2] | 0, c[x >> 2] | 0, c[p >> 2] | 0) | 0;
	                    zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                    do if ((((c[w >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 104 >> 2] | 0) != 0 : 0) ? (c[(c[n >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[(c[n >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                        if (!(c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0))break;
	                        y = Xm((c[n >> 2] | 0) + 108 | 0, c[(c[n >> 2] | 0) + 8 >> 2] | 0, c[(c[n >> 2] | 0) + 52 >> 2] | 0, c[m >> 2] | 0, c[w >> 2] | 0, c[l >> 2] | 0) | 0;
	                        u = (c[n >> 2] | 0) + 100 | 0;
	                        c[u >> 2] = c[u >> 2] & y
	                    } while (0);
	                    if (c[p >> 2] | 0)zb[c[135736 >> 2] & 511](c[p >> 2] | 0);
	                    if (c[r >> 2] | 0)zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                    if ((c[x >> 2] | 0) == (c[l >> 2] | 0)) {
	                        i = g;
	                        return
	                    }
	                    zb[c[135736 >> 2] & 511](c[x >> 2] | 0);
	                    i = g;
	                    return
	                }
	                a:do if (c[q >> 2] | 0) {
	                    c[s >> 2] = cj(c[(c[n >> 2] | 0) + 8 >> 2] | 0, c[(c[n >> 2] | 0) + 52 >> 2] | 0, c[q >> 2] | 0) | 0;
	                    x = c[n >> 2] | 0;
	                    if (!(c[s >> 2] | 0)) {
	                        BQ(x, 201, 198520, c[q >> 2] | 0, c[p >> 2] | 0);
	                        D = 101;
	                        break
	                    }
	                    c[z >> 2] = c[(c[x + 52 >> 2] | 0) + 44 >> 2];
	                    while (1) {
	                        if (!(c[z >> 2] | 0)) {
	                            D = 101;
	                            break a
	                        }
	                        if ((c[(c[z >> 2] | 0) + 36 >> 2] | 0) != 0 ? (qy(c[p >> 2] | 0, c[(c[z >> 2] | 0) + 8 >> 2] | 0) | 0) != 0 : 0) {
	                            if ((c[s >> 2] | 0) == (c[(c[z >> 2] | 0) + 36 >> 2] | 0))break;
	                            if (qy(c[(c[s >> 2] | 0) + 8 >> 2] | 0, c[(c[(c[z >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) | 0)break
	                        }
	                        c[z >> 2] = c[(c[z >> 2] | 0) + 24 >> 2]
	                    }
	                    BQ(c[n >> 2] | 0, 42, 198576, c[p >> 2] | 0, c[(c[s >> 2] | 0) + 8 >> 2] | 0);
	                    c[(c[n >> 2] | 0) + 12 >> 2] = 0;
	                    if (!(c[(c[n >> 2] | 0) + 288 >> 2] | 0))c[(c[n >> 2] | 0) + 212 >> 2] = 1
	                } else {
	                    c[s >> 2] = 0;
	                    D = 101
	                } while (0);
	                do if ((D | 0) == 101) {
	                    c[o >> 2] = bi(c[(c[n >> 2] | 0) + 52 >> 2] | 0, c[s >> 2] | 0, c[p >> 2] | 0, 0) | 0;
	                    b:do if (c[o >> 2] | 0) {
	                        if ((c[(c[n >> 2] | 0) + 16 >> 2] | 0) == 0 ? (c[(c[n >> 2] | 0) + 32 >> 2] | 0) == 0 : 0) {
	                            z = Zh(c[(c[n >> 2] | 0) + 8 >> 2] | 0, c[l >> 2] | 0) | 0;
	                            c[(c[o >> 2] | 0) + 12 >> 2] = z;
	                            c[A >> 2] = c[(c[o >> 2] | 0) + 12 >> 2];
	                            while (1) {
	                                if (!(c[A >> 2] | 0))break b;
	                                c[(c[A >> 2] | 0) + 20 >> 2] = c[o >> 2];
	                                if (!(c[(c[A >> 2] | 0) + 24 >> 2] | 0))c[(c[o >> 2] | 0) + 16 >> 2] = c[A >> 2];
	                                c[A >> 2] = c[(c[A >> 2] | 0) + 24 >> 2]
	                            }
	                        }
	                        if ((c[l >> 2] | 0) != 0 ? (z = Wh(c[(c[n >> 2] | 0) + 8 >> 2] | 0, c[l >> 2] | 0) | 0, c[(c[o >> 2] | 0) + 12 >> 2] = z, c[(c[o >> 2] | 0) + 16 >> 2] = c[(c[o >> 2] | 0) + 12 >> 2], (c[(c[o >> 2] | 0) + 12 >> 2] | 0) != 0) : 0)c[(c[(c[o >> 2] | 0) + 12 >> 2] | 0) + 20 >> 2] = c[o >> 2]
	                    } while (0);
	                    if (((((c[(c[n >> 2] | 0) + 32 >> 2] | 0) == 0 ? (c[(c[n >> 2] | 0) + 104 >> 2] | 0) != 0 : 0) ? (c[(c[n >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[(c[n >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (c[(c[(c[n >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0) != 0 : 0) {
	                        z = c[n >> 2] | 0;
	                        if (c[(c[n >> 2] | 0) + 16 >> 2] | 0) {
	                            x = Wm(z + 108 | 0, c[(c[n >> 2] | 0) + 8 >> 2] | 0, c[(c[n >> 2] | 0) + 52 >> 2] | 0, c[o >> 2] | 0, c[l >> 2] | 0) | 0;
	                            w = (c[n >> 2] | 0) + 100 | 0;
	                            c[w >> 2] = c[w >> 2] & x;
	                            break
	                        }
	                        x = z + 248 | 0;
	                        c[x >> 2] = (c[x >> 2] | 0) + 1;
	                        c[B >> 2] = af(c[n >> 2] | 0, c[l >> 2] | 0, 1, 0, 0, 0) | 0;
	                        x = (c[n >> 2] | 0) + 248 | 0;
	                        c[x >> 2] = (c[x >> 2] | 0) + -1;
	                        x = c[n >> 2] | 0;
	                        if (!(c[B >> 2] | 0)) {
	                            z = Wm(x + 108 | 0, c[(c[n >> 2] | 0) + 8 >> 2] | 0, c[(c[n >> 2] | 0) + 52 >> 2] | 0, c[o >> 2] | 0, c[l >> 2] | 0) | 0;
	                            w = (c[n >> 2] | 0) + 100 | 0;
	                            c[w >> 2] = c[w >> 2] & z;
	                            break
	                        }
	                        c[C >> 2] = Tm(c[x + 8 >> 2] | 0, c[(c[n >> 2] | 0) + 52 >> 2] | 0, c[k >> 2] | 0, c[B >> 2] | 0) | 0;
	                        if (c[C >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[B >> 2] | 0);
	                            c[B >> 2] = c[C >> 2]
	                        }
	                        x = Wm((c[n >> 2] | 0) + 108 | 0, c[(c[n >> 2] | 0) + 8 >> 2] | 0, c[(c[n >> 2] | 0) + 52 >> 2] | 0, c[o >> 2] | 0, c[B >> 2] | 0) | 0;
	                        z = (c[n >> 2] | 0) + 100 | 0;
	                        c[z >> 2] = c[z >> 2] & x;
	                        zb[c[135736 >> 2] & 511](c[B >> 2] | 0);
	                        break
	                    }
	                    if (!(c[(c[n >> 2] | 0) + 276 >> 2] & 8)) {
	                        if (!((c[(c[n >> 2] | 0) + 16 >> 2] | 0) == 0 ? (c[(c[n >> 2] | 0) + 96 >> 2] | 0) != 2 : 0)) {
	                            if (!(c[(c[n >> 2] | 0) + 16 >> 2] | 0))break;
	                            if (c[(c[n >> 2] | 0) + 216 >> 2] | 0)break
	                        }
	                        if (qy(c[k >> 2] | 0, 197408) | 0) {
	                            if (Eh(c[l >> 2] | 0, 1) | 0)vQ(c[n >> 2] | 0, 539, 198200, c[l >> 2] | 0, 0);
	                            Cm((c[n >> 2] | 0) + 108 | 0, c[(c[n >> 2] | 0) + 8 >> 2] | 0, c[l >> 2] | 0, c[o >> 2] | 0) | 0;
	                            break
	                        }
	                        x = (Em(c[(c[n >> 2] | 0) + 8 >> 2] | 0, c[(c[n >> 2] | 0) + 52 >> 2] | 0, c[o >> 2] | 0) | 0) != 0;
	                        z = c[n >> 2] | 0;
	                        if (x) {
	                            Cm(z + 108 | 0, c[(c[n >> 2] | 0) + 8 >> 2] | 0, c[l >> 2] | 0, c[o >> 2] | 0) | 0;
	                            break
	                        }
	                        if (Km(c[z + 8 >> 2] | 0, c[(c[n >> 2] | 0) + 52 >> 2] | 0, c[o >> 2] | 0) | 0)Im((c[n >> 2] | 0) + 108 | 0, c[(c[n >> 2] | 0) + 8 >> 2] | 0, c[l >> 2] | 0, c[o >> 2] | 0) | 0
	                    }
	                } while (0);
	                if (c[r >> 2] | 0)zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                if (!(c[q >> 2] | 0)) {
	                    i = g;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                i = g;
	                return
	            }

	            function yQ(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g;
	                j = g + 24 | 0;
	                k = g + 20 | 0;
	                l = g + 16 | 0;
	                m = g + 12 | 0;
	                n = g + 8 | 0;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                if (((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 212 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 172 >> 2] | 0) == -1 : 0) {
	                    i = g;
	                    return
	                }
	                if (c[j >> 2] | 0)c[(c[j >> 2] | 0) + 84 >> 2] = c[k >> 2];
	                f = c[j >> 2] | 0;
	                j = c[k >> 2] | 0;
	                k = c[m >> 2] | 0;
	                e = c[n >> 2] | 0;
	                d = c[l >> 2] | 0;
	                l = c[n >> 2] | 0;
	                c[h >> 2] = c[m >> 2];
	                c[h + 4 >> 2] = l;
	                Xd(0, 0, 0, f, 0, 3, j, 1, 0, 0, k, e, 0, 0, 0, d, h);
	                i = g;
	                return
	            }

	            function zQ(a, b, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0;
	                h = i;
	                i = i + 112 | 0;
	                j = h + 48 | 0;
	                k = h + 44 | 0;
	                l = h + 40 | 0;
	                m = h + 36 | 0;
	                n = h + 32 | 0;
	                o = h + 28 | 0;
	                p = h + 24 | 0;
	                q = h + 20 | 0;
	                r = h + 16 | 0;
	                s = h + 12 | 0;
	                t = h + 8 | 0;
	                u = h + 4 | 0;
	                v = h + 52 | 0;
	                w = h;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                c[n >> 2] = g;
	                c[p >> 2] = 0;
	                c[q >> 2] = 0;
	                if (c[l >> 2] | 0)c[p >> 2] = cj(c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[(c[j >> 2] | 0) + 52 >> 2] | 0, c[l >> 2] | 0) | 0;
	                g = c[j >> 2] | 0;
	                if (c[(c[j >> 2] | 0) + 380 >> 2] | 0) {
	                    c[o >> 2] = c[g + 380 >> 2];
	                    c[(c[j >> 2] | 0) + 380 >> 2] = c[(c[o >> 2] | 0) + 24 >> 2];
	                    f = (c[j >> 2] | 0) + 376 | 0;
	                    c[f >> 2] = (c[f >> 2] | 0) + -1;
	                    f = (c[o >> 2] | 0) + 0 | 0;
	                    e = f + 48 | 0;
	                    do {
	                        c[f >> 2] = 0;
	                        f = f + 4 | 0
	                    } while ((f | 0) < (e | 0));
	                    c[(c[o >> 2] | 0) + 4 >> 2] = 2;
	                    c[(c[o >> 2] | 0) + 20 >> 2] = c[(c[j >> 2] | 0) + 52 >> 2];
	                    c[(c[o >> 2] | 0) + 32 >> 2] = c[(c[j >> 2] | 0) + 8 >> 2];
	                    c[(c[o >> 2] | 0) + 36 >> 2] = c[p >> 2];
	                    f = c[k >> 2] | 0;
	                    if (c[(c[j >> 2] | 0) + 364 >> 2] | 0)c[(c[o >> 2] | 0) + 8 >> 2] = f; else {
	                        e = my(f) | 0;
	                        c[(c[o >> 2] | 0) + 8 >> 2] = e
	                    }
	                    if (!(c[(c[(c[j >> 2] | 0) + 52 >> 2] | 0) + 44 >> 2] | 0))c[(c[(c[j >> 2] | 0) + 52 >> 2] | 0) + 44 >> 2] = c[o >> 2]; else {
	                        c[r >> 2] = c[(c[(c[j >> 2] | 0) + 52 >> 2] | 0) + 44 >> 2];
	                        while (1) {
	                            if (!(c[(c[r >> 2] | 0) + 24 >> 2] | 0))break;
	                            c[r >> 2] = c[(c[r >> 2] | 0) + 24 >> 2]
	                        }
	                        c[(c[r >> 2] | 0) + 24 >> 2] = c[o >> 2];
	                        c[(c[o >> 2] | 0) + 28 >> 2] = c[r >> 2]
	                    }
	                    if ((c[18774] | 0) != 0 & (c[33968] | 0) != 0)zb[c[135872 >> 2] & 511](c[o >> 2] | 0)
	                } else {
	                    r = c[(c[j >> 2] | 0) + 52 >> 2] | 0;
	                    e = c[p >> 2] | 0;
	                    p = c[k >> 2] | 0;
	                    if (c[g + 364 >> 2] | 0)c[o >> 2] = bi(r, e, p, 0) | 0; else c[o >> 2] = ai(r, e, p, 0) | 0;
	                    if (!(c[o >> 2] | 0)) {
	                        ie(c[j >> 2] | 0, 198176);
	                        i = h;
	                        return
	                    }
	                }
	                a:do if ((c[(c[j >> 2] | 0) + 16 >> 2] | 0) == 0 ? (c[(c[j >> 2] | 0) + 32 >> 2] | 0) == 0 : 0) {
	                    p = c[j >> 2] | 0;
	                    if (d[c[n >> 2] >> 0] | 0) {
	                        c[s >> 2] = AQ(p, c[m >> 2] | 0, (c[n >> 2] | 0) - (c[m >> 2] | 0) | 0) | 0;
	                        c[(c[o >> 2] | 0) + 12 >> 2] = c[s >> 2];
	                        c[(c[o >> 2] | 0) + 16 >> 2] = c[s >> 2];
	                        if (!(c[s >> 2] | 0))break;
	                        c[(c[s >> 2] | 0) + 32 >> 2] = c[(c[o >> 2] | 0) + 32 >> 2];
	                        c[(c[s >> 2] | 0) + 20 >> 2] = c[o >> 2];
	                        break
	                    }
	                    e = Vh(c[p + 8 >> 2] | 0, c[m >> 2] | 0, (c[n >> 2] | 0) - (c[m >> 2] | 0) | 0) | 0;
	                    c[(c[o >> 2] | 0) + 12 >> 2] = e;
	                    c[s >> 2] = c[(c[o >> 2] | 0) + 12 >> 2];
	                    while (1) {
	                        if (!(c[s >> 2] | 0))break a;
	                        c[(c[s >> 2] | 0) + 32 >> 2] = c[(c[o >> 2] | 0) + 32 >> 2];
	                        c[(c[s >> 2] | 0) + 20 >> 2] = c[o >> 2];
	                        if (!(c[(c[s >> 2] | 0) + 24 >> 2] | 0))c[(c[o >> 2] | 0) + 16 >> 2] = c[s >> 2];
	                        c[s >> 2] = c[(c[s >> 2] | 0) + 24 >> 2]
	                    }
	                } else x = 30; while (0);
	                if (((x | 0) == 30 ? (c[m >> 2] | 0) != 0 : 0) ? (c[t >> 2] = AQ(c[j >> 2] | 0, c[m >> 2] | 0, (c[n >> 2] | 0) - (c[m >> 2] | 0) | 0) | 0, c[(c[o >> 2] | 0) + 12 >> 2] = c[t >> 2], c[(c[o >> 2] | 0) + 16 >> 2] = c[t >> 2], (c[t >> 2] | 0) != 0) : 0) {
	                    c[(c[t >> 2] | 0) + 32 >> 2] = c[(c[o >> 2] | 0) + 32 >> 2];
	                    c[(c[t >> 2] | 0) + 20 >> 2] = c[o >> 2]
	                }
	                do if (((((c[(c[j >> 2] | 0) + 32 >> 2] | 0) == 0 ? (c[(c[j >> 2] | 0) + 104 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (c[(c[(c[j >> 2] | 0) + 8 >> 2] | 0) + 44 >> 2] | 0) != 0 : 0) {
	                    if (c[(c[j >> 2] | 0) + 16 >> 2] | 0) {
	                        c[q >> 2] = ly(c[m >> 2] | 0, (c[n >> 2] | 0) - (c[m >> 2] | 0) | 0) | 0;
	                        t = Wm((c[j >> 2] | 0) + 108 | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[(c[j >> 2] | 0) + 52 >> 2] | 0, c[o >> 2] | 0, c[q >> 2] | 0) | 0;
	                        s = (c[j >> 2] | 0) + 100 | 0;
	                        c[s >> 2] = c[s >> 2] & t;
	                        break
	                    }
	                    c[q >> 2] = CQ(c[j >> 2] | 0, c[m >> 2] | 0, c[n >> 2] | 0) | 0;
	                    if (!(c[q >> 2] | 0))if (!(d[c[n >> 2] >> 0] | 0)) {
	                        t = Wm((c[j >> 2] | 0) + 108 | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[(c[j >> 2] | 0) + 52 >> 2] | 0, c[o >> 2] | 0, c[m >> 2] | 0) | 0;
	                        s = (c[j >> 2] | 0) + 100 | 0;
	                        c[s >> 2] = c[s >> 2] & t;
	                        break
	                    } else {
	                        c[q >> 2] = ly(c[m >> 2] | 0, (c[n >> 2] | 0) - (c[m >> 2] | 0) | 0) | 0;
	                        t = Wm((c[j >> 2] | 0) + 108 | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[(c[j >> 2] | 0) + 52 >> 2] | 0, c[o >> 2] | 0, c[q >> 2] | 0) | 0;
	                        s = (c[j >> 2] | 0) + 100 | 0;
	                        c[s >> 2] = c[s >> 2] & t;
	                        break
	                    }
	                    if ((c[(c[j >> 2] | 0) + 352 >> 2] | 0) != 0 ? (c[w >> 2] = Bh(c[k >> 2] | 0, c[l >> 2] | 0, v, 50) | 0, (c[w >> 2] | 0) != 0) : 0) {
	                        c[(c[j >> 2] | 0) + 144 >> 2] = 1;
	                        c[u >> 2] = Sm((c[j >> 2] | 0) + 108 | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[(c[j >> 2] | 0) + 52 >> 2] | 0, c[w >> 2] | 0, c[q >> 2] | 0) | 0;
	                        if ((c[(c[j >> 2] | 0) + 144 >> 2] | 0) != 1)c[(c[j >> 2] | 0) + 100 >> 2] = 0;
	                        if ((c[w >> 2] | 0) != (v | 0) ? (c[w >> 2] | 0) != (c[k >> 2] | 0) : 0)zb[c[135736 >> 2] & 511](c[w >> 2] | 0);
	                        if (c[u >> 2] | 0) {
	                            zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                            c[q >> 2] = c[u >> 2]
	                        }
	                    }
	                    t = Wm((c[j >> 2] | 0) + 108 | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[(c[j >> 2] | 0) + 52 >> 2] | 0, c[o >> 2] | 0, c[q >> 2] | 0) | 0;
	                    s = (c[j >> 2] | 0) + 100 | 0;
	                    c[s >> 2] = c[s >> 2] & t
	                } else x = 54; while (0);
	                do if ((x | 0) == 54 ? (c[(c[j >> 2] | 0) + 276 >> 2] & 8 | 0) == 0 : 0) {
	                    if (!((c[(c[j >> 2] | 0) + 16 >> 2] | 0) == 0 ? (c[(c[j >> 2] | 0) + 96 >> 2] | 0) != 2 : 0)) {
	                        if (!(c[(c[j >> 2] | 0) + 16 >> 2] | 0))break;
	                        if (c[(c[j >> 2] | 0) + 216 >> 2] | 0)break
	                    }
	                    if ((((c[l >> 2] | 0) == (c[(c[j >> 2] | 0) + 312 >> 2] | 0) ? (d[c[k >> 2] >> 0] | 0 | 0) == 105 : 0) ? (d[(c[k >> 2] | 0) + 1 >> 0] | 0 | 0) == 100 : 0) ? (d[(c[k >> 2] | 0) + 2 >> 0] | 0 | 0) == 0 : 0) {
	                        if (!(c[q >> 2] | 0))c[q >> 2] = ly(c[m >> 2] | 0, (c[n >> 2] | 0) - (c[m >> 2] | 0) | 0) | 0;
	                        if (Eh(c[q >> 2] | 0, 1) | 0)vQ(c[j >> 2] | 0, 539, 198200, c[q >> 2] | 0, 0);
	                        Cm((c[j >> 2] | 0) + 108 | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[q >> 2] | 0, c[o >> 2] | 0) | 0;
	                        break
	                    }
	                    if (Em(c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[(c[j >> 2] | 0) + 52 >> 2] | 0, c[o >> 2] | 0) | 0) {
	                        if (!(c[q >> 2] | 0))c[q >> 2] = ly(c[m >> 2] | 0, (c[n >> 2] | 0) - (c[m >> 2] | 0) | 0) | 0;
	                        Cm((c[j >> 2] | 0) + 108 | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[q >> 2] | 0, c[o >> 2] | 0) | 0;
	                        break
	                    }
	                    if (Km(c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[(c[j >> 2] | 0) + 52 >> 2] | 0, c[o >> 2] | 0) | 0) {
	                        if (!(c[q >> 2] | 0))c[q >> 2] = ly(c[m >> 2] | 0, (c[n >> 2] | 0) - (c[m >> 2] | 0) | 0) | 0;
	                        Im((c[j >> 2] | 0) + 108 | 0, c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[q >> 2] | 0, c[o >> 2] | 0) | 0
	                    }
	                } while (0);
	                if (!(c[q >> 2] | 0)) {
	                    i = h;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[q >> 2] | 0);
	                i = h;
	                return
	            }

	            function AQ(e, f, g) {
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h + 28 | 0;
	                k = h + 24 | 0;
	                l = h + 20 | 0;
	                m = h + 16 | 0;
	                n = h + 12 | 0;
	                o = h + 8 | 0;
	                p = h + 32 | 0;
	                q = h + 4 | 0;
	                r = h;
	                c[k >> 2] = e;
	                c[l >> 2] = f;
	                c[m >> 2] = g;
	                c[o >> 2] = 0;
	                if (c[(c[k >> 2] | 0) + 372 >> 2] | 0) {
	                    c[n >> 2] = c[(c[k >> 2] | 0) + 372 >> 2];
	                    c[(c[k >> 2] | 0) + 372 >> 2] = c[(c[n >> 2] | 0) + 24 >> 2];
	                    g = (c[k >> 2] | 0) + 368 | 0;
	                    c[g >> 2] = (c[g >> 2] | 0) + -1
	                } else c[n >> 2] = Cb[c[135744 >> 2] & 511](60) | 0;
	                if (!(c[n >> 2] | 0)) {
	                    ie(c[k >> 2] | 0, 198e3);
	                    c[j >> 2] = 0;
	                    s = c[j >> 2] | 0;
	                    i = h;
	                    return s | 0
	                }
	                g = (c[n >> 2] | 0) + 0 | 0;
	                f = g + 60 | 0;
	                do {
	                    c[g >> 2] = 0;
	                    g = g + 4 | 0
	                } while ((g | 0) < (f | 0));
	                a:do if (c[(c[k >> 2] | 0) + 364 >> 2] | 0) {
	                    a[p >> 0] = a[(c[l >> 2] | 0) + (c[m >> 2] | 0) >> 0] | 0;
	                    if ((c[m >> 2] | 0) < 8 ? (c[(c[k >> 2] | 0) + 360 >> 2] & 65536 | 0) != 0 : 0) {
	                        c[q >> 2] = (c[n >> 2] | 0) + 44;
	                        eU(c[q >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0) | 0;
	                        a[(c[q >> 2] | 0) + (c[m >> 2] | 0) >> 0] = 0;
	                        c[o >> 2] = c[q >> 2];
	                        break
	                    }
	                    do if ((c[m >> 2] | 0) <= 3) {
	                        if ((d[p >> 0] | 0 | 0) != 34 ? (d[p >> 0] | 0 | 0) != 39 : 0) {
	                            if ((d[p >> 0] | 0 | 0) != 60)break;
	                            if ((d[(c[l >> 2] | 0) + ((c[m >> 2] | 0) + 1) >> 0] | 0 | 0) == 33)break
	                        }
	                        c[o >> 2] = AP(c[(c[k >> 2] | 0) + 296 >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0) | 0;
	                        break a
	                    } while (0);
	                    do if ((d[c[l >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[l >> 2] >> 0] | 0 | 0) ? (d[c[l >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            t = 20;
	                            break
	                        }
	                        if (!((c[m >> 2] | 0) < 60 ? (d[c[l >> 2] >> 0] | 0 | 0) == 13 : 0))break a
	                    } else t = 20; while (0);
	                    if ((t | 0) == 20 ? (c[m >> 2] | 0) >= 60 : 0)break;
	                    if ((d[p >> 0] | 0 | 0) == 60 ? (d[(c[l >> 2] | 0) + ((c[m >> 2] | 0) + 1) >> 0] | 0 | 0) != 33 : 0) {
	                        c[r >> 2] = 1;
	                        while (1) {
	                            if ((c[r >> 2] | 0) >= (c[m >> 2] | 0))break;
	                            do if ((d[(c[l >> 2] | 0) + (c[r >> 2] | 0) >> 0] | 0 | 0) != 32) {
	                                if (9 <= (d[(c[l >> 2] | 0) + (c[r >> 2] | 0) >> 0] | 0 | 0) ? (d[(c[l >> 2] | 0) + (c[r >> 2] | 0) >> 0] | 0 | 0) <= 10 : 0)break;
	                                if ((d[(c[l >> 2] | 0) + (c[r >> 2] | 0) >> 0] | 0 | 0) != 13)break a
	                            } while (0);
	                            c[r >> 2] = (c[r >> 2] | 0) + 1
	                        }
	                        c[o >> 2] = AP(c[(c[k >> 2] | 0) + 296 >> 2] | 0, c[l >> 2] | 0, c[m >> 2] | 0) | 0
	                    }
	                } while (0);
	                c[(c[n >> 2] | 0) + 4 >> 2] = 3;
	                c[(c[n >> 2] | 0) + 8 >> 2] = 75104;
	                if (!(c[o >> 2] | 0)) {
	                    r = ly(c[l >> 2] | 0, c[m >> 2] | 0) | 0;
	                    c[(c[n >> 2] | 0) + 40 >> 2] = r;
	                    if (!(c[(c[n >> 2] | 0) + 40 >> 2] | 0)) {
	                        sQ(c[k >> 2] | 0, 198160);
	                        zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                        c[j >> 2] = 0;
	                        s = c[j >> 2] | 0;
	                        i = h;
	                        return s | 0
	                    }
	                } else c[(c[n >> 2] | 0) + 40 >> 2] = c[o >> 2];
	                do if ((c[(c[k >> 2] | 0) + 280 >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) {
	                    if ((c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2] | 0) < 65535) {
	                        b[(c[n >> 2] | 0) + 56 >> 1] = c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2];
	                        break
	                    }
	                    b[(c[n >> 2] | 0) + 56 >> 1] = -1;
	                    if (c[(c[k >> 2] | 0) + 360 >> 2] & 4194304)c[(c[n >> 2] | 0) + 52 >> 2] = c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 28 >> 2]
	                } while (0);
	                if ((c[18774] | 0) != 0 & (c[33968] | 0) != 0)zb[c[135872 >> 2] & 511](c[n >> 2] | 0);
	                c[j >> 2] = c[n >> 2];
	                s = c[j >> 2] | 0;
	                i = h;
	                return s | 0
	            }

	            function BQ(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g;
	                j = g + 24 | 0;
	                k = g + 20 | 0;
	                l = g + 16 | 0;
	                m = g + 12 | 0;
	                n = g + 8 | 0;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                if (((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 212 >> 2] | 0) != 0 : 0) ? (c[(c[j >> 2] | 0) + 172 >> 2] | 0) == -1 : 0) {
	                    i = g;
	                    return
	                }
	                if (c[j >> 2] | 0)c[(c[j >> 2] | 0) + 84 >> 2] = c[k >> 2];
	                f = c[j >> 2] | 0;
	                j = c[k >> 2] | 0;
	                k = c[m >> 2] | 0;
	                e = c[n >> 2] | 0;
	                d = c[l >> 2] | 0;
	                l = c[n >> 2] | 0;
	                c[h >> 2] = c[m >> 2];
	                c[h + 4 >> 2] = l;
	                Xd(0, 0, 0, f, 0, 3, j, 2, 0, 0, k, e, 0, 0, 0, d, h);
	                i = g;
	                return
	            }

	            function CQ(a, b, e) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 20 | 0;
	                h = f + 16 | 0;
	                j = f + 12 | 0;
	                k = f + 8 | 0;
	                l = f + 4 | 0;
	                m = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[l >> 2] = c[j >> 2];
	                while (1) {
	                    if ((c[l >> 2] | 0) >>> 0 >= (c[k >> 2] | 0) >>> 0) {
	                        n = 4;
	                        break
	                    }
	                    e = c[l >> 2] | 0;
	                    c[l >> 2] = e + 1;
	                    if ((d[e >> 0] | 0 | 0) == 38) {
	                        n = 5;
	                        break
	                    }
	                }
	                if ((n | 0) == 4) {
	                    c[g >> 2] = 0;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                } else if ((n | 0) == 5) {
	                    n = (c[h >> 2] | 0) + 248 | 0;
	                    c[n >> 2] = (c[n >> 2] | 0) + 1;
	                    c[m >> 2] = $e(c[h >> 2] | 0, c[j >> 2] | 0, (c[k >> 2] | 0) - (c[j >> 2] | 0) | 0, 1, 0, 0, 0) | 0;
	                    j = (c[h >> 2] | 0) + 248 | 0;
	                    c[j >> 2] = (c[j >> 2] | 0) + -1;
	                    c[g >> 2] = c[m >> 2];
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                return 0
	            }

	            function DQ(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                d = i;
	                i = i + 32 | 0;
	                f = d + 28 | 0;
	                g = d + 24 | 0;
	                h = d + 20 | 0;
	                j = d + 16 | 0;
	                k = d + 12 | 0;
	                l = d + 8 | 0;
	                m = d + 4 | 0;
	                n = d;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    o = c[f >> 2] | 0;
	                    i = d;
	                    return o | 0
	                }
	                b = c[h >> 2] | 0;
	                a:do if ((c[g >> 2] | 0) >>> 0 < 65536) {
	                    if (!(c[b >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        o = c[f >> 2] | 0;
	                        i = d;
	                        return o | 0
	                    }
	                    c[j >> 2] = 0;
	                    c[k >> 2] = (c[c[h >> 2] >> 2] | 0) - 1;
	                    c[m >> 2] = c[(c[h >> 2] | 0) + 8 >> 2];
	                    while (1) {
	                        if ((c[j >> 2] | 0) > (c[k >> 2] | 0))break a;
	                        c[l >> 2] = ((c[j >> 2] | 0) + (c[k >> 2] | 0) | 0) / 2 | 0;
	                        if ((c[g >> 2] & 65535 | 0) < (e[(c[m >> 2] | 0) + (c[l >> 2] << 2) >> 1] | 0 | 0)) {
	                            c[k >> 2] = (c[l >> 2] | 0) - 1;
	                            continue
	                        }
	                        if ((c[g >> 2] & 65535 | 0) <= (e[(c[m >> 2] | 0) + (c[l >> 2] << 2) + 2 >> 1] | 0 | 0))break;
	                        c[j >> 2] = (c[l >> 2] | 0) + 1
	                    }
	                    c[f >> 2] = 1;
	                    o = c[f >> 2] | 0;
	                    i = d;
	                    return o | 0
	                } else {
	                    if (!(c[b + 4 >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        o = c[f >> 2] | 0;
	                        i = d;
	                        return o | 0
	                    }
	                    c[j >> 2] = 0;
	                    c[k >> 2] = (c[(c[h >> 2] | 0) + 4 >> 2] | 0) - 1;
	                    c[n >> 2] = c[(c[h >> 2] | 0) + 12 >> 2];
	                    while (1) {
	                        if ((c[j >> 2] | 0) > (c[k >> 2] | 0))break a;
	                        c[l >> 2] = ((c[j >> 2] | 0) + (c[k >> 2] | 0) | 0) / 2 | 0;
	                        if ((c[g >> 2] | 0) >>> 0 < (c[(c[n >> 2] | 0) + (c[l >> 2] << 3) >> 2] | 0) >>> 0) {
	                            c[k >> 2] = (c[l >> 2] | 0) - 1;
	                            continue
	                        }
	                        if ((c[g >> 2] | 0) >>> 0 <= (c[(c[n >> 2] | 0) + (c[l >> 2] << 3) + 4 >> 2] | 0) >>> 0)break;
	                        c[j >> 2] = (c[l >> 2] | 0) + 1
	                    }
	                    c[f >> 2] = 1;
	                    o = c[f >> 2] | 0;
	                    i = d;
	                    return o | 0
	                } while (0);
	                c[f >> 2] = 0;
	                o = c[f >> 2] | 0;
	                i = d;
	                return o | 0
	            }

	            function EQ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 8 >> 2] | 0)EQ(c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 32 >> 2] | 0)TQ(c[(c[d >> 2] | 0) + 32 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 12 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 12 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 28 >> 2] | 0) {
	                    a:do if (!(c[(c[d >> 2] | 0) + 4 >> 2] | 0)) {
	                        c[f >> 2] = 0;
	                        while (1) {
	                            if ((c[f >> 2] | 0) >= (c[(c[d >> 2] | 0) + 20 >> 2] | 0))break a;
	                            c[e >> 2] = (c[(c[d >> 2] | 0) + 28 >> 2] | 0) + ((c[f >> 2] | 0) * 12 | 0);
	                            if (c[(c[e >> 2] | 0) + 4 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[e >> 2] | 0) + 4 >> 2] | 0);
	                            if (c[(c[e >> 2] | 0) + 8 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[e >> 2] | 0) + 8 >> 2] | 0);
	                            c[f >> 2] = (c[f >> 2] | 0) + 1
	                        }
	                    } while (0);
	                    zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 28 >> 2] | 0)
	                }
	                if (c[(c[d >> 2] | 0) + 4 >> 2] | 0)zP(c[(c[d >> 2] | 0) + 4 >> 2] | 0);
	                f = (c[d >> 2] | 0) + 0 | 0;
	                e = f + 36 | 0;
	                do {
	                    c[f >> 2] = -1;
	                    f = f + 4 | 0
	                } while ((f | 0) < (e | 0));
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function FQ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                while (1) {
	                    if (!(c[d >> 2] | 0))break;
	                    c[e >> 2] = c[d >> 2];
	                    c[d >> 2] = c[(c[d >> 2] | 0) + 8 >> 2];
	                    c[(c[e >> 2] | 0) + 8 >> 2] = 0;
	                    EQ(c[e >> 2] | 0)
	                }
	                i = b;
	                return
	            }

	            function GQ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                while (1) {
	                    if (!(c[d >> 2] | 0))break;
	                    c[e >> 2] = c[c[d >> 2] >> 2];
	                    if (c[(c[d >> 2] | 0) + 20 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 20 >> 2] | 0);
	                    zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                    c[d >> 2] = c[e >> 2]
	                }
	                i = b;
	                return
	            }

	            function HQ(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                d = UQ(c[f >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0, 1) | 0;
	                i = e;
	                return d | 0
	            }

	            function IQ(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 12 | 0;
	                h = f + 8 | 0;
	                j = f + 4 | 0;
	                k = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                e = UQ(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0) | 0;
	                i = f;
	                return e | 0
	            }

	            function JQ(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                d = UQ(c[f >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0, 2) | 0;
	                i = e;
	                return d | 0
	            }

	            function KQ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = -1;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                while (1) {
	                    if (!(c[e >> 2] | 0))break;
	                    if ((c[(c[e >> 2] | 0) + 28 >> 2] | 0) == (c[(c[e >> 2] | 0) + 16 >> 2] | 0))c[(c[e >> 2] | 0) + 28 >> 2] = -1;
	                    if (c[(c[e >> 2] | 0) + 16 >> 2] | 0) {
	                        a = (c[e >> 2] | 0) + 16 | 0;
	                        c[a >> 2] = (c[a >> 2] | 0) + -1
	                    }
	                    c[f >> 2] = (c[(c[e >> 2] | 0) + 8 >> 2] | 0) - 1;
	                    while (1) {
	                        if ((c[f >> 2] | 0) < 0)break;
	                        c[g >> 2] = c[(c[(c[e >> 2] | 0) + 20 >> 2] | 0) + ((c[f >> 2] << 1) + 1 << 2) >> 2];
	                        if ((c[g >> 2] | 0) > (c[(c[e >> 2] | 0) + 16 >> 2] | 0)) {
	                            a = (c[e >> 2] | 0) + 8 | 0;
	                            c[a >> 2] = (c[a >> 2] | 0) + -1
	                        }
	                        if ((c[g >> 2] | 0) <= (c[(c[e >> 2] | 0) + 16 >> 2] | 0))break;
	                        c[f >> 2] = (c[f >> 2] | 0) + -1
	                    }
	                    c[e >> 2] = c[c[e >> 2] >> 2]
	                }
	                c[d >> 2] = 0;
	                h = c[d >> 2] | 0;
	                i = b;
	                return h | 0
	            }

	            function LQ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                do if (c[e >> 2] | 0) {
	                    while (1) {
	                        if (!(c[e >> 2] | 0)) {
	                            f = 7;
	                            break
	                        }
	                        if (c[(c[(c[e >> 2] | 0) + 4 >> 2] | 0) + 16 >> 2] & 16384) {
	                            f = 5;
	                            break
	                        }
	                        c[e >> 2] = c[c[e >> 2] >> 2]
	                    }
	                    if ((f | 0) == 5) {
	                        c[d >> 2] = 1;
	                        break
	                    } else if ((f | 0) == 7) {
	                        c[d >> 2] = 0;
	                        break
	                    }
	                } else c[d >> 2] = -1; while (0);
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function MQ(a, b, e, f) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0;
	                g = i;
	                i = i + 64 | 0;
	                h = g + 48 | 0;
	                j = g + 44 | 0;
	                k = g + 40 | 0;
	                l = g + 36 | 0;
	                m = g + 32 | 0;
	                n = g + 28 | 0;
	                o = g + 24 | 0;
	                p = g + 20 | 0;
	                q = g + 16 | 0;
	                r = g + 12 | 0;
	                s = g + 8 | 0;
	                t = g + 4 | 0;
	                u = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                c[n >> 2] = 0;
	                c[p >> 2] = 0;
	                c[s >> 2] = 0;
	                c[t >> 2] = 0;
	                c[u >> 2] = 1;
	                if (!(c[j >> 2] | 0)) {
	                    c[h >> 2] = 0;
	                    v = c[h >> 2] | 0;
	                    i = g;
	                    return v | 0
	                }
	                c[r >> 2] = c[j >> 2];
	                c[q >> 2] = c[r >> 2];
	                while (1) {
	                    if (!(d[c[q >> 2] >> 0] | 0)) {
	                        w = 41;
	                        break
	                    }
	                    c[s >> 2] = 0;
	                    while (1) {
	                        if (d[c[q >> 2] >> 0] | 0)x = (d[c[q >> 2] >> 0] | 0 | 0) != 124; else x = 0;
	                        y = c[q >> 2] | 0;
	                        if (!x)break;
	                        c[q >> 2] = y + 1
	                    }
	                    j = c[r >> 2] | 0;
	                    if (!(d[y >> 0] | 0))c[p >> 2] = VQ(j, c[k >> 2] | 0, c[m >> 2] | 0) | 0; else {
	                        c[s >> 2] = ly(j, (c[q >> 2] | 0) - (c[r >> 2] | 0) | 0) | 0;
	                        if (c[s >> 2] | 0)c[p >> 2] = VQ(c[s >> 2] | 0, c[k >> 2] | 0, c[m >> 2] | 0) | 0;
	                        c[q >> 2] = (c[q >> 2] | 0) + 1
	                    }
	                    if (!(c[p >> 2] | 0)) {
	                        w = 48;
	                        break
	                    }
	                    c[o >> 2] = WQ() | 0;
	                    if (!(c[o >> 2] | 0)) {
	                        w = 48;
	                        break
	                    }
	                    if (c[k >> 2] | 0) {
	                        c[(c[o >> 2] | 0) + 4 >> 2] = c[k >> 2];
	                        yP(c[k >> 2] | 0) | 0
	                    }
	                    if (!(c[n >> 2] | 0))c[n >> 2] = c[o >> 2]; else {
	                        c[(c[o >> 2] | 0) + 8 >> 2] = c[(c[n >> 2] | 0) + 8 >> 2];
	                        c[(c[n >> 2] | 0) + 8 >> 2] = c[o >> 2]
	                    }
	                    c[(c[o >> 2] | 0) + 16 >> 2] = c[l >> 2];
	                    c[(c[p >> 2] | 0) + 16 >> 2] = c[o >> 2];
	                    j = c[p >> 2] | 0;
	                    if (c[(c[o >> 2] | 0) + 16 >> 2] & 6)XQ(j); else YQ(j);
	                    if (c[(c[p >> 2] | 0) + 8 >> 2] | 0) {
	                        w = 48;
	                        break
	                    }
	                    ZQ(c[p >> 2] | 0);
	                    c[p >> 2] = 0;
	                    do if (c[u >> 2] | 0) {
	                        if (!(c[t >> 2] | 0)) {
	                            c[t >> 2] = c[(c[o >> 2] | 0) + 16 >> 2] & 768;
	                            break
	                        }
	                        if ((c[t >> 2] | 0) == 256) {
	                            if (!(c[(c[o >> 2] | 0) + 16 >> 2] & 512))break;
	                            c[u >> 2] = 0;
	                            break
	                        }
	                        if ((c[t >> 2] | 0) == 512 ? (c[(c[o >> 2] | 0) + 16 >> 2] & 256 | 0) != 0 : 0)c[u >> 2] = 0
	                    } while (0);
	                    if (c[u >> 2] | 0)_Q(c[o >> 2] | 0) | 0;
	                    if (($Q(c[o >> 2] | 0) | 0) < 0) {
	                        w = 48;
	                        break
	                    }
	                    if (c[s >> 2] | 0) {
	                        zb[c[135736 >> 2] & 511](c[s >> 2] | 0);
	                        c[s >> 2] = 0
	                    }
	                    c[r >> 2] = c[q >> 2]
	                }
	                if ((w | 0) == 41) {
	                    a:do if (!(c[u >> 2] | 0)) {
	                        c[o >> 2] = c[n >> 2];
	                        while (1) {
	                            if (!(c[o >> 2] | 0))break a;
	                            if (c[(c[o >> 2] | 0) + 32 >> 2] | 0) {
	                                TQ(c[(c[o >> 2] | 0) + 32 >> 2] | 0);
	                                c[(c[o >> 2] | 0) + 32 >> 2] = 0
	                            }
	                            c[o >> 2] = c[(c[o >> 2] | 0) + 8 >> 2]
	                        }
	                    } while (0);
	                    c[h >> 2] = c[n >> 2];
	                    v = c[h >> 2] | 0;
	                    i = g;
	                    return v | 0
	                } else if ((w | 0) == 48) {
	                    if (c[p >> 2] | 0)ZQ(c[p >> 2] | 0);
	                    if (c[n >> 2] | 0)EQ(c[n >> 2] | 0);
	                    if (c[s >> 2] | 0)zb[c[135736 >> 2] & 511](c[s >> 2] | 0);
	                    c[h >> 2] = 0;
	                    v = c[h >> 2] | 0;
	                    i = g;
	                    return v | 0
	                }
	                return 0
	            }

	            function NQ(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = -1;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                while (1) {
	                    if (!(c[f >> 2] | 0)) {
	                        k = 7;
	                        break
	                    }
	                    c[h >> 2] = aR(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                    if (c[h >> 2] | 0) {
	                        k = 5;
	                        break
	                    }
	                    c[f >> 2] = c[(c[f >> 2] | 0) + 8 >> 2]
	                }
	                if ((k | 0) == 5) {
	                    c[e >> 2] = c[h >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } else if ((k | 0) == 7) {
	                    c[e >> 2] = c[h >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                return 0
	            }

	            function OQ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 32 >> 2] | 0) != 0 : 0) {
	                    while (1) {
	                        if (!(c[e >> 2] | 0)) {
	                            h = 11;
	                            break
	                        }
	                        if (!(c[(c[e >> 2] | 0) + 32 >> 2] | 0)) {
	                            h = 12;
	                            break
	                        }
	                        c[g >> 2] = bR(c[(c[e >> 2] | 0) + 32 >> 2] | 0) | 0;
	                        if (!(c[g >> 2] | 0)) {
	                            h = 12;
	                            break
	                        }
	                        if (!(c[f >> 2] | 0))c[f >> 2] = c[g >> 2]; else {
	                            c[c[g >> 2] >> 2] = c[c[f >> 2] >> 2];
	                            c[c[f >> 2] >> 2] = c[g >> 2]
	                        }
	                        c[(c[g >> 2] | 0) + 24 >> 2] = c[(c[e >> 2] | 0) + 16 >> 2];
	                        c[e >> 2] = c[(c[e >> 2] | 0) + 8 >> 2]
	                    }
	                    if ((h | 0) == 11) {
	                        c[d >> 2] = c[f >> 2];
	                        j = c[d >> 2] | 0;
	                        i = b;
	                        return j | 0
	                    } else if ((h | 0) == 12) {
	                        GQ(c[f >> 2] | 0);
	                        c[d >> 2] = 0;
	                        j = c[d >> 2] | 0;
	                        i = b;
	                        return j | 0
	                    }
	                }
	                c[d >> 2] = 0;
	                j = c[d >> 2] | 0;
	                i = b;
	                return j | 0
	            }

	            function PQ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                do if (c[e >> 2] | 0) {
	                    while (1) {
	                        if (!(c[e >> 2] | 0)) {
	                            f = 7;
	                            break
	                        }
	                        if (!(c[(c[e >> 2] | 0) + 32 >> 2] | 0)) {
	                            f = 5;
	                            break
	                        }
	                        c[e >> 2] = c[(c[e >> 2] | 0) + 8 >> 2]
	                    }
	                    if ((f | 0) == 5) {
	                        c[d >> 2] = 0;
	                        break
	                    } else if ((f | 0) == 7) {
	                        c[d >> 2] = 1;
	                        break
	                    }
	                } else c[d >> 2] = -1; while (0);
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function QQ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 12 | 0;
	                e = b + 8 | 0;
	                f = b + 4 | 0;
	                g = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = -1;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                a:while (1) {
	                    if (!(c[e >> 2] | 0)) {
	                        j = 14;
	                        break
	                    }
	                    if (!(c[(c[e >> 2] | 0) + 32 >> 2] | 0)) {
	                        j = 5;
	                        break
	                    }
	                    c[g >> 2] = 0;
	                    while (1) {
	                        if ((c[g >> 2] | 0) >= (c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 4 >> 2] | 0))break;
	                        if (c[(c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 12 >> 2] | 0) + (c[g >> 2] << 4) >> 2] & 1) {
	                            j = 9;
	                            break a
	                        }
	                        c[g >> 2] = (c[g >> 2] | 0) + 1
	                    }
	                    if ((c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 4 >> 2] | 0) > (c[f >> 2] | 0))c[f >> 2] = c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 4 >> 2];
	                    c[e >> 2] = c[(c[e >> 2] | 0) + 8 >> 2]
	                }
	                if ((j | 0) == 5) {
	                    c[d >> 2] = -1;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                } else if ((j | 0) == 9) {
	                    c[d >> 2] = -2;
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                } else if ((j | 0) == 14) {
	                    c[d >> 2] = c[f >> 2];
	                    h = c[d >> 2] | 0;
	                    i = b;
	                    return h | 0
	                }
	                return 0
	            }

	            function RQ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 12345678;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = -1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                while (1) {
	                    if (!(c[e >> 2] | 0)) {
	                        h = 11;
	                        break
	                    }
	                    if (!(c[(c[e >> 2] | 0) + 32 >> 2] | 0)) {
	                        h = 5;
	                        break
	                    }
	                    if ((c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 4 >> 2] | 0) < (c[f >> 2] | 0))c[f >> 2] = c[(c[(c[e >> 2] | 0) + 32 >> 2] | 0) + 4 >> 2];
	                    if (!(c[f >> 2] | 0)) {
	                        h = 9;
	                        break
	                    }
	                    c[e >> 2] = c[(c[e >> 2] | 0) + 8 >> 2]
	                }
	                if ((h | 0) == 5) {
	                    c[d >> 2] = -1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else if ((h | 0) == 9) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else if ((h | 0) == 11) {
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function SQ(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                do if (c[e >> 2] | 0) {
	                    while (1) {
	                        if (!(c[e >> 2] | 0)) {
	                            f = 9;
	                            break
	                        }
	                        if (!(c[(c[e >> 2] | 0) + 32 >> 2] | 0)) {
	                            f = 5;
	                            break
	                        }
	                        if (c[(c[e >> 2] | 0) + 16 >> 2] & 256) {
	                            f = 7;
	                            break
	                        }
	                        c[e >> 2] = c[(c[e >> 2] | 0) + 8 >> 2]
	                    }
	                    if ((f | 0) == 5) {
	                        c[d >> 2] = -1;
	                        break
	                    } else if ((f | 0) == 7) {
	                        c[d >> 2] = 1;
	                        break
	                    } else if ((f | 0) == 9) {
	                        c[d >> 2] = 0;
	                        break
	                    }
	                } else c[d >> 2] = -1; while (0);
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function TQ(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 12 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 12 >> 2] | 0);
	                if (c[c[d >> 2] >> 2] | 0)zP(c[c[d >> 2] >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function UQ(a, b, e, f) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0;
	                g = i;
	                i = i + 80 | 0;
	                h = g + 72 | 0;
	                j = g + 68 | 0;
	                k = g + 64 | 0;
	                l = g + 60 | 0;
	                m = g + 56 | 0;
	                n = g + 52 | 0;
	                o = g + 48 | 0;
	                p = g + 44 | 0;
	                q = g + 40 | 0;
	                r = g + 36 | 0;
	                s = g + 32 | 0;
	                t = g + 28 | 0;
	                u = g + 24 | 0;
	                v = g + 20 | 0;
	                w = g + 16 | 0;
	                x = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                c[n >> 2] = 0;
	                c[o >> 2] = 0;
	                c[p >> 2] = 0;
	                if ((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 8 >> 2] | 0) >= 0 : 0) {
	                    a:while (1) {
	                        if (!(c[j >> 2] | 0))break;
	                        c[w >> 2] = c[(c[j >> 2] | 0) + 4 >> 2];
	                        if ((c[m >> 2] | 0) == 1 & (c[k >> 2] | 0) == 0 & (c[l >> 2] | 0) == 0) {
	                            c[(c[j >> 2] | 0) + 8 >> 2] = 0;
	                            c[(c[j >> 2] | 0) + 16 >> 2] = 0;
	                            c[(c[j >> 2] | 0) + 28 >> 2] = -1;
	                            do if (c[(c[w >> 2] | 0) + 16 >> 2] & 32768) {
	                                if (!(c[(c[w >> 2] | 0) + 4 >> 2] | 0)) {
	                                    c[n >> 2] = 1;
	                                    break
	                                }
	                                if (((c[(c[w >> 2] | 0) + 4 >> 2] | 0) == 1 ? (c[(c[(c[w >> 2] | 0) + 12 >> 2] | 0) + 12 >> 2] | 0) == 100 : 0) ? (c[c[(c[w >> 2] | 0) + 12 >> 2] >> 2] & 1 | 0) != 0 : 0) {
	                                    c[n >> 2] = 1;
	                                    break
	                                }
	                                if ((c[c[(c[w >> 2] | 0) + 12 >> 2] >> 2] & 4 | 0) != 0 ? (c[q >> 2] = cR(c[j >> 2] | 0, 0, 0) | 0, (c[q >> 2] | 0) < 0) : 0)c[o >> 2] = (c[o >> 2] | 0) + 1
	                            } while (0);
	                            c[j >> 2] = c[c[j >> 2] >> 2];
	                            continue
	                        }
	                        f = c[j >> 2] | 0;
	                        b:do if (c[(c[w >> 2] | 0) + 4 >> 2] | 0) {
	                            if ((c[f + 28 >> 2] | 0) != -1) {
	                                e = (c[j >> 2] | 0) + 16 | 0;
	                                c[e >> 2] = (c[e >> 2] | 0) + 1;
	                                break
	                            }
	                            if ((c[m >> 2] | 0) != 1 & (c[m >> 2] | 0) != 2 ? (c[(c[w >> 2] | 0) + 16 >> 2] & 16384 | 0) == 0 : 0) {
	                                e = (c[j >> 2] | 0) + 16 | 0;
	                                c[e >> 2] = (c[e >> 2] | 0) + 1;
	                                break
	                            }
	                            c[r >> 2] = 0;
	                            c[s >> 2] = c[(c[j >> 2] | 0) + 8 >> 2];
	                            while (1) {
	                                if ((c[r >> 2] | 0) >= (c[s >> 2] | 0))break;
	                                if (c[(c[w >> 2] | 0) + 16 >> 2] & 65536) {
	                                    c[u >> 2] = c[(c[(c[j >> 2] | 0) + 20 >> 2] | 0) + (c[r >> 2] << 1 << 2) >> 2];
	                                    if (((c[u >> 2] | 0) >= 0 ? (c[q >> 2] = c[(c[(c[j >> 2] | 0) + 20 >> 2] | 0) + ((c[r >> 2] << 1) + 1 << 2) >> 2], (c[q >> 2] | 0) <= (c[(c[j >> 2] | 0) + 16 >> 2] | 0)) : 0) ? (c[v >> 2] = c[(c[(c[w >> 2] | 0) + 12 >> 2] | 0) + (c[u >> 2] << 4) >> 2] & 1, (c[v >> 2] | 0) != 0 ? 1 : (c[q >> 2] | 0) >= (c[(c[j >> 2] | 0) + 16 >> 2] | 0)) : 0)y = 39
	                                } else {
	                                    c[u >> 2] = c[(c[(c[j >> 2] | 0) + 20 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 8 >> 2] | 0) - 1 << 1 << 2) >> 2];
	                                    if ((c[(c[(c[j >> 2] | 0) + 20 >> 2] | 0) + (((c[(c[j >> 2] | 0) + 8 >> 2] | 0) - 1 << 1) + 1 << 2) >> 2] | 0) < (c[(c[j >> 2] | 0) + 16 >> 2] | 0)) {
	                                        y = 34;
	                                        break a
	                                    }
	                                    c[v >> 2] = 0;
	                                    c[r >> 2] = c[s >> 2];
	                                    y = 39
	                                }
	                                c:do if ((y | 0) == 39) {
	                                    y = 0;
	                                    e = (c[(c[w >> 2] | 0) + 12 >> 2] | 0) + (c[u >> 2] << 4) | 0;
	                                    c[x + 0 >> 2] = c[e + 0 >> 2];
	                                    c[x + 4 >> 2] = c[e + 4 >> 2];
	                                    c[x + 8 >> 2] = c[e + 8 >> 2];
	                                    c[x + 12 >> 2] = c[e + 12 >> 2];
	                                    do if ((c[x + 12 >> 2] | 0) != (c[m >> 2] | 0)) {
	                                        if ((c[x + 12 >> 2] | 0) != 2)if ((c[x + 12 >> 2] | 0) != 100)break c; else break;
	                                        if (c[(c[w >> 2] | 0) + 16 >> 2] & 65536)break c;
	                                        c[(c[j >> 2] | 0) + 28 >> 2] = (c[(c[j >> 2] | 0) + 16 >> 2] | 0) + 1;
	                                        break c
	                                    } while (0);
	                                    c[t >> 2] = 0;
	                                    do if ((c[x + 12 >> 2] | 0) != 100) {
	                                        e = c[x + 8 >> 2] | 0;
	                                        if (!(c[x + 4 >> 2] | 0)) {
	                                            if (!e) {
	                                                c[t >> 2] = 1;
	                                                break
	                                            }
	                                            if (!(c[l >> 2] | 0))break;
	                                            c[t >> 2] = qy(c[x + 8 >> 2] | 0, c[l >> 2] | 0) | 0;
	                                            break
	                                        }
	                                        if (((c[k >> 2] | 0) != 0 ? ((e | 0) != 0 | 0) == ((c[l >> 2] | 0) != 0 | 0) : 0) ? (d[c[x + 4 >> 2] >> 0] | 0 | 0) == (d[c[k >> 2] >> 0] | 0 | 0) : 0) {
	                                            if (!(qy(c[x + 4 >> 2] | 0, c[k >> 2] | 0) | 0))break;
	                                            if ((c[x + 8 >> 2] | 0) != (c[l >> 2] | 0) ? (qy(c[x + 8 >> 2] | 0, c[l >> 2] | 0) | 0) == 0 : 0)break;
	                                            c[t >> 2] = 1
	                                        }
	                                    } else c[t >> 2] = 1; while (0);
	                                    do if (c[t >> 2] | 0) {
	                                        c[p >> 2] = c[x >> 2] & 2;
	                                        e = (c[p >> 2] | 0) != 0;
	                                        do if (c[v >> 2] | 0)if (e) {
	                                            c[n >> 2] = 1;
	                                            break
	                                        } else {
	                                            cR(c[j >> 2] | 0, (c[u >> 2] | 0) + 1 | 0, (c[(c[j >> 2] | 0) + 16 >> 2] | 0) + 1 | 0) | 0;
	                                            break
	                                        } else if (e) {
	                                            c[n >> 2] = 1;
	                                            break
	                                        } else {
	                                            cR(c[j >> 2] | 0, (c[u >> 2] | 0) + 1 | 0, (c[(c[j >> 2] | 0) + 16 >> 2] | 0) + 1 | 0) | 0;
	                                            break
	                                        } while (0);
	                                        if ((c[n >> 2] | 0) != 1) {
	                                            if (!(c[x >> 2] & 32))break;
	                                            c[n >> 2] = 1
	                                        }
	                                    } while (0);
	                                    if ((c[(c[w >> 2] | 0) + 16 >> 2] & 65536 | 0) == 0 ? (c[t >> 2] | 0) == 0 | (c[p >> 2] | 0) != 0 : 0)c[(c[j >> 2] | 0) + 28 >> 2] = (c[(c[j >> 2] | 0) + 16 >> 2] | 0) + 1
	                                } while (0);
	                                c[r >> 2] = (c[r >> 2] | 0) + 1
	                            }
	                            e = (c[j >> 2] | 0) + 16 | 0;
	                            c[e >> 2] = (c[e >> 2] | 0) + 1;
	                            e = c[(c[w >> 2] | 0) + 12 >> 2] | 0;
	                            c[x + 0 >> 2] = c[e + 0 >> 2];
	                            c[x + 4 >> 2] = c[e + 4 >> 2];
	                            c[x + 8 >> 2] = c[e + 8 >> 2];
	                            c[x + 12 >> 2] = c[e + 12 >> 2];
	                            if (!(c[x >> 2] & 4)) {
	                                c[v >> 2] = c[x >> 2] & 1;
	                                do if (c[(c[j >> 2] | 0) + 24 >> 2] & 7) {
	                                    if ((c[(c[j >> 2] | 0) + 16 >> 2] | 0) == 1)if (c[(c[j >> 2] | 0) + 24 >> 2] & 6)break b; else break;
	                                    if (!(c[v >> 2] | 0)) {
	                                        if ((c[(c[j >> 2] | 0) + 16 >> 2] | 0) != 2)break b;
	                                        if (!(c[(c[j >> 2] | 0) + 24 >> 2] & 6))break b
	                                    }
	                                } while (0);
	                                if ((c[x + 12 >> 2] | 0) != (c[m >> 2] | 0)) {
	                                    if ((c[m >> 2] | 0) == 2)break;
	                                    if ((c[x + 12 >> 2] | 0) != 100)break
	                                }
	                                c[t >> 2] = 0;
	                                do if ((c[x + 12 >> 2] | 0) != 100) {
	                                    e = c[x + 8 >> 2] | 0;
	                                    if (!(c[x + 4 >> 2] | 0)) {
	                                        if (!e) {
	                                            c[t >> 2] = 1;
	                                            break
	                                        }
	                                        if (!(c[l >> 2] | 0))break;
	                                        c[t >> 2] = qy(c[x + 8 >> 2] | 0, c[l >> 2] | 0) | 0;
	                                        break
	                                    }
	                                    if ((((c[k >> 2] | 0) != 0 ? ((e | 0) != 0 | 0) == ((c[l >> 2] | 0) != 0 | 0) : 0) ? (d[c[x + 4 >> 2] >> 0] | 0 | 0) == (d[c[k >> 2] >> 0] | 0 | 0) : 0) ? (qy(c[x + 4 >> 2] | 0, c[k >> 2] | 0) | 0) != 0 : 0) {
	                                        if ((c[x + 8 >> 2] | 0) != (c[l >> 2] | 0) ? (qy(c[x + 8 >> 2] | 0, c[l >> 2] | 0) | 0) == 0 : 0)break;
	                                        c[t >> 2] = 1
	                                    }
	                                } else c[t >> 2] = 1; while (0);
	                                c[p >> 2] = c[x >> 2] & 2;
	                                if (c[t >> 2] | 0) {
	                                    if (c[p >> 2] | 0)c[n >> 2] = 1; else cR(c[j >> 2] | 0, 1, c[(c[j >> 2] | 0) + 16 >> 2] | 0) | 0;
	                                    if ((c[n >> 2] | 0) != 1 ? (c[x >> 2] & 32 | 0) != 0 : 0)c[n >> 2] = 1
	                                }
	                                if ((c[(c[w >> 2] | 0) + 16 >> 2] & 65536 | 0) == 0 ? (c[t >> 2] | 0) == 0 | (c[p >> 2] | 0) != 0 : 0)c[(c[j >> 2] | 0) + 28 >> 2] = c[(c[j >> 2] | 0) + 16 >> 2]
	                            }
	                        } else {
	                            if (c[f + 24 >> 2] & 1) {
	                                c[j >> 2] = c[c[j >> 2] >> 2];
	                                continue a
	                            }
	                            do if ((c[m >> 2] | 0) != 2) {
	                                if ((c[(c[j >> 2] | 0) + 24 >> 2] & 7 | 0) != 0 ? (c[(c[j >> 2] | 0) + 16 >> 2] | 0) != 0 : 0)break;
	                                c[n >> 2] = 1
	                            } while (0);
	                            e = (c[j >> 2] | 0) + 16 | 0;
	                            c[e >> 2] = (c[e >> 2] | 0) + 1
	                        } while (0);
	                        c[j >> 2] = c[c[j >> 2] >> 2]
	                    }
	                    if ((y | 0) == 34) {
	                        c[h >> 2] = -1;
	                        z = c[h >> 2] | 0;
	                        i = g;
	                        return z | 0
	                    }
	                    if ((c[o >> 2] | 0) > 0)c[n >> 2] = -1;
	                    c[h >> 2] = c[n >> 2];
	                    z = c[h >> 2] | 0;
	                    i = g;
	                    return z | 0
	                }
	                c[h >> 2] = -1;
	                z = c[h >> 2] | 0;
	                i = g;
	                return z | 0
	            }

	            function VQ(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                if (!(c[g >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                c[k >> 2] = Cb[c[135744 >> 2] & 511](32) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                d = c[k >> 2] | 0;
	                c[d + 0 >> 2] = 0;
	                c[d + 4 >> 2] = 0;
	                c[d + 8 >> 2] = 0;
	                c[d + 12 >> 2] = 0;
	                c[d + 16 >> 2] = 0;
	                c[d + 20 >> 2] = 0;
	                c[d + 24 >> 2] = 0;
	                c[d + 28 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 12 >> 2] = c[h >> 2];
	                c[c[k >> 2] >> 2] = c[g >> 2];
	                c[(c[k >> 2] | 0) + 4 >> 2] = c[g >> 2];
	                if (c[j >> 2] | 0) {
	                    c[l >> 2] = 0;
	                    while (1) {
	                        n = c[l >> 2] | 0;
	                        if (!(c[(c[j >> 2] | 0) + (c[l >> 2] << 1 << 2) >> 2] | 0))break;
	                        c[l >> 2] = n + 1
	                    }
	                    c[(c[k >> 2] | 0) + 28 >> 2] = n
	                } else c[(c[k >> 2] | 0) + 28 >> 2] = 0;
	                c[(c[k >> 2] | 0) + 24 >> 2] = c[j >> 2];
	                c[f >> 2] = c[k >> 2];
	                m = c[f >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function WQ() {
	                var a = 0, b = 0, d = 0, e = 0, f = 0, g = 0;
	                a = i;
	                i = i + 16 | 0;
	                b = a + 4 | 0;
	                d = a;
	                c[d >> 2] = Cb[c[135744 >> 2] & 511](36) | 0;
	                if (!(c[d >> 2] | 0)) {
	                    c[b >> 2] = 0;
	                    e = c[b >> 2] | 0;
	                    i = a;
	                    return e | 0
	                }
	                f = (c[d >> 2] | 0) + 0 | 0;
	                g = f + 36 | 0;
	                do {
	                    c[f >> 2] = 0;
	                    f = f + 4 | 0
	                } while ((f | 0) < (g | 0));
	                c[(c[d >> 2] | 0) + 24 >> 2] = 10;
	                f = Cb[c[135744 >> 2] & 511]((c[(c[d >> 2] | 0) + 24 >> 2] | 0) * 12 | 0) | 0;
	                c[(c[d >> 2] | 0) + 28 >> 2] = f;
	                if (!(c[(c[d >> 2] | 0) + 28 >> 2] | 0)) {
	                    zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                    c[b >> 2] = 0;
	                    e = c[b >> 2] | 0;
	                    i = a;
	                    return e | 0
	                } else {
	                    c[b >> 2] = c[d >> 2];
	                    e = c[b >> 2] | 0;
	                    i = a;
	                    return e | 0
	                }
	                return 0
	            }

	            function XQ(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b;
	                c[e >> 2] = a;
	                while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)f = 1; else {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            f = 1;
	                            break
	                        }
	                        f = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                    } while (0);
	                    g = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                    if (!f)break;
	                    a = c[e >> 2] | 0;
	                    if (!g)continue;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1
	                }
	                a:do if ((g | 0) != 47) {
	                    f = (c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 | 0;
	                    c[f >> 2] = c[f >> 2] | 512;
	                    if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 46) {
	                        f = c[e >> 2] | 0;
	                        if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[f >> 2] = (c[f >> 2] | 0) + 1;
	                        while (1) {
	                            do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)h = 1; else {
	                                if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                    h = 1;
	                                    break
	                                }
	                                h = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                            } while (0);
	                            j = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                            if (!h)break;
	                            f = c[e >> 2] | 0;
	                            if (!j)continue;
	                            c[f >> 2] = (c[f >> 2] | 0) + 1
	                        }
	                        f = c[e >> 2] | 0;
	                        if (!j) {
	                            if (dR(f, c[(c[e >> 2] | 0) + 16 >> 2] | 0, 2, 0, 0) | 0)break;
	                            i = b;
	                            return
	                        }
	                        if ((d[c[f >> 2] >> 0] | 0 | 0) != 47)break;
	                        f = c[e >> 2] | 0;
	                        if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[f >> 2] = (c[f >> 2] | 0) + 1;
	                        while (1) {
	                            do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)k = 1; else {
	                                if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                    k = 1;
	                                    break
	                                }
	                                k = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                            } while (0);
	                            l = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                            if (!k)break;
	                            f = c[e >> 2] | 0;
	                            if (!l)continue;
	                            c[f >> 2] = (c[f >> 2] | 0) + 1
	                        }
	                        b:do if ((l | 0) == 47) {
	                            if ((d[(c[c[e >> 2] >> 2] | 0) + -1 >> 0] | 0 | 0) == 32)break a;
	                            if (9 <= (d[(c[c[e >> 2] >> 2] | 0) + -1 >> 0] | 0 | 0) ? (d[(c[c[e >> 2] >> 2] | 0) + -1 >> 0] | 0 | 0) <= 10 : 0)break a;
	                            if ((d[(c[c[e >> 2] >> 2] | 0) + -1 >> 0] | 0 | 0) == 13)break a;
	                            if (dR(c[e >> 2] | 0, c[(c[e >> 2] | 0) + 16 >> 2] | 0, 6, 0, 0) | 0)break a;
	                            f = c[e >> 2] | 0;
	                            if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[f >> 2] = (c[f >> 2] | 0) + 1;
	                            while (1) {
	                                do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                                    if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                                    if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)break b
	                                } while (0);
	                                f = c[e >> 2] | 0;
	                                if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                                c[f >> 2] = (c[f >> 2] | 0) + 1
	                            }
	                        } while (0);
	                        if (d[c[c[e >> 2] >> 2] >> 0] | 0)m = 47
	                    } else m = 47;
	                    c:do if ((m | 0) == 47) {
	                        while (1) {
	                            m = 0;
	                            eR(c[e >> 2] | 0);
	                            if (c[(c[e >> 2] | 0) + 8 >> 2] | 0)break a;
	                            while (1) {
	                                do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)n = 1; else {
	                                    if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                        n = 1;
	                                        break
	                                    }
	                                    n = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                                } while (0);
	                                o = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                                if (!n)break;
	                                f = c[e >> 2] | 0;
	                                if (!o)continue;
	                                c[f >> 2] = (c[f >> 2] | 0) + 1
	                            }
	                            if ((o | 0) != 47)break;
	                            if (dR(c[e >> 2] | 0, c[(c[e >> 2] | 0) + 16 >> 2] | 0, 5, 0, 0) | 0)break a;
	                            f = c[e >> 2] | 0;
	                            if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[f >> 2] = (c[f >> 2] | 0) + 1;
	                            while (1) {
	                                do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)p = 1; else {
	                                    if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                        p = 1;
	                                        break
	                                    }
	                                    p = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                                } while (0);
	                                q = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                                if (!p)break;
	                                f = c[e >> 2] | 0;
	                                if (!q)continue;
	                                c[f >> 2] = (c[f >> 2] | 0) + 1
	                            }
	                            if ((q | 0) == 47)break a;
	                            if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))break c;
	                            if (d[c[c[e >> 2] >> 2] >> 0] | 0)m = 47; else break
	                        }
	                        if (!(d[c[c[e >> 2] >> 2] >> 0] | 0)) {
	                            i = b;
	                            return
	                        }
	                        c[(c[e >> 2] | 0) + 8 >> 2] = 1;
	                        i = b;
	                        return
	                    } while (0);
	                    c[(c[e >> 2] | 0) + 8 >> 2] = 1;
	                    i = b;
	                    return
	                } while (0);
	                c[(c[e >> 2] | 0) + 8 >> 2] = 1;
	                i = b;
	                return
	            }

	            function YQ(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b;
	                c[e >> 2] = a;
	                while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)f = 1; else {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            f = 1;
	                            break
	                        }
	                        f = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                    } while (0);
	                    g = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                    if (!f)break;
	                    a = c[e >> 2] | 0;
	                    if (!g)continue;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1
	                }
	                f = c[e >> 2] | 0;
	                do if ((g | 0) == 47) {
	                    a = (c[f + 16 >> 2] | 0) + 16 | 0;
	                    c[a >> 2] = c[a >> 2] | 256
	                } else {
	                    if ((d[c[f >> 2] >> 0] | 0 | 0) != 46 ? (c[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 2] & 7 | 0) == 0 : 0)break;
	                    a = (c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 | 0;
	                    c[a >> 2] = c[a >> 2] | 512
	                } while (0);
	                if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 47 ? (d[(c[c[e >> 2] >> 2] | 0) + 1 >> 0] | 0 | 0) == 47 : 0) {
	                    if (dR(c[e >> 2] | 0, c[(c[e >> 2] | 0) + 16 >> 2] | 0, 6, 0, 0) | 0) {
	                        i = b;
	                        return
	                    }
	                    f = c[e >> 2] | 0;
	                    if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[f >> 2] = (c[f >> 2] | 0) + 1;
	                    f = c[e >> 2] | 0;
	                    if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[f >> 2] = (c[f >> 2] | 0) + 1
	                } else h = 21;
	                if ((((h | 0) == 21 ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 46 : 0) ? (d[(c[c[e >> 2] >> 2] | 0) + 1 >> 0] | 0 | 0) == 47 : 0) ? (d[(c[c[e >> 2] >> 2] | 0) + 2 >> 0] | 0 | 0) == 47 : 0) {
	                    if (dR(c[e >> 2] | 0, c[(c[e >> 2] | 0) + 16 >> 2] | 0, 6, 0, 0) | 0) {
	                        i = b;
	                        return
	                    }
	                    f = c[e >> 2] | 0;
	                    if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[f >> 2] = (c[f >> 2] | 0) + 1;
	                    f = c[e >> 2] | 0;
	                    if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[f >> 2] = (c[f >> 2] | 0) + 1;
	                    f = c[e >> 2] | 0;
	                    if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[f >> 2] = (c[f >> 2] | 0) + 1;
	                    while (1) {
	                        do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)j = 1; else {
	                            if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                j = 1;
	                                break
	                            }
	                            j = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        k = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                        if (!j)break;
	                        f = c[e >> 2] | 0;
	                        if (!k)continue;
	                        c[f >> 2] = (c[f >> 2] | 0) + 1
	                    }
	                    if (!k) {
	                        c[(c[e >> 2] | 0) + 8 >> 2] = 1;
	                        i = b;
	                        return
	                    }
	                }
	                k = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                a:do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 64) {
	                    j = c[e >> 2] | 0;
	                    if (k)c[j >> 2] = (c[j >> 2] | 0) + 1;
	                    fR(c[e >> 2] | 0);
	                    while (1) {
	                        do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)l = 1; else {
	                            if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                l = 1;
	                                break
	                            }
	                            l = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                        } while (0);
	                        m = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 0;
	                        if (!l)break;
	                        j = c[e >> 2] | 0;
	                        if (!m)continue;
	                        c[j >> 2] = (c[j >> 2] | 0) + 1
	                    }
	                    if (m ? (eR(c[e >> 2] | 0), (c[(c[e >> 2] | 0) + 8 >> 2] | 0) != 0) : 0) {
	                        i = b;
	                        return
	                    }
	                } else {
	                    if ((k | 0) == 47) {
	                        if (dR(c[e >> 2] | 0, c[(c[e >> 2] | 0) + 16 >> 2] | 0, 1, 0, 0) | 0) {
	                            i = b;
	                            return
	                        }
	                        j = c[e >> 2] | 0;
	                        if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[j >> 2] = (c[j >> 2] | 0) + 1;
	                        while (1) {
	                            do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)n = 1; else {
	                                if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                    n = 1;
	                                    break
	                                }
	                                n = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                            } while (0);
	                            o = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                            if (!n)break;
	                            j = c[e >> 2] | 0;
	                            if (!o)continue;
	                            c[j >> 2] = (c[j >> 2] | 0) + 1
	                        }
	                        if (!o) {
	                            c[(c[e >> 2] | 0) + 8 >> 2] = 1;
	                            i = b;
	                            return
	                        }
	                    }
	                    eR(c[e >> 2] | 0);
	                    if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                        i = b;
	                        return
	                    }
	                    b:while (1) {
	                        do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                            if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)break b
	                        } while (0);
	                        j = c[e >> 2] | 0;
	                        if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                        c[j >> 2] = (c[j >> 2] | 0) + 1
	                    }
	                    while (1) {
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 47)break a;
	                        j = c[e >> 2] | 0;
	                        f = c[(c[e >> 2] | 0) + 16 >> 2] | 0;
	                        if ((d[(c[c[e >> 2] >> 2] | 0) + 1 >> 0] | 0 | 0) != 47) {
	                            if (dR(j, f, 5, 0, 0) | 0) {
	                                h = 103;
	                                break
	                            }
	                            g = c[e >> 2] | 0;
	                            if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[g >> 2] = (c[g >> 2] | 0) + 1;
	                            while (1) {
	                                do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)p = 1; else {
	                                    if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                        p = 1;
	                                        break
	                                    }
	                                    p = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                                } while (0);
	                                q = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                                if (!p)break;
	                                g = c[e >> 2] | 0;
	                                if (!q)continue;
	                                c[g >> 2] = (c[g >> 2] | 0) + 1
	                            }
	                            r = c[e >> 2] | 0;
	                            if (!q) {
	                                h = 99;
	                                break
	                            }
	                            eR(r);
	                            if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                                h = 103;
	                                break
	                            } else continue
	                        }
	                        if (dR(j, f, 6, 0, 0) | 0) {
	                            h = 103;
	                            break
	                        }
	                        g = c[e >> 2] | 0;
	                        if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[g >> 2] = (c[g >> 2] | 0) + 1;
	                        g = c[e >> 2] | 0;
	                        if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[g >> 2] = (c[g >> 2] | 0) + 1;
	                        while (1) {
	                            do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)s = 1; else {
	                                if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                                    s = 1;
	                                    break
	                                }
	                                s = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                            } while (0);
	                            t = c[e >> 2] | 0;
	                            if (!s)break;
	                            g = c[e >> 2] | 0;
	                            if (!(d[c[t >> 2] >> 0] | 0))continue;
	                            c[g >> 2] = (c[g >> 2] | 0) + 1
	                        }
	                        eR(t);
	                        if (c[(c[e >> 2] | 0) + 8 >> 2] | 0) {
	                            h = 103;
	                            break
	                        }
	                    }
	                    if ((h | 0) == 99) {
	                        c[r + 8 >> 2] = 1;
	                        i = b;
	                        return
	                    } else if ((h | 0) == 103) {
	                        i = b;
	                        return
	                    }
	                } while (0);
	                if (!(d[c[c[e >> 2] >> 2] >> 0] | 0)) {
	                    i = b;
	                    return
	                }
	                c[(c[e >> 2] | 0) + 8 >> 2] = 1;
	                i = b;
	                return
	            }

	            function ZQ(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                a = c[d >> 2] | 0;
	                c[a + 0 >> 2] = -1;
	                c[a + 4 >> 2] = -1;
	                c[a + 8 >> 2] = -1;
	                c[a + 12 >> 2] = -1;
	                c[a + 16 >> 2] = -1;
	                c[a + 20 >> 2] = -1;
	                c[a + 24 >> 2] = -1;
	                c[a + 28 >> 2] = -1;
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function _Q(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                b = i;
	                i = i + 48 | 0;
	                d = b + 40 | 0;
	                e = b + 36 | 0;
	                f = b + 32 | 0;
	                g = b + 28 | 0;
	                h = b + 24 | 0;
	                j = b + 20 | 0;
	                k = b + 16 | 0;
	                l = b + 12 | 0;
	                m = b;
	                c[e >> 2] = a;
	                c[h >> 2] = 0;
	                c[j >> 2] = 0;
	                c[k >> 2] = 0;
	                c[l >> 2] = -1;
	                if ((c[e >> 2] | 0) != 0 ? (c[(c[e >> 2] | 0) + 28 >> 2] | 0) != 0 : 0) {
	                    if ((((c[(c[e >> 2] | 0) + 20 >> 2] | 0) == 1 ? (c[c[(c[e >> 2] | 0) + 28 >> 2] >> 2] | 0) == 2 : 0) ? (c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + 4 >> 2] | 0) == 0 : 0) ? (c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + 8 >> 2] | 0) == 0 : 0) {
	                        c[f >> 2] = gR(0) | 0;
	                        if (!(c[f >> 2] | 0)) {
	                            c[d >> 2] = -1;
	                            n = c[d >> 2] | 0;
	                            i = b;
	                            return n | 0
	                        } else {
	                            a = (c[f >> 2] | 0) + 16 | 0;
	                            c[a >> 2] = c[a >> 2] | 16384;
	                            c[(c[e >> 2] | 0) + 32 >> 2] = c[f >> 2];
	                            c[d >> 2] = 0;
	                            n = c[d >> 2] | 0;
	                            i = b;
	                            return n | 0
	                        }
	                    }
	                    c[f >> 2] = gR(((c[(c[e >> 2] | 0) + 20 >> 2] | 0) / 2 | 0) + 1 | 0) | 0;
	                    if (!(c[f >> 2] | 0)) {
	                        c[d >> 2] = -1;
	                        n = c[d >> 2] | 0;
	                        i = b;
	                        return n | 0
	                    }
	                    if (c[(c[e >> 2] | 0) + 4 >> 2] | 0) {
	                        c[c[f >> 2] >> 2] = c[(c[e >> 2] | 0) + 4 >> 2];
	                        yP(c[c[f >> 2] >> 2] | 0) | 0
	                    }
	                    c[g >> 2] = 0;
	                    if (c[(c[e >> 2] | 0) + 16 >> 2] & 256) {
	                        a = (c[f >> 2] | 0) + 16 | 0;
	                        c[a >> 2] = c[a >> 2] | 32768
	                    }
	                    a:while (1) {
	                        if ((c[g >> 2] | 0) >= (c[(c[e >> 2] | 0) + 20 >> 2] | 0)) {
	                            o = 43;
	                            break
	                        }
	                        a = (c[(c[e >> 2] | 0) + 28 >> 2] | 0) + ((c[g >> 2] | 0) * 12 | 0) | 0;
	                        c[m + 0 >> 2] = c[a + 0 >> 2];
	                        c[m + 4 >> 2] = c[a + 4 >> 2];
	                        c[m + 8 >> 2] = c[a + 8 >> 2];
	                        b:do switch (c[m >> 2] | 0) {
	                            case 1:
	                            {
	                                if (c[g >> 2] | 0)break a;
	                                c[j >> 2] = 1;
	                                break
	                            }
	                            case 2:
	                            {
	                                if ((c[m + 4 >> 2] | 0) == 0 ? (c[m + 8 >> 2] | 0) == 0 : 0) {
	                                    if ((c[(c[e >> 2] | 0) + 20 >> 2] | 0) != ((c[g >> 2] | 0) + 1 | 0))break b;
	                                    if (!(c[k >> 2] & 1))break b;
	                                    if ((c[(c[e >> 2] | 0) + 20 >> 2] | 0) == ((c[g >> 2] | 0) + 1 | 0)) {
	                                        a = (c[f >> 2] | 0) + 16 | 0;
	                                        c[a >> 2] = c[a >> 2] | 16384
	                                    }
	                                    c[k >> 2] = c[k >> 2] | 16;
	                                    c[h >> 2] = hR(c[f >> 2] | 0, 0, 0, 100, c[k >> 2] | 0) | 0;
	                                    if ((c[h >> 2] | 0) < 0)break a;
	                                    c[k >> 2] = 0;
	                                    if ((c[l >> 2] | 0) == -1)break b;
	                                    a = (c[(c[f >> 2] | 0) + 12 >> 2] | 0) + (c[l >> 2] << 4) | 0;
	                                    c[a >> 2] = c[a >> 2] | 32;
	                                    c[l >> 2] = -1;
	                                    break b
	                                }
	                                c[h >> 2] = hR(c[f >> 2] | 0, c[m + 4 >> 2] | 0, c[m + 8 >> 2] | 0, 1, c[k >> 2] | 0) | 0;
	                                if ((c[h >> 2] | 0) < 0)break a;
	                                c[l >> 2] = c[h >> 2];
	                                c[k >> 2] = 0;
	                                break
	                            }
	                            case 6:
	                            {
	                                if ((c[k >> 2] & 1 | 0) == 0 ? (c[k >> 2] = c[k >> 2] | 1, (c[(c[f >> 2] | 0) + 16 >> 2] & 65536 | 0) == 0) : 0) {
	                                    a = (c[f >> 2] | 0) + 16 | 0;
	                                    c[a >> 2] = c[a >> 2] | 65536
	                                }
	                                break
	                            }
	                            case 4:
	                            {
	                                c[k >> 2] = c[k >> 2] | 8;
	                                c[l >> 2] = -1;
	                                c[h >> 2] = hR(c[f >> 2] | 0, c[m + 4 >> 2] | 0, c[m + 8 >> 2] | 0, 2, c[k >> 2] | 0) | 0;
	                                c[k >> 2] = 0;
	                                if ((c[h >> 2] | 0) < 0)break a;
	                                break
	                            }
	                            case 8:
	                            {
	                                c[h >> 2] = hR(c[f >> 2] | 0, 0, 0, 1, c[k >> 2] | 0) | 0;
	                                if ((c[h >> 2] | 0) < 0)break a;
	                                c[l >> 2] = c[h >> 2];
	                                c[k >> 2] = 0;
	                                break
	                            }
	                            case 7:
	                            {
	                                c[h >> 2] = hR(c[f >> 2] | 0, 0, c[m + 4 >> 2] | 0, 1, c[k >> 2] | 0) | 0;
	                                if ((c[h >> 2] | 0) < 0)break a;
	                                c[l >> 2] = c[h >> 2];
	                                c[k >> 2] = 0;
	                                break
	                            }
	                            case 3:
	                            {
	                                c[h >> 2] = hR(c[f >> 2] | 0, c[m + 4 >> 2] | 0, c[m + 8 >> 2] | 0, 1, c[k >> 2] | 0) | 0;
	                                if ((c[h >> 2] | 0) < 0)break a;
	                                c[l >> 2] = c[h >> 2];
	                                c[k >> 2] = 0;
	                                break
	                            }
	                            default:
	                            {
	                            }
	                        } while (0);
	                        c[g >> 2] = (c[g >> 2] | 0) + 1
	                    }
	                    if ((o | 0) == 43) {
	                        if ((c[j >> 2] | 0) == 0 ? (c[(c[e >> 2] | 0) + 16 >> 2] & 7 | 0) == 0 : 0) {
	                            if (!(c[(c[f >> 2] | 0) + 16 >> 2] & 65536)) {
	                                o = (c[f >> 2] | 0) + 16 | 0;
	                                c[o >> 2] = c[o >> 2] | 65536
	                            }
	                            if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) > 0 ? (c[c[(c[f >> 2] | 0) + 12 >> 2] >> 2] & 1 | 0) == 0 : 0) {
	                                o = c[(c[f >> 2] | 0) + 12 >> 2] | 0;
	                                c[o >> 2] = c[o >> 2] | 1
	                            }
	                        }
	                        if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) > (c[h >> 2] | 0)) {
	                            o = (c[(c[f >> 2] | 0) + 12 >> 2] | 0) + (c[h >> 2] << 4) | 0;
	                            c[o >> 2] = c[o >> 2] | 2;
	                            if (c[j >> 2] | 0) {
	                                j = c[(c[f >> 2] | 0) + 12 >> 2] | 0;
	                                c[j >> 2] = c[j >> 2] | 4
	                            }
	                            c[(c[e >> 2] | 0) + 32 >> 2] = c[f >> 2];
	                            c[d >> 2] = 0;
	                            n = c[d >> 2] | 0;
	                            i = b;
	                            return n | 0
	                        }
	                    }
	                    TQ(c[f >> 2] | 0);
	                    c[d >> 2] = 0;
	                    n = c[d >> 2] | 0;
	                    i = b;
	                    return n | 0
	                }
	                c[d >> 2] = -1;
	                n = c[d >> 2] | 0;
	                i = b;
	                return n | 0
	            }

	            function $Q(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                b = i;
	                i = i + 32 | 0;
	                d = b + 24 | 0;
	                e = b + 20 | 0;
	                f = b + 16 | 0;
	                g = b + 12 | 0;
	                h = b + 8 | 0;
	                j = b + 4 | 0;
	                k = b;
	                c[e >> 2] = a;
	                if ((c[(c[e >> 2] | 0) + 20 >> 2] | 0) > 0 ? (c[c[(c[e >> 2] | 0) + 28 >> 2] >> 2] | 0) == 6 : 0) {
	                    c[f >> 2] = 0;
	                    c[g >> 2] = 1;
	                    while (1) {
	                        if ((c[g >> 2] | 0) >= (c[(c[e >> 2] | 0) + 20 >> 2] | 0))break;
	                        c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + ((c[f >> 2] | 0) * 12 | 0) + 4 >> 2] = c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + ((c[g >> 2] | 0) * 12 | 0) + 4 >> 2];
	                        c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + ((c[f >> 2] | 0) * 12 | 0) + 8 >> 2] = c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + ((c[g >> 2] | 0) * 12 | 0) + 8 >> 2];
	                        c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + ((c[f >> 2] | 0) * 12 | 0) >> 2] = c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + ((c[g >> 2] | 0) * 12 | 0) >> 2];
	                        c[f >> 2] = (c[f >> 2] | 0) + 1;
	                        c[g >> 2] = (c[g >> 2] | 0) + 1
	                    }
	                    a = (c[e >> 2] | 0) + 20 | 0;
	                    c[a >> 2] = (c[a >> 2] | 0) + -1
	                }
	                do if ((c[(c[e >> 2] | 0) + 20 >> 2] | 0) >= (c[(c[e >> 2] | 0) + 24 >> 2] | 0)) {
	                    c[h >> 2] = Hb[c[135760 >> 2] & 511](c[(c[e >> 2] | 0) + 28 >> 2] | 0, (c[(c[e >> 2] | 0) + 24 >> 2] << 1) * 12 | 0) | 0;
	                    if (c[h >> 2] | 0) {
	                        c[(c[e >> 2] | 0) + 28 >> 2] = c[h >> 2];
	                        a = (c[e >> 2] | 0) + 24 | 0;
	                        c[a >> 2] = c[a >> 2] << 1;
	                        break
	                    }
	                    c[d >> 2] = -1;
	                    l = c[d >> 2] | 0;
	                    i = b;
	                    return l | 0
	                } while (0);
	                c[f >> 2] = 0;
	                c[g >> 2] = (c[(c[e >> 2] | 0) + 20 >> 2] | 0) - 1;
	                while (1) {
	                    if ((c[g >> 2] | 0) <= (c[f >> 2] | 0))break;
	                    c[j >> 2] = c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + ((c[f >> 2] | 0) * 12 | 0) + 4 >> 2];
	                    c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + ((c[f >> 2] | 0) * 12 | 0) + 4 >> 2] = c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + ((c[g >> 2] | 0) * 12 | 0) + 4 >> 2];
	                    c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + ((c[g >> 2] | 0) * 12 | 0) + 4 >> 2] = c[j >> 2];
	                    c[j >> 2] = c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + ((c[f >> 2] | 0) * 12 | 0) + 8 >> 2];
	                    c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + ((c[f >> 2] | 0) * 12 | 0) + 8 >> 2] = c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + ((c[g >> 2] | 0) * 12 | 0) + 8 >> 2];
	                    c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + ((c[g >> 2] | 0) * 12 | 0) + 8 >> 2] = c[j >> 2];
	                    c[k >> 2] = c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + ((c[f >> 2] | 0) * 12 | 0) >> 2];
	                    c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + ((c[f >> 2] | 0) * 12 | 0) >> 2] = c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + ((c[g >> 2] | 0) * 12 | 0) >> 2];
	                    c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + ((c[g >> 2] | 0) * 12 | 0) >> 2] = c[k >> 2];
	                    c[g >> 2] = (c[g >> 2] | 0) + -1;
	                    c[f >> 2] = (c[f >> 2] | 0) + 1
	                }
	                c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + ((c[(c[e >> 2] | 0) + 20 >> 2] | 0) * 12 | 0) + 4 >> 2] = 0;
	                c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + ((c[(c[e >> 2] | 0) + 20 >> 2] | 0) * 12 | 0) + 8 >> 2] = 0;
	                f = (c[e >> 2] | 0) + 20 | 0;
	                g = c[f >> 2] | 0;
	                c[f >> 2] = g + 1;
	                c[(c[(c[e >> 2] | 0) + 28 >> 2] | 0) + (g * 12 | 0) >> 2] = 0;
	                c[d >> 2] = 0;
	                l = c[d >> 2] | 0;
	                i = b;
	                return l | 0
	            }

	            function aR(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 32 | 0;
	                g = e + 28 | 0;
	                h = e + 24 | 0;
	                j = e + 20 | 0;
	                k = e + 16 | 0;
	                l = e + 4 | 0;
	                m = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[l + 0 >> 2] = 0;
	                c[l + 4 >> 2] = 0;
	                c[l + 8 >> 2] = 0;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0) {
	                    c[f >> 2] = -1;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                c[j >> 2] = 0;
	                a:while (1) {
	                    if ((c[j >> 2] | 0) >= (c[(c[g >> 2] | 0) + 20 >> 2] | 0)) {
	                        o = 84;
	                        break
	                    }
	                    c[k >> 2] = (c[(c[g >> 2] | 0) + 28 >> 2] | 0) + ((c[j >> 2] | 0) * 12 | 0);
	                    b:do switch (c[c[k >> 2] >> 2] | 0) {
	                        case 8:
	                        {
	                            if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 1)o = 83;
	                            break
	                        }
	                        case 3:
	                        {
	                            if ((((c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 9 : 0) ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 21 : 0) ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 13 : 0)break b;
	                            c[m >> 2] = c[(c[h >> 2] | 0) + 12 >> 2];
	                            if (c[(c[k >> 2] | 0) + 4 >> 2] | 0) {
	                                while (1) {
	                                    if (!(c[m >> 2] | 0))break;
	                                    if (((c[(c[m >> 2] | 0) + 4 >> 2] | 0) == 1 ? (d[c[(c[k >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) == (d[c[(c[m >> 2] | 0) + 8 >> 2] >> 0] | 0 | 0) : 0) ? (qy(c[(c[k >> 2] | 0) + 4 >> 2] | 0, c[(c[m >> 2] | 0) + 8 >> 2] | 0) | 0) != 0 : 0)break;
	                                    c[m >> 2] = c[(c[m >> 2] | 0) + 24 >> 2]
	                                }
	                                if (c[m >> 2] | 0)o = 83
	                            }
	                            break
	                        }
	                        case 2:
	                        {
	                            if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 1)if (c[(c[k >> 2] | 0) + 4 >> 2] | 0) {
	                                if ((d[c[(c[k >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) == (d[c[(c[h >> 2] | 0) + 8 >> 2] >> 0] | 0 | 0) ? (qy(c[(c[k >> 2] | 0) + 4 >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0) | 0) != 0 : 0) {
	                                    if (!(c[(c[h >> 2] | 0) + 36 >> 2] | 0))if (c[(c[k >> 2] | 0) + 8 >> 2] | 0)break b; else {
	                                        o = 83;
	                                        break b
	                                    }
	                                    if (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) {
	                                        if ((c[(c[k >> 2] | 0) + 8 >> 2] | 0) != 0 ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) | 0) != 0 : 0)o = 83
	                                    } else o = 83
	                                }
	                            } else o = 83;
	                            break
	                        }
	                        case 5:
	                        {
	                            if (((((c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 9 ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 13 : 0) ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 21 : 0) ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) ? (c[h >> 2] = c[(c[h >> 2] | 0) + 20 >> 2], (c[h >> 2] | 0) != 0) : 0)if (c[(c[k >> 2] | 0) + 4 >> 2] | 0) {
	                                if ((d[c[(c[k >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) == (d[c[(c[h >> 2] | 0) + 8 >> 2] >> 0] | 0 | 0) ? (qy(c[(c[k >> 2] | 0) + 4 >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0) | 0) != 0 : 0) {
	                                    if (!(c[(c[h >> 2] | 0) + 36 >> 2] | 0))if (c[(c[k >> 2] | 0) + 8 >> 2] | 0)break b; else {
	                                        o = 83;
	                                        break b
	                                    }
	                                    if (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) {
	                                        if ((c[(c[k >> 2] | 0) + 8 >> 2] | 0) != 0 ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) | 0) != 0 : 0)o = 83
	                                    } else o = 83
	                                }
	                            } else o = 83;
	                            break
	                        }
	                        case 6:
	                        {
	                            if (!(c[(c[k >> 2] | 0) + 4 >> 2] | 0)) {
	                                c[j >> 2] = (c[j >> 2] | 0) + 1;
	                                c[k >> 2] = (c[(c[g >> 2] | 0) + 28 >> 2] | 0) + ((c[j >> 2] | 0) * 12 | 0);
	                                if ((c[c[k >> 2] >> 2] | 0) == 1) {
	                                    o = 84;
	                                    break a
	                                }
	                                if ((c[c[k >> 2] >> 2] | 0) != 2)break b;
	                                if (!(c[(c[k >> 2] | 0) + 4 >> 2] | 0)) {
	                                    o = 55;
	                                    break a
	                                }
	                            }
	                            if (((((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 9 : 0) ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 13 : 0) ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 21 : 0) ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 18 : 0) {
	                                c[h >> 2] = c[(c[h >> 2] | 0) + 20 >> 2];
	                                c:while (1) {
	                                    if (!(c[h >> 2] | 0))break;
	                                    do if (((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 1 ? (d[c[(c[k >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) == (d[c[(c[h >> 2] | 0) + 8 >> 2] >> 0] | 0 | 0) : 0) ? (qy(c[(c[k >> 2] | 0) + 4 >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0) | 0) != 0 : 0) {
	                                        if (!(c[(c[h >> 2] | 0) + 36 >> 2] | 0))if (!(c[(c[k >> 2] | 0) + 8 >> 2] | 0))break c; else break;
	                                        if (((c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) | 0) != 0 : 0)break c
	                                    } while (0);
	                                    c[h >> 2] = c[(c[h >> 2] | 0) + 20 >> 2]
	                                }
	                                if (c[h >> 2] | 0) {
	                                    b = c[j >> 2] | 0;
	                                    if ((c[c[k >> 2] >> 2] | 0) == 6) {
	                                        iR(l, b, c[h >> 2] | 0) | 0;
	                                        o = 83;
	                                        break b
	                                    } else {
	                                        iR(l, b - 1 | 0, c[h >> 2] | 0) | 0;
	                                        o = 83;
	                                        break b
	                                    }
	                                }
	                            }
	                            break
	                        }
	                        case 1:
	                        {
	                            if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 18) {
	                                c[h >> 2] = c[(c[h >> 2] | 0) + 20 >> 2];
	                                if (!(((c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 9 ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 21 : 0) ? (c[(c[h >> 2] | 0) + 4 >> 2] | 0) != 13 : 0))o = 83
	                            }
	                            break
	                        }
	                        case 4:
	                        {
	                            if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 2) {
	                                if (c[(c[k >> 2] | 0) + 4 >> 2] | 0) {
	                                    if ((d[c[(c[k >> 2] | 0) + 4 >> 2] >> 0] | 0 | 0) != (d[c[(c[h >> 2] | 0) + 8 >> 2] >> 0] | 0 | 0))break b;
	                                    if (!(qy(c[(c[k >> 2] | 0) + 4 >> 2] | 0, c[(c[h >> 2] | 0) + 8 >> 2] | 0) | 0))break b
	                                }
	                                b = (c[(c[k >> 2] | 0) + 8 >> 2] | 0) != 0;
	                                if (!(c[(c[h >> 2] | 0) + 36 >> 2] | 0))if (b)break b; else {
	                                    o = 83;
	                                    break b
	                                }
	                                if (!(b ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) | 0) == 0 : 0))o = 83
	                            }
	                            break
	                        }
	                        case 7:
	                        {
	                            if ((c[(c[h >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                                if (!(c[(c[h >> 2] | 0) + 36 >> 2] | 0))if (c[(c[k >> 2] | 0) + 4 >> 2] | 0)break b; else {
	                                    o = 83;
	                                    break b
	                                }
	                                if (c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) {
	                                    if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) != 0 ? (qy(c[(c[k >> 2] | 0) + 4 >> 2] | 0, c[(c[(c[h >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0) | 0) != 0 : 0)o = 83
	                                } else o = 83
	                            }
	                            break
	                        }
	                        case 0:
	                        {
	                            o = 84;
	                            break a;
	                            break
	                        }
	                        default:
	                            o = 83
	                    } while (0);
	                    if ((o | 0) == 83) {
	                        o = 0;
	                        c[j >> 2] = (c[j >> 2] | 0) + 1;
	                        continue
	                    }
	                    if (!(c[l + 8 >> 2] | 0)) {
	                        o = 88;
	                        break
	                    }
	                    if ((c[l >> 2] | 0) <= 0) {
	                        o = 90;
	                        break
	                    }
	                    c[l >> 2] = (c[l >> 2] | 0) + -1;
	                    c[j >> 2] = c[(c[l + 8 >> 2] | 0) + (c[l >> 2] << 3) >> 2];
	                    c[h >> 2] = c[(c[l + 8 >> 2] | 0) + (c[l >> 2] << 3) + 4 >> 2]
	                }
	                if ((o | 0) == 55) {
	                    c[f >> 2] = -1;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                } else if ((o | 0) == 84) {
	                    if (c[l + 8 >> 2] | 0)zb[c[135736 >> 2] & 511](c[l + 8 >> 2] | 0);
	                    c[f >> 2] = 1;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                } else if ((o | 0) == 88) {
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                } else if ((o | 0) == 90) {
	                    zb[c[135736 >> 2] & 511](c[l + 8 >> 2] | 0);
	                    c[f >> 2] = 0;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                return 0
	            }

	            function bR(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](32) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = c[f >> 2] | 0;
	                c[a + 0 >> 2] = 0;
	                c[a + 4 >> 2] = 0;
	                c[a + 8 >> 2] = 0;
	                c[a + 12 >> 2] = 0;
	                c[a + 16 >> 2] = 0;
	                c[a + 20 >> 2] = 0;
	                c[a + 24 >> 2] = 0;
	                c[a + 28 >> 2] = 0;
	                a = Cb[c[135744 >> 2] & 511](32) | 0;
	                c[(c[f >> 2] | 0) + 20 >> 2] = a;
	                if (!(c[(c[f >> 2] | 0) + 20 >> 2] | 0)) {
	                    zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    c[(c[f >> 2] | 0) + 8 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 12 >> 2] = 4;
	                    c[(c[f >> 2] | 0) + 16 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 4 >> 2] = c[e >> 2];
	                    c[(c[f >> 2] | 0) + 28 >> 2] = -1;
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function cR(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 0;
	                while (1) {
	                    if ((c[k >> 2] | 0) >= (c[(c[g >> 2] | 0) + 8 >> 2] | 0))break;
	                    if ((c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + (c[k >> 2] << 1 << 2) >> 2] | 0) < 0) {
	                        m = 4;
	                        break
	                    }
	                    c[k >> 2] = (c[k >> 2] | 0) + 1
	                }
	                if ((m | 0) == 4) {
	                    c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + (c[k >> 2] << 1 << 2) >> 2] = c[h >> 2];
	                    c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + ((c[k >> 2] << 1) + 1 << 2) >> 2] = c[j >> 2];
	                    c[f >> 2] = c[k >> 2];
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                }
	                do if ((c[(c[g >> 2] | 0) + 8 >> 2] | 0) >= (c[(c[g >> 2] | 0) + 12 >> 2] | 0)) {
	                    c[l >> 2] = Hb[c[135760 >> 2] & 511](c[(c[g >> 2] | 0) + 20 >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] << 2 << 2) | 0;
	                    if (c[l >> 2] | 0) {
	                        c[(c[g >> 2] | 0) + 20 >> 2] = c[l >> 2];
	                        k = (c[g >> 2] | 0) + 12 | 0;
	                        c[k >> 2] = c[k >> 2] << 1;
	                        break
	                    }
	                    c[f >> 2] = -1;
	                    n = c[f >> 2] | 0;
	                    i = e;
	                    return n | 0
	                } while (0);
	                c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + (c[(c[g >> 2] | 0) + 8 >> 2] << 1 << 2) >> 2] = c[h >> 2];
	                h = c[j >> 2] | 0;
	                j = (c[g >> 2] | 0) + 8 | 0;
	                l = c[j >> 2] | 0;
	                c[j >> 2] = l + 1;
	                c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + ((l << 1) + 1 << 2) >> 2] = h;
	                c[f >> 2] = (c[(c[g >> 2] | 0) + 8 >> 2] | 0) - 1;
	                n = c[f >> 2] | 0;
	                i = e;
	                return n | 0
	            }

	            function dR(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 24 | 0;
	                j = g + 16 | 0;
	                k = g + 12 | 0;
	                l = g + 8 | 0;
	                m = g + 4 | 0;
	                n = g;
	                c[g + 20 >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                do if ((c[(c[j >> 2] | 0) + 20 >> 2] | 0) >= (c[(c[j >> 2] | 0) + 24 >> 2] | 0)) {
	                    c[n >> 2] = Hb[c[135760 >> 2] & 511](c[(c[j >> 2] | 0) + 28 >> 2] | 0, (c[(c[j >> 2] | 0) + 24 >> 2] << 1) * 12 | 0) | 0;
	                    if (c[n >> 2] | 0) {
	                        c[(c[j >> 2] | 0) + 28 >> 2] = c[n >> 2];
	                        f = (c[j >> 2] | 0) + 24 | 0;
	                        c[f >> 2] = c[f >> 2] << 1;
	                        break
	                    }
	                    c[h >> 2] = -1;
	                    o = c[h >> 2] | 0;
	                    i = g;
	                    return o | 0
	                } while (0);
	                c[(c[(c[j >> 2] | 0) + 28 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 20 >> 2] | 0) * 12 | 0) >> 2] = c[k >> 2];
	                c[(c[(c[j >> 2] | 0) + 28 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 20 >> 2] | 0) * 12 | 0) + 4 >> 2] = c[l >> 2];
	                c[(c[(c[j >> 2] | 0) + 28 >> 2] | 0) + ((c[(c[j >> 2] | 0) + 20 >> 2] | 0) * 12 | 0) + 8 >> 2] = c[m >> 2];
	                m = (c[j >> 2] | 0) + 20 | 0;
	                c[m >> 2] = (c[m >> 2] | 0) + 1;
	                c[h >> 2] = 0;
	                o = c[h >> 2] | 0;
	                i = g;
	                return o | 0
	            }

	            function eR(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                b = i;
	                i = i + 48 | 0;
	                e = b + 32 | 0;
	                f = b + 28 | 0;
	                g = b + 24 | 0;
	                h = b + 20 | 0;
	                j = b + 16 | 0;
	                k = b + 12 | 0;
	                l = b + 8 | 0;
	                m = b + 4 | 0;
	                n = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                c[g >> 2] = 0;
	                c[h >> 2] = 0;
	                c[j >> 2] = 0;
	                while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)o = 1; else {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            o = 1;
	                            break
	                        }
	                        o = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                    } while (0);
	                    p = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                    if (!o)break;
	                    a = c[e >> 2] | 0;
	                    if (!p)continue;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1
	                }
	                o = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                a:do if ((p | 0) == 46) {
	                    a = c[e >> 2] | 0;
	                    if (o)c[a >> 2] = (c[a >> 2] | 0) + 1;
	                    if (!(dR(c[e >> 2] | 0, c[(c[e >> 2] | 0) + 16 >> 2] | 0, 2, 0, 0) | 0)) {
	                        i = b;
	                        return
	                    }
	                } else {
	                    a = c[e >> 2] | 0;
	                    if ((o | 0) == 64) {
	                        q = c[e >> 2] | 0;
	                        if (c[(c[a + 16 >> 2] | 0) + 16 >> 2] & 2) {
	                            c[q + 8 >> 2] = 1;
	                            i = b;
	                            return
	                        }
	                        r = c[e >> 2] | 0;
	                        if (d[c[q >> 2] >> 0] | 0)c[r >> 2] = (c[r >> 2] | 0) + 1;
	                        fR(c[e >> 2] | 0);
	                        if (c[(c[e >> 2] | 0) + 8 >> 2] | 0)break;
	                        i = b;
	                        return
	                    }
	                    c[g >> 2] = jR(a) | 0;
	                    a = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                    if (!(c[g >> 2] | 0)) {
	                        r = c[e >> 2] | 0;
	                        if ((a | 0) != 42) {
	                            c[r + 8 >> 2] = 1;
	                            i = b;
	                            return
	                        }
	                        q = c[e >> 2] | 0;
	                        if (d[c[r >> 2] >> 0] | 0)c[q >> 2] = (c[q >> 2] | 0) + 1;
	                        if (dR(c[e >> 2] | 0, c[(c[e >> 2] | 0) + 16 >> 2] | 0, 8, 0, 0) | 0)break;
	                        i = b;
	                        return
	                    }
	                    do if ((a | 0) != 32) {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            s = 29;
	                            break
	                        }
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13)s = 29
	                    } else s = 29; while (0);
	                    b:do if ((s | 0) == 29) {
	                        c[j >> 2] = 1;
	                        while (1) {
	                            do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                                if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                                if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13)break b
	                            } while (0);
	                            a = c[e >> 2] | 0;
	                            if (!(d[c[c[e >> 2] >> 2] >> 0] | 0))continue;
	                            c[a >> 2] = (c[a >> 2] | 0) + 1
	                        }
	                    } while (0);
	                    a = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                    if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 58) {
	                        if ((a | 0) != 42) {
	                            if (dR(c[e >> 2] | 0, c[(c[e >> 2] | 0) + 16 >> 2] | 0, 2, c[g >> 2] | 0, 0) | 0)break;
	                            i = b;
	                            return
	                        }
	                        q = c[e >> 2] | 0;
	                        if (c[g >> 2] | 0) {
	                            c[q + 8 >> 2] = 1;
	                            break
	                        }
	                        r = c[e >> 2] | 0;
	                        if (d[c[q >> 2] >> 0] | 0)c[r >> 2] = (c[r >> 2] | 0) + 1;
	                        if (dR(c[e >> 2] | 0, c[(c[e >> 2] | 0) + 16 >> 2] | 0, 8, c[f >> 2] | 0, 0) | 0)break;
	                        i = b;
	                        return
	                    }
	                    r = c[e >> 2] | 0;
	                    if (a)c[r >> 2] = (c[r >> 2] | 0) + 1;
	                    if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 58) {
	                        c[k >> 2] = c[g >> 2];
	                        do if ((c[j >> 2] | 0) == 0 ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32 : 0) {
	                            if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                            if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13) {
	                                c[f >> 2] = kR(c[e >> 2] | 0) | 0;
	                                do if ((((d[c[k >> 2] >> 0] | 0 | 0) == 120 ? (d[(c[k >> 2] | 0) + 1 >> 0] | 0 | 0) == 109 : 0) ? (d[(c[k >> 2] | 0) + 2 >> 0] | 0 | 0) == 108 : 0) ? (d[(c[k >> 2] | 0) + 3 >> 0] | 0 | 0) == 0 : 0)if (c[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) {
	                                    c[h >> 2] = AP(c[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0, 200288, -1) | 0;
	                                    break
	                                } else {
	                                    c[h >> 2] = my(200288) | 0;
	                                    break
	                                } else s = 53; while (0);
	                                if ((s | 0) == 53) {
	                                    c[l >> 2] = 0;
	                                    while (1) {
	                                        if ((c[l >> 2] | 0) >= (c[(c[e >> 2] | 0) + 28 >> 2] | 0))break;
	                                        if (qy(c[(c[(c[e >> 2] | 0) + 24 >> 2] | 0) + ((c[l >> 2] << 1) + 1 << 2) >> 2] | 0, c[k >> 2] | 0) | 0) {
	                                            s = 56;
	                                            break
	                                        }
	                                        c[l >> 2] = (c[l >> 2] | 0) + 1
	                                    }
	                                    do if ((s | 0) == 56)if (c[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) {
	                                        c[h >> 2] = AP(c[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0, c[(c[(c[e >> 2] | 0) + 24 >> 2] | 0) + (c[l >> 2] << 1 << 2) >> 2] | 0, -1) | 0;
	                                        break
	                                    } else {
	                                        c[h >> 2] = my(c[(c[(c[e >> 2] | 0) + 24 >> 2] | 0) + (c[l >> 2] << 1 << 2) >> 2] | 0) | 0;
	                                        break
	                                    } while (0);
	                                    if ((c[l >> 2] | 0) >= (c[(c[e >> 2] | 0) + 28 >> 2] | 0)) {
	                                        c[(c[e >> 2] | 0) + 8 >> 2] = 1;
	                                        break a
	                                    }
	                                }
	                                if (!(c[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0))zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                                c[g >> 2] = 0;
	                                r = c[e >> 2] | 0;
	                                if (c[f >> 2] | 0) {
	                                    if (dR(r, c[(c[e >> 2] | 0) + 16 >> 2] | 0, 2, c[f >> 2] | 0, c[h >> 2] | 0) | 0)break a;
	                                    i = b;
	                                    return
	                                }
	                                a = c[e >> 2] | 0;
	                                if ((d[c[r >> 2] >> 0] | 0 | 0) != 42) {
	                                    c[a + 8 >> 2] = 1;
	                                    break a
	                                }
	                                r = c[e >> 2] | 0;
	                                if (d[c[a >> 2] >> 0] | 0)c[r >> 2] = (c[r >> 2] | 0) + 1;
	                                if (dR(c[e >> 2] | 0, c[(c[e >> 2] | 0) + 16 >> 2] | 0, 7, c[h >> 2] | 0, 0) | 0)break a;
	                                i = b;
	                                return
	                            }
	                        } while (0);
	                        c[(c[e >> 2] | 0) + 8 >> 2] = 1;
	                        break
	                    }
	                    r = c[e >> 2] | 0;
	                    if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[r >> 2] = (c[r >> 2] | 0) + 1;
	                    if (!(qy(c[g >> 2] | 0, 200328) | 0)) {
	                        r = (qy(c[g >> 2] | 0, 200336) | 0) != 0;
	                        a = c[e >> 2] | 0;
	                        if (!r) {
	                            c[a + 8 >> 2] = 1;
	                            break
	                        }
	                        if (!(c[(c[a + 16 >> 2] | 0) + 4 >> 2] | 0))zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                        c[g >> 2] = 0;
	                        a = c[e >> 2] | 0;
	                        if (c[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 16 >> 2] & 2) {
	                            c[a + 8 >> 2] = 1;
	                            break
	                        }
	                        fR(a);
	                        if (c[(c[e >> 2] | 0) + 8 >> 2] | 0)break;
	                        i = b;
	                        return
	                    }
	                    if (!(c[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0))zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                    c[g >> 2] = kR(c[e >> 2] | 0) | 0;
	                    a = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                    if (!(c[g >> 2] | 0)) {
	                        r = c[e >> 2] | 0;
	                        if ((a | 0) != 42) {
	                            c[r + 8 >> 2] = 1;
	                            break
	                        }
	                        q = c[e >> 2] | 0;
	                        if (d[c[r >> 2] >> 0] | 0)c[q >> 2] = (c[q >> 2] | 0) + 1;
	                        if (dR(c[e >> 2] | 0, c[(c[e >> 2] | 0) + 16 >> 2] | 0, 8, 0, 0) | 0)break;
	                        i = b;
	                        return
	                    }
	                    if ((a | 0) != 58) {
	                        if (dR(c[e >> 2] | 0, c[(c[e >> 2] | 0) + 16 >> 2] | 0, 3, c[g >> 2] | 0, 0) | 0)break;
	                        i = b;
	                        return
	                    }
	                    c[m >> 2] = c[g >> 2];
	                    a = c[e >> 2] | 0;
	                    if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[a >> 2] = (c[a >> 2] | 0) + 1;
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13) {
	                            c[f >> 2] = kR(c[e >> 2] | 0) | 0;
	                            do if ((d[c[m >> 2] >> 0] | 0 | 0) == 120) {
	                                if ((d[(c[m >> 2] | 0) + 1 >> 0] | 0 | 0) != 109) {
	                                    s = 97;
	                                    break
	                                }
	                                if ((d[(c[m >> 2] | 0) + 2 >> 0] | 0 | 0) != 108) {
	                                    s = 97;
	                                    break
	                                }
	                                if (d[(c[m >> 2] | 0) + 3 >> 0] | 0) {
	                                    s = 97;
	                                    break
	                                }
	                                if (c[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) {
	                                    c[h >> 2] = AP(c[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0, 200288, -1) | 0;
	                                    break
	                                } else {
	                                    c[h >> 2] = my(200288) | 0;
	                                    break
	                                }
	                            } else s = 97; while (0);
	                            do if ((s | 0) == 97) {
	                                c[n >> 2] = 0;
	                                while (1) {
	                                    if ((c[n >> 2] | 0) >= (c[(c[e >> 2] | 0) + 28 >> 2] | 0))break;
	                                    if (qy(c[(c[(c[e >> 2] | 0) + 24 >> 2] | 0) + ((c[n >> 2] << 1) + 1 << 2) >> 2] | 0, c[m >> 2] | 0) | 0) {
	                                        s = 100;
	                                        break
	                                    }
	                                    c[n >> 2] = (c[n >> 2] | 0) + 1
	                                }
	                                do if ((s | 0) == 100)if (c[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) {
	                                    c[h >> 2] = AP(c[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0, c[(c[(c[e >> 2] | 0) + 24 >> 2] | 0) + (c[n >> 2] << 1 << 2) >> 2] | 0, -1) | 0;
	                                    break
	                                } else {
	                                    c[h >> 2] = my(c[(c[(c[e >> 2] | 0) + 24 >> 2] | 0) + (c[n >> 2] << 1 << 2) >> 2] | 0) | 0;
	                                    break
	                                } while (0);
	                                if ((c[n >> 2] | 0) < (c[(c[e >> 2] | 0) + 28 >> 2] | 0))break;
	                                c[(c[e >> 2] | 0) + 8 >> 2] = 1;
	                                break a
	                            } while (0);
	                            if (!(c[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0))zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                            c[g >> 2] = 0;
	                            a = c[e >> 2] | 0;
	                            if (c[f >> 2] | 0) {
	                                if (dR(a, c[(c[e >> 2] | 0) + 16 >> 2] | 0, 3, c[f >> 2] | 0, c[h >> 2] | 0) | 0)break a;
	                                i = b;
	                                return
	                            }
	                            q = c[e >> 2] | 0;
	                            if ((d[c[a >> 2] >> 0] | 0 | 0) != 42) {
	                                c[q + 8 >> 2] = 1;
	                                break a
	                            }
	                            a = c[e >> 2] | 0;
	                            if (d[c[q >> 2] >> 0] | 0)c[a >> 2] = (c[a >> 2] | 0) + 1;
	                            if (dR(c[e >> 2] | 0, c[(c[e >> 2] | 0) + 16 >> 2] | 0, 7, c[h >> 2] | 0, 0) | 0)break a;
	                            i = b;
	                            return
	                        }
	                    } while (0);
	                    c[(c[e >> 2] | 0) + 8 >> 2] = 1
	                } while (0);
	                if ((c[h >> 2] | 0) != 0 ? (c[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) == 0 : 0)zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                if ((c[f >> 2] | 0) != 0 ? (c[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) == 0 : 0)zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                if (!(c[g >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) {
	                    i = b;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[g >> 2] | 0);
	                i = b;
	                return
	            }

	            function fR(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                b = i;
	                i = i + 32 | 0;
	                e = b + 20 | 0;
	                f = b + 16 | 0;
	                g = b + 12 | 0;
	                h = b + 8 | 0;
	                j = b + 4 | 0;
	                k = b;
	                c[e >> 2] = a;
	                c[f >> 2] = 0;
	                c[g >> 2] = 0;
	                c[h >> 2] = 0;
	                while (1) {
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 32)l = 1; else {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            l = 1;
	                            break
	                        }
	                        l = (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) == 13
	                    } while (0);
	                    m = c[e >> 2] | 0;
	                    if (!l)break;
	                    a = c[e >> 2] | 0;
	                    if (!(d[c[m >> 2] >> 0] | 0))continue;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1
	                }
	                c[g >> 2] = jR(m) | 0;
	                m = d[c[c[e >> 2] >> 2] >> 0] | 0;
	                a:do if (!(c[g >> 2] | 0)) {
	                    l = c[e >> 2] | 0;
	                    if ((m | 0) != 42) {
	                        c[l + 8 >> 2] = 1;
	                        i = b;
	                        return
	                    }
	                    if (!(dR(l, c[(c[e >> 2] | 0) + 16 >> 2] | 0, 4, 0, 0) | 0)) {
	                        l = c[e >> 2] | 0;
	                        if (!(d[c[c[e >> 2] >> 2] >> 0] | 0)) {
	                            i = b;
	                            return
	                        }
	                        c[l >> 2] = (c[l >> 2] | 0) + 1;
	                        i = b;
	                        return
	                    }
	                } else {
	                    if ((m | 0) != 58) {
	                        if (dR(c[e >> 2] | 0, c[(c[e >> 2] | 0) + 16 >> 2] | 0, 4, c[g >> 2] | 0, 0) | 0)break;
	                        i = b;
	                        return
	                    }
	                    c[k >> 2] = c[g >> 2];
	                    l = c[e >> 2] | 0;
	                    if (d[c[c[e >> 2] >> 2] >> 0] | 0)c[l >> 2] = (c[l >> 2] | 0) + 1;
	                    do if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 32) {
	                        if (9 <= (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0)break;
	                        if ((d[c[c[e >> 2] >> 2] >> 0] | 0 | 0) != 13) {
	                            c[f >> 2] = kR(c[e >> 2] | 0) | 0;
	                            do if ((((d[c[k >> 2] >> 0] | 0 | 0) == 120 ? (d[(c[k >> 2] | 0) + 1 >> 0] | 0 | 0) == 109 : 0) ? (d[(c[k >> 2] | 0) + 2 >> 0] | 0 | 0) == 108 : 0) ? (d[(c[k >> 2] | 0) + 3 >> 0] | 0 | 0) == 0 : 0)if (c[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) {
	                                c[h >> 2] = AP(c[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0, 200288, -1) | 0;
	                                break
	                            } else {
	                                c[h >> 2] = my(200288) | 0;
	                                break
	                            } else n = 32; while (0);
	                            if ((n | 0) == 32) {
	                                c[j >> 2] = 0;
	                                while (1) {
	                                    if ((c[j >> 2] | 0) >= (c[(c[e >> 2] | 0) + 28 >> 2] | 0))break;
	                                    if (qy(c[(c[(c[e >> 2] | 0) + 24 >> 2] | 0) + ((c[j >> 2] << 1) + 1 << 2) >> 2] | 0, c[k >> 2] | 0) | 0) {
	                                        n = 35;
	                                        break
	                                    }
	                                    c[j >> 2] = (c[j >> 2] | 0) + 1
	                                }
	                                do if ((n | 0) == 35)if (c[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) {
	                                    c[h >> 2] = AP(c[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0, c[(c[(c[e >> 2] | 0) + 24 >> 2] | 0) + (c[j >> 2] << 1 << 2) >> 2] | 0, -1) | 0;
	                                    break
	                                } else {
	                                    c[h >> 2] = my(c[(c[(c[e >> 2] | 0) + 24 >> 2] | 0) + (c[j >> 2] << 1 << 2) >> 2] | 0) | 0;
	                                    break
	                                } while (0);
	                                if ((c[j >> 2] | 0) >= (c[(c[e >> 2] | 0) + 28 >> 2] | 0)) {
	                                    c[(c[e >> 2] | 0) + 8 >> 2] = 1;
	                                    break a
	                                }
	                            }
	                            if (!(c[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0))zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                            l = c[e >> 2] | 0;
	                            if (c[f >> 2] | 0) {
	                                if (dR(l, c[(c[e >> 2] | 0) + 16 >> 2] | 0, 4, c[f >> 2] | 0, c[h >> 2] | 0) | 0)break a;
	                                i = b;
	                                return
	                            }
	                            a = c[e >> 2] | 0;
	                            if ((d[c[l >> 2] >> 0] | 0 | 0) != 42) {
	                                c[a + 8 >> 2] = 1;
	                                break a
	                            }
	                            l = c[e >> 2] | 0;
	                            if (d[c[a >> 2] >> 0] | 0)c[l >> 2] = (c[l >> 2] | 0) + 1;
	                            if (dR(c[e >> 2] | 0, c[(c[e >> 2] | 0) + 16 >> 2] | 0, 4, 0, c[h >> 2] | 0) | 0)break a;
	                            i = b;
	                            return
	                        }
	                    } while (0);
	                    if (!(c[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0))zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    c[(c[e >> 2] | 0) + 8 >> 2] = 1
	                } while (0);
	                if ((c[h >> 2] | 0) != 0 ? (c[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) == 0 : 0)zb[c[135736 >> 2] & 511](c[h >> 2] | 0);
	                if (!(c[f >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[(c[e >> 2] | 0) + 16 >> 2] | 0) + 4 >> 2] | 0) {
	                    i = b;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                i = b;
	                return
	            }

	            function gR(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[e >> 2] = (c[e >> 2] | 0) < 4 ? 4 : a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](20) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = c[f >> 2] | 0;
	                c[a + 0 >> 2] = 0;
	                c[a + 4 >> 2] = 0;
	                c[a + 8 >> 2] = 0;
	                c[a + 12 >> 2] = 0;
	                c[a + 16 >> 2] = 0;
	                a = Cb[c[135744 >> 2] & 511](c[e >> 2] << 4) | 0;
	                c[(c[f >> 2] | 0) + 12 >> 2] = a;
	                if (!(c[(c[f >> 2] | 0) + 12 >> 2] | 0)) {
	                    zb[c[135736 >> 2] & 511](c[f >> 2] | 0);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    c[(c[f >> 2] | 0) + 4 >> 2] = 0;
	                    c[(c[f >> 2] | 0) + 8 >> 2] = c[e >> 2];
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function hR(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                g = i;
	                i = i + 32 | 0;
	                h = g + 24 | 0;
	                j = g + 20 | 0;
	                k = g + 16 | 0;
	                l = g + 12 | 0;
	                m = g + 8 | 0;
	                n = g + 4 | 0;
	                o = g;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                do if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) >= (c[(c[j >> 2] | 0) + 8 >> 2] | 0)) {
	                    c[o >> 2] = Hb[c[135760 >> 2] & 511](c[(c[j >> 2] | 0) + 12 >> 2] | 0, c[(c[j >> 2] | 0) + 8 >> 2] << 1 << 4) | 0;
	                    if (c[o >> 2] | 0) {
	                        c[(c[j >> 2] | 0) + 12 >> 2] = c[o >> 2];
	                        f = (c[j >> 2] | 0) + 8 | 0;
	                        c[f >> 2] = c[f >> 2] << 1;
	                        break
	                    }
	                    c[h >> 2] = -1;
	                    p = c[h >> 2] | 0;
	                    i = g;
	                    return p | 0
	                } while (0);
	                f = (c[j >> 2] | 0) + 4 | 0;
	                e = c[f >> 2] | 0;
	                c[f >> 2] = e + 1;
	                c[o >> 2] = (c[(c[j >> 2] | 0) + 12 >> 2] | 0) + (e << 4);
	                c[c[o >> 2] >> 2] = c[n >> 2];
	                c[(c[o >> 2] | 0) + 4 >> 2] = c[k >> 2];
	                c[(c[o >> 2] | 0) + 8 >> 2] = c[l >> 2];
	                c[(c[o >> 2] | 0) + 12 >> 2] = c[m >> 2];
	                c[h >> 2] = (c[(c[j >> 2] | 0) + 4 >> 2] | 0) - 1;
	                p = c[h >> 2] | 0;
	                i = g;
	                return p | 0
	            }

	            function iR(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                do if ((c[(c[g >> 2] | 0) + 8 >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) > 0 : 0) {
	                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) <= (c[c[g >> 2] >> 2] | 0)) {
	                        c[k >> 2] = Hb[c[135760 >> 2] & 511](c[(c[g >> 2] | 0) + 8 >> 2] | 0, c[(c[g >> 2] | 0) + 4 >> 2] << 1 << 3) | 0;
	                        if (c[k >> 2] | 0) {
	                            c[(c[g >> 2] | 0) + 8 >> 2] = c[k >> 2];
	                            d = (c[g >> 2] | 0) + 4 | 0;
	                            c[d >> 2] = c[d >> 2] << 1;
	                            break
	                        }
	                        c[f >> 2] = -1;
	                        l = c[f >> 2] | 0;
	                        i = e;
	                        return l | 0
	                    }
	                } else m = 3; while (0);
	                if ((m | 0) == 3) {
	                    c[(c[g >> 2] | 0) + 4 >> 2] = 4;
	                    c[c[g >> 2] >> 2] = 0;
	                    m = Cb[c[135744 >> 2] & 511](32) | 0;
	                    c[(c[g >> 2] | 0) + 8 >> 2] = m
	                }
	                c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + (c[c[g >> 2] >> 2] << 3) >> 2] = c[h >> 2];
	                h = c[j >> 2] | 0;
	                j = c[g >> 2] | 0;
	                m = c[j >> 2] | 0;
	                c[j >> 2] = m + 1;
	                c[(c[(c[g >> 2] | 0) + 8 >> 2] | 0) + (m << 3) + 4 >> 2] = h;
	                c[f >> 2] = 0;
	                l = c[f >> 2] | 0;
	                i = e;
	                return l | 0
	            }

	            function jR(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                b = i;
	                i = i + 32 | 0;
	                e = b + 24 | 0;
	                f = b + 20 | 0;
	                g = b + 16 | 0;
	                h = b + 12 | 0;
	                j = b + 8 | 0;
	                k = b + 4 | 0;
	                l = b;
	                c[f >> 2] = a;
	                c[j >> 2] = 0;
	                while (1) {
	                    do if ((d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) == 32)m = 1; else {
	                        if (9 <= (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            m = 1;
	                            break
	                        }
	                        m = (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) == 13
	                    } while (0);
	                    n = c[c[f >> 2] >> 2] | 0;
	                    if (!m)break;
	                    a = c[f >> 2] | 0;
	                    if (!(d[n >> 0] | 0))continue;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1
	                }
	                c[g >> 2] = n;
	                c[h >> 2] = n;
	                c[k >> 2] = oe(0, c[h >> 2] | 0, l) | 0;
	                n = c[k >> 2] | 0;
	                if ((c[k >> 2] | 0) < 256) {
	                    if (((!(65 <= (n | 0) & (c[k >> 2] | 0) <= 90) ? !(97 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 122) : 0) ? !(192 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 214) : 0) ? !(216 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 246 | 248 <= (c[k >> 2] | 0)) : 0)o = 15
	                } else if (!(DQ(n, 199744) | 0))o = 15;
	                do if ((o | 0) == 15) {
	                    n = c[k >> 2] | 0;
	                    if ((c[k >> 2] | 0) < 256) {
	                        if ((n | 0) == 95)break
	                    } else {
	                        if (19968 <= (n | 0) & (c[k >> 2] | 0) <= 40869 | (c[k >> 2] | 0) == 12295)break;
	                        if (!((12321 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 12329 ^ 1) & (c[k >> 2] | 0) != 95))break
	                    }
	                    c[e >> 2] = 0;
	                    p = c[e >> 2] | 0;
	                    i = b;
	                    return p | 0
	                } while (0);
	                a:while (1) {
	                    n = c[k >> 2] | 0;
	                    if ((c[k >> 2] | 0) < 256) {
	                        if (((!(65 <= (n | 0) & (c[k >> 2] | 0) <= 90) ? !(97 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 122) : 0) ? !(192 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 214) : 0) ? !(216 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 246 | 248 <= (c[k >> 2] | 0)) : 0)o = 26
	                    } else if (!(DQ(n, 199744) | 0))o = 26;
	                    do if ((o | 0) == 26) {
	                        o = 0;
	                        if ((c[k >> 2] | 0) >= 256) {
	                            if (19968 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 40869 | (c[k >> 2] | 0) == 12295)break;
	                            if (12321 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 12329)break
	                        }
	                        n = c[k >> 2] | 0;
	                        if ((c[k >> 2] | 0) < 256) {
	                            if (48 <= (n | 0) & (c[k >> 2] | 0) <= 57 | (c[k >> 2] | 0) == 46 | (c[k >> 2] | 0) == 45 | (c[k >> 2] | 0) == 95)break
	                        } else {
	                            m = (DQ(n, 200216) | 0) != 0;
	                            if (m | (c[k >> 2] | 0) == 46 | (c[k >> 2] | 0) == 45 | (c[k >> 2] | 0) == 95)break
	                        }
	                        if ((c[k >> 2] | 0) >= 256 ? (DQ(c[k >> 2] | 0, 200144) | 0) != 0 : 0)break;
	                        m = c[k >> 2] | 0;
	                        if ((c[k >> 2] | 0) < 256)q = (m | 0) == 183 & 1; else q = DQ(m, 200272) | 0;
	                        if (!q)break a
	                    } while (0);
	                    c[h >> 2] = (c[h >> 2] | 0) + (c[l >> 2] | 0);
	                    c[k >> 2] = oe(0, c[h >> 2] | 0, l) | 0
	                }
	                if (c[(c[f >> 2] | 0) + 12 >> 2] | 0)c[j >> 2] = AP(c[(c[f >> 2] | 0) + 12 >> 2] | 0, c[g >> 2] | 0, (c[h >> 2] | 0) - (c[g >> 2] | 0) | 0) | 0; else c[j >> 2] = ly(c[g >> 2] | 0, (c[h >> 2] | 0) - (c[g >> 2] | 0) | 0) | 0;
	                c[c[f >> 2] >> 2] = c[h >> 2];
	                c[e >> 2] = c[j >> 2];
	                p = c[e >> 2] | 0;
	                i = b;
	                return p | 0
	            }

	            function kR(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                b = i;
	                i = i + 32 | 0;
	                e = b + 24 | 0;
	                f = b + 20 | 0;
	                g = b + 16 | 0;
	                h = b + 12 | 0;
	                j = b + 8 | 0;
	                k = b + 4 | 0;
	                l = b;
	                c[f >> 2] = a;
	                c[j >> 2] = 0;
	                while (1) {
	                    do if ((d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) == 32)m = 1; else {
	                        if (9 <= (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) ? (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) <= 10 : 0) {
	                            m = 1;
	                            break
	                        }
	                        m = (d[c[c[f >> 2] >> 2] >> 0] | 0 | 0) == 13
	                    } while (0);
	                    n = c[c[f >> 2] >> 2] | 0;
	                    if (!m)break;
	                    a = c[f >> 2] | 0;
	                    if (!(d[n >> 0] | 0))continue;
	                    c[a >> 2] = (c[a >> 2] | 0) + 1
	                }
	                c[g >> 2] = n;
	                c[h >> 2] = n;
	                c[k >> 2] = oe(0, c[h >> 2] | 0, l) | 0;
	                n = c[k >> 2] | 0;
	                if ((c[k >> 2] | 0) < 256) {
	                    if (((!(65 <= (n | 0) & (c[k >> 2] | 0) <= 90) ? !(97 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 122) : 0) ? !(192 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 214) : 0) ? !(216 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 246 | 248 <= (c[k >> 2] | 0)) : 0)o = 15
	                } else if (!(DQ(n, 199744) | 0))o = 15;
	                do if ((o | 0) == 15) {
	                    n = c[k >> 2] | 0;
	                    if ((c[k >> 2] | 0) < 256) {
	                        if (!((n | 0) != 95 & (c[k >> 2] | 0) != 58))break
	                    } else {
	                        if (19968 <= (n | 0) & (c[k >> 2] | 0) <= 40869 | (c[k >> 2] | 0) == 12295)break;
	                        if (!((12321 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 12329 ^ 1) & (c[k >> 2] | 0) != 95 & (c[k >> 2] | 0) != 58))break
	                    }
	                    c[e >> 2] = 0;
	                    p = c[e >> 2] | 0;
	                    i = b;
	                    return p | 0
	                } while (0);
	                a:while (1) {
	                    n = c[k >> 2] | 0;
	                    if ((c[k >> 2] | 0) < 256) {
	                        if (((!(65 <= (n | 0) & (c[k >> 2] | 0) <= 90) ? !(97 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 122) : 0) ? !(192 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 214) : 0) ? !(216 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 246 | 248 <= (c[k >> 2] | 0)) : 0)o = 26
	                    } else if (!(DQ(n, 199744) | 0))o = 26;
	                    do if ((o | 0) == 26) {
	                        o = 0;
	                        if ((c[k >> 2] | 0) >= 256) {
	                            if (19968 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 40869 | (c[k >> 2] | 0) == 12295)break;
	                            if (12321 <= (c[k >> 2] | 0) & (c[k >> 2] | 0) <= 12329)break
	                        }
	                        n = c[k >> 2] | 0;
	                        if ((c[k >> 2] | 0) < 256) {
	                            if (48 <= (n | 0) & (c[k >> 2] | 0) <= 57 | (c[k >> 2] | 0) == 46 | (c[k >> 2] | 0) == 45 | (c[k >> 2] | 0) == 95)break
	                        } else {
	                            m = (DQ(n, 200216) | 0) != 0;
	                            if (m | (c[k >> 2] | 0) == 46 | (c[k >> 2] | 0) == 45 | (c[k >> 2] | 0) == 95)break
	                        }
	                        if ((c[k >> 2] | 0) >= 256 ? (DQ(c[k >> 2] | 0, 200144) | 0) != 0 : 0)break;
	                        m = c[k >> 2] | 0;
	                        if ((c[k >> 2] | 0) < 256)q = (m | 0) == 183 & 1; else q = DQ(m, 200272) | 0;
	                        if (!q)break a
	                    } while (0);
	                    c[h >> 2] = (c[h >> 2] | 0) + (c[l >> 2] | 0);
	                    c[k >> 2] = oe(0, c[h >> 2] | 0, l) | 0
	                }
	                if (c[(c[f >> 2] | 0) + 12 >> 2] | 0)c[j >> 2] = AP(c[(c[f >> 2] | 0) + 12 >> 2] | 0, c[g >> 2] | 0, (c[h >> 2] | 0) - (c[g >> 2] | 0) | 0) | 0; else c[j >> 2] = ly(c[g >> 2] | 0, (c[h >> 2] | 0) - (c[g >> 2] | 0) | 0) | 0;
	                c[c[f >> 2] >> 2] = c[h >> 2];
	                c[e >> 2] = c[j >> 2];
	                p = c[e >> 2] | 0;
	                i = b;
	                return p | 0
	            }

	            function lR(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                do if ((c[f >> 2] | 0) == 0 & (c[g >> 2] | 0) == 0)c[e >> 2] = -1; else {
	                    if (c[g >> 2] | 0) {
	                        if (qy(c[g >> 2] | 0, 200352) | 0) {
	                            c[e >> 2] = 1;
	                            break
	                        }
	                        if (qy(c[g >> 2] | 0, 200392) | 0) {
	                            c[e >> 2] = 1;
	                            break
	                        }
	                        if (qy(c[g >> 2] | 0, 200432) | 0) {
	                            c[e >> 2] = 1;
	                            break
	                        }
	                    }
	                    if (c[f >> 2] | 0) {
	                        if (qy(c[f >> 2] | 0, 200472) | 0) {
	                            c[e >> 2] = 1;
	                            break
	                        }
	                        if (qy(c[f >> 2] | 0, 200528) | 0) {
	                            c[e >> 2] = 1;
	                            break
	                        }
	                        if (qy(c[f >> 2] | 0, 200584) | 0) {
	                            c[e >> 2] = 1;
	                            break
	                        }
	                    }
	                    c[e >> 2] = 0
	                } while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function mR(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[g >> 2] = kj() | 0;
	                if (!(c[g >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                Bm(c[g >> 2] | 0, c[f >> 2] | 0);
	                hz(c[e >> 2] | 0, c[g >> 2] | 0) | 0;
	                i = d;
	                return
	            }

	            function nR(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[g >> 2] = kj() | 0;
	                if (!(c[g >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                pm(c[g >> 2] | 0, c[f >> 2] | 0);
	                hz(c[e >> 2] | 0, c[g >> 2] | 0) | 0;
	                i = d;
	                return
	            }

	            function oR(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[g >> 2] = kj() | 0;
	                if (!(c[g >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                wm(c[g >> 2] | 0, c[f >> 2] | 0);
	                hz(c[e >> 2] | 0, c[g >> 2] | 0) | 0;
	                i = d;
	                return
	            }

	            function pR(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[g >> 2] = kj() | 0;
	                if (!(c[g >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                fd(c[g >> 2] | 0, c[f >> 2] | 0);
	                hz(c[e >> 2] | 0, c[g >> 2] | 0) | 0;
	                i = d;
	                return
	            }

	            function qR(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                while (1) {
	                    if (!(c[f >> 2] | 0))break;
	                    KR(c[e >> 2] | 0, c[f >> 2] | 0, 0);
	                    c[f >> 2] = c[c[f >> 2] >> 2]
	                }
	                i = d;
	                return
	            }

	            function rR(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 16 | 0;
	                g = e + 12 | 0;
	                h = e + 8 | 0;
	                j = e + 4 | 0;
	                k = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = LR(c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                j = Jk(c[g >> 2] | 0, c[(c[k >> 2] | 0) + 20 >> 2] | 0) | 0;
	                c[(c[k >> 2] | 0) + 24 >> 2] = j;
	                j = c[k >> 2] | 0;
	                if (!(c[(c[k >> 2] | 0) + 24 >> 2] | 0)) {
	                    MR(j);
	                    c[f >> 2] = 0;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                } else {
	                    c[f >> 2] = j;
	                    l = c[f >> 2] | 0;
	                    i = e;
	                    return l | 0
	                }
	                return 0
	            }

	            function sR(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[l >> 2] = 0;
	                c[k >> 2] = LR(c[h >> 2] | 0, c[j >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                j = Ek(c[g >> 2] | 0, c[(c[k >> 2] | 0) + 20 >> 2] | 0, c[l >> 2] | 0) | 0;
	                c[(c[k >> 2] | 0) + 24 >> 2] = j;
	                j = c[k >> 2] | 0;
	                if (!(c[(c[k >> 2] | 0) + 24 >> 2] | 0)) {
	                    MR(j);
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                } else {
	                    c[f >> 2] = j;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                return 0
	            }

	            function tR(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                do if (!((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0))if ((NR(c[f >> 2] | 0, c[g >> 2] | 0) | 0) < 0) {
	                    c[e >> 2] = -1;
	                    break
	                } else {
	                    c[e >> 2] = c[h >> 2];
	                    break
	                } else c[e >> 2] = -1; while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function uR(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    c[e >> 2] = -1;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } else {
	                    OR(c[f >> 2] | 0, c[g >> 2] | 0);
	                    c[e >> 2] = c[h >> 2];
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                return 0
	            }

	            function vR(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                do if (c[e >> 2] | 0)if (!(c[(c[e >> 2] | 0) + 24 >> 2] | 0)) {
	                    c[d >> 2] = -1;
	                    break
	                } else {
	                    c[d >> 2] = Ak(c[(c[e >> 2] | 0) + 24 >> 2] | 0) | 0;
	                    break
	                } else c[d >> 2] = -1; while (0);
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function wR(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = -1;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    c[f >> 2] = vR(c[e >> 2] | 0) | 0;
	                    MR(c[e >> 2] | 0);
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function xR(a, b, e, f) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                g = i;
	                i = i + 48 | 0;
	                h = g + 28 | 0;
	                j = g + 24 | 0;
	                k = g + 20 | 0;
	                l = g + 16 | 0;
	                m = g + 12 | 0;
	                n = g + 8 | 0;
	                o = g + 32 | 0;
	                p = g + 4 | 0;
	                q = g;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[l >> 2] = f;
	                if (!(c[l >> 2] | 0)) {
	                    i = g;
	                    return
	                }
	                f = c[l >> 2] | 0;
	                c[n >> 2] = f;
	                c[m >> 2] = f;
	                a:while (1) {
	                    if (!(d[c[n >> 2] >> 0] | 0))break;
	                    if ((d[c[n >> 2] >> 0] | 0 | 0) == 10) {
	                        if ((c[m >> 2] | 0) != (c[n >> 2] | 0))cz(c[h >> 2] | 0, c[m >> 2] | 0, (c[n >> 2] | 0) - (c[m >> 2] | 0) | 0) | 0;
	                        cz(c[h >> 2] | 0, 200640, 5) | 0;
	                        c[n >> 2] = (c[n >> 2] | 0) + 1;
	                        c[m >> 2] = c[n >> 2];
	                        continue
	                    }
	                    if ((d[c[n >> 2] >> 0] | 0 | 0) == 13) {
	                        if ((c[m >> 2] | 0) != (c[n >> 2] | 0))cz(c[h >> 2] | 0, c[m >> 2] | 0, (c[n >> 2] | 0) - (c[m >> 2] | 0) | 0) | 0;
	                        cz(c[h >> 2] | 0, 200648, 5) | 0;
	                        c[n >> 2] = (c[n >> 2] | 0) + 1;
	                        c[m >> 2] = c[n >> 2];
	                        continue
	                    }
	                    if ((d[c[n >> 2] >> 0] | 0 | 0) == 9) {
	                        if ((c[m >> 2] | 0) != (c[n >> 2] | 0))cz(c[h >> 2] | 0, c[m >> 2] | 0, (c[n >> 2] | 0) - (c[m >> 2] | 0) | 0) | 0;
	                        cz(c[h >> 2] | 0, 200656, 4) | 0;
	                        c[n >> 2] = (c[n >> 2] | 0) + 1;
	                        c[m >> 2] = c[n >> 2];
	                        continue
	                    }
	                    if ((d[c[n >> 2] >> 0] | 0 | 0) == 34) {
	                        if ((c[m >> 2] | 0) != (c[n >> 2] | 0))cz(c[h >> 2] | 0, c[m >> 2] | 0, (c[n >> 2] | 0) - (c[m >> 2] | 0) | 0) | 0;
	                        cz(c[h >> 2] | 0, 200664, 6) | 0;
	                        c[n >> 2] = (c[n >> 2] | 0) + 1;
	                        c[m >> 2] = c[n >> 2];
	                        continue
	                    }
	                    if ((d[c[n >> 2] >> 0] | 0 | 0) == 60) {
	                        if ((c[m >> 2] | 0) != (c[n >> 2] | 0))cz(c[h >> 2] | 0, c[m >> 2] | 0, (c[n >> 2] | 0) - (c[m >> 2] | 0) | 0) | 0;
	                        cz(c[h >> 2] | 0, 200672, 4) | 0;
	                        c[n >> 2] = (c[n >> 2] | 0) + 1;
	                        c[m >> 2] = c[n >> 2];
	                        continue
	                    }
	                    if ((d[c[n >> 2] >> 0] | 0 | 0) == 62) {
	                        if ((c[m >> 2] | 0) != (c[n >> 2] | 0))cz(c[h >> 2] | 0, c[m >> 2] | 0, (c[n >> 2] | 0) - (c[m >> 2] | 0) | 0) | 0;
	                        cz(c[h >> 2] | 0, 200680, 4) | 0;
	                        c[n >> 2] = (c[n >> 2] | 0) + 1;
	                        c[m >> 2] = c[n >> 2];
	                        continue
	                    }
	                    if ((d[c[n >> 2] >> 0] | 0 | 0) == 38) {
	                        if ((c[m >> 2] | 0) != (c[n >> 2] | 0))cz(c[h >> 2] | 0, c[m >> 2] | 0, (c[n >> 2] | 0) - (c[m >> 2] | 0) | 0) | 0;
	                        cz(c[h >> 2] | 0, 200688, 5) | 0;
	                        c[n >> 2] = (c[n >> 2] | 0) + 1;
	                        c[m >> 2] = c[n >> 2];
	                        continue
	                    }
	                    do if ((d[c[n >> 2] >> 0] | 0 | 0) >= 128) {
	                        if ((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 60 >> 2] | 0) != 0 : 0)break;
	                        c[p >> 2] = 0;
	                        c[q >> 2] = 1;
	                        if ((c[m >> 2] | 0) != (c[n >> 2] | 0))cz(c[h >> 2] | 0, c[m >> 2] | 0, (c[n >> 2] | 0) - (c[m >> 2] | 0) | 0) | 0;
	                        if ((d[c[n >> 2] >> 0] | 0 | 0) < 192) {
	                            PR(1400, c[k >> 2] | 0, 0);
	                            if (c[j >> 2] | 0) {
	                                f = my(200696) | 0;
	                                c[(c[j >> 2] | 0) + 60 >> 2] = f
	                            }
	                            QR(o, d[c[n >> 2] >> 0] | 0) | 0;
	                            cz(c[h >> 2] | 0, o, -1) | 0;
	                            c[n >> 2] = (c[n >> 2] | 0) + 1;
	                            c[m >> 2] = c[n >> 2];
	                            continue a
	                        }
	                        f = c[n >> 2] | 0;
	                        do if ((d[c[n >> 2] >> 0] | 0 | 0) >= 224) {
	                            l = c[n >> 2] | 0;
	                            if ((d[f >> 0] | 0 | 0) < 240) {
	                                c[p >> 2] = (d[l >> 0] | 0) & 15;
	                                c[p >> 2] = c[p >> 2] << 6;
	                                c[p >> 2] = c[p >> 2] | (d[(c[n >> 2] | 0) + 1 >> 0] | 0) & 63;
	                                c[p >> 2] = c[p >> 2] << 6;
	                                c[p >> 2] = c[p >> 2] | (d[(c[n >> 2] | 0) + 2 >> 0] | 0) & 63;
	                                c[q >> 2] = 3;
	                                break
	                            }
	                            if ((d[l >> 0] | 0 | 0) < 248) {
	                                c[p >> 2] = (d[c[n >> 2] >> 0] | 0) & 7;
	                                c[p >> 2] = c[p >> 2] << 6;
	                                c[p >> 2] = c[p >> 2] | (d[(c[n >> 2] | 0) + 1 >> 0] | 0) & 63;
	                                c[p >> 2] = c[p >> 2] << 6;
	                                c[p >> 2] = c[p >> 2] | (d[(c[n >> 2] | 0) + 2 >> 0] | 0) & 63;
	                                c[p >> 2] = c[p >> 2] << 6;
	                                c[p >> 2] = c[p >> 2] | (d[(c[n >> 2] | 0) + 3 >> 0] | 0) & 63;
	                                c[q >> 2] = 4
	                            }
	                        } else {
	                            c[p >> 2] = (d[f >> 0] | 0) & 31;
	                            c[p >> 2] = c[p >> 2] << 6;
	                            c[p >> 2] = c[p >> 2] | (d[(c[n >> 2] | 0) + 1 >> 0] | 0) & 63;
	                            c[q >> 2] = 2
	                        } while (0);
	                        b:do if ((c[q >> 2] | 0) != 1) {
	                            f = c[p >> 2] | 0;
	                            do if ((c[p >> 2] | 0) < 256) {
	                                if (!(9 <= (f | 0) & (c[p >> 2] | 0) <= 10 | (c[p >> 2] | 0) == 13 | 32 <= (c[p >> 2] | 0)))break b
	                            } else {
	                                if (256 <= (f | 0) & (c[p >> 2] | 0) <= 55295)break;
	                                if (57344 <= (c[p >> 2] | 0) & (c[p >> 2] | 0) <= 65533)break;
	                                if (!(65536 <= (c[p >> 2] | 0) & (c[p >> 2] | 0) <= 1114111))break b
	                            } while (0);
	                            QR(o, c[p >> 2] | 0) | 0;
	                            cz(c[h >> 2] | 0, o, -1) | 0;
	                            c[n >> 2] = (c[n >> 2] | 0) + (c[q >> 2] | 0);
	                            c[m >> 2] = c[n >> 2];
	                            continue a
	                        } while (0);
	                        PR(1401, c[k >> 2] | 0, 0);
	                        if (c[j >> 2] | 0) {
	                            f = my(200696) | 0;
	                            c[(c[j >> 2] | 0) + 60 >> 2] = f
	                        }
	                        QR(o, d[c[n >> 2] >> 0] | 0) | 0;
	                        cz(c[h >> 2] | 0, o, -1) | 0;
	                        c[n >> 2] = (c[n >> 2] | 0) + 1;
	                        c[m >> 2] = c[n >> 2];
	                        continue a
	                    } while (0);
	                    c[n >> 2] = (c[n >> 2] | 0) + 1
	                }
	                if ((c[m >> 2] | 0) == (c[n >> 2] | 0)) {
	                    i = g;
	                    return
	                }
	                cz(c[h >> 2] | 0, c[m >> 2] | 0, (c[n >> 2] | 0) - (c[m >> 2] | 0) | 0) | 0;
	                i = g;
	                return
	            }

	            function yR(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                h = i;
	                i = i + 160 | 0;
	                j = h + 152 | 0;
	                k = h + 148 | 0;
	                l = h + 144 | 0;
	                m = h + 140 | 0;
	                n = h + 136 | 0;
	                o = h + 132 | 0;
	                p = h + 8 | 0;
	                q = h + 4 | 0;
	                r = h;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                c[r >> 2] = 0;
	                Rf();
	                if ((c[j >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0) {
	                    i = h;
	                    return
	                }
	                if (!(c[o >> 2] | 0))c[o >> 2] = 200728;
	                g = p + 0 | 0;
	                f = g + 124 | 0;
	                do {
	                    c[g >> 2] = 0;
	                    g = g + 4 | 0
	                } while ((g | 0) < (f | 0));
	                c[p + 28 >> 2] = c[k >> 2];
	                c[p + 24 >> 2] = c[j >> 2];
	                c[p + 36 >> 2] = c[m >> 2];
	                c[p + 40 >> 2] = (c[n >> 2] | 0) != 0 ? 1 : 0;
	                c[p + 16 >> 2] = c[o >> 2];
	                SR(p);
	                o = p + 32 | 0;
	                c[o >> 2] = c[o >> 2] | 32;
	                c[q >> 2] = Nh(c[k >> 2] | 0) | 0;
	                if (c[q >> 2] | 0) {
	                    k = lR(c[(c[q >> 2] | 0) + 56 >> 2] | 0, c[(c[q >> 2] | 0) + 52 >> 2] | 0) | 0;
	                    c[r >> 2] = k;
	                    c[r >> 2] = (c[r >> 2] | 0) < 0 ? 0 : k
	                }
	                k = c[l >> 2] | 0;
	                if (c[r >> 2] | 0) {
	                    TR(p, k);
	                    i = h;
	                    return
	                } else {
	                    OR(p, k);
	                    i = h;
	                    return
	                }
	            }

	            function zR(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                Rf();
	                if (!(c[h >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                c[j >> 2] = Fk(c[f >> 2] | 0, 0) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                if ((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 13 : 0)yp(c[j >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0, 0); else yR(c[j >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0, 0, 1, 0);
	                zk(c[j >> 2] | 0) | 0;
	                i = e;
	                return
	            }

	            function AR(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                g = i;
	                i = i + 160 | 0;
	                h = g + 152 | 0;
	                j = g + 148 | 0;
	                k = g + 144 | 0;
	                l = g + 140 | 0;
	                m = g + 136 | 0;
	                n = g + 12 | 0;
	                o = g + 8 | 0;
	                p = g + 4 | 0;
	                q = g;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[m >> 2] = f;
	                c[o >> 2] = 0;
	                c[p >> 2] = 0;
	                c[q >> 2] = 0;
	                if (!(c[k >> 2] | 0))c[k >> 2] = o;
	                if (!(c[j >> 2] | 0)) {
	                    c[c[k >> 2] >> 2] = 0;
	                    i = g;
	                    return
	                }
	                c[c[j >> 2] >> 2] = 0;
	                c[c[k >> 2] >> 2] = 0;
	                if (!(c[h >> 2] | 0)) {
	                    i = g;
	                    return
	                }
	                if (!(c[l >> 2] | 0))c[l >> 2] = c[(c[h >> 2] | 0) + 60 >> 2];
	                if ((c[l >> 2] | 0) != 0 ? (c[q >> 2] = Dd(c[l >> 2] | 0) | 0, (c[q >> 2] | 0) == 0) : 0) {
	                    PR(1403, c[h >> 2] | 0, c[l >> 2] | 0);
	                    i = g;
	                    return
	                }
	                o = wk(c[q >> 2] | 0) | 0;
	                c[p >> 2] = o;
	                if (!o) {
	                    RR(200712);
	                    i = g;
	                    return
	                }
	                o = n + 0 | 0;
	                q = o + 124 | 0;
	                do {
	                    c[o >> 2] = 0;
	                    o = o + 4 | 0
	                } while ((o | 0) < (q | 0));
	                c[n + 28 >> 2] = c[h >> 2];
	                c[n + 24 >> 2] = c[p >> 2];
	                c[n + 36 >> 2] = 0;
	                c[n + 40 >> 2] = (c[m >> 2] | 0) != 0 ? 1 : 0;
	                c[n + 16 >> 2] = c[l >> 2];
	                SR(n);
	                l = n + 32 | 0;
	                c[l >> 2] = c[l >> 2] | 32;
	                NR(n, c[h >> 2] | 0) | 0;
	                Ak(c[p >> 2] | 0) | 0;
	                h = c[p >> 2] | 0;
	                if (c[(c[p >> 2] | 0) + 20 >> 2] | 0) {
	                    n = _y(c[h + 20 >> 2] | 0) | 0;
	                    c[c[k >> 2] >> 2] = n;
	                    n = Vy(c[(c[p >> 2] | 0) + 20 >> 2] | 0) | 0;
	                    l = ly(n, c[c[k >> 2] >> 2] | 0) | 0;
	                    c[c[j >> 2] >> 2] = l
	                } else {
	                    l = _y(c[h + 16 >> 2] | 0) | 0;
	                    c[c[k >> 2] >> 2] = l;
	                    l = Vy(c[(c[p >> 2] | 0) + 16 >> 2] | 0) | 0;
	                    h = ly(l, c[c[k >> 2] >> 2] | 0) | 0;
	                    c[c[j >> 2] >> 2] = h
	                }
	                zk(c[p >> 2] | 0) | 0;
	                if (c[c[j >> 2] >> 2] | 0) {
	                    i = g;
	                    return
	                }
	                if ((c[c[k >> 2] >> 2] | 0) <= 0) {
	                    i = g;
	                    return
	                }
	                c[c[k >> 2] >> 2] = 0;
	                RR(200736);
	                i = g;
	                return
	            }

	            function BR(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                AR(c[f >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0, 0, 0);
	                i = e;
	                return
	            }

	            function CR(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 12 | 0;
	                h = f + 8 | 0;
	                j = f + 4 | 0;
	                k = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                AR(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, 0, c[k >> 2] | 0);
	                i = f;
	                return
	            }

	            function DR(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f + 12 | 0;
	                h = f + 8 | 0;
	                j = f + 4 | 0;
	                k = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = e;
	                AR(c[g >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[k >> 2] | 0, 0);
	                i = f;
	                return
	            }

	            function ER(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                e = i;
	                i = i + 160 | 0;
	                f = e + 152 | 0;
	                g = e + 148 | 0;
	                h = e + 144 | 0;
	                j = e + 140 | 0;
	                k = e + 16 | 0;
	                l = e + 12 | 0;
	                m = e + 8 | 0;
	                n = e + 4 | 0;
	                o = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[n >> 2] = 0;
	                if (!(c[h >> 2] | 0)) {
	                    c[f >> 2] = -1;
	                    p = c[f >> 2] | 0;
	                    i = e;
	                    return p | 0
	                }
	                c[m >> 2] = c[(c[h >> 2] | 0) + 60 >> 2];
	                if ((c[m >> 2] | 0) != 0 ? (c[n >> 2] = Dd(c[m >> 2] | 0) | 0, (c[n >> 2] | 0) == 0) : 0) {
	                    zb[c[135736 >> 2] & 511](c[(c[h >> 2] | 0) + 60 >> 2] | 0);
	                    c[(c[h >> 2] | 0) + 60 >> 2] = 0;
	                    c[m >> 2] = 0
	                }
	                c[l >> 2] = Fk(c[g >> 2] | 0, c[n >> 2] | 0) | 0;
	                if (!(c[l >> 2] | 0)) {
	                    c[f >> 2] = -1;
	                    p = c[f >> 2] | 0;
	                    i = e;
	                    return p | 0
	                } else {
	                    n = k + 0 | 0;
	                    g = n + 124 | 0;
	                    do {
	                        c[n >> 2] = 0;
	                        n = n + 4 | 0
	                    } while ((n | 0) < (g | 0));
	                    c[k + 28 >> 2] = c[h >> 2];
	                    c[k + 24 >> 2] = c[l >> 2];
	                    c[k + 36 >> 2] = 0;
	                    c[k + 40 >> 2] = (c[j >> 2] | 0) != 0 ? 1 : 0;
	                    c[k + 16 >> 2] = c[m >> 2];
	                    SR(k);
	                    m = k + 32 | 0;
	                    c[m >> 2] = c[m >> 2] | 32;
	                    NR(k, c[h >> 2] | 0) | 0;
	                    c[o >> 2] = zk(c[l >> 2] | 0) | 0;
	                    c[f >> 2] = c[o >> 2];
	                    p = c[f >> 2] | 0;
	                    i = e;
	                    return p | 0
	                }
	                return 0
	            }

	            function FR(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                b = ER(c[e >> 2] | 0, c[f >> 2] | 0, 0) | 0;
	                i = d;
	                return b | 0
	            }

	            function GR(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                f = i;
	                i = i + 160 | 0;
	                g = f + 152 | 0;
	                h = f + 148 | 0;
	                j = f + 144 | 0;
	                k = f + 140 | 0;
	                l = f + 136 | 0;
	                m = f + 12 | 0;
	                n = f + 8 | 0;
	                o = f + 4 | 0;
	                p = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                c[o >> 2] = 0;
	                if (!(c[j >> 2] | 0)) {
	                    c[g >> 2] = -1;
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                if (!(c[k >> 2] | 0))c[k >> 2] = c[(c[j >> 2] | 0) + 60 >> 2];
	                if ((c[k >> 2] | 0) != 0 ? (c[o >> 2] = Dd(c[k >> 2] | 0) | 0, (c[o >> 2] | 0) == 0) : 0) {
	                    c[g >> 2] = -1;
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                c[n >> 2] = Ek(c[h >> 2] | 0, c[o >> 2] | 0, c[(c[j >> 2] | 0) + 36 >> 2] | 0) | 0;
	                if (!(c[n >> 2] | 0)) {
	                    c[g >> 2] = -1;
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                } else {
	                    o = m + 0 | 0;
	                    h = o + 124 | 0;
	                    do {
	                        c[o >> 2] = 0;
	                        o = o + 4 | 0
	                    } while ((o | 0) < (h | 0));
	                    c[m + 28 >> 2] = c[j >> 2];
	                    c[m + 24 >> 2] = c[n >> 2];
	                    c[m + 36 >> 2] = 0;
	                    c[m + 40 >> 2] = (c[l >> 2] | 0) != 0 ? 1 : 0;
	                    c[m + 16 >> 2] = c[k >> 2];
	                    SR(m);
	                    k = m + 32 | 0;
	                    c[k >> 2] = c[k >> 2] | 32;
	                    NR(m, c[j >> 2] | 0) | 0;
	                    c[p >> 2] = zk(c[n >> 2] | 0) | 0;
	                    c[g >> 2] = c[p >> 2];
	                    q = c[g >> 2] | 0;
	                    i = f;
	                    return q | 0
	                }
	                return 0
	            }

	            function HR(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                d = GR(c[f >> 2] | 0, c[g >> 2] | 0, c[h >> 2] | 0, 0) | 0;
	                i = e;
	                return d | 0
	            }

	            function IR(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                d = GR(c[f >> 2] | 0, c[g >> 2] | 0, 0, c[h >> 2] | 0) | 0;
	                i = e;
	                return d | 0
	            }

	            function JR(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                b = GR(c[e >> 2] | 0, c[f >> 2] | 0, 0, 0) | 0;
	                i = d;
	                return b | 0
	            }

	            function KR(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if ((c[g >> 2] | 0) == 0 | (c[f >> 2] | 0) == 0) {
	                    i = e;
	                    return
	                }
	                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 18) {
	                    i = e;
	                    return
	                }
	                if (!(c[(c[g >> 2] | 0) + 8 >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                if (qy(c[(c[g >> 2] | 0) + 12 >> 2] | 0, 201224) | 0) {
	                    i = e;
	                    return
	                }
	                if ((c[h >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 40 >> 2] | 0) == 2 : 0)UR(c[h >> 2] | 0, 2); else Ok(c[f >> 2] | 0, 1, 200760) | 0;
	                h = c[f >> 2] | 0;
	                if (c[(c[g >> 2] | 0) + 12 >> 2] | 0) {
	                    Ok(h, 6, 201752) | 0;
	                    Qk(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] | 0) | 0
	                } else Ok(h, 5, 201760) | 0;
	                Ok(c[f >> 2] | 0, 1, 201768) | 0;
	                gz(c[(c[f >> 2] | 0) + 16 >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0) | 0;
	                i = e;
	                return
	            }

	            function LR(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = Cb[c[135744 >> 2] & 511](124) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    RR(201728);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                b = (c[h >> 2] | 0) + 0 | 0;
	                a = b + 124 | 0;
	                do {
	                    c[b >> 2] = 0;
	                    b = b + 4 | 0
	                } while ((b | 0) < (a | 0));
	                do if (c[f >> 2] | 0) {
	                    b = Dd(c[f >> 2] | 0) | 0;
	                    c[(c[h >> 2] | 0) + 20 >> 2] = b;
	                    b = c[f >> 2] | 0;
	                    if (c[(c[h >> 2] | 0) + 20 >> 2] | 0) {
	                        a = my(b) | 0;
	                        c[(c[h >> 2] | 0) + 16 >> 2] = a;
	                        c[(c[h >> 2] | 0) + 116 >> 2] = 0;
	                        break
	                    }
	                    PR(1403, 0, b);
	                    MR(c[h >> 2] | 0);
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } while (0);
	                SR(c[h >> 2] | 0);
	                if ((c[(c[h >> 2] | 0) + 32 >> 2] & 4 | 0) != 0 ? (c[g >> 2] & 4 | 0) == 0 : 0)c[g >> 2] = c[g >> 2] | 4;
	                c[(c[h >> 2] | 0) + 32 >> 2] = c[g >> 2];
	                if (!(c[g >> 2] & 1)) {
	                    if (c[g >> 2] & 128)c[(c[h >> 2] | 0) + 40 >> 2] = 2
	                } else c[(c[h >> 2] | 0) + 40 >> 2] = 1;
	                c[e >> 2] = c[h >> 2];
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function MR(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 16 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 16 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 24 >> 2] | 0)zk(c[(c[d >> 2] | 0) + 24 >> 2] | 0) | 0;
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function NR(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                d = i;
	                i = i + 64 | 0;
	                e = d + 52 | 0;
	                f = d + 48 | 0;
	                g = d + 44 | 0;
	                h = d + 40 | 0;
	                j = d + 36 | 0;
	                k = d + 32 | 0;
	                l = d + 28 | 0;
	                m = d + 24 | 0;
	                n = d + 20 | 0;
	                o = d + 16 | 0;
	                p = d + 12 | 0;
	                q = d + 8 | 0;
	                r = d + 4 | 0;
	                s = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[j >> 2] = 0;
	                c[k >> 2] = c[(c[g >> 2] | 0) + 60 >> 2];
	                c[l >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                c[m >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                c[n >> 2] = c[(c[f >> 2] | 0) + 116 >> 2];
	                c[o >> 2] = c[(c[f >> 2] | 0) + 120 >> 2];
	                c[p >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                c[r >> 2] = 0;
	                Rf();
	                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 13 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 9 : 0) {
	                    c[e >> 2] = -1;
	                    t = c[e >> 2] | 0;
	                    i = d;
	                    return t | 0
	                }
	                do if (!(c[(c[f >> 2] | 0) + 16 >> 2] | 0)) {
	                    b = c[g >> 2] | 0;
	                    if (c[(c[g >> 2] | 0) + 60 >> 2] | 0) {
	                        c[m >> 2] = c[b + 60 >> 2];
	                        break
	                    }
	                    if ((c[b + 76 >> 2] | 0) != 1)c[m >> 2] = xd(c[(c[g >> 2] | 0) + 76 >> 2] | 0) | 0
	                } else c[(c[g >> 2] | 0) + 60 >> 2] = c[(c[f >> 2] | 0) + 16 >> 2]; while (0);
	                if (!(((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 13 ? (c[(c[f >> 2] | 0) + 32 >> 2] & 32 | 0) == 0 : 0) ? (c[(c[f >> 2] | 0) + 32 >> 2] & 16 | 0) == 0 : 0))u = 13;
	                if ((u | 0) == 13 ? (c[(c[f >> 2] | 0) + 32 >> 2] & 64 | 0) == 0 : 0) {
	                    if (!(((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 9 ? (c[(c[f >> 2] | 0) + 32 >> 2] & 32 | 0) == 0 : 0) ? (c[(c[f >> 2] | 0) + 32 >> 2] & 16 | 0) == 0 : 0))u = 34;
	                    a:do if ((u | 0) == 34) {
	                        c[q >> 2] = wd(c[m >> 2] | 0) | 0;
	                        if ((((c[m >> 2] | 0) != 0 & (c[l >> 2] | 0) == 0 ? (c[(c[p >> 2] | 0) + 12 >> 2] | 0) == 0 : 0) ? (c[(c[p >> 2] | 0) + 20 >> 2] | 0) == 0 : 0) ? (c[(c[f >> 2] | 0) + 32 >> 2] & 2 | 0) == 0 : 0) {
	                            do if ((c[q >> 2] | 0) != 1 & (c[q >> 2] | 0) != 0 & (c[q >> 2] | 0) != 22) {
	                                if ((VR(c[f >> 2] | 0, c[m >> 2] | 0) | 0) >= 0) {
	                                    c[r >> 2] = 1;
	                                    break
	                                }
	                                c[(c[g >> 2] | 0) + 60 >> 2] = c[k >> 2];
	                                c[e >> 2] = -1;
	                                t = c[e >> 2] | 0;
	                                i = d;
	                                return t | 0
	                            } while (0);
	                            if ((c[(c[f >> 2] | 0) + 116 >> 2] | 0) == 389)c[(c[f >> 2] | 0) + 116 >> 2] = 0;
	                            if ((c[(c[f >> 2] | 0) + 120 >> 2] | 0) == 389)c[(c[f >> 2] | 0) + 120 >> 2] = 0
	                        }
	                        if (!(c[(c[f >> 2] | 0) + 32 >> 2] & 2)) {
	                            Ok(c[p >> 2] | 0, 14, 201632) | 0;
	                            b = c[p >> 2] | 0;
	                            if (c[(c[g >> 2] | 0) + 56 >> 2] | 0)gz(c[b + 16 >> 2] | 0, c[(c[g >> 2] | 0) + 56 >> 2] | 0) | 0; else Ok(b, 5, 201648) | 0;
	                            if (c[m >> 2] | 0) {
	                                Ok(c[p >> 2] | 0, 10, 201656) | 0;
	                                gz(c[(c[p >> 2] | 0) + 16 >> 2] | 0, c[m >> 2] | 0) | 0
	                            }
	                            b = c[(c[g >> 2] | 0) + 40 >> 2] | 0;
	                            if ((b | 0) == 1)Ok(c[p >> 2] | 0, 17, 201696) | 0; else if (!b)Ok(c[p >> 2] | 0, 16, 201672) | 0;
	                            Ok(c[p >> 2] | 0, 3, 201720) | 0
	                        }
	                        if (c[(c[f >> 2] | 0) + 32 >> 2] & 16)c[j >> 2] = 1;
	                        if ((c[(c[f >> 2] | 0) + 32 >> 2] & 8 | 0) == 0 ? (c[h >> 2] = Nh(c[g >> 2] | 0) | 0, (c[h >> 2] | 0) != 0) : 0) {
	                            b = lR(c[(c[h >> 2] | 0) + 56 >> 2] | 0, c[(c[h >> 2] | 0) + 52 >> 2] | 0) | 0;
	                            c[j >> 2] = b;
	                            c[j >> 2] = (c[j >> 2] | 0) < 0 ? 0 : b
	                        }
	                        if (c[(c[g >> 2] | 0) + 12 >> 2] | 0) {
	                            c[s >> 2] = c[(c[g >> 2] | 0) + 12 >> 2];
	                            while (1) {
	                                if (!(c[s >> 2] | 0))break a;
	                                c[(c[f >> 2] | 0) + 36 >> 2] = 0;
	                                b = c[f >> 2] | 0;
	                                a = c[s >> 2] | 0;
	                                if (c[j >> 2] | 0)TR(b, a); else OR(b, a);
	                                Ok(c[p >> 2] | 0, 1, 200976) | 0;
	                                c[s >> 2] = c[(c[s >> 2] | 0) + 24 >> 2]
	                            }
	                        }
	                    } while (0);
	                    if ((c[r >> 2] | 0) != 0 & (c[l >> 2] | 0) == 0) {
	                        XR(c[f >> 2] | 0) | 0;
	                        c[(c[f >> 2] | 0) + 116 >> 2] = c[n >> 2];
	                        c[(c[f >> 2] | 0) + 120 >> 2] = c[o >> 2]
	                    }
	                    c[(c[g >> 2] | 0) + 60 >> 2] = c[k >> 2];
	                    c[e >> 2] = 0;
	                    t = c[e >> 2] | 0;
	                    i = d;
	                    return t | 0
	                }
	                if (c[m >> 2] | 0)rp(c[g >> 2] | 0, c[m >> 2] | 0) | 0;
	                if (!(c[m >> 2] | 0))c[m >> 2] = qp(c[g >> 2] | 0) | 0;
	                if (!(c[m >> 2] | 0))c[m >> 2] = 201592;
	                if ((((c[m >> 2] | 0) != 0 & (c[l >> 2] | 0) == 0 ? (c[(c[p >> 2] | 0) + 12 >> 2] | 0) == 0 : 0) ? (c[(c[p >> 2] | 0) + 20 >> 2] | 0) == 0 : 0) ? (VR(c[f >> 2] | 0, c[m >> 2] | 0) | 0) < 0 : 0) {
	                    c[(c[g >> 2] | 0) + 60 >> 2] = c[k >> 2];
	                    c[e >> 2] = -1;
	                    t = c[e >> 2] | 0;
	                    i = d;
	                    return t | 0
	                }
	                l = c[p >> 2] | 0;
	                p = c[g >> 2] | 0;
	                o = c[m >> 2] | 0;
	                if (c[(c[f >> 2] | 0) + 32 >> 2] & 1)wp(l, p, o, 1); else wp(l, p, o, 0);
	                if (c[(c[f >> 2] | 0) + 16 >> 2] | 0)c[(c[g >> 2] | 0) + 60 >> 2] = c[k >> 2];
	                c[e >> 2] = 0;
	                t = c[e >> 2] | 0;
	                i = d;
	                return t | 0
	            }

	            function OR(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 24 | 0;
	                g = e + 20 | 0;
	                h = e + 16 | 0;
	                j = e + 12 | 0;
	                k = e + 8 | 0;
	                l = e + 4 | 0;
	                m = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[g >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                c[m >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 19) {
	                    i = e;
	                    return
	                }
	                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 20) {
	                    i = e;
	                    return
	                }
	                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 9 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 13 : 0) {
	                    if (c[(c[f >> 2] | 0) + 32 >> 2] & 16) {
	                        TR(c[f >> 2] | 0, c[g >> 2] | 0);
	                        i = e;
	                        return
	                    }
	                    if (!((((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 18 ? (c[(c[g >> 2] | 0) + 32 >> 2] | 0) != 0 : 0) ? (c[(c[(c[g >> 2] | 0) + 32 >> 2] | 0) + 4 >> 2] | 0) == 13 : 0) ? (c[(c[f >> 2] | 0) + 32 >> 2] & 32 | 0) == 0 : 0))n = 13;
	                    if ((n | 0) == 13 ? (c[(c[f >> 2] | 0) + 32 >> 2] & 64 | 0) == 0 : 0) {
	                        if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 14) {
	                            ZR(c[f >> 2] | 0, c[g >> 2] | 0);
	                            i = e;
	                            return
	                        }
	                        if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 11) {
	                            _R(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] | 0);
	                            i = e;
	                            return
	                        }
	                        if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 15) {
	                            nR(c[(c[m >> 2] | 0) + 16 >> 2] | 0, c[g >> 2] | 0);
	                            i = e;
	                            return
	                        }
	                        if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 16) {
	                            oR(c[(c[m >> 2] | 0) + 16 >> 2] | 0, c[g >> 2] | 0);
	                            i = e;
	                            return
	                        }
	                        if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 17) {
	                            pR(c[(c[m >> 2] | 0) + 16 >> 2] | 0, c[g >> 2] | 0);
	                            i = e;
	                            return
	                        }
	                        b = c[g >> 2] | 0;
	                        if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 3) {
	                            if (!(c[b + 40 >> 2] | 0)) {
	                                i = e;
	                                return
	                            }
	                            a = c[m >> 2] | 0;
	                            o = c[(c[g >> 2] | 0) + 40 >> 2] | 0;
	                            if ((c[(c[g >> 2] | 0) + 8 >> 2] | 0) != 75112) {
	                                Pk(a, o, c[(c[f >> 2] | 0) + 116 >> 2] | 0) | 0;
	                                i = e;
	                                return
	                            } else {
	                                Qk(a, o) | 0;
	                                i = e;
	                                return
	                            }
	                        }
	                        o = c[g >> 2] | 0;
	                        if ((c[b + 4 >> 2] | 0) == 7) {
	                            b = (c[o + 40 >> 2] | 0) != 0;
	                            Ok(c[m >> 2] | 0, 2, 200752) | 0;
	                            Qk(c[m >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0) | 0;
	                            if (!b) {
	                                if ((c[(c[f >> 2] | 0) + 40 >> 2] | 0) == 2)UR(c[f >> 2] | 0, 0);
	                                Ok(c[m >> 2] | 0, 2, 200768) | 0;
	                                i = e;
	                                return
	                            }
	                            if (c[(c[g >> 2] | 0) + 40 >> 2] | 0) {
	                                if ((c[(c[f >> 2] | 0) + 40 >> 2] | 0) == 2)UR(c[f >> 2] | 0, 0); else Ok(c[m >> 2] | 0, 1, 200760) | 0;
	                                Qk(c[m >> 2] | 0, c[(c[g >> 2] | 0) + 40 >> 2] | 0) | 0
	                            }
	                            Ok(c[m >> 2] | 0, 2, 200768) | 0;
	                            i = e;
	                            return
	                        }
	                        b = c[g >> 2] | 0;
	                        if ((c[o + 4 >> 2] | 0) == 8) {
	                            if (!(c[b + 40 >> 2] | 0)) {
	                                i = e;
	                                return
	                            }
	                            Ok(c[m >> 2] | 0, 4, 200776) | 0;
	                            Qk(c[m >> 2] | 0, c[(c[g >> 2] | 0) + 40 >> 2] | 0) | 0;
	                            Ok(c[m >> 2] | 0, 3, 200784) | 0;
	                            i = e;
	                            return
	                        }
	                        if ((c[b + 4 >> 2] | 0) == 5) {
	                            Ok(c[m >> 2] | 0, 1, 200792) | 0;
	                            Qk(c[m >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0) | 0;
	                            Ok(c[m >> 2] | 0, 1, 200800) | 0;
	                            i = e;
	                            return
	                        }
	                        b = c[g >> 2] | 0;
	                        if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 4) {
	                            do if (c[b + 40 >> 2] | 0) {
	                                if (!(d[c[(c[g >> 2] | 0) + 40 >> 2] >> 0] | 0))break;
	                                o = c[(c[g >> 2] | 0) + 40 >> 2] | 0;
	                                c[l >> 2] = o;
	                                c[k >> 2] = o;
	                                while (1) {
	                                    if (!(d[c[l >> 2] >> 0] | 0))break;
	                                    do if ((d[c[l >> 2] >> 0] | 0 | 0) == 93) {
	                                        if ((d[(c[l >> 2] | 0) + 1 >> 0] | 0 | 0) != 93)break;
	                                        if ((d[(c[l >> 2] | 0) + 2 >> 0] | 0 | 0) != 62)break;
	                                        c[l >> 2] = (c[l >> 2] | 0) + 2;
	                                        Ok(c[m >> 2] | 0, 9, 200824) | 0;
	                                        Ok(c[m >> 2] | 0, (c[l >> 2] | 0) - (c[k >> 2] | 0) | 0, c[k >> 2] | 0) | 0;
	                                        Ok(c[m >> 2] | 0, 3, 200840) | 0;
	                                        c[k >> 2] = c[l >> 2]
	                                    } while (0);
	                                    c[l >> 2] = (c[l >> 2] | 0) + 1
	                                }
	                                if ((c[k >> 2] | 0) == (c[l >> 2] | 0)) {
	                                    i = e;
	                                    return
	                                }
	                                Ok(c[m >> 2] | 0, 9, 200824) | 0;
	                                Qk(c[m >> 2] | 0, c[k >> 2] | 0) | 0;
	                                Ok(c[m >> 2] | 0, 3, 200840) | 0;
	                                i = e;
	                                return
	                            } while (0);
	                            Ok(c[m >> 2] | 0, 12, 200808) | 0;
	                            i = e;
	                            return
	                        }
	                        if ((c[b + 4 >> 2] | 0) == 2) {
	                            $R(c[f >> 2] | 0, c[g >> 2] | 0);
	                            i = e;
	                            return
	                        }
	                        b = c[f >> 2] | 0;
	                        if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 18) {
	                            aS(b, c[g >> 2] | 0);
	                            i = e;
	                            return
	                        }
	                        c[h >> 2] = c[b + 40 >> 2];
	                        a:do if ((c[h >> 2] | 0) == 1) {
	                            c[j >> 2] = c[(c[g >> 2] | 0) + 12 >> 2];
	                            while (1) {
	                                if (!(c[j >> 2] | 0))break a;
	                                if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) == 3)break;
	                                if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) == 4)break;
	                                if ((c[(c[j >> 2] | 0) + 4 >> 2] | 0) == 5)break;
	                                c[j >> 2] = c[(c[j >> 2] | 0) + 24 >> 2]
	                            }
	                            c[(c[f >> 2] | 0) + 40 >> 2] = 0
	                        } while (0);
	                        Ok(c[m >> 2] | 0, 1, 200848) | 0;
	                        do if (c[(c[g >> 2] | 0) + 36 >> 2] | 0) {
	                            if (!(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0))break;
	                            Qk(c[m >> 2] | 0, c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0;
	                            Ok(c[m >> 2] | 0, 1, 200856) | 0
	                        } while (0);
	                        Qk(c[m >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        if (c[(c[g >> 2] | 0) + 48 >> 2] | 0)bS(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 48 >> 2] | 0);
	                        if (c[(c[g >> 2] | 0) + 44 >> 2] | 0)cS(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 44 >> 2] | 0);
	                        if (!((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[g >> 2] | 0) + 40 >> 2] | 0) != 0 : 0))n = 80;
	                        do if ((n | 0) == 80) {
	                            if (c[(c[g >> 2] | 0) + 12 >> 2] | 0)break;
	                            if (c[(c[f >> 2] | 0) + 32 >> 2] & 4)break;
	                            if ((c[(c[f >> 2] | 0) + 40 >> 2] | 0) == 2)UR(c[f >> 2] | 0, 0);
	                            Ok(c[m >> 2] | 0, 2, 201584) | 0;
	                            c[(c[f >> 2] | 0) + 40 >> 2] = c[h >> 2];
	                            i = e;
	                            return
	                        } while (0);
	                        if ((c[(c[f >> 2] | 0) + 40 >> 2] | 0) == 2)UR(c[f >> 2] | 0, 1);
	                        Ok(c[m >> 2] | 0, 1, 200968) | 0;
	                        do if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 1) {
	                            if (!(c[(c[g >> 2] | 0) + 40 >> 2] | 0))break;
	                            Pk(c[m >> 2] | 0, c[(c[g >> 2] | 0) + 40 >> 2] | 0, c[(c[f >> 2] | 0) + 116 >> 2] | 0) | 0
	                        } while (0);
	                        do if (c[(c[g >> 2] | 0) + 12 >> 2] | 0) {
	                            if ((c[(c[f >> 2] | 0) + 40 >> 2] | 0) == 1)Ok(c[m >> 2] | 0, 1, 200976) | 0;
	                            if ((c[(c[f >> 2] | 0) + 36 >> 2] | 0) >= 0) {
	                                n = (c[f >> 2] | 0) + 36 | 0;
	                                c[n >> 2] = (c[n >> 2] | 0) + 1
	                            }
	                            _R(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] | 0);
	                            if ((c[(c[f >> 2] | 0) + 36 >> 2] | 0) > 0) {
	                                n = (c[f >> 2] | 0) + 36 | 0;
	                                c[n >> 2] = (c[n >> 2] | 0) + -1
	                            }
	                            if (!(c[33984] | 0))break;
	                            if ((c[(c[f >> 2] | 0) + 40 >> 2] | 0) != 1)break;
	                            n = c[f >> 2] | 0;
	                            if ((c[(c[f >> 2] | 0) + 36 >> 2] | 0) > (c[(c[f >> 2] | 0) + 108 >> 2] | 0))p = c[n + 108 >> 2] | 0; else p = c[n + 36 >> 2] | 0;
	                            n = ca(c[(c[f >> 2] | 0) + 112 >> 2] | 0, p) | 0;
	                            Ok(c[m >> 2] | 0, n, (c[f >> 2] | 0) + 44 | 0) | 0
	                        } while (0);
	                        Ok(c[m >> 2] | 0, 2, 201056) | 0;
	                        do if (c[(c[g >> 2] | 0) + 36 >> 2] | 0) {
	                            if (!(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0))break;
	                            Qk(c[m >> 2] | 0, c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0;
	                            Ok(c[m >> 2] | 0, 1, 200856) | 0
	                        } while (0);
	                        Qk(c[m >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        if ((c[(c[f >> 2] | 0) + 40 >> 2] | 0) == 2)UR(c[f >> 2] | 0, 0);
	                        Ok(c[m >> 2] | 0, 1, 200968) | 0;
	                        c[(c[f >> 2] | 0) + 40 >> 2] = c[h >> 2];
	                        i = e;
	                        return
	                    }
	                    YR(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                    i = e;
	                    return
	                }
	                NR(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                i = e;
	                return
	            }

	            function PR(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                c[j >> 2] = 0;
	                d = c[f >> 2] | 0;
	                if ((d | 0) == 1400)c[j >> 2] = 201440; else if ((d | 0) == 1403)c[j >> 2] = 201496; else if ((d | 0) == 1401)c[j >> 2] = 201464; else if ((d | 0) == 1402)c[j >> 2] = 201520; else c[j >> 2] = 201552;
	                ce(7, c[f >> 2] | 0, c[g >> 2] | 0, c[j >> 2] | 0, c[h >> 2] | 0);
	                i = e;
	                return
	            }

	            function QR(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = b;
	                c[g >> 2] = d;
	                d = c[f >> 2] | 0;
	                c[f >> 2] = d + 1;
	                a[d >> 0] = 38;
	                d = c[f >> 2] | 0;
	                c[f >> 2] = d + 1;
	                a[d >> 0] = 35;
	                d = c[f >> 2] | 0;
	                c[f >> 2] = d + 1;
	                a[d >> 0] = 120;
	                do if ((c[g >> 2] | 0) >= 16) {
	                    if ((c[g >> 2] | 0) < 256) {
	                        c[h >> 2] = (c[f >> 2] | 0) + 1;
	                        break
	                    }
	                    if ((c[g >> 2] | 0) < 4096) {
	                        c[h >> 2] = (c[f >> 2] | 0) + 2;
	                        break
	                    }
	                    if ((c[g >> 2] | 0) < 65536) {
	                        c[h >> 2] = (c[f >> 2] | 0) + 3;
	                        break
	                    }
	                    d = c[f >> 2] | 0;
	                    if ((c[g >> 2] | 0) < 1048576) {
	                        c[h >> 2] = d + 4;
	                        break
	                    } else {
	                        c[h >> 2] = d + 5;
	                        break
	                    }
	                } else c[h >> 2] = c[f >> 2]; while (0);
	                c[f >> 2] = (c[h >> 2] | 0) + 1;
	                while (1) {
	                    if ((c[g >> 2] | 0) <= 0)break;
	                    do switch (c[g >> 2] & 15 | 0) {
	                        case 14:
	                        {
	                            d = c[h >> 2] | 0;
	                            c[h >> 2] = d + -1;
	                            a[d >> 0] = 69;
	                            break
	                        }
	                        case 10:
	                        {
	                            d = c[h >> 2] | 0;
	                            c[h >> 2] = d + -1;
	                            a[d >> 0] = 65;
	                            break
	                        }
	                        case 2:
	                        {
	                            d = c[h >> 2] | 0;
	                            c[h >> 2] = d + -1;
	                            a[d >> 0] = 50;
	                            break
	                        }
	                        case 7:
	                        {
	                            d = c[h >> 2] | 0;
	                            c[h >> 2] = d + -1;
	                            a[d >> 0] = 55;
	                            break
	                        }
	                        case 9:
	                        {
	                            d = c[h >> 2] | 0;
	                            c[h >> 2] = d + -1;
	                            a[d >> 0] = 57;
	                            break
	                        }
	                        case 5:
	                        {
	                            d = c[h >> 2] | 0;
	                            c[h >> 2] = d + -1;
	                            a[d >> 0] = 53;
	                            break
	                        }
	                        case 12:
	                        {
	                            d = c[h >> 2] | 0;
	                            c[h >> 2] = d + -1;
	                            a[d >> 0] = 67;
	                            break
	                        }
	                        case 0:
	                        {
	                            d = c[h >> 2] | 0;
	                            c[h >> 2] = d + -1;
	                            a[d >> 0] = 48;
	                            break
	                        }
	                        case 3:
	                        {
	                            d = c[h >> 2] | 0;
	                            c[h >> 2] = d + -1;
	                            a[d >> 0] = 51;
	                            break
	                        }
	                        case 11:
	                        {
	                            d = c[h >> 2] | 0;
	                            c[h >> 2] = d + -1;
	                            a[d >> 0] = 66;
	                            break
	                        }
	                        case 15:
	                        {
	                            d = c[h >> 2] | 0;
	                            c[h >> 2] = d + -1;
	                            a[d >> 0] = 70;
	                            break
	                        }
	                        case 13:
	                        {
	                            d = c[h >> 2] | 0;
	                            c[h >> 2] = d + -1;
	                            a[d >> 0] = 68;
	                            break
	                        }
	                        case 6:
	                        {
	                            d = c[h >> 2] | 0;
	                            c[h >> 2] = d + -1;
	                            a[d >> 0] = 54;
	                            break
	                        }
	                        case 8:
	                        {
	                            d = c[h >> 2] | 0;
	                            c[h >> 2] = d + -1;
	                            a[d >> 0] = 56;
	                            break
	                        }
	                        case 4:
	                        {
	                            d = c[h >> 2] | 0;
	                            c[h >> 2] = d + -1;
	                            a[d >> 0] = 52;
	                            break
	                        }
	                        case 1:
	                        {
	                            d = c[h >> 2] | 0;
	                            c[h >> 2] = d + -1;
	                            a[d >> 0] = 49;
	                            break
	                        }
	                        default:
	                        {
	                            d = c[h >> 2] | 0;
	                            c[h >> 2] = d + -1;
	                            a[d >> 0] = 48
	                        }
	                    } while (0);
	                    c[g >> 2] = c[g >> 2] >> 4
	                }
	                g = c[f >> 2] | 0;
	                c[f >> 2] = g + 1;
	                a[g >> 0] = 59;
	                a[c[f >> 2] >> 0] = 0;
	                i = e;
	                return c[f >> 2] | 0
	            }

	            function RR(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                ce(7, 2, 0, 0, c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function SR(b) {
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if ((c[(c[e >> 2] | 0) + 16 >> 2] | 0) == 0 ? (c[(c[e >> 2] | 0) + 116 >> 2] | 0) == 0 : 0)c[(c[e >> 2] | 0) + 116 >> 2] = 389;
	                c[g >> 2] = xy(c[33988] | 0) | 0;
	                if ((c[33988] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    b = (c[e >> 2] | 0) + 44 | 0;
	                    h = b + 61 | 0;
	                    do {
	                        a[b >> 0] = 0;
	                        b = b + 1 | 0
	                    } while ((b | 0) < (h | 0))
	                } else {
	                    c[(c[e >> 2] | 0) + 112 >> 2] = c[g >> 2];
	                    c[(c[e >> 2] | 0) + 108 >> 2] = 60 / (c[(c[e >> 2] | 0) + 112 >> 2] | 0) | 0;
	                    c[f >> 2] = 0;
	                    while (1) {
	                        if ((c[f >> 2] | 0) >= (c[(c[e >> 2] | 0) + 108 >> 2] | 0))break;
	                        g = ca(c[f >> 2] | 0, c[(c[e >> 2] | 0) + 112 >> 2] | 0) | 0;
	                        eU((c[e >> 2] | 0) + 44 + g | 0, c[33988] | 0, c[(c[e >> 2] | 0) + 112 >> 2] | 0) | 0;
	                        c[f >> 2] = (c[f >> 2] | 0) + 1
	                    }
	                    f = ca(c[(c[e >> 2] | 0) + 108 >> 2] | 0, c[(c[e >> 2] | 0) + 112 >> 2] | 0) | 0;
	                    a[(c[e >> 2] | 0) + 44 + f >> 0] = 0
	                }
	                if (!(c[33990] | 0)) {
	                    i = d;
	                    return
	                }
	                f = (c[e >> 2] | 0) + 32 | 0;
	                c[f >> 2] = c[f >> 2] | 4;
	                i = d;
	                return
	            }

	            function TR(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                e = i;
	                i = i + 48 | 0;
	                f = e + 36 | 0;
	                g = e + 32 | 0;
	                h = e + 28 | 0;
	                j = e + 24 | 0;
	                k = e + 20 | 0;
	                l = e + 16 | 0;
	                m = e + 12 | 0;
	                n = e + 8 | 0;
	                o = e + 4 | 0;
	                p = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[j >> 2] = 0;
	                if (!(c[g >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 9 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 13 : 0) {
	                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 19) {
	                        i = e;
	                        return
	                    }
	                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 20) {
	                        i = e;
	                        return
	                    }
	                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 18) {
	                        aS(c[f >> 2] | 0, c[g >> 2] | 0);
	                        i = e;
	                        return
	                    }
	                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 14) {
	                        ZR(c[f >> 2] | 0, c[g >> 2] | 0);
	                        i = e;
	                        return
	                    }
	                    b = c[f >> 2] | 0;
	                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 11) {
	                        dS(b, c[(c[g >> 2] | 0) + 12 >> 2] | 0);
	                        i = e;
	                        return
	                    }
	                    c[n >> 2] = c[b + 24 >> 2];
	                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 15) {
	                        nR(c[(c[n >> 2] | 0) + 16 >> 2] | 0, c[g >> 2] | 0);
	                        i = e;
	                        return
	                    }
	                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 16) {
	                        oR(c[(c[n >> 2] | 0) + 16 >> 2] | 0, c[g >> 2] | 0);
	                        i = e;
	                        return
	                    }
	                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 17) {
	                        pR(c[(c[n >> 2] | 0) + 16 >> 2] | 0, c[g >> 2] | 0);
	                        i = e;
	                        return
	                    }
	                    b = c[g >> 2] | 0;
	                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 3) {
	                        if (!(c[b + 40 >> 2] | 0)) {
	                            i = e;
	                            return
	                        }
	                        if ((c[(c[g >> 2] | 0) + 8 >> 2] | 0) != 75104 ? (c[(c[g >> 2] | 0) + 8 >> 2] | 0) == 75112 : 0) {
	                            Qk(c[n >> 2] | 0, c[(c[g >> 2] | 0) + 40 >> 2] | 0) | 0;
	                            i = e;
	                            return
	                        }
	                        Pk(c[n >> 2] | 0, c[(c[g >> 2] | 0) + 40 >> 2] | 0, c[(c[f >> 2] | 0) + 116 >> 2] | 0) | 0;
	                        i = e;
	                        return
	                    }
	                    a = c[g >> 2] | 0;
	                    if ((c[b + 4 >> 2] | 0) == 7) {
	                        b = (c[a + 40 >> 2] | 0) != 0;
	                        Ok(c[n >> 2] | 0, 2, 200752) | 0;
	                        Qk(c[n >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        if (!b) {
	                            Ok(c[n >> 2] | 0, 2, 200768) | 0;
	                            i = e;
	                            return
	                        }
	                        if (c[(c[g >> 2] | 0) + 40 >> 2] | 0) {
	                            Ok(c[n >> 2] | 0, 1, 200760) | 0;
	                            Qk(c[n >> 2] | 0, c[(c[g >> 2] | 0) + 40 >> 2] | 0) | 0
	                        }
	                        Ok(c[n >> 2] | 0, 2, 200768) | 0;
	                        i = e;
	                        return
	                    }
	                    b = c[g >> 2] | 0;
	                    if ((c[a + 4 >> 2] | 0) == 8) {
	                        if (!(c[b + 40 >> 2] | 0)) {
	                            i = e;
	                            return
	                        }
	                        Ok(c[n >> 2] | 0, 4, 200776) | 0;
	                        Qk(c[n >> 2] | 0, c[(c[g >> 2] | 0) + 40 >> 2] | 0) | 0;
	                        Ok(c[n >> 2] | 0, 3, 200784) | 0;
	                        i = e;
	                        return
	                    }
	                    if ((c[b + 4 >> 2] | 0) == 5) {
	                        Ok(c[n >> 2] | 0, 1, 200792) | 0;
	                        Qk(c[n >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        Ok(c[n >> 2] | 0, 1, 200800) | 0;
	                        i = e;
	                        return
	                    }
	                    b = c[g >> 2] | 0;
	                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 4) {
	                        do if (c[b + 40 >> 2] | 0) {
	                            if (!(d[c[(c[g >> 2] | 0) + 40 >> 2] >> 0] | 0))break;
	                            a = c[(c[g >> 2] | 0) + 40 >> 2] | 0;
	                            c[m >> 2] = a;
	                            c[l >> 2] = a;
	                            while (1) {
	                                if (!(d[c[m >> 2] >> 0] | 0))break;
	                                do if ((d[c[m >> 2] >> 0] | 0 | 0) == 93) {
	                                    if ((d[(c[m >> 2] | 0) + 1 >> 0] | 0 | 0) != 93)break;
	                                    if ((d[(c[m >> 2] | 0) + 2 >> 0] | 0 | 0) != 62)break;
	                                    c[m >> 2] = (c[m >> 2] | 0) + 2;
	                                    Ok(c[n >> 2] | 0, 9, 200824) | 0;
	                                    Ok(c[n >> 2] | 0, (c[m >> 2] | 0) - (c[l >> 2] | 0) | 0, c[l >> 2] | 0) | 0;
	                                    Ok(c[n >> 2] | 0, 3, 200840) | 0;
	                                    c[l >> 2] = c[m >> 2]
	                                } while (0);
	                                c[m >> 2] = (c[m >> 2] | 0) + 1
	                            }
	                            if ((c[l >> 2] | 0) == (c[m >> 2] | 0)) {
	                                i = e;
	                                return
	                            }
	                            Ok(c[n >> 2] | 0, 9, 200824) | 0;
	                            Qk(c[n >> 2] | 0, c[l >> 2] | 0) | 0;
	                            Ok(c[n >> 2] | 0, 3, 200840) | 0;
	                            i = e;
	                            return
	                        } while (0);
	                        Ok(c[n >> 2] | 0, 12, 200808) | 0;
	                        i = e;
	                        return
	                    }
	                    l = c[f >> 2] | 0;
	                    if ((c[b + 4 >> 2] | 0) == 2) {
	                        $R(l, c[g >> 2] | 0);
	                        i = e;
	                        return
	                    }
	                    c[h >> 2] = c[l + 40 >> 2];
	                    a:do if ((c[h >> 2] | 0) == 1) {
	                        c[k >> 2] = c[(c[g >> 2] | 0) + 12 >> 2];
	                        while (1) {
	                            if (!(c[k >> 2] | 0))break a;
	                            if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 3)break;
	                            if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 5)break;
	                            c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                        }
	                        c[h >> 2] = 0
	                    } while (0);
	                    Ok(c[n >> 2] | 0, 1, 200848) | 0;
	                    do if (c[(c[g >> 2] | 0) + 36 >> 2] | 0) {
	                        if (!(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0))break;
	                        Qk(c[n >> 2] | 0, c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0;
	                        Ok(c[n >> 2] | 0, 1, 200856) | 0
	                    } while (0);
	                    Qk(c[n >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0) | 0;
	                    if (c[(c[g >> 2] | 0) + 48 >> 2] | 0)bS(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 48 >> 2] | 0);
	                    do if (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 200864) | 0) {
	                        if (c[(c[g >> 2] | 0) + 36 >> 2] | 0)break;
	                        if (c[(c[g >> 2] | 0) + 48 >> 2] | 0)break;
	                        Qk(c[n >> 2] | 0, 200872) | 0
	                    } while (0);
	                    if (c[(c[g >> 2] | 0) + 44 >> 2] | 0)eS(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 44 >> 2] | 0);
	                    do if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                        if (!(c[(c[g >> 2] | 0) + 20 >> 2] | 0))break;
	                        if ((c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 20 >> 2] | 0) != (c[(c[g >> 2] | 0) + 32 >> 2] | 0))break;
	                        if (!(qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 200912) | 0))break;
	                        if (!(qy(c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 8 >> 2] | 0, 200864) | 0))break;
	                        c[k >> 2] = c[(c[g >> 2] | 0) + 12 >> 2];
	                        b:while (1) {
	                            if (!(c[k >> 2] | 0))break;
	                            do if (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 200920) | 0) {
	                                c[o >> 2] = Yi(c[k >> 2] | 0, 200928) | 0;
	                                if (!(c[o >> 2] | 0))break;
	                                l = (ty(c[o >> 2] | 0, 200944) | 0) == 0;
	                                zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                                if (l)break b
	                            } while (0);
	                            c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                        }
	                        if (c[k >> 2] | 0)break;
	                        c[j >> 2] = 1
	                    } while (0);
	                    do if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                        if (c[(c[g >> 2] | 0) + 12 >> 2] | 0)break;
	                        if (!((c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0))q = 86;
	                        do if ((q | 0) == 86) {
	                            k = (fS(c[g >> 2] | 0) | 0) == 1;
	                            if (!(k & (c[j >> 2] | 0) == 0))break;
	                            Ok(c[n >> 2] | 0, 3, 200960) | 0;
	                            i = e;
	                            return
	                        } while (0);
	                        k = (c[j >> 2] | 0) == 1;
	                        Ok(c[n >> 2] | 0, 1, 200968) | 0;
	                        do if (k) {
	                            do if ((c[(c[f >> 2] | 0) + 40 >> 2] | 0) == 1) {
	                                Ok(c[n >> 2] | 0, 1, 200976) | 0;
	                                if (!(c[33984] | 0))break;
	                                o = c[f >> 2] | 0;
	                                if (((c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 1 | 0) > (c[(c[f >> 2] | 0) + 108 >> 2] | 0))r = c[o + 108 >> 2] | 0; else r = (c[o + 36 >> 2] | 0) + 1 | 0;
	                                o = ca(c[(c[f >> 2] | 0) + 112 >> 2] | 0, r) | 0;
	                                Ok(c[n >> 2] | 0, o, (c[f >> 2] | 0) + 44 | 0) | 0
	                            } while (0);
	                            Qk(c[n >> 2] | 0, 200984) | 0;
	                            o = c[n >> 2] | 0;
	                            if (c[(c[f >> 2] | 0) + 16 >> 2] | 0)Qk(o, c[(c[f >> 2] | 0) + 16 >> 2] | 0) | 0; else Ok(o, 5, 200728) | 0;
	                            Ok(c[n >> 2] | 0, 4, 201048) | 0;
	                            if ((c[(c[f >> 2] | 0) + 40 >> 2] | 0) != 1)break;
	                            Ok(c[n >> 2] | 0, 1, 200976) | 0
	                        } while (0);
	                        Ok(c[n >> 2] | 0, 2, 201056) | 0;
	                        do if (c[(c[g >> 2] | 0) + 36 >> 2] | 0) {
	                            if (!(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0))break;
	                            Qk(c[n >> 2] | 0, c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0;
	                            Ok(c[n >> 2] | 0, 1, 200856) | 0
	                        } while (0);
	                        Qk(c[n >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0) | 0;
	                        Ok(c[n >> 2] | 0, 1, 200968) | 0;
	                        i = e;
	                        return
	                    } while (0);
	                    Ok(c[n >> 2] | 0, 1, 200968) | 0;
	                    if ((c[j >> 2] | 0) == 1) {
	                        do if ((c[(c[f >> 2] | 0) + 40 >> 2] | 0) == 1) {
	                            Ok(c[n >> 2] | 0, 1, 200976) | 0;
	                            if (!(c[33984] | 0))break;
	                            j = c[f >> 2] | 0;
	                            if (((c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 1 | 0) > (c[(c[f >> 2] | 0) + 108 >> 2] | 0))s = c[j + 108 >> 2] | 0; else s = (c[j + 36 >> 2] | 0) + 1 | 0;
	                            j = ca(c[(c[f >> 2] | 0) + 112 >> 2] | 0, s) | 0;
	                            Ok(c[n >> 2] | 0, j, (c[f >> 2] | 0) + 44 | 0) | 0
	                        } while (0);
	                        Qk(c[n >> 2] | 0, 200984) | 0;
	                        s = c[n >> 2] | 0;
	                        if (c[(c[f >> 2] | 0) + 16 >> 2] | 0)Qk(s, c[(c[f >> 2] | 0) + 16 >> 2] | 0) | 0; else Ok(s, 5, 200728) | 0;
	                        Ok(c[n >> 2] | 0, 4, 201048) | 0
	                    }
	                    do if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 1) {
	                        if (!(c[(c[g >> 2] | 0) + 40 >> 2] | 0))break;
	                        Pk(c[n >> 2] | 0, c[(c[g >> 2] | 0) + 40 >> 2] | 0, c[(c[f >> 2] | 0) + 116 >> 2] | 0) | 0
	                    } while (0);
	                    do if (c[(c[g >> 2] | 0) + 12 >> 2] | 0) {
	                        c[p >> 2] = c[(c[f >> 2] | 0) + 40 >> 2];
	                        if ((c[h >> 2] | 0) == 1)Ok(c[n >> 2] | 0, 1, 200976) | 0;
	                        if ((c[(c[f >> 2] | 0) + 36 >> 2] | 0) >= 0) {
	                            s = (c[f >> 2] | 0) + 36 | 0;
	                            c[s >> 2] = (c[s >> 2] | 0) + 1
	                        }
	                        c[(c[f >> 2] | 0) + 40 >> 2] = c[h >> 2];
	                        dS(c[f >> 2] | 0, c[(c[g >> 2] | 0) + 12 >> 2] | 0);
	                        if ((c[(c[f >> 2] | 0) + 36 >> 2] | 0) > 0) {
	                            s = (c[f >> 2] | 0) + 36 | 0;
	                            c[s >> 2] = (c[s >> 2] | 0) + -1
	                        }
	                        c[(c[f >> 2] | 0) + 40 >> 2] = c[p >> 2];
	                        if (!((c[33984] | 0) != 0 & (c[h >> 2] | 0) == 1))break;
	                        s = c[f >> 2] | 0;
	                        if ((c[(c[f >> 2] | 0) + 36 >> 2] | 0) > (c[(c[f >> 2] | 0) + 108 >> 2] | 0))t = c[s + 108 >> 2] | 0; else t = c[s + 36 >> 2] | 0;
	                        s = ca(c[(c[f >> 2] | 0) + 112 >> 2] | 0, t) | 0;
	                        Ok(c[n >> 2] | 0, s, (c[f >> 2] | 0) + 44 | 0) | 0
	                    } while (0);
	                    Ok(c[n >> 2] | 0, 2, 201056) | 0;
	                    do if (c[(c[g >> 2] | 0) + 36 >> 2] | 0) {
	                        if (!(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0))break;
	                        Qk(c[n >> 2] | 0, c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0;
	                        Ok(c[n >> 2] | 0, 1, 200856) | 0
	                    } while (0);
	                    Qk(c[n >> 2] | 0, c[(c[g >> 2] | 0) + 8 >> 2] | 0) | 0;
	                    Ok(c[n >> 2] | 0, 1, 200968) | 0;
	                    i = e;
	                    return
	                }
	                NR(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                i = e;
	                return
	            }

	            function UR(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[e >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if (!(c[(c[e >> 2] | 0) + 24 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                Ok(c[(c[e >> 2] | 0) + 24 >> 2] | 0, 1, 200976) | 0;
	                c[g >> 2] = 0;
	                while (1) {
	                    if ((c[g >> 2] | 0) >= ((c[(c[e >> 2] | 0) + 36 >> 2] | 0) + (c[f >> 2] | 0) | 0))break;
	                    b = c[e >> 2] | 0;
	                    if (((c[(c[e >> 2] | 0) + 36 >> 2] | 0) + (c[f >> 2] | 0) - (c[g >> 2] | 0) | 0) > (c[(c[e >> 2] | 0) + 108 >> 2] | 0))h = c[b + 108 >> 2] | 0; else h = (c[b + 36 >> 2] | 0) + (c[f >> 2] | 0) - (c[g >> 2] | 0) | 0;
	                    b = ca(c[(c[e >> 2] | 0) + 112 >> 2] | 0, h) | 0;
	                    Ok(c[(c[e >> 2] | 0) + 24 >> 2] | 0, b, (c[e >> 2] | 0) + 44 | 0) | 0;
	                    c[g >> 2] = (c[g >> 2] | 0) + (c[(c[e >> 2] | 0) + 108 >> 2] | 0)
	                }
	                i = d;
	                return
	            }

	            function VR(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                do if (((c[g >> 2] | 0) != 0 ? (c[(c[h >> 2] | 0) + 12 >> 2] | 0) == 0 : 0) ? (c[(c[h >> 2] | 0) + 20 >> 2] | 0) == 0 : 0) {
	                    f = Dd(c[g >> 2] | 0) | 0;
	                    c[(c[h >> 2] | 0) + 12 >> 2] = f;
	                    if (!(c[(c[h >> 2] | 0) + 12 >> 2] | 0)) {
	                        PR(1403, 0, c[g >> 2] | 0);
	                        c[e >> 2] = -1;
	                        j = c[e >> 2] | 0;
	                        i = d;
	                        return j | 0
	                    }
	                    f = Ly() | 0;
	                    c[(c[h >> 2] | 0) + 20 >> 2] = f;
	                    f = c[h >> 2] | 0;
	                    if (c[(c[h >> 2] | 0) + 20 >> 2] | 0) {
	                        Gd(f, 1) | 0;
	                        break
	                    }
	                    Hd(c[f + 12 >> 2] | 0) | 0;
	                    RR(201600);
	                    c[e >> 2] = -1;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                } while (0);
	                c[e >> 2] = 0;
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function WR(b, e, f, g) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h;
	                k = h + 40 | 0;
	                l = h + 36 | 0;
	                m = h + 32 | 0;
	                n = h + 28 | 0;
	                o = h + 24 | 0;
	                p = h + 20 | 0;
	                q = h + 16 | 0;
	                r = h + 12 | 0;
	                s = h + 8 | 0;
	                t = h + 4 | 0;
	                c[l >> 2] = b;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                c[p >> 2] = c[l >> 2];
	                c[q >> 2] = c[n >> 2];
	                c[r >> 2] = (c[l >> 2] | 0) + (c[c[m >> 2] >> 2] | 0);
	                c[s >> 2] = (c[n >> 2] | 0) + (c[c[o >> 2] >> 2] | 0);
	                a:while (1) {
	                    if ((c[n >> 2] | 0) >>> 0 >= (c[s >> 2] | 0) >>> 0) {
	                        u = 46;
	                        break
	                    }
	                    if ((c[l >> 2] | 0) >>> 0 >= (c[r >> 2] | 0) >>> 0) {
	                        u = 46;
	                        break
	                    }
	                    if ((d[c[n >> 2] >> 0] | 0 | 0) == 60) {
	                        if (((c[r >> 2] | 0) - (c[l >> 2] | 0) | 0) < 4) {
	                            u = 46;
	                            break
	                        }
	                        g = c[l >> 2] | 0;
	                        c[l >> 2] = g + 1;
	                        a[g >> 0] = 38;
	                        g = c[l >> 2] | 0;
	                        c[l >> 2] = g + 1;
	                        a[g >> 0] = 108;
	                        g = c[l >> 2] | 0;
	                        c[l >> 2] = g + 1;
	                        a[g >> 0] = 116;
	                        g = c[l >> 2] | 0;
	                        c[l >> 2] = g + 1;
	                        a[g >> 0] = 59;
	                        c[n >> 2] = (c[n >> 2] | 0) + 1;
	                        continue
	                    }
	                    if ((d[c[n >> 2] >> 0] | 0 | 0) == 62) {
	                        if (((c[r >> 2] | 0) - (c[l >> 2] | 0) | 0) < 4) {
	                            u = 46;
	                            break
	                        }
	                        g = c[l >> 2] | 0;
	                        c[l >> 2] = g + 1;
	                        a[g >> 0] = 38;
	                        g = c[l >> 2] | 0;
	                        c[l >> 2] = g + 1;
	                        a[g >> 0] = 103;
	                        g = c[l >> 2] | 0;
	                        c[l >> 2] = g + 1;
	                        a[g >> 0] = 116;
	                        g = c[l >> 2] | 0;
	                        c[l >> 2] = g + 1;
	                        a[g >> 0] = 59;
	                        c[n >> 2] = (c[n >> 2] | 0) + 1;
	                        continue
	                    }
	                    if ((d[c[n >> 2] >> 0] | 0 | 0) == 38) {
	                        if (((c[r >> 2] | 0) - (c[l >> 2] | 0) | 0) < 5) {
	                            u = 46;
	                            break
	                        }
	                        g = c[l >> 2] | 0;
	                        c[l >> 2] = g + 1;
	                        a[g >> 0] = 38;
	                        g = c[l >> 2] | 0;
	                        c[l >> 2] = g + 1;
	                        a[g >> 0] = 97;
	                        g = c[l >> 2] | 0;
	                        c[l >> 2] = g + 1;
	                        a[g >> 0] = 109;
	                        g = c[l >> 2] | 0;
	                        c[l >> 2] = g + 1;
	                        a[g >> 0] = 112;
	                        g = c[l >> 2] | 0;
	                        c[l >> 2] = g + 1;
	                        a[g >> 0] = 59;
	                        c[n >> 2] = (c[n >> 2] | 0) + 1;
	                        continue
	                    }
	                    if (!((d[c[n >> 2] >> 0] | 0 | 0) >= 32 ? (d[c[n >> 2] >> 0] | 0 | 0) < 128 : 0))u = 15;
	                    if (((u | 0) == 15 ? (u = 0, (d[c[n >> 2] >> 0] | 0 | 0) != 10) : 0) ? (d[c[n >> 2] >> 0] | 0 | 0) != 9 : 0) {
	                        if ((d[c[n >> 2] >> 0] | 0 | 0) < 128) {
	                            if (!(9 <= (d[c[n >> 2] >> 0] | 0 | 0) ? (d[c[n >> 2] >> 0] | 0 | 0) <= 10 : 0))u = 41;
	                            if (((u | 0) == 41 ? (u = 0, (d[c[n >> 2] >> 0] | 0 | 0) != 13) : 0) ? 32 > (d[c[n >> 2] >> 0] | 0 | 0) : 0) {
	                                u = 45;
	                                break
	                            }
	                            if (((c[r >> 2] | 0) - (c[l >> 2] | 0) | 0) < 6) {
	                                u = 46;
	                                break
	                            }
	                            g = c[l >> 2] | 0;
	                            f = c[n >> 2] | 0;
	                            c[n >> 2] = f + 1;
	                            c[l >> 2] = QR(g, d[f >> 0] | 0) | 0;
	                            continue
	                        }
	                        if (((c[r >> 2] | 0) - (c[l >> 2] | 0) | 0) < 11) {
	                            u = 46;
	                            break
	                        }
	                        if ((d[c[n >> 2] >> 0] | 0 | 0) < 192) {
	                            u = 21;
	                            break
	                        }
	                        do if ((d[c[n >> 2] >> 0] | 0 | 0) < 224) {
	                            if (((c[s >> 2] | 0) - (c[n >> 2] | 0) | 0) < 2) {
	                                u = 46;
	                                break a
	                            }
	                            c[t >> 2] = (d[c[n >> 2] >> 0] | 0) & 31;
	                            c[t >> 2] = c[t >> 2] << 6;
	                            c[t >> 2] = c[t >> 2] | (d[(c[n >> 2] | 0) + 1 >> 0] | 0) & 63;
	                            c[n >> 2] = (c[n >> 2] | 0) + 2
	                        } else {
	                            if ((d[c[n >> 2] >> 0] | 0 | 0) < 240) {
	                                if (((c[s >> 2] | 0) - (c[n >> 2] | 0) | 0) < 3) {
	                                    u = 46;
	                                    break a
	                                }
	                                c[t >> 2] = (d[c[n >> 2] >> 0] | 0) & 15;
	                                c[t >> 2] = c[t >> 2] << 6;
	                                c[t >> 2] = c[t >> 2] | (d[(c[n >> 2] | 0) + 1 >> 0] | 0) & 63;
	                                c[t >> 2] = c[t >> 2] << 6;
	                                c[t >> 2] = c[t >> 2] | (d[(c[n >> 2] | 0) + 2 >> 0] | 0) & 63;
	                                c[n >> 2] = (c[n >> 2] | 0) + 3;
	                                break
	                            }
	                            if ((d[c[n >> 2] >> 0] | 0 | 0) >= 248) {
	                                u = 31;
	                                break a
	                            }
	                            if (((c[s >> 2] | 0) - (c[n >> 2] | 0) | 0) < 4) {
	                                u = 46;
	                                break a
	                            }
	                            c[t >> 2] = (d[c[n >> 2] >> 0] | 0) & 7;
	                            c[t >> 2] = c[t >> 2] << 6;
	                            c[t >> 2] = c[t >> 2] | (d[(c[n >> 2] | 0) + 1 >> 0] | 0) & 63;
	                            c[t >> 2] = c[t >> 2] << 6;
	                            c[t >> 2] = c[t >> 2] | (d[(c[n >> 2] | 0) + 2 >> 0] | 0) & 63;
	                            c[t >> 2] = c[t >> 2] << 6;
	                            c[t >> 2] = c[t >> 2] | (d[(c[n >> 2] | 0) + 3 >> 0] | 0) & 63;
	                            c[n >> 2] = (c[n >> 2] | 0) + 4
	                        } while (0);
	                        f = c[t >> 2] | 0;
	                        if ((c[t >> 2] | 0) < 256) {
	                            if (!(9 <= (f | 0) & (c[t >> 2] | 0) <= 10 | (c[t >> 2] | 0) == 13 | 32 <= (c[t >> 2] | 0))) {
	                                u = 37;
	                                break
	                            }
	                        } else if ((!(256 <= (f | 0) & (c[t >> 2] | 0) <= 55295) ? !(57344 <= (c[t >> 2] | 0) & (c[t >> 2] | 0) <= 65533) : 0) ? !(65536 <= (c[t >> 2] | 0) & (c[t >> 2] | 0) <= 1114111) : 0) {
	                            u = 37;
	                            break
	                        }
	                        c[l >> 2] = QR(c[l >> 2] | 0, c[t >> 2] | 0) | 0;
	                        continue
	                    }
	                    f = c[n >> 2] | 0;
	                    c[n >> 2] = f + 1;
	                    g = a[f >> 0] | 0;
	                    f = c[l >> 2] | 0;
	                    c[l >> 2] = f + 1;
	                    a[f >> 0] = g
	                }
	                if ((u | 0) == 21) {
	                    PR(1400, 0, 0);
	                    c[n >> 2] = (c[n >> 2] | 0) + 1
	                } else if ((u | 0) == 31) {
	                    PR(1401, 0, 0);
	                    c[n >> 2] = (c[n >> 2] | 0) + 1
	                } else if ((u | 0) == 37) {
	                    PR(1401, 0, 0);
	                    c[n >> 2] = (c[n >> 2] | 0) + 1
	                } else if ((u | 0) == 45) {
	                    Db[c[135904 >> 2] & 511](c[33980] | 0, 201400, j);
	                    c[n >> 2] = (c[n >> 2] | 0) + 1
	                } else if ((u | 0) == 46) {
	                    c[c[m >> 2] >> 2] = (c[l >> 2] | 0) - (c[p >> 2] | 0);
	                    c[c[o >> 2] >> 2] = (c[n >> 2] | 0) - (c[q >> 2] | 0);
	                    c[k >> 2] = 0;
	                    v = c[k >> 2] | 0;
	                    i = h;
	                    return v | 0
	                }
	                c[c[m >> 2] >> 2] = (c[l >> 2] | 0) - (c[p >> 2] | 0);
	                c[c[o >> 2] >> 2] = (c[n >> 2] | 0) - (c[q >> 2] | 0);
	                c[k >> 2] = -1;
	                v = c[k >> 2] | 0;
	                i = h;
	                return v | 0
	            }

	            function XR(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                c[e >> 2] = c[(c[d >> 2] | 0) + 24 >> 2];
	                Ak(c[e >> 2] | 0) | 0;
	                Hd(c[(c[e >> 2] | 0) + 12 >> 2] | 0) | 0;
	                Ry(c[(c[e >> 2] | 0) + 20 >> 2] | 0);
	                c[(c[e >> 2] | 0) + 12 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 20 >> 2] = 0;
	                i = b;
	                return 0
	            }

	            function YR(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                d = i;
	                i = i + 48 | 0;
	                e = d + 32 | 0;
	                f = d + 28 | 0;
	                g = d + 24 | 0;
	                h = d + 20 | 0;
	                j = d + 16 | 0;
	                k = d + 12 | 0;
	                l = d + 8 | 0;
	                m = d + 4 | 0;
	                n = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                c[j >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                c[k >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                c[l >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                c[m >> 2] = 0;
	                Rf();
	                c[n >> 2] = c[(c[g >> 2] | 0) + 32 >> 2];
	                do if (c[n >> 2] | 0) {
	                    c[h >> 2] = c[(c[n >> 2] | 0) + 60 >> 2];
	                    if (c[(c[f >> 2] | 0) + 16 >> 2] | 0) {
	                        c[(c[n >> 2] | 0) + 60 >> 2] = c[(c[f >> 2] | 0) + 16 >> 2];
	                        break
	                    }
	                    if (c[(c[n >> 2] | 0) + 60 >> 2] | 0)c[k >> 2] = c[(c[n >> 2] | 0) + 60 >> 2]
	                } while (0);
	                if ((c[k >> 2] | 0) != 0 & (c[n >> 2] | 0) != 0)rp(c[n >> 2] | 0, c[k >> 2] | 0) | 0;
	                if ((c[k >> 2] | 0) == 0 & (c[n >> 2] | 0) != 0)c[k >> 2] = qp(c[n >> 2] | 0) | 0;
	                if (!(c[k >> 2] | 0))c[k >> 2] = 201592;
	                do if (((c[k >> 2] | 0) != 0 & (c[j >> 2] | 0) == 0 ? (c[(c[l >> 2] | 0) + 12 >> 2] | 0) == 0 : 0) ? (c[(c[l >> 2] | 0) + 20 >> 2] | 0) == 0 : 0) {
	                    if ((VR(c[f >> 2] | 0, c[k >> 2] | 0) | 0) >= 0) {
	                        c[m >> 2] = 1;
	                        break
	                    }
	                    c[(c[n >> 2] | 0) + 60 >> 2] = c[h >> 2];
	                    c[e >> 2] = -1;
	                    o = c[e >> 2] | 0;
	                    i = d;
	                    return o | 0
	                } while (0);
	                b = c[l >> 2] | 0;
	                l = c[n >> 2] | 0;
	                a = c[g >> 2] | 0;
	                g = c[k >> 2] | 0;
	                if (c[(c[f >> 2] | 0) + 32 >> 2] & 1)up(b, l, a, g, 1); else up(b, l, a, g, 0);
	                if ((c[m >> 2] | 0) != 0 & (c[j >> 2] | 0) == 0)XR(c[f >> 2] | 0) | 0;
	                if (c[n >> 2] | 0)c[(c[n >> 2] | 0) + 60 >> 2] = c[h >> 2];
	                c[e >> 2] = 0;
	                o = c[e >> 2] | 0;
	                i = d;
	                return o | 0
	            }

	            function ZR(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if ((c[f >> 2] | 0) == 0 | (c[e >> 2] | 0) == 0) {
	                    i = d;
	                    return
	                }
	                if (!(c[(c[e >> 2] | 0) + 24 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                c[g >> 2] = c[(c[e >> 2] | 0) + 24 >> 2];
	                Ok(c[g >> 2] | 0, 10, 201336) | 0;
	                Qk(c[g >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0) | 0;
	                if (!(c[(c[f >> 2] | 0) + 52 >> 2] | 0)) {
	                    if (c[(c[f >> 2] | 0) + 56 >> 2] | 0) {
	                        Ok(c[g >> 2] | 0, 8, 201368) | 0;
	                        gz(c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[(c[f >> 2] | 0) + 56 >> 2] | 0) | 0
	                    }
	                } else {
	                    Ok(c[g >> 2] | 0, 8, 201352) | 0;
	                    gz(c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[(c[f >> 2] | 0) + 52 >> 2] | 0) | 0;
	                    Ok(c[g >> 2] | 0, 1, 200760) | 0;
	                    gz(c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[(c[f >> 2] | 0) + 56 >> 2] | 0) | 0
	                }
	                if (((((c[(c[f >> 2] | 0) + 48 >> 2] | 0) == 0 ? (c[(c[f >> 2] | 0) + 40 >> 2] | 0) == 0 : 0) ? (c[(c[f >> 2] | 0) + 44 >> 2] | 0) == 0 : 0) ? (c[(c[f >> 2] | 0) + 36 >> 2] | 0) == 0 : 0) ? (c[(c[f >> 2] | 0) + 60 >> 2] | 0) == 0 : 0) {
	                    Ok(c[g >> 2] | 0, 1, 200968) | 0;
	                    i = d;
	                    return
	                }
	                Ok(c[g >> 2] | 0, 3, 201384) | 0;
	                do if (c[(c[f >> 2] | 0) + 36 >> 2] | 0) {
	                    if ((c[(c[f >> 2] | 0) + 32 >> 2] | 0) != 0 ? (c[(c[(c[f >> 2] | 0) + 32 >> 2] | 0) + 44 >> 2] | 0) != (c[f >> 2] | 0) : 0)break;
	                    mR(c[(c[g >> 2] | 0) + 16 >> 2] | 0, c[(c[f >> 2] | 0) + 36 >> 2] | 0)
	                } while (0);
	                c[h >> 2] = c[(c[e >> 2] | 0) + 40 >> 2];
	                c[j >> 2] = c[(c[e >> 2] | 0) + 36 >> 2];
	                c[k >> 2] = c[(c[e >> 2] | 0) + 28 >> 2];
	                c[(c[e >> 2] | 0) + 40 >> 2] = 0;
	                c[(c[e >> 2] | 0) + 36 >> 2] = -1;
	                c[(c[e >> 2] | 0) + 28 >> 2] = c[(c[f >> 2] | 0) + 32 >> 2];
	                _R(c[e >> 2] | 0, c[(c[f >> 2] | 0) + 12 >> 2] | 0);
	                c[(c[e >> 2] | 0) + 40 >> 2] = c[h >> 2];
	                c[(c[e >> 2] | 0) + 36 >> 2] = c[j >> 2];
	                c[(c[e >> 2] | 0) + 28 >> 2] = c[k >> 2];
	                Ok(c[g >> 2] | 0, 2, 201392) | 0;
	                i = d;
	                return
	            }

	            function _R(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                c[g >> 2] = c[(c[e >> 2] | 0) + 24 >> 2];
	                while (1) {
	                    if (!(c[f >> 2] | 0))break;
	                    do if ((c[33984] | 0) != 0 ? (c[(c[e >> 2] | 0) + 40 >> 2] | 0) == 1 : 0) {
	                        if (((c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 1 ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 8 : 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 7 : 0)break;
	                        b = c[e >> 2] | 0;
	                        if ((c[(c[e >> 2] | 0) + 36 >> 2] | 0) > (c[(c[e >> 2] | 0) + 108 >> 2] | 0))h = c[b + 108 >> 2] | 0; else h = c[b + 36 >> 2] | 0;
	                        b = ca(c[(c[e >> 2] | 0) + 112 >> 2] | 0, h) | 0;
	                        Ok(c[g >> 2] | 0, b, (c[e >> 2] | 0) + 44 | 0) | 0
	                    } while (0);
	                    OR(c[e >> 2] | 0, c[f >> 2] | 0);
	                    if ((c[(c[e >> 2] | 0) + 40 >> 2] | 0) == 1)Ok(c[g >> 2] | 0, 1, 200976) | 0;
	                    c[f >> 2] = c[(c[f >> 2] | 0) + 24 >> 2]
	                }
	                i = d;
	                return
	            }

	            function $R(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                c[g >> 2] = c[(c[e >> 2] | 0) + 24 >> 2];
	                if (!(c[g >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                if ((c[(c[e >> 2] | 0) + 40 >> 2] | 0) == 2)UR(c[e >> 2] | 0, 2); else Ok(c[g >> 2] | 0, 1, 200760) | 0;
	                if ((c[(c[f >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                    Qk(c[g >> 2] | 0, c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0;
	                    Ok(c[g >> 2] | 0, 1, 200856) | 0
	                }
	                Qk(c[g >> 2] | 0, c[(c[f >> 2] | 0) + 8 >> 2] | 0) | 0;
	                Ok(c[g >> 2] | 0, 2, 201328) | 0;
	                gS(c[g >> 2] | 0, c[f >> 2] | 0);
	                Ok(c[g >> 2] | 0, 1, 201296) | 0;
	                i = d;
	                return
	            }

	            function aS(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                KR(c[(c[e >> 2] | 0) + 24 >> 2] | 0, c[f >> 2] | 0, c[e >> 2] | 0);
	                i = d;
	                return
	            }

	            function bS(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                while (1) {
	                    if (!(c[f >> 2] | 0))break;
	                    KR(c[(c[e >> 2] | 0) + 24 >> 2] | 0, c[f >> 2] | 0, c[e >> 2] | 0);
	                    c[f >> 2] = c[c[f >> 2] >> 2]
	                }
	                i = d;
	                return
	            }

	            function cS(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!((c[f >> 2] | 0) != 0 & (c[f >> 2] | 0) != 0)) {
	                    i = d;
	                    return
	                }
	                do {
	                    $R(c[e >> 2] | 0, c[f >> 2] | 0);
	                    c[f >> 2] = c[(c[f >> 2] | 0) + 24 >> 2]
	                } while ((c[f >> 2] | 0) != 0);
	                i = d;
	                return
	            }

	            function dS(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                c[g >> 2] = c[(c[e >> 2] | 0) + 24 >> 2];
	                while (1) {
	                    if (!(c[f >> 2] | 0))break;
	                    if (((c[33984] | 0) != 0 ? (c[(c[e >> 2] | 0) + 40 >> 2] | 0) == 1 : 0) ? (c[(c[f >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) {
	                        b = c[e >> 2] | 0;
	                        if ((c[(c[e >> 2] | 0) + 36 >> 2] | 0) > (c[(c[e >> 2] | 0) + 108 >> 2] | 0))h = c[b + 108 >> 2] | 0; else h = c[b + 36 >> 2] | 0;
	                        b = ca(c[(c[e >> 2] | 0) + 112 >> 2] | 0, h) | 0;
	                        Ok(c[g >> 2] | 0, b, (c[e >> 2] | 0) + 44 | 0) | 0
	                    }
	                    TR(c[e >> 2] | 0, c[f >> 2] | 0);
	                    if ((c[(c[e >> 2] | 0) + 40 >> 2] | 0) == 1)Ok(c[g >> 2] | 0, 1, 200976) | 0;
	                    c[f >> 2] = c[(c[f >> 2] | 0) + 24 >> 2]
	                }
	                i = d;
	                return
	            }

	            function eS(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 28 | 0;
	                g = e + 24 | 0;
	                h = e + 20 | 0;
	                j = e + 16 | 0;
	                k = e + 12 | 0;
	                l = e + 8 | 0;
	                m = e + 4 | 0;
	                n = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = 0;
	                c[j >> 2] = 0;
	                c[k >> 2] = 0;
	                c[l >> 2] = 0;
	                if (!(c[g >> 2] | 0)) {
	                    i = e;
	                    return
	                }
	                c[n >> 2] = c[(c[f >> 2] | 0) + 24 >> 2];
	                c[m >> 2] = c[(c[g >> 2] | 0) + 20 >> 2];
	                while (1) {
	                    if (!(c[g >> 2] | 0))break;
	                    if ((c[(c[g >> 2] | 0) + 36 >> 2] | 0) == 0 ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 201200) | 0) != 0 : 0)c[l >> 2] = c[g >> 2]; else o = 7;
	                    do if ((o | 0) == 7) {
	                        o = 0;
	                        if ((c[(c[g >> 2] | 0) + 36 >> 2] | 0) == 0 ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 201208) | 0) != 0 : 0) {
	                            c[k >> 2] = c[g >> 2];
	                            break
	                        }
	                        if ((c[(c[g >> 2] | 0) + 36 >> 2] | 0) == 0 ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 201216) | 0) != 0 : 0) {
	                            c[j >> 2] = c[g >> 2];
	                            break
	                        }
	                        if (((c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 201216) | 0) != 0 : 0) ? (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0, 201224) | 0) != 0 : 0) {
	                            c[h >> 2] = c[g >> 2];
	                            break
	                        }
	                        if (!(c[(c[g >> 2] | 0) + 36 >> 2] | 0)) {
	                            if (((c[(c[g >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 40 >> 2] | 0) != 0 : 0) ? (d[c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 40 >> 2] >> 0] | 0 | 0) != 0 : 0)break;
	                            if (sp(c[(c[g >> 2] | 0) + 8 >> 2] | 0) | 0) {
	                                if (c[(c[g >> 2] | 0) + 12 >> 2] | 0)Rh(c[(c[g >> 2] | 0) + 12 >> 2] | 0);
	                                b = li(c[(c[g >> 2] | 0) + 8 >> 2] | 0) | 0;
	                                c[(c[g >> 2] | 0) + 12 >> 2] = b;
	                                if (c[(c[g >> 2] | 0) + 12 >> 2] | 0)c[(c[(c[g >> 2] | 0) + 12 >> 2] | 0) + 20 >> 2] = c[g >> 2]
	                            }
	                        }
	                    } while (0);
	                    $R(c[f >> 2] | 0, c[g >> 2] | 0);
	                    c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2]
	                }
	                do if ((c[k >> 2] | 0) != 0 & (c[l >> 2] | 0) == 0 & (c[m >> 2] | 0) != 0 ? (c[(c[m >> 2] | 0) + 8 >> 2] | 0) != 0 : 0) {
	                    if (((((((((qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 201232) | 0) == 0 ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 201240) | 0) == 0 : 0) ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 201248) | 0) == 0 : 0) ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 201160) | 0) == 0 : 0) ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 201256) | 0) == 0 : 0) ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 201264) | 0) == 0 : 0) ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 201272) | 0) == 0 : 0) ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 201144) | 0) == 0 : 0) ? (qy(c[(c[m >> 2] | 0) + 8 >> 2] | 0, 201280) | 0) == 0 : 0)break;
	                    Ok(c[n >> 2] | 0, 5, 201288) | 0;
	                    gS(c[n >> 2] | 0, c[k >> 2] | 0);
	                    Ok(c[n >> 2] | 0, 1, 201296) | 0
	                } while (0);
	                if ((c[j >> 2] | 0) != 0 & (c[h >> 2] | 0) == 0) {
	                    Ok(c[n >> 2] | 0, 11, 201304) | 0;
	                    gS(c[n >> 2] | 0, c[j >> 2] | 0);
	                    Ok(c[n >> 2] | 0, 1, 201296) | 0;
	                    i = e;
	                    return
	                }
	                if (!((c[h >> 2] | 0) != 0 & (c[j >> 2] | 0) == 0)) {
	                    i = e;
	                    return
	                }
	                Ok(c[n >> 2] | 0, 7, 201320) | 0;
	                gS(c[n >> 2] | 0, c[h >> 2] | 0);
	                Ok(c[n >> 2] | 0, 1, 201296) | 0;
	                i = e;
	                return
	            }

	            function fS(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[f >> 2] = a;
	                a:do if (!(c[f >> 2] | 0))c[e >> 2] = -1; else {
	                    if ((c[(c[f >> 2] | 0) + 4 >> 2] | 0) != 1) {
	                        c[e >> 2] = 0;
	                        break
	                    }
	                    if ((c[(c[f >> 2] | 0) + 36 >> 2] | 0) != 0 ? (qy(c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, 201064) | 0) == 0 : 0) {
	                        c[e >> 2] = 0;
	                        break
	                    }
	                    if (c[(c[f >> 2] | 0) + 12 >> 2] | 0) {
	                        c[e >> 2] = 0;
	                        break
	                    }
	                    do switch (d[c[(c[f >> 2] | 0) + 8 >> 2] >> 0] | 0 | 0) {
	                        case 98:
	                        {
	                            if (qy(c[(c[f >> 2] | 0) + 8 >> 2] | 0, 201104) | 0) {
	                                c[e >> 2] = 1;
	                                break a
	                            }
	                            if (qy(c[(c[f >> 2] | 0) + 8 >> 2] | 0, 201112) | 0) {
	                                c[e >> 2] = 1;
	                                break a
	                            }
	                            if (qy(c[(c[f >> 2] | 0) + 8 >> 2] | 0, 201120) | 0) {
	                                c[e >> 2] = 1;
	                                break a
	                            } else {
	                                c[e >> 2] = 0;
	                                break a
	                            }
	                            break
	                        }
	                        case 99:
	                        {
	                            if (qy(c[(c[f >> 2] | 0) + 8 >> 2] | 0, 201136) | 0) {
	                                c[e >> 2] = 1;
	                                break a
	                            } else {
	                                c[e >> 2] = 0;
	                                break a
	                            }
	                            break
	                        }
	                        case 97:
	                        {
	                            if (qy(c[(c[f >> 2] | 0) + 8 >> 2] | 0, 201096) | 0) {
	                                c[e >> 2] = 1;
	                                break a
	                            } else {
	                                c[e >> 2] = 0;
	                                break a
	                            }
	                            break
	                        }
	                        case 109:
	                        {
	                            if (qy(c[(c[f >> 2] | 0) + 8 >> 2] | 0, 200920) | 0) {
	                                c[e >> 2] = 1;
	                                break a
	                            } else {
	                                c[e >> 2] = 0;
	                                break a
	                            }
	                            break
	                        }
	                        case 102:
	                        {
	                            if (qy(c[(c[f >> 2] | 0) + 8 >> 2] | 0, 201144) | 0) {
	                                c[e >> 2] = 1;
	                                break a
	                            } else {
	                                c[e >> 2] = 0;
	                                break a
	                            }
	                            break
	                        }
	                        case 105:
	                        {
	                            if (qy(c[(c[f >> 2] | 0) + 8 >> 2] | 0, 201160) | 0) {
	                                c[e >> 2] = 1;
	                                break a
	                            }
	                            if (qy(c[(c[f >> 2] | 0) + 8 >> 2] | 0, 201168) | 0) {
	                                c[e >> 2] = 1;
	                                break a
	                            }
	                            if (qy(c[(c[f >> 2] | 0) + 8 >> 2] | 0, 201176) | 0) {
	                                c[e >> 2] = 1;
	                                break a
	                            } else {
	                                c[e >> 2] = 0;
	                                break a
	                            }
	                            break
	                        }
	                        case 104:
	                        {
	                            if (qy(c[(c[f >> 2] | 0) + 8 >> 2] | 0, 201152) | 0) {
	                                c[e >> 2] = 1;
	                                break a
	                            } else {
	                                c[e >> 2] = 0;
	                                break a
	                            }
	                            break
	                        }
	                        case 112:
	                        {
	                            if (qy(c[(c[f >> 2] | 0) + 8 >> 2] | 0, 201192) | 0) {
	                                c[e >> 2] = 1;
	                                break a
	                            } else {
	                                c[e >> 2] = 0;
	                                break a
	                            }
	                            break
	                        }
	                        case 108:
	                        {
	                            if (qy(c[(c[f >> 2] | 0) + 8 >> 2] | 0, 201184) | 0) {
	                                c[e >> 2] = 1;
	                                break a
	                            } else {
	                                c[e >> 2] = 0;
	                                break a
	                            }
	                            break
	                        }
	                        default:
	                        {
	                            c[e >> 2] = 0;
	                            break a
	                        }
	                    } while (0)
	                } while (0);
	                i = b;
	                return c[e >> 2] | 0
	            }

	            function gS(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[g >> 2] = c[(c[f >> 2] | 0) + 12 >> 2];
	                while (1) {
	                    if (!(c[g >> 2] | 0))break;
	                    b = c[(c[g >> 2] | 0) + 4 >> 2] | 0;
	                    if ((b | 0) == 5) {
	                        cz(c[(c[e >> 2] | 0) + 16 >> 2] | 0, 200792, 1) | 0;
	                        a = c[(c[e >> 2] | 0) + 16 >> 2] | 0;
	                        h = c[(c[g >> 2] | 0) + 8 >> 2] | 0;
	                        cz(a, h, xy(c[(c[g >> 2] | 0) + 8 >> 2] | 0) | 0) | 0;
	                        cz(c[(c[e >> 2] | 0) + 16 >> 2] | 0, 200800, 1) | 0
	                    } else if ((b | 0) == 3)xR(c[(c[e >> 2] | 0) + 16 >> 2] | 0, c[(c[f >> 2] | 0) + 32 >> 2] | 0, c[f >> 2] | 0, c[(c[g >> 2] | 0) + 40 >> 2] | 0);
	                    c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2]
	                }
	                i = d;
	                return
	            }

	            function hS(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if ((c[(c[d >> 2] | 0) + 8 >> 2] | 0) != 0 ? (c[(c[d >> 2] | 0) + 4 >> 2] | 0) == 0 : 0)Th(c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 52 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 52 >> 2] | 0);
	                oS(c[(c[d >> 2] | 0) + 40 >> 2] | 0);
	                pS(c[(c[d >> 2] | 0) + 36 >> 2] | 0);
	                zP(c[(c[d >> 2] | 0) + 20 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function iS(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0)) {
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](84) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    qS(0, 201776, 0);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                a = (c[f >> 2] | 0) + 0 | 0;
	                h = a + 84 | 0;
	                do {
	                    c[a >> 2] = 0;
	                    a = a + 4 | 0
	                } while ((a | 0) < (h | 0));
	                c[c[f >> 2] >> 2] = 1;
	                a = xP() | 0;
	                c[(c[f >> 2] | 0) + 24 >> 2] = a;
	                a = AP(c[(c[f >> 2] | 0) + 24 >> 2] | 0, c[e >> 2] | 0, -1) | 0;
	                c[(c[f >> 2] | 0) + 4 >> 2] = a;
	                c[(c[f >> 2] | 0) + 64 >> 2] = 0;
	                a = Lr(0) | 0;
	                c[(c[f >> 2] | 0) + 36 >> 2] = a;
	                if (!(c[(c[f >> 2] | 0) + 36 >> 2] | 0)) {
	                    qS(0, 201816, 0);
	                    jS(c[f >> 2] | 0);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    c[(c[(c[f >> 2] | 0) + 36 >> 2] | 0) + 196 >> 2] = 1;
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function jS(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if ((c[(c[d >> 2] | 0) + 8 >> 2] | 0) != 0 ? (c[(c[d >> 2] | 0) + 12 >> 2] | 0) == 0 : 0)Th(c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 36 >> 2] | 0)Nr(c[(c[d >> 2] | 0) + 36 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 52 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 52 >> 2] | 0);
	                zP(c[(c[d >> 2] | 0) + 24 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function kS(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                b = i;
	                i = i + 48 | 0;
	                e = b + 36 | 0;
	                f = b + 32 | 0;
	                g = b + 28 | 0;
	                h = b + 24 | 0;
	                j = b + 20 | 0;
	                k = b + 16 | 0;
	                l = b + 12 | 0;
	                m = b + 8 | 0;
	                n = b + 4 | 0;
	                o = b;
	                c[f >> 2] = a;
	                c[g >> 2] = 0;
	                c[l >> 2] = 0;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    p = c[e >> 2] | 0;
	                    i = b;
	                    return p | 0
	                }
	                c[(c[f >> 2] | 0) + 28 >> 2] = 0;
	                a = c[f >> 2] | 0;
	                do if (!(c[(c[f >> 2] | 0) + 4 >> 2] | 0)) {
	                    q = c[f >> 2] | 0;
	                    if (c[a + 16 >> 2] | 0) {
	                        c[h >> 2] = hg(c[q + 16 >> 2] | 0, c[(c[f >> 2] | 0) + 20 >> 2] | 0, 0, 0, 2) | 0;
	                        if (c[h >> 2] | 0) {
	                            r = my(201944) | 0;
	                            c[(c[h >> 2] | 0) + 72 >> 2] = r;
	                            r = AP(c[(c[f >> 2] | 0) + 24 >> 2] | 0, 201944, -1) | 0;
	                            c[(c[f >> 2] | 0) + 4 >> 2] = r;
	                            c[(c[f >> 2] | 0) + 12 >> 2] = 0;
	                            break
	                        }
	                        rS(c[f >> 2] | 0, 0, 1766, 201904, 0, 0);
	                        c[e >> 2] = 0;
	                        p = c[e >> 2] | 0;
	                        i = b;
	                        return p | 0
	                    } else {
	                        r = c[f >> 2] | 0;
	                        if (c[q + 8 >> 2] | 0) {
	                            c[h >> 2] = c[r + 8 >> 2];
	                            c[l >> 2] = 1;
	                            c[(c[f >> 2] | 0) + 12 >> 2] = 1;
	                            break
	                        }
	                        rS(r, 0, 1758, 201904, 0, 0);
	                        c[e >> 2] = 0;
	                        p = c[e >> 2] | 0;
	                        i = b;
	                        return p | 0
	                    }
	                } else {
	                    c[h >> 2] = gg(c[a + 4 >> 2] | 0, 0, 2) | 0;
	                    r = c[f >> 2] | 0;
	                    if (c[h >> 2] | 0) {
	                        c[r + 12 >> 2] = 0;
	                        break
	                    }
	                    rS(r, 0, 1757, 201856, c[(c[f >> 2] | 0) + 4 >> 2] | 0, 0);
	                    c[e >> 2] = 0;
	                    p = c[e >> 2] | 0;
	                    i = b;
	                    return p | 0
	                } while (0);
	                c[j >> 2] = Pi(c[h >> 2] | 0) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    rS(c[f >> 2] | 0, c[h >> 2] | 0, 1759, 201968, 0, 0);
	                    if (!(c[l >> 2] | 0))Th(c[h >> 2] | 0);
	                    c[e >> 2] = 0;
	                    p = c[e >> 2] | 0;
	                    i = b;
	                    return p | 0
	                }
	                do if ((((c[j >> 2] | 0) != 0 ? (c[(c[j >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (c[(c[j >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[j >> 2] | 0) + 8 >> 2] | 0, 202008) | 0) != 0 : 0) {
	                    if ((qy(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50504] | 0) | 0) == 0 ? (qy(c[(c[(c[j >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50506] | 0) | 0) == 0 : 0) {
	                        s = 24;
	                        break
	                    }
	                    c[g >> 2] = sS(c[f >> 2] | 0) | 0;
	                    if (c[g >> 2] | 0) {
	                        c[(c[f >> 2] | 0) + 40 >> 2] = c[g >> 2];
	                        c[k >> 2] = c[(c[j >> 2] | 0) + 12 >> 2];
	                        while (1) {
	                            if (!(c[k >> 2] | 0))break;
	                            if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 1 ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) {
	                                if (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50504] | 0) | 0)break;
	                                if (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50506] | 0) | 0)break
	                            }
	                            c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                        }
	                        a:do if ((((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 202088) | 0) != 0 : 0) {
	                            if ((qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50504] | 0) | 0) == 0 ? (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50506] | 0) | 0) == 0 : 0)break;
	                            c[m >> 2] = _i(c[k >> 2] | 0) | 0;
	                            if (c[m >> 2] | 0) {
	                                a = AP(c[(c[g >> 2] | 0) + 20 >> 2] | 0, c[m >> 2] | 0, -1) | 0;
	                                c[(c[g >> 2] | 0) + 24 >> 2] = a;
	                                zb[c[135736 >> 2] & 511](c[m >> 2] | 0)
	                            }
	                            c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2];
	                            while (1) {
	                                if (!(c[k >> 2] | 0))break a;
	                                do if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                                    if (!(c[(c[k >> 2] | 0) + 36 >> 2] | 0))break;
	                                    if (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50504] | 0) | 0)break a;
	                                    if (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50506] | 0) | 0)break a
	                                } while (0);
	                                c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                            }
	                        } while (0);
	                        b:while (1) {
	                            if (!(c[k >> 2] | 0))break;
	                            if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) != 1)break;
	                            if (!(c[(c[k >> 2] | 0) + 36 >> 2] | 0))break;
	                            if (!(qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 202096) | 0))break;
	                            if ((qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50504] | 0) | 0) == 0 ? (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50506] | 0) | 0) == 0 : 0)break;
	                            c[n >> 2] = ej(c[k >> 2] | 0, 202104) | 0;
	                            c[o >> 2] = ej(c[k >> 2] | 0, 202112) | 0;
	                            if (!((c[o >> 2] | 0) != 0 ? (d[c[o >> 2] >> 0] | 0 | 0) != 0 : 0))rS(c[f >> 2] | 0, c[k >> 2] | 0, 1759, 202120, 0, 0);
	                            if (!((c[n >> 2] | 0) != 0 ? (d[c[n >> 2] >> 0] | 0 | 0) != 0 : 0))rS(c[f >> 2] | 0, c[k >> 2] | 0, 1759, 202144, 0, 0);
	                            if ((c[n >> 2] | 0) != 0 & (c[o >> 2] | 0) != 0) {
	                                rr(c[(c[f >> 2] | 0) + 36 >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0) | 0;
	                                tS(c[f >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0);
	                                a = (c[g >> 2] | 0) + 28 | 0;
	                                c[a >> 2] = (c[a >> 2] | 0) + 1
	                            }
	                            if (c[o >> 2] | 0)zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                            if (c[n >> 2] | 0)zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                            c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2];
	                            while (1) {
	                                if (!(c[k >> 2] | 0))continue b;
	                                do if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                                    if (!(c[(c[k >> 2] | 0) + 36 >> 2] | 0))break;
	                                    if (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50504] | 0) | 0)continue b;
	                                    if (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50506] | 0) | 0)continue b
	                                } while (0);
	                                c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                            }
	                        }
	                        c:while (1) {
	                            if (!(c[k >> 2] | 0))break;
	                            do if ((((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 202176) | 0) != 0 : 0) {
	                                if ((qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50504] | 0) | 0) == 0 ? (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50506] | 0) | 0) == 0 : 0) {
	                                    s = 81;
	                                    break
	                                }
	                                uS(c[f >> 2] | 0, c[k >> 2] | 0);
	                                a = (c[g >> 2] | 0) + 32 | 0;
	                                c[a >> 2] = (c[a >> 2] | 0) + 1
	                            } else s = 81; while (0);
	                            if ((s | 0) == 81) {
	                                s = 0;
	                                rS(c[f >> 2] | 0, c[k >> 2] | 0, 1759, 202184, c[(c[k >> 2] | 0) + 8 >> 2] | 0, 0)
	                            }
	                            c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2];
	                            while (1) {
	                                if (!(c[k >> 2] | 0))continue c;
	                                if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 1 ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) {
	                                    if (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50504] | 0) | 0)continue c;
	                                    if (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50506] | 0) | 0)continue c
	                                }
	                                c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                            }
	                        }
	                        if (!(c[(c[g >> 2] | 0) + 32 >> 2] | 0)) {
	                            rS(c[f >> 2] | 0, c[j >> 2] | 0, 1759, 202232, c[(c[f >> 2] | 0) + 4 >> 2] | 0, 0);
	                            break
	                        }
	                        c[(c[g >> 2] | 0) + 8 >> 2] = c[h >> 2];
	                        if (c[l >> 2] | 0)c[(c[g >> 2] | 0) + 4 >> 2] = 1;
	                        c[l >> 2] = 1
	                    }
	                } else s = 24; while (0);
	                if ((s | 0) == 24)rS(c[f >> 2] | 0, c[j >> 2] | 0, 1759, 202032, c[(c[f >> 2] | 0) + 4 >> 2] | 0, 0);
	                if (!(c[l >> 2] | 0))Th(c[h >> 2] | 0);
	                do if (c[g >> 2] | 0)if (c[(c[f >> 2] | 0) + 28 >> 2] | 0) {
	                    hS(c[g >> 2] | 0);
	                    c[g >> 2] = 0;
	                    break
	                } else {
	                    c[(c[g >> 2] | 0) + 52 >> 2] = c[(c[f >> 2] | 0) + 52 >> 2];
	                    c[(c[g >> 2] | 0) + 44 >> 2] = c[(c[f >> 2] | 0) + 44 >> 2];
	                    c[(c[f >> 2] | 0) + 52 >> 2] = 0;
	                    break
	                } while (0);
	                c[e >> 2] = c[g >> 2];
	                p = c[e >> 2] | 0;
	                i = b;
	                return p | 0
	            }

	            function lS(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 16 | 0;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 4 | 0;
	                j = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[j >> 2] = Cb[c[135744 >> 2] & 511](64) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    vS(0, 202280, 0);
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                b = (c[j >> 2] | 0) + 0 | 0;
	                a = b + 64 | 0;
	                do {
	                    c[b >> 2] = 0;
	                    b = b + 4 | 0
	                } while ((b | 0) < (a | 0));
	                c[c[j >> 2] >> 2] = 2;
	                c[(c[j >> 2] | 0) + 20 >> 2] = c[f >> 2];
	                b = Lr(0) | 0;
	                c[(c[j >> 2] | 0) + 24 >> 2] = b;
	                c[(c[j >> 2] | 0) + 4 >> 2] = c[g >> 2];
	                if (!(c[(c[j >> 2] | 0) + 24 >> 2] | 0)) {
	                    qS(0, 201816, 0);
	                    mS(c[j >> 2] | 0);
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                c[h >> 2] = 0;
	                while (1) {
	                    if ((c[h >> 2] | 0) >= (c[(c[f >> 2] | 0) + 44 >> 2] | 0))break;
	                    if (!(c[(c[(c[f >> 2] | 0) + 52 >> 2] | 0) + (c[h >> 2] << 1 << 2) >> 2] | 0))break;
	                    if (!(c[(c[(c[f >> 2] | 0) + 52 >> 2] | 0) + ((c[h >> 2] << 1) + 1 << 2) >> 2] | 0))break;
	                    rr(c[(c[j >> 2] | 0) + 24 >> 2] | 0, c[(c[(c[f >> 2] | 0) + 52 >> 2] | 0) + ((c[h >> 2] << 1) + 1 << 2) >> 2] | 0, c[(c[(c[f >> 2] | 0) + 52 >> 2] | 0) + (c[h >> 2] << 1 << 2) >> 2] | 0) | 0;
	                    c[h >> 2] = (c[h >> 2] | 0) + 1
	                }
	                c[e >> 2] = c[j >> 2];
	                k = c[e >> 2] | 0;
	                i = d;
	                return k | 0
	            }

	            function mS(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                if (c[(c[d >> 2] | 0) + 24 >> 2] | 0)Nr(c[(c[d >> 2] | 0) + 24 >> 2] | 0);
	                if (c[(c[d >> 2] | 0) + 8 >> 2] | 0)zP(c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function nS(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0;
	                d = i;
	                i = i + 48 | 0;
	                e = d;
	                f = d + 36 | 0;
	                g = d + 32 | 0;
	                h = d + 28 | 0;
	                j = d + 24 | 0;
	                k = d + 20 | 0;
	                l = d + 16 | 0;
	                m = d + 12 | 0;
	                n = d + 8 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                if (((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 20 >> 2] | 0) != 0 : 0) ? !((c[h >> 2] | 0) == 0 ? 1 : (c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 40 >> 2] | 0) == 0) : 0) {
	                    c[(c[g >> 2] | 0) + 12 >> 2] = 0;
	                    c[k >> 2] = Pi(c[h >> 2] | 0) | 0;
	                    if (!(c[k >> 2] | 0)) {
	                        b = c[33976] | 0;
	                        a = c[33980] | 0;
	                        c[e >> 2] = 202344;
	                        c[e + 4 >> 2] = 1679;
	                        Db[b & 511](a, 202312, e);
	                        e = (c[g >> 2] | 0) + 12 | 0;
	                        c[e >> 2] = (c[e >> 2] | 0) + 1;
	                        c[f >> 2] = 1;
	                        o = c[f >> 2] | 0;
	                        i = d;
	                        return o | 0
	                    }
	                    a:do if ((c[(c[g >> 2] | 0) + 4 >> 2] & 1 | 0) == 0 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) {
	                        c[l >> 2] = c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 36 >> 2];
	                        while (1) {
	                            if (!(c[l >> 2] | 0))break a;
	                            yS(c[g >> 2] | 0, c[l >> 2] | 0);
	                            c[j >> 2] = c[k >> 2];
	                            while (1) {
	                                p = c[l >> 2] | 0;
	                                if (!(c[j >> 2] | 0))break;
	                                c[m >> 2] = c[p + 4 >> 2];
	                                while (1) {
	                                    if (!(c[m >> 2] | 0))break;
	                                    b:do if ((NQ(c[(c[m >> 2] | 0) + 20 >> 2] | 0, c[j >> 2] | 0) | 0) == 1) {
	                                        c[n >> 2] = c[(c[m >> 2] | 0) + 16 >> 2];
	                                        while (1) {
	                                            if (!(c[n >> 2] | 0))break b;
	                                            wS(c[g >> 2] | 0, c[n >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[l >> 2] | 0) | 0;
	                                            c[n >> 2] = c[c[n >> 2] >> 2]
	                                        }
	                                    } while (0);
	                                    c[m >> 2] = c[(c[m >> 2] | 0) + 4 >> 2]
	                                }
	                                c[j >> 2] = xS(c[j >> 2] | 0) | 0
	                            }
	                            c[l >> 2] = c[p >> 2]
	                        }
	                    } else q = 9; while (0);
	                    c:do if ((q | 0) == 9) {
	                        c[j >> 2] = c[k >> 2];
	                        while (1) {
	                            if (!(c[j >> 2] | 0))break c;
	                            c[m >> 2] = c[(c[(c[g >> 2] | 0) + 20 >> 2] | 0) + 40 >> 2];
	                            while (1) {
	                                if (!(c[m >> 2] | 0))break;
	                                d:do if ((NQ(c[(c[m >> 2] | 0) + 20 >> 2] | 0, c[j >> 2] | 0) | 0) == 1) {
	                                    c[n >> 2] = c[(c[m >> 2] | 0) + 16 >> 2];
	                                    while (1) {
	                                        if (!(c[n >> 2] | 0))break d;
	                                        wS(c[g >> 2] | 0, c[n >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[(c[m >> 2] | 0) + 20 >> 2] | 0) | 0;
	                                        c[n >> 2] = c[c[n >> 2] >> 2]
	                                    }
	                                } while (0);
	                                c[m >> 2] = c[c[m >> 2] >> 2]
	                            }
	                            c[j >> 2] = xS(c[j >> 2] | 0) | 0
	                        }
	                    } while (0);
	                    c[f >> 2] = c[(c[g >> 2] | 0) + 12 >> 2];
	                    o = c[f >> 2] | 0;
	                    i = d;
	                    return o | 0
	                }
	                c[f >> 2] = -1;
	                o = c[f >> 2] | 0;
	                i = d;
	                return o | 0
	            }

	            function oS(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                while (1) {
	                    if (!(c[d >> 2] | 0))break;
	                    c[e >> 2] = c[c[d >> 2] >> 2];
	                    if (c[(c[d >> 2] | 0) + 16 >> 2] | 0)zS(c[(c[d >> 2] | 0) + 16 >> 2] | 0);
	                    if (c[(c[d >> 2] | 0) + 12 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 12 >> 2] | 0);
	                    if (c[(c[d >> 2] | 0) + 20 >> 2] | 0)EQ(c[(c[d >> 2] | 0) + 20 >> 2] | 0);
	                    if (c[(c[d >> 2] | 0) + 24 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 24 >> 2] | 0);
	                    zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                    c[d >> 2] = c[e >> 2]
	                }
	                i = b;
	                return
	            }

	            function pS(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                while (1) {
	                    if (!(c[d >> 2] | 0))break;
	                    c[e >> 2] = c[c[d >> 2] >> 2];
	                    if (c[(c[d >> 2] | 0) + 8 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 8 >> 2] | 0);
	                    zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                    c[d >> 2] = c[e >> 2]
	                }
	                i = b;
	                return
	            }

	            function qS(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if (c[f >> 2] | 0) {
	                    d = (c[f >> 2] | 0) + 28 | 0;
	                    c[d >> 2] = (c[d >> 2] | 0) + 1
	                }
	                ce(16, 2, c[h >> 2] | 0, 0, c[g >> 2] | 0);
	                i = e;
	                return
	            }

	            function rS(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h;
	                k = h + 40 | 0;
	                l = h + 36 | 0;
	                m = h + 32 | 0;
	                n = h + 28 | 0;
	                o = h + 24 | 0;
	                p = h + 20 | 0;
	                q = h + 16 | 0;
	                r = h + 12 | 0;
	                s = h + 8 | 0;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                c[q >> 2] = 0;
	                c[r >> 2] = 0;
	                c[s >> 2] = 0;
	                if (c[k >> 2] | 0) {
	                    g = (c[k >> 2] | 0) + 28 | 0;
	                    c[g >> 2] = (c[g >> 2] | 0) + 1;
	                    c[q >> 2] = c[(c[k >> 2] | 0) + 72 >> 2];
	                    c[s >> 2] = c[(c[k >> 2] | 0) + 68 >> 2];
	                    c[r >> 2] = c[(c[k >> 2] | 0) + 80 >> 2]
	                }
	                g = c[r >> 2] | 0;
	                r = c[q >> 2] | 0;
	                q = c[s >> 2] | 0;
	                s = c[k >> 2] | 0;
	                k = c[l >> 2] | 0;
	                l = c[m >> 2] | 0;
	                m = c[o >> 2] | 0;
	                f = c[p >> 2] | 0;
	                e = c[n >> 2] | 0;
	                n = c[p >> 2] | 0;
	                c[j >> 2] = c[o >> 2];
	                c[j + 4 >> 2] = n;
	                Xd(g, r, q, s, k, 16, l, 2, 0, 0, m, f, 0, 0, 0, e, j);
	                i = h;
	                return
	            }

	            function sS(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[e >> 2] = a;
	                c[f >> 2] = Cb[c[135744 >> 2] & 511](56) | 0;
	                if (!(c[f >> 2] | 0)) {
	                    qS(c[e >> 2] | 0, 203040, 0);
	                    c[d >> 2] = 0;
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                } else {
	                    a = (c[f >> 2] | 0) + 0 | 0;
	                    h = a + 56 | 0;
	                    do {
	                        c[a >> 2] = 0;
	                        a = a + 4 | 0
	                    } while ((a | 0) < (h | 0));
	                    c[(c[f >> 2] | 0) + 20 >> 2] = c[(c[e >> 2] | 0) + 24 >> 2];
	                    yP(c[(c[f >> 2] | 0) + 20 >> 2] | 0) | 0;
	                    c[d >> 2] = c[f >> 2];
	                    g = c[d >> 2] | 0;
	                    i = b;
	                    return g | 0
	                }
	                return 0
	            }

	            function tS(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                d = c[f >> 2] | 0;
	                do if (c[(c[f >> 2] | 0) + 52 >> 2] | 0) {
	                    if (((c[d + 44 >> 2] | 0) + 2 | 0) >= (c[(c[f >> 2] | 0) + 48 >> 2] | 0)) {
	                        c[j >> 2] = Hb[c[135760 >> 2] & 511](c[(c[f >> 2] | 0) + 52 >> 2] | 0, c[(c[f >> 2] | 0) + 48 >> 2] << 2 << 2) | 0;
	                        if (c[j >> 2] | 0) {
	                            c[(c[f >> 2] | 0) + 52 >> 2] = c[j >> 2];
	                            b = (c[f >> 2] | 0) + 48 | 0;
	                            c[b >> 2] = c[b >> 2] << 1;
	                            break
	                        }
	                        qS(0, 203008, 0);
	                        i = e;
	                        return
	                    }
	                } else {
	                    c[d + 48 >> 2] = 10;
	                    b = Cb[c[135744 >> 2] & 511](c[(c[f >> 2] | 0) + 48 >> 2] << 1 << 2) | 0;
	                    c[(c[f >> 2] | 0) + 52 >> 2] = b;
	                    if (c[(c[f >> 2] | 0) + 52 >> 2] | 0) {
	                        c[(c[f >> 2] | 0) + 44 >> 2] = 0;
	                        break
	                    }
	                    qS(0, 203008, 0);
	                    i = e;
	                    return
	                } while (0);
	                d = AP(c[(c[f >> 2] | 0) + 24 >> 2] | 0, c[h >> 2] | 0, -1) | 0;
	                c[(c[(c[f >> 2] | 0) + 52 >> 2] | 0) + (c[(c[f >> 2] | 0) + 44 >> 2] << 1 << 2) >> 2] = d;
	                d = AP(c[(c[f >> 2] | 0) + 24 >> 2] | 0, c[g >> 2] | 0, -1) | 0;
	                c[(c[(c[f >> 2] | 0) + 52 >> 2] | 0) + ((c[(c[f >> 2] | 0) + 44 >> 2] << 1) + 1 << 2) >> 2] = d;
	                d = (c[f >> 2] | 0) + 44 | 0;
	                c[d >> 2] = (c[d >> 2] | 0) + 1;
	                c[(c[(c[f >> 2] | 0) + 52 >> 2] | 0) + (c[(c[f >> 2] | 0) + 44 >> 2] << 1 << 2) >> 2] = 0;
	                c[(c[(c[f >> 2] | 0) + 52 >> 2] | 0) + ((c[(c[f >> 2] | 0) + 44 >> 2] << 1) + 1 << 2) >> 2] = 0;
	                i = e;
	                return
	            }

	            function uS(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                k = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[j >> 2] = 0;
	                if ((c[e >> 2] | 0) == 0 | (c[f >> 2] | 0) == 0) {
	                    i = d;
	                    return
	                }
	                c[k >> 2] = ej(c[f >> 2] | 0, 202488) | 0;
	                if (!(c[k >> 2] | 0))c[k >> 2] = ej(c[f >> 2] | 0, 202464) | 0;
	                c[h >> 2] = AS(c[e >> 2] | 0, c[(c[e >> 2] | 0) + 40 >> 2] | 0, c[f >> 2] | 0, c[k >> 2] | 0) | 0;
	                if (!(c[h >> 2] | 0)) {
	                    if (!(c[k >> 2] | 0)) {
	                        i = d;
	                        return
	                    }
	                    zb[c[135736 >> 2] & 511](c[k >> 2] | 0);
	                    i = d;
	                    return
	                }
	                c[g >> 2] = c[(c[f >> 2] | 0) + 12 >> 2];
	                while (1) {
	                    if (!(c[g >> 2] | 0))break;
	                    if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) {
	                        if (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50504] | 0) | 0)break;
	                        if (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50506] | 0) | 0)break
	                    }
	                    c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2]
	                }
	                a:while (1) {
	                    if (!(c[g >> 2] | 0))break;
	                    do if ((((c[g >> 2] | 0) != 0 ? (c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[g >> 2] | 0) + 8 >> 2] | 0, 202496) | 0) != 0 : 0) {
	                        if ((qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50504] | 0) | 0) == 0 ? (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50506] | 0) | 0) == 0 : 0) {
	                            l = 22;
	                            break
	                        }
	                        BS(c[e >> 2] | 0, c[h >> 2] | 0, c[g >> 2] | 0);
	                        c[j >> 2] = (c[j >> 2] | 0) + 1
	                    } else l = 22; while (0);
	                    if ((l | 0) == 22) {
	                        l = 0;
	                        rS(c[e >> 2] | 0, c[g >> 2] | 0, 1759, 202504, c[(c[g >> 2] | 0) + 8 >> 2] | 0, 0)
	                    }
	                    c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2];
	                    while (1) {
	                        if (!(c[g >> 2] | 0))continue a;
	                        if ((c[(c[g >> 2] | 0) + 4 >> 2] | 0) == 1 ? (c[(c[g >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) {
	                            if (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50504] | 0) | 0)continue a;
	                            if (qy(c[(c[(c[g >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50506] | 0) | 0)continue a
	                        }
	                        c[g >> 2] = c[(c[g >> 2] | 0) + 24 >> 2]
	                    }
	                }
	                if (c[j >> 2] | 0) {
	                    i = d;
	                    return
	                }
	                rS(c[e >> 2] | 0, c[f >> 2] | 0, 1759, 202544, 0, 0);
	                i = d;
	                return
	            }

	            function vS(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 8 | 0;
	                g = e + 4 | 0;
	                h = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if (c[f >> 2] | 0) {
	                    d = (c[f >> 2] | 0) + 12 | 0;
	                    c[d >> 2] = (c[d >> 2] | 0) + 1;
	                    c[(c[f >> 2] | 0) + 16 >> 2] = 1818
	                }
	                ce(17, 2, c[h >> 2] | 0, 0, c[g >> 2] | 0);
	                i = e;
	                return
	            }

	            function wS(a, b, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                j = i;
	                i = i + 32 | 0;
	                k = j + 24 | 0;
	                l = j + 20 | 0;
	                m = j + 16 | 0;
	                n = j + 12 | 0;
	                o = j + 8 | 0;
	                p = j + 4 | 0;
	                q = j;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                c[o >> 2] = g;
	                c[q >> 2] = 0;
	                c[c[(c[k >> 2] | 0) + 24 >> 2] >> 2] = c[m >> 2];
	                c[(c[(c[k >> 2] | 0) + 24 >> 2] | 0) + 4 >> 2] = c[n >> 2];
	                c[p >> 2] = Ps(c[(c[l >> 2] | 0) + 16 >> 2] | 0, c[(c[k >> 2] | 0) + 24 >> 2] | 0) | 0;
	                if (!(c[p >> 2] | 0))c[q >> 2] = 1; else {
	                    a:do switch (c[c[p >> 2] >> 2] | 0) {
	                        case 4:
	                        {
	                            if ((c[(c[p >> 2] | 0) + 24 >> 2] | 0) != 0 ? (d[c[(c[p >> 2] | 0) + 24 >> 2] >> 0] | 0 | 0) != 0 : 0)break a;
	                            c[q >> 2] = 1;
	                            break
	                        }
	                        case 3:
	                        {
	                            if ((Lq(+h[(c[p >> 2] | 0) + 16 >> 3]) | 0) == 0 ? !(+h[(c[p >> 2] | 0) + 16 >> 3] == 0.0) : 0)break a;
	                            c[q >> 2] = 1;
	                            break
	                        }
	                        case 8:
	                        case 7:
	                        case 6:
	                        case 5:
	                        case 0:
	                        {
	                            c[q >> 2] = 1;
	                            break
	                        }
	                        case 2:
	                        {
	                            c[q >> 2] = ((c[(c[p >> 2] | 0) + 8 >> 2] | 0) != 0 ^ 1) & 1;
	                            break
	                        }
	                        case 1:
	                        case 9:
	                        {
	                            if ((c[(c[p >> 2] | 0) + 4 >> 2] | 0) != 0 ? (c[c[(c[p >> 2] | 0) + 4 >> 2] >> 2] | 0) != 0 : 0)break a;
	                            c[q >> 2] = 1;
	                            break
	                        }
	                        default:
	                        {
	                        }
	                    } while (0);
	                    Qq(c[p >> 2] | 0)
	                }
	                if ((c[q >> 2] | 0) != 0 ? (c[(c[l >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) {
	                    p = (c[k >> 2] | 0) + 12 | 0;
	                    c[p >> 2] = (c[p >> 2] | 0) + 1
	                } else r = 19;
	                if (((r | 0) == 19 ? (c[q >> 2] | 0) == 0 : 0) ? (c[(c[l >> 2] | 0) + 4 >> 2] | 0) == 2 : 0) {
	                    r = (c[k >> 2] | 0) + 12 | 0;
	                    c[r >> 2] = (c[r >> 2] | 0) + 1
	                }
	                CS(c[k >> 2] | 0, c[l >> 2] | 0, c[n >> 2] | 0, c[o >> 2] | 0, ((c[q >> 2] | 0) != 0 ^ 1) & 1);
	                i = j;
	                return ((c[q >> 2] | 0) != 0 ^ 1) & 1 | 0
	            }

	            function xS(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                if (((c[(c[e >> 2] | 0) + 12 >> 2] | 0) != 0 ? (c[(c[(c[e >> 2] | 0) + 12 >> 2] | 0) + 4 >> 2] | 0) != 17 : 0) ? (c[e >> 2] = c[(c[e >> 2] | 0) + 12 >> 2], (c[(c[e >> 2] | 0) + 4 >> 2] | 0) != 14) : 0) {
	                    c[d >> 2] = c[e >> 2];
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                }
	                while (1) {
	                    if (!(c[(c[e >> 2] | 0) + 24 >> 2] | 0))break;
	                    c[e >> 2] = c[(c[e >> 2] | 0) + 24 >> 2];
	                    if ((c[(c[e >> 2] | 0) + 4 >> 2] | 0) == 17)continue;
	                    if ((c[(c[e >> 2] | 0) + 4 >> 2] | 0) != 14) {
	                        g = 8;
	                        break
	                    }
	                }
	                if ((g | 0) == 8) {
	                    c[d >> 2] = c[e >> 2];
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                }
	                while (1) {
	                    c[e >> 2] = c[(c[e >> 2] | 0) + 20 >> 2];
	                    if (!(c[e >> 2] | 0)) {
	                        g = 15;
	                        break
	                    }
	                    if ((c[(c[e >> 2] | 0) + 4 >> 2] | 0) == 9) {
	                        g = 11;
	                        break
	                    }
	                    h = c[e >> 2] | 0;
	                    if (c[(c[e >> 2] | 0) + 24 >> 2] | 0) {
	                        g = 13;
	                        break
	                    }
	                    if (!h) {
	                        g = 15;
	                        break
	                    }
	                }
	                if ((g | 0) == 11) {
	                    c[d >> 2] = 0;
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                } else if ((g | 0) == 13) {
	                    c[e >> 2] = c[h + 24 >> 2];
	                    c[d >> 2] = c[e >> 2];
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                } else if ((g | 0) == 15) {
	                    c[d >> 2] = c[e >> 2];
	                    f = c[d >> 2] | 0;
	                    i = b;
	                    return f | 0
	                }
	                return 0
	            }

	            function yS(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 1024 | 0;
	                e = d;
	                f = d + 12 | 0;
	                g = d + 8 | 0;
	                h = d + 16 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    i = d;
	                    return
	                }
	                if (c[(c[f >> 2] | 0) + 4 >> 2] & 1) {
	                    i = d;
	                    return
	                }
	                if (c[(c[f >> 2] | 0) + 4 >> 2] & 8) {
	                    i = d;
	                    return
	                }
	                if (c[(c[f >> 2] | 0) + 4 >> 2] & 4) {
	                    b = c[33976] | 0;
	                    a = c[33980] | 0;
	                    c[e >> 2] = 202344;
	                    c[e + 4 >> 2] = 1457;
	                    Db[b & 511](a, 202312, e);
	                    i = d;
	                    return
	                }
	                if (!(c[(c[g >> 2] | 0) + 8 >> 2] | 0)) {
	                    i = d;
	                    return
	                }
	                c[e >> 2] = c[(c[g >> 2] | 0) + 8 >> 2];
	                JT(h, 999, 202368, e) | 0;
	                DS(c[f >> 2] | 0, 0, h);
	                i = d;
	                return
	            }

	            function zS(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[d >> 2] = a;
	                while (1) {
	                    if (!(c[d >> 2] | 0))break;
	                    c[e >> 2] = c[c[d >> 2] >> 2];
	                    if (c[(c[d >> 2] | 0) + 12 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 12 >> 2] | 0);
	                    if (c[(c[d >> 2] | 0) + 16 >> 2] | 0)Pq(c[(c[d >> 2] | 0) + 16 >> 2] | 0);
	                    if (c[(c[d >> 2] | 0) + 20 >> 2] | 0)zb[c[135736 >> 2] & 511](c[(c[d >> 2] | 0) + 20 >> 2] | 0);
	                    zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                    c[d >> 2] = c[e >> 2]
	                }
	                i = b;
	                return
	            }

	            function AS(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0;
	                f = i;
	                i = i + 32 | 0;
	                g = f + 24 | 0;
	                h = f + 20 | 0;
	                j = f + 16 | 0;
	                k = f + 12 | 0;
	                l = f + 8 | 0;
	                m = f + 4 | 0;
	                n = f;
	                c[h >> 2] = a;
	                c[j >> 2] = b;
	                c[k >> 2] = d;
	                c[l >> 2] = e;
	                if ((c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0) {
	                    c[g >> 2] = 0;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                c[m >> 2] = Cb[c[135744 >> 2] & 511](12) | 0;
	                if (!(c[m >> 2] | 0)) {
	                    qS(c[h >> 2] | 0, 202976, c[k >> 2] | 0);
	                    c[g >> 2] = 0;
	                    o = c[g >> 2] | 0;
	                    i = f;
	                    return o | 0
	                }
	                k = c[m >> 2] | 0;
	                c[k + 0 >> 2] = 0;
	                c[k + 4 >> 2] = 0;
	                c[k + 8 >> 2] = 0;
	                c[(c[m >> 2] | 0) + 8 >> 2] = c[l >> 2];
	                c[c[m >> 2] >> 2] = 0;
	                if (!(c[(c[j >> 2] | 0) + 36 >> 2] | 0))c[(c[j >> 2] | 0) + 36 >> 2] = c[m >> 2]; else {
	                    c[n >> 2] = c[(c[j >> 2] | 0) + 36 >> 2];
	                    while (1) {
	                        if (!(c[c[n >> 2] >> 2] | 0))break;
	                        c[n >> 2] = c[c[n >> 2] >> 2]
	                    }
	                    c[c[n >> 2] >> 2] = c[m >> 2]
	                }
	                c[g >> 2] = c[m >> 2];
	                o = c[g >> 2] | 0;
	                i = f;
	                return o | 0
	            }

	            function BS(a, b, e) {
	                a = a | 0;
	                b = b | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                f = i;
	                i = i + 48 | 0;
	                g = f + 36 | 0;
	                h = f + 32 | 0;
	                j = f + 28 | 0;
	                k = f + 24 | 0;
	                l = f + 20 | 0;
	                m = f + 16 | 0;
	                n = f + 12 | 0;
	                o = f + 8 | 0;
	                p = f + 4 | 0;
	                q = f;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = e;
	                c[l >> 2] = 0;
	                if ((c[g >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    i = f;
	                    return
	                }
	                c[n >> 2] = ej(c[j >> 2] | 0, 202576) | 0;
	                if (!(c[n >> 2] | 0)) {
	                    rS(c[g >> 2] | 0, c[j >> 2] | 0, 1759, 202584, 0, 0);
	                    i = f;
	                    return
	                }
	                e = c[g >> 2] | 0;
	                if (!(d[c[n >> 2] >> 0] | 0)) {
	                    rS(e, c[j >> 2] | 0, 1759, 202616, 0, 0);
	                    zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                    i = f;
	                    return
	                }
	                c[p >> 2] = ES(e, c[(c[g >> 2] | 0) + 40 >> 2] | 0, c[h >> 2] | 0, c[j >> 2] | 0, c[n >> 2] | 0, 0) | 0;
	                if (!(c[p >> 2] | 0)) {
	                    zb[c[135736 >> 2] & 511](c[n >> 2] | 0);
	                    i = f;
	                    return
	                }
	                c[k >> 2] = c[(c[j >> 2] | 0) + 12 >> 2];
	                while (1) {
	                    if (!(c[k >> 2] | 0))break;
	                    if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 1 ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) {
	                        if (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50504] | 0) | 0)break;
	                        if (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50506] | 0) | 0)break
	                    }
	                    c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                }
	                a:while (1) {
	                    if (!(c[k >> 2] | 0))break;
	                    do if ((((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 202656) | 0) != 0 : 0) {
	                        if ((qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50504] | 0) | 0) == 0 ? (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50506] | 0) | 0) == 0 : 0) {
	                            r = 28;
	                            break
	                        }
	                        c[l >> 2] = (c[l >> 2] | 0) + 1;
	                        c[m >> 2] = ej(c[k >> 2] | 0, 202664) | 0;
	                        if (!(c[m >> 2] | 0)) {
	                            rS(c[g >> 2] | 0, c[k >> 2] | 0, 1759, 202672, 0, 0);
	                            break
	                        }
	                        if (!(d[c[m >> 2] >> 0] | 0)) {
	                            rS(c[g >> 2] | 0, c[k >> 2] | 0, 1759, 202704, 0, 0);
	                            zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                            break
	                        }
	                        c[o >> 2] = _i(c[k >> 2] | 0) | 0;
	                        c[q >> 2] = FS(c[g >> 2] | 0, 1, c[p >> 2] | 0, c[k >> 2] | 0, c[m >> 2] | 0, c[o >> 2] | 0) | 0;
	                        if (!(c[q >> 2] | 0))zb[c[135736 >> 2] & 511](c[m >> 2] | 0)
	                    } else r = 28; while (0);
	                    b:do if ((r | 0) == 28) {
	                        r = 0;
	                        do if ((((c[k >> 2] | 0) != 0 ? (c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[k >> 2] | 0) + 8 >> 2] | 0, 202744) | 0) != 0 : 0) {
	                            if ((qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50504] | 0) | 0) == 0 ? (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50506] | 0) | 0) == 0 : 0)break;
	                            c[l >> 2] = (c[l >> 2] | 0) + 1;
	                            c[m >> 2] = ej(c[k >> 2] | 0, 202664) | 0;
	                            if (!(c[m >> 2] | 0)) {
	                                rS(c[g >> 2] | 0, c[k >> 2] | 0, 1759, 202672, 0, 0);
	                                break b
	                            }
	                            if (!(d[c[m >> 2] >> 0] | 0)) {
	                                rS(c[g >> 2] | 0, c[k >> 2] | 0, 1759, 202704, 0, 0);
	                                zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                                break b
	                            }
	                            c[o >> 2] = _i(c[k >> 2] | 0) | 0;
	                            c[q >> 2] = FS(c[g >> 2] | 0, 2, c[p >> 2] | 0, c[k >> 2] | 0, c[m >> 2] | 0, c[o >> 2] | 0) | 0;
	                            if (c[q >> 2] | 0)break b;
	                            zb[c[135736 >> 2] & 511](c[m >> 2] | 0);
	                            break b
	                        } while (0);
	                        rS(c[g >> 2] | 0, c[k >> 2] | 0, 1759, 202752, c[(c[k >> 2] | 0) + 8 >> 2] | 0, 0)
	                    } while (0);
	                    c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2];
	                    while (1) {
	                        if (!(c[k >> 2] | 0))continue a;
	                        if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 1 ? (c[(c[k >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) {
	                            if (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50504] | 0) | 0)continue a;
	                            if (qy(c[(c[(c[k >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50506] | 0) | 0)continue a
	                        }
	                        c[k >> 2] = c[(c[k >> 2] | 0) + 24 >> 2]
	                    }
	                }
	                if (c[l >> 2] | 0) {
	                    i = f;
	                    return
	                }
	                rS(c[g >> 2] | 0, c[j >> 2] | 0, 1759, 202808, 0, 0);
	                i = f;
	                return
	            }

	            function CS(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                g = i;
	                i = i + 1056 | 0;
	                h = g;
	                j = g + 52 | 0;
	                k = g + 48 | 0;
	                l = g + 44 | 0;
	                m = g + 40 | 0;
	                n = g + 36 | 0;
	                o = g + 32 | 0;
	                p = g + 56 | 0;
	                q = g + 28 | 0;
	                r = g + 24 | 0;
	                s = g + 20 | 0;
	                t = g + 16 | 0;
	                u = g + 12 | 0;
	                c[j >> 2] = a;
	                c[k >> 2] = b;
	                c[l >> 2] = d;
	                c[m >> 2] = e;
	                c[n >> 2] = f;
	                if ((c[j >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0 | (c[k >> 2] | 0) == 0) {
	                    i = g;
	                    return
	                }
	                if (((c[(c[j >> 2] | 0) + 4 >> 2] & 1 | 0) != 0 ? (c[(c[j >> 2] | 0) + 4 >> 2] & 4 | 0) == 0 : 0) ? (c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 2 : 0) {
	                    i = g;
	                    return
	                }
	                if (c[(c[j >> 2] | 0) + 4 >> 2] & 4) {
	                    f = c[33976] | 0;
	                    e = c[33980] | 0;
	                    c[h >> 2] = 202344;
	                    c[h + 4 >> 2] = 1380;
	                    Db[f & 511](e, 202312, h);
	                    i = g;
	                    return
	                }
	                c[r >> 2] = 0;
	                if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 2 & (((c[n >> 2] | 0) != 0 ^ 1) & 1)) {
	                    i = g;
	                    return
	                }
	                if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 1 & c[n >> 2]) {
	                    i = g;
	                    return
	                }
	                c[q >> 2] = Ni(c[l >> 2] | 0) | 0;
	                c[o >> 2] = Oi(c[l >> 2] | 0) | 0;
	                if (!(c[o >> 2] | 0))c[o >> 2] = c[(c[l >> 2] | 0) + 8 >> 2];
	                if (c[(c[k >> 2] | 0) + 8 >> 2] | 0)c[r >> 2] = GS(c[j >> 2] | 0, c[(c[k >> 2] | 0) + 8 >> 2] | 0, c[l >> 2] | 0) | 0;
	                do if (!(c[r >> 2] | 0))if ((c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 1) {
	                    c[r >> 2] = my(202392) | 0;
	                    break
	                } else {
	                    c[r >> 2] = my(202416) | 0;
	                    break
	                } while (0);
	                n = c[q >> 2] | 0;
	                e = c[r >> 2] | 0;
	                c[h >> 2] = c[o >> 2];
	                c[h + 4 >> 2] = n;
	                c[h + 8 >> 2] = e;
	                JT(p, 999, 202440, h) | 0;
	                if (c[(c[j >> 2] | 0) + 4 >> 2] & 8) {
	                    c[s >> 2] = 0;
	                    c[t >> 2] = 0;
	                    c[u >> 2] = 0;
	                    if (c[j >> 2] | 0) {
	                        e = c[j >> 2] | 0;
	                        if (c[(c[j >> 2] | 0) + 60 >> 2] | 0)c[s >> 2] = c[e + 60 >> 2]; else c[t >> 2] = c[e + 52 >> 2];
	                        c[u >> 2] = c[(c[j >> 2] | 0) + 48 >> 2]
	                    }
	                    e = c[s >> 2] | 0;
	                    s = c[t >> 2] | 0;
	                    t = c[u >> 2] | 0;
	                    u = c[l >> 2] | 0;
	                    n = (c[(c[k >> 2] | 0) + 4 >> 2] | 0) == 1 ? 4e3 : 4001;
	                    k = c[q >> 2] | 0;
	                    if (!(c[m >> 2] | 0))v = 0; else v = c[(c[m >> 2] | 0) + 8 >> 2] | 0;
	                    m = c[o >> 2] | 0;
	                    q = c[r >> 2] | 0;
	                    c[h >> 2] = p;
	                    Xd(e, s, t, 0, u, 28, n, 2, 0, k, v, m, q, 0, 0, 202384, h)
	                } else DS(c[j >> 2] | 0, c[l >> 2] | 0, p);
	                zb[c[135736 >> 2] & 511](c[r >> 2] | 0);
	                if (!(c[o >> 2] | 0)) {
	                    i = g;
	                    return
	                }
	                if ((c[o >> 2] | 0) == (c[(c[l >> 2] | 0) + 8 >> 2] | 0)) {
	                    i = g;
	                    return
	                }
	                zb[c[135736 >> 2] & 511](c[o >> 2] | 0);
	                i = g;
	                return
	            }

	            function DS(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e;
	                g = e + 4 | 0;
	                c[e + 12 >> 2] = a;
	                c[e + 8 >> 2] = b;
	                c[g >> 2] = d;
	                d = c[o >> 2] | 0;
	                c[f >> 2] = c[g >> 2];
	                Ka(d | 0, 202384, f | 0) | 0;
	                i = e;
	                return
	            }

	            function ES(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h + 40 | 0;
	                k = h + 36 | 0;
	                l = h + 32 | 0;
	                m = h + 28 | 0;
	                n = h + 24 | 0;
	                o = h + 20 | 0;
	                p = h + 16 | 0;
	                q = h + 12 | 0;
	                r = h + 8 | 0;
	                s = h + 4 | 0;
	                t = h;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                if ((c[k >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0 | (c[n >> 2] | 0) == 0 | (c[o >> 2] | 0) == 0) {
	                    c[j >> 2] = 0;
	                    u = c[j >> 2] | 0;
	                    i = h;
	                    return u | 0
	                }
	                c[r >> 2] = MQ(c[o >> 2] | 0, c[(c[k >> 2] | 0) + 24 >> 2] | 0, 1, c[(c[k >> 2] | 0) + 52 >> 2] | 0) | 0;
	                if (!(c[r >> 2] | 0))rS(c[k >> 2] | 0, c[n >> 2] | 0, 1759, 202912, c[o >> 2] | 0, 0);
	                c[q >> 2] = Cb[c[135744 >> 2] & 511](28) | 0;
	                if (!(c[q >> 2] | 0)) {
	                    qS(c[k >> 2] | 0, 202952, c[n >> 2] | 0);
	                    c[j >> 2] = 0;
	                    u = c[j >> 2] | 0;
	                    i = h;
	                    return u | 0
	                }
	                k = c[q >> 2] | 0;
	                c[k + 0 >> 2] = 0;
	                c[k + 4 >> 2] = 0;
	                c[k + 8 >> 2] = 0;
	                c[k + 12 >> 2] = 0;
	                c[k + 16 >> 2] = 0;
	                c[k + 20 >> 2] = 0;
	                c[k + 24 >> 2] = 0;
	                c[(c[q >> 2] | 0) + 8 >> 2] = c[n >> 2];
	                c[(c[q >> 2] | 0) + 12 >> 2] = c[o >> 2];
	                c[(c[q >> 2] | 0) + 20 >> 2] = c[r >> 2];
	                c[(c[q >> 2] | 0) + 24 >> 2] = c[p >> 2];
	                c[c[q >> 2] >> 2] = 0;
	                if (!(c[(c[l >> 2] | 0) + 40 >> 2] | 0))c[(c[l >> 2] | 0) + 40 >> 2] = c[q >> 2]; else {
	                    c[s >> 2] = c[(c[l >> 2] | 0) + 40 >> 2];
	                    while (1) {
	                        if (!(c[c[s >> 2] >> 2] | 0))break;
	                        c[s >> 2] = c[c[s >> 2] >> 2]
	                    }
	                    c[c[s >> 2] >> 2] = c[q >> 2]
	                }
	                c[(c[q >> 2] | 0) + 4 >> 2] = 0;
	                if (!(c[(c[m >> 2] | 0) + 4 >> 2] | 0))c[(c[m >> 2] | 0) + 4 >> 2] = c[q >> 2]; else {
	                    c[t >> 2] = c[(c[m >> 2] | 0) + 4 >> 2];
	                    while (1) {
	                        if (!(c[(c[t >> 2] | 0) + 4 >> 2] | 0))break;
	                        c[t >> 2] = c[(c[t >> 2] | 0) + 4 >> 2]
	                    }
	                    c[(c[t >> 2] | 0) + 4 >> 2] = c[q >> 2]
	                }
	                c[j >> 2] = c[q >> 2];
	                u = c[j >> 2] | 0;
	                i = h;
	                return u | 0
	            }

	            function FS(a, b, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                var h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                h = i;
	                i = i + 48 | 0;
	                j = h + 36 | 0;
	                k = h + 32 | 0;
	                l = h + 28 | 0;
	                m = h + 24 | 0;
	                n = h + 20 | 0;
	                o = h + 16 | 0;
	                p = h + 12 | 0;
	                q = h + 8 | 0;
	                r = h + 4 | 0;
	                s = h;
	                c[k >> 2] = a;
	                c[l >> 2] = b;
	                c[m >> 2] = d;
	                c[n >> 2] = e;
	                c[o >> 2] = f;
	                c[p >> 2] = g;
	                if ((c[k >> 2] | 0) == 0 | (c[m >> 2] | 0) == 0 | (c[n >> 2] | 0) == 0 | (c[o >> 2] | 0) == 0) {
	                    c[j >> 2] = 0;
	                    t = c[j >> 2] | 0;
	                    i = h;
	                    return t | 0
	                }
	                c[r >> 2] = Os(c[(c[k >> 2] | 0) + 36 >> 2] | 0, c[o >> 2] | 0) | 0;
	                if (!(c[r >> 2] | 0)) {
	                    rS(c[k >> 2] | 0, c[n >> 2] | 0, 1759, 202848, c[o >> 2] | 0, 0);
	                    c[j >> 2] = 0;
	                    t = c[j >> 2] | 0;
	                    i = h;
	                    return t | 0
	                }
	                c[q >> 2] = Cb[c[135744 >> 2] & 511](24) | 0;
	                if (!(c[q >> 2] | 0)) {
	                    qS(c[k >> 2] | 0, 202888, c[n >> 2] | 0);
	                    c[j >> 2] = 0;
	                    t = c[j >> 2] | 0;
	                    i = h;
	                    return t | 0
	                }
	                k = c[q >> 2] | 0;
	                c[k + 0 >> 2] = 0;
	                c[k + 4 >> 2] = 0;
	                c[k + 8 >> 2] = 0;
	                c[k + 12 >> 2] = 0;
	                c[k + 16 >> 2] = 0;
	                c[k + 20 >> 2] = 0;
	                c[(c[q >> 2] | 0) + 4 >> 2] = c[l >> 2];
	                c[(c[q >> 2] | 0) + 8 >> 2] = c[n >> 2];
	                c[(c[q >> 2] | 0) + 12 >> 2] = c[o >> 2];
	                c[(c[q >> 2] | 0) + 16 >> 2] = c[r >> 2];
	                c[(c[q >> 2] | 0) + 20 >> 2] = c[p >> 2];
	                c[c[q >> 2] >> 2] = 0;
	                if (!(c[(c[m >> 2] | 0) + 16 >> 2] | 0))c[(c[m >> 2] | 0) + 16 >> 2] = c[q >> 2]; else {
	                    c[s >> 2] = c[(c[m >> 2] | 0) + 16 >> 2];
	                    while (1) {
	                        if (!(c[c[s >> 2] >> 2] | 0))break;
	                        c[s >> 2] = c[c[s >> 2] >> 2]
	                    }
	                    c[c[s >> 2] >> 2] = c[q >> 2]
	                }
	                c[j >> 2] = c[q >> 2];
	                t = c[j >> 2] | 0;
	                i = h;
	                return t | 0
	            }

	            function GS(b, e, f) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0;
	                g = i;
	                i = i + 48 | 0;
	                h = g + 32 | 0;
	                j = g + 28 | 0;
	                k = g + 24 | 0;
	                l = g + 20 | 0;
	                m = g + 16 | 0;
	                n = g + 12 | 0;
	                o = g + 8 | 0;
	                p = g + 4 | 0;
	                q = g;
	                r = g + 36 | 0;
	                c[j >> 2] = b;
	                c[k >> 2] = e;
	                c[l >> 2] = f;
	                c[m >> 2] = 0;
	                if ((c[k >> 2] | 0) == 0 | (c[l >> 2] | 0) == 0) {
	                    c[h >> 2] = c[m >> 2];
	                    s = c[h >> 2] | 0;
	                    i = g;
	                    return s | 0
	                }
	                c[n >> 2] = c[(c[k >> 2] | 0) + 12 >> 2];
	                a:while (1) {
	                    if (!(c[n >> 2] | 0))break;
	                    b:do if ((c[(c[n >> 2] | 0) + 4 >> 2] | 0) != 3 ? (c[(c[n >> 2] | 0) + 4 >> 2] | 0) != 4 : 0) {
	                        do if ((((c[n >> 2] | 0) != 0 ? (c[(c[n >> 2] | 0) + 4 >> 2] | 0) == 1 : 0) ? (c[(c[n >> 2] | 0) + 36 >> 2] | 0) != 0 : 0) ? (qy(c[(c[n >> 2] | 0) + 8 >> 2] | 0, 202464) | 0) != 0 : 0) {
	                            if ((qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50504] | 0) | 0) == 0 ? (qy(c[(c[(c[n >> 2] | 0) + 36 >> 2] | 0) + 8 >> 2] | 0, c[50506] | 0) | 0) == 0 : 0)break;
	                            c[p >> 2] = ej(c[n >> 2] | 0, 202472) | 0;
	                            c[o >> 2] = c[l >> 2];
	                            if (c[p >> 2] | 0) {
	                                c[o >> 2] = HS(c[j >> 2] | 0, c[l >> 2] | 0, c[p >> 2] | 0) | 0;
	                                if (!(c[o >> 2] | 0))c[o >> 2] = c[l >> 2];
	                                zb[c[135736 >> 2] & 511](c[p >> 2] | 0)
	                            }
	                            if ((c[(c[o >> 2] | 0) + 36 >> 2] | 0) != 0 ? (c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) != 0 : 0) {
	                                c[m >> 2] = By(c[m >> 2] | 0, c[(c[(c[o >> 2] | 0) + 36 >> 2] | 0) + 12 >> 2] | 0) | 0;
	                                c[m >> 2] = By(c[m >> 2] | 0, 202480) | 0;
	                                c[m >> 2] = By(c[m >> 2] | 0, c[(c[o >> 2] | 0) + 8 >> 2] | 0) | 0;
	                                break b
	                            }
	                            c[m >> 2] = By(c[m >> 2] | 0, c[(c[o >> 2] | 0) + 8 >> 2] | 0) | 0;
	                            break b
	                        } while (0);
	                        c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2];
	                        continue a
	                    } else t = 7; while (0);
	                    if ((t | 0) == 7) {
	                        t = 0;
	                        c[m >> 2] = By(c[m >> 2] | 0, c[(c[n >> 2] | 0) + 40 >> 2] | 0) | 0
	                    }
	                    do if ((c[m >> 2] | 0) != 0 ? (c[q >> 2] = xy(c[m >> 2] | 0) | 0, (c[q >> 2] | 0) > 0) : 0) {
	                        a[r >> 0] = a[(c[m >> 2] | 0) + ((c[q >> 2] | 0) - 1) >> 0] | 0;
	                        if ((((d[r >> 0] | 0 | 0) != 32 ? (d[r >> 0] | 0 | 0) != 10 : 0) ? (d[r >> 0] | 0 | 0) != 13 : 0) ? (d[r >> 0] | 0 | 0) != 9 : 0)break;
	                        while (1) {
	                            if ((((d[r >> 0] | 0 | 0) != 32 ? (d[r >> 0] | 0 | 0) != 10 : 0) ? (d[r >> 0] | 0 | 0) != 13 : 0) ? (d[r >> 0] | 0 | 0) != 9 : 0)break;
	                            c[q >> 2] = (c[q >> 2] | 0) + -1;
	                            if (!(c[q >> 2] | 0))break;
	                            a[r >> 0] = a[(c[m >> 2] | 0) + ((c[q >> 2] | 0) - 1) >> 0] | 0
	                        }
	                        a[(c[m >> 2] | 0) + (c[q >> 2] | 0) >> 0] = 32;
	                        a[(c[m >> 2] | 0) + ((c[q >> 2] | 0) + 1) >> 0] = 0
	                    } while (0);
	                    c[n >> 2] = c[(c[n >> 2] | 0) + 24 >> 2]
	                }
	                c[h >> 2] = c[m >> 2];
	                s = c[h >> 2] | 0;
	                i = g;
	                return s | 0
	            }

	            function HS(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                e = i;
	                i = i + 32 | 0;
	                f = e + 20 | 0;
	                g = e + 16 | 0;
	                h = e + 12 | 0;
	                j = e + 8 | 0;
	                k = e + 4 | 0;
	                l = e;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                c[j >> 2] = d;
	                c[k >> 2] = 0;
	                if ((c[g >> 2] | 0) == 0 | (c[h >> 2] | 0) == 0 | (c[j >> 2] | 0) == 0) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                c[c[(c[g >> 2] | 0) + 24 >> 2] >> 2] = c[(c[h >> 2] | 0) + 32 >> 2];
	                c[(c[(c[g >> 2] | 0) + 24 >> 2] | 0) + 4 >> 2] = c[h >> 2];
	                c[l >> 2] = Rs(c[j >> 2] | 0, c[(c[g >> 2] | 0) + 24 >> 2] | 0) | 0;
	                if (!(c[l >> 2] | 0)) {
	                    c[f >> 2] = 0;
	                    m = c[f >> 2] | 0;
	                    i = e;
	                    return m | 0
	                }
	                if (((c[c[l >> 2] >> 2] | 0) == 1 ? (c[(c[l >> 2] | 0) + 4 >> 2] | 0) != 0 : 0) ? (c[c[(c[l >> 2] | 0) + 4 >> 2] >> 2] | 0) > 0 : 0)c[k >> 2] = c[c[(c[(c[l >> 2] | 0) + 4 >> 2] | 0) + 8 >> 2] >> 2];
	                Qq(c[l >> 2] | 0);
	                c[f >> 2] = c[k >> 2];
	                m = c[f >> 2] | 0;
	                i = e;
	                return m | 0
	            }

	            function IS(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                c[g >> 2] = a;
	                c[h >> 2] = b;
	                b = Cb[c[135744 >> 2] & 511](12) | 0;
	                c[j >> 2] = b;
	                if (!b) {
	                    Db[c[135904 >> 2] & 511](c[33980] | 0, 203144, e);
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                b = c[j >> 2] | 0;
	                c[b + 0 >> 2] = 0;
	                c[b + 4 >> 2] = 0;
	                c[b + 8 >> 2] = 0;
	                b = Cb[c[135744 >> 2] & 511](12) | 0;
	                c[c[j >> 2] >> 2] = b;
	                if (!b) {
	                    Db[c[135904 >> 2] & 511](c[33980] | 0, 203184, e);
	                    zb[c[135736 >> 2] & 511](c[j >> 2] | 0);
	                    c[f >> 2] = 0;
	                    k = c[f >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                c[c[c[j >> 2] >> 2] >> 2] = c[c[j >> 2] >> 2];
	                c[(c[c[j >> 2] >> 2] | 0) + 4 >> 2] = c[c[j >> 2] >> 2];
	                c[(c[c[j >> 2] >> 2] | 0) + 8 >> 2] = 0;
	                if (c[g >> 2] | 0)c[(c[j >> 2] | 0) + 4 >> 2] = c[g >> 2];
	                if (c[h >> 2] | 0)c[(c[j >> 2] | 0) + 8 >> 2] = c[h >> 2]; else c[(c[j >> 2] | 0) + 8 >> 2] = 390;
	                c[f >> 2] = c[j >> 2];
	                k = c[f >> 2] | 0;
	                i = d;
	                return k | 0
	            }

	            function JS(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                do if (c[f >> 2] | 0) {
	                    c[h >> 2] = RS(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                    if (c[h >> 2] | 0) {
	                        c[e >> 2] = c[(c[h >> 2] | 0) + 8 >> 2];
	                        break
	                    } else {
	                        c[e >> 2] = 0;
	                        break
	                    }
	                } else c[e >> 2] = 0; while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function KS(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 1;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                c[h >> 2] = SS(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                c[j >> 2] = Cb[c[135744 >> 2] & 511](12) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    Db[c[135904 >> 2] & 511](c[33980] | 0, 203224, d);
	                    c[e >> 2] = 1;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                } else {
	                    c[(c[j >> 2] | 0) + 8 >> 2] = c[g >> 2];
	                    c[h >> 2] = c[(c[h >> 2] | 0) + 4 >> 2];
	                    c[c[j >> 2] >> 2] = c[c[h >> 2] >> 2];
	                    c[(c[c[h >> 2] >> 2] | 0) + 4 >> 2] = c[j >> 2];
	                    c[c[h >> 2] >> 2] = c[j >> 2];
	                    c[(c[j >> 2] | 0) + 4 >> 2] = c[h >> 2];
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                return 0
	            }

	            function LS(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                d = i;
	                i = i + 32 | 0;
	                e = d + 20 | 0;
	                f = d + 16 | 0;
	                g = d + 12 | 0;
	                h = d + 8 | 0;
	                j = d + 4 | 0;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 1;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                c[h >> 2] = TS(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                c[j >> 2] = Cb[c[135744 >> 2] & 511](12) | 0;
	                if (!(c[j >> 2] | 0)) {
	                    Db[c[135904 >> 2] & 511](c[33980] | 0, 203224, d);
	                    c[e >> 2] = 1;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                } else {
	                    c[(c[j >> 2] | 0) + 8 >> 2] = c[g >> 2];
	                    c[c[j >> 2] >> 2] = c[c[h >> 2] >> 2];
	                    c[(c[c[h >> 2] >> 2] | 0) + 4 >> 2] = c[j >> 2];
	                    c[c[h >> 2] >> 2] = c[j >> 2];
	                    c[(c[j >> 2] | 0) + 4 >> 2] = c[h >> 2];
	                    c[e >> 2] = 0;
	                    k = c[e >> 2] | 0;
	                    i = d;
	                    return k | 0
	                }
	                return 0
	            }

	            function MS(a) {
	                a = a | 0;
	                var b = 0, d = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                NS(c[d >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[c[d >> 2] >> 2] | 0);
	                zb[c[135736 >> 2] & 511](c[d >> 2] | 0);
	                i = b;
	                return
	            }

	            function NS(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 8 | 0;
	                e = b + 4 | 0;
	                f = b;
	                c[d >> 2] = a;
	                if (!(c[d >> 2] | 0)) {
	                    i = b;
	                    return
	                }
	                c[e >> 2] = c[c[c[d >> 2] >> 2] >> 2];
	                while (1) {
	                    if ((c[e >> 2] | 0) == (c[c[d >> 2] >> 2] | 0))break;
	                    c[f >> 2] = c[c[e >> 2] >> 2];
	                    US(c[d >> 2] | 0, c[e >> 2] | 0);
	                    c[e >> 2] = c[f >> 2]
	                }
	                i = b;
	                return
	            }

	            function OS(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0;
	                b = i;
	                i = i + 16 | 0;
	                d = b + 4 | 0;
	                e = b;
	                c[e >> 2] = a;
	                if (!(c[e >> 2] | 0))c[d >> 2] = 0; else c[d >> 2] = c[(c[e >> 2] | 0) + 8 >> 2];
	                i = b;
	                return c[d >> 2] | 0
	            }

	            function PS(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e + 12 | 0;
	                g = e + 8 | 0;
	                h = e + 4 | 0;
	                j = e;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                c[h >> 2] = d;
	                if ((c[f >> 2] | 0) == 0 | (c[g >> 2] | 0) == 0) {
	                    i = e;
	                    return
	                }
	                c[j >> 2] = c[c[c[f >> 2] >> 2] >> 2];
	                while (1) {
	                    if ((c[j >> 2] | 0) == (c[c[f >> 2] >> 2] | 0)) {
	                        k = 6;
	                        break
	                    }
	                    if (!(Hb[c[g >> 2] & 511](c[(c[j >> 2] | 0) + 8 >> 2] | 0, c[h >> 2] | 0) | 0)) {
	                        k = 6;
	                        break
	                    }
	                    c[j >> 2] = c[c[j >> 2] >> 2]
	                }
	                if ((k | 0) == 6) {
	                    i = e;
	                    return
	                }
	            }

	            function QS(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 8 | 0;
	                f = d + 4 | 0;
	                g = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                do if ((c[f >> 2] | 0) >>> 0 >= (c[g >> 2] | 0) >>> 0)if ((c[f >> 2] | 0) == (c[g >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    break
	                } else {
	                    c[e >> 2] = 1;
	                    break
	                } else c[e >> 2] = -1; while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function RS(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                do if (c[f >> 2] | 0) {
	                    c[h >> 2] = SS(c[f >> 2] | 0, c[g >> 2] | 0) | 0;
	                    if ((c[h >> 2] | 0) == (c[c[f >> 2] >> 2] | 0)) {
	                        c[e >> 2] = 0;
	                        break
	                    }
	                    if (!(Hb[c[(c[f >> 2] | 0) + 8 >> 2] & 511](c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[g >> 2] | 0) | 0)) {
	                        c[e >> 2] = c[h >> 2];
	                        break
	                    } else {
	                        c[e >> 2] = 0;
	                        break
	                    }
	                } else c[e >> 2] = 0; while (0);
	                i = d;
	                return c[e >> 2] | 0
	            }

	            function SS(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[h >> 2] = c[c[c[f >> 2] >> 2] >> 2];
	                while (1) {
	                    if ((c[h >> 2] | 0) == (c[c[f >> 2] >> 2] | 0))break;
	                    if ((Hb[c[(c[f >> 2] | 0) + 8 >> 2] & 511](c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[g >> 2] | 0) | 0) >= 0)break;
	                    c[h >> 2] = c[c[h >> 2] >> 2]
	                }
	                c[e >> 2] = c[h >> 2];
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function TS(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 12 | 0;
	                f = d + 8 | 0;
	                g = d + 4 | 0;
	                h = d;
	                c[f >> 2] = a;
	                c[g >> 2] = b;
	                if (!(c[f >> 2] | 0)) {
	                    c[e >> 2] = 0;
	                    j = c[e >> 2] | 0;
	                    i = d;
	                    return j | 0
	                }
	                c[h >> 2] = c[(c[c[f >> 2] >> 2] | 0) + 4 >> 2];
	                while (1) {
	                    if ((c[h >> 2] | 0) == (c[c[f >> 2] >> 2] | 0))break;
	                    if ((Hb[c[(c[f >> 2] | 0) + 8 >> 2] & 511](c[(c[h >> 2] | 0) + 8 >> 2] | 0, c[g >> 2] | 0) | 0) <= 0)break;
	                    c[h >> 2] = c[(c[h >> 2] | 0) + 4 >> 2]
	                }
	                c[e >> 2] = c[h >> 2];
	                j = c[e >> 2] | 0;
	                i = d;
	                return j | 0
	            }

	            function US(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                i = i + 16 | 0;
	                e = d + 4 | 0;
	                f = d;
	                c[e >> 2] = a;
	                c[f >> 2] = b;
	                c[c[(c[f >> 2] | 0) + 4 >> 2] >> 2] = c[c[f >> 2] >> 2];
	                c[(c[c[f >> 2] >> 2] | 0) + 4 >> 2] = c[(c[f >> 2] | 0) + 4 >> 2];
	                if (!(c[(c[e >> 2] | 0) + 4 >> 2] | 0)) {
	                    g = c[33934] | 0;
	                    h = c[f >> 2] | 0;
	                    zb[g & 511](h);
	                    i = d;
	                    return
	                }
	                zb[c[(c[e >> 2] | 0) + 4 >> 2] & 511](c[f >> 2] | 0);
	                g = c[33934] | 0;
	                h = c[f >> 2] | 0;
	                zb[g & 511](h);
	                i = d;
	                return
	            }

	            function VS(a) {
	                a = a | 0;
	                return (a + -97 | 0) >>> 0 < 26 | 0
	            }

	            function WS(a) {
	                a = a | 0;
	                var b = 0, c = 0;
	                b = i;
	                c = (VS(a) | 0) == 0;
	                i = b;
	                return (c ? a : a & 95) | 0
	            }

	            function XS(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0;
	                e = i;
	                f = gT(a) | 0;
	                if (((f | 0) != -1 ? (a = gT(b) | 0, (a | 0) != -1) : 0) ? (d[203264 + f >> 0] | 0) <= 207 : 0) {
	                    g = a << 16 | f;
	                    i = e;
	                    return g | 0
	                }
	                c[(_a() | 0) >> 2] = 22;
	                g = -1;
	                i = e;
	                return g | 0
	            }

	            function YS(a) {
	                a = a | 0;
	                return 0
	            }

	            function ZS(f, g, h, j, k) {
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                j = j | 0;
	                k = k | 0;
	                var l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0, J = 0, K = 0, L = 0, M = 0, N = 0, O = 0, P = 0, Q = 0, R = 0, S = 0, T = 0, U = 0, V = 0, W = 0, X = 0, Y = 0, Z = 0, _ = 0, $ = 0, aa = 0, ba = 0, ca = 0, da = 0, ea = 0, fa = 0, ga = 0, ha = 0, ia = 0, ja = 0, ka = 0, la = 0, ma = 0, na = 0, oa = 0, pa = 0, qa = 0, ra = 0, sa = 0, ta = 0, ua = 0, va = 0, wa = 0, xa = 0, ya = 0, za = 0, Aa = 0, Ba = 0, Ca = 0, Da = 0, Ea = 0, Fa = 0, Ga = 0, Ha = 0, Ia = 0;
	                l = i;
	                i = i + 32 | 0;
	                m = l;
	                n = l + 16 | 0;
	                o = l + 12 | 0;
	                p = l + 8 | 0;
	                q = l + 20 | 0;
	                r = f;
	                f = r & 65535;
	                s = r >>> 16;
	                r = s + 1 | 0;
	                t = f + 1 | 0;
	                u = m;
	                c[u >> 2] = 0;
	                c[u + 4 >> 2] = 0;
	                u = a[203264 + s >> 0] | 0;
	                v = a[203264 + f >> 0] | 0;
	                if (!g) {
	                    w = 0;
	                    i = l;
	                    return w | 0
	                }
	                x = c[g >> 2] | 0;
	                if (!x) {
	                    w = 0;
	                    i = l;
	                    return w | 0
	                }
	                y = c[h >> 2] | 0;
	                if (!y) {
	                    w = 0;
	                    i = l;
	                    return w | 0
	                }
	                z = u & 255;
	                A = z + 128 | 0;
	                B = s + 2 | 0;
	                s = z & 3;
	                C = s ^ 1;
	                D = s ^ 2;
	                E = s ^ 3;
	                F = z & 1;
	                G = F ^ 1;
	                H = (z & 254 | 0) == 196;
	                I = F | 2;
	                J = G | 2;
	                K = u << 24 >> 24 == -38;
	                L = u << 24 >> 24 == -40;
	                M = v & 255;
	                N = M + -192 | 0;
	                O = N >>> 0 > 8;
	                P = f;
	                Q = 281312 + N | 0;
	                N = M + 128 | 0;
	                R = 128 - M | 0;
	                S = v << 24 >> 24 == -128;
	                v = f + 2 | 0;
	                f = (u & -2) << 24 >> 24 == -60;
	                u = M & 1;
	                T = u ^ 1;
	                U = u | 2;
	                V = T | 2;
	                W = M & 3;
	                X = W ^ 1;
	                Y = W ^ 2;
	                Z = W ^ 3;
	                _ = (z + -192 | 0) >>> 0 < 7;
	                $ = x;
	                x = y;
	                y = 0;
	                a:while (1) {
	                    aa = a[$ >> 0] | 0;
	                    ba = aa & 255;
	                    b:do if (aa << 24 >> 24 < 0 | _) {
	                        do switch (z | 0) {
	                            case 208:
	                            {
	                                if (x >>> 0 < 2) {
	                                    ca = 22;
	                                    break a
	                                }
	                                da = d[$ + 1 >> 0] | 0;
	                                if (aa << 24 >> 24 != -114) {
	                                    ea = ba + -161 | 0;
	                                    fa = da + -161 | 0;
	                                    if (ea >>> 0 > 83 | fa >>> 0 > 93) {
	                                        ga = 84;
	                                        ha = 114;
	                                        break a
	                                    }
	                                    ia = b[207296 + (ea * 188 | 0) + (fa << 1) >> 1] | 0;
	                                    if (!(ia << 16 >> 16)) {
	                                        ga = 84;
	                                        ha = 114;
	                                        break a
	                                    } else {
	                                        ja = ia & 65535;
	                                        ka = 2;
	                                        ha = 89;
	                                        break b
	                                    }
	                                } else {
	                                    if ((da + -161 | 0) >>> 0 > 62) {
	                                        ga = 84;
	                                        ha = 114;
	                                        break a
	                                    }
	                                    ja = da + 65216 | 0;
	                                    ka = 2;
	                                    ha = 89;
	                                    break b
	                                }
	                                break
	                            }
	                            case 198:
	                            {
	                                if (x >>> 0 < 4) {
	                                    ca = 22;
	                                    break a
	                                }
	                                la = c[$ >> 2] | 0;
	                                ha = 14;
	                                break
	                            }
	                            case 200:
	                            {
	                                da = _S(n, $, x, m) | 0;
	                                if (!da)ma = 1; else if ((da | 0) == -1) {
	                                    ga = 84;
	                                    ha = 114;
	                                    break a
	                                } else if ((da | 0) == -2) {
	                                    ca = 22;
	                                    break a
	                                } else ma = da;
	                                ja = c[n >> 2] | 0;
	                                ka = ma;
	                                ha = 89;
	                                break b;
	                                break
	                            }
	                            case 224:
	                            {
	                                if (x >>> 0 < 2) {
	                                    ca = 22;
	                                    break a
	                                }
	                                da = d[$ + 1 >> 0] | 0;
	                                ia = da + -64 | 0;
	                                if (ia >>> 0 > 190 | (da + -127 | 0) >>> 0 < 34) {
	                                    ga = 84;
	                                    ha = 114;
	                                    break a
	                                }
	                                fa = ia >>> 0 > 62 ? da + -98 | 0 : ia;
	                                ia = ba + -161 | 0;
	                                if (ia >>> 0 <= 88) {
	                                    da = e[281352 + (ia * 314 | 0) + (fa << 1) >> 1] | 0;
	                                    if ((ia | 0) == 39 ? (fa | 0) == 66 | (fa | 0) == 58 | (fa | 0) == 60 : 0)na = 131072; else na = 0;
	                                    ia = na | da;
	                                    if (!ia) {
	                                        ga = 84;
	                                        ha = 114;
	                                        break a
	                                    } else {
	                                        ja = ia;
	                                        ka = 2;
	                                        ha = 89;
	                                        break b
	                                    }
	                                }
	                                ia = ba + -135 | 0;
	                                if (ia >>> 0 > 119) {
	                                    ga = 84;
	                                    ha = 114;
	                                    break a
	                                }
	                                da = fa + (((aa & 255) < 161 ? ia : ba + -224 | 0) * 157 | 0) | 0;
	                                ia = e[270968 + (da << 1) >> 1] | 0;
	                                fa = ia | (((e[270968 + ((da >>> 4) + 4867 << 1) >> 1] | 0) >>> (da & 15) | 0) % 2 | 0) << 17;
	                                if ((fa & -65792 | 0) != 56320)if (!fa) {
	                                    ga = 84;
	                                    ha = 114;
	                                    break a
	                                } else {
	                                    ja = fa;
	                                    ka = 2;
	                                    ha = 89;
	                                    break b
	                                }
	                                if (O)oa = 2; else oa = a[Q >> 0] | 0;
	                                if (oa >>> 0 > (c[k >> 2] | 0) >>> 0) {
	                                    ga = 7;
	                                    ha = 114;
	                                    break a
	                                }
	                                c[o >> 2] = 281328 + (ia & 255);
	                                c[p >> 2] = 4;
	                                pa = 2;
	                                qa = (ZS(P, o, p, j, k) | 0) + y | 0;
	                                break b;
	                                break
	                            }
	                            case 218:
	                            {
	                                if ((aa & 255) < 161) {
	                                    ga = 84;
	                                    ha = 114;
	                                    break a
	                                }
	                                break
	                            }
	                            case 216:
	                            case 217:
	                                break;
	                            case 193:
	                            case 194:
	                            case 197:
	                            case 196:
	                            {
	                                if (x >>> 0 < 2) {
	                                    ca = 22;
	                                    break a
	                                }
	                                ia = d[$ + F >> 0] << 8;
	                                fa = ia | d[$ + G >> 0];
	                                da = ia & 64512;
	                                if ((da | 0) == 56320) {
	                                    ga = 84;
	                                    ha = 114;
	                                    break a
	                                } else if ((da | 0) != 55296) {
	                                    ja = fa;
	                                    ka = 2;
	                                    ha = 89;
	                                    break b
	                                }
	                                if (H) {
	                                    ga = 84;
	                                    ha = 114;
	                                    break a
	                                }
	                                if (x >>> 0 < 4) {
	                                    ca = 22;
	                                    break a
	                                }
	                                da = (d[$ + I >> 0] << 8 | d[$ + J >> 0]) + -56320 | 0;
	                                if (da >>> 0 > 1023) {
	                                    ga = 84;
	                                    ha = 114;
	                                    break a
	                                }
	                                ja = (fa << 10) + -56557568 + da | 0;
	                                ka = 4;
	                                ha = 89;
	                                break b;
	                                break
	                            }
	                            case 195:
	                            case 192:
	                            {
	                                if (x >>> 0 < 4) {
	                                    ca = 22;
	                                    break a
	                                }
	                                la = d[$ + C >> 0] << 16 | d[$ + s >> 0] << 24 | d[$ + D >> 0] << 8 | d[$ + E >> 0];
	                                ha = 14;
	                                break
	                            }
	                            case 232:
	                            {
	                                if (x >>> 0 < 2) {
	                                    ca = 22;
	                                    break a
	                                }
	                                da = a[$ + 1 >> 0] | 0;
	                                fa = da & 255;
	                                ia = ba + -161 | 0;
	                                ea = fa + -161 | 0;
	                                if (!(ia >>> 0 > 92 | ea >>> 0 > 93)) {
	                                    ra = b[309304 + (ia * 188 | 0) + (ea << 1) >> 1] | 0;
	                                    if (!(ra << 16 >> 16)) {
	                                        ga = 84;
	                                        ha = 114;
	                                        break a
	                                    } else {
	                                        ja = ra & 65535;
	                                        ka = 2;
	                                        ha = 89;
	                                        break b
	                                    }
	                                }
	                                ra = ba + -129 | 0;
	                                if (ra >>> 0 > 92) {
	                                    ga = 84;
	                                    ha = 114;
	                                    break a
	                                }
	                                if (ra >>> 0 > 68 & (da & 255) > 82) {
	                                    ga = 84;
	                                    ha = 114;
	                                    break a
	                                }
	                                da = fa + -65 | 0;
	                                do if (da >>> 0 < 26)sa = da; else {
	                                    if ((fa + -97 | 0) >>> 0 < 26) {
	                                        sa = fa + -71 | 0;
	                                        break
	                                    }
	                                    if ((fa + -129 | 0) >>> 0 >= 126) {
	                                        ga = 84;
	                                        ha = 114;
	                                        break a
	                                    }
	                                    sa = fa + -77 | 0
	                                } while (0);
	                                if (ra >>> 0 < 32)ta = ra * 178 | 0; else ta = (ia * 84 | 0) + 5696 | 0;
	                                fa = sa + 44032 + ta | 0;
	                                if (fa >>> 0 < 44032) {
	                                    ja = fa;
	                                    ka = 2;
	                                    ha = 89;
	                                    break b
	                                } else {
	                                    ua = fa;
	                                    va = 44032
	                                }
	                                while (1) {
	                                    fa = ua - va | 0;
	                                    da = 0;
	                                    ea = 0;
	                                    while (1) {
	                                        wa = 0;
	                                        xa = ea;
	                                        do {
	                                            xa = (((e[309304 + (da * 188 | 0) + (wa << 1) >> 1] | 0) - va | 0) >>> 0 <= fa >>> 0 & 1) + xa | 0;
	                                            wa = wa + 1 | 0
	                                        } while ((wa | 0) != 94);
	                                        da = da + 1 | 0;
	                                        if ((da | 0) == 93)break; else ea = xa
	                                    }
	                                    va = ua + 1 | 0;
	                                    ea = xa + ua | 0;
	                                    if (ea >>> 0 < va >>> 0) {
	                                        ja = ea;
	                                        ka = 2;
	                                        ha = 89;
	                                        break b
	                                    } else ua = ea
	                                }
	                                break
	                            }
	                            case 209:
	                            {
	                                if ((ba + -161 | 0) >>> 0 < 63) {
	                                    ja = ba + 65216 | 0;
	                                    ka = 1;
	                                    ha = 89;
	                                    break b
	                                }
	                                if (x >>> 0 < 2) {
	                                    ca = 22;
	                                    break a
	                                }
	                                ia = a[$ + 1 >> 0] | 0;
	                                ra = ia & 255;
	                                ea = ba + -129 | 0;
	                                if (ea >>> 0 < 31)ya = ea; else {
	                                    if ((ba & 240 | 0) != 224) {
	                                        ga = 84;
	                                        ha = 114;
	                                        break a
	                                    }
	                                    ya = ba + -193 | 0
	                                }
	                                ea = ya << 1;
	                                da = ra + -64 | 0;
	                                if (da >>> 0 < 95) {
	                                    if (ia << 24 >> 24 == 127) {
	                                        ga = 84;
	                                        ha = 114;
	                                        break a
	                                    }
	                                    za = ea;
	                                    Aa = da + (ia << 24 >> 24 >> 7 << 24 >> 24) | 0
	                                } else {
	                                    ia = ra + -159 | 0;
	                                    da = ia >>> 0 < 94;
	                                    za = ea | da & 1;
	                                    Aa = da ? ia : ra
	                                }
	                                ra = b[207296 + (za * 188 | 0) + (Aa << 1) >> 1] | 0;
	                                if (!(ra << 16 >> 16)) {
	                                    ga = 84;
	                                    ha = 114;
	                                    break a
	                                } else {
	                                    ja = ra & 65535;
	                                    ka = 2;
	                                    ha = 89;
	                                    break b
	                                }
	                                break
	                            }
	                            case 199:
	                            {
	                                ga = 84;
	                                ha = 114;
	                                break a;
	                                break
	                            }
	                            default:
	                            {
	                                if (ba >>> 0 < A >>> 0) {
	                                    ja = ba;
	                                    ka = 1;
	                                    ha = 89;
	                                    break b
	                                }
	                                ra = ba - A | 0;
	                                ia = (ra * 5 | 0) >>> 2;
	                                da = ra << 1 & 6;
	                                ra = d[203264 + (B + ia) >> 0] << 8 - da & 1023 | (d[203264 + (ia + r) >> 0] | 0) >>> da;
	                                da = (ra | 0) == 0 ? ba : e[326792 + (ra << 1) >> 1] | 0;
	                                if ((da | 0) == 1) {
	                                    ga = 84;
	                                    ha = 114;
	                                    break a
	                                } else {
	                                    ja = da;
	                                    ka = 1;
	                                    ha = 89;
	                                    break b
	                                }
	                            }
	                        } while (0);
	                        if ((ha | 0) == 14) {
	                            ha = 0;
	                            if ((la & -2048 | 0) == 55296 | la >>> 0 > 1114111) {
	                                ga = 84;
	                                ha = 114;
	                                break a
	                            } else {
	                                ja = la;
	                                ka = 4;
	                                ha = 89;
	                                break
	                            }
	                        }
	                        da = ba + -129 | 0;
	                        if (da >>> 0 > 125) {
	                            ga = 84;
	                            ha = 114;
	                            break a
	                        }
	                        if (x >>> 0 < 2) {
	                            ca = 22;
	                            break a
	                        }
	                        ra = a[$ + 1 >> 0] | 0;
	                        ia = ra & 255;
	                        if ((ra & 255) < 161 & K) {
	                            ga = 84;
	                            ha = 114;
	                            break a
	                        }
	                        ea = ia + -64 | 0;
	                        if (!(ea >>> 0 > 190 | ra << 24 >> 24 == 127)) {
	                            ja = e[223088 + (da * 380 | 0) + ((ea >>> 0 > 63 ? ia + -65 | 0 : ea) << 1) >> 1] | 0;
	                            ka = 2;
	                            ha = 89;
	                            break
	                        }
	                        if (!((ia + -48 | 0) >>> 0 < 10 & L)) {
	                            ga = 84;
	                            ha = 114;
	                            break a
	                        }
	                        if (x >>> 0 < 4) {
	                            ca = 22;
	                            break a
	                        }
	                        ea = (d[$ + 2 >> 0] | 0) + -129 | 0;
	                        if (ea >>> 0 > 126) {
	                            ga = 84;
	                            ha = 114;
	                            break a
	                        }
	                        ra = (d[$ + 3 >> 0] | 0) + -48 | 0;
	                        if (ra >>> 0 > 9) {
	                            ga = 84;
	                            ha = 114;
	                            break a
	                        }
	                        fa = ((ia + (da * 10 | 0) | 0) * 1260 | 0) + -60352 + (ea * 10 | 0) + ra | 0;
	                        ra = 0;
	                        while (1) {
	                            ea = fa - ra | 0;
	                            da = 0;
	                            ia = 0;
	                            while (1) {
	                                wa = 0;
	                                Ba = ia;
	                                do {
	                                    Ba = (((e[223088 + (da * 380 | 0) + (wa << 1) >> 1] | 0) - ra | 0) >>> 0 <= ea >>> 0 & 1) + Ba | 0;
	                                    wa = wa + 1 | 0
	                                } while ((wa | 0) != 190);
	                                da = da + 1 | 0;
	                                if ((da | 0) == 126)break; else ia = Ba
	                            }
	                            ra = fa + 1 | 0;
	                            ia = Ba + fa | 0;
	                            if (ia >>> 0 < ra >>> 0) {
	                                ja = ia;
	                                ka = 4;
	                                ha = 89;
	                                break
	                            } else fa = ia
	                        }
	                    } else {
	                        ja = ba;
	                        ka = 1;
	                        ha = 89
	                    } while (0);
	                    c:do if ((ha | 0) == 89) {
	                        ha = 0;
	                        switch (M | 0) {
	                            case 195:
	                            case 192:
	                            {
	                                if ((c[k >> 2] | 0) >>> 0 < 4) {
	                                    ga = 7;
	                                    ha = 114;
	                                    break a
	                                }
	                                ba = c[j >> 2] | 0;
	                                a[ba + W >> 0] = ja >>> 24;
	                                a[ba + X >> 0] = ja >>> 16;
	                                a[ba + Y >> 0] = ja >>> 8;
	                                a[ba + Z >> 0] = ja;
	                                c[j >> 2] = ba + 4;
	                                c[k >> 2] = (c[k >> 2] | 0) + -4;
	                                pa = ka;
	                                qa = y;
	                                break c;
	                                break
	                            }
	                            case 199:
	                            {
	                                if (ja >>> 0 > 127) {
	                                    Ca = y;
	                                    ha = 98
	                                } else {
	                                    Da = ja;
	                                    Ea = y
	                                }
	                                break
	                            }
	                            case 200:
	                            {
	                                if ((c[k >> 2] | 0) >>> 0 < 4) {
	                                    ba = CT(q, ja) | 0;
	                                    if ((c[k >> 2] | 0) >>> 0 < ba >>> 0) {
	                                        ga = 7;
	                                        ha = 114;
	                                        break a
	                                    }
	                                    aa = c[j >> 2] | 0;
	                                    eU(aa | 0, q | 0, ba | 0) | 0;
	                                    Fa = aa;
	                                    Ga = ba
	                                } else {
	                                    ba = c[j >> 2] | 0;
	                                    Fa = ba;
	                                    Ga = CT(ba, ja) | 0
	                                }
	                                c[j >> 2] = Fa + Ga;
	                                c[k >> 2] = (c[k >> 2] | 0) - Ga;
	                                pa = ka;
	                                qa = y;
	                                break c;
	                                break
	                            }
	                            case 193:
	                            case 194:
	                            case 197:
	                            case 196:
	                            {
	                                if (ja >>> 0 < 65536 | f) {
	                                    ba = ja >>> 0 > 65535 ? 65533 : ja;
	                                    if ((c[k >> 2] | 0) >>> 0 < 2) {
	                                        ga = 7;
	                                        ha = 114;
	                                        break a
	                                    }
	                                    aa = c[j >> 2] | 0;
	                                    a[aa + u >> 0] = ba >>> 8;
	                                    a[aa + T >> 0] = ba;
	                                    c[j >> 2] = aa + 2;
	                                    c[k >> 2] = (c[k >> 2] | 0) + -2;
	                                    pa = ka;
	                                    qa = y;
	                                    break c
	                                } else {
	                                    if ((c[k >> 2] | 0) >>> 0 < 4) {
	                                        ga = 7;
	                                        ha = 114;
	                                        break a
	                                    }
	                                    aa = ja + -65536 | 0;
	                                    ba = c[j >> 2] | 0;
	                                    a[ba + u >> 0] = aa >>> 18 | 216;
	                                    a[ba + T >> 0] = aa >>> 10;
	                                    a[ba + U >> 0] = aa >>> 8 & 3 | 220;
	                                    a[ba + V >> 0] = aa;
	                                    c[j >> 2] = ba + 4;
	                                    c[k >> 2] = (c[k >> 2] | 0) + -4;
	                                    pa = ka;
	                                    qa = y;
	                                    break c
	                                }
	                                break
	                            }
	                            case 198:
	                            {
	                                if ((c[k >> 2] | 0) >>> 0 < 4) {
	                                    ga = 7;
	                                    ha = 114;
	                                    break a
	                                }
	                                ba = c[j >> 2] | 0;
	                                c[ba >> 2] = ja;
	                                c[j >> 2] = ba + 4;
	                                c[k >> 2] = (c[k >> 2] | 0) + -4;
	                                pa = ka;
	                                qa = y;
	                                break c;
	                                break
	                            }
	                            default:
	                            {
	                                Da = ja;
	                                Ea = y
	                            }
	                        }
	                        d:while (1) {
	                            if ((ha | 0) == 98) {
	                                ha = 0;
	                                Da = 42;
	                                Ea = Ca + 1 | 0
	                            }
	                            if (!(c[k >> 2] | 0)) {
	                                ga = 7;
	                                ha = 114;
	                                break a
	                            }
	                            if (Da >>> 0 < N >>> 0) {
	                                Ha = Da;
	                                break
	                            }
	                            if (S) {
	                                Ca = Ea;
	                                ha = 98;
	                                continue
	                            } else Ia = 0;
	                            while (1) {
	                                ba = (Ia * 5 | 0) >>> 2;
	                                aa = Ia << 1 & 6;
	                                fa = Ia + 1 | 0;
	                                if ((Da | 0) == (e[326792 + ((d[203264 + (v + ba) >> 0] << 8 - aa & 1023 | (d[203264 + (ba + t) >> 0] | 0) >>> aa) << 1) >> 1] | 0)) {
	                                    ha = 105;
	                                    break d
	                                }
	                                if (fa >>> 0 < R >>> 0)Ia = fa; else {
	                                    Ca = Ea;
	                                    ha = 98;
	                                    continue d
	                                }
	                            }
	                        }
	                        if ((ha | 0) == 105) {
	                            ha = 0;
	                            Ha = Ia + 128 | 0
	                        }
	                        fa = c[j >> 2] | 0;
	                        c[j >> 2] = fa + 1;
	                        a[fa >> 0] = Ha;
	                        c[k >> 2] = (c[k >> 2] | 0) + -1;
	                        pa = ka;
	                        qa = Ea
	                    } while (0);
	                    $ = (c[g >> 2] | 0) + pa | 0;
	                    c[g >> 2] = $;
	                    fa = x;
	                    x = x - pa | 0;
	                    c[h >> 2] = x;
	                    if ((fa | 0) == (pa | 0)) {
	                        w = qa;
	                        ha = 116;
	                        break
	                    } else y = qa
	                }
	                if ((ha | 0) == 114)ca = ga; else if ((ha | 0) == 116) {
	                    i = l;
	                    return w | 0
	                }
	                c[(_a() | 0) >> 2] = ca;
	                w = -1;
	                i = l;
	                return w | 0
	            }

	            function _S(b, d, e, f) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0;
	                g = i;
	                i = i + 16 | 0;
	                h = g;
	                c[h >> 2] = b;
	                j = (f | 0) == 0 ? 328248 : f;
	                f = c[j >> 2] | 0;
	                a:do if (!d) {
	                    if (!f) {
	                        k = 0;
	                        i = g;
	                        return k | 0
	                    }
	                } else {
	                    if (!b) {
	                        c[h >> 2] = h;
	                        l = h
	                    } else l = b;
	                    if (!e) {
	                        k = -2;
	                        i = g;
	                        return k | 0
	                    }
	                    do if (!f) {
	                        m = a[d >> 0] | 0;
	                        n = m & 255;
	                        if (m << 24 >> 24 > -1) {
	                            c[l >> 2] = n;
	                            k = m << 24 >> 24 != 0 & 1;
	                            i = g;
	                            return k | 0
	                        } else {
	                            m = n + -194 | 0;
	                            if (m >>> 0 > 50)break a;
	                            o = e + -1 | 0;
	                            p = c[328040 + (m << 2) >> 2] | 0;
	                            q = d + 1 | 0;
	                            break
	                        }
	                    } else {
	                        o = e;
	                        p = f;
	                        q = d
	                    } while (0);
	                    b:do if (!o)r = p; else {
	                        m = a[q >> 0] | 0;
	                        n = (m & 255) >>> 3;
	                        if ((n + -16 | n + (p >> 26)) >>> 0 > 7)break a; else {
	                            s = o;
	                            t = m;
	                            u = p;
	                            v = q
	                        }
	                        while (1) {
	                            v = v + 1 | 0;
	                            u = (t & 255) + -128 | u << 6;
	                            s = s + -1 | 0;
	                            if ((u | 0) >= 0)break;
	                            if (!s) {
	                                r = u;
	                                break b
	                            }
	                            t = a[v >> 0] | 0;
	                            if ((t & -64) << 24 >> 24 != -128)break a
	                        }
	                        c[j >> 2] = 0;
	                        c[l >> 2] = u;
	                        k = e - s | 0;
	                        i = g;
	                        return k | 0
	                    } while (0);
	                    c[j >> 2] = r;
	                    k = -2;
	                    i = g;
	                    return k | 0
	                } while (0);
	                c[j >> 2] = 0;
	                c[(_a() | 0) >> 2] = 84;
	                k = -1;
	                i = g;
	                return k | 0
	            }

	            function $S(a) {
	                a = a | 0;
	                var b = 0;
	                if (!a)b = 1; else b = (c[a >> 2] | 0) == 0;
	                return b & 1 | 0
	            }

	            function aT(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0;
	                e = i;
	                f = a + 84 | 0;
	                g = c[f >> 2] | 0;
	                h = d + 256 | 0;
	                j = NT(g, 0, h) | 0;
	                if (!j)k = h; else k = j - g | 0;
	                j = k >>> 0 < d >>> 0 ? k : d;
	                eU(b | 0, g | 0, j | 0) | 0;
	                c[a + 4 >> 2] = g + j;
	                b = g + k | 0;
	                c[a + 8 >> 2] = b;
	                c[f >> 2] = b;
	                i = e;
	                return j | 0
	            }

	            function bT(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0;
	                e = i;
	                i = i + 16 | 0;
	                f = e;
	                c[f >> 2] = d;
	                d = dT(a, b, f) | 0;
	                i = e;
	                return d | 0
	            }

	            function cT(e, f, j) {
	                e = e | 0;
	                f = f | 0;
	                j = j | 0;
	                var k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, H = 0, I = 0, J = 0, K = 0, L = 0, M = 0, N = 0, O = 0, P = 0, Q = 0, R = 0, S = 0, T = 0, U = 0, V = 0, W = 0, X = 0, Y = 0, Z = 0, _ = 0, $ = 0, aa = 0, ba = 0, ca = 0, da = 0, ea = 0, fa = 0, ga = 0, ha = 0, ia = 0, ja = 0, ka = 0, la = 0, ma = 0, na = 0.0, oa = 0, pa = 0, qa = 0, ra = 0, sa = 0, ta = 0, ua = 0, va = 0, wa = 0, xa = 0, ya = 0, za = 0, Aa = 0, Ba = 0, Ca = 0, Da = 0, Ea = 0, Fa = 0, Ga = 0, Ha = 0, Ia = 0, Ja = 0, Ka = 0, La = 0, Ma = 0, Na = 0, Oa = 0, Pa = 0, Qa = 0, Ra = 0, Sa = 0, Ta = 0, Ua = 0, Va = 0, Wa = 0, Xa = 0, Ya = 0, Za = 0, _a = 0, $a = 0, ab = 0, bb = 0, cb = 0, db = 0;
	                k = i;
	                i = i + 304 | 0;
	                l = k + 16 | 0;
	                m = k + 8 | 0;
	                n = k + 33 | 0;
	                o = k;
	                p = k + 32 | 0;
	                q = a[f >> 0] | 0;
	                if (!(q << 24 >> 24)) {
	                    r = 0;
	                    i = k;
	                    return r | 0
	                }
	                s = e + 4 | 0;
	                t = e + 100 | 0;
	                u = e + 108 | 0;
	                v = e + 8 | 0;
	                w = n + 10 | 0;
	                x = n + 33 | 0;
	                y = m + 4 | 0;
	                z = n + 46 | 0;
	                A = n + 94 | 0;
	                B = q;
	                q = 0;
	                C = f;
	                f = 0;
	                D = 0;
	                E = 0;
	                a:while (1) {
	                    b:do if (!(mT(B & 255) | 0)) {
	                        F = (a[C >> 0] | 0) == 37;
	                        c:do if (F) {
	                            H = C + 1 | 0;
	                            I = a[H >> 0] | 0;
	                            do if (I << 24 >> 24 == 37)break c; else if (I << 24 >> 24 == 42) {
	                                J = 0;
	                                K = C + 2 | 0
	                            } else {
	                                L = (I & 255) + -48 | 0;
	                                if (L >>> 0 < 10 ? (a[C + 2 >> 0] | 0) == 36 : 0) {
	                                    c[l >> 2] = c[j >> 2];
	                                    M = L;
	                                    while (1) {
	                                        L = c[l >> 2] | 0;
	                                        N = c[L >> 2] | 0;
	                                        c[l >> 2] = L + 4;
	                                        if (M >>> 0 > 1)M = M + -1 | 0; else break
	                                    }
	                                    J = N;
	                                    K = C + 3 | 0;
	                                    break
	                                }
	                                M = c[j >> 2] | 0;
	                                L = c[M >> 2] | 0;
	                                c[j >> 2] = M + 4;
	                                J = L;
	                                K = H
	                            } while (0);
	                            H = a[K >> 0] | 0;
	                            I = H & 255;
	                            if ((I + -48 | 0) >>> 0 < 10) {
	                                L = I;
	                                I = K;
	                                M = 0;
	                                while (1) {
	                                    O = (M * 10 | 0) + -48 + L | 0;
	                                    P = I + 1 | 0;
	                                    Q = a[P >> 0] | 0;
	                                    L = Q & 255;
	                                    if ((L + -48 | 0) >>> 0 >= 10) {
	                                        R = Q;
	                                        S = P;
	                                        T = O;
	                                        break
	                                    } else {
	                                        I = P;
	                                        M = O
	                                    }
	                                }
	                            } else {
	                                R = H;
	                                S = K;
	                                T = 0
	                            }
	                            if (R << 24 >> 24 == 109) {
	                                M = S + 1 | 0;
	                                U = a[M >> 0] | 0;
	                                V = (J | 0) != 0 & 1;
	                                W = M;
	                                X = 0;
	                                Y = 0
	                            } else {
	                                U = R;
	                                V = 0;
	                                W = S;
	                                X = D;
	                                Y = E
	                            }
	                            M = W + 1 | 0;
	                            switch (U & 255 | 0) {
	                                case 76:
	                                {
	                                    Z = M;
	                                    _ = 2;
	                                    break
	                                }
	                                case 110:
	                                case 112:
	                                case 67:
	                                case 83:
	                                case 91:
	                                case 99:
	                                case 115:
	                                case 88:
	                                case 71:
	                                case 70:
	                                case 69:
	                                case 65:
	                                case 103:
	                                case 102:
	                                case 101:
	                                case 97:
	                                case 120:
	                                case 117:
	                                case 111:
	                                case 105:
	                                case 100:
	                                {
	                                    Z = W;
	                                    _ = 0;
	                                    break
	                                }
	                                case 108:
	                                {
	                                    I = (a[M >> 0] | 0) == 108;
	                                    Z = I ? W + 2 | 0 : M;
	                                    _ = I ? 3 : 1;
	                                    break
	                                }
	                                case 104:
	                                {
	                                    I = (a[M >> 0] | 0) == 104;
	                                    Z = I ? W + 2 | 0 : M;
	                                    _ = I ? -2 : -1;
	                                    break
	                                }
	                                case 116:
	                                case 122:
	                                {
	                                    Z = M;
	                                    _ = 1;
	                                    break
	                                }
	                                case 106:
	                                {
	                                    Z = M;
	                                    _ = 3;
	                                    break
	                                }
	                                default:
	                                {
	                                    $ = V;
	                                    aa = X;
	                                    ba = Y;
	                                    ca = 162;
	                                    break a
	                                }
	                            }
	                            M = d[Z >> 0] | 0;
	                            I = (M & 47 | 0) == 3;
	                            L = I ? M | 32 : M;
	                            M = I ? 1 : _;
	                            if ((L | 0) == 91) {
	                                da = f;
	                                ea = T
	                            } else if ((L | 0) == 99) {
	                                da = f;
	                                ea = (T | 0) < 1 ? 1 : T
	                            } else if ((L | 0) == 110) {
	                                if (!J) {
	                                    fa = q;
	                                    ga = Z;
	                                    ha = f;
	                                    ia = X;
	                                    ja = Y;
	                                    break b
	                                }
	                                switch (M | 0) {
	                                    case -1:
	                                    {
	                                        b[J >> 1] = f;
	                                        fa = q;
	                                        ga = Z;
	                                        ha = f;
	                                        ia = X;
	                                        ja = Y;
	                                        break b;
	                                        break
	                                    }
	                                    case -2:
	                                    {
	                                        a[J >> 0] = f;
	                                        fa = q;
	                                        ga = Z;
	                                        ha = f;
	                                        ia = X;
	                                        ja = Y;
	                                        break b;
	                                        break
	                                    }
	                                    case 3:
	                                    {
	                                        I = J;
	                                        c[I >> 2] = f;
	                                        c[I + 4 >> 2] = ((f | 0) < 0) << 31 >> 31;
	                                        fa = q;
	                                        ga = Z;
	                                        ha = f;
	                                        ia = X;
	                                        ja = Y;
	                                        break b;
	                                        break
	                                    }
	                                    case 0:
	                                    {
	                                        c[J >> 2] = f;
	                                        fa = q;
	                                        ga = Z;
	                                        ha = f;
	                                        ia = X;
	                                        ja = Y;
	                                        break b;
	                                        break
	                                    }
	                                    case 1:
	                                    {
	                                        c[J >> 2] = f;
	                                        fa = q;
	                                        ga = Z;
	                                        ha = f;
	                                        ia = X;
	                                        ja = Y;
	                                        break b;
	                                        break
	                                    }
	                                    default:
	                                    {
	                                        fa = q;
	                                        ga = Z;
	                                        ha = f;
	                                        ia = X;
	                                        ja = Y;
	                                        break b
	                                    }
	                                }
	                            } else {
	                                pT(e, 0);
	                                do {
	                                    I = c[s >> 2] | 0;
	                                    if (I >>> 0 < (c[t >> 2] | 0) >>> 0) {
	                                        c[s >> 2] = I + 1;
	                                        ka = d[I >> 0] | 0
	                                    } else ka = qT(e) | 0
	                                } while ((mT(ka) | 0) != 0);
	                                H = c[s >> 2] | 0;
	                                if (!(c[t >> 2] | 0))la = H; else {
	                                    I = H + -1 | 0;
	                                    c[s >> 2] = I;
	                                    la = I
	                                }
	                                da = (c[u >> 2] | 0) + f + la - (c[v >> 2] | 0) | 0;
	                                ea = T
	                            }
	                            pT(e, ea);
	                            I = c[s >> 2] | 0;
	                            H = c[t >> 2] | 0;
	                            if (I >>> 0 < H >>> 0) {
	                                c[s >> 2] = I + 1;
	                                ma = H
	                            } else {
	                                if ((qT(e) | 0) < 0) {
	                                    $ = V;
	                                    aa = X;
	                                    ba = Y;
	                                    ca = 162;
	                                    break a
	                                }
	                                ma = c[t >> 2] | 0
	                            }
	                            if (ma)c[s >> 2] = (c[s >> 2] | 0) + -1;
	                            d:do switch (L | 0) {
	                                case 71:
	                                case 103:
	                                case 70:
	                                case 102:
	                                case 69:
	                                case 101:
	                                case 65:
	                                case 97:
	                                {
	                                    na = +oT(e, M, 0);
	                                    if ((c[u >> 2] | 0) == ((c[v >> 2] | 0) - (c[s >> 2] | 0) | 0)) {
	                                        oa = V;
	                                        pa = q;
	                                        qa = X;
	                                        ra = Y;
	                                        break a
	                                    }
	                                    if (J)if (!M) {
	                                        g[J >> 2] = na;
	                                        sa = Z;
	                                        ta = X;
	                                        ua = Y;
	                                        break d
	                                    } else if ((M | 0) == 1) {
	                                        h[J >> 3] = na;
	                                        sa = Z;
	                                        ta = X;
	                                        ua = Y;
	                                        break d
	                                    } else if ((M | 0) == 2) {
	                                        h[J >> 3] = na;
	                                        sa = Z;
	                                        ta = X;
	                                        ua = Y;
	                                        break d
	                                    } else {
	                                        sa = Z;
	                                        ta = X;
	                                        ua = Y;
	                                        break d
	                                    } else {
	                                        sa = Z;
	                                        ta = X;
	                                        ua = Y
	                                    }
	                                    break
	                                }
	                                case 111:
	                                {
	                                    va = 8;
	                                    ca = 144;
	                                    break
	                                }
	                                case 117:
	                                case 100:
	                                {
	                                    va = 10;
	                                    ca = 144;
	                                    break
	                                }
	                                case 105:
	                                {
	                                    va = 0;
	                                    ca = 144;
	                                    break
	                                }
	                                case 91:
	                                case 99:
	                                case 115:
	                                {
	                                    H = (L | 0) == 99;
	                                    e:do if ((L & 239 | 0) == 99) {
	                                        cU(n | 0, -1, 257) | 0;
	                                        a[n >> 0] = 0;
	                                        if ((L | 0) == 115) {
	                                            a[x >> 0] = 0;
	                                            a[w + 0 >> 0] = 0;
	                                            a[w + 1 >> 0] = 0;
	                                            a[w + 2 >> 0] = 0;
	                                            a[w + 3 >> 0] = 0;
	                                            a[w + 4 >> 0] = 0;
	                                            wa = Z
	                                        } else wa = Z
	                                    } else {
	                                        I = Z + 1 | 0;
	                                        O = (a[I >> 0] | 0) == 94;
	                                        P = O & 1;
	                                        Q = O ? Z + 2 | 0 : I;
	                                        cU(n | 0, O & 1 | 0, 257) | 0;
	                                        a[n >> 0] = 0;
	                                        O = a[Q >> 0] | 0;
	                                        if (O << 24 >> 24 == 45) {
	                                            I = (P ^ 1) & 255;
	                                            a[z >> 0] = I;
	                                            xa = I;
	                                            ya = Q + 1 | 0
	                                        } else if (O << 24 >> 24 == 93) {
	                                            O = (P ^ 1) & 255;
	                                            a[A >> 0] = O;
	                                            xa = O;
	                                            ya = Q + 1 | 0
	                                        } else {
	                                            xa = (P ^ 1) & 255;
	                                            ya = Q
	                                        }
	                                        Q = ya;
	                                        while (1) {
	                                            P = a[Q >> 0] | 0;
	                                            if (!(P << 24 >> 24)) {
	                                                $ = V;
	                                                aa = X;
	                                                ba = Y;
	                                                ca = 162;
	                                                break a
	                                            } else if (P << 24 >> 24 == 93) {
	                                                wa = Q;
	                                                break e
	                                            } else if (P << 24 >> 24 == 45) {
	                                                O = Q + 1 | 0;
	                                                I = a[O >> 0] | 0;
	                                                if (!(I << 24 >> 24 == 93 | I << 24 >> 24 == 0)) {
	                                                    za = a[Q + -1 >> 0] | 0;
	                                                    if ((za & 255) < (I & 255)) {
	                                                        Aa = za & 255;
	                                                        do {
	                                                            Aa = Aa + 1 | 0;
	                                                            a[n + Aa >> 0] = xa;
	                                                            za = a[O >> 0] | 0
	                                                        } while ((Aa | 0) < (za & 255 | 0));
	                                                        Ba = za;
	                                                        Ca = O
	                                                    } else {
	                                                        Ba = I;
	                                                        Ca = O
	                                                    }
	                                                } else {
	                                                    Ba = 45;
	                                                    Ca = Q
	                                                }
	                                            } else {
	                                                Ba = P;
	                                                Ca = Q
	                                            }
	                                            a[n + ((Ba & 255) + 1) >> 0] = xa;
	                                            Q = Ca + 1 | 0
	                                        }
	                                    } while (0);
	                                    Q = H ? ea + 1 | 0 : 31;
	                                    Aa = (M | 0) == 1;
	                                    za = (V | 0) != 0;
	                                    f:do if (Aa) {
	                                        if (za) {
	                                            Da = iT(Q << 2) | 0;
	                                            if (!Da) {
	                                                $ = V;
	                                                aa = 0;
	                                                ba = Da;
	                                                ca = 162;
	                                                break a
	                                            } else Ea = Da
	                                        } else Ea = J;
	                                        c[m >> 2] = 0;
	                                        c[y >> 2] = 0;
	                                        Da = 0;
	                                        Fa = Q;
	                                        Ga = Ea;
	                                        g:while (1) {
	                                            if (!Ga)while (1) {
	                                                Ha = c[s >> 2] | 0;
	                                                if (Ha >>> 0 < (c[t >> 2] | 0) >>> 0) {
	                                                    c[s >> 2] = Ha + 1;
	                                                    Ia = d[Ha >> 0] | 0
	                                                } else Ia = qT(e) | 0;
	                                                if (!(a[n + (Ia + 1) >> 0] | 0)) {
	                                                    Ja = Da;
	                                                    Ka = 0;
	                                                    break g
	                                                }
	                                                a[p >> 0] = Ia;
	                                                Ha = _S(o, p, 1, m) | 0;
	                                                if ((Ha | 0) == -2)continue; else if ((Ha | 0) == -1) {
	                                                    $ = V;
	                                                    aa = 0;
	                                                    ba = 0;
	                                                    ca = 162;
	                                                    break a
	                                                }
	                                                if (za & (Da | 0) == (Fa | 0)) {
	                                                    La = Da;
	                                                    break
	                                                }
	                                            } else {
	                                                if (za)Ma = Da; else {
	                                                    Na = Da;
	                                                    ca = 98;
	                                                    break
	                                                }
	                                                while (1) {
	                                                    while (1) {
	                                                        P = c[s >> 2] | 0;
	                                                        if (P >>> 0 < (c[t >> 2] | 0) >>> 0) {
	                                                            c[s >> 2] = P + 1;
	                                                            Oa = d[P >> 0] | 0
	                                                        } else Oa = qT(e) | 0;
	                                                        if (!(a[n + (Oa + 1) >> 0] | 0)) {
	                                                            Ja = Ma;
	                                                            Ka = Ga;
	                                                            break g
	                                                        }
	                                                        a[p >> 0] = Oa;
	                                                        P = _S(o, p, 1, m) | 0;
	                                                        if ((P | 0) == -1) {
	                                                            $ = V;
	                                                            aa = 0;
	                                                            ba = Ga;
	                                                            ca = 162;
	                                                            break a
	                                                        } else if ((P | 0) != -2)break
	                                                    }
	                                                    c[Ga + (Ma << 2) >> 2] = c[o >> 2];
	                                                    Ma = Ma + 1 | 0;
	                                                    if ((Ma | 0) == (Fa | 0)) {
	                                                        La = Fa;
	                                                        break
	                                                    }
	                                                }
	                                            }
	                                            P = Fa << 1 | 1;
	                                            O = kT(Ga, P << 2) | 0;
	                                            if (!O) {
	                                                $ = V;
	                                                aa = 0;
	                                                ba = Ga;
	                                                ca = 162;
	                                                break a
	                                            }
	                                            Da = La;
	                                            Fa = P;
	                                            Ga = O
	                                        }
	                                        h:do if ((ca | 0) == 98)while (1) {
	                                            ca = 0;
	                                            while (1) {
	                                                Fa = c[s >> 2] | 0;
	                                                if (Fa >>> 0 < (c[t >> 2] | 0) >>> 0) {
	                                                    c[s >> 2] = Fa + 1;
	                                                    Pa = d[Fa >> 0] | 0
	                                                } else Pa = qT(e) | 0;
	                                                if (!(a[n + (Pa + 1) >> 0] | 0)) {
	                                                    Ja = Na;
	                                                    Ka = Ga;
	                                                    break h
	                                                }
	                                                a[p >> 0] = Pa;
	                                                Fa = _S(o, p, 1, m) | 0;
	                                                if ((Fa | 0) == -1) {
	                                                    $ = 0;
	                                                    aa = 0;
	                                                    ba = Ga;
	                                                    ca = 162;
	                                                    break a
	                                                } else if ((Fa | 0) != -2)break
	                                            }
	                                            c[Ga + (Na << 2) >> 2] = c[o >> 2];
	                                            Na = Na + 1 | 0;
	                                            ca = 98
	                                        } while (0);
	                                        if (!($S(m) | 0)) {
	                                            $ = V;
	                                            aa = 0;
	                                            ba = Ka;
	                                            ca = 162;
	                                            break a
	                                        } else {
	                                            Qa = Ja;
	                                            Ra = 0;
	                                            Sa = Ka
	                                        }
	                                    } else {
	                                        if (za) {
	                                            Ga = iT(Q) | 0;
	                                            if (!Ga) {
	                                                $ = V;
	                                                aa = 0;
	                                                ba = 0;
	                                                ca = 162;
	                                                break a
	                                            } else {
	                                                Ta = 0;
	                                                Ua = Q;
	                                                Va = Ga
	                                            }
	                                            while (1) {
	                                                Ga = Ta;
	                                                do {
	                                                    Fa = c[s >> 2] | 0;
	                                                    if (Fa >>> 0 < (c[t >> 2] | 0) >>> 0) {
	                                                        c[s >> 2] = Fa + 1;
	                                                        Wa = d[Fa >> 0] | 0
	                                                    } else Wa = qT(e) | 0;
	                                                    if (!(a[n + (Wa + 1) >> 0] | 0)) {
	                                                        Qa = Ga;
	                                                        Ra = Va;
	                                                        Sa = 0;
	                                                        break f
	                                                    }
	                                                    a[Va + Ga >> 0] = Wa;
	                                                    Ga = Ga + 1 | 0
	                                                } while ((Ga | 0) != (Ua | 0));
	                                                Ga = Ua << 1 | 1;
	                                                Fa = kT(Va, Ga) | 0;
	                                                if (!Fa) {
	                                                    $ = V;
	                                                    aa = Va;
	                                                    ba = 0;
	                                                    ca = 162;
	                                                    break a
	                                                } else {
	                                                    Da = Ua;
	                                                    Ua = Ga;
	                                                    Va = Fa;
	                                                    Ta = Da
	                                                }
	                                            }
	                                        }
	                                        if (!J) {
	                                            Da = ma;
	                                            while (1) {
	                                                Fa = c[s >> 2] | 0;
	                                                if (Fa >>> 0 < Da >>> 0) {
	                                                    c[s >> 2] = Fa + 1;
	                                                    Xa = d[Fa >> 0] | 0
	                                                } else Xa = qT(e) | 0;
	                                                if (!(a[n + (Xa + 1) >> 0] | 0)) {
	                                                    Qa = 0;
	                                                    Ra = 0;
	                                                    Sa = 0;
	                                                    break f
	                                                }
	                                                Da = c[t >> 2] | 0
	                                            }
	                                        } else {
	                                            Da = ma;
	                                            Fa = 0;
	                                            while (1) {
	                                                Ga = c[s >> 2] | 0;
	                                                if (Ga >>> 0 < Da >>> 0) {
	                                                    c[s >> 2] = Ga + 1;
	                                                    Ya = d[Ga >> 0] | 0
	                                                } else Ya = qT(e) | 0;
	                                                if (!(a[n + (Ya + 1) >> 0] | 0)) {
	                                                    Qa = Fa;
	                                                    Ra = J;
	                                                    Sa = 0;
	                                                    break f
	                                                }
	                                                a[J + Fa >> 0] = Ya;
	                                                Da = c[t >> 2] | 0;
	                                                Fa = Fa + 1 | 0
	                                            }
	                                        }
	                                    } while (0);
	                                    Q = c[s >> 2] | 0;
	                                    if (!(c[t >> 2] | 0))Za = Q; else {
	                                        Fa = Q + -1 | 0;
	                                        c[s >> 2] = Fa;
	                                        Za = Fa
	                                    }
	                                    Fa = Za - (c[v >> 2] | 0) + (c[u >> 2] | 0) | 0;
	                                    if (!Fa) {
	                                        oa = V;
	                                        pa = q;
	                                        qa = Ra;
	                                        ra = Sa;
	                                        break a
	                                    }
	                                    if (!((Fa | 0) == (ea | 0) | H ^ 1)) {
	                                        oa = V;
	                                        pa = q;
	                                        qa = Ra;
	                                        ra = Sa;
	                                        break a
	                                    }
	                                    do if (za)if (Aa) {
	                                        c[J >> 2] = Sa;
	                                        break
	                                    } else {
	                                        c[J >> 2] = Ra;
	                                        break
	                                    } while (0);
	                                    if (!H) {
	                                        if (Sa)c[Sa + (Qa << 2) >> 2] = 0;
	                                        if (!Ra) {
	                                            sa = wa;
	                                            ta = 0;
	                                            ua = Sa
	                                        } else {
	                                            a[Ra + Qa >> 0] = 0;
	                                            sa = wa;
	                                            ta = Ra;
	                                            ua = Sa
	                                        }
	                                    } else {
	                                        sa = wa;
	                                        ta = Ra;
	                                        ua = Sa
	                                    }
	                                    break
	                                }
	                                case 120:
	                                case 88:
	                                case 112:
	                                {
	                                    va = 16;
	                                    ca = 144;
	                                    break
	                                }
	                                default:
	                                {
	                                    sa = Z;
	                                    ta = X;
	                                    ua = Y
	                                }
	                            } while (0);
	                            i:do if ((ca | 0) == 144) {
	                                ca = 0;
	                                Aa = nT(e, va, 0, -1, -1) | 0;
	                                if ((c[u >> 2] | 0) == ((c[v >> 2] | 0) - (c[s >> 2] | 0) | 0)) {
	                                    oa = V;
	                                    pa = q;
	                                    qa = X;
	                                    ra = Y;
	                                    break a
	                                }
	                                if ((L | 0) == 112 & (J | 0) != 0) {
	                                    c[J >> 2] = Aa;
	                                    sa = Z;
	                                    ta = X;
	                                    ua = Y;
	                                    break
	                                }
	                                if (!J) {
	                                    sa = Z;
	                                    ta = X;
	                                    ua = Y
	                                } else switch (M | 0) {
	                                    case -2:
	                                    {
	                                        a[J >> 0] = Aa;
	                                        sa = Z;
	                                        ta = X;
	                                        ua = Y;
	                                        break i;
	                                        break
	                                    }
	                                    case -1:
	                                    {
	                                        b[J >> 1] = Aa;
	                                        sa = Z;
	                                        ta = X;
	                                        ua = Y;
	                                        break i;
	                                        break
	                                    }
	                                    case 0:
	                                    {
	                                        c[J >> 2] = Aa;
	                                        sa = Z;
	                                        ta = X;
	                                        ua = Y;
	                                        break i;
	                                        break
	                                    }
	                                    case 1:
	                                    {
	                                        c[J >> 2] = Aa;
	                                        sa = Z;
	                                        ta = X;
	                                        ua = Y;
	                                        break i;
	                                        break
	                                    }
	                                    case 3:
	                                    {
	                                        za = J;
	                                        c[za >> 2] = Aa;
	                                        c[za + 4 >> 2] = G;
	                                        sa = Z;
	                                        ta = X;
	                                        ua = Y;
	                                        break i;
	                                        break
	                                    }
	                                    default:
	                                    {
	                                        sa = Z;
	                                        ta = X;
	                                        ua = Y;
	                                        break i
	                                    }
	                                }
	                            } while (0);
	                            fa = ((J | 0) != 0 & 1) + q | 0;
	                            ga = sa;
	                            ha = (c[u >> 2] | 0) + da + (c[s >> 2] | 0) - (c[v >> 2] | 0) | 0;
	                            ia = ta;
	                            ja = ua;
	                            break b
	                        } while (0);
	                        M = C + (F & 1) | 0;
	                        pT(e, 0);
	                        L = c[s >> 2] | 0;
	                        if (L >>> 0 < (c[t >> 2] | 0) >>> 0) {
	                            c[s >> 2] = L + 1;
	                            _a = d[L >> 0] | 0
	                        } else _a = qT(e) | 0;
	                        if ((_a | 0) != (d[M >> 0] | 0)) {
	                            ca = 19;
	                            break a
	                        }
	                        fa = q;
	                        ga = M;
	                        ha = f + 1 | 0;
	                        ia = D;
	                        ja = E
	                    } else {
	                        M = C;
	                        while (1) {
	                            L = M + 1 | 0;
	                            if (!(mT(d[L >> 0] | 0) | 0))break; else M = L
	                        }
	                        pT(e, 0);
	                        do {
	                            F = c[s >> 2] | 0;
	                            if (F >>> 0 < (c[t >> 2] | 0) >>> 0) {
	                                c[s >> 2] = F + 1;
	                                $a = d[F >> 0] | 0
	                            } else $a = qT(e) | 0
	                        } while ((mT($a) | 0) != 0);
	                        F = c[s >> 2] | 0;
	                        if (!(c[t >> 2] | 0))ab = F; else {
	                            L = F + -1 | 0;
	                            c[s >> 2] = L;
	                            ab = L
	                        }
	                        fa = q;
	                        ga = M;
	                        ha = (c[u >> 2] | 0) + f + ab - (c[v >> 2] | 0) | 0;
	                        ia = D;
	                        ja = E
	                    } while (0);
	                    C = ga + 1 | 0;
	                    B = a[C >> 0] | 0;
	                    if (!(B << 24 >> 24)) {
	                        r = fa;
	                        ca = 166;
	                        break
	                    } else {
	                        q = fa;
	                        f = ha;
	                        D = ia;
	                        E = ja
	                    }
	                }
	                if ((ca | 0) == 19) {
	                    if (c[t >> 2] | 0)c[s >> 2] = (c[s >> 2] | 0) + -1;
	                    if ((_a | 0) > -1 | (q | 0) != 0) {
	                        r = q;
	                        i = k;
	                        return r | 0
	                    } else {
	                        bb = 0;
	                        cb = D;
	                        db = E;
	                        ca = 163
	                    }
	                } else if ((ca | 0) == 162)if (!q) {
	                    bb = $;
	                    cb = aa;
	                    db = ba;
	                    ca = 163
	                } else {
	                    oa = $;
	                    pa = q;
	                    qa = aa;
	                    ra = ba
	                } else if ((ca | 0) == 166) {
	                    i = k;
	                    return r | 0
	                }
	                if ((ca | 0) == 163) {
	                    oa = bb;
	                    pa = -1;
	                    qa = cb;
	                    ra = db
	                }
	                if (!oa) {
	                    r = pa;
	                    i = k;
	                    return r | 0
	                }
	                jT(qa);
	                jT(ra);
	                r = pa;
	                i = k;
	                return r | 0
	            }

	            function dT(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                i = i + 112 | 0;
	                f = e;
	                g = f + 0 | 0;
	                h = g + 112 | 0;
	                do {
	                    c[g >> 2] = 0;
	                    g = g + 4 | 0
	                } while ((g | 0) < (h | 0));
	                c[f + 32 >> 2] = 391;
	                c[f + 44 >> 2] = a;
	                c[f + 76 >> 2] = -1;
	                c[f + 84 >> 2] = a;
	                a = cT(f, b, d) | 0;
	                i = e;
	                return a | 0
	            }

	            function eT(b, c) {
	                b = b | 0;
	                c = c | 0;
	                var d = 0, e = 0;
	                d = i;
	                e = fT(b, c) | 0;
	                i = d;
	                return ((a[e >> 0] | 0) == (c & 255) << 24 >> 24 ? e : 0) | 0
	            }

	            function fT(b, d) {
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0;
	                e = i;
	                f = d & 255;
	                if (!f) {
	                    g = b + (ZT(b | 0) | 0) | 0;
	                    i = e;
	                    return g | 0
	                }
	                a:do if (!(b & 3))h = b; else {
	                    j = d & 255;
	                    k = b;
	                    while (1) {
	                        l = a[k >> 0] | 0;
	                        m = k + 1 | 0;
	                        if (l << 24 >> 24 == 0 ? 1 : l << 24 >> 24 == j << 24 >> 24) {
	                            g = k;
	                            break
	                        }
	                        if (!(m & 3)) {
	                            h = m;
	                            break a
	                        } else k = m
	                    }
	                    i = e;
	                    return g | 0
	                } while (0);
	                b = ca(f, 16843009) | 0;
	                f = c[h >> 2] | 0;
	                b:do if (!((f & -2139062144 ^ -2139062144) & f + -16843009)) {
	                    k = f;
	                    j = h;
	                    while (1) {
	                        m = k ^ b;
	                        l = j + 4 | 0;
	                        if ((m & -2139062144 ^ -2139062144) & m + -16843009) {
	                            n = j;
	                            break b
	                        }
	                        k = c[l >> 2] | 0;
	                        if ((k & -2139062144 ^ -2139062144) & k + -16843009) {
	                            n = l;
	                            break
	                        } else j = l
	                    }
	                } else n = h; while (0);
	                h = d & 255;
	                d = n;
	                while (1) {
	                    n = a[d >> 0] | 0;
	                    if (n << 24 >> 24 == 0 ? 1 : n << 24 >> 24 == h << 24 >> 24) {
	                        g = d;
	                        break
	                    } else d = d + 1 | 0
	                }
	                i = e;
	                return g | 0
	            }

	            function gT(b) {
	                b = b | 0;
	                var c = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0;
	                c = i;
	                d = a[b >> 0] | 0;
	                a:do if (d << 24 >> 24) {
	                    e = 203264;
	                    while (1) {
	                        f = b;
	                        g = e;
	                        h = d;
	                        while (1) {
	                            j = a[g >> 0] | 0;
	                            if (!(j << 24 >> 24)) {
	                                k = g;
	                                l = h;
	                                m = 16;
	                                break
	                            }
	                            b:do if (!(h << 24 >> 24)) {
	                                n = f;
	                                o = 0
	                            } else {
	                                p = f;
	                                q = h & 255;
	                                r = h;
	                                while (1) {
	                                    s = p + 1 | 0;
	                                    if (!(((q | 32) + -97 | 0) >>> 0 > 26 & (q + -48 | 0) >>> 0 > 10)) {
	                                        n = p;
	                                        o = r;
	                                        break b
	                                    }
	                                    t = a[s >> 0] | 0;
	                                    if (!(t << 24 >> 24)) {
	                                        n = s;
	                                        o = 0;
	                                        break
	                                    } else {
	                                        p = s;
	                                        q = t & 255;
	                                        r = t
	                                    }
	                                }
	                            } while (0);
	                            if ((o & 255 | 32 | 0) != (j & 255 | 0))break;
	                            f = n + 1 | 0;
	                            r = g + 1 | 0;
	                            h = a[f >> 0] | 0;
	                            if (!(h << 24 >> 24)) {
	                                k = r;
	                                l = 0;
	                                m = 16;
	                                break
	                            } else g = r
	                        }
	                        if ((m | 0) == 16 ? (m = 0, l << 24 >> 24 == (a[k >> 0] | 0)) : 0)break;
	                        g = ZT(e | 0) | 0;
	                        h = e + (g + 1) | 0;
	                        do if (!(a[h >> 0] | 0)) {
	                            f = a[e + (g + 2) >> 0] | 0;
	                            if ((f & 255) > 128) {
	                                u = e + (g + 3) | 0;
	                                break
	                            } else {
	                                u = e + (g + 3 + (((128 - (f & 255) | 0) >>> 2) * 5 | 0)) | 0;
	                                break
	                            }
	                        } else u = h; while (0);
	                        if (!(a[u >> 0] | 0)) {
	                            v = -1;
	                            m = 25;
	                            break
	                        } else e = u
	                    }
	                    if ((m | 0) == 25) {
	                        i = c;
	                        return v | 0
	                    }
	                    if (!(a[e >> 0] | 0))w = e; else {
	                        h = e;
	                        while (1) {
	                            g = h + ((ZT(h | 0) | 0) + 1) | 0;
	                            if (!(a[g >> 0] | 0)) {
	                                w = g;
	                                break
	                            } else h = g
	                        }
	                    }
	                } else {
	                    h = 203264;
	                    while (1) {
	                        if (!(a[h >> 0] | 0)) {
	                            w = h;
	                            break a
	                        }
	                        e = ZT(h | 0) | 0;
	                        g = h + (e + 1) | 0;
	                        do if (!(a[g >> 0] | 0)) {
	                            f = a[h + (e + 2) >> 0] | 0;
	                            if ((f & 255) > 128) {
	                                x = h + (e + 3) | 0;
	                                break
	                            } else {
	                                x = h + (e + 3 + (((128 - (f & 255) | 0) >>> 2) * 5 | 0)) | 0;
	                                break
	                            }
	                        } else x = g; while (0);
	                        if (!(a[x >> 0] | 0)) {
	                            v = -1;
	                            break
	                        } else h = x
	                    }
	                    i = c;
	                    return v | 0
	                } while (0);
	                v = w + 1 - 203264 | 0;
	                i = c;
	                return v | 0
	            }

	            function hT(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                var d = 0, e = 0;
	                d = i;
	                e = aT(a, b, c) | 0;
	                i = d;
	                return e | 0
	            }

	            function iT(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0, J = 0, K = 0, L = 0, M = 0, N = 0, O = 0, P = 0, Q = 0, R = 0, S = 0, T = 0, U = 0, V = 0, W = 0, X = 0, Y = 0, Z = 0, _ = 0, $ = 0, aa = 0, ba = 0, ca = 0, da = 0, ea = 0, fa = 0, ga = 0, ha = 0, ia = 0, ja = 0, ka = 0, la = 0, ma = 0, na = 0, oa = 0, pa = 0, qa = 0, ra = 0, sa = 0, ta = 0, ua = 0, va = 0, wa = 0, xa = 0, ya = 0, za = 0, Aa = 0, Ba = 0, Ca = 0, Da = 0, Ea = 0, Fa = 0, Ga = 0, Ha = 0, Ia = 0, Ja = 0, Ka = 0, La = 0;
	                b = i;
	                do if (a >>> 0 < 245) {
	                    if (a >>> 0 < 11)d = 16; else d = a + 11 & -8;
	                    e = d >>> 3;
	                    f = c[82064] | 0;
	                    g = f >>> e;
	                    if (g & 3) {
	                        h = (g & 1 ^ 1) + e | 0;
	                        j = h << 1;
	                        k = 328296 + (j << 2) | 0;
	                        l = 328296 + (j + 2 << 2) | 0;
	                        j = c[l >> 2] | 0;
	                        m = j + 8 | 0;
	                        n = c[m >> 2] | 0;
	                        do if ((k | 0) != (n | 0)) {
	                            if (n >>> 0 < (c[82068] | 0) >>> 0)hb();
	                            o = n + 12 | 0;
	                            if ((c[o >> 2] | 0) == (j | 0)) {
	                                c[o >> 2] = k;
	                                c[l >> 2] = n;
	                                break
	                            } else hb()
	                        } else c[82064] = f & ~(1 << h); while (0);
	                        n = h << 3;
	                        c[j + 4 >> 2] = n | 3;
	                        l = j + (n | 4) | 0;
	                        c[l >> 2] = c[l >> 2] | 1;
	                        p = m;
	                        i = b;
	                        return p | 0
	                    }
	                    l = c[82066] | 0;
	                    if (d >>> 0 > l >>> 0) {
	                        if (g) {
	                            n = 2 << e;
	                            k = g << e & (n | 0 - n);
	                            n = (k & 0 - k) + -1 | 0;
	                            k = n >>> 12 & 16;
	                            o = n >>> k;
	                            n = o >>> 5 & 8;
	                            q = o >>> n;
	                            o = q >>> 2 & 4;
	                            r = q >>> o;
	                            q = r >>> 1 & 2;
	                            s = r >>> q;
	                            r = s >>> 1 & 1;
	                            t = (n | k | o | q | r) + (s >>> r) | 0;
	                            r = t << 1;
	                            s = 328296 + (r << 2) | 0;
	                            q = 328296 + (r + 2 << 2) | 0;
	                            r = c[q >> 2] | 0;
	                            o = r + 8 | 0;
	                            k = c[o >> 2] | 0;
	                            do if ((s | 0) != (k | 0)) {
	                                if (k >>> 0 < (c[82068] | 0) >>> 0)hb();
	                                n = k + 12 | 0;
	                                if ((c[n >> 2] | 0) == (r | 0)) {
	                                    c[n >> 2] = s;
	                                    c[q >> 2] = k;
	                                    u = c[82066] | 0;
	                                    break
	                                } else hb()
	                            } else {
	                                c[82064] = f & ~(1 << t);
	                                u = l
	                            } while (0);
	                            l = t << 3;
	                            f = l - d | 0;
	                            c[r + 4 >> 2] = d | 3;
	                            k = r + d | 0;
	                            c[r + (d | 4) >> 2] = f | 1;
	                            c[r + l >> 2] = f;
	                            if (u) {
	                                l = c[82069] | 0;
	                                q = u >>> 3;
	                                s = q << 1;
	                                e = 328296 + (s << 2) | 0;
	                                g = c[82064] | 0;
	                                m = 1 << q;
	                                if (g & m) {
	                                    q = 328296 + (s + 2 << 2) | 0;
	                                    j = c[q >> 2] | 0;
	                                    if (j >>> 0 < (c[82068] | 0) >>> 0)hb(); else {
	                                        v = q;
	                                        w = j
	                                    }
	                                } else {
	                                    c[82064] = g | m;
	                                    v = 328296 + (s + 2 << 2) | 0;
	                                    w = e
	                                }
	                                c[v >> 2] = l;
	                                c[w + 12 >> 2] = l;
	                                c[l + 8 >> 2] = w;
	                                c[l + 12 >> 2] = e
	                            }
	                            c[82066] = f;
	                            c[82069] = k;
	                            p = o;
	                            i = b;
	                            return p | 0
	                        }
	                        k = c[82065] | 0;
	                        if (k) {
	                            f = (k & 0 - k) + -1 | 0;
	                            k = f >>> 12 & 16;
	                            e = f >>> k;
	                            f = e >>> 5 & 8;
	                            l = e >>> f;
	                            e = l >>> 2 & 4;
	                            s = l >>> e;
	                            l = s >>> 1 & 2;
	                            m = s >>> l;
	                            s = m >>> 1 & 1;
	                            g = c[328560 + ((f | k | e | l | s) + (m >>> s) << 2) >> 2] | 0;
	                            s = (c[g + 4 >> 2] & -8) - d | 0;
	                            m = g;
	                            l = g;
	                            while (1) {
	                                g = c[m + 16 >> 2] | 0;
	                                if (!g) {
	                                    e = c[m + 20 >> 2] | 0;
	                                    if (!e)break; else x = e
	                                } else x = g;
	                                g = (c[x + 4 >> 2] & -8) - d | 0;
	                                e = g >>> 0 < s >>> 0;
	                                s = e ? g : s;
	                                m = x;
	                                l = e ? x : l
	                            }
	                            m = c[82068] | 0;
	                            if (l >>> 0 < m >>> 0)hb();
	                            o = l + d | 0;
	                            if (l >>> 0 >= o >>> 0)hb();
	                            r = c[l + 24 >> 2] | 0;
	                            t = c[l + 12 >> 2] | 0;
	                            do if ((t | 0) == (l | 0)) {
	                                e = l + 20 | 0;
	                                g = c[e >> 2] | 0;
	                                if (!g) {
	                                    k = l + 16 | 0;
	                                    f = c[k >> 2] | 0;
	                                    if (!f) {
	                                        y = 0;
	                                        break
	                                    } else {
	                                        z = f;
	                                        A = k
	                                    }
	                                } else {
	                                    z = g;
	                                    A = e
	                                }
	                                while (1) {
	                                    e = z + 20 | 0;
	                                    g = c[e >> 2] | 0;
	                                    if (g) {
	                                        z = g;
	                                        A = e;
	                                        continue
	                                    }
	                                    e = z + 16 | 0;
	                                    g = c[e >> 2] | 0;
	                                    if (!g)break; else {
	                                        z = g;
	                                        A = e
	                                    }
	                                }
	                                if (A >>> 0 < m >>> 0)hb(); else {
	                                    c[A >> 2] = 0;
	                                    y = z;
	                                    break
	                                }
	                            } else {
	                                e = c[l + 8 >> 2] | 0;
	                                if (e >>> 0 < m >>> 0)hb();
	                                g = e + 12 | 0;
	                                if ((c[g >> 2] | 0) != (l | 0))hb();
	                                k = t + 8 | 0;
	                                if ((c[k >> 2] | 0) == (l | 0)) {
	                                    c[g >> 2] = t;
	                                    c[k >> 2] = e;
	                                    y = t;
	                                    break
	                                } else hb()
	                            } while (0);
	                            do if (r) {
	                                t = c[l + 28 >> 2] | 0;
	                                m = 328560 + (t << 2) | 0;
	                                if ((l | 0) == (c[m >> 2] | 0)) {
	                                    c[m >> 2] = y;
	                                    if (!y) {
	                                        c[82065] = c[82065] & ~(1 << t);
	                                        break
	                                    }
	                                } else {
	                                    if (r >>> 0 < (c[82068] | 0) >>> 0)hb();
	                                    t = r + 16 | 0;
	                                    if ((c[t >> 2] | 0) == (l | 0))c[t >> 2] = y; else c[r + 20 >> 2] = y;
	                                    if (!y)break
	                                }
	                                t = c[82068] | 0;
	                                if (y >>> 0 < t >>> 0)hb();
	                                c[y + 24 >> 2] = r;
	                                m = c[l + 16 >> 2] | 0;
	                                do if (m)if (m >>> 0 < t >>> 0)hb(); else {
	                                    c[y + 16 >> 2] = m;
	                                    c[m + 24 >> 2] = y;
	                                    break
	                                } while (0);
	                                m = c[l + 20 >> 2] | 0;
	                                if (m)if (m >>> 0 < (c[82068] | 0) >>> 0)hb(); else {
	                                    c[y + 20 >> 2] = m;
	                                    c[m + 24 >> 2] = y;
	                                    break
	                                }
	                            } while (0);
	                            if (s >>> 0 < 16) {
	                                r = s + d | 0;
	                                c[l + 4 >> 2] = r | 3;
	                                m = l + (r + 4) | 0;
	                                c[m >> 2] = c[m >> 2] | 1
	                            } else {
	                                c[l + 4 >> 2] = d | 3;
	                                c[l + (d | 4) >> 2] = s | 1;
	                                c[l + (s + d) >> 2] = s;
	                                m = c[82066] | 0;
	                                if (m) {
	                                    r = c[82069] | 0;
	                                    t = m >>> 3;
	                                    m = t << 1;
	                                    e = 328296 + (m << 2) | 0;
	                                    k = c[82064] | 0;
	                                    g = 1 << t;
	                                    if (k & g) {
	                                        t = 328296 + (m + 2 << 2) | 0;
	                                        f = c[t >> 2] | 0;
	                                        if (f >>> 0 < (c[82068] | 0) >>> 0)hb(); else {
	                                            B = t;
	                                            C = f
	                                        }
	                                    } else {
	                                        c[82064] = k | g;
	                                        B = 328296 + (m + 2 << 2) | 0;
	                                        C = e
	                                    }
	                                    c[B >> 2] = r;
	                                    c[C + 12 >> 2] = r;
	                                    c[r + 8 >> 2] = C;
	                                    c[r + 12 >> 2] = e
	                                }
	                                c[82066] = s;
	                                c[82069] = o
	                            }
	                            p = l + 8 | 0;
	                            i = b;
	                            return p | 0
	                        } else D = d
	                    } else D = d
	                } else if (a >>> 0 <= 4294967231) {
	                    e = a + 11 | 0;
	                    r = e & -8;
	                    m = c[82065] | 0;
	                    if (m) {
	                        g = 0 - r | 0;
	                        k = e >>> 8;
	                        if (k)if (r >>> 0 > 16777215)E = 31; else {
	                            e = (k + 1048320 | 0) >>> 16 & 8;
	                            f = k << e;
	                            k = (f + 520192 | 0) >>> 16 & 4;
	                            t = f << k;
	                            f = (t + 245760 | 0) >>> 16 & 2;
	                            j = 14 - (k | e | f) + (t << f >>> 15) | 0;
	                            E = r >>> (j + 7 | 0) & 1 | j << 1
	                        } else E = 0;
	                        j = c[328560 + (E << 2) >> 2] | 0;
	                        a:do if (!j) {
	                            F = g;
	                            G = 0;
	                            H = 0
	                        } else {
	                            if ((E | 0) == 31)I = 0; else I = 25 - (E >>> 1) | 0;
	                            f = g;
	                            t = 0;
	                            e = r << I;
	                            k = j;
	                            q = 0;
	                            while (1) {
	                                h = c[k + 4 >> 2] & -8;
	                                n = h - r | 0;
	                                if (n >>> 0 < f >>> 0)if ((h | 0) == (r | 0)) {
	                                    F = n;
	                                    G = k;
	                                    H = k;
	                                    break a
	                                } else {
	                                    J = n;
	                                    K = k
	                                } else {
	                                    J = f;
	                                    K = q
	                                }
	                                n = c[k + 20 >> 2] | 0;
	                                k = c[k + (e >>> 31 << 2) + 16 >> 2] | 0;
	                                h = (n | 0) == 0 | (n | 0) == (k | 0) ? t : n;
	                                if (!k) {
	                                    F = J;
	                                    G = h;
	                                    H = K;
	                                    break
	                                } else {
	                                    f = J;
	                                    t = h;
	                                    e = e << 1;
	                                    q = K
	                                }
	                            }
	                        } while (0);
	                        if ((G | 0) == 0 & (H | 0) == 0) {
	                            j = 2 << E;
	                            g = m & (j | 0 - j);
	                            if (!g) {
	                                D = r;
	                                break
	                            }
	                            j = (g & 0 - g) + -1 | 0;
	                            g = j >>> 12 & 16;
	                            l = j >>> g;
	                            j = l >>> 5 & 8;
	                            o = l >>> j;
	                            l = o >>> 2 & 4;
	                            s = o >>> l;
	                            o = s >>> 1 & 2;
	                            q = s >>> o;
	                            s = q >>> 1 & 1;
	                            L = c[328560 + ((j | g | l | o | s) + (q >>> s) << 2) >> 2] | 0
	                        } else L = G;
	                        if (!L) {
	                            M = F;
	                            N = H
	                        } else {
	                            s = F;
	                            q = L;
	                            o = H;
	                            while (1) {
	                                l = (c[q + 4 >> 2] & -8) - r | 0;
	                                g = l >>> 0 < s >>> 0;
	                                j = g ? l : s;
	                                l = g ? q : o;
	                                g = c[q + 16 >> 2] | 0;
	                                if (g) {
	                                    s = j;
	                                    q = g;
	                                    o = l;
	                                    continue
	                                }
	                                q = c[q + 20 >> 2] | 0;
	                                if (!q) {
	                                    M = j;
	                                    N = l;
	                                    break
	                                } else {
	                                    s = j;
	                                    o = l
	                                }
	                            }
	                        }
	                        if ((N | 0) != 0 ? M >>> 0 < ((c[82066] | 0) - r | 0) >>> 0 : 0) {
	                            o = c[82068] | 0;
	                            if (N >>> 0 < o >>> 0)hb();
	                            s = N + r | 0;
	                            if (N >>> 0 >= s >>> 0)hb();
	                            q = c[N + 24 >> 2] | 0;
	                            m = c[N + 12 >> 2] | 0;
	                            do if ((m | 0) == (N | 0)) {
	                                l = N + 20 | 0;
	                                j = c[l >> 2] | 0;
	                                if (!j) {
	                                    g = N + 16 | 0;
	                                    e = c[g >> 2] | 0;
	                                    if (!e) {
	                                        O = 0;
	                                        break
	                                    } else {
	                                        P = e;
	                                        Q = g
	                                    }
	                                } else {
	                                    P = j;
	                                    Q = l
	                                }
	                                while (1) {
	                                    l = P + 20 | 0;
	                                    j = c[l >> 2] | 0;
	                                    if (j) {
	                                        P = j;
	                                        Q = l;
	                                        continue
	                                    }
	                                    l = P + 16 | 0;
	                                    j = c[l >> 2] | 0;
	                                    if (!j)break; else {
	                                        P = j;
	                                        Q = l
	                                    }
	                                }
	                                if (Q >>> 0 < o >>> 0)hb(); else {
	                                    c[Q >> 2] = 0;
	                                    O = P;
	                                    break
	                                }
	                            } else {
	                                l = c[N + 8 >> 2] | 0;
	                                if (l >>> 0 < o >>> 0)hb();
	                                j = l + 12 | 0;
	                                if ((c[j >> 2] | 0) != (N | 0))hb();
	                                g = m + 8 | 0;
	                                if ((c[g >> 2] | 0) == (N | 0)) {
	                                    c[j >> 2] = m;
	                                    c[g >> 2] = l;
	                                    O = m;
	                                    break
	                                } else hb()
	                            } while (0);
	                            do if (q) {
	                                m = c[N + 28 >> 2] | 0;
	                                o = 328560 + (m << 2) | 0;
	                                if ((N | 0) == (c[o >> 2] | 0)) {
	                                    c[o >> 2] = O;
	                                    if (!O) {
	                                        c[82065] = c[82065] & ~(1 << m);
	                                        break
	                                    }
	                                } else {
	                                    if (q >>> 0 < (c[82068] | 0) >>> 0)hb();
	                                    m = q + 16 | 0;
	                                    if ((c[m >> 2] | 0) == (N | 0))c[m >> 2] = O; else c[q + 20 >> 2] = O;
	                                    if (!O)break
	                                }
	                                m = c[82068] | 0;
	                                if (O >>> 0 < m >>> 0)hb();
	                                c[O + 24 >> 2] = q;
	                                o = c[N + 16 >> 2] | 0;
	                                do if (o)if (o >>> 0 < m >>> 0)hb(); else {
	                                    c[O + 16 >> 2] = o;
	                                    c[o + 24 >> 2] = O;
	                                    break
	                                } while (0);
	                                o = c[N + 20 >> 2] | 0;
	                                if (o)if (o >>> 0 < (c[82068] | 0) >>> 0)hb(); else {
	                                    c[O + 20 >> 2] = o;
	                                    c[o + 24 >> 2] = O;
	                                    break
	                                }
	                            } while (0);
	                            b:do if (M >>> 0 >= 16) {
	                                c[N + 4 >> 2] = r | 3;
	                                c[N + (r | 4) >> 2] = M | 1;
	                                c[N + (M + r) >> 2] = M;
	                                q = M >>> 3;
	                                if (M >>> 0 < 256) {
	                                    o = q << 1;
	                                    m = 328296 + (o << 2) | 0;
	                                    l = c[82064] | 0;
	                                    g = 1 << q;
	                                    do if (!(l & g)) {
	                                        c[82064] = l | g;
	                                        R = 328296 + (o + 2 << 2) | 0;
	                                        S = m
	                                    } else {
	                                        q = 328296 + (o + 2 << 2) | 0;
	                                        j = c[q >> 2] | 0;
	                                        if (j >>> 0 >= (c[82068] | 0) >>> 0) {
	                                            R = q;
	                                            S = j;
	                                            break
	                                        }
	                                        hb()
	                                    } while (0);
	                                    c[R >> 2] = s;
	                                    c[S + 12 >> 2] = s;
	                                    c[N + (r + 8) >> 2] = S;
	                                    c[N + (r + 12) >> 2] = m;
	                                    break
	                                }
	                                o = M >>> 8;
	                                if (o)if (M >>> 0 > 16777215)T = 31; else {
	                                    g = (o + 1048320 | 0) >>> 16 & 8;
	                                    l = o << g;
	                                    o = (l + 520192 | 0) >>> 16 & 4;
	                                    j = l << o;
	                                    l = (j + 245760 | 0) >>> 16 & 2;
	                                    q = 14 - (o | g | l) + (j << l >>> 15) | 0;
	                                    T = M >>> (q + 7 | 0) & 1 | q << 1
	                                } else T = 0;
	                                q = 328560 + (T << 2) | 0;
	                                c[N + (r + 28) >> 2] = T;
	                                c[N + (r + 20) >> 2] = 0;
	                                c[N + (r + 16) >> 2] = 0;
	                                l = c[82065] | 0;
	                                j = 1 << T;
	                                if (!(l & j)) {
	                                    c[82065] = l | j;
	                                    c[q >> 2] = s;
	                                    c[N + (r + 24) >> 2] = q;
	                                    c[N + (r + 12) >> 2] = s;
	                                    c[N + (r + 8) >> 2] = s;
	                                    break
	                                }
	                                j = c[q >> 2] | 0;
	                                if ((T | 0) == 31)U = 0; else U = 25 - (T >>> 1) | 0;
	                                c:do if ((c[j + 4 >> 2] & -8 | 0) != (M | 0)) {
	                                    q = M << U;
	                                    l = j;
	                                    while (1) {
	                                        V = l + (q >>> 31 << 2) + 16 | 0;
	                                        g = c[V >> 2] | 0;
	                                        if (!g)break;
	                                        if ((c[g + 4 >> 2] & -8 | 0) == (M | 0)) {
	                                            W = g;
	                                            break c
	                                        } else {
	                                            q = q << 1;
	                                            l = g
	                                        }
	                                    }
	                                    if (V >>> 0 < (c[82068] | 0) >>> 0)hb(); else {
	                                        c[V >> 2] = s;
	                                        c[N + (r + 24) >> 2] = l;
	                                        c[N + (r + 12) >> 2] = s;
	                                        c[N + (r + 8) >> 2] = s;
	                                        break b
	                                    }
	                                } else W = j; while (0);
	                                j = W + 8 | 0;
	                                m = c[j >> 2] | 0;
	                                q = c[82068] | 0;
	                                if (W >>> 0 >= q >>> 0 & m >>> 0 >= q >>> 0) {
	                                    c[m + 12 >> 2] = s;
	                                    c[j >> 2] = s;
	                                    c[N + (r + 8) >> 2] = m;
	                                    c[N + (r + 12) >> 2] = W;
	                                    c[N + (r + 24) >> 2] = 0;
	                                    break
	                                } else hb()
	                            } else {
	                                m = M + r | 0;
	                                c[N + 4 >> 2] = m | 3;
	                                j = N + (m + 4) | 0;
	                                c[j >> 2] = c[j >> 2] | 1
	                            } while (0);
	                            p = N + 8 | 0;
	                            i = b;
	                            return p | 0
	                        } else D = r
	                    } else D = r
	                } else D = -1; while (0);
	                N = c[82066] | 0;
	                if (N >>> 0 >= D >>> 0) {
	                    M = N - D | 0;
	                    W = c[82069] | 0;
	                    if (M >>> 0 > 15) {
	                        c[82069] = W + D;
	                        c[82066] = M;
	                        c[W + (D + 4) >> 2] = M | 1;
	                        c[W + N >> 2] = M;
	                        c[W + 4 >> 2] = D | 3
	                    } else {
	                        c[82066] = 0;
	                        c[82069] = 0;
	                        c[W + 4 >> 2] = N | 3;
	                        M = W + (N + 4) | 0;
	                        c[M >> 2] = c[M >> 2] | 1
	                    }
	                    p = W + 8 | 0;
	                    i = b;
	                    return p | 0
	                }
	                W = c[82067] | 0;
	                if (W >>> 0 > D >>> 0) {
	                    M = W - D | 0;
	                    c[82067] = M;
	                    W = c[82070] | 0;
	                    c[82070] = W + D;
	                    c[W + (D + 4) >> 2] = M | 1;
	                    c[W + 4 >> 2] = D | 3;
	                    p = W + 8 | 0;
	                    i = b;
	                    return p | 0
	                }
	                do if (!(c[82182] | 0)) {
	                    W = db(30) | 0;
	                    if (!(W + -1 & W)) {
	                        c[82184] = W;
	                        c[82183] = W;
	                        c[82185] = -1;
	                        c[82186] = -1;
	                        c[82187] = 0;
	                        c[82175] = 0;
	                        c[82182] = (jb(0) | 0) & -16 ^ 1431655768;
	                        break
	                    } else hb()
	                } while (0);
	                W = D + 48 | 0;
	                M = c[82184] | 0;
	                N = D + 47 | 0;
	                V = M + N | 0;
	                U = 0 - M | 0;
	                M = V & U;
	                if (M >>> 0 <= D >>> 0) {
	                    p = 0;
	                    i = b;
	                    return p | 0
	                }
	                T = c[82174] | 0;
	                if ((T | 0) != 0 ? (S = c[82172] | 0, R = S + M | 0, R >>> 0 <= S >>> 0 | R >>> 0 > T >>> 0) : 0) {
	                    p = 0;
	                    i = b;
	                    return p | 0
	                }
	                d:do if (!(c[82175] & 4)) {
	                    T = c[82070] | 0;
	                    e:do if (T) {
	                        R = 328704 | 0;
	                        while (1) {
	                            S = c[R >> 2] | 0;
	                            if (S >>> 0 <= T >>> 0 ? (X = R + 4 | 0, (S + (c[X >> 2] | 0) | 0) >>> 0 > T >>> 0) : 0)break;
	                            S = c[R + 8 >> 2] | 0;
	                            if (!S) {
	                                Y = 181;
	                                break e
	                            } else R = S
	                        }
	                        if (R) {
	                            S = V - (c[82067] | 0) & U;
	                            if (S >>> 0 < 2147483647) {
	                                O = Ma(S | 0) | 0;
	                                if ((O | 0) == ((c[R >> 2] | 0) + (c[X >> 2] | 0) | 0)) {
	                                    Z = O;
	                                    _ = S;
	                                    Y = 190
	                                } else {
	                                    $ = O;
	                                    aa = S;
	                                    Y = 191
	                                }
	                            } else ba = 0
	                        } else Y = 181
	                    } else Y = 181; while (0);
	                    do if ((Y | 0) == 181) {
	                        T = Ma(0) | 0;
	                        if ((T | 0) != (-1 | 0)) {
	                            r = T;
	                            S = c[82183] | 0;
	                            O = S + -1 | 0;
	                            if (!(O & r))ca = M; else ca = M - r + (O + r & 0 - S) | 0;
	                            S = c[82172] | 0;
	                            r = S + ca | 0;
	                            if (ca >>> 0 > D >>> 0 & ca >>> 0 < 2147483647) {
	                                O = c[82174] | 0;
	                                if ((O | 0) != 0 ? r >>> 0 <= S >>> 0 | r >>> 0 > O >>> 0 : 0) {
	                                    ba = 0;
	                                    break
	                                }
	                                O = Ma(ca | 0) | 0;
	                                if ((O | 0) == (T | 0)) {
	                                    Z = T;
	                                    _ = ca;
	                                    Y = 190
	                                } else {
	                                    $ = O;
	                                    aa = ca;
	                                    Y = 191
	                                }
	                            } else ba = 0
	                        } else ba = 0
	                    } while (0);
	                    f:do if ((Y | 0) == 190)if ((Z | 0) == (-1 | 0))ba = _; else {
	                        da = Z;
	                        ea = _;
	                        Y = 201;
	                        break d
	                    } else if ((Y | 0) == 191) {
	                        O = 0 - aa | 0;
	                        do if (($ | 0) != (-1 | 0) & aa >>> 0 < 2147483647 & W >>> 0 > aa >>> 0 ? (T = c[82184] | 0, r = N - aa + T & 0 - T, r >>> 0 < 2147483647) : 0)if ((Ma(r | 0) | 0) == (-1 | 0)) {
	                            Ma(O | 0) | 0;
	                            ba = 0;
	                            break f
	                        } else {
	                            fa = r + aa | 0;
	                            break
	                        } else fa = aa; while (0);
	                        if (($ | 0) == (-1 | 0))ba = 0; else {
	                            da = $;
	                            ea = fa;
	                            Y = 201;
	                            break d
	                        }
	                    } while (0);
	                    c[82175] = c[82175] | 4;
	                    ga = ba;
	                    Y = 198
	                } else {
	                    ga = 0;
	                    Y = 198
	                } while (0);
	                if ((((Y | 0) == 198 ? M >>> 0 < 2147483647 : 0) ? (ba = Ma(M | 0) | 0, M = Ma(0) | 0, (ba | 0) != (-1 | 0) & (M | 0) != (-1 | 0) & ba >>> 0 < M >>> 0) : 0) ? (fa = M - ba | 0, M = fa >>> 0 > (D + 40 | 0) >>> 0, M) : 0) {
	                    da = ba;
	                    ea = M ? fa : ga;
	                    Y = 201
	                }
	                if ((Y | 0) == 201) {
	                    ga = (c[82172] | 0) + ea | 0;
	                    c[82172] = ga;
	                    if (ga >>> 0 > (c[82173] | 0) >>> 0)c[82173] = ga;
	                    ga = c[82070] | 0;
	                    g:do if (ga) {
	                        fa = 328704 | 0;
	                        while (1) {
	                            ha = c[fa >> 2] | 0;
	                            ia = fa + 4 | 0;
	                            ja = c[ia >> 2] | 0;
	                            if ((da | 0) == (ha + ja | 0)) {
	                                Y = 213;
	                                break
	                            }
	                            M = c[fa + 8 >> 2] | 0;
	                            if (!M)break; else fa = M
	                        }
	                        if (((Y | 0) == 213 ? (c[fa + 12 >> 2] & 8 | 0) == 0 : 0) ? ga >>> 0 >= ha >>> 0 & ga >>> 0 < da >>> 0 : 0) {
	                            c[ia >> 2] = ja + ea;
	                            M = (c[82067] | 0) + ea | 0;
	                            ba = ga + 8 | 0;
	                            if (!(ba & 7))ka = 0; else ka = 0 - ba & 7;
	                            ba = M - ka | 0;
	                            c[82070] = ga + ka;
	                            c[82067] = ba;
	                            c[ga + (ka + 4) >> 2] = ba | 1;
	                            c[ga + (M + 4) >> 2] = 40;
	                            c[82071] = c[82186];
	                            break
	                        }
	                        M = c[82068] | 0;
	                        if (da >>> 0 < M >>> 0) {
	                            c[82068] = da;
	                            la = da
	                        } else la = M;
	                        M = da + ea | 0;
	                        ba = 328704 | 0;
	                        while (1) {
	                            if ((c[ba >> 2] | 0) == (M | 0)) {
	                                Y = 223;
	                                break
	                            }
	                            $ = c[ba + 8 >> 2] | 0;
	                            if (!$)break; else ba = $
	                        }
	                        if ((Y | 0) == 223 ? (c[ba + 12 >> 2] & 8 | 0) == 0 : 0) {
	                            c[ba >> 2] = da;
	                            M = ba + 4 | 0;
	                            c[M >> 2] = (c[M >> 2] | 0) + ea;
	                            M = da + 8 | 0;
	                            if (!(M & 7))ma = 0; else ma = 0 - M & 7;
	                            M = da + (ea + 8) | 0;
	                            if (!(M & 7))na = 0; else na = 0 - M & 7;
	                            M = da + (na + ea) | 0;
	                            fa = ma + D | 0;
	                            $ = da + fa | 0;
	                            aa = M - (da + ma) - D | 0;
	                            c[da + (ma + 4) >> 2] = D | 3;
	                            h:do if ((M | 0) != (ga | 0)) {
	                                if ((M | 0) == (c[82069] | 0)) {
	                                    N = (c[82066] | 0) + aa | 0;
	                                    c[82066] = N;
	                                    c[82069] = $;
	                                    c[da + (fa + 4) >> 2] = N | 1;
	                                    c[da + (N + fa) >> 2] = N;
	                                    break
	                                }
	                                N = ea + 4 | 0;
	                                W = c[da + (N + na) >> 2] | 0;
	                                if ((W & 3 | 0) == 1) {
	                                    _ = W & -8;
	                                    Z = W >>> 3;
	                                    i:do if (W >>> 0 >= 256) {
	                                        ca = c[da + ((na | 24) + ea) >> 2] | 0;
	                                        X = c[da + (ea + 12 + na) >> 2] | 0;
	                                        do if ((X | 0) == (M | 0)) {
	                                            U = na | 16;
	                                            V = da + (N + U) | 0;
	                                            O = c[V >> 2] | 0;
	                                            if (!O) {
	                                                R = da + (U + ea) | 0;
	                                                U = c[R >> 2] | 0;
	                                                if (!U) {
	                                                    oa = 0;
	                                                    break
	                                                } else {
	                                                    pa = U;
	                                                    qa = R
	                                                }
	                                            } else {
	                                                pa = O;
	                                                qa = V
	                                            }
	                                            while (1) {
	                                                V = pa + 20 | 0;
	                                                O = c[V >> 2] | 0;
	                                                if (O) {
	                                                    pa = O;
	                                                    qa = V;
	                                                    continue
	                                                }
	                                                V = pa + 16 | 0;
	                                                O = c[V >> 2] | 0;
	                                                if (!O)break; else {
	                                                    pa = O;
	                                                    qa = V
	                                                }
	                                            }
	                                            if (qa >>> 0 < la >>> 0)hb(); else {
	                                                c[qa >> 2] = 0;
	                                                oa = pa;
	                                                break
	                                            }
	                                        } else {
	                                            V = c[da + ((na | 8) + ea) >> 2] | 0;
	                                            if (V >>> 0 < la >>> 0)hb();
	                                            O = V + 12 | 0;
	                                            if ((c[O >> 2] | 0) != (M | 0))hb();
	                                            R = X + 8 | 0;
	                                            if ((c[R >> 2] | 0) == (M | 0)) {
	                                                c[O >> 2] = X;
	                                                c[R >> 2] = V;
	                                                oa = X;
	                                                break
	                                            } else hb()
	                                        } while (0);
	                                        if (!ca)break;
	                                        X = c[da + (ea + 28 + na) >> 2] | 0;
	                                        l = 328560 + (X << 2) | 0;
	                                        do if ((M | 0) != (c[l >> 2] | 0)) {
	                                            if (ca >>> 0 < (c[82068] | 0) >>> 0)hb();
	                                            V = ca + 16 | 0;
	                                            if ((c[V >> 2] | 0) == (M | 0))c[V >> 2] = oa; else c[ca + 20 >> 2] = oa;
	                                            if (!oa)break i
	                                        } else {
	                                            c[l >> 2] = oa;
	                                            if (oa)break;
	                                            c[82065] = c[82065] & ~(1 << X);
	                                            break i
	                                        } while (0);
	                                        X = c[82068] | 0;
	                                        if (oa >>> 0 < X >>> 0)hb();
	                                        c[oa + 24 >> 2] = ca;
	                                        l = na | 16;
	                                        V = c[da + (l + ea) >> 2] | 0;
	                                        do if (V)if (V >>> 0 < X >>> 0)hb(); else {
	                                            c[oa + 16 >> 2] = V;
	                                            c[V + 24 >> 2] = oa;
	                                            break
	                                        } while (0);
	                                        V = c[da + (N + l) >> 2] | 0;
	                                        if (!V)break;
	                                        if (V >>> 0 < (c[82068] | 0) >>> 0)hb(); else {
	                                            c[oa + 20 >> 2] = V;
	                                            c[V + 24 >> 2] = oa;
	                                            break
	                                        }
	                                    } else {
	                                        V = c[da + ((na | 8) + ea) >> 2] | 0;
	                                        X = c[da + (ea + 12 + na) >> 2] | 0;
	                                        ca = 328296 + (Z << 1 << 2) | 0;
	                                        do if ((V | 0) != (ca | 0)) {
	                                            if (V >>> 0 < la >>> 0)hb();
	                                            if ((c[V + 12 >> 2] | 0) == (M | 0))break;
	                                            hb()
	                                        } while (0);
	                                        if ((X | 0) == (V | 0)) {
	                                            c[82064] = c[82064] & ~(1 << Z);
	                                            break
	                                        }
	                                        do if ((X | 0) == (ca | 0))ra = X + 8 | 0; else {
	                                            if (X >>> 0 < la >>> 0)hb();
	                                            l = X + 8 | 0;
	                                            if ((c[l >> 2] | 0) == (M | 0)) {
	                                                ra = l;
	                                                break
	                                            }
	                                            hb()
	                                        } while (0);
	                                        c[V + 12 >> 2] = X;
	                                        c[ra >> 2] = V
	                                    } while (0);
	                                    sa = da + ((_ | na) + ea) | 0;
	                                    ta = _ + aa | 0
	                                } else {
	                                    sa = M;
	                                    ta = aa
	                                }
	                                Z = sa + 4 | 0;
	                                c[Z >> 2] = c[Z >> 2] & -2;
	                                c[da + (fa + 4) >> 2] = ta | 1;
	                                c[da + (ta + fa) >> 2] = ta;
	                                Z = ta >>> 3;
	                                if (ta >>> 0 < 256) {
	                                    N = Z << 1;
	                                    W = 328296 + (N << 2) | 0;
	                                    ca = c[82064] | 0;
	                                    l = 1 << Z;
	                                    do if (!(ca & l)) {
	                                        c[82064] = ca | l;
	                                        ua = 328296 + (N + 2 << 2) | 0;
	                                        va = W
	                                    } else {
	                                        Z = 328296 + (N + 2 << 2) | 0;
	                                        R = c[Z >> 2] | 0;
	                                        if (R >>> 0 >= (c[82068] | 0) >>> 0) {
	                                            ua = Z;
	                                            va = R;
	                                            break
	                                        }
	                                        hb()
	                                    } while (0);
	                                    c[ua >> 2] = $;
	                                    c[va + 12 >> 2] = $;
	                                    c[da + (fa + 8) >> 2] = va;
	                                    c[da + (fa + 12) >> 2] = W;
	                                    break
	                                }
	                                N = ta >>> 8;
	                                do if (!N)wa = 0; else {
	                                    if (ta >>> 0 > 16777215) {
	                                        wa = 31;
	                                        break
	                                    }
	                                    l = (N + 1048320 | 0) >>> 16 & 8;
	                                    ca = N << l;
	                                    _ = (ca + 520192 | 0) >>> 16 & 4;
	                                    R = ca << _;
	                                    ca = (R + 245760 | 0) >>> 16 & 2;
	                                    Z = 14 - (_ | l | ca) + (R << ca >>> 15) | 0;
	                                    wa = ta >>> (Z + 7 | 0) & 1 | Z << 1
	                                } while (0);
	                                N = 328560 + (wa << 2) | 0;
	                                c[da + (fa + 28) >> 2] = wa;
	                                c[da + (fa + 20) >> 2] = 0;
	                                c[da + (fa + 16) >> 2] = 0;
	                                W = c[82065] | 0;
	                                Z = 1 << wa;
	                                if (!(W & Z)) {
	                                    c[82065] = W | Z;
	                                    c[N >> 2] = $;
	                                    c[da + (fa + 24) >> 2] = N;
	                                    c[da + (fa + 12) >> 2] = $;
	                                    c[da + (fa + 8) >> 2] = $;
	                                    break
	                                }
	                                Z = c[N >> 2] | 0;
	                                if ((wa | 0) == 31)xa = 0; else xa = 25 - (wa >>> 1) | 0;
	                                j:do if ((c[Z + 4 >> 2] & -8 | 0) != (ta | 0)) {
	                                    N = ta << xa;
	                                    W = Z;
	                                    while (1) {
	                                        ya = W + (N >>> 31 << 2) + 16 | 0;
	                                        ca = c[ya >> 2] | 0;
	                                        if (!ca)break;
	                                        if ((c[ca + 4 >> 2] & -8 | 0) == (ta | 0)) {
	                                            za = ca;
	                                            break j
	                                        } else {
	                                            N = N << 1;
	                                            W = ca
	                                        }
	                                    }
	                                    if (ya >>> 0 < (c[82068] | 0) >>> 0)hb(); else {
	                                        c[ya >> 2] = $;
	                                        c[da + (fa + 24) >> 2] = W;
	                                        c[da + (fa + 12) >> 2] = $;
	                                        c[da + (fa + 8) >> 2] = $;
	                                        break h
	                                    }
	                                } else za = Z; while (0);
	                                Z = za + 8 | 0;
	                                N = c[Z >> 2] | 0;
	                                V = c[82068] | 0;
	                                if (za >>> 0 >= V >>> 0 & N >>> 0 >= V >>> 0) {
	                                    c[N + 12 >> 2] = $;
	                                    c[Z >> 2] = $;
	                                    c[da + (fa + 8) >> 2] = N;
	                                    c[da + (fa + 12) >> 2] = za;
	                                    c[da + (fa + 24) >> 2] = 0;
	                                    break
	                                } else hb()
	                            } else {
	                                N = (c[82067] | 0) + aa | 0;
	                                c[82067] = N;
	                                c[82070] = $;
	                                c[da + (fa + 4) >> 2] = N | 1
	                            } while (0);
	                            p = da + (ma | 8) | 0;
	                            i = b;
	                            return p | 0
	                        }
	                        fa = 328704 | 0;
	                        while (1) {
	                            Aa = c[fa >> 2] | 0;
	                            if (Aa >>> 0 <= ga >>> 0 ? (Ba = c[fa + 4 >> 2] | 0, Ca = Aa + Ba | 0, Ca >>> 0 > ga >>> 0) : 0)break;
	                            fa = c[fa + 8 >> 2] | 0
	                        }
	                        fa = Aa + (Ba + -39) | 0;
	                        if (!(fa & 7))Da = 0; else Da = 0 - fa & 7;
	                        fa = Aa + (Ba + -47 + Da) | 0;
	                        $ = fa >>> 0 < (ga + 16 | 0) >>> 0 ? ga : fa;
	                        fa = $ + 8 | 0;
	                        aa = da + 8 | 0;
	                        if (!(aa & 7))Ea = 0; else Ea = 0 - aa & 7;
	                        aa = ea + -40 - Ea | 0;
	                        c[82070] = da + Ea;
	                        c[82067] = aa;
	                        c[da + (Ea + 4) >> 2] = aa | 1;
	                        c[da + (ea + -36) >> 2] = 40;
	                        c[82071] = c[82186];
	                        c[$ + 4 >> 2] = 27;
	                        c[fa + 0 >> 2] = c[82176];
	                        c[fa + 4 >> 2] = c[82177];
	                        c[fa + 8 >> 2] = c[82178];
	                        c[fa + 12 >> 2] = c[82179];
	                        c[82176] = da;
	                        c[82177] = ea;
	                        c[82179] = 0;
	                        c[82178] = fa;
	                        fa = $ + 28 | 0;
	                        c[fa >> 2] = 7;
	                        if (($ + 32 | 0) >>> 0 < Ca >>> 0) {
	                            aa = fa;
	                            do {
	                                fa = aa;
	                                aa = aa + 4 | 0;
	                                c[aa >> 2] = 7
	                            } while ((fa + 8 | 0) >>> 0 < Ca >>> 0)
	                        }
	                        if (($ | 0) != (ga | 0)) {
	                            aa = $ - ga | 0;
	                            fa = ga + (aa + 4) | 0;
	                            c[fa >> 2] = c[fa >> 2] & -2;
	                            c[ga + 4 >> 2] = aa | 1;
	                            c[ga + aa >> 2] = aa;
	                            fa = aa >>> 3;
	                            if (aa >>> 0 < 256) {
	                                M = fa << 1;
	                                ba = 328296 + (M << 2) | 0;
	                                N = c[82064] | 0;
	                                Z = 1 << fa;
	                                do if (!(N & Z)) {
	                                    c[82064] = N | Z;
	                                    Fa = 328296 + (M + 2 << 2) | 0;
	                                    Ga = ba
	                                } else {
	                                    fa = 328296 + (M + 2 << 2) | 0;
	                                    V = c[fa >> 2] | 0;
	                                    if (V >>> 0 >= (c[82068] | 0) >>> 0) {
	                                        Fa = fa;
	                                        Ga = V;
	                                        break
	                                    }
	                                    hb()
	                                } while (0);
	                                c[Fa >> 2] = ga;
	                                c[Ga + 12 >> 2] = ga;
	                                c[ga + 8 >> 2] = Ga;
	                                c[ga + 12 >> 2] = ba;
	                                break
	                            }
	                            M = aa >>> 8;
	                            if (M)if (aa >>> 0 > 16777215)Ha = 31; else {
	                                Z = (M + 1048320 | 0) >>> 16 & 8;
	                                N = M << Z;
	                                M = (N + 520192 | 0) >>> 16 & 4;
	                                $ = N << M;
	                                N = ($ + 245760 | 0) >>> 16 & 2;
	                                V = 14 - (M | Z | N) + ($ << N >>> 15) | 0;
	                                Ha = aa >>> (V + 7 | 0) & 1 | V << 1
	                            } else Ha = 0;
	                            V = 328560 + (Ha << 2) | 0;
	                            c[ga + 28 >> 2] = Ha;
	                            c[ga + 20 >> 2] = 0;
	                            c[ga + 16 >> 2] = 0;
	                            N = c[82065] | 0;
	                            $ = 1 << Ha;
	                            if (!(N & $)) {
	                                c[82065] = N | $;
	                                c[V >> 2] = ga;
	                                c[ga + 24 >> 2] = V;
	                                c[ga + 12 >> 2] = ga;
	                                c[ga + 8 >> 2] = ga;
	                                break
	                            }
	                            $ = c[V >> 2] | 0;
	                            if ((Ha | 0) == 31)Ia = 0; else Ia = 25 - (Ha >>> 1) | 0;
	                            k:do if ((c[$ + 4 >> 2] & -8 | 0) != (aa | 0)) {
	                                V = aa << Ia;
	                                N = $;
	                                while (1) {
	                                    Ja = N + (V >>> 31 << 2) + 16 | 0;
	                                    Z = c[Ja >> 2] | 0;
	                                    if (!Z)break;
	                                    if ((c[Z + 4 >> 2] & -8 | 0) == (aa | 0)) {
	                                        Ka = Z;
	                                        break k
	                                    } else {
	                                        V = V << 1;
	                                        N = Z
	                                    }
	                                }
	                                if (Ja >>> 0 < (c[82068] | 0) >>> 0)hb(); else {
	                                    c[Ja >> 2] = ga;
	                                    c[ga + 24 >> 2] = N;
	                                    c[ga + 12 >> 2] = ga;
	                                    c[ga + 8 >> 2] = ga;
	                                    break g
	                                }
	                            } else Ka = $; while (0);
	                            $ = Ka + 8 | 0;
	                            aa = c[$ >> 2] | 0;
	                            ba = c[82068] | 0;
	                            if (Ka >>> 0 >= ba >>> 0 & aa >>> 0 >= ba >>> 0) {
	                                c[aa + 12 >> 2] = ga;
	                                c[$ >> 2] = ga;
	                                c[ga + 8 >> 2] = aa;
	                                c[ga + 12 >> 2] = Ka;
	                                c[ga + 24 >> 2] = 0;
	                                break
	                            } else hb()
	                        }
	                    } else {
	                        aa = c[82068] | 0;
	                        if ((aa | 0) == 0 | da >>> 0 < aa >>> 0)c[82068] = da;
	                        c[82176] = da;
	                        c[82177] = ea;
	                        c[82179] = 0;
	                        c[82073] = c[82182];
	                        c[82072] = -1;
	                        aa = 0;
	                        do {
	                            $ = aa << 1;
	                            ba = 328296 + ($ << 2) | 0;
	                            c[328296 + ($ + 3 << 2) >> 2] = ba;
	                            c[328296 + ($ + 2 << 2) >> 2] = ba;
	                            aa = aa + 1 | 0
	                        } while ((aa | 0) != 32);
	                        aa = da + 8 | 0;
	                        if (!(aa & 7))La = 0; else La = 0 - aa & 7;
	                        aa = ea + -40 - La | 0;
	                        c[82070] = da + La;
	                        c[82067] = aa;
	                        c[da + (La + 4) >> 2] = aa | 1;
	                        c[da + (ea + -36) >> 2] = 40;
	                        c[82071] = c[82186]
	                    } while (0);
	                    ea = c[82067] | 0;
	                    if (ea >>> 0 > D >>> 0) {
	                        da = ea - D | 0;
	                        c[82067] = da;
	                        ea = c[82070] | 0;
	                        c[82070] = ea + D;
	                        c[ea + (D + 4) >> 2] = da | 1;
	                        c[ea + 4 >> 2] = D | 3;
	                        p = ea + 8 | 0;
	                        i = b;
	                        return p | 0
	                    }
	                }
	                c[(_a() | 0) >> 2] = 12;
	                p = 0;
	                i = b;
	                return p | 0
	            }

	            function jT(a) {
	                a = a | 0;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0, I = 0, J = 0, K = 0;
	                b = i;
	                if (!a) {
	                    i = b;
	                    return
	                }
	                d = a + -8 | 0;
	                e = c[82068] | 0;
	                if (d >>> 0 < e >>> 0)hb();
	                f = c[a + -4 >> 2] | 0;
	                g = f & 3;
	                if ((g | 0) == 1)hb();
	                h = f & -8;
	                j = a + (h + -8) | 0;
	                do if (!(f & 1)) {
	                    k = c[d >> 2] | 0;
	                    if (!g) {
	                        i = b;
	                        return
	                    }
	                    l = -8 - k | 0;
	                    m = a + l | 0;
	                    n = k + h | 0;
	                    if (m >>> 0 < e >>> 0)hb();
	                    if ((m | 0) == (c[82069] | 0)) {
	                        o = a + (h + -4) | 0;
	                        p = c[o >> 2] | 0;
	                        if ((p & 3 | 0) != 3) {
	                            q = m;
	                            r = n;
	                            break
	                        }
	                        c[82066] = n;
	                        c[o >> 2] = p & -2;
	                        c[a + (l + 4) >> 2] = n | 1;
	                        c[j >> 2] = n;
	                        i = b;
	                        return
	                    }
	                    p = k >>> 3;
	                    if (k >>> 0 < 256) {
	                        k = c[a + (l + 8) >> 2] | 0;
	                        o = c[a + (l + 12) >> 2] | 0;
	                        s = 328296 + (p << 1 << 2) | 0;
	                        if ((k | 0) != (s | 0)) {
	                            if (k >>> 0 < e >>> 0)hb();
	                            if ((c[k + 12 >> 2] | 0) != (m | 0))hb()
	                        }
	                        if ((o | 0) == (k | 0)) {
	                            c[82064] = c[82064] & ~(1 << p);
	                            q = m;
	                            r = n;
	                            break
	                        }
	                        if ((o | 0) != (s | 0)) {
	                            if (o >>> 0 < e >>> 0)hb();
	                            s = o + 8 | 0;
	                            if ((c[s >> 2] | 0) == (m | 0))t = s; else hb()
	                        } else t = o + 8 | 0;
	                        c[k + 12 >> 2] = o;
	                        c[t >> 2] = k;
	                        q = m;
	                        r = n;
	                        break
	                    }
	                    k = c[a + (l + 24) >> 2] | 0;
	                    o = c[a + (l + 12) >> 2] | 0;
	                    do if ((o | 0) == (m | 0)) {
	                        s = a + (l + 20) | 0;
	                        p = c[s >> 2] | 0;
	                        if (!p) {
	                            u = a + (l + 16) | 0;
	                            v = c[u >> 2] | 0;
	                            if (!v) {
	                                w = 0;
	                                break
	                            } else {
	                                x = v;
	                                y = u
	                            }
	                        } else {
	                            x = p;
	                            y = s
	                        }
	                        while (1) {
	                            s = x + 20 | 0;
	                            p = c[s >> 2] | 0;
	                            if (p) {
	                                x = p;
	                                y = s;
	                                continue
	                            }
	                            s = x + 16 | 0;
	                            p = c[s >> 2] | 0;
	                            if (!p)break; else {
	                                x = p;
	                                y = s
	                            }
	                        }
	                        if (y >>> 0 < e >>> 0)hb(); else {
	                            c[y >> 2] = 0;
	                            w = x;
	                            break
	                        }
	                    } else {
	                        s = c[a + (l + 8) >> 2] | 0;
	                        if (s >>> 0 < e >>> 0)hb();
	                        p = s + 12 | 0;
	                        if ((c[p >> 2] | 0) != (m | 0))hb();
	                        u = o + 8 | 0;
	                        if ((c[u >> 2] | 0) == (m | 0)) {
	                            c[p >> 2] = o;
	                            c[u >> 2] = s;
	                            w = o;
	                            break
	                        } else hb()
	                    } while (0);
	                    if (k) {
	                        o = c[a + (l + 28) >> 2] | 0;
	                        s = 328560 + (o << 2) | 0;
	                        if ((m | 0) == (c[s >> 2] | 0)) {
	                            c[s >> 2] = w;
	                            if (!w) {
	                                c[82065] = c[82065] & ~(1 << o);
	                                q = m;
	                                r = n;
	                                break
	                            }
	                        } else {
	                            if (k >>> 0 < (c[82068] | 0) >>> 0)hb();
	                            o = k + 16 | 0;
	                            if ((c[o >> 2] | 0) == (m | 0))c[o >> 2] = w; else c[k + 20 >> 2] = w;
	                            if (!w) {
	                                q = m;
	                                r = n;
	                                break
	                            }
	                        }
	                        o = c[82068] | 0;
	                        if (w >>> 0 < o >>> 0)hb();
	                        c[w + 24 >> 2] = k;
	                        s = c[a + (l + 16) >> 2] | 0;
	                        do if (s)if (s >>> 0 < o >>> 0)hb(); else {
	                            c[w + 16 >> 2] = s;
	                            c[s + 24 >> 2] = w;
	                            break
	                        } while (0);
	                        s = c[a + (l + 20) >> 2] | 0;
	                        if (s)if (s >>> 0 < (c[82068] | 0) >>> 0)hb(); else {
	                            c[w + 20 >> 2] = s;
	                            c[s + 24 >> 2] = w;
	                            q = m;
	                            r = n;
	                            break
	                        } else {
	                            q = m;
	                            r = n
	                        }
	                    } else {
	                        q = m;
	                        r = n
	                    }
	                } else {
	                    q = d;
	                    r = h
	                } while (0);
	                if (q >>> 0 >= j >>> 0)hb();
	                d = a + (h + -4) | 0;
	                w = c[d >> 2] | 0;
	                if (!(w & 1))hb();
	                if (!(w & 2)) {
	                    if ((j | 0) == (c[82070] | 0)) {
	                        e = (c[82067] | 0) + r | 0;
	                        c[82067] = e;
	                        c[82070] = q;
	                        c[q + 4 >> 2] = e | 1;
	                        if ((q | 0) != (c[82069] | 0)) {
	                            i = b;
	                            return
	                        }
	                        c[82069] = 0;
	                        c[82066] = 0;
	                        i = b;
	                        return
	                    }
	                    if ((j | 0) == (c[82069] | 0)) {
	                        e = (c[82066] | 0) + r | 0;
	                        c[82066] = e;
	                        c[82069] = q;
	                        c[q + 4 >> 2] = e | 1;
	                        c[q + e >> 2] = e;
	                        i = b;
	                        return
	                    }
	                    e = (w & -8) + r | 0;
	                    x = w >>> 3;
	                    do if (w >>> 0 >= 256) {
	                        y = c[a + (h + 16) >> 2] | 0;
	                        t = c[a + (h | 4) >> 2] | 0;
	                        do if ((t | 0) == (j | 0)) {
	                            g = a + (h + 12) | 0;
	                            f = c[g >> 2] | 0;
	                            if (!f) {
	                                s = a + (h + 8) | 0;
	                                o = c[s >> 2] | 0;
	                                if (!o) {
	                                    z = 0;
	                                    break
	                                } else {
	                                    A = o;
	                                    B = s
	                                }
	                            } else {
	                                A = f;
	                                B = g
	                            }
	                            while (1) {
	                                g = A + 20 | 0;
	                                f = c[g >> 2] | 0;
	                                if (f) {
	                                    A = f;
	                                    B = g;
	                                    continue
	                                }
	                                g = A + 16 | 0;
	                                f = c[g >> 2] | 0;
	                                if (!f)break; else {
	                                    A = f;
	                                    B = g
	                                }
	                            }
	                            if (B >>> 0 < (c[82068] | 0) >>> 0)hb(); else {
	                                c[B >> 2] = 0;
	                                z = A;
	                                break
	                            }
	                        } else {
	                            g = c[a + h >> 2] | 0;
	                            if (g >>> 0 < (c[82068] | 0) >>> 0)hb();
	                            f = g + 12 | 0;
	                            if ((c[f >> 2] | 0) != (j | 0))hb();
	                            s = t + 8 | 0;
	                            if ((c[s >> 2] | 0) == (j | 0)) {
	                                c[f >> 2] = t;
	                                c[s >> 2] = g;
	                                z = t;
	                                break
	                            } else hb()
	                        } while (0);
	                        if (y) {
	                            t = c[a + (h + 20) >> 2] | 0;
	                            n = 328560 + (t << 2) | 0;
	                            if ((j | 0) == (c[n >> 2] | 0)) {
	                                c[n >> 2] = z;
	                                if (!z) {
	                                    c[82065] = c[82065] & ~(1 << t);
	                                    break
	                                }
	                            } else {
	                                if (y >>> 0 < (c[82068] | 0) >>> 0)hb();
	                                t = y + 16 | 0;
	                                if ((c[t >> 2] | 0) == (j | 0))c[t >> 2] = z; else c[y + 20 >> 2] = z;
	                                if (!z)break
	                            }
	                            t = c[82068] | 0;
	                            if (z >>> 0 < t >>> 0)hb();
	                            c[z + 24 >> 2] = y;
	                            n = c[a + (h + 8) >> 2] | 0;
	                            do if (n)if (n >>> 0 < t >>> 0)hb(); else {
	                                c[z + 16 >> 2] = n;
	                                c[n + 24 >> 2] = z;
	                                break
	                            } while (0);
	                            n = c[a + (h + 12) >> 2] | 0;
	                            if (n)if (n >>> 0 < (c[82068] | 0) >>> 0)hb(); else {
	                                c[z + 20 >> 2] = n;
	                                c[n + 24 >> 2] = z;
	                                break
	                            }
	                        }
	                    } else {
	                        n = c[a + h >> 2] | 0;
	                        t = c[a + (h | 4) >> 2] | 0;
	                        y = 328296 + (x << 1 << 2) | 0;
	                        if ((n | 0) != (y | 0)) {
	                            if (n >>> 0 < (c[82068] | 0) >>> 0)hb();
	                            if ((c[n + 12 >> 2] | 0) != (j | 0))hb()
	                        }
	                        if ((t | 0) == (n | 0)) {
	                            c[82064] = c[82064] & ~(1 << x);
	                            break
	                        }
	                        if ((t | 0) != (y | 0)) {
	                            if (t >>> 0 < (c[82068] | 0) >>> 0)hb();
	                            y = t + 8 | 0;
	                            if ((c[y >> 2] | 0) == (j | 0))C = y; else hb()
	                        } else C = t + 8 | 0;
	                        c[n + 12 >> 2] = t;
	                        c[C >> 2] = n
	                    } while (0);
	                    c[q + 4 >> 2] = e | 1;
	                    c[q + e >> 2] = e;
	                    if ((q | 0) == (c[82069] | 0)) {
	                        c[82066] = e;
	                        i = b;
	                        return
	                    } else D = e
	                } else {
	                    c[d >> 2] = w & -2;
	                    c[q + 4 >> 2] = r | 1;
	                    c[q + r >> 2] = r;
	                    D = r
	                }
	                r = D >>> 3;
	                if (D >>> 0 < 256) {
	                    w = r << 1;
	                    d = 328296 + (w << 2) | 0;
	                    e = c[82064] | 0;
	                    C = 1 << r;
	                    if (e & C) {
	                        r = 328296 + (w + 2 << 2) | 0;
	                        j = c[r >> 2] | 0;
	                        if (j >>> 0 < (c[82068] | 0) >>> 0)hb(); else {
	                            E = r;
	                            F = j
	                        }
	                    } else {
	                        c[82064] = e | C;
	                        E = 328296 + (w + 2 << 2) | 0;
	                        F = d
	                    }
	                    c[E >> 2] = q;
	                    c[F + 12 >> 2] = q;
	                    c[q + 8 >> 2] = F;
	                    c[q + 12 >> 2] = d;
	                    i = b;
	                    return
	                }
	                d = D >>> 8;
	                if (d)if (D >>> 0 > 16777215)G = 31; else {
	                    F = (d + 1048320 | 0) >>> 16 & 8;
	                    E = d << F;
	                    d = (E + 520192 | 0) >>> 16 & 4;
	                    w = E << d;
	                    E = (w + 245760 | 0) >>> 16 & 2;
	                    C = 14 - (d | F | E) + (w << E >>> 15) | 0;
	                    G = D >>> (C + 7 | 0) & 1 | C << 1
	                } else G = 0;
	                C = 328560 + (G << 2) | 0;
	                c[q + 28 >> 2] = G;
	                c[q + 20 >> 2] = 0;
	                c[q + 16 >> 2] = 0;
	                E = c[82065] | 0;
	                w = 1 << G;
	                a:do if (E & w) {
	                    F = c[C >> 2] | 0;
	                    if ((G | 0) == 31)H = 0; else H = 25 - (G >>> 1) | 0;
	                    b:do if ((c[F + 4 >> 2] & -8 | 0) != (D | 0)) {
	                        d = D << H;
	                        e = F;
	                        while (1) {
	                            I = e + (d >>> 31 << 2) + 16 | 0;
	                            j = c[I >> 2] | 0;
	                            if (!j)break;
	                            if ((c[j + 4 >> 2] & -8 | 0) == (D | 0)) {
	                                J = j;
	                                break b
	                            } else {
	                                d = d << 1;
	                                e = j
	                            }
	                        }
	                        if (I >>> 0 < (c[82068] | 0) >>> 0)hb(); else {
	                            c[I >> 2] = q;
	                            c[q + 24 >> 2] = e;
	                            c[q + 12 >> 2] = q;
	                            c[q + 8 >> 2] = q;
	                            break a
	                        }
	                    } else J = F; while (0);
	                    F = J + 8 | 0;
	                    d = c[F >> 2] | 0;
	                    j = c[82068] | 0;
	                    if (J >>> 0 >= j >>> 0 & d >>> 0 >= j >>> 0) {
	                        c[d + 12 >> 2] = q;
	                        c[F >> 2] = q;
	                        c[q + 8 >> 2] = d;
	                        c[q + 12 >> 2] = J;
	                        c[q + 24 >> 2] = 0;
	                        break
	                    } else hb()
	                } else {
	                    c[82065] = E | w;
	                    c[C >> 2] = q;
	                    c[q + 24 >> 2] = C;
	                    c[q + 12 >> 2] = q;
	                    c[q + 8 >> 2] = q
	                } while (0);
	                q = (c[82072] | 0) + -1 | 0;
	                c[82072] = q;
	                if (!q)K = 328712 | 0; else {
	                    i = b;
	                    return
	                }
	                while (1) {
	                    q = c[K >> 2] | 0;
	                    if (!q)break; else K = q + 8 | 0
	                }
	                c[82072] = -1;
	                i = b;
	                return
	            }

	            function kT(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0;
	                d = i;
	                do if (a) {
	                    if (b >>> 0 > 4294967231) {
	                        c[(_a() | 0) >> 2] = 12;
	                        e = 0;
	                        break
	                    }
	                    if (b >>> 0 < 11)f = 16; else f = b + 11 & -8;
	                    g = ST(a + -8 | 0, f) | 0;
	                    if (g) {
	                        e = g + 8 | 0;
	                        break
	                    }
	                    g = iT(b) | 0;
	                    if (!g)e = 0; else {
	                        h = c[a + -4 >> 2] | 0;
	                        j = (h & -8) - ((h & 3 | 0) == 0 ? 8 : 4) | 0;
	                        eU(g | 0, a | 0, (j >>> 0 < b >>> 0 ? j : b) | 0) | 0;
	                        jT(a);
	                        e = g
	                    }
	                } else e = iT(b) | 0; while (0);
	                i = d;
	                return e | 0
	            }

	            function lT(a) {
	                a = a | 0;
	                return (a + -48 | 0) >>> 0 < 10 | 0
	            }

	            function mT(a) {
	                a = a | 0;
	                var b = 0;
	                if ((a | 0) == 32)b = 1; else b = (a + -9 | 0) >>> 0 < 5;
	                return b & 1 | 0
	            }

	            function nT(b, e, f, g, h) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                var j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, H = 0, I = 0, J = 0, K = 0, L = 0, M = 0, N = 0, O = 0, P = 0, Q = 0, R = 0, S = 0, T = 0, U = 0, V = 0, W = 0, X = 0, Y = 0, Z = 0, _ = 0, $ = 0, aa = 0, ba = 0, da = 0, ea = 0, fa = 0, ga = 0;
	                j = i;
	                if (e >>> 0 > 36) {
	                    c[(_a() | 0) >> 2] = 22;
	                    k = 0;
	                    l = 0;
	                    G = k;
	                    i = j;
	                    return l | 0
	                }
	                m = b + 4 | 0;
	                n = b + 100 | 0;
	                do {
	                    o = c[m >> 2] | 0;
	                    if (o >>> 0 < (c[n >> 2] | 0) >>> 0) {
	                        c[m >> 2] = o + 1;
	                        p = d[o >> 0] | 0
	                    } else p = qT(b) | 0
	                } while ((mT(p) | 0) != 0);
	                do if ((p | 0) == 43 | (p | 0) == 45) {
	                    o = ((p | 0) == 45) << 31 >> 31;
	                    q = c[m >> 2] | 0;
	                    if (q >>> 0 < (c[n >> 2] | 0) >>> 0) {
	                        c[m >> 2] = q + 1;
	                        r = d[q >> 0] | 0;
	                        s = o;
	                        break
	                    } else {
	                        r = qT(b) | 0;
	                        s = o;
	                        break
	                    }
	                } else {
	                    r = p;
	                    s = 0
	                } while (0);
	                p = (e | 0) == 0;
	                do if ((e & -17 | 0) == 0 & (r | 0) == 48) {
	                    o = c[m >> 2] | 0;
	                    if (o >>> 0 < (c[n >> 2] | 0) >>> 0) {
	                        c[m >> 2] = o + 1;
	                        t = d[o >> 0] | 0
	                    } else t = qT(b) | 0;
	                    if ((t | 32 | 0) != 120)if (p) {
	                        u = 8;
	                        v = t;
	                        w = 46;
	                        break
	                    } else {
	                        x = e;
	                        y = t;
	                        w = 32;
	                        break
	                    }
	                    o = c[m >> 2] | 0;
	                    if (o >>> 0 < (c[n >> 2] | 0) >>> 0) {
	                        c[m >> 2] = o + 1;
	                        z = d[o >> 0] | 0
	                    } else z = qT(b) | 0;
	                    if ((d[z + 328753 >> 0] | 0) > 15) {
	                        o = (c[n >> 2] | 0) == 0;
	                        if (!o)c[m >> 2] = (c[m >> 2] | 0) + -1;
	                        if (!f) {
	                            pT(b, 0);
	                            k = 0;
	                            l = 0;
	                            G = k;
	                            i = j;
	                            return l | 0
	                        }
	                        if (o) {
	                            k = 0;
	                            l = 0;
	                            G = k;
	                            i = j;
	                            return l | 0
	                        }
	                        c[m >> 2] = (c[m >> 2] | 0) + -1;
	                        k = 0;
	                        l = 0;
	                        G = k;
	                        i = j;
	                        return l | 0
	                    } else {
	                        u = 16;
	                        v = z;
	                        w = 46
	                    }
	                } else {
	                    o = p ? 10 : e;
	                    if ((d[r + 328753 >> 0] | 0) >>> 0 < o >>> 0) {
	                        x = o;
	                        y = r;
	                        w = 32
	                    } else {
	                        if (c[n >> 2] | 0)c[m >> 2] = (c[m >> 2] | 0) + -1;
	                        pT(b, 0);
	                        c[(_a() | 0) >> 2] = 22;
	                        k = 0;
	                        l = 0;
	                        G = k;
	                        i = j;
	                        return l | 0
	                    }
	                } while (0);
	                if ((w | 0) == 32)if ((x | 0) == 10) {
	                    r = y + -48 | 0;
	                    if (r >>> 0 < 10) {
	                        e = r;
	                        r = 0;
	                        do {
	                            r = (r * 10 | 0) + e | 0;
	                            p = c[m >> 2] | 0;
	                            if (p >>> 0 < (c[n >> 2] | 0) >>> 0) {
	                                c[m >> 2] = p + 1;
	                                A = d[p >> 0] | 0
	                            } else A = qT(b) | 0;
	                            e = A + -48 | 0
	                        } while (e >>> 0 < 10 & r >>> 0 < 429496729);
	                        B = r;
	                        C = 0;
	                        D = A
	                    } else {
	                        B = 0;
	                        C = 0;
	                        D = y
	                    }
	                    A = D + -48 | 0;
	                    if (A >>> 0 < 10) {
	                        r = B;
	                        e = C;
	                        p = A;
	                        A = D;
	                        while (1) {
	                            D = mU(r | 0, e | 0, 10, 0) | 0;
	                            z = G;
	                            f = ((p | 0) < 0) << 31 >> 31;
	                            t = ~f;
	                            if (z >>> 0 > t >>> 0 | (z | 0) == (t | 0) & D >>> 0 > ~p >>> 0) {
	                                E = p;
	                                F = r;
	                                H = e;
	                                I = A;
	                                break
	                            }
	                            t = bU(D | 0, z | 0, p | 0, f | 0) | 0;
	                            f = G;
	                            z = c[m >> 2] | 0;
	                            if (z >>> 0 < (c[n >> 2] | 0) >>> 0) {
	                                c[m >> 2] = z + 1;
	                                J = d[z >> 0] | 0
	                            } else J = qT(b) | 0;
	                            z = J + -48 | 0;
	                            if (z >>> 0 < 10 & (f >>> 0 < 429496729 | (f | 0) == 429496729 & t >>> 0 < 2576980378)) {
	                                r = t;
	                                e = f;
	                                p = z;
	                                A = J
	                            } else {
	                                E = z;
	                                F = t;
	                                H = f;
	                                I = J;
	                                break
	                            }
	                        }
	                        if (E >>> 0 > 9) {
	                            K = H;
	                            L = F
	                        } else {
	                            M = 10;
	                            N = F;
	                            O = H;
	                            P = I;
	                            w = 72
	                        }
	                    } else {
	                        K = C;
	                        L = B
	                    }
	                } else {
	                    u = x;
	                    v = y;
	                    w = 46
	                }
	                a:do if ((w | 0) == 46) {
	                    if (!(u + -1 & u)) {
	                        y = a[329016 + ((u * 23 | 0) >>> 5 & 7) >> 0] | 0;
	                        x = a[v + 328753 >> 0] | 0;
	                        B = x & 255;
	                        if (B >>> 0 < u >>> 0) {
	                            C = B;
	                            B = 0;
	                            do {
	                                B = C | B << y;
	                                I = c[m >> 2] | 0;
	                                if (I >>> 0 < (c[n >> 2] | 0) >>> 0) {
	                                    c[m >> 2] = I + 1;
	                                    Q = d[I >> 0] | 0
	                                } else Q = qT(b) | 0;
	                                R = a[Q + 328753 >> 0] | 0;
	                                C = R & 255
	                            } while (C >>> 0 < u >>> 0 & B >>> 0 < 134217728);
	                            S = R;
	                            T = 0;
	                            U = B;
	                            V = Q
	                        } else {
	                            S = x;
	                            T = 0;
	                            U = 0;
	                            V = v
	                        }
	                        C = dU(-1, -1, y | 0) | 0;
	                        I = G;
	                        if ((S & 255) >>> 0 >= u >>> 0 | (T >>> 0 > I >>> 0 | (T | 0) == (I | 0) & U >>> 0 > C >>> 0)) {
	                            M = u;
	                            N = U;
	                            O = T;
	                            P = V;
	                            w = 72;
	                            break
	                        } else {
	                            W = U;
	                            X = T;
	                            Y = S
	                        }
	                        while (1) {
	                            H = $T(W | 0, X | 0, y | 0) | 0;
	                            F = G;
	                            E = Y & 255 | H;
	                            H = c[m >> 2] | 0;
	                            if (H >>> 0 < (c[n >> 2] | 0) >>> 0) {
	                                c[m >> 2] = H + 1;
	                                Z = d[H >> 0] | 0
	                            } else Z = qT(b) | 0;
	                            Y = a[Z + 328753 >> 0] | 0;
	                            if ((Y & 255) >>> 0 >= u >>> 0 | (F >>> 0 > I >>> 0 | (F | 0) == (I | 0) & E >>> 0 > C >>> 0)) {
	                                M = u;
	                                N = E;
	                                O = F;
	                                P = Z;
	                                w = 72;
	                                break a
	                            } else {
	                                W = E;
	                                X = F
	                            }
	                        }
	                    }
	                    C = a[v + 328753 >> 0] | 0;
	                    I = C & 255;
	                    if (I >>> 0 < u >>> 0) {
	                        y = I;
	                        I = 0;
	                        do {
	                            I = y + (ca(I, u) | 0) | 0;
	                            x = c[m >> 2] | 0;
	                            if (x >>> 0 < (c[n >> 2] | 0) >>> 0) {
	                                c[m >> 2] = x + 1;
	                                _ = d[x >> 0] | 0
	                            } else _ = qT(b) | 0;
	                            $ = a[_ + 328753 >> 0] | 0;
	                            y = $ & 255
	                        } while (y >>> 0 < u >>> 0 & I >>> 0 < 119304647);
	                        aa = $;
	                        ba = I;
	                        da = 0;
	                        ea = _
	                    } else {
	                        aa = C;
	                        ba = 0;
	                        da = 0;
	                        ea = v
	                    }
	                    if ((aa & 255) >>> 0 < u >>> 0) {
	                        y = nU(-1, -1, u | 0, 0) | 0;
	                        x = G;
	                        B = da;
	                        F = ba;
	                        E = aa;
	                        H = ea;
	                        while (1) {
	                            if (B >>> 0 > x >>> 0 | (B | 0) == (x | 0) & F >>> 0 > y >>> 0) {
	                                M = u;
	                                N = F;
	                                O = B;
	                                P = H;
	                                w = 72;
	                                break a
	                            }
	                            J = mU(F | 0, B | 0, u | 0, 0) | 0;
	                            A = G;
	                            p = E & 255;
	                            if (A >>> 0 > 4294967295 | (A | 0) == -1 & J >>> 0 > ~p >>> 0) {
	                                M = u;
	                                N = F;
	                                O = B;
	                                P = H;
	                                w = 72;
	                                break a
	                            }
	                            e = bU(p | 0, 0, J | 0, A | 0) | 0;
	                            A = G;
	                            J = c[m >> 2] | 0;
	                            if (J >>> 0 < (c[n >> 2] | 0) >>> 0) {
	                                c[m >> 2] = J + 1;
	                                fa = d[J >> 0] | 0
	                            } else fa = qT(b) | 0;
	                            E = a[fa + 328753 >> 0] | 0;
	                            if ((E & 255) >>> 0 >= u >>> 0) {
	                                M = u;
	                                N = e;
	                                O = A;
	                                P = fa;
	                                w = 72;
	                                break
	                            } else {
	                                B = A;
	                                F = e;
	                                H = fa
	                            }
	                        }
	                    } else {
	                        M = u;
	                        N = ba;
	                        O = da;
	                        P = ea;
	                        w = 72
	                    }
	                } while (0);
	                if ((w | 0) == 72)if ((d[P + 328753 >> 0] | 0) >>> 0 < M >>> 0) {
	                    do {
	                        P = c[m >> 2] | 0;
	                        if (P >>> 0 < (c[n >> 2] | 0) >>> 0) {
	                            c[m >> 2] = P + 1;
	                            ga = d[P >> 0] | 0
	                        } else ga = qT(b) | 0
	                    } while ((d[ga + 328753 >> 0] | 0) >>> 0 < M >>> 0);
	                    c[(_a() | 0) >> 2] = 34;
	                    K = h;
	                    L = g
	                } else {
	                    K = O;
	                    L = N
	                }
	                if (c[n >> 2] | 0)c[m >> 2] = (c[m >> 2] | 0) + -1;
	                if (!(K >>> 0 < h >>> 0 | (K | 0) == (h | 0) & L >>> 0 < g >>> 0)) {
	                    if (!((g & 1 | 0) != 0 | 0 != 0 | (s | 0) != 0)) {
	                        c[(_a() | 0) >> 2] = 34;
	                        m = bU(g | 0, h | 0, -1, -1) | 0;
	                        k = G;
	                        l = m;
	                        G = k;
	                        i = j;
	                        return l | 0
	                    }
	                    if (K >>> 0 > h >>> 0 | (K | 0) == (h | 0) & L >>> 0 > g >>> 0) {
	                        c[(_a() | 0) >> 2] = 34;
	                        k = h;
	                        l = g;
	                        G = k;
	                        i = j;
	                        return l | 0
	                    }
	                }
	                g = ((s | 0) < 0) << 31 >> 31;
	                h = XT(L ^ s | 0, K ^ g | 0, s | 0, g | 0) | 0;
	                k = G;
	                l = h;
	                G = k;
	                i = j;
	                return l | 0
	            }

	            function oT(b, e, f) {
	                b = b | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0.0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, H = 0, I = 0, J = 0, K = 0, L = 0, M = 0, N = 0, O = 0, P = 0, Q = 0, S = 0, T = 0.0, U = 0, V = 0.0, W = 0, X = 0, Y = 0, Z = 0, _ = 0, $ = 0, aa = 0, ba = 0, da = 0, ea = 0, fa = 0.0, ga = 0, ha = 0.0, ia = 0, ja = 0.0, ka = 0, la = 0.0, ma = 0, na = 0.0, oa = 0, pa = 0, qa = 0, ra = 0, sa = 0, ta = 0, ua = 0.0, va = 0, wa = 0.0, xa = 0, ya = 0, za = 0, Aa = 0, Ba = 0.0, Ca = 0, Da = 0, Ea = 0, Fa = 0.0, Ga = 0.0, Ha = 0, Ia = 0, Ja = 0, Ka = 0, La = 0, Ma = 0, Na = 0, Oa = 0, Pa = 0, Qa = 0, Ra = 0, Sa = 0, Ta = 0, Ua = 0, Va = 0, Wa = 0, Xa = 0, Ya = 0, Za = 0, $a = 0, ab = 0, bb = 0, cb = 0, db = 0, eb = 0, fb = 0, gb = 0, hb = 0, ib = 0, jb = 0, kb = 0, lb = 0, mb = 0, nb = 0, ob = 0, pb = 0, qb = 0, rb = 0, sb = 0, tb = 0, ub = 0, vb = 0, wb = 0, xb = 0, yb = 0, zb = 0, Ab = 0, Bb = 0, Cb = 0, Db = 0, Eb = 0, Fb = 0, Gb = 0, Hb = 0, Ib = 0, Jb = 0, Kb = 0, Lb = 0, Mb = 0, Nb = 0, Ob = 0, Pb = 0, Qb = 0, Rb = 0, Sb = 0, Tb = 0, Ub = 0, Vb = 0, Wb = 0, Xb = 0, Yb = 0, Zb = 0, _b = 0, $b = 0, ac = 0, bc = 0, cc = 0, dc = 0, ec = 0, fc = 0, gc = 0, hc = 0, ic = 0, jc = 0, kc = 0, lc = 0, mc = 0, nc = 0, oc = 0, pc = 0, qc = 0, rc = 0, sc = 0, tc = 0, uc = 0, vc = 0, wc = 0, xc = 0, yc = 0, zc = 0, Ac = 0, Bc = 0, Cc = 0, Dc = 0, Ec = 0, Fc = 0.0, Gc = 0, Hc = 0, Ic = 0, Jc = 0, Kc = 0, Lc = 0.0, Mc = 0, Nc = 0.0, Oc = 0.0, Pc = 0.0, Qc = 0.0, Rc = 0.0, Sc = 0, Tc = 0, Uc = 0.0, Vc = 0, Wc = 0.0;
	                g = i;
	                i = i + 512 | 0;
	                h = g;
	                if (!e) {
	                    j = 24;
	                    k = -149
	                } else if ((e | 0) == 1) {
	                    j = 53;
	                    k = -1074
	                } else if ((e | 0) == 2) {
	                    j = 53;
	                    k = -1074
	                } else {
	                    l = 0.0;
	                    i = g;
	                    return +l
	                }
	                e = b + 4 | 0;
	                m = b + 100 | 0;
	                do {
	                    n = c[e >> 2] | 0;
	                    if (n >>> 0 < (c[m >> 2] | 0) >>> 0) {
	                        c[e >> 2] = n + 1;
	                        o = d[n >> 0] | 0
	                    } else o = qT(b) | 0
	                } while ((mT(o) | 0) != 0);
	                do if ((o | 0) == 43 | (o | 0) == 45) {
	                    n = 1 - (((o | 0) == 45 & 1) << 1) | 0;
	                    p = c[e >> 2] | 0;
	                    if (p >>> 0 < (c[m >> 2] | 0) >>> 0) {
	                        c[e >> 2] = p + 1;
	                        q = d[p >> 0] | 0;
	                        r = n;
	                        break
	                    } else {
	                        q = qT(b) | 0;
	                        r = n;
	                        break
	                    }
	                } else {
	                    q = o;
	                    r = 1
	                } while (0);
	                o = q;
	                q = 0;
	                while (1) {
	                    if ((o | 32 | 0) != (a[329032 + q >> 0] | 0)) {
	                        s = o;
	                        t = q;
	                        break
	                    }
	                    do if (q >>> 0 < 7) {
	                        n = c[e >> 2] | 0;
	                        if (n >>> 0 < (c[m >> 2] | 0) >>> 0) {
	                            c[e >> 2] = n + 1;
	                            u = d[n >> 0] | 0;
	                            break
	                        } else {
	                            u = qT(b) | 0;
	                            break
	                        }
	                    } else u = o; while (0);
	                    n = q + 1 | 0;
	                    if (n >>> 0 < 8) {
	                        o = u;
	                        q = n
	                    } else {
	                        s = u;
	                        t = n;
	                        break
	                    }
	                }
	                do if ((t | 0) == 3)x = 23; else if ((t | 0) != 8) {
	                    u = (f | 0) != 0;
	                    if (t >>> 0 > 3 & u)if ((t | 0) == 8)break; else {
	                        x = 23;
	                        break
	                    }
	                    a:do if (!t) {
	                        q = s;
	                        o = 0;
	                        while (1) {
	                            if ((q | 32 | 0) != (a[329048 + o >> 0] | 0)) {
	                                y = q;
	                                z = o;
	                                break a
	                            }
	                            do if (o >>> 0 < 2) {
	                                n = c[e >> 2] | 0;
	                                if (n >>> 0 < (c[m >> 2] | 0) >>> 0) {
	                                    c[e >> 2] = n + 1;
	                                    A = d[n >> 0] | 0;
	                                    break
	                                } else {
	                                    A = qT(b) | 0;
	                                    break
	                                }
	                            } else A = q; while (0);
	                            n = o + 1 | 0;
	                            if (n >>> 0 < 3) {
	                                q = A;
	                                o = n
	                            } else {
	                                y = A;
	                                z = n;
	                                break
	                            }
	                        }
	                    } else {
	                        y = s;
	                        z = t
	                    } while (0);
	                    if ((z | 0) == 3) {
	                        o = c[e >> 2] | 0;
	                        if (o >>> 0 < (c[m >> 2] | 0) >>> 0) {
	                            c[e >> 2] = o + 1;
	                            B = d[o >> 0] | 0
	                        } else B = qT(b) | 0;
	                        if ((B | 0) == 40)C = 1; else {
	                            if (!(c[m >> 2] | 0)) {
	                                l = v;
	                                i = g;
	                                return +l
	                            }
	                            c[e >> 2] = (c[e >> 2] | 0) + -1;
	                            l = v;
	                            i = g;
	                            return +l
	                        }
	                        while (1) {
	                            o = c[e >> 2] | 0;
	                            if (o >>> 0 < (c[m >> 2] | 0) >>> 0) {
	                                c[e >> 2] = o + 1;
	                                D = d[o >> 0] | 0
	                            } else D = qT(b) | 0;
	                            if (!((D + -48 | 0) >>> 0 < 10 | (D + -65 | 0) >>> 0 < 26) ? !((D + -97 | 0) >>> 0 < 26 | (D | 0) == 95) : 0)break;
	                            C = C + 1 | 0
	                        }
	                        if ((D | 0) == 41) {
	                            l = v;
	                            i = g;
	                            return +l
	                        }
	                        o = (c[m >> 2] | 0) == 0;
	                        if (!o)c[e >> 2] = (c[e >> 2] | 0) + -1;
	                        if (!u) {
	                            c[(_a() | 0) >> 2] = 22;
	                            pT(b, 0);
	                            l = 0.0;
	                            i = g;
	                            return +l
	                        }
	                        if ((C | 0) == 0 | o) {
	                            l = v;
	                            i = g;
	                            return +l
	                        } else E = C;
	                        do {
	                            E = E + -1 | 0;
	                            c[e >> 2] = (c[e >> 2] | 0) + -1
	                        } while ((E | 0) != 0);
	                        l = v;
	                        i = g;
	                        return +l
	                    } else if (!z) {
	                        do if ((y | 0) == 48) {
	                            u = c[e >> 2] | 0;
	                            if (u >>> 0 < (c[m >> 2] | 0) >>> 0) {
	                                c[e >> 2] = u + 1;
	                                F = d[u >> 0] | 0
	                            } else F = qT(b) | 0;
	                            if ((F | 32 | 0) != 120) {
	                                if (!(c[m >> 2] | 0)) {
	                                    H = 48;
	                                    break
	                                }
	                                c[e >> 2] = (c[e >> 2] | 0) + -1;
	                                H = 48;
	                                break
	                            }
	                            u = c[e >> 2] | 0;
	                            if (u >>> 0 < (c[m >> 2] | 0) >>> 0) {
	                                c[e >> 2] = u + 1;
	                                I = d[u >> 0] | 0;
	                                J = 0
	                            } else {
	                                I = qT(b) | 0;
	                                J = 0
	                            }
	                            while (1) {
	                                if ((I | 0) == 46) {
	                                    x = 70;
	                                    break
	                                } else if ((I | 0) != 48) {
	                                    K = 0;
	                                    L = 0;
	                                    M = 0;
	                                    N = 0;
	                                    O = I;
	                                    P = J;
	                                    Q = 0;
	                                    S = 0;
	                                    T = 1.0;
	                                    U = 0;
	                                    V = 0.0;
	                                    break
	                                }
	                                u = c[e >> 2] | 0;
	                                if (u >>> 0 < (c[m >> 2] | 0) >>> 0) {
	                                    c[e >> 2] = u + 1;
	                                    I = d[u >> 0] | 0;
	                                    J = 1;
	                                    continue
	                                } else {
	                                    I = qT(b) | 0;
	                                    J = 1;
	                                    continue
	                                }
	                            }
	                            if ((x | 0) == 70) {
	                                u = c[e >> 2] | 0;
	                                if (u >>> 0 < (c[m >> 2] | 0) >>> 0) {
	                                    c[e >> 2] = u + 1;
	                                    W = d[u >> 0] | 0
	                                } else W = qT(b) | 0;
	                                if ((W | 0) == 48) {
	                                    u = 0;
	                                    o = 0;
	                                    while (1) {
	                                        q = c[e >> 2] | 0;
	                                        if (q >>> 0 < (c[m >> 2] | 0) >>> 0) {
	                                            c[e >> 2] = q + 1;
	                                            X = d[q >> 0] | 0
	                                        } else X = qT(b) | 0;
	                                        q = bU(u | 0, o | 0, -1, -1) | 0;
	                                        n = G;
	                                        if ((X | 0) == 48) {
	                                            u = q;
	                                            o = n
	                                        } else {
	                                            K = 0;
	                                            L = 0;
	                                            M = q;
	                                            N = n;
	                                            O = X;
	                                            P = 1;
	                                            Q = 1;
	                                            S = 0;
	                                            T = 1.0;
	                                            U = 0;
	                                            V = 0.0;
	                                            break
	                                        }
	                                    }
	                                } else {
	                                    K = 0;
	                                    L = 0;
	                                    M = 0;
	                                    N = 0;
	                                    O = W;
	                                    P = J;
	                                    Q = 1;
	                                    S = 0;
	                                    T = 1.0;
	                                    U = 0;
	                                    V = 0.0
	                                }
	                            }
	                            b:while (1) {
	                                o = O + -48 | 0;
	                                do if (o >>> 0 >= 10) {
	                                    u = O | 32;
	                                    n = (O | 0) == 46;
	                                    if (!((u + -97 | 0) >>> 0 < 6 | n)) {
	                                        Y = O;
	                                        break b
	                                    }
	                                    if (n)if (!Q) {
	                                        Z = L;
	                                        _ = K;
	                                        $ = L;
	                                        aa = K;
	                                        ba = P;
	                                        da = 1;
	                                        ea = S;
	                                        fa = T;
	                                        ga = U;
	                                        ha = V;
	                                        break
	                                    } else {
	                                        Y = 46;
	                                        break b
	                                    } else {
	                                        ia = (O | 0) > 57 ? u + -87 | 0 : o;
	                                        x = 83;
	                                        break
	                                    }
	                                } else {
	                                    ia = o;
	                                    x = 83
	                                } while (0);
	                                if ((x | 0) == 83) {
	                                    x = 0;
	                                    do if (!((K | 0) < 0 | (K | 0) == 0 & L >>> 0 < 8)) {
	                                        if ((K | 0) < 0 | (K | 0) == 0 & L >>> 0 < 14) {
	                                            ja = T * .0625;
	                                            ka = S;
	                                            la = ja;
	                                            ma = U;
	                                            na = V + ja * +(ia | 0);
	                                            break
	                                        }
	                                        if ((ia | 0) == 0 | (S | 0) != 0) {
	                                            ka = S;
	                                            la = T;
	                                            ma = U;
	                                            na = V
	                                        } else {
	                                            ka = 1;
	                                            la = T;
	                                            ma = U;
	                                            na = V + T * .5
	                                        }
	                                    } else {
	                                        ka = S;
	                                        la = T;
	                                        ma = ia + (U << 4) | 0;
	                                        na = V
	                                    } while (0);
	                                    o = bU(L | 0, K | 0, 1, 0) | 0;
	                                    Z = M;
	                                    _ = N;
	                                    $ = o;
	                                    aa = G;
	                                    ba = 1;
	                                    da = Q;
	                                    ea = ka;
	                                    fa = la;
	                                    ga = ma;
	                                    ha = na
	                                }
	                                o = c[e >> 2] | 0;
	                                if (o >>> 0 < (c[m >> 2] | 0) >>> 0) {
	                                    c[e >> 2] = o + 1;
	                                    K = aa;
	                                    L = $;
	                                    M = Z;
	                                    N = _;
	                                    O = d[o >> 0] | 0;
	                                    P = ba;
	                                    Q = da;
	                                    S = ea;
	                                    T = fa;
	                                    U = ga;
	                                    V = ha;
	                                    continue
	                                } else {
	                                    K = aa;
	                                    L = $;
	                                    M = Z;
	                                    N = _;
	                                    O = qT(b) | 0;
	                                    P = ba;
	                                    Q = da;
	                                    S = ea;
	                                    T = fa;
	                                    U = ga;
	                                    V = ha;
	                                    continue
	                                }
	                            }
	                            if (!P) {
	                                o = (c[m >> 2] | 0) == 0;
	                                if (!o)c[e >> 2] = (c[e >> 2] | 0) + -1;
	                                if (f) {
	                                    if (!o ? (o = c[e >> 2] | 0, c[e >> 2] = o + -1, (Q | 0) != 0) : 0)c[e >> 2] = o + -2
	                                } else pT(b, 0);
	                                l = +(r | 0) * 0.0;
	                                i = g;
	                                return +l
	                            }
	                            o = (Q | 0) == 0;
	                            u = o ? L : M;
	                            n = o ? K : N;
	                            if ((K | 0) < 0 | (K | 0) == 0 & L >>> 0 < 8) {
	                                o = L;
	                                q = K;
	                                p = U;
	                                while (1) {
	                                    oa = p << 4;
	                                    o = bU(o | 0, q | 0, 1, 0) | 0;
	                                    q = G;
	                                    if (!((q | 0) < 0 | (q | 0) == 0 & o >>> 0 < 8)) {
	                                        pa = oa;
	                                        break
	                                    } else p = oa
	                                }
	                            } else pa = U;
	                            do if ((Y | 32 | 0) == 112) {
	                                p = UT(b, f) | 0;
	                                o = G;
	                                if ((p | 0) == 0 & (o | 0) == -2147483648)if (!f) {
	                                    pT(b, 0);
	                                    l = 0.0;
	                                    i = g;
	                                    return +l
	                                } else {
	                                    if (!(c[m >> 2] | 0)) {
	                                        qa = 0;
	                                        ra = 0;
	                                        break
	                                    }
	                                    c[e >> 2] = (c[e >> 2] | 0) + -1;
	                                    qa = 0;
	                                    ra = 0;
	                                    break
	                                } else {
	                                    qa = p;
	                                    ra = o
	                                }
	                            } else if (!(c[m >> 2] | 0)) {
	                                qa = 0;
	                                ra = 0
	                            } else {
	                                c[e >> 2] = (c[e >> 2] | 0) + -1;
	                                qa = 0;
	                                ra = 0
	                            } while (0);
	                            o = $T(u | 0, n | 0, 2) | 0;
	                            p = bU(o | 0, G | 0, -32, -1) | 0;
	                            o = bU(p | 0, G | 0, qa | 0, ra | 0) | 0;
	                            p = G;
	                            if (!pa) {
	                                l = +(r | 0) * 0.0;
	                                i = g;
	                                return +l
	                            }
	                            if ((p | 0) > 0 | (p | 0) == 0 & o >>> 0 > (0 - k | 0) >>> 0) {
	                                c[(_a() | 0) >> 2] = 34;
	                                l = +(r | 0) * 1797693134862315708145274.0e284 * 1797693134862315708145274.0e284;
	                                i = g;
	                                return +l
	                            }
	                            q = k + -106 | 0;
	                            oa = ((q | 0) < 0) << 31 >> 31;
	                            if ((p | 0) < (oa | 0) | (p | 0) == (oa | 0) & o >>> 0 < q >>> 0) {
	                                c[(_a() | 0) >> 2] = 34;
	                                l = +(r | 0) * 2.2250738585072014e-308 * 2.2250738585072014e-308;
	                                i = g;
	                                return +l
	                            }
	                            if ((pa | 0) > -1) {
	                                q = o;
	                                oa = p;
	                                sa = pa;
	                                ja = V;
	                                while (1) {
	                                    ta = sa << 1;
	                                    if (!(ja >= .5)) {
	                                        ua = ja;
	                                        va = ta
	                                    } else {
	                                        ua = ja + -1.0;
	                                        va = ta | 1
	                                    }
	                                    wa = ja + ua;
	                                    ta = bU(q | 0, oa | 0, -1, -1) | 0;
	                                    xa = G;
	                                    if ((va | 0) > -1) {
	                                        q = ta;
	                                        oa = xa;
	                                        sa = va;
	                                        ja = wa
	                                    } else {
	                                        ya = ta;
	                                        za = xa;
	                                        Aa = va;
	                                        Ba = wa;
	                                        break
	                                    }
	                                }
	                            } else {
	                                ya = o;
	                                za = p;
	                                Aa = pa;
	                                Ba = V
	                            }
	                            sa = XT(32, 0, k | 0, ((k | 0) < 0) << 31 >> 31 | 0) | 0;
	                            oa = bU(ya | 0, za | 0, sa | 0, G | 0) | 0;
	                            sa = G;
	                            if (0 > (sa | 0) | 0 == (sa | 0) & j >>> 0 > oa >>> 0)if ((oa | 0) < 0) {
	                                Ca = 0;
	                                x = 126
	                            } else {
	                                Da = oa;
	                                x = 124
	                            } else {
	                                Da = j;
	                                x = 124
	                            }
	                            if ((x | 0) == 124)if ((Da | 0) < 53) {
	                                Ca = Da;
	                                x = 126
	                            } else {
	                                Ea = Da;
	                                Fa = +(r | 0);
	                                Ga = 0.0
	                            }
	                            if ((x | 0) == 126) {
	                                ja = +(r | 0);
	                                Ea = Ca;
	                                Fa = ja;
	                                Ga = +tT(+AT(1.0, 84 - Ca | 0), ja)
	                            }
	                            oa = (Ea | 0) < 32 & Ba != 0.0 & (Aa & 1 | 0) == 0;
	                            ja = Fa * (oa ? 0.0 : Ba) + (Ga + Fa * +(((oa & 1) + Aa | 0) >>> 0)) - Ga;
	                            if (!(ja != 0.0))c[(_a() | 0) >> 2] = 34;
	                            l = +BT(ja, ya);
	                            i = g;
	                            return +l
	                        } else H = y; while (0);
	                        oa = k + j | 0;
	                        sa = 0 - oa | 0;
	                        q = H;
	                        n = 0;
	                        while (1) {
	                            if ((q | 0) == 46) {
	                                x = 137;
	                                break
	                            } else if ((q | 0) != 48) {
	                                Ha = q;
	                                Ia = 0;
	                                Ja = 0;
	                                Ka = n;
	                                La = 0;
	                                break
	                            }
	                            u = c[e >> 2] | 0;
	                            if (u >>> 0 < (c[m >> 2] | 0) >>> 0) {
	                                c[e >> 2] = u + 1;
	                                q = d[u >> 0] | 0;
	                                n = 1;
	                                continue
	                            } else {
	                                q = qT(b) | 0;
	                                n = 1;
	                                continue
	                            }
	                        }
	                        if ((x | 0) == 137) {
	                            q = c[e >> 2] | 0;
	                            if (q >>> 0 < (c[m >> 2] | 0) >>> 0) {
	                                c[e >> 2] = q + 1;
	                                Ma = d[q >> 0] | 0
	                            } else Ma = qT(b) | 0;
	                            if ((Ma | 0) == 48) {
	                                q = 0;
	                                u = 0;
	                                while (1) {
	                                    xa = bU(q | 0, u | 0, -1, -1) | 0;
	                                    ta = G;
	                                    Na = c[e >> 2] | 0;
	                                    if (Na >>> 0 < (c[m >> 2] | 0) >>> 0) {
	                                        c[e >> 2] = Na + 1;
	                                        Oa = d[Na >> 0] | 0
	                                    } else Oa = qT(b) | 0;
	                                    if ((Oa | 0) == 48) {
	                                        q = xa;
	                                        u = ta
	                                    } else {
	                                        Ha = Oa;
	                                        Ia = xa;
	                                        Ja = ta;
	                                        Ka = 1;
	                                        La = 1;
	                                        break
	                                    }
	                                }
	                            } else {
	                                Ha = Ma;
	                                Ia = 0;
	                                Ja = 0;
	                                Ka = n;
	                                La = 1
	                            }
	                        }
	                        c[h >> 2] = 0;
	                        u = Ha + -48 | 0;
	                        q = (Ha | 0) == 46;
	                        c:do if (u >>> 0 < 10 | q) {
	                            ta = h + 496 | 0;
	                            xa = Ha;
	                            Na = 0;
	                            Pa = 0;
	                            Qa = q;
	                            Ra = u;
	                            Sa = Ia;
	                            Ta = Ja;
	                            Ua = Ka;
	                            Va = La;
	                            Wa = 0;
	                            Xa = 0;
	                            Ya = 0;
	                            d:while (1) {
	                                do if (Qa)if (!Va) {
	                                    Za = Na;
	                                    $a = Pa;
	                                    ab = Na;
	                                    bb = Pa;
	                                    cb = Ua;
	                                    db = 1;
	                                    eb = Wa;
	                                    fb = Xa;
	                                    gb = Ya
	                                } else break d; else {
	                                    hb = bU(Na | 0, Pa | 0, 1, 0) | 0;
	                                    ib = G;
	                                    jb = (xa | 0) != 48;
	                                    if ((Xa | 0) >= 125) {
	                                        if (!jb) {
	                                            Za = Sa;
	                                            $a = Ta;
	                                            ab = hb;
	                                            bb = ib;
	                                            cb = Ua;
	                                            db = Va;
	                                            eb = Wa;
	                                            fb = Xa;
	                                            gb = Ya;
	                                            break
	                                        }
	                                        c[ta >> 2] = c[ta >> 2] | 1;
	                                        Za = Sa;
	                                        $a = Ta;
	                                        ab = hb;
	                                        bb = ib;
	                                        cb = Ua;
	                                        db = Va;
	                                        eb = Wa;
	                                        fb = Xa;
	                                        gb = Ya;
	                                        break
	                                    }
	                                    kb = h + (Xa << 2) | 0;
	                                    if (!Wa)lb = Ra; else lb = xa + -48 + ((c[kb >> 2] | 0) * 10 | 0) | 0;
	                                    c[kb >> 2] = lb;
	                                    kb = Wa + 1 | 0;
	                                    mb = (kb | 0) == 9;
	                                    Za = Sa;
	                                    $a = Ta;
	                                    ab = hb;
	                                    bb = ib;
	                                    cb = 1;
	                                    db = Va;
	                                    eb = mb ? 0 : kb;
	                                    fb = (mb & 1) + Xa | 0;
	                                    gb = jb ? hb : Ya
	                                } while (0);
	                                hb = c[e >> 2] | 0;
	                                if (hb >>> 0 < (c[m >> 2] | 0) >>> 0) {
	                                    c[e >> 2] = hb + 1;
	                                    nb = d[hb >> 0] | 0
	                                } else nb = qT(b) | 0;
	                                Ra = nb + -48 | 0;
	                                Qa = (nb | 0) == 46;
	                                if (!(Ra >>> 0 < 10 | Qa)) {
	                                    ob = nb;
	                                    pb = Za;
	                                    qb = ab;
	                                    rb = $a;
	                                    sb = bb;
	                                    tb = cb;
	                                    ub = db;
	                                    vb = eb;
	                                    wb = fb;
	                                    xb = gb;
	                                    x = 160;
	                                    break c
	                                } else {
	                                    xa = nb;
	                                    Na = ab;
	                                    Pa = bb;
	                                    Sa = Za;
	                                    Ta = $a;
	                                    Ua = cb;
	                                    Va = db;
	                                    Wa = eb;
	                                    Xa = fb;
	                                    Ya = gb
	                                }
	                            }
	                            yb = Na;
	                            zb = Pa;
	                            Ab = Sa;
	                            Bb = Ta;
	                            Cb = (Ua | 0) != 0;
	                            Db = Wa;
	                            Eb = Xa;
	                            Fb = Ya;
	                            x = 168
	                        } else {
	                            ob = Ha;
	                            pb = Ia;
	                            qb = 0;
	                            rb = Ja;
	                            sb = 0;
	                            tb = Ka;
	                            ub = La;
	                            vb = 0;
	                            wb = 0;
	                            xb = 0;
	                            x = 160
	                        } while (0);
	                        do if ((x | 0) == 160) {
	                            u = (ub | 0) == 0;
	                            q = u ? qb : pb;
	                            n = u ? sb : rb;
	                            u = (tb | 0) != 0;
	                            if (!(u & (ob | 32 | 0) == 101))if ((ob | 0) > -1) {
	                                yb = qb;
	                                zb = sb;
	                                Ab = q;
	                                Bb = n;
	                                Cb = u;
	                                Db = vb;
	                                Eb = wb;
	                                Fb = xb;
	                                x = 168;
	                                break
	                            } else {
	                                Gb = qb;
	                                Hb = sb;
	                                Ib = u;
	                                Jb = q;
	                                Kb = n;
	                                Lb = vb;
	                                Mb = wb;
	                                Nb = xb;
	                                x = 170;
	                                break
	                            }
	                            u = UT(b, f) | 0;
	                            Va = G;
	                            do if ((u | 0) == 0 & (Va | 0) == -2147483648)if (!f) {
	                                pT(b, 0);
	                                l = 0.0;
	                                i = g;
	                                return +l
	                            } else {
	                                if (!(c[m >> 2] | 0)) {
	                                    Ob = 0;
	                                    Pb = 0;
	                                    break
	                                }
	                                c[e >> 2] = (c[e >> 2] | 0) + -1;
	                                Ob = 0;
	                                Pb = 0;
	                                break
	                            } else {
	                                Ob = u;
	                                Pb = Va
	                            } while (0);
	                            Va = bU(Ob | 0, Pb | 0, q | 0, n | 0) | 0;
	                            Qb = Va;
	                            Rb = qb;
	                            Sb = G;
	                            Tb = sb;
	                            Ub = vb;
	                            Vb = wb;
	                            Wb = xb
	                        } while (0);
	                        if ((x | 0) == 168)if (c[m >> 2] | 0) {
	                            c[e >> 2] = (c[e >> 2] | 0) + -1;
	                            if (Cb) {
	                                Qb = Ab;
	                                Rb = yb;
	                                Sb = Bb;
	                                Tb = zb;
	                                Ub = Db;
	                                Vb = Eb;
	                                Wb = Fb
	                            } else x = 171
	                        } else {
	                            Gb = yb;
	                            Hb = zb;
	                            Ib = Cb;
	                            Jb = Ab;
	                            Kb = Bb;
	                            Lb = Db;
	                            Mb = Eb;
	                            Nb = Fb;
	                            x = 170
	                        }
	                        if ((x | 0) == 170)if (Ib) {
	                            Qb = Jb;
	                            Rb = Gb;
	                            Sb = Kb;
	                            Tb = Hb;
	                            Ub = Lb;
	                            Vb = Mb;
	                            Wb = Nb
	                        } else x = 171;
	                        if ((x | 0) == 171) {
	                            c[(_a() | 0) >> 2] = 22;
	                            pT(b, 0);
	                            l = 0.0;
	                            i = g;
	                            return +l
	                        }
	                        Va = c[h >> 2] | 0;
	                        if (!Va) {
	                            l = +(r | 0) * 0.0;
	                            i = g;
	                            return +l
	                        }
	                        if ((Qb | 0) == (Rb | 0) & (Sb | 0) == (Tb | 0) & ((Tb | 0) < 0 | (Tb | 0) == 0 & Rb >>> 0 < 10) ? j >>> 0 > 30 | (Va >>> j | 0) == 0 : 0) {
	                            l = +(r | 0) * +(Va >>> 0);
	                            i = g;
	                            return +l
	                        }
	                        Va = (k | 0) / -2 | 0;
	                        u = ((Va | 0) < 0) << 31 >> 31;
	                        if ((Sb | 0) > (u | 0) | (Sb | 0) == (u | 0) & Qb >>> 0 > Va >>> 0) {
	                            c[(_a() | 0) >> 2] = 34;
	                            l = +(r | 0) * 1797693134862315708145274.0e284 * 1797693134862315708145274.0e284;
	                            i = g;
	                            return +l
	                        }
	                        Va = k + -106 | 0;
	                        u = ((Va | 0) < 0) << 31 >> 31;
	                        if ((Sb | 0) < (u | 0) | (Sb | 0) == (u | 0) & Qb >>> 0 < Va >>> 0) {
	                            c[(_a() | 0) >> 2] = 34;
	                            l = +(r | 0) * 2.2250738585072014e-308 * 2.2250738585072014e-308;
	                            i = g;
	                            return +l
	                        }
	                        if (!Ub)Xb = Vb; else {
	                            if ((Ub | 0) < 9) {
	                                Va = h + (Vb << 2) | 0;
	                                u = c[Va >> 2] | 0;
	                                Ya = Ub;
	                                do {
	                                    u = u * 10 | 0;
	                                    Ya = Ya + 1 | 0
	                                } while ((Ya | 0) != 9);
	                                c[Va >> 2] = u
	                            }
	                            Xb = Vb + 1 | 0
	                        }
	                        if ((Wb | 0) < 9 ? (Wb | 0) <= (Qb | 0) & (Qb | 0) < 18 : 0) {
	                            if ((Qb | 0) == 9) {
	                                l = +(r | 0) * +((c[h >> 2] | 0) >>> 0);
	                                i = g;
	                                return +l
	                            }
	                            if ((Qb | 0) < 9) {
	                                l = +(r | 0) * +((c[h >> 2] | 0) >>> 0) / +(c[329064 + (8 - Qb << 2) >> 2] | 0);
	                                i = g;
	                                return +l
	                            }
	                            Ya = j + 27 + (ca(Qb, -3) | 0) | 0;
	                            Xa = c[h >> 2] | 0;
	                            if ((Ya | 0) > 30 | (Xa >>> Ya | 0) == 0) {
	                                l = +(r | 0) * +(Xa >>> 0) * +(c[329064 + (Qb + -10 << 2) >> 2] | 0);
	                                i = g;
	                                return +l
	                            }
	                        }
	                        Xa = (Qb | 0) % 9 | 0;
	                        if (!Xa) {
	                            Yb = 0;
	                            Zb = 0;
	                            _b = Qb;
	                            $b = Xb
	                        } else {
	                            Ya = (Qb | 0) > -1 ? Xa : Xa + 9 | 0;
	                            Xa = c[329064 + (8 - Ya << 2) >> 2] | 0;
	                            if (Xb) {
	                                Wa = 1e9 / (Xa | 0) | 0;
	                                Ua = 0;
	                                Ta = 0;
	                                Sa = 0;
	                                Pa = Qb;
	                                while (1) {
	                                    Na = h + (Sa << 2) | 0;
	                                    xa = c[Na >> 2] | 0;
	                                    Qa = ((xa >>> 0) / (Xa >>> 0) | 0) + Ta | 0;
	                                    c[Na >> 2] = Qa;
	                                    Ta = ca((xa >>> 0) % (Xa >>> 0) | 0, Wa) | 0;
	                                    xa = Sa;
	                                    Sa = Sa + 1 | 0;
	                                    if ((xa | 0) == (Ua | 0) & (Qa | 0) == 0) {
	                                        ac = Sa & 127;
	                                        bc = Pa + -9 | 0
	                                    } else {
	                                        ac = Ua;
	                                        bc = Pa
	                                    }
	                                    if ((Sa | 0) == (Xb | 0))break; else {
	                                        Ua = ac;
	                                        Pa = bc
	                                    }
	                                }
	                                if (!Ta) {
	                                    cc = ac;
	                                    dc = bc;
	                                    ec = Xb
	                                } else {
	                                    c[h + (Xb << 2) >> 2] = Ta;
	                                    cc = ac;
	                                    dc = bc;
	                                    ec = Xb + 1 | 0
	                                }
	                            } else {
	                                cc = 0;
	                                dc = Qb;
	                                ec = 0
	                            }
	                            Yb = cc;
	                            Zb = 0;
	                            _b = 9 - Ya + dc | 0;
	                            $b = ec
	                        }
	                        e:while (1) {
	                            Pa = h + (Yb << 2) | 0;
	                            if ((_b | 0) < 18) {
	                                Ua = Zb;
	                                Sa = $b;
	                                while (1) {
	                                    Wa = 0;
	                                    Xa = Sa + 127 | 0;
	                                    u = Sa;
	                                    while (1) {
	                                        Va = Xa & 127;
	                                        Qa = h + (Va << 2) | 0;
	                                        xa = $T(c[Qa >> 2] | 0, 0, 29) | 0;
	                                        Na = bU(xa | 0, G | 0, Wa | 0, 0) | 0;
	                                        xa = G;
	                                        if (xa >>> 0 > 0 | (xa | 0) == 0 & Na >>> 0 > 1e9) {
	                                            Ra = nU(Na | 0, xa | 0, 1e9, 0) | 0;
	                                            ta = oU(Na | 0, xa | 0, 1e9, 0) | 0;
	                                            fc = ta;
	                                            gc = Ra
	                                        } else {
	                                            fc = Na;
	                                            gc = 0
	                                        }
	                                        c[Qa >> 2] = fc;
	                                        Qa = (Va | 0) == (Yb | 0);
	                                        if ((Va | 0) != (u + 127 & 127 | 0) | Qa)hc = u; else hc = (fc | 0) == 0 ? Va : u;
	                                        if (Qa)break; else {
	                                            Wa = gc;
	                                            Xa = Va + -1 | 0;
	                                            u = hc
	                                        }
	                                    }
	                                    u = Ua + -29 | 0;
	                                    if (!gc) {
	                                        Ua = u;
	                                        Sa = hc
	                                    } else {
	                                        ic = u;
	                                        jc = gc;
	                                        kc = hc;
	                                        break
	                                    }
	                                }
	                            } else {
	                                if ((_b | 0) == 18) {
	                                    lc = Zb;
	                                    mc = $b
	                                } else {
	                                    nc = Yb;
	                                    oc = Zb;
	                                    pc = _b;
	                                    qc = $b;
	                                    break
	                                }
	                                while (1) {
	                                    if ((c[Pa >> 2] | 0) >>> 0 >= 9007199) {
	                                        nc = Yb;
	                                        oc = lc;
	                                        pc = 18;
	                                        qc = mc;
	                                        break e
	                                    }
	                                    Sa = 0;
	                                    Ua = mc + 127 | 0;
	                                    n = mc;
	                                    while (1) {
	                                        q = Ua & 127;
	                                        u = h + (q << 2) | 0;
	                                        Xa = $T(c[u >> 2] | 0, 0, 29) | 0;
	                                        Wa = bU(Xa | 0, G | 0, Sa | 0, 0) | 0;
	                                        Xa = G;
	                                        if (Xa >>> 0 > 0 | (Xa | 0) == 0 & Wa >>> 0 > 1e9) {
	                                            Va = nU(Wa | 0, Xa | 0, 1e9, 0) | 0;
	                                            Qa = oU(Wa | 0, Xa | 0, 1e9, 0) | 0;
	                                            rc = Qa;
	                                            sc = Va
	                                        } else {
	                                            rc = Wa;
	                                            sc = 0
	                                        }
	                                        c[u >> 2] = rc;
	                                        u = (q | 0) == (Yb | 0);
	                                        if ((q | 0) != (n + 127 & 127 | 0) | u)tc = n; else tc = (rc | 0) == 0 ? q : n;
	                                        if (u)break; else {
	                                            Sa = sc;
	                                            Ua = q + -1 | 0;
	                                            n = tc
	                                        }
	                                    }
	                                    n = lc + -29 | 0;
	                                    if (!sc) {
	                                        lc = n;
	                                        mc = tc
	                                    } else {
	                                        ic = n;
	                                        jc = sc;
	                                        kc = tc;
	                                        break
	                                    }
	                                }
	                            }
	                            Pa = Yb + 127 & 127;
	                            if ((Pa | 0) == (kc | 0)) {
	                                n = kc + 127 & 127;
	                                Ua = h + ((kc + 126 & 127) << 2) | 0;
	                                c[Ua >> 2] = c[Ua >> 2] | c[h + (n << 2) >> 2];
	                                uc = n
	                            } else uc = kc;
	                            c[h + (Pa << 2) >> 2] = jc;
	                            Yb = Pa;
	                            Zb = ic;
	                            _b = _b + 9 | 0;
	                            $b = uc
	                        }
	                        f:while (1) {
	                            vc = qc + 1 & 127;
	                            Ya = h + ((qc + 127 & 127) << 2) | 0;
	                            Ta = nc;
	                            Pa = oc;
	                            n = pc;
	                            while (1) {
	                                Ua = (n | 0) == 18;
	                                Sa = (n | 0) > 27 ? 9 : 1;
	                                wc = Ta;
	                                xc = Pa;
	                                while (1) {
	                                    q = 0;
	                                    while (1) {
	                                        u = q + wc & 127;
	                                        if ((u | 0) == (qc | 0)) {
	                                            yc = 2;
	                                            break
	                                        }
	                                        Wa = c[h + (u << 2) >> 2] | 0;
	                                        u = c[329056 + (q << 2) >> 2] | 0;
	                                        if (Wa >>> 0 < u >>> 0) {
	                                            yc = 2;
	                                            break
	                                        }
	                                        Va = q + 1 | 0;
	                                        if (Wa >>> 0 > u >>> 0) {
	                                            yc = q;
	                                            break
	                                        }
	                                        if ((Va | 0) < 2)q = Va; else {
	                                            yc = Va;
	                                            break
	                                        }
	                                    }
	                                    if ((yc | 0) == 2 & Ua)break f;
	                                    zc = Sa + xc | 0;
	                                    if ((wc | 0) == (qc | 0)) {
	                                        wc = qc;
	                                        xc = zc
	                                    } else break
	                                }
	                                Ua = (1 << Sa) + -1 | 0;
	                                q = 1e9 >>> Sa;
	                                Ac = wc;
	                                Bc = 0;
	                                Va = wc;
	                                Cc = n;
	                                do {
	                                    u = h + (Va << 2) | 0;
	                                    Wa = c[u >> 2] | 0;
	                                    Qa = (Wa >>> Sa) + Bc | 0;
	                                    c[u >> 2] = Qa;
	                                    Bc = ca(Wa & Ua, q) | 0;
	                                    Wa = (Va | 0) == (Ac | 0) & (Qa | 0) == 0;
	                                    Va = Va + 1 & 127;
	                                    Cc = Wa ? Cc + -9 | 0 : Cc;
	                                    Ac = Wa ? Va : Ac
	                                } while ((Va | 0) != (qc | 0));
	                                if (!Bc) {
	                                    Ta = Ac;
	                                    Pa = zc;
	                                    n = Cc;
	                                    continue
	                                }
	                                if ((vc | 0) != (Ac | 0))break;
	                                c[Ya >> 2] = c[Ya >> 2] | 1;
	                                Ta = Ac;
	                                Pa = zc;
	                                n = Cc
	                            }
	                            c[h + (qc << 2) >> 2] = Bc;
	                            nc = Ac;
	                            oc = zc;
	                            pc = Cc;
	                            qc = vc
	                        }
	                        n = wc & 127;
	                        if ((n | 0) == (qc | 0)) {
	                            c[h + (vc + -1 << 2) >> 2] = 0;
	                            Dc = vc
	                        } else Dc = qc;
	                        ja = +((c[h + (n << 2) >> 2] | 0) >>> 0);
	                        n = wc + 1 & 127;
	                        if ((n | 0) == (Dc | 0)) {
	                            Pa = Dc + 1 & 127;
	                            c[h + (Pa + -1 << 2) >> 2] = 0;
	                            Ec = Pa
	                        } else Ec = Dc;
	                        wa = +(r | 0);
	                        Fc = wa * (ja * 1.0e9 + +((c[h + (n << 2) >> 2] | 0) >>> 0));
	                        n = xc + 53 | 0;
	                        Pa = n - k | 0;
	                        if ((Pa | 0) < (j | 0))if ((Pa | 0) < 0) {
	                            Gc = 0;
	                            Hc = 1;
	                            x = 244
	                        } else {
	                            Ic = Pa;
	                            Jc = 1;
	                            x = 243
	                        } else {
	                            Ic = j;
	                            Jc = 0;
	                            x = 243
	                        }
	                        if ((x | 0) == 243)if ((Ic | 0) < 53) {
	                            Gc = Ic;
	                            Hc = Jc;
	                            x = 244
	                        } else {
	                            Kc = Ic;
	                            Lc = 0.0;
	                            Mc = Jc;
	                            Nc = 0.0;
	                            Oc = Fc
	                        }
	                        if ((x | 0) == 244) {
	                            ja = +tT(+AT(1.0, 105 - Gc | 0), Fc);
	                            Pc = +vT(Fc, +AT(1.0, 53 - Gc | 0));
	                            Kc = Gc;
	                            Lc = ja;
	                            Mc = Hc;
	                            Nc = Pc;
	                            Oc = ja + (Fc - Pc)
	                        }
	                        Ta = wc + 2 & 127;
	                        do if ((Ta | 0) == (Ec | 0))Qc = Nc; else {
	                            Ya = c[h + (Ta << 2) >> 2] | 0;
	                            do if (Ya >>> 0 >= 5e8) {
	                                if (Ya >>> 0 > 5e8) {
	                                    Rc = wa * .75 + Nc;
	                                    break
	                                }
	                                if ((wc + 3 & 127 | 0) == (Ec | 0)) {
	                                    Rc = wa * .5 + Nc;
	                                    break
	                                } else {
	                                    Rc = wa * .75 + Nc;
	                                    break
	                                }
	                            } else {
	                                if ((Ya | 0) == 0 ? (wc + 3 & 127 | 0) == (Ec | 0) : 0) {
	                                    Rc = Nc;
	                                    break
	                                }
	                                Rc = wa * .25 + Nc
	                            } while (0);
	                            if ((53 - Kc | 0) <= 1) {
	                                Qc = Rc;
	                                break
	                            }
	                            if (+vT(Rc, 1.0) != 0.0) {
	                                Qc = Rc;
	                                break
	                            }
	                            Qc = Rc + 1.0
	                        } while (0);
	                        wa = Oc + Qc - Lc;
	                        do if ((n & 2147483647 | 0) > (-2 - oa | 0)) {
	                            if (!(+R(+wa) >= 9007199254740992.0)) {
	                                Sc = Mc;
	                                Tc = xc;
	                                Uc = wa
	                            } else {
	                                Sc = (Mc | 0) != 0 & (Kc | 0) == (Pa | 0) ? 0 : Mc;
	                                Tc = xc + 1 | 0;
	                                Uc = wa * .5
	                            }
	                            if ((Tc + 50 | 0) <= (sa | 0) ? !((Sc | 0) != 0 & Qc != 0.0) : 0) {
	                                Vc = Tc;
	                                Wc = Uc;
	                                break
	                            }
	                            c[(_a() | 0) >> 2] = 34;
	                            Vc = Tc;
	                            Wc = Uc
	                        } else {
	                            Vc = xc;
	                            Wc = wa
	                        } while (0);
	                        l = +BT(Wc, Vc);
	                        i = g;
	                        return +l
	                    } else {
	                        if (c[m >> 2] | 0)c[e >> 2] = (c[e >> 2] | 0) + -1;
	                        c[(_a() | 0) >> 2] = 22;
	                        pT(b, 0);
	                        l = 0.0;
	                        i = g;
	                        return +l
	                    }
	                } while (0);
	                if ((x | 0) == 23) {
	                    x = (c[m >> 2] | 0) == 0;
	                    if (!x)c[e >> 2] = (c[e >> 2] | 0) + -1;
	                    if (!(t >>> 0 < 4 | (f | 0) == 0 | x)) {
	                        x = t;
	                        do {
	                            c[e >> 2] = (c[e >> 2] | 0) + -1;
	                            x = x + -1 | 0
	                        } while (x >>> 0 > 3)
	                    }
	                }
	                l = +(r | 0) * w;
	                i = g;
	                return +l
	            }

	            function pT(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                c[a + 104 >> 2] = b;
	                e = c[a + 8 >> 2] | 0;
	                f = c[a + 4 >> 2] | 0;
	                g = e - f | 0;
	                c[a + 108 >> 2] = g;
	                if ((b | 0) != 0 & (g | 0) > (b | 0)) {
	                    c[a + 100 >> 2] = f + b;
	                    i = d;
	                    return
	                } else {
	                    c[a + 100 >> 2] = e;
	                    i = d;
	                    return
	                }
	            }

	            function qT(b) {
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                f = b + 104 | 0;
	                g = c[f >> 2] | 0;
	                if (!((g | 0) != 0 ? (c[b + 108 >> 2] | 0) >= (g | 0) : 0))h = 3;
	                if ((h | 0) == 3 ? (h = HT(b) | 0, (h | 0) >= 0) : 0) {
	                    g = c[f >> 2] | 0;
	                    f = c[b + 8 >> 2] | 0;
	                    if ((g | 0) != 0 ? (j = c[b + 4 >> 2] | 0, k = g - (c[b + 108 >> 2] | 0) + -1 | 0, (f - j | 0) > (k | 0)) : 0)c[b + 100 >> 2] = j + k; else c[b + 100 >> 2] = f;
	                    k = c[b + 4 >> 2] | 0;
	                    if (f) {
	                        j = b + 108 | 0;
	                        c[j >> 2] = f + 1 - k + (c[j >> 2] | 0)
	                    }
	                    j = k + -1 | 0;
	                    if ((d[j >> 0] | 0 | 0) == (h | 0)) {
	                        l = h;
	                        i = e;
	                        return l | 0
	                    }
	                    a[j >> 0] = h;
	                    l = h;
	                    i = e;
	                    return l | 0
	                }
	                c[b + 100 >> 2] = 0;
	                l = -1;
	                i = e;
	                return l | 0
	            }

	            function rT(a) {
	                a = +a;
	                var b = 0, d = 0, e = 0, f = 0, g = 0, j = 0;
	                b = i;
	                h[k >> 3] = a;
	                d = c[k >> 2] | 0;
	                e = c[k + 4 >> 2] | 0;
	                f = dU(d | 0, e | 0, 52) | 0;
	                g = f & 2047;
	                if ((g | 0) == 2047) {
	                    j = (d | 0) == 0 & (e & 1048575 | 0) == 0 & 1;
	                    i = b;
	                    return j | 0
	                } else if (!g) {
	                    j = (d | 0) != 0 | (e & 2147483647 | 0) != 0 ? 3 : 2;
	                    i = b;
	                    return j | 0
	                } else {
	                    j = 4;
	                    i = b;
	                    return j | 0
	                }
	                return 0
	            }

	            function sT(a, b) {
	                a = +a;
	                b = +b;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                h[k >> 3] = a;
	                e = c[k >> 2] | 0;
	                f = c[k + 4 >> 2] | 0;
	                h[k >> 3] = b;
	                g = c[k + 4 >> 2] & -2147483648 | f & 2147483647;
	                c[k >> 2] = e;
	                c[k + 4 >> 2] = g;
	                b = +h[k >> 3];
	                i = d;
	                return +b
	            }

	            function tT(a, b) {
	                a = +a;
	                b = +b;
	                var c = 0, d = 0.0;
	                c = i;
	                d = +sT(a, b);
	                i = c;
	                return +d
	            }

	            function uT(a, b) {
	                a = +a;
	                b = +b;
	                var d = 0, e = 0, f = 0, g = 0, j = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0.0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, H = 0, I = 0, J = 0, K = 0, L = 0, M = 0, N = 0, O = 0, P = 0, Q = 0, R = 0, S = 0, T = 0, U = 0.0;
	                d = i;
	                h[k >> 3] = a;
	                e = c[k >> 2] | 0;
	                f = c[k + 4 >> 2] | 0;
	                h[k >> 3] = b;
	                g = c[k >> 2] | 0;
	                j = c[k + 4 >> 2] | 0;
	                l = dU(e | 0, f | 0, 52) | 0;
	                m = l & 2047;
	                l = dU(g | 0, j | 0, 52) | 0;
	                n = l & 2047;
	                l = f & -2147483648;
	                o = $T(g | 0, j | 0, 1) | 0;
	                p = G;
	                if (!((o | 0) == 0 & (p | 0) == 0) ? (q = j & 2147483647, !(q >>> 0 > 2146435072 | (q | 0) == 2146435072 & g >>> 0 > 0 | (m | 0) == 2047)) : 0) {
	                    q = $T(e | 0, f | 0, 1) | 0;
	                    r = G;
	                    if (!(r >>> 0 > p >>> 0 | (r | 0) == (p | 0) & q >>> 0 > o >>> 0)) {
	                        if (!((q | 0) == (o | 0) & (r | 0) == (p | 0))) {
	                            s = a;
	                            i = d;
	                            return +s
	                        }
	                        s = a * 0.0;
	                        i = d;
	                        return +s
	                    }
	                    if (!m) {
	                        p = $T(e | 0, f | 0, 12) | 0;
	                        r = G;
	                        if ((r | 0) > -1 | (r | 0) == -1 & p >>> 0 > 4294967295) {
	                            o = p;
	                            p = r;
	                            r = 0;
	                            while (1) {
	                                q = r + -1 | 0;
	                                o = $T(o | 0, p | 0, 1) | 0;
	                                p = G;
	                                if (!((p | 0) > -1 | (p | 0) == -1 & o >>> 0 > 4294967295)) {
	                                    t = q;
	                                    break
	                                } else r = q
	                            }
	                        } else t = 0;
	                        r = $T(e | 0, f | 0, 1 - t | 0) | 0;
	                        u = r;
	                        v = G;
	                        w = t
	                    } else {
	                        u = e;
	                        v = f & 1048575 | 1048576;
	                        w = m
	                    }
	                    if (!n) {
	                        m = $T(g | 0, j | 0, 12) | 0;
	                        f = G;
	                        if ((f | 0) > -1 | (f | 0) == -1 & m >>> 0 > 4294967295) {
	                            e = m;
	                            m = f;
	                            f = 0;
	                            while (1) {
	                                t = f + -1 | 0;
	                                e = $T(e | 0, m | 0, 1) | 0;
	                                m = G;
	                                if (!((m | 0) > -1 | (m | 0) == -1 & e >>> 0 > 4294967295)) {
	                                    x = t;
	                                    break
	                                } else f = t
	                            }
	                        } else x = 0;
	                        f = $T(g | 0, j | 0, 1 - x | 0) | 0;
	                        y = f;
	                        z = G;
	                        A = x
	                    } else {
	                        y = g;
	                        z = j & 1048575 | 1048576;
	                        A = n
	                    }
	                    n = XT(u | 0, v | 0, y | 0, z | 0) | 0;
	                    j = G;
	                    g = (j | 0) > -1 | (j | 0) == -1 & n >>> 0 > 4294967295;
	                    a:do if ((w | 0) > (A | 0)) {
	                        x = g;
	                        f = n;
	                        e = j;
	                        m = u;
	                        t = v;
	                        r = w;
	                        while (1) {
	                            if (x)if ((m | 0) == (y | 0) & (t | 0) == (z | 0))break; else {
	                                B = f;
	                                C = e
	                            } else {
	                                B = m;
	                                C = t
	                            }
	                            o = $T(B | 0, C | 0, 1) | 0;
	                            p = G;
	                            q = r + -1 | 0;
	                            D = XT(o | 0, p | 0, y | 0, z | 0) | 0;
	                            E = G;
	                            F = (E | 0) > -1 | (E | 0) == -1 & D >>> 0 > 4294967295;
	                            if ((q | 0) > (A | 0)) {
	                                x = F;
	                                f = D;
	                                e = E;
	                                m = o;
	                                t = p;
	                                r = q
	                            } else {
	                                H = F;
	                                I = o;
	                                J = p;
	                                K = D;
	                                L = E;
	                                M = q;
	                                break a
	                            }
	                        }
	                        s = a * 0.0;
	                        i = d;
	                        return +s
	                    } else {
	                        H = g;
	                        I = u;
	                        J = v;
	                        K = n;
	                        L = j;
	                        M = w
	                    } while (0);
	                    if (H)if ((I | 0) == (y | 0) & (J | 0) == (z | 0)) {
	                        s = a * 0.0;
	                        i = d;
	                        return +s
	                    } else {
	                        N = L;
	                        O = K
	                    } else {
	                        N = J;
	                        O = I
	                    }
	                    if (N >>> 0 < 1048576 | (N | 0) == 1048576 & O >>> 0 < 0) {
	                        I = O;
	                        J = N;
	                        K = M;
	                        while (1) {
	                            L = $T(I | 0, J | 0, 1) | 0;
	                            z = G;
	                            y = K + -1 | 0;
	                            if (z >>> 0 < 1048576 | (z | 0) == 1048576 & L >>> 0 < 0) {
	                                I = L;
	                                J = z;
	                                K = y
	                            } else {
	                                P = L;
	                                Q = z;
	                                R = y;
	                                break
	                            }
	                        }
	                    } else {
	                        P = O;
	                        Q = N;
	                        R = M
	                    }
	                    if ((R | 0) > 0) {
	                        M = bU(P | 0, Q | 0, 0, -1048576) | 0;
	                        N = G;
	                        O = $T(R | 0, 0, 52) | 0;
	                        S = N | G;
	                        T = M | O
	                    } else {
	                        O = dU(P | 0, Q | 0, 1 - R | 0) | 0;
	                        S = G;
	                        T = O
	                    }
	                    c[k >> 2] = T;
	                    c[k + 4 >> 2] = S | l;
	                    s = +h[k >> 3];
	                    i = d;
	                    return +s
	                }
	                U = a * b;
	                s = U / U;
	                i = d;
	                return +s
	            }

	            function vT(a, b) {
	                a = +a;
	                b = +b;
	                var c = 0, d = 0.0;
	                c = i;
	                d = +uT(a, b);
	                i = c;
	                return +d
	            }

	            function wT(a, b) {
	                a = +a;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, j = 0, l = 0.0, m = 0.0, n = 0, o = 0.0;
	                d = i;
	                h[k >> 3] = a;
	                e = c[k >> 2] | 0;
	                f = c[k + 4 >> 2] | 0;
	                g = dU(e | 0, f | 0, 52) | 0;
	                j = g & 2047;
	                if (!j) {
	                    if (a != 0.0) {
	                        l = +wT(a * 18446744073709551616.0, b);
	                        m = l;
	                        n = (c[b >> 2] | 0) + -64 | 0
	                    } else {
	                        m = a;
	                        n = 0
	                    }
	                    c[b >> 2] = n;
	                    o = m;
	                    i = d;
	                    return +o
	                } else if ((j | 0) == 2047) {
	                    o = a;
	                    i = d;
	                    return +o
	                } else {
	                    c[b >> 2] = j + -1022;
	                    c[k >> 2] = e;
	                    c[k + 4 >> 2] = f & -2146435073 | 1071644672;
	                    o = +h[k >> 3];
	                    i = d;
	                    return +o
	                }
	                return +(0.0)
	            }

	            function xT(a, b) {
	                a = +a;
	                b = b | 0;
	                var c = 0, d = 0.0;
	                c = i;
	                d = +wT(a, b);
	                i = c;
	                return +d
	            }

	            function yT(a) {
	                a = +a;
	                var b = 0, d = 0, e = 0, f = 0, g = 0.0, j = 0, l = 0, m = 0, n = 0, o = 0, p = 0.0, q = 0.0, r = 0.0, s = 0.0, t = 0.0, u = 0.0;
	                b = i;
	                h[k >> 3] = a;
	                d = c[k >> 2] | 0;
	                e = c[k + 4 >> 2] | 0;
	                f = (e | 0) < 0;
	                do if (!(e >>> 0 < 1048576 | f)) {
	                    if (e >>> 0 > 2146435071) {
	                        g = a;
	                        i = b;
	                        return +g
	                    }
	                    if ((e | 0) == 1072693248 & ((d | 0) == 0 & 0 == 0)) {
	                        g = 0.0;
	                        i = b;
	                        return +g
	                    } else {
	                        j = d;
	                        l = e;
	                        m = e;
	                        n = -1023
	                    }
	                } else {
	                    if ((d | 0) == 0 & (e & 2147483647 | 0) == 0) {
	                        g = -1.0 / (a * a);
	                        i = b;
	                        return +g
	                    }
	                    if (!f) {
	                        h[k >> 3] = a * 18014398509481984.0;
	                        o = c[k + 4 >> 2] | 0;
	                        j = c[k >> 2] | 0;
	                        l = o;
	                        m = o;
	                        n = -1077;
	                        break
	                    }
	                    g = (a - a) / 0.0;
	                    i = b;
	                    return +g
	                } while (0);
	                l = m + 614242 | 0;
	                c[k >> 2] = j;
	                c[k + 4 >> 2] = (l & 1048575) + 1072079006;
	                a = +h[k >> 3] + -1.0;
	                p = a * (a * .5);
	                q = a / (a + 2.0);
	                r = q * q;
	                s = r * r;
	                h[k >> 3] = a - p;
	                j = c[k + 4 >> 2] | 0;
	                c[k >> 2] = 0;
	                c[k + 4 >> 2] = j;
	                t = +h[k >> 3];
	                u = q * (p + (s * (s * (s * .15313837699209373 + .22222198432149784) + .3999999999940942) + r * (s * (s * (s * .14798198605116586 + .1818357216161805) + .2857142874366239) + .6666666666666735))) + (a - t - p);
	                p = t * .4342944818781689;
	                a = +(n + (l >>> 20) | 0);
	                s = a * .30102999566361177;
	                r = s + p;
	                g = r + (p + (s - r) + (u * .4342944818781689 + (a * 3.694239077158931e-13 + (t + u) * 2.5082946711645275e-11)));
	                i = b;
	                return +g
	            }

	            function zT(a) {
	                a = a | 0;
	                return +v
	            }

	            function AT(a, b) {
	                a = +a;
	                b = b | 0;
	                var d = 0, e = 0.0, f = 0, g = 0, j = 0, l = 0.0;
	                d = i;
	                if ((b | 0) > 1023) {
	                    e = a * 8988465674311579538646525.0e283;
	                    f = b + -1023 | 0;
	                    if ((f | 0) > 1023) {
	                        g = b + -2046 | 0;
	                        j = (g | 0) > 1023 ? 1023 : g;
	                        l = e * 8988465674311579538646525.0e283
	                    } else {
	                        j = f;
	                        l = e
	                    }
	                } else if ((b | 0) < -1022) {
	                    e = a * 2.2250738585072014e-308;
	                    f = b + 1022 | 0;
	                    if ((f | 0) < -1022) {
	                        g = b + 2044 | 0;
	                        j = (g | 0) < -1022 ? -1022 : g;
	                        l = e * 2.2250738585072014e-308
	                    } else {
	                        j = f;
	                        l = e
	                    }
	                } else {
	                    j = b;
	                    l = a
	                }
	                b = $T(j + 1023 | 0, 0, 52) | 0;
	                j = G;
	                c[k >> 2] = b;
	                c[k + 4 >> 2] = j;
	                a = l * +h[k >> 3];
	                i = d;
	                return +a
	            }

	            function BT(a, b) {
	                a = +a;
	                b = b | 0;
	                var c = 0, d = 0.0;
	                c = i;
	                d = +AT(a, b);
	                i = c;
	                return +d
	            }

	            function CT(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var c = 0, d = 0;
	                c = i;
	                if (!a)d = 0; else d = DT(a, b, 0) | 0;
	                i = c;
	                return d | 0
	            }

	            function DT(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0;
	                e = i;
	                if (!b) {
	                    f = 1;
	                    i = e;
	                    return f | 0
	                }
	                if (d >>> 0 < 128) {
	                    a[b >> 0] = d;
	                    f = 1;
	                    i = e;
	                    return f | 0
	                }
	                if (d >>> 0 < 2048) {
	                    a[b >> 0] = d >>> 6 | 192;
	                    a[b + 1 >> 0] = d & 63 | 128;
	                    f = 2;
	                    i = e;
	                    return f | 0
	                }
	                if (d >>> 0 < 55296 | (d & -8192 | 0) == 57344) {
	                    a[b >> 0] = d >>> 12 | 224;
	                    a[b + 1 >> 0] = d >>> 6 & 63 | 128;
	                    a[b + 2 >> 0] = d & 63 | 128;
	                    f = 3;
	                    i = e;
	                    return f | 0
	                }
	                if ((d + -65536 | 0) >>> 0 < 1048576) {
	                    a[b >> 0] = d >>> 18 | 240;
	                    a[b + 1 >> 0] = d >>> 12 & 63 | 128;
	                    a[b + 2 >> 0] = d >>> 6 & 63 | 128;
	                    a[b + 3 >> 0] = d & 63 | 128;
	                    f = 4;
	                    i = e;
	                    return f | 0
	                } else {
	                    c[(_a() | 0) >> 2] = 84;
	                    f = -1;
	                    i = e;
	                    return f | 0
	                }
	                return 0
	            }

	            function ET(a) {
	                a = a | 0;
	                var b = 0;
	                b = (ca(c[a >> 2] | 0, 1103515245) | 0) + 12345 | 0;
	                c[a >> 2] = b;
	                a = b >>> 11 ^ b;
	                b = a << 7 & -1658038656 ^ a;
	                a = b << 15 & -272236544 ^ b;
	                return (a >>> 18 ^ a) >>> 1 | 0
	            }

	            function FT(b) {
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                e = b + 74 | 0;
	                f = a[e >> 0] | 0;
	                a[e >> 0] = f + 255 | f;
	                f = b + 20 | 0;
	                e = b + 44 | 0;
	                if ((c[f >> 2] | 0) >>> 0 > (c[e >> 2] | 0) >>> 0)vb[c[b + 36 >> 2] & 511](b, 0, 0) | 0;
	                c[b + 16 >> 2] = 0;
	                c[b + 28 >> 2] = 0;
	                c[f >> 2] = 0;
	                f = c[b >> 2] | 0;
	                if (!(f & 20)) {
	                    g = c[e >> 2] | 0;
	                    c[b + 8 >> 2] = g;
	                    c[b + 4 >> 2] = g;
	                    h = 0;
	                    i = d;
	                    return h | 0
	                }
	                if (!(f & 4)) {
	                    h = -1;
	                    i = d;
	                    return h | 0
	                }
	                c[b >> 2] = f | 32;
	                h = -1;
	                i = d;
	                return h | 0
	            }

	            function GT(b) {
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0;
	                d = i;
	                e = b + 74 | 0;
	                f = a[e >> 0] | 0;
	                a[e >> 0] = f + 255 | f;
	                f = c[b >> 2] | 0;
	                if (!(f & 8)) {
	                    c[b + 8 >> 2] = 0;
	                    c[b + 4 >> 2] = 0;
	                    e = c[b + 44 >> 2] | 0;
	                    c[b + 28 >> 2] = e;
	                    c[b + 20 >> 2] = e;
	                    c[b + 16 >> 2] = e + (c[b + 48 >> 2] | 0);
	                    g = 0;
	                    i = d;
	                    return g | 0
	                } else {
	                    c[b >> 2] = f | 32;
	                    g = -1;
	                    i = d;
	                    return g | 0
	                }
	                return 0
	            }

	            function HT(a) {
	                a = a | 0;
	                var b = 0, e = 0, f = 0;
	                b = i;
	                i = i + 16 | 0;
	                e = b;
	                if ((c[a + 8 >> 2] | 0) == 0 ? (FT(a) | 0) != 0 : 0)f = -1; else if ((vb[c[a + 32 >> 2] & 511](a, e, 1) | 0) == 1)f = d[e >> 0] | 0; else f = -1;
	                i = b;
	                return f | 0
	            }

	            function IT(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                f = i;
	                g = e + 16 | 0;
	                h = c[g >> 2] | 0;
	                do if (!h)if (!(GT(e) | 0)) {
	                    j = c[g >> 2] | 0;
	                    break
	                } else {
	                    k = 0;
	                    i = f;
	                    return k | 0
	                } else j = h; while (0);
	                h = e + 20 | 0;
	                g = c[h >> 2] | 0;
	                if ((j - g | 0) >>> 0 < d >>> 0) {
	                    k = vb[c[e + 36 >> 2] & 511](e, b, d) | 0;
	                    i = f;
	                    return k | 0
	                }
	                a:do if ((a[e + 75 >> 0] | 0) > -1) {
	                    j = d;
	                    while (1) {
	                        if (!j) {
	                            l = d;
	                            m = b;
	                            n = g;
	                            o = 0;
	                            break a
	                        }
	                        p = j + -1 | 0;
	                        if ((a[b + p >> 0] | 0) == 10)break; else j = p
	                    }
	                    if ((vb[c[e + 36 >> 2] & 511](e, b, j) | 0) >>> 0 < j >>> 0) {
	                        k = j;
	                        i = f;
	                        return k | 0
	                    } else {
	                        l = d - j | 0;
	                        m = b + j | 0;
	                        n = c[h >> 2] | 0;
	                        o = j;
	                        break
	                    }
	                } else {
	                    l = d;
	                    m = b;
	                    n = g;
	                    o = 0
	                } while (0);
	                eU(n | 0, m | 0, l | 0) | 0;
	                c[h >> 2] = (c[h >> 2] | 0) + l;
	                k = o + l | 0;
	                i = f;
	                return k | 0
	            }

	            function JT(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0;
	                f = i;
	                i = i + 16 | 0;
	                g = f;
	                c[g >> 2] = e;
	                e = LT(a, b, d, g) | 0;
	                i = f;
	                return e | 0
	            }

	            function KT(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                e = i;
	                i = i + 224 | 0;
	                f = e + 120 | 0;
	                g = e + 80 | 0;
	                h = e;
	                j = e + 136 | 0;
	                k = g + 0 | 0;
	                l = k + 40 | 0;
	                do {
	                    c[k >> 2] = 0;
	                    k = k + 4 | 0
	                } while ((k | 0) < (l | 0));
	                c[f >> 2] = c[d >> 2];
	                if ((VT(0, b, f, h, g) | 0) < 0) {
	                    m = -1;
	                    i = e;
	                    return m | 0
	                }
	                d = a + 48 | 0;
	                if (!(c[d >> 2] | 0)) {
	                    k = a + 44 | 0;
	                    l = c[k >> 2] | 0;
	                    c[k >> 2] = j;
	                    n = a + 28 | 0;
	                    c[n >> 2] = j;
	                    o = a + 20 | 0;
	                    c[o >> 2] = j;
	                    c[d >> 2] = 80;
	                    p = a + 16 | 0;
	                    c[p >> 2] = j + 80;
	                    j = VT(a, b, f, h, g) | 0;
	                    if (!l)q = j; else {
	                        vb[c[a + 36 >> 2] & 511](a, 0, 0) | 0;
	                        r = (c[o >> 2] | 0) == 0 ? -1 : j;
	                        c[k >> 2] = l;
	                        c[d >> 2] = 0;
	                        c[p >> 2] = 0;
	                        c[n >> 2] = 0;
	                        c[o >> 2] = 0;
	                        q = r
	                    }
	                } else q = VT(a, b, f, h, g) | 0;
	                m = q;
	                i = e;
	                return m | 0
	            }

	            function LT(b, d, e, f) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                g = i;
	                i = i + 128 | 0;
	                h = g + 112 | 0;
	                j = g;
	                k = j + 0 | 0;
	                l = 329664 | 0;
	                m = k + 112 | 0;
	                do {
	                    c[k >> 2] = c[l >> 2];
	                    k = k + 4 | 0;
	                    l = l + 4 | 0
	                } while ((k | 0) < (m | 0));
	                if ((d + -1 | 0) >>> 0 > 2147483646)if (!d) {
	                    n = h;
	                    o = 1
	                } else {
	                    c[(_a() | 0) >> 2] = 75;
	                    p = -1;
	                    i = g;
	                    return p | 0
	                } else {
	                    n = b;
	                    o = d
	                }
	                d = -2 - n | 0;
	                b = o >>> 0 > d >>> 0 ? d : o;
	                c[j + 48 >> 2] = b;
	                o = j + 20 | 0;
	                c[o >> 2] = n;
	                c[j + 44 >> 2] = n;
	                d = n + b | 0;
	                n = j + 16 | 0;
	                c[n >> 2] = d;
	                c[j + 28 >> 2] = d;
	                d = KT(j, e, f) | 0;
	                if (!b) {
	                    p = d;
	                    i = g;
	                    return p | 0
	                }
	                b = c[o >> 2] | 0;
	                a[b + (((b | 0) == (c[n >> 2] | 0)) << 31 >> 31) >> 0] = 0;
	                p = d;
	                i = g;
	                return p | 0
	            }

	            function MT(b) {
	                b = b | 0;
	                var c = 0, d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0;
	                c = i;
	                d = b;
	                while (1) {
	                    e = d + 1 | 0;
	                    if (!(mT(a[d >> 0] | 0) | 0))break; else d = e
	                }
	                b = a[d >> 0] | 0;
	                f = b << 24 >> 24;
	                if ((f | 0) == 43) {
	                    g = 0;
	                    h = 5
	                } else if ((f | 0) == 45) {
	                    g = 1;
	                    h = 5
	                } else {
	                    j = d;
	                    k = b;
	                    l = 0
	                }
	                if ((h | 0) == 5) {
	                    j = e;
	                    k = a[e >> 0] | 0;
	                    l = g
	                }
	                if (!(lT(k << 24 >> 24) | 0)) {
	                    m = 0;
	                    n = (l | 0) != 0;
	                    o = 0 - m | 0;
	                    p = n ? m : o;
	                    i = c;
	                    return p | 0
	                } else {
	                    q = j;
	                    r = 0
	                }
	                while (1) {
	                    j = (r * 10 | 0) + 48 - (a[q >> 0] | 0) | 0;
	                    q = q + 1 | 0;
	                    if (!(lT(a[q >> 0] | 0) | 0)) {
	                        m = j;
	                        break
	                    } else r = j
	                }
	                n = (l | 0) != 0;
	                o = 0 - m | 0;
	                p = n ? m : o;
	                i = c;
	                return p | 0
	            }

	            function NT(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0;
	                f = i;
	                g = d & 255;
	                h = (e | 0) != 0;
	                a:do if ((b & 3 | 0) != 0 & h) {
	                    j = d & 255;
	                    k = e;
	                    l = b;
	                    while (1) {
	                        if ((a[l >> 0] | 0) == j << 24 >> 24) {
	                            m = k;
	                            n = l;
	                            o = 6;
	                            break a
	                        }
	                        p = l + 1 | 0;
	                        q = k + -1 | 0;
	                        r = (q | 0) != 0;
	                        if ((p & 3 | 0) != 0 & r) {
	                            k = q;
	                            l = p
	                        } else {
	                            s = q;
	                            t = r;
	                            u = p;
	                            o = 5;
	                            break
	                        }
	                    }
	                } else {
	                    s = e;
	                    t = h;
	                    u = b;
	                    o = 5
	                } while (0);
	                if ((o | 0) == 5)if (t) {
	                    m = s;
	                    n = u;
	                    o = 6
	                } else {
	                    v = 0;
	                    w = u
	                }
	                b:do if ((o | 0) == 6) {
	                    u = d & 255;
	                    if ((a[n >> 0] | 0) != u << 24 >> 24) {
	                        s = ca(g, 16843009) | 0;
	                        c:do if (m >>> 0 > 3) {
	                            t = m;
	                            b = n;
	                            while (1) {
	                                h = c[b >> 2] ^ s;
	                                if ((h & -2139062144 ^ -2139062144) & h + -16843009) {
	                                    x = t;
	                                    y = b;
	                                    break c
	                                }
	                                h = b + 4 | 0;
	                                e = t + -4 | 0;
	                                if (e >>> 0 > 3) {
	                                    t = e;
	                                    b = h
	                                } else {
	                                    x = e;
	                                    y = h;
	                                    break
	                                }
	                            }
	                        } else {
	                            x = m;
	                            y = n
	                        } while (0);
	                        if (!x) {
	                            v = 0;
	                            w = y
	                        } else {
	                            s = x;
	                            b = y;
	                            while (1) {
	                                if ((a[b >> 0] | 0) == u << 24 >> 24) {
	                                    v = s;
	                                    w = b;
	                                    break b
	                                }
	                                t = b + 1 | 0;
	                                s = s + -1 | 0;
	                                if (!s) {
	                                    v = 0;
	                                    w = t;
	                                    break
	                                } else b = t
	                            }
	                        }
	                    } else {
	                        v = m;
	                        w = n
	                    }
	                } while (0);
	                i = f;
	                return ((v | 0) != 0 ? w : 0) | 0
	            }

	            function OT(b, c, d) {
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0;
	                e = i;
	                a:do if (!d)f = 0; else {
	                    g = d;
	                    h = b;
	                    j = c;
	                    while (1) {
	                        k = a[h >> 0] | 0;
	                        l = a[j >> 0] | 0;
	                        if (k << 24 >> 24 != l << 24 >> 24)break;
	                        g = g + -1 | 0;
	                        if (!g) {
	                            f = 0;
	                            break a
	                        } else {
	                            h = h + 1 | 0;
	                            j = j + 1 | 0
	                        }
	                    }
	                    f = (k & 255) - (l & 255) | 0
	                } while (0);
	                i = e;
	                return f | 0
	            }

	            function PT(b, c) {
	                b = b | 0;
	                c = c | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0;
	                d = i;
	                e = a[b >> 0] | 0;
	                f = a[c >> 0] | 0;
	                if (e << 24 >> 24 == 0 ? 1 : e << 24 >> 24 != f << 24 >> 24) {
	                    g = e;
	                    h = f
	                } else {
	                    f = b;
	                    b = c;
	                    do {
	                        f = f + 1 | 0;
	                        b = b + 1 | 0;
	                        c = a[f >> 0] | 0;
	                        e = a[b >> 0] | 0
	                    } while (!(c << 24 >> 24 == 0 ? 1 : c << 24 >> 24 != e << 24 >> 24));
	                    g = c;
	                    h = e
	                }
	                i = d;
	                return (g & 255) - (h & 255) | 0
	            }

	            function QT(b, c, e) {
	                b = b | 0;
	                c = c | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0;
	                f = i;
	                if (!e) {
	                    g = 0;
	                    i = f;
	                    return g | 0
	                }
	                h = a[b >> 0] | 0;
	                a:do if (!(h << 24 >> 24)) {
	                    j = 0;
	                    k = c
	                } else {
	                    l = e;
	                    m = h;
	                    n = b;
	                    o = c;
	                    while (1) {
	                        l = l + -1 | 0;
	                        p = a[o >> 0] | 0;
	                        if (!(p << 24 >> 24 != 0 & (l | 0) != 0 & m << 24 >> 24 == p << 24 >> 24)) {
	                            j = m;
	                            k = o;
	                            break a
	                        }
	                        n = n + 1 | 0;
	                        p = o + 1 | 0;
	                        m = a[n >> 0] | 0;
	                        if (!(m << 24 >> 24)) {
	                            j = 0;
	                            k = p;
	                            break
	                        } else o = p
	                    }
	                } while (0);
	                g = (j & 255) - (d[k >> 0] | 0) | 0;
	                i = f;
	                return g | 0
	            }

	            function RT(a, b, d) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0;
	                e = i;
	                f = a + 20 | 0;
	                g = c[f >> 2] | 0;
	                h = (c[a + 16 >> 2] | 0) - g | 0;
	                a = h >>> 0 > d >>> 0 ? d : h;
	                eU(g | 0, b | 0, a | 0) | 0;
	                c[f >> 2] = (c[f >> 2] | 0) + a;
	                i = e;
	                return d | 0
	            }

	            function ST(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0;
	                d = i;
	                e = a + 4 | 0;
	                f = c[e >> 2] | 0;
	                g = f & -8;
	                h = a + g | 0;
	                j = c[82068] | 0;
	                k = f & 3;
	                if (!((k | 0) != 1 & a >>> 0 >= j >>> 0 & a >>> 0 < h >>> 0))hb();
	                l = a + (g | 4) | 0;
	                m = c[l >> 2] | 0;
	                if (!(m & 1))hb();
	                if (!k) {
	                    if (b >>> 0 < 256) {
	                        n = 0;
	                        i = d;
	                        return n | 0
	                    }
	                    if (g >>> 0 >= (b + 4 | 0) >>> 0 ? (g - b | 0) >>> 0 <= c[82184] << 1 >>> 0 : 0) {
	                        n = a;
	                        i = d;
	                        return n | 0
	                    }
	                    n = 0;
	                    i = d;
	                    return n | 0
	                }
	                if (g >>> 0 >= b >>> 0) {
	                    k = g - b | 0;
	                    if (k >>> 0 <= 15) {
	                        n = a;
	                        i = d;
	                        return n | 0
	                    }
	                    c[e >> 2] = f & 1 | b | 2;
	                    c[a + (b + 4) >> 2] = k | 3;
	                    c[l >> 2] = c[l >> 2] | 1;
	                    TT(a + b | 0, k);
	                    n = a;
	                    i = d;
	                    return n | 0
	                }
	                if ((h | 0) == (c[82070] | 0)) {
	                    k = (c[82067] | 0) + g | 0;
	                    if (k >>> 0 <= b >>> 0) {
	                        n = 0;
	                        i = d;
	                        return n | 0
	                    }
	                    l = k - b | 0;
	                    c[e >> 2] = f & 1 | b | 2;
	                    c[a + (b + 4) >> 2] = l | 1;
	                    c[82070] = a + b;
	                    c[82067] = l;
	                    n = a;
	                    i = d;
	                    return n | 0
	                }
	                if ((h | 0) == (c[82069] | 0)) {
	                    l = (c[82066] | 0) + g | 0;
	                    if (l >>> 0 < b >>> 0) {
	                        n = 0;
	                        i = d;
	                        return n | 0
	                    }
	                    k = l - b | 0;
	                    if (k >>> 0 > 15) {
	                        c[e >> 2] = f & 1 | b | 2;
	                        c[a + (b + 4) >> 2] = k | 1;
	                        c[a + l >> 2] = k;
	                        o = a + (l + 4) | 0;
	                        c[o >> 2] = c[o >> 2] & -2;
	                        p = a + b | 0;
	                        q = k
	                    } else {
	                        c[e >> 2] = f & 1 | l | 2;
	                        k = a + (l + 4) | 0;
	                        c[k >> 2] = c[k >> 2] | 1;
	                        p = 0;
	                        q = 0
	                    }
	                    c[82066] = q;
	                    c[82069] = p;
	                    n = a;
	                    i = d;
	                    return n | 0
	                }
	                if (m & 2) {
	                    n = 0;
	                    i = d;
	                    return n | 0
	                }
	                p = (m & -8) + g | 0;
	                if (p >>> 0 < b >>> 0) {
	                    n = 0;
	                    i = d;
	                    return n | 0
	                }
	                q = p - b | 0;
	                k = m >>> 3;
	                do if (m >>> 0 >= 256) {
	                    l = c[a + (g + 24) >> 2] | 0;
	                    o = c[a + (g + 12) >> 2] | 0;
	                    do if ((o | 0) == (h | 0)) {
	                        r = a + (g + 20) | 0;
	                        s = c[r >> 2] | 0;
	                        if (!s) {
	                            t = a + (g + 16) | 0;
	                            u = c[t >> 2] | 0;
	                            if (!u) {
	                                v = 0;
	                                break
	                            } else {
	                                w = u;
	                                x = t
	                            }
	                        } else {
	                            w = s;
	                            x = r
	                        }
	                        while (1) {
	                            r = w + 20 | 0;
	                            s = c[r >> 2] | 0;
	                            if (s) {
	                                w = s;
	                                x = r;
	                                continue
	                            }
	                            r = w + 16 | 0;
	                            s = c[r >> 2] | 0;
	                            if (!s)break; else {
	                                w = s;
	                                x = r
	                            }
	                        }
	                        if (x >>> 0 < j >>> 0)hb(); else {
	                            c[x >> 2] = 0;
	                            v = w;
	                            break
	                        }
	                    } else {
	                        r = c[a + (g + 8) >> 2] | 0;
	                        if (r >>> 0 < j >>> 0)hb();
	                        s = r + 12 | 0;
	                        if ((c[s >> 2] | 0) != (h | 0))hb();
	                        t = o + 8 | 0;
	                        if ((c[t >> 2] | 0) == (h | 0)) {
	                            c[s >> 2] = o;
	                            c[t >> 2] = r;
	                            v = o;
	                            break
	                        } else hb()
	                    } while (0);
	                    if (l) {
	                        o = c[a + (g + 28) >> 2] | 0;
	                        r = 328560 + (o << 2) | 0;
	                        if ((h | 0) == (c[r >> 2] | 0)) {
	                            c[r >> 2] = v;
	                            if (!v) {
	                                c[82065] = c[82065] & ~(1 << o);
	                                break
	                            }
	                        } else {
	                            if (l >>> 0 < (c[82068] | 0) >>> 0)hb();
	                            o = l + 16 | 0;
	                            if ((c[o >> 2] | 0) == (h | 0))c[o >> 2] = v; else c[l + 20 >> 2] = v;
	                            if (!v)break
	                        }
	                        o = c[82068] | 0;
	                        if (v >>> 0 < o >>> 0)hb();
	                        c[v + 24 >> 2] = l;
	                        r = c[a + (g + 16) >> 2] | 0;
	                        do if (r)if (r >>> 0 < o >>> 0)hb(); else {
	                            c[v + 16 >> 2] = r;
	                            c[r + 24 >> 2] = v;
	                            break
	                        } while (0);
	                        r = c[a + (g + 20) >> 2] | 0;
	                        if (r)if (r >>> 0 < (c[82068] | 0) >>> 0)hb(); else {
	                            c[v + 20 >> 2] = r;
	                            c[r + 24 >> 2] = v;
	                            break
	                        }
	                    }
	                } else {
	                    r = c[a + (g + 8) >> 2] | 0;
	                    o = c[a + (g + 12) >> 2] | 0;
	                    l = 328296 + (k << 1 << 2) | 0;
	                    if ((r | 0) != (l | 0)) {
	                        if (r >>> 0 < j >>> 0)hb();
	                        if ((c[r + 12 >> 2] | 0) != (h | 0))hb()
	                    }
	                    if ((o | 0) == (r | 0)) {
	                        c[82064] = c[82064] & ~(1 << k);
	                        break
	                    }
	                    if ((o | 0) != (l | 0)) {
	                        if (o >>> 0 < j >>> 0)hb();
	                        l = o + 8 | 0;
	                        if ((c[l >> 2] | 0) == (h | 0))y = l; else hb()
	                    } else y = o + 8 | 0;
	                    c[r + 12 >> 2] = o;
	                    c[y >> 2] = r
	                } while (0);
	                if (q >>> 0 < 16) {
	                    c[e >> 2] = p | f & 1 | 2;
	                    y = a + (p | 4) | 0;
	                    c[y >> 2] = c[y >> 2] | 1;
	                    n = a;
	                    i = d;
	                    return n | 0
	                } else {
	                    c[e >> 2] = f & 1 | b | 2;
	                    c[a + (b + 4) >> 2] = q | 3;
	                    f = a + (p | 4) | 0;
	                    c[f >> 2] = c[f >> 2] | 1;
	                    TT(a + b | 0, q);
	                    n = a;
	                    i = d;
	                    return n | 0
	                }
	                return 0
	            }

	            function TT(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var d = 0, e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, G = 0, H = 0;
	                d = i;
	                e = a + b | 0;
	                f = c[a + 4 >> 2] | 0;
	                do if (!(f & 1)) {
	                    g = c[a >> 2] | 0;
	                    if (!(f & 3)) {
	                        i = d;
	                        return
	                    }
	                    h = a + (0 - g) | 0;
	                    j = g + b | 0;
	                    k = c[82068] | 0;
	                    if (h >>> 0 < k >>> 0)hb();
	                    if ((h | 0) == (c[82069] | 0)) {
	                        l = a + (b + 4) | 0;
	                        m = c[l >> 2] | 0;
	                        if ((m & 3 | 0) != 3) {
	                            n = h;
	                            o = j;
	                            break
	                        }
	                        c[82066] = j;
	                        c[l >> 2] = m & -2;
	                        c[a + (4 - g) >> 2] = j | 1;
	                        c[e >> 2] = j;
	                        i = d;
	                        return
	                    }
	                    m = g >>> 3;
	                    if (g >>> 0 < 256) {
	                        l = c[a + (8 - g) >> 2] | 0;
	                        p = c[a + (12 - g) >> 2] | 0;
	                        q = 328296 + (m << 1 << 2) | 0;
	                        if ((l | 0) != (q | 0)) {
	                            if (l >>> 0 < k >>> 0)hb();
	                            if ((c[l + 12 >> 2] | 0) != (h | 0))hb()
	                        }
	                        if ((p | 0) == (l | 0)) {
	                            c[82064] = c[82064] & ~(1 << m);
	                            n = h;
	                            o = j;
	                            break
	                        }
	                        if ((p | 0) != (q | 0)) {
	                            if (p >>> 0 < k >>> 0)hb();
	                            q = p + 8 | 0;
	                            if ((c[q >> 2] | 0) == (h | 0))r = q; else hb()
	                        } else r = p + 8 | 0;
	                        c[l + 12 >> 2] = p;
	                        c[r >> 2] = l;
	                        n = h;
	                        o = j;
	                        break
	                    }
	                    l = c[a + (24 - g) >> 2] | 0;
	                    p = c[a + (12 - g) >> 2] | 0;
	                    do if ((p | 0) == (h | 0)) {
	                        q = 16 - g | 0;
	                        m = a + (q + 4) | 0;
	                        s = c[m >> 2] | 0;
	                        if (!s) {
	                            t = a + q | 0;
	                            q = c[t >> 2] | 0;
	                            if (!q) {
	                                u = 0;
	                                break
	                            } else {
	                                v = q;
	                                w = t
	                            }
	                        } else {
	                            v = s;
	                            w = m
	                        }
	                        while (1) {
	                            m = v + 20 | 0;
	                            s = c[m >> 2] | 0;
	                            if (s) {
	                                v = s;
	                                w = m;
	                                continue
	                            }
	                            m = v + 16 | 0;
	                            s = c[m >> 2] | 0;
	                            if (!s)break; else {
	                                v = s;
	                                w = m
	                            }
	                        }
	                        if (w >>> 0 < k >>> 0)hb(); else {
	                            c[w >> 2] = 0;
	                            u = v;
	                            break
	                        }
	                    } else {
	                        m = c[a + (8 - g) >> 2] | 0;
	                        if (m >>> 0 < k >>> 0)hb();
	                        s = m + 12 | 0;
	                        if ((c[s >> 2] | 0) != (h | 0))hb();
	                        t = p + 8 | 0;
	                        if ((c[t >> 2] | 0) == (h | 0)) {
	                            c[s >> 2] = p;
	                            c[t >> 2] = m;
	                            u = p;
	                            break
	                        } else hb()
	                    } while (0);
	                    if (l) {
	                        p = c[a + (28 - g) >> 2] | 0;
	                        k = 328560 + (p << 2) | 0;
	                        if ((h | 0) == (c[k >> 2] | 0)) {
	                            c[k >> 2] = u;
	                            if (!u) {
	                                c[82065] = c[82065] & ~(1 << p);
	                                n = h;
	                                o = j;
	                                break
	                            }
	                        } else {
	                            if (l >>> 0 < (c[82068] | 0) >>> 0)hb();
	                            p = l + 16 | 0;
	                            if ((c[p >> 2] | 0) == (h | 0))c[p >> 2] = u; else c[l + 20 >> 2] = u;
	                            if (!u) {
	                                n = h;
	                                o = j;
	                                break
	                            }
	                        }
	                        p = c[82068] | 0;
	                        if (u >>> 0 < p >>> 0)hb();
	                        c[u + 24 >> 2] = l;
	                        k = 16 - g | 0;
	                        m = c[a + k >> 2] | 0;
	                        do if (m)if (m >>> 0 < p >>> 0)hb(); else {
	                            c[u + 16 >> 2] = m;
	                            c[m + 24 >> 2] = u;
	                            break
	                        } while (0);
	                        m = c[a + (k + 4) >> 2] | 0;
	                        if (m)if (m >>> 0 < (c[82068] | 0) >>> 0)hb(); else {
	                            c[u + 20 >> 2] = m;
	                            c[m + 24 >> 2] = u;
	                            n = h;
	                            o = j;
	                            break
	                        } else {
	                            n = h;
	                            o = j
	                        }
	                    } else {
	                        n = h;
	                        o = j
	                    }
	                } else {
	                    n = a;
	                    o = b
	                } while (0);
	                u = c[82068] | 0;
	                if (e >>> 0 < u >>> 0)hb();
	                v = a + (b + 4) | 0;
	                w = c[v >> 2] | 0;
	                if (!(w & 2)) {
	                    if ((e | 0) == (c[82070] | 0)) {
	                        r = (c[82067] | 0) + o | 0;
	                        c[82067] = r;
	                        c[82070] = n;
	                        c[n + 4 >> 2] = r | 1;
	                        if ((n | 0) != (c[82069] | 0)) {
	                            i = d;
	                            return
	                        }
	                        c[82069] = 0;
	                        c[82066] = 0;
	                        i = d;
	                        return
	                    }
	                    if ((e | 0) == (c[82069] | 0)) {
	                        r = (c[82066] | 0) + o | 0;
	                        c[82066] = r;
	                        c[82069] = n;
	                        c[n + 4 >> 2] = r | 1;
	                        c[n + r >> 2] = r;
	                        i = d;
	                        return
	                    }
	                    r = (w & -8) + o | 0;
	                    f = w >>> 3;
	                    do if (w >>> 0 >= 256) {
	                        m = c[a + (b + 24) >> 2] | 0;
	                        p = c[a + (b + 12) >> 2] | 0;
	                        do if ((p | 0) == (e | 0)) {
	                            g = a + (b + 20) | 0;
	                            l = c[g >> 2] | 0;
	                            if (!l) {
	                                t = a + (b + 16) | 0;
	                                s = c[t >> 2] | 0;
	                                if (!s) {
	                                    x = 0;
	                                    break
	                                } else {
	                                    y = s;
	                                    z = t
	                                }
	                            } else {
	                                y = l;
	                                z = g
	                            }
	                            while (1) {
	                                g = y + 20 | 0;
	                                l = c[g >> 2] | 0;
	                                if (l) {
	                                    y = l;
	                                    z = g;
	                                    continue
	                                }
	                                g = y + 16 | 0;
	                                l = c[g >> 2] | 0;
	                                if (!l)break; else {
	                                    y = l;
	                                    z = g
	                                }
	                            }
	                            if (z >>> 0 < u >>> 0)hb(); else {
	                                c[z >> 2] = 0;
	                                x = y;
	                                break
	                            }
	                        } else {
	                            g = c[a + (b + 8) >> 2] | 0;
	                            if (g >>> 0 < u >>> 0)hb();
	                            l = g + 12 | 0;
	                            if ((c[l >> 2] | 0) != (e | 0))hb();
	                            t = p + 8 | 0;
	                            if ((c[t >> 2] | 0) == (e | 0)) {
	                                c[l >> 2] = p;
	                                c[t >> 2] = g;
	                                x = p;
	                                break
	                            } else hb()
	                        } while (0);
	                        if (m) {
	                            p = c[a + (b + 28) >> 2] | 0;
	                            j = 328560 + (p << 2) | 0;
	                            if ((e | 0) == (c[j >> 2] | 0)) {
	                                c[j >> 2] = x;
	                                if (!x) {
	                                    c[82065] = c[82065] & ~(1 << p);
	                                    break
	                                }
	                            } else {
	                                if (m >>> 0 < (c[82068] | 0) >>> 0)hb();
	                                p = m + 16 | 0;
	                                if ((c[p >> 2] | 0) == (e | 0))c[p >> 2] = x; else c[m + 20 >> 2] = x;
	                                if (!x)break
	                            }
	                            p = c[82068] | 0;
	                            if (x >>> 0 < p >>> 0)hb();
	                            c[x + 24 >> 2] = m;
	                            j = c[a + (b + 16) >> 2] | 0;
	                            do if (j)if (j >>> 0 < p >>> 0)hb(); else {
	                                c[x + 16 >> 2] = j;
	                                c[j + 24 >> 2] = x;
	                                break
	                            } while (0);
	                            j = c[a + (b + 20) >> 2] | 0;
	                            if (j)if (j >>> 0 < (c[82068] | 0) >>> 0)hb(); else {
	                                c[x + 20 >> 2] = j;
	                                c[j + 24 >> 2] = x;
	                                break
	                            }
	                        }
	                    } else {
	                        j = c[a + (b + 8) >> 2] | 0;
	                        p = c[a + (b + 12) >> 2] | 0;
	                        m = 328296 + (f << 1 << 2) | 0;
	                        if ((j | 0) != (m | 0)) {
	                            if (j >>> 0 < u >>> 0)hb();
	                            if ((c[j + 12 >> 2] | 0) != (e | 0))hb()
	                        }
	                        if ((p | 0) == (j | 0)) {
	                            c[82064] = c[82064] & ~(1 << f);
	                            break
	                        }
	                        if ((p | 0) != (m | 0)) {
	                            if (p >>> 0 < u >>> 0)hb();
	                            m = p + 8 | 0;
	                            if ((c[m >> 2] | 0) == (e | 0))A = m; else hb()
	                        } else A = p + 8 | 0;
	                        c[j + 12 >> 2] = p;
	                        c[A >> 2] = j
	                    } while (0);
	                    c[n + 4 >> 2] = r | 1;
	                    c[n + r >> 2] = r;
	                    if ((n | 0) == (c[82069] | 0)) {
	                        c[82066] = r;
	                        i = d;
	                        return
	                    } else B = r
	                } else {
	                    c[v >> 2] = w & -2;
	                    c[n + 4 >> 2] = o | 1;
	                    c[n + o >> 2] = o;
	                    B = o
	                }
	                o = B >>> 3;
	                if (B >>> 0 < 256) {
	                    w = o << 1;
	                    v = 328296 + (w << 2) | 0;
	                    r = c[82064] | 0;
	                    A = 1 << o;
	                    if (r & A) {
	                        o = 328296 + (w + 2 << 2) | 0;
	                        e = c[o >> 2] | 0;
	                        if (e >>> 0 < (c[82068] | 0) >>> 0)hb(); else {
	                            C = o;
	                            D = e
	                        }
	                    } else {
	                        c[82064] = r | A;
	                        C = 328296 + (w + 2 << 2) | 0;
	                        D = v
	                    }
	                    c[C >> 2] = n;
	                    c[D + 12 >> 2] = n;
	                    c[n + 8 >> 2] = D;
	                    c[n + 12 >> 2] = v;
	                    i = d;
	                    return
	                }
	                v = B >>> 8;
	                if (v)if (B >>> 0 > 16777215)E = 31; else {
	                    D = (v + 1048320 | 0) >>> 16 & 8;
	                    C = v << D;
	                    v = (C + 520192 | 0) >>> 16 & 4;
	                    w = C << v;
	                    C = (w + 245760 | 0) >>> 16 & 2;
	                    A = 14 - (v | D | C) + (w << C >>> 15) | 0;
	                    E = B >>> (A + 7 | 0) & 1 | A << 1
	                } else E = 0;
	                A = 328560 + (E << 2) | 0;
	                c[n + 28 >> 2] = E;
	                c[n + 20 >> 2] = 0;
	                c[n + 16 >> 2] = 0;
	                C = c[82065] | 0;
	                w = 1 << E;
	                if (!(C & w)) {
	                    c[82065] = C | w;
	                    c[A >> 2] = n;
	                    c[n + 24 >> 2] = A;
	                    c[n + 12 >> 2] = n;
	                    c[n + 8 >> 2] = n;
	                    i = d;
	                    return
	                }
	                w = c[A >> 2] | 0;
	                if ((E | 0) == 31)F = 0; else F = 25 - (E >>> 1) | 0;
	                a:do if ((c[w + 4 >> 2] & -8 | 0) == (B | 0))G = w; else {
	                    E = B << F;
	                    A = w;
	                    while (1) {
	                        H = A + (E >>> 31 << 2) + 16 | 0;
	                        C = c[H >> 2] | 0;
	                        if (!C)break;
	                        if ((c[C + 4 >> 2] & -8 | 0) == (B | 0)) {
	                            G = C;
	                            break a
	                        } else {
	                            E = E << 1;
	                            A = C
	                        }
	                    }
	                    if (H >>> 0 < (c[82068] | 0) >>> 0)hb();
	                    c[H >> 2] = n;
	                    c[n + 24 >> 2] = A;
	                    c[n + 12 >> 2] = n;
	                    c[n + 8 >> 2] = n;
	                    i = d;
	                    return
	                } while (0);
	                H = G + 8 | 0;
	                B = c[H >> 2] | 0;
	                w = c[82068] | 0;
	                if (!(G >>> 0 >= w >>> 0 & B >>> 0 >= w >>> 0))hb();
	                c[B + 12 >> 2] = n;
	                c[H >> 2] = n;
	                c[n + 8 >> 2] = B;
	                c[n + 12 >> 2] = G;
	                c[n + 24 >> 2] = 0;
	                i = d;
	                return
	            }

	            function UT(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var e = 0, f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0;
	                e = i;
	                f = a + 4 | 0;
	                g = c[f >> 2] | 0;
	                h = a + 100 | 0;
	                if (g >>> 0 < (c[h >> 2] | 0) >>> 0) {
	                    c[f >> 2] = g + 1;
	                    j = d[g >> 0] | 0
	                } else j = qT(a) | 0;
	                if ((j | 0) == 43 | (j | 0) == 45) {
	                    g = c[f >> 2] | 0;
	                    k = (j | 0) == 45 & 1;
	                    if (g >>> 0 < (c[h >> 2] | 0) >>> 0) {
	                        c[f >> 2] = g + 1;
	                        l = d[g >> 0] | 0
	                    } else l = qT(a) | 0;
	                    if ((l + -48 | 0) >>> 0 > 9 & (b | 0) != 0 ? (c[h >> 2] | 0) != 0 : 0) {
	                        c[f >> 2] = (c[f >> 2] | 0) + -1;
	                        m = l;
	                        n = k
	                    } else {
	                        m = l;
	                        n = k
	                    }
	                } else {
	                    m = j;
	                    n = 0
	                }
	                if ((m + -48 | 0) >>> 0 > 9) {
	                    if (!(c[h >> 2] | 0)) {
	                        o = -2147483648;
	                        p = 0;
	                        G = o;
	                        i = e;
	                        return p | 0
	                    }
	                    c[f >> 2] = (c[f >> 2] | 0) + -1;
	                    o = -2147483648;
	                    p = 0;
	                    G = o;
	                    i = e;
	                    return p | 0
	                } else {
	                    q = m;
	                    r = 0
	                }
	                while (1) {
	                    r = q + -48 + (r * 10 | 0) | 0;
	                    m = c[f >> 2] | 0;
	                    if (m >>> 0 < (c[h >> 2] | 0) >>> 0) {
	                        c[f >> 2] = m + 1;
	                        s = d[m >> 0] | 0
	                    } else s = qT(a) | 0;
	                    if (!((s + -48 | 0) >>> 0 < 10 & (r | 0) < 214748364))break; else q = s
	                }
	                q = ((r | 0) < 0) << 31 >> 31;
	                if ((s + -48 | 0) >>> 0 < 10) {
	                    m = r;
	                    j = q;
	                    k = s;
	                    while (1) {
	                        l = mU(m | 0, j | 0, 10, 0) | 0;
	                        b = G;
	                        g = bU(k | 0, ((k | 0) < 0) << 31 >> 31 | 0, -48, -1) | 0;
	                        t = bU(g | 0, G | 0, l | 0, b | 0) | 0;
	                        b = G;
	                        l = c[f >> 2] | 0;
	                        if (l >>> 0 < (c[h >> 2] | 0) >>> 0) {
	                            c[f >> 2] = l + 1;
	                            u = d[l >> 0] | 0
	                        } else u = qT(a) | 0;
	                        if ((u + -48 | 0) >>> 0 < 10 & ((b | 0) < 21474836 | (b | 0) == 21474836 & t >>> 0 < 2061584302)) {
	                            m = t;
	                            j = b;
	                            k = u
	                        } else {
	                            v = t;
	                            w = b;
	                            x = u;
	                            break
	                        }
	                    }
	                } else {
	                    v = r;
	                    w = q;
	                    x = s
	                }
	                if ((x + -48 | 0) >>> 0 < 10)do {
	                    x = c[f >> 2] | 0;
	                    if (x >>> 0 < (c[h >> 2] | 0) >>> 0) {
	                        c[f >> 2] = x + 1;
	                        y = d[x >> 0] | 0
	                    } else y = qT(a) | 0
	                } while ((y + -48 | 0) >>> 0 < 10);
	                if (c[h >> 2] | 0)c[f >> 2] = (c[f >> 2] | 0) + -1;
	                f = (n | 0) != 0;
	                n = XT(0, 0, v | 0, w | 0) | 0;
	                o = f ? G : w;
	                p = f ? n : v;
	                G = o;
	                i = e;
	                return p | 0
	            }

	            function VT(e, f, g, j, l) {
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                j = j | 0;
	                l = l | 0;
	                var m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, H = 0, I = 0, J = 0, K = 0, L = 0, M = 0, N = 0, O = 0, P = 0, Q = 0, R = 0, S = 0, T = 0, U = 0, V = 0, W = 0, X = 0, Y = 0, Z = 0, _ = 0, $ = 0, aa = 0, ba = 0, da = 0, ea = 0, fa = 0, ga = 0, ha = 0, ia = 0, ja = 0, ka = 0, la = 0, ma = 0, na = 0, oa = 0, pa = 0, qa = 0, ra = 0, sa = 0, ta = 0, ua = 0, va = 0, wa = 0, xa = 0, ya = 0, za = 0, Aa = 0, Ba = 0, Ca = 0, Da = 0, Ea = 0, Fa = 0, Ga = 0, Ha = 0, Ia = 0, Ja = 0, Ka = 0, La = 0.0, Ma = 0, Na = 0, Oa = 0, Pa = 0, Qa = 0, Ra = 0.0, Sa = 0, Ta = 0, Ua = 0, Va = 0, Wa = 0, Xa = 0, Ya = 0, Za = 0, $a = 0, ab = 0, bb = 0, cb = 0, db = 0, eb = 0.0, fb = 0.0, gb = 0, hb = 0, ib = 0, jb = 0, kb = 0, mb = 0.0, nb = 0, ob = 0, pb = 0, qb = 0, rb = 0, sb = 0, tb = 0, ub = 0, vb = 0, wb = 0, xb = 0.0, yb = 0, zb = 0, Ab = 0, Bb = 0, Cb = 0, Db = 0, Eb = 0, Fb = 0, Gb = 0, Hb = 0, Ib = 0, Jb = 0, Kb = 0, Lb = 0, Mb = 0, Nb = 0, Ob = 0, Pb = 0, Qb = 0, Rb = 0, Sb = 0, Tb = 0, Ub = 0, Vb = 0, Wb = 0, Xb = 0, Yb = 0, Zb = 0, _b = 0, $b = 0, ac = 0.0, bc = 0.0, cc = 0.0, dc = 0, ec = 0, fc = 0, gc = 0, hc = 0, ic = 0, jc = 0, kc = 0, lc = 0, mc = 0, nc = 0, oc = 0, pc = 0, qc = 0, rc = 0, sc = 0, tc = 0, uc = 0, vc = 0, wc = 0, xc = 0, yc = 0, zc = 0, Ac = 0, Bc = 0, Cc = 0, Dc = 0, Ec = 0, Fc = 0, Gc = 0, Hc = 0, Ic = 0, Jc = 0, Kc = 0, Lc = 0, Mc = 0, Nc = 0, Oc = 0, Pc = 0, Qc = 0, Rc = 0, Sc = 0, Tc = 0, Uc = 0, Vc = 0, Wc = 0, Xc = 0, Yc = 0, Zc = 0, _c = 0, $c = 0, ad = 0, bd = 0, cd = 0, dd = 0, ed = 0, fd = 0, gd = 0, hd = 0, id = 0, jd = 0, kd = 0, ld = 0, md = 0, nd = 0, od = 0, pd = 0, qd = 0, rd = 0, sd = 0, td = 0, ud = 0, vd = 0, wd = 0;
	                m = i;
	                i = i + 864 | 0;
	                n = m + 16 | 0;
	                o = m + 8 | 0;
	                p = m + 836 | 0;
	                q = p;
	                r = m + 824 | 0;
	                s = m + 568 | 0;
	                t = m + 528 | 0;
	                u = m;
	                v = m + 520 | 0;
	                w = (e | 0) != 0;
	                x = t + 40 | 0;
	                y = x;
	                z = t + 39 | 0;
	                t = u + 4 | 0;
	                A = u;
	                B = r + 12 | 0;
	                C = r + 11 | 0;
	                r = B;
	                D = r - q | 0;
	                E = -2 - q | 0;
	                F = r + 2 | 0;
	                H = n + 288 | 0;
	                I = p + 9 | 0;
	                J = I;
	                K = p + 8 | 0;
	                L = 0;
	                M = 0;
	                N = f;
	                f = 0;
	                O = 0;
	                P = 0;
	                a:while (1) {
	                    do if ((f | 0) > -1)if ((O | 0) > (2147483647 - f | 0)) {
	                        c[(_a() | 0) >> 2] = 75;
	                        Q = -1;
	                        break
	                    } else {
	                        Q = O + f | 0;
	                        break
	                    } else Q = f; while (0);
	                    R = a[N >> 0] | 0;
	                    if (!(R << 24 >> 24)) {
	                        S = 352;
	                        break
	                    } else {
	                        T = R;
	                        U = N
	                    }
	                    while (1) {
	                        if (T << 24 >> 24 == 37) {
	                            V = U;
	                            W = U;
	                            S = 9;
	                            break
	                        } else if (!(T << 24 >> 24)) {
	                            X = U;
	                            Y = U;
	                            break
	                        }
	                        R = U + 1 | 0;
	                        T = a[R >> 0] | 0;
	                        U = R
	                    }
	                    b:do if ((S | 0) == 9)while (1) {
	                        S = 0;
	                        if ((a[V + 1 >> 0] | 0) != 37) {
	                            X = V;
	                            Y = W;
	                            break b
	                        }
	                        R = W + 1 | 0;
	                        Z = V + 2 | 0;
	                        if ((a[Z >> 0] | 0) == 37) {
	                            V = Z;
	                            W = R;
	                            S = 9
	                        } else {
	                            X = Z;
	                            Y = R;
	                            break
	                        }
	                    } while (0);
	                    R = Y - N | 0;
	                    if (w)IT(N, R, e) | 0;
	                    if ((Y | 0) != (N | 0)) {
	                        N = X;
	                        f = Q;
	                        O = R;
	                        continue
	                    }
	                    Z = X + 1 | 0;
	                    _ = a[Z >> 0] | 0;
	                    $ = (_ << 24 >> 24) + -48 | 0;
	                    if ($ >>> 0 < 10 ? (a[X + 2 >> 0] | 0) == 36 : 0) {
	                        aa = X + 3 | 0;
	                        ba = a[aa >> 0] | 0;
	                        da = $;
	                        ea = 1;
	                        fa = aa
	                    } else {
	                        ba = _;
	                        da = -1;
	                        ea = P;
	                        fa = Z
	                    }
	                    Z = ba << 24 >> 24;
	                    c:do if ((Z & -32 | 0) == 32) {
	                        _ = ba;
	                        aa = Z;
	                        $ = 0;
	                        ga = fa;
	                        while (1) {
	                            ha = 1 << aa + -32;
	                            if (!(ha & 75913)) {
	                                ia = _;
	                                ja = $;
	                                ka = ga;
	                                break c
	                            }
	                            la = ha | $;
	                            ha = ga + 1 | 0;
	                            ma = a[ha >> 0] | 0;
	                            aa = ma << 24 >> 24;
	                            if ((aa & -32 | 0) != 32) {
	                                ia = ma;
	                                ja = la;
	                                ka = ha;
	                                break
	                            } else {
	                                _ = ma;
	                                $ = la;
	                                ga = ha
	                            }
	                        }
	                    } else {
	                        ia = ba;
	                        ja = 0;
	                        ka = fa
	                    } while (0);
	                    do if (ia << 24 >> 24 == 42) {
	                        Z = ka + 1 | 0;
	                        ga = (a[Z >> 0] | 0) + -48 | 0;
	                        if (ga >>> 0 < 10 ? (a[ka + 2 >> 0] | 0) == 36 : 0) {
	                            c[l + (ga << 2) >> 2] = 10;
	                            na = 1;
	                            oa = ka + 3 | 0;
	                            pa = c[j + ((a[Z >> 0] | 0) + -48 << 3) >> 2] | 0
	                        } else {
	                            if (ea) {
	                                qa = -1;
	                                S = 370;
	                                break a
	                            }
	                            if (!w) {
	                                ra = Z;
	                                sa = ja;
	                                ta = 0;
	                                ua = 0;
	                                break
	                            }
	                            ga = c[g >> 2] | 0;
	                            $ = c[ga >> 2] | 0;
	                            c[g >> 2] = ga + 4;
	                            na = 0;
	                            oa = Z;
	                            pa = $
	                        }
	                        if ((pa | 0) < 0) {
	                            ra = oa;
	                            sa = ja | 8192;
	                            ta = na;
	                            ua = 0 - pa | 0
	                        } else {
	                            ra = oa;
	                            sa = ja;
	                            ta = na;
	                            ua = pa
	                        }
	                    } else {
	                        $ = ia << 24 >> 24;
	                        if (($ + -48 | 0) >>> 0 < 10) {
	                            Z = $;
	                            $ = ka;
	                            ga = 0;
	                            do {
	                                ga = Z + -48 + (ga * 10 | 0) | 0;
	                                $ = $ + 1 | 0;
	                                Z = a[$ >> 0] | 0
	                            } while ((Z + -48 | 0) >>> 0 < 10);
	                            if ((ga | 0) < 0) {
	                                qa = -1;
	                                S = 370;
	                                break a
	                            } else {
	                                ra = $;
	                                sa = ja;
	                                ta = ea;
	                                ua = ga
	                            }
	                        } else {
	                            ra = ka;
	                            sa = ja;
	                            ta = ea;
	                            ua = 0
	                        }
	                    } while (0);
	                    d:do if ((a[ra >> 0] | 0) == 46) {
	                        Z = ra + 1 | 0;
	                        _ = a[Z >> 0] | 0;
	                        if (_ << 24 >> 24 != 42) {
	                            aa = _ << 24 >> 24;
	                            if ((aa + -48 | 0) >>> 0 < 10) {
	                                va = aa;
	                                wa = Z;
	                                xa = 0
	                            } else {
	                                ya = Z;
	                                za = 0;
	                                break
	                            }
	                            while (1) {
	                                Z = va + -48 + (xa * 10 | 0) | 0;
	                                aa = wa + 1 | 0;
	                                va = a[aa >> 0] | 0;
	                                if ((va + -48 | 0) >>> 0 >= 10) {
	                                    ya = aa;
	                                    za = Z;
	                                    break d
	                                } else {
	                                    wa = aa;
	                                    xa = Z
	                                }
	                            }
	                        }
	                        ga = ra + 2 | 0;
	                        $ = (a[ga >> 0] | 0) + -48 | 0;
	                        if ($ >>> 0 < 10 ? (a[ra + 3 >> 0] | 0) == 36 : 0) {
	                            c[l + ($ << 2) >> 2] = 10;
	                            ya = ra + 4 | 0;
	                            za = c[j + ((a[ga >> 0] | 0) + -48 << 3) >> 2] | 0;
	                            break
	                        }
	                        if (ta) {
	                            qa = -1;
	                            S = 370;
	                            break a
	                        }
	                        if (w) {
	                            $ = c[g >> 2] | 0;
	                            Z = c[$ >> 2] | 0;
	                            c[g >> 2] = $ + 4;
	                            ya = ga;
	                            za = Z
	                        } else {
	                            ya = ga;
	                            za = 0
	                        }
	                    } else {
	                        ya = ra;
	                        za = -1
	                    } while (0);
	                    ga = ya;
	                    Z = 0;
	                    while (1) {
	                        Aa = a[ga >> 0] | 0;
	                        $ = (Aa << 24 >> 24) + -65 | 0;
	                        if ($ >>> 0 > 57) {
	                            qa = -1;
	                            S = 370;
	                            break a
	                        }
	                        Ba = ga + 1 | 0;
	                        Ca = a[329096 + (Z * 58 | 0) + $ >> 0] | 0;
	                        Da = Ca & 255;
	                        if ((Da + -1 | 0) >>> 0 < 8) {
	                            ga = Ba;
	                            Z = Da
	                        } else break
	                    }
	                    if (!(Ca << 24 >> 24)) {
	                        qa = -1;
	                        S = 370;
	                        break
	                    }
	                    $ = (da | 0) > -1;
	                    e:do if (Ca << 24 >> 24 == 19)if ($) {
	                        qa = -1;
	                        S = 370;
	                        break a
	                    } else {
	                        Ea = L;
	                        Fa = M;
	                        S = 63
	                    } else {
	                        if ($) {
	                            c[l + (da << 2) >> 2] = Da;
	                            aa = j + (da << 3) | 0;
	                            Ea = c[aa >> 2] | 0;
	                            Fa = c[aa + 4 >> 2] | 0;
	                            S = 63;
	                            break
	                        }
	                        if (!w) {
	                            qa = 0;
	                            S = 370;
	                            break a
	                        }
	                        if ((Ca & 255) > 20) {
	                            Ga = Aa;
	                            Ha = L;
	                            Ia = M
	                        } else do switch (Da | 0) {
	                            case 16:
	                            {
	                                aa = c[g >> 2] | 0;
	                                _ = c[aa >> 2] | 0;
	                                c[g >> 2] = aa + 4;
	                                Ja = 0;
	                                Ka = _ & 255;
	                                S = 64;
	                                break e;
	                                break
	                            }
	                            case 11:
	                            {
	                                _ = c[g >> 2] | 0;
	                                aa = c[_ >> 2] | 0;
	                                c[g >> 2] = _ + 4;
	                                Ja = 0;
	                                Ka = aa;
	                                S = 64;
	                                break e;
	                                break
	                            }
	                            case 12:
	                            {
	                                aa = c[g >> 2] | 0;
	                                _ = aa;
	                                ha = c[_ >> 2] | 0;
	                                la = c[_ + 4 >> 2] | 0;
	                                c[g >> 2] = aa + 8;
	                                Ja = la;
	                                Ka = ha;
	                                S = 64;
	                                break e;
	                                break
	                            }
	                            case 14:
	                            {
	                                ha = c[g >> 2] | 0;
	                                la = c[ha >> 2] | 0;
	                                c[g >> 2] = ha + 4;
	                                Ja = 0;
	                                Ka = la & 65535;
	                                S = 64;
	                                break e;
	                                break
	                            }
	                            case 13:
	                            {
	                                la = c[g >> 2] | 0;
	                                ha = c[la >> 2] | 0;
	                                c[g >> 2] = la + 4;
	                                Ja = (((ha & 65535) << 16 >> 16 | 0) < 0) << 31 >> 31;
	                                Ka = ha << 16 >> 16;
	                                S = 64;
	                                break e;
	                                break
	                            }
	                            case 17:
	                            {
	                                ha = c[g >> 2] | 0;
	                                c[k >> 2] = c[ha >> 2];
	                                c[k + 4 >> 2] = c[ha + 4 >> 2];
	                                La = +h[k >> 3];
	                                c[g >> 2] = ha + 8;
	                                h[k >> 3] = La;
	                                Ja = c[k + 4 >> 2] | 0;
	                                Ka = c[k >> 2] | 0;
	                                S = 64;
	                                break e;
	                                break
	                            }
	                            case 10:
	                            {
	                                ha = c[g >> 2] | 0;
	                                la = c[ha >> 2] | 0;
	                                c[g >> 2] = ha + 4;
	                                Ja = ((la | 0) < 0) << 31 >> 31;
	                                Ka = la;
	                                S = 64;
	                                break e;
	                                break
	                            }
	                            case 15:
	                            {
	                                la = c[g >> 2] | 0;
	                                ha = c[la >> 2] | 0;
	                                c[g >> 2] = la + 4;
	                                Ja = (((ha & 255) << 24 >> 24 | 0) < 0) << 31 >> 31;
	                                Ka = ha << 24 >> 24;
	                                S = 64;
	                                break e;
	                                break
	                            }
	                            case 18:
	                            {
	                                ha = c[g >> 2] | 0;
	                                c[k >> 2] = c[ha >> 2];
	                                c[k + 4 >> 2] = c[ha + 4 >> 2];
	                                La = +h[k >> 3];
	                                c[g >> 2] = ha + 8;
	                                h[k >> 3] = La;
	                                Ea = c[k >> 2] | 0;
	                                Fa = c[k + 4 >> 2] | 0;
	                                S = 63;
	                                break e;
	                                break
	                            }
	                            case 9:
	                            {
	                                ha = c[g >> 2] | 0;
	                                la = c[ha >> 2] | 0;
	                                c[g >> 2] = ha + 4;
	                                Ja = M;
	                                Ka = la;
	                                S = 64;
	                                break e;
	                                break
	                            }
	                            default:
	                            {
	                                Ja = M;
	                                Ka = L;
	                                S = 64;
	                                break e
	                            }
	                        } while (0)
	                    } while (0);
	                    if ((S | 0) == 63) {
	                        S = 0;
	                        if (w) {
	                            Ja = Fa;
	                            Ka = Ea;
	                            S = 64
	                        } else {
	                            L = Ea;
	                            M = Fa;
	                            N = Ba;
	                            f = Q;
	                            O = R;
	                            P = ta;
	                            continue
	                        }
	                    }
	                    if ((S | 0) == 64) {
	                        S = 0;
	                        Ga = a[ga >> 0] | 0;
	                        Ha = Ka;
	                        Ia = Ja
	                    }
	                    $ = Ga << 24 >> 24;
	                    la = (Z | 0) != 0 & ($ & 15 | 0) == 3 ? $ & -33 : $;
	                    $ = sa & -65537;
	                    ha = (sa & 8192 | 0) == 0 ? sa : $;
	                    f:do switch (la | 0) {
	                        case 110:
	                        {
	                            switch (Z | 0) {
	                                case 7:
	                                {
	                                    aa = Ha;
	                                    c[aa >> 2] = Q;
	                                    c[aa + 4 >> 2] = ((Q | 0) < 0) << 31 >> 31;
	                                    L = Ha;
	                                    M = Ia;
	                                    N = Ba;
	                                    f = Q;
	                                    O = R;
	                                    P = ta;
	                                    continue a;
	                                    break
	                                }
	                                case 3:
	                                {
	                                    b[Ha >> 1] = Q;
	                                    L = Ha;
	                                    M = Ia;
	                                    N = Ba;
	                                    f = Q;
	                                    O = R;
	                                    P = ta;
	                                    continue a;
	                                    break
	                                }
	                                case 4:
	                                {
	                                    a[Ha >> 0] = Q;
	                                    L = Ha;
	                                    M = Ia;
	                                    N = Ba;
	                                    f = Q;
	                                    O = R;
	                                    P = ta;
	                                    continue a;
	                                    break
	                                }
	                                case 6:
	                                {
	                                    c[Ha >> 2] = Q;
	                                    L = Ha;
	                                    M = Ia;
	                                    N = Ba;
	                                    f = Q;
	                                    O = R;
	                                    P = ta;
	                                    continue a;
	                                    break
	                                }
	                                case 1:
	                                {
	                                    c[Ha >> 2] = Q;
	                                    L = Ha;
	                                    M = Ia;
	                                    N = Ba;
	                                    f = Q;
	                                    O = R;
	                                    P = ta;
	                                    continue a;
	                                    break
	                                }
	                                case 0:
	                                {
	                                    c[Ha >> 2] = Q;
	                                    L = Ha;
	                                    M = Ia;
	                                    N = Ba;
	                                    f = Q;
	                                    O = R;
	                                    P = ta;
	                                    continue a;
	                                    break
	                                }
	                                case 2:
	                                {
	                                    aa = Ha;
	                                    c[aa >> 2] = Q;
	                                    c[aa + 4 >> 2] = ((Q | 0) < 0) << 31 >> 31;
	                                    L = Ha;
	                                    M = Ia;
	                                    N = Ba;
	                                    f = Q;
	                                    O = R;
	                                    P = ta;
	                                    continue a;
	                                    break
	                                }
	                                default:
	                                {
	                                    L = Ha;
	                                    M = Ia;
	                                    N = Ba;
	                                    f = Q;
	                                    O = R;
	                                    P = ta;
	                                    continue a
	                                }
	                            }
	                            break
	                        }
	                        case 109:
	                        {
	                            Ma = lb(c[(_a() | 0) >> 2] | 0) | 0;
	                            S = 96;
	                            break
	                        }
	                        case 105:
	                        case 100:
	                        {
	                            if ((Ia | 0) < 0) {
	                                aa = XT(0, 0, Ha | 0, Ia | 0) | 0;
	                                Na = G;
	                                Oa = aa;
	                                Pa = 1;
	                                Qa = 329560;
	                                S = 86;
	                                break f
	                            }
	                            if (!(ha & 2048)) {
	                                aa = ha & 1;
	                                Na = Ia;
	                                Oa = Ha;
	                                Pa = aa;
	                                Qa = (aa | 0) == 0 ? 329560 : 329562;
	                                S = 86
	                            } else {
	                                Na = Ia;
	                                Oa = Ha;
	                                Pa = 1;
	                                Qa = 329561;
	                                S = 86
	                            }
	                            break
	                        }
	                        case 65:
	                        case 71:
	                        case 70:
	                        case 69:
	                        case 97:
	                        case 103:
	                        case 102:
	                        case 101:
	                        {
	                            c[k >> 2] = Ha;
	                            c[k + 4 >> 2] = Ia;
	                            La = +h[k >> 3];
	                            c[o >> 2] = 0;
	                            if ((Ia | 0) >= 0)if (!(ha & 2048)) {
	                                aa = ha & 1;
	                                Ra = La;
	                                Sa = aa;
	                                Ta = (aa | 0) == 0 ? 329585 : 329590
	                            } else {
	                                Ra = La;
	                                Sa = 1;
	                                Ta = 329587
	                            } else {
	                                Ra = -La;
	                                Sa = 1;
	                                Ta = 329584
	                            }
	                            h[k >> 3] = Ra;
	                            aa = c[k + 4 >> 2] & 2146435072;
	                            if (!(aa >>> 0 < 2146435072 | (aa | 0) == 2146435072 & 0 < 0)) {
	                                aa = (la & 32 | 0) != 0;
	                                if (Ra != Ra | 0.0 != 0.0) {
	                                    Ua = 0;
	                                    Va = aa ? 329624 : 329632
	                                } else {
	                                    Ua = Sa;
	                                    Va = aa ? 329608 : 329616
	                                }
	                                aa = Ua + 3 | 0;
	                                _ = (ua | 0) > (aa | 0);
	                                if ((ha & 8192 | 0) == 0 & _) {
	                                    ma = ua - aa | 0;
	                                    cU(s | 0, 32, (ma >>> 0 > 256 ? 256 : ma) | 0) | 0;
	                                    if (ma >>> 0 > 255) {
	                                        Wa = ma;
	                                        do {
	                                            IT(s, 256, e) | 0;
	                                            Wa = Wa + -256 | 0
	                                        } while (Wa >>> 0 > 255);
	                                        Xa = ma & 255
	                                    } else Xa = ma;
	                                    IT(s, Xa, e) | 0
	                                }
	                                IT(Ta, Ua, e) | 0;
	                                IT(Va, 3, e) | 0;
	                                if ((ha & 73728 | 0) == 8192 & _) {
	                                    Wa = ua - aa | 0;
	                                    cU(s | 0, 32, (Wa >>> 0 > 256 ? 256 : Wa) | 0) | 0;
	                                    if (Wa >>> 0 > 255) {
	                                        Ya = Wa;
	                                        do {
	                                            IT(s, 256, e) | 0;
	                                            Ya = Ya + -256 | 0
	                                        } while (Ya >>> 0 > 255);
	                                        Za = Wa & 255
	                                    } else Za = Wa;
	                                    IT(s, Za, e) | 0
	                                }
	                                L = Ha;
	                                M = Ia;
	                                N = Ba;
	                                f = Q;
	                                O = _ ? ua : aa;
	                                P = ta;
	                                continue a
	                            }
	                            La = +xT(Ra, o) * 2.0;
	                            Ya = La != 0.0;
	                            if (Ya)c[o >> 2] = (c[o >> 2] | 0) + -1;
	                            ma = la | 32;
	                            if ((ma | 0) == 97) {
	                                $a = la & 32;
	                                ab = ($a | 0) == 0 ? Ta : Ta + 9 | 0;
	                                bb = Sa | 2;
	                                cb = za >>> 0 > 11 ? 0 : 12 - za | 0;
	                                do if (cb) {
	                                    db = cb;
	                                    eb = 8.0;
	                                    do {
	                                        db = db + -1 | 0;
	                                        eb = eb * 16.0
	                                    } while ((db | 0) != 0);
	                                    if ((a[ab >> 0] | 0) == 45) {
	                                        fb = -(eb + (-La - eb));
	                                        break
	                                    } else {
	                                        fb = La + eb - eb;
	                                        break
	                                    }
	                                } else fb = La; while (0);
	                                cb = c[o >> 2] | 0;
	                                aa = (cb | 0) < 0 ? 0 - cb | 0 : cb;
	                                if ((aa | 0) < 0) {
	                                    cb = B;
	                                    _ = aa;
	                                    Wa = ((aa | 0) < 0) << 31 >> 31;
	                                    while (1) {
	                                        db = oU(_ | 0, Wa | 0, 10, 0) | 0;
	                                        cb = cb + -1 | 0;
	                                        a[cb >> 0] = db | 48;
	                                        db = _;
	                                        _ = nU(_ | 0, Wa | 0, 10, 0) | 0;
	                                        if (!(Wa >>> 0 > 9 | (Wa | 0) == 9 & db >>> 0 > 4294967295))break; else Wa = G
	                                    }
	                                    gb = cb;
	                                    hb = _
	                                } else {
	                                    gb = B;
	                                    hb = aa
	                                }
	                                if (!hb)ib = gb; else {
	                                    Wa = gb;
	                                    db = hb;
	                                    while (1) {
	                                        jb = Wa + -1 | 0;
	                                        a[jb >> 0] = (db >>> 0) % 10 | 0 | 48;
	                                        if (db >>> 0 < 10) {
	                                            ib = jb;
	                                            break
	                                        } else {
	                                            Wa = jb;
	                                            db = (db >>> 0) / 10 | 0
	                                        }
	                                    }
	                                }
	                                if ((ib | 0) == (B | 0)) {
	                                    a[C >> 0] = 48;
	                                    kb = C
	                                } else kb = ib;
	                                a[kb + -1 >> 0] = (c[o >> 2] >> 31 & 2) + 43;
	                                db = kb + -2 | 0;
	                                a[db >> 0] = la + 15;
	                                if ((za | 0) < 1)if (!(ha & 8)) {
	                                    mb = fb;
	                                    Wa = p;
	                                    while (1) {
	                                        aa = ~~mb;
	                                        _ = Wa + 1 | 0;
	                                        a[Wa >> 0] = d[329640 + aa >> 0] | $a;
	                                        mb = (mb - +(aa | 0)) * 16.0;
	                                        if ((_ - q | 0) != 1 | mb == 0.0)nb = _; else {
	                                            a[_ >> 0] = 46;
	                                            nb = Wa + 2 | 0
	                                        }
	                                        if (!(mb != 0.0)) {
	                                            ob = nb;
	                                            break
	                                        } else Wa = nb
	                                    }
	                                } else {
	                                    mb = fb;
	                                    Wa = p;
	                                    while (1) {
	                                        _ = ~~mb;
	                                        aa = Wa + 1 | 0;
	                                        a[Wa >> 0] = d[329640 + _ >> 0] | $a;
	                                        mb = (mb - +(_ | 0)) * 16.0;
	                                        if ((aa - q | 0) == 1) {
	                                            a[aa >> 0] = 46;
	                                            pb = Wa + 2 | 0
	                                        } else pb = aa;
	                                        if (!(mb != 0.0)) {
	                                            ob = pb;
	                                            break
	                                        } else Wa = pb
	                                    }
	                                } else {
	                                    mb = fb;
	                                    Wa = p;
	                                    while (1) {
	                                        aa = ~~mb;
	                                        _ = Wa + 1 | 0;
	                                        a[Wa >> 0] = d[329640 + aa >> 0] | $a;
	                                        mb = (mb - +(aa | 0)) * 16.0;
	                                        if ((_ - q | 0) == 1) {
	                                            a[_ >> 0] = 46;
	                                            qb = Wa + 2 | 0
	                                        } else qb = _;
	                                        if (!(mb != 0.0)) {
	                                            ob = qb;
	                                            break
	                                        } else Wa = qb
	                                    }
	                                }
	                                Wa = ob;
	                                $a = db;
	                                if ((za | 0) != 0 & (E + Wa | 0) < (za | 0))rb = F + za - $a | 0; else rb = D - $a + Wa | 0;
	                                $a = rb + bb | 0;
	                                _ = ha & 73728;
	                                aa = (ua | 0) > ($a | 0);
	                                if ((_ | 0) == 0 & aa) {
	                                    cb = ua - $a | 0;
	                                    cU(s | 0, 32, (cb >>> 0 > 256 ? 256 : cb) | 0) | 0;
	                                    if (cb >>> 0 > 255) {
	                                        jb = cb;
	                                        do {
	                                            IT(s, 256, e) | 0;
	                                            jb = jb + -256 | 0
	                                        } while (jb >>> 0 > 255);
	                                        sb = cb & 255
	                                    } else sb = cb;
	                                    IT(s, sb, e) | 0
	                                }
	                                IT(ab, bb, e) | 0;
	                                if ((_ | 0) == 65536 & aa) {
	                                    jb = ua - $a | 0;
	                                    cU(s | 0, 48, (jb >>> 0 > 256 ? 256 : jb) | 0) | 0;
	                                    if (jb >>> 0 > 255) {
	                                        tb = jb;
	                                        do {
	                                            IT(s, 256, e) | 0;
	                                            tb = tb + -256 | 0
	                                        } while (tb >>> 0 > 255);
	                                        ub = jb & 255
	                                    } else ub = jb;
	                                    IT(s, ub, e) | 0
	                                }
	                                tb = Wa - q | 0;
	                                IT(p, tb, e) | 0;
	                                bb = r - db | 0;
	                                ab = rb - bb - tb | 0;
	                                if ((ab | 0) > 0) {
	                                    cU(s | 0, 48, (ab >>> 0 > 256 ? 256 : ab) | 0) | 0;
	                                    if (ab >>> 0 > 255) {
	                                        tb = ab;
	                                        do {
	                                            IT(s, 256, e) | 0;
	                                            tb = tb + -256 | 0
	                                        } while (tb >>> 0 > 255);
	                                        vb = ab & 255
	                                    } else vb = ab;
	                                    IT(s, vb, e) | 0
	                                }
	                                IT(db, bb, e) | 0;
	                                if ((_ | 0) == 8192 & aa) {
	                                    tb = ua - $a | 0;
	                                    cU(s | 0, 32, (tb >>> 0 > 256 ? 256 : tb) | 0) | 0;
	                                    if (tb >>> 0 > 255) {
	                                        Wa = tb;
	                                        do {
	                                            IT(s, 256, e) | 0;
	                                            Wa = Wa + -256 | 0
	                                        } while (Wa >>> 0 > 255);
	                                        wb = tb & 255
	                                    } else wb = tb;
	                                    IT(s, wb, e) | 0
	                                }
	                                L = Ha;
	                                M = Ia;
	                                N = Ba;
	                                f = Q;
	                                O = aa ? ua : $a;
	                                P = ta;
	                                continue a
	                            }
	                            Wa = (za | 0) < 0 ? 6 : za;
	                            if (Ya) {
	                                _ = (c[o >> 2] | 0) + -28 | 0;
	                                c[o >> 2] = _;
	                                xb = La * 268435456.0;
	                                yb = _
	                            } else {
	                                xb = La;
	                                yb = c[o >> 2] | 0
	                            }
	                            _ = (yb | 0) < 0 ? n : H;
	                            bb = _;
	                            mb = xb;
	                            db = _;
	                            do {
	                                ab = ~~mb >>> 0;
	                                c[db >> 2] = ab;
	                                db = db + 4 | 0;
	                                mb = (mb - +(ab >>> 0)) * 1.0e9
	                            } while (mb != 0.0);
	                            Ya = c[o >> 2] | 0;
	                            if ((Ya | 0) > 0) {
	                                $a = Ya;
	                                aa = _;
	                                tb = db;
	                                while (1) {
	                                    ab = ($a | 0) > 29 ? 29 : $a;
	                                    jb = tb + -4 | 0;
	                                    do if (jb >>> 0 < aa >>> 0)zb = aa; else {
	                                        cb = 0;
	                                        Ab = jb;
	                                        do {
	                                            Bb = $T(c[Ab >> 2] | 0, 0, ab | 0) | 0;
	                                            Cb = bU(Bb | 0, G | 0, cb | 0, 0) | 0;
	                                            Bb = G;
	                                            Db = oU(Cb | 0, Bb | 0, 1e9, 0) | 0;
	                                            c[Ab >> 2] = Db;
	                                            cb = nU(Cb | 0, Bb | 0, 1e9, 0) | 0;
	                                            Ab = Ab + -4 | 0
	                                        } while (Ab >>> 0 >= aa >>> 0);
	                                        if (!cb) {
	                                            zb = aa;
	                                            break
	                                        }
	                                        Ab = aa + -4 | 0;
	                                        c[Ab >> 2] = cb;
	                                        zb = Ab
	                                    } while (0);
	                                    jb = tb;
	                                    while (1) {
	                                        if (jb >>> 0 <= zb >>> 0)break;
	                                        Ab = jb + -4 | 0;
	                                        if (!(c[Ab >> 2] | 0))jb = Ab; else break
	                                    }
	                                    Ab = (c[o >> 2] | 0) - ab | 0;
	                                    c[o >> 2] = Ab;
	                                    if ((Ab | 0) > 0) {
	                                        $a = Ab;
	                                        aa = zb;
	                                        tb = jb
	                                    } else {
	                                        Eb = Ab;
	                                        Fb = zb;
	                                        Gb = jb;
	                                        break
	                                    }
	                                }
	                            } else {
	                                Eb = Ya;
	                                Fb = _;
	                                Gb = db
	                            }
	                            g:do if ((Eb | 0) < 0) {
	                                tb = ((Wa + 25 | 0) / 9 | 0) + 1 | 0;
	                                if ((ma | 0) == 102) {
	                                    aa = _ + (tb << 2) | 0;
	                                    $a = Eb;
	                                    Ab = Fb;
	                                    Bb = Gb;
	                                    while (1) {
	                                        Cb = 0 - $a | 0;
	                                        Db = (Cb | 0) > 9 ? 9 : Cb;
	                                        do if (Ab >>> 0 < Bb >>> 0) {
	                                            Cb = (1 << Db) + -1 | 0;
	                                            Hb = 1e9 >>> Db;
	                                            Ib = 0;
	                                            Jb = Ab;
	                                            do {
	                                                Kb = c[Jb >> 2] | 0;
	                                                c[Jb >> 2] = (Kb >>> Db) + Ib;
	                                                Ib = ca(Kb & Cb, Hb) | 0;
	                                                Jb = Jb + 4 | 0
	                                            } while (Jb >>> 0 < Bb >>> 0);
	                                            Jb = (c[Ab >> 2] | 0) == 0 ? Ab + 4 | 0 : Ab;
	                                            if (!Ib) {
	                                                Lb = Jb;
	                                                Mb = Bb;
	                                                break
	                                            }
	                                            c[Bb >> 2] = Ib;
	                                            Lb = Jb;
	                                            Mb = Bb + 4 | 0
	                                        } else {
	                                            Lb = (c[Ab >> 2] | 0) == 0 ? Ab + 4 | 0 : Ab;
	                                            Mb = Bb
	                                        } while (0);
	                                        cb = (Mb - bb >> 2 | 0) > (tb | 0) ? aa : Mb;
	                                        $a = (c[o >> 2] | 0) + Db | 0;
	                                        c[o >> 2] = $a;
	                                        if (($a | 0) >= 0) {
	                                            Nb = Lb;
	                                            Ob = cb;
	                                            break g
	                                        } else {
	                                            Ab = Lb;
	                                            Bb = cb
	                                        }
	                                    }
	                                } else {
	                                    Pb = Eb;
	                                    Qb = Fb;
	                                    Rb = Gb
	                                }
	                                while (1) {
	                                    Bb = 0 - Pb | 0;
	                                    Ab = (Bb | 0) > 9 ? 9 : Bb;
	                                    do if (Qb >>> 0 < Rb >>> 0) {
	                                        Bb = (1 << Ab) + -1 | 0;
	                                        $a = 1e9 >>> Ab;
	                                        aa = 0;
	                                        jb = Qb;
	                                        do {
	                                            ab = c[jb >> 2] | 0;
	                                            c[jb >> 2] = (ab >>> Ab) + aa;
	                                            aa = ca(ab & Bb, $a) | 0;
	                                            jb = jb + 4 | 0
	                                        } while (jb >>> 0 < Rb >>> 0);
	                                        jb = (c[Qb >> 2] | 0) == 0 ? Qb + 4 | 0 : Qb;
	                                        if (!aa) {
	                                            Sb = jb;
	                                            Tb = Rb;
	                                            break
	                                        }
	                                        c[Rb >> 2] = aa;
	                                        Sb = jb;
	                                        Tb = Rb + 4 | 0
	                                    } else {
	                                        Sb = (c[Qb >> 2] | 0) == 0 ? Qb + 4 | 0 : Qb;
	                                        Tb = Rb
	                                    } while (0);
	                                    if ((Tb - Sb >> 2 | 0) > (tb | 0))Ub = Sb + (tb << 2) | 0; else Ub = Tb;
	                                    Pb = (c[o >> 2] | 0) + Ab | 0;
	                                    c[o >> 2] = Pb;
	                                    if ((Pb | 0) >= 0) {
	                                        Nb = Sb;
	                                        Ob = Ub;
	                                        break
	                                    } else {
	                                        Qb = Sb;
	                                        Rb = Ub
	                                    }
	                                }
	                            } else {
	                                Nb = Fb;
	                                Ob = Gb
	                            } while (0);
	                            do if (Nb >>> 0 < Ob >>> 0) {
	                                db = (bb - Nb >> 2) * 9 | 0;
	                                Ya = c[Nb >> 2] | 0;
	                                if (Ya >>> 0 < 10) {
	                                    Vb = db;
	                                    break
	                                } else {
	                                    Wb = db;
	                                    Xb = 10
	                                }
	                                while (1) {
	                                    Xb = Xb * 10 | 0;
	                                    db = Wb + 1 | 0;
	                                    if (Ya >>> 0 < Xb >>> 0) {
	                                        Vb = db;
	                                        break
	                                    } else Wb = db
	                                }
	                            } else Vb = 0; while (0);
	                            Ya = (ma | 0) == 103;
	                            db = Wa - ((ma | 0) != 102 ? Vb : 0) + ((Ya & (Wa | 0) != 0) << 31 >> 31) | 0;
	                            if ((db | 0) < (((Ob - bb >> 2) * 9 | 0) + -9 | 0)) {
	                                tb = db + 9216 | 0;
	                                db = (tb | 0) / 9 | 0;
	                                Db = _ + (db + -1023 << 2) | 0;
	                                jb = ((tb | 0) % 9 | 0) + 1 | 0;
	                                if ((jb | 0) < 9) {
	                                    tb = 10;
	                                    $a = jb;
	                                    while (1) {
	                                        jb = tb * 10 | 0;
	                                        $a = $a + 1 | 0;
	                                        if (($a | 0) == 9) {
	                                            Yb = jb;
	                                            break
	                                        } else tb = jb
	                                    }
	                                } else Yb = 10;
	                                tb = c[Db >> 2] | 0;
	                                $a = (tb >>> 0) % (Yb >>> 0) | 0;
	                                if (($a | 0) == 0 ? (_ + (db + -1022 << 2) | 0) == (Ob | 0) : 0) {
	                                    Zb = Nb;
	                                    _b = Db;
	                                    $b = Vb
	                                } else S = 232;
	                                do if ((S | 0) == 232) {
	                                    S = 0;
	                                    eb = (((tb >>> 0) / (Yb >>> 0) | 0) & 1 | 0) == 0 ? 9007199254740992.0 : 9007199254740994.0;
	                                    ma = (Yb | 0) / 2 | 0;
	                                    do if ($a >>> 0 < ma >>> 0)ac = .5; else {
	                                        if (($a | 0) == (ma | 0) ? (_ + (db + -1022 << 2) | 0) == (Ob | 0) : 0) {
	                                            ac = 1.0;
	                                            break
	                                        }
	                                        ac = 1.5
	                                    } while (0);
	                                    do if (!Sa) {
	                                        bc = eb;
	                                        cc = ac
	                                    } else {
	                                        if ((a[Ta >> 0] | 0) != 45) {
	                                            bc = eb;
	                                            cc = ac;
	                                            break
	                                        }
	                                        bc = eb * -1.0;
	                                        cc = ac * -1.0
	                                    } while (0);
	                                    ma = tb - $a | 0;
	                                    c[Db >> 2] = ma;
	                                    if (!(bc + cc != bc)) {
	                                        Zb = Nb;
	                                        _b = Db;
	                                        $b = Vb;
	                                        break
	                                    }
	                                    jb = ma + Yb | 0;
	                                    c[Db >> 2] = jb;
	                                    if (jb >>> 0 > 999999999) {
	                                        jb = Nb;
	                                        ma = Db;
	                                        while (1) {
	                                            Bb = ma + -4 | 0;
	                                            c[ma >> 2] = 0;
	                                            if (Bb >>> 0 < jb >>> 0) {
	                                                Ib = jb + -4 | 0;
	                                                c[Ib >> 2] = 0;
	                                                dc = Ib
	                                            } else dc = jb;
	                                            Ib = (c[Bb >> 2] | 0) + 1 | 0;
	                                            c[Bb >> 2] = Ib;
	                                            if (Ib >>> 0 > 999999999) {
	                                                jb = dc;
	                                                ma = Bb
	                                            } else {
	                                                ec = dc;
	                                                fc = Bb;
	                                                break
	                                            }
	                                        }
	                                    } else {
	                                        ec = Nb;
	                                        fc = Db
	                                    }
	                                    ma = (bb - ec >> 2) * 9 | 0;
	                                    jb = c[ec >> 2] | 0;
	                                    if (jb >>> 0 < 10) {
	                                        Zb = ec;
	                                        _b = fc;
	                                        $b = ma;
	                                        break
	                                    } else {
	                                        gc = ma;
	                                        hc = 10
	                                    }
	                                    while (1) {
	                                        hc = hc * 10 | 0;
	                                        ma = gc + 1 | 0;
	                                        if (jb >>> 0 < hc >>> 0) {
	                                            Zb = ec;
	                                            _b = fc;
	                                            $b = ma;
	                                            break
	                                        } else gc = ma
	                                    }
	                                } while (0);
	                                Db = _b + 4 | 0;
	                                ic = Zb;
	                                jc = $b;
	                                kc = Ob >>> 0 > Db >>> 0 ? Db : Ob
	                            } else {
	                                ic = Nb;
	                                jc = Vb;
	                                kc = Ob
	                            }
	                            Db = 0 - jc | 0;
	                            $a = kc;
	                            while (1) {
	                                if ($a >>> 0 <= ic >>> 0) {
	                                    lc = 0;
	                                    break
	                                }
	                                tb = $a + -4 | 0;
	                                if (!(c[tb >> 2] | 0))$a = tb; else {
	                                    lc = 1;
	                                    break
	                                }
	                            }
	                            do if (Ya) {
	                                tb = ((Wa | 0) == 0 & 1) + Wa | 0;
	                                if ((tb | 0) > (jc | 0) & (jc | 0) > -5) {
	                                    mc = la + -1 | 0;
	                                    nc = tb + -1 - jc | 0
	                                } else {
	                                    mc = la + -2 | 0;
	                                    nc = tb + -1 | 0
	                                }
	                                if (ha & 8) {
	                                    oc = mc;
	                                    pc = nc;
	                                    break
	                                }
	                                do if (lc) {
	                                    tb = c[$a + -4 >> 2] | 0;
	                                    if (!tb) {
	                                        qc = 9;
	                                        break
	                                    }
	                                    if (!((tb >>> 0) % 10 | 0)) {
	                                        rc = 10;
	                                        sc = 0
	                                    } else {
	                                        qc = 0;
	                                        break
	                                    }
	                                    while (1) {
	                                        rc = rc * 10 | 0;
	                                        db = sc + 1 | 0;
	                                        if ((tb >>> 0) % (rc >>> 0) | 0) {
	                                            qc = db;
	                                            break
	                                        } else sc = db
	                                    }
	                                } else qc = 9; while (0);
	                                tb = (($a - bb >> 2) * 9 | 0) + -9 | 0;
	                                if ((mc | 32 | 0) == 102) {
	                                    Ab = tb - qc | 0;
	                                    db = (Ab | 0) < 0 ? 0 : Ab;
	                                    oc = mc;
	                                    pc = (nc | 0) < (db | 0) ? nc : db;
	                                    break
	                                } else {
	                                    db = tb + jc - qc | 0;
	                                    tb = (db | 0) < 0 ? 0 : db;
	                                    oc = mc;
	                                    pc = (nc | 0) < (tb | 0) ? nc : tb;
	                                    break
	                                }
	                            } else {
	                                oc = la;
	                                pc = Wa
	                            } while (0);
	                            Wa = (pc | 0) != 0;
	                            if (Wa)tc = 1; else tc = (ha & 8 | 0) != 0;
	                            bb = tc & 1;
	                            Ya = (oc | 32 | 0) == 102;
	                            if (Ya) {
	                                uc = (jc | 0) > 0 ? jc : 0;
	                                vc = 0
	                            } else {
	                                tb = (jc | 0) < 0 ? Db : jc;
	                                if ((tb | 0) < 0) {
	                                    db = B;
	                                    Ab = tb;
	                                    jb = ((tb | 0) < 0) << 31 >> 31;
	                                    while (1) {
	                                        ma = oU(Ab | 0, jb | 0, 10, 0) | 0;
	                                        db = db + -1 | 0;
	                                        a[db >> 0] = ma | 48;
	                                        ma = Ab;
	                                        Ab = nU(Ab | 0, jb | 0, 10, 0) | 0;
	                                        if (!(jb >>> 0 > 9 | (jb | 0) == 9 & ma >>> 0 > 4294967295))break; else jb = G
	                                    }
	                                    wc = db;
	                                    xc = Ab
	                                } else {
	                                    wc = B;
	                                    xc = tb
	                                }
	                                if (!xc)yc = wc; else {
	                                    jb = wc;
	                                    Db = xc;
	                                    while (1) {
	                                        ma = jb + -1 | 0;
	                                        a[ma >> 0] = (Db >>> 0) % 10 | 0 | 48;
	                                        if (Db >>> 0 < 10) {
	                                            yc = ma;
	                                            break
	                                        } else {
	                                            jb = ma;
	                                            Db = (Db >>> 0) / 10 | 0
	                                        }
	                                    }
	                                }
	                                if ((r - yc | 0) < 2) {
	                                    Db = yc;
	                                    while (1) {
	                                        jb = Db + -1 | 0;
	                                        a[jb >> 0] = 48;
	                                        if ((r - jb | 0) < 2)Db = jb; else {
	                                            zc = jb;
	                                            break
	                                        }
	                                    }
	                                } else zc = yc;
	                                a[zc + -1 >> 0] = (jc >> 31 & 2) + 43;
	                                Db = zc + -2 | 0;
	                                a[Db >> 0] = oc;
	                                uc = r - Db | 0;
	                                vc = Db
	                            }
	                            Db = Sa + 1 + pc + bb + uc | 0;
	                            jb = ha & 73728;
	                            tb = (ua | 0) > (Db | 0);
	                            if ((jb | 0) == 0 & tb) {
	                                Ab = ua - Db | 0;
	                                cU(s | 0, 32, (Ab >>> 0 > 256 ? 256 : Ab) | 0) | 0;
	                                if (Ab >>> 0 > 255) {
	                                    db = Ab;
	                                    do {
	                                        IT(s, 256, e) | 0;
	                                        db = db + -256 | 0
	                                    } while (db >>> 0 > 255);
	                                    Ac = Ab & 255
	                                } else Ac = Ab;
	                                IT(s, Ac, e) | 0
	                            }
	                            IT(Ta, Sa, e) | 0;
	                            if ((jb | 0) == 65536 & tb) {
	                                db = ua - Db | 0;
	                                cU(s | 0, 48, (db >>> 0 > 256 ? 256 : db) | 0) | 0;
	                                if (db >>> 0 > 255) {
	                                    bb = db;
	                                    do {
	                                        IT(s, 256, e) | 0;
	                                        bb = bb + -256 | 0
	                                    } while (bb >>> 0 > 255);
	                                    Bc = db & 255
	                                } else Bc = db;
	                                IT(s, Bc, e) | 0
	                            }
	                            do if (Ya) {
	                                bb = ic >>> 0 > _ >>> 0 ? _ : ic;
	                                Ab = bb;
	                                do {
	                                    ma = c[Ab >> 2] | 0;
	                                    if (!ma)Cc = I; else {
	                                        Bb = I;
	                                        Ib = ma;
	                                        while (1) {
	                                            ma = Bb + -1 | 0;
	                                            a[ma >> 0] = (Ib >>> 0) % 10 | 0 | 48;
	                                            if (Ib >>> 0 < 10) {
	                                                Cc = ma;
	                                                break
	                                            } else {
	                                                Bb = ma;
	                                                Ib = (Ib >>> 0) / 10 | 0
	                                            }
	                                        }
	                                    }
	                                    do if ((Ab | 0) == (bb | 0)) {
	                                        if ((Cc | 0) != (I | 0)) {
	                                            Dc = Cc;
	                                            break
	                                        }
	                                        a[K >> 0] = 48;
	                                        Dc = K
	                                    } else {
	                                        if (Cc >>> 0 > p >>> 0)Ec = Cc; else {
	                                            Dc = Cc;
	                                            break
	                                        }
	                                        while (1) {
	                                            Ib = Ec + -1 | 0;
	                                            a[Ib >> 0] = 48;
	                                            if (Ib >>> 0 > p >>> 0)Ec = Ib; else {
	                                                Dc = Ib;
	                                                break
	                                            }
	                                        }
	                                    } while (0);
	                                    IT(Dc, J - Dc | 0, e) | 0;
	                                    Ab = Ab + 4 | 0
	                                } while (Ab >>> 0 <= _ >>> 0);
	                                if (!((ha & 8 | 0) == 0 & (Wa ^ 1)))IT(329656, 1, e) | 0;
	                                if (Ab >>> 0 < $a >>> 0 & (pc | 0) > 0) {
	                                    bb = pc;
	                                    aa = Ab;
	                                    while (1) {
	                                        Ib = c[aa >> 2] | 0;
	                                        if (Ib) {
	                                            Bb = I;
	                                            ma = Ib;
	                                            while (1) {
	                                                Bb = Bb + -1 | 0;
	                                                a[Bb >> 0] = (ma >>> 0) % 10 | 0 | 48;
	                                                if (ma >>> 0 < 10)break; else ma = (ma >>> 0) / 10 | 0
	                                            }
	                                            if (Bb >>> 0 > p >>> 0) {
	                                                Fc = Bb;
	                                                S = 301
	                                            } else Gc = Bb
	                                        } else {
	                                            Fc = I;
	                                            S = 301
	                                        }
	                                        if ((S | 0) == 301)while (1) {
	                                            S = 0;
	                                            ma = Fc + -1 | 0;
	                                            a[ma >> 0] = 48;
	                                            if (ma >>> 0 > p >>> 0) {
	                                                Fc = ma;
	                                                S = 301
	                                            } else {
	                                                Gc = ma;
	                                                break
	                                            }
	                                        }
	                                        IT(Gc, (bb | 0) > 9 ? 9 : bb, e) | 0;
	                                        aa = aa + 4 | 0;
	                                        Bb = bb + -9 | 0;
	                                        if (!(aa >>> 0 < $a >>> 0 & (Bb | 0) > 0)) {
	                                            Hc = Bb;
	                                            break
	                                        } else bb = Bb
	                                    }
	                                } else Hc = pc;
	                                if ((Hc | 0) <= 0)break;
	                                cU(s | 0, 48, (Hc >>> 0 > 256 ? 256 : Hc) | 0) | 0;
	                                if (Hc >>> 0 > 255) {
	                                    bb = Hc;
	                                    do {
	                                        IT(s, 256, e) | 0;
	                                        bb = bb + -256 | 0
	                                    } while (bb >>> 0 > 255);
	                                    Ic = Hc & 255
	                                } else Ic = Hc;
	                                IT(s, Ic, e) | 0
	                            } else {
	                                bb = lc ? $a : ic + 4 | 0;
	                                do if ((pc | 0) > -1) {
	                                    aa = (ha & 8 | 0) == 0;
	                                    Ab = pc;
	                                    Bb = ic;
	                                    do {
	                                        ma = c[Bb >> 2] | 0;
	                                        if (ma) {
	                                            Ib = I;
	                                            ab = ma;
	                                            while (1) {
	                                                Ib = Ib + -1 | 0;
	                                                a[Ib >> 0] = (ab >>> 0) % 10 | 0 | 48;
	                                                if (ab >>> 0 < 10)break; else ab = (ab >>> 0) / 10 | 0
	                                            }
	                                            if ((Ib | 0) != (I | 0))Jc = Ib; else S = 313
	                                        } else S = 313;
	                                        if ((S | 0) == 313) {
	                                            S = 0;
	                                            a[K >> 0] = 48;
	                                            Jc = K
	                                        }
	                                        do if ((Bb | 0) == (ic | 0)) {
	                                            ab = Jc + 1 | 0;
	                                            IT(Jc, 1, e) | 0;
	                                            if ((Ab | 0) < 1 & aa) {
	                                                Kc = ab;
	                                                break
	                                            }
	                                            IT(329656, 1, e) | 0;
	                                            Kc = ab
	                                        } else {
	                                            if (Jc >>> 0 > p >>> 0)Lc = Jc; else {
	                                                Kc = Jc;
	                                                break
	                                            }
	                                            while (1) {
	                                                ab = Lc + -1 | 0;
	                                                a[ab >> 0] = 48;
	                                                if (ab >>> 0 > p >>> 0)Lc = ab; else {
	                                                    Kc = ab;
	                                                    break
	                                                }
	                                            }
	                                        } while (0);
	                                        Ib = J - Kc | 0;
	                                        IT(Kc, (Ab | 0) > (Ib | 0) ? Ib : Ab, e) | 0;
	                                        Ab = Ab - Ib | 0;
	                                        Bb = Bb + 4 | 0
	                                    } while (Bb >>> 0 < bb >>> 0 & (Ab | 0) > -1);
	                                    if ((Ab | 0) <= 0)break;
	                                    cU(s | 0, 48, (Ab >>> 0 > 256 ? 256 : Ab) | 0) | 0;
	                                    if (Ab >>> 0 > 255) {
	                                        Bb = Ab;
	                                        do {
	                                            IT(s, 256, e) | 0;
	                                            Bb = Bb + -256 | 0
	                                        } while (Bb >>> 0 > 255);
	                                        Mc = Ab & 255
	                                    } else Mc = Ab;
	                                    IT(s, Mc, e) | 0
	                                } while (0);
	                                IT(vc, r - vc | 0, e) | 0
	                            } while (0);
	                            if ((jb | 0) == 8192 & tb) {
	                                $a = ua - Db | 0;
	                                cU(s | 0, 32, ($a >>> 0 > 256 ? 256 : $a) | 0) | 0;
	                                if ($a >>> 0 > 255) {
	                                    Wa = $a;
	                                    do {
	                                        IT(s, 256, e) | 0;
	                                        Wa = Wa + -256 | 0
	                                    } while (Wa >>> 0 > 255);
	                                    Nc = $a & 255
	                                } else Nc = $a;
	                                IT(s, Nc, e) | 0
	                            }
	                            L = Ha;
	                            M = Ia;
	                            N = Ba;
	                            f = Q;
	                            O = tb ? ua : Db;
	                            P = ta;
	                            continue a;
	                            break
	                        }
	                        case 117:
	                        {
	                            Na = Ia;
	                            Oa = Ha;
	                            Pa = 0;
	                            Qa = 329560;
	                            S = 86;
	                            break
	                        }
	                        case 88:
	                        case 120:
	                        {
	                            Oc = ha;
	                            Pc = za;
	                            Qc = la;
	                            S = 75;
	                            break
	                        }
	                        case 99:
	                        {
	                            a[z >> 0] = Ha;
	                            Rc = Ha;
	                            Sc = Ia;
	                            Tc = z;
	                            Uc = $;
	                            Vc = 1;
	                            Wc = 0;
	                            Xc = 329560;
	                            Yc = x;
	                            break
	                        }
	                        case 111:
	                        {
	                            Wa = (Ha | 0) == 0 & (Ia | 0) == 0;
	                            if (Wa)Zc = x; else {
	                                jb = x;
	                                _ = Ha;
	                                Ya = Ia;
	                                while (1) {
	                                    db = jb + -1 | 0;
	                                    a[db >> 0] = _ & 7 | 48;
	                                    _ = dU(_ | 0, Ya | 0, 3) | 0;
	                                    Ya = G;
	                                    if ((_ | 0) == 0 & (Ya | 0) == 0) {
	                                        Zc = db;
	                                        break
	                                    } else jb = db
	                                }
	                            }
	                            jb = (ha & 8 | 0) == 0 | Wa;
	                            _c = Ha;
	                            $c = Ia;
	                            ad = Zc;
	                            bd = ha;
	                            cd = za;
	                            dd = jb & 1 ^ 1;
	                            ed = jb ? 329560 : 329565;
	                            S = 91;
	                            break
	                        }
	                        case 67:
	                        {
	                            c[u >> 2] = Ha;
	                            c[t >> 2] = 0;
	                            fd = u;
	                            gd = A;
	                            hd = -1;
	                            S = 101;
	                            break
	                        }
	                        case 83:
	                        {
	                            jb = Ha;
	                            if (!za) {
	                                id = Ha;
	                                jd = jb;
	                                kd = 0;
	                                S = 106
	                            } else {
	                                fd = jb;
	                                gd = Ha;
	                                hd = za;
	                                S = 101
	                            }
	                            break
	                        }
	                        case 112:
	                        {
	                            Oc = ha | 8;
	                            Pc = za >>> 0 > 8 ? za : 8;
	                            Qc = 120;
	                            S = 75;
	                            break
	                        }
	                        case 115:
	                        {
	                            Ma = (Ha | 0) == 0 ? 329576 : Ha;
	                            S = 96;
	                            break
	                        }
	                        default:
	                        {
	                            Rc = Ha;
	                            Sc = Ia;
	                            Tc = N;
	                            Uc = ha;
	                            Vc = za;
	                            Wc = 0;
	                            Xc = 329560;
	                            Yc = x
	                        }
	                    } while (0);
	                    do if ((S | 0) == 75) {
	                        S = 0;
	                        la = Qc & 32;
	                        if (!((Ha | 0) == 0 & (Ia | 0) == 0)) {
	                            R = x;
	                            Z = Ha;
	                            ga = Ia;
	                            do {
	                                R = R + -1 | 0;
	                                a[R >> 0] = d[329640 + (Z & 15) >> 0] | la;
	                                Z = dU(Z | 0, ga | 0, 4) | 0;
	                                ga = G
	                            } while (!((Z | 0) == 0 & (ga | 0) == 0));
	                            if (!(Oc & 8)) {
	                                _c = Ha;
	                                $c = Ia;
	                                ad = R;
	                                bd = Oc;
	                                cd = Pc;
	                                dd = 0;
	                                ed = 329560;
	                                S = 91
	                            } else {
	                                _c = Ha;
	                                $c = Ia;
	                                ad = R;
	                                bd = Oc;
	                                cd = Pc;
	                                dd = 2;
	                                ed = 329560 + (Qc >> 4) | 0;
	                                S = 91
	                            }
	                        } else {
	                            _c = Ha;
	                            $c = Ia;
	                            ad = x;
	                            bd = Oc;
	                            cd = Pc;
	                            dd = 0;
	                            ed = 329560;
	                            S = 91
	                        }
	                    } else if ((S | 0) == 86) {
	                        S = 0;
	                        if (Na >>> 0 > 0 | (Na | 0) == 0 & Oa >>> 0 > 4294967295) {
	                            ga = x;
	                            Z = Oa;
	                            la = Na;
	                            while (1) {
	                                Wa = oU(Z | 0, la | 0, 10, 0) | 0;
	                                ga = ga + -1 | 0;
	                                a[ga >> 0] = Wa | 48;
	                                Wa = Z;
	                                Z = nU(Z | 0, la | 0, 10, 0) | 0;
	                                if (!(la >>> 0 > 9 | (la | 0) == 9 & Wa >>> 0 > 4294967295))break; else la = G
	                            }
	                            ld = ga;
	                            md = Z
	                        } else {
	                            ld = x;
	                            md = Oa
	                        }
	                        if (!md) {
	                            _c = Oa;
	                            $c = Na;
	                            ad = ld;
	                            bd = ha;
	                            cd = za;
	                            dd = Pa;
	                            ed = Qa;
	                            S = 91
	                        } else {
	                            la = ld;
	                            R = md;
	                            while (1) {
	                                Wa = la + -1 | 0;
	                                a[Wa >> 0] = (R >>> 0) % 10 | 0 | 48;
	                                if (R >>> 0 < 10) {
	                                    _c = Oa;
	                                    $c = Na;
	                                    ad = Wa;
	                                    bd = ha;
	                                    cd = za;
	                                    dd = Pa;
	                                    ed = Qa;
	                                    S = 91;
	                                    break
	                                } else {
	                                    la = Wa;
	                                    R = (R >>> 0) / 10 | 0
	                                }
	                            }
	                        }
	                    } else if ((S | 0) == 96) {
	                        S = 0;
	                        R = NT(Ma, 0, za) | 0;
	                        if (!R) {
	                            Rc = Ha;
	                            Sc = Ia;
	                            Tc = Ma;
	                            Uc = $;
	                            Vc = za;
	                            Wc = 0;
	                            Xc = 329560;
	                            Yc = Ma + za | 0;
	                            break
	                        } else {
	                            Rc = Ha;
	                            Sc = Ia;
	                            Tc = Ma;
	                            Uc = $;
	                            Vc = R - Ma | 0;
	                            Wc = 0;
	                            Xc = 329560;
	                            Yc = R;
	                            break
	                        }
	                    } else if ((S | 0) == 101) {
	                        S = 0;
	                        R = 0;
	                        la = 0;
	                        Z = fd;
	                        while (1) {
	                            ga = c[Z >> 2] | 0;
	                            if (!ga) {
	                                nd = R;
	                                od = la;
	                                break
	                            }
	                            Wa = CT(v, ga) | 0;
	                            if ((Wa | 0) < 0 | Wa >>> 0 > (hd - R | 0) >>> 0) {
	                                nd = R;
	                                od = Wa;
	                                break
	                            }
	                            ga = Wa + R | 0;
	                            if (hd >>> 0 > ga >>> 0) {
	                                R = ga;
	                                la = Wa;
	                                Z = Z + 4 | 0
	                            } else {
	                                nd = ga;
	                                od = Wa;
	                                break
	                            }
	                        }
	                        if ((od | 0) < 0) {
	                            qa = -1;
	                            S = 370;
	                            break a
	                        } else {
	                            id = gd;
	                            jd = fd;
	                            kd = nd;
	                            S = 106
	                        }
	                    } while (0);
	                    if ((S | 0) == 91) {
	                        S = 0;
	                        $ = (cd | 0) > -1 ? bd & -65537 : bd;
	                        Z = (_c | 0) != 0 | ($c | 0) != 0;
	                        if (Z | (cd | 0) != 0) {
	                            la = (Z & 1 ^ 1) + (y - ad) | 0;
	                            Rc = _c;
	                            Sc = $c;
	                            Tc = ad;
	                            Uc = $;
	                            Vc = (cd | 0) > (la | 0) ? cd : la;
	                            Wc = dd;
	                            Xc = ed;
	                            Yc = x
	                        } else {
	                            Rc = _c;
	                            Sc = $c;
	                            Tc = x;
	                            Uc = $;
	                            Vc = 0;
	                            Wc = dd;
	                            Xc = ed;
	                            Yc = x
	                        }
	                    } else if ((S | 0) == 106) {
	                        S = 0;
	                        $ = ha & 73728;
	                        la = (ua | 0) > (kd | 0);
	                        if (($ | 0) == 0 & la) {
	                            Z = ua - kd | 0;
	                            cU(s | 0, 32, (Z >>> 0 > 256 ? 256 : Z) | 0) | 0;
	                            if (Z >>> 0 > 255) {
	                                R = Z;
	                                do {
	                                    IT(s, 256, e) | 0;
	                                    R = R + -256 | 0
	                                } while (R >>> 0 > 255);
	                                pd = Z & 255
	                            } else pd = Z;
	                            IT(s, pd, e) | 0
	                        }
	                        h:do if (kd) {
	                            R = 0;
	                            ha = jd;
	                            while (1) {
	                                Wa = c[ha >> 2] | 0;
	                                if (!Wa)break h;
	                                ga = CT(v, Wa) | 0;
	                                R = ga + R | 0;
	                                if ((R | 0) > (kd | 0))break h;
	                                IT(v, ga, e) | 0;
	                                if (R >>> 0 >= kd >>> 0)break; else ha = ha + 4 | 0
	                            }
	                        } while (0);
	                        if (($ | 0) == 8192 & la) {
	                            Z = ua - kd | 0;
	                            cU(s | 0, 32, (Z >>> 0 > 256 ? 256 : Z) | 0) | 0;
	                            if (Z >>> 0 > 255) {
	                                ha = Z;
	                                do {
	                                    IT(s, 256, e) | 0;
	                                    ha = ha + -256 | 0
	                                } while (ha >>> 0 > 255);
	                                qd = Z & 255
	                            } else qd = Z;
	                            IT(s, qd, e) | 0
	                        }
	                        L = id;
	                        M = Ia;
	                        N = Ba;
	                        f = Q;
	                        O = la ? ua : kd;
	                        P = ta;
	                        continue
	                    }
	                    ha = Yc - Tc | 0;
	                    $ = (Vc | 0) < (ha | 0) ? ha : Vc;
	                    R = Wc + $ | 0;
	                    ga = (ua | 0) < (R | 0) ? R : ua;
	                    Wa = Uc & 73728;
	                    jb = (ga | 0) > (R | 0);
	                    if ((Wa | 0) == 0 & jb) {
	                        Ya = ga - R | 0;
	                        cU(s | 0, 32, (Ya >>> 0 > 256 ? 256 : Ya) | 0) | 0;
	                        if (Ya >>> 0 > 255) {
	                            _ = Ya;
	                            do {
	                                IT(s, 256, e) | 0;
	                                _ = _ + -256 | 0
	                            } while (_ >>> 0 > 255);
	                            rd = Ya & 255
	                        } else rd = Ya;
	                        IT(s, rd, e) | 0
	                    }
	                    IT(Xc, Wc, e) | 0;
	                    if ((Wa | 0) == 65536 & jb) {
	                        _ = ga - R | 0;
	                        cU(s | 0, 48, (_ >>> 0 > 256 ? 256 : _) | 0) | 0;
	                        if (_ >>> 0 > 255) {
	                            la = _;
	                            do {
	                                IT(s, 256, e) | 0;
	                                la = la + -256 | 0
	                            } while (la >>> 0 > 255);
	                            sd = _ & 255
	                        } else sd = _;
	                        IT(s, sd, e) | 0
	                    }
	                    if (($ | 0) > (ha | 0)) {
	                        la = $ - ha | 0;
	                        cU(s | 0, 48, (la >>> 0 > 256 ? 256 : la) | 0) | 0;
	                        if (la >>> 0 > 255) {
	                            Ya = la;
	                            do {
	                                IT(s, 256, e) | 0;
	                                Ya = Ya + -256 | 0
	                            } while (Ya >>> 0 > 255);
	                            td = la & 255
	                        } else td = la;
	                        IT(s, td, e) | 0
	                    }
	                    IT(Tc, ha, e) | 0;
	                    if (!((Wa | 0) == 8192 & jb)) {
	                        L = Rc;
	                        M = Sc;
	                        N = Ba;
	                        f = Q;
	                        O = ga;
	                        P = ta;
	                        continue
	                    }
	                    Ya = ga - R | 0;
	                    cU(s | 0, 32, (Ya >>> 0 > 256 ? 256 : Ya) | 0) | 0;
	                    if (Ya >>> 0 > 255) {
	                        $ = Ya;
	                        do {
	                            IT(s, 256, e) | 0;
	                            $ = $ + -256 | 0
	                        } while ($ >>> 0 > 255);
	                        ud = Ya & 255
	                    } else ud = Ya;
	                    IT(s, ud, e) | 0;
	                    L = Rc;
	                    M = Sc;
	                    N = Ba;
	                    f = Q;
	                    O = ga;
	                    P = ta
	                }
	                if ((S | 0) == 352) {
	                    if (e) {
	                        qa = Q;
	                        i = m;
	                        return qa | 0
	                    }
	                    if (!P) {
	                        qa = 0;
	                        i = m;
	                        return qa | 0
	                    } else vd = 1;
	                    while (1) {
	                        P = c[l + (vd << 2) >> 2] | 0;
	                        if (!P) {
	                            wd = vd;
	                            break
	                        }
	                        Q = j + (vd << 3) | 0;
	                        i:do if (P >>> 0 <= 20)do switch (P | 0) {
	                            case 9:
	                            {
	                                e = c[g >> 2] | 0;
	                                ta = c[e >> 2] | 0;
	                                c[g >> 2] = e + 4;
	                                c[Q >> 2] = ta;
	                                break i;
	                                break
	                            }
	                            case 10:
	                            {
	                                ta = c[g >> 2] | 0;
	                                e = c[ta >> 2] | 0;
	                                c[g >> 2] = ta + 4;
	                                ta = Q;
	                                c[ta >> 2] = e;
	                                c[ta + 4 >> 2] = ((e | 0) < 0) << 31 >> 31;
	                                break i;
	                                break
	                            }
	                            case 11:
	                            {
	                                e = c[g >> 2] | 0;
	                                ta = c[e >> 2] | 0;
	                                c[g >> 2] = e + 4;
	                                e = Q;
	                                c[e >> 2] = ta;
	                                c[e + 4 >> 2] = 0;
	                                break i;
	                                break
	                            }
	                            case 12:
	                            {
	                                e = c[g >> 2] | 0;
	                                ta = e;
	                                O = c[ta >> 2] | 0;
	                                f = c[ta + 4 >> 2] | 0;
	                                c[g >> 2] = e + 8;
	                                e = Q;
	                                c[e >> 2] = O;
	                                c[e + 4 >> 2] = f;
	                                break i;
	                                break
	                            }
	                            case 13:
	                            {
	                                f = c[g >> 2] | 0;
	                                e = c[f >> 2] | 0;
	                                c[g >> 2] = f + 4;
	                                f = (e & 65535) << 16 >> 16;
	                                e = Q;
	                                c[e >> 2] = f;
	                                c[e + 4 >> 2] = ((f | 0) < 0) << 31 >> 31;
	                                break i;
	                                break
	                            }
	                            case 14:
	                            {
	                                f = c[g >> 2] | 0;
	                                e = c[f >> 2] | 0;
	                                c[g >> 2] = f + 4;
	                                f = Q;
	                                c[f >> 2] = e & 65535;
	                                c[f + 4 >> 2] = 0;
	                                break i;
	                                break
	                            }
	                            case 15:
	                            {
	                                f = c[g >> 2] | 0;
	                                e = c[f >> 2] | 0;
	                                c[g >> 2] = f + 4;
	                                f = (e & 255) << 24 >> 24;
	                                e = Q;
	                                c[e >> 2] = f;
	                                c[e + 4 >> 2] = ((f | 0) < 0) << 31 >> 31;
	                                break i;
	                                break
	                            }
	                            case 16:
	                            {
	                                f = c[g >> 2] | 0;
	                                e = c[f >> 2] | 0;
	                                c[g >> 2] = f + 4;
	                                f = Q;
	                                c[f >> 2] = e & 255;
	                                c[f + 4 >> 2] = 0;
	                                break i;
	                                break
	                            }
	                            case 17:
	                            {
	                                f = c[g >> 2] | 0;
	                                c[k >> 2] = c[f >> 2];
	                                c[k + 4 >> 2] = c[f + 4 >> 2];
	                                bc = +h[k >> 3];
	                                c[g >> 2] = f + 8;
	                                h[Q >> 3] = bc;
	                                break i;
	                                break
	                            }
	                            case 18:
	                            {
	                                f = c[g >> 2] | 0;
	                                c[k >> 2] = c[f >> 2];
	                                c[k + 4 >> 2] = c[f + 4 >> 2];
	                                bc = +h[k >> 3];
	                                c[g >> 2] = f + 8;
	                                h[Q >> 3] = bc;
	                                break i;
	                                break
	                            }
	                            default:
	                                break i
	                        } while (0); while (0);
	                        vd = vd + 1 | 0;
	                        if ((vd | 0) >= 10) {
	                            qa = 1;
	                            S = 370;
	                            break
	                        }
	                    }
	                    if ((S | 0) == 370) {
	                        i = m;
	                        return qa | 0
	                    }
	                    while (1) {
	                        if (c[l + (wd << 2) >> 2] | 0) {
	                            qa = -1;
	                            S = 370;
	                            break
	                        }
	                        wd = wd + 1 | 0;
	                        if ((wd | 0) >= 10) {
	                            qa = 1;
	                            S = 370;
	                            break
	                        }
	                    }
	                    if ((S | 0) == 370) {
	                        i = m;
	                        return qa | 0
	                    }
	                } else if ((S | 0) == 370) {
	                    i = m;
	                    return qa | 0
	                }
	                return 0
	            }

	            function WT() {
	            }

	            function XT(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                var e = 0;
	                e = b - d >>> 0;
	                e = b - d - (c >>> 0 > a >>> 0 | 0) >>> 0;
	                return (G = e, a - c >>> 0 | 0) | 0
	            }

	            function YT(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                if ((c | 0) < 32) {
	                    G = b >> c;
	                    return a >>> c | (b & (1 << c) - 1) << 32 - c
	                }
	                G = (b | 0) < 0 ? -1 : 0;
	                return b >> c - 32 | 0
	            }

	            function ZT(b) {
	                b = b | 0;
	                var c = 0;
	                c = b;
	                while (a[c >> 0] | 0)c = c + 1 | 0;
	                return c - b | 0
	            }

	            function _T(b, c) {
	                b = b | 0;
	                c = c | 0;
	                var d = 0, e = 0;
	                d = b + (ZT(b) | 0) | 0;
	                do {
	                    a[d + e >> 0] = a[c + e >> 0];
	                    e = e + 1 | 0
	                } while (a[c + (e - 1) >> 0] | 0);
	                return b | 0
	            }

	            function $T(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                if ((c | 0) < 32) {
	                    G = b << c | (a & (1 << c) - 1 << 32 - c) >>> 32 - c;
	                    return a << c
	                }
	                G = a << c - 32;
	                return 0
	            }

	            function aU(b, c, d) {
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                var e = 0, f = 0;
	                while ((e | 0) < (d | 0)) {
	                    a[b + e >> 0] = f ? 0 : a[c + e >> 0] | 0;
	                    f = f ? 1 : (a[c + e >> 0] | 0) == 0;
	                    e = e + 1 | 0
	                }
	                return b | 0
	            }

	            function bU(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                var e = 0;
	                e = a + c >>> 0;
	                return (G = b + d + (e >>> 0 < a >>> 0 | 0) >>> 0, e | 0) | 0
	            }

	            function cU(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, i = 0;
	                f = b + e | 0;
	                if ((e | 0) >= 20) {
	                    d = d & 255;
	                    g = b & 3;
	                    h = d | d << 8 | d << 16 | d << 24;
	                    i = f & ~3;
	                    if (g) {
	                        g = b + 4 - g | 0;
	                        while ((b | 0) < (g | 0)) {
	                            a[b >> 0] = d;
	                            b = b + 1 | 0
	                        }
	                    }
	                    while ((b | 0) < (i | 0)) {
	                        c[b >> 2] = h;
	                        b = b + 4 | 0
	                    }
	                }
	                while ((b | 0) < (f | 0)) {
	                    a[b >> 0] = d;
	                    b = b + 1 | 0
	                }
	                return b - e | 0
	            }

	            function dU(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                if ((c | 0) < 32) {
	                    G = b >>> c;
	                    return a >>> c | (b & (1 << c) - 1) << 32 - c
	                }
	                G = 0;
	                return b >>> c - 32 | 0
	            }

	            function eU(b, d, e) {
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0;
	                if ((e | 0) >= 4096)return Na(b | 0, d | 0, e | 0) | 0;
	                f = b | 0;
	                if ((b & 3) == (d & 3)) {
	                    while (b & 3) {
	                        if (!e)return f | 0;
	                        a[b >> 0] = a[d >> 0] | 0;
	                        b = b + 1 | 0;
	                        d = d + 1 | 0;
	                        e = e - 1 | 0
	                    }
	                    while ((e | 0) >= 4) {
	                        c[b >> 2] = c[d >> 2];
	                        b = b + 4 | 0;
	                        d = d + 4 | 0;
	                        e = e - 4 | 0
	                    }
	                }
	                while ((e | 0) > 0) {
	                    a[b >> 0] = a[d >> 0] | 0;
	                    b = b + 1 | 0;
	                    d = d + 1 | 0;
	                    e = e - 1 | 0
	                }
	                return f | 0
	            }

	            function fU(b, c, d) {
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                var e = 0;
	                if ((c | 0) < (b | 0) & (b | 0) < (c + d | 0)) {
	                    e = b;
	                    c = c + d | 0;
	                    b = b + d | 0;
	                    while ((d | 0) > 0) {
	                        b = b - 1 | 0;
	                        c = c - 1 | 0;
	                        d = d - 1 | 0;
	                        a[b >> 0] = a[c >> 0] | 0
	                    }
	                    b = e
	                } else eU(b, c, d) | 0;
	                return b | 0
	            }

	            function gU(b, c) {
	                b = b | 0;
	                c = c | 0;
	                var d = 0;
	                do {
	                    a[b + d >> 0] = a[c + d >> 0];
	                    d = d + 1 | 0
	                } while (a[c + (d - 1) >> 0] | 0);
	                return b | 0
	            }

	            function hU(b) {
	                b = b | 0;
	                var c = 0;
	                c = a[n + (b >>> 24) >> 0] | 0;
	                if ((c | 0) < 8)return c | 0;
	                c = a[n + (b >> 16 & 255) >> 0] | 0;
	                if ((c | 0) < 8)return c + 8 | 0;
	                c = a[n + (b >> 8 & 255) >> 0] | 0;
	                if ((c | 0) < 8)return c + 16 | 0;
	                return (a[n + (b & 255) >> 0] | 0) + 24 | 0
	            }

	            function iU(b) {
	                b = b | 0;
	                var c = 0;
	                c = a[m + (b & 255) >> 0] | 0;
	                if ((c | 0) < 8)return c | 0;
	                c = a[m + (b >> 8 & 255) >> 0] | 0;
	                if ((c | 0) < 8)return c + 8 | 0;
	                c = a[m + (b >> 16 & 255) >> 0] | 0;
	                if ((c | 0) < 8)return c + 16 | 0;
	                return (a[m + (b >>> 24) >> 0] | 0) + 24 | 0
	            }

	            function jU(a, b) {
	                a = a | 0;
	                b = b | 0;
	                var c = 0, d = 0, e = 0, f = 0;
	                c = a & 65535;
	                d = b & 65535;
	                e = ca(d, c) | 0;
	                f = a >>> 16;
	                a = (e >>> 16) + (ca(d, f) | 0) | 0;
	                d = b >>> 16;
	                b = ca(d, c) | 0;
	                return (G = (a >>> 16) + (ca(d, f) | 0) + (((a & 65535) + b | 0) >>> 16) | 0, a + b << 16 | e & 65535 | 0) | 0
	            }

	            function kU(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                var e = 0, f = 0, g = 0, h = 0, i = 0;
	                e = b >> 31 | ((b | 0) < 0 ? -1 : 0) << 1;
	                f = ((b | 0) < 0 ? -1 : 0) >> 31 | ((b | 0) < 0 ? -1 : 0) << 1;
	                g = d >> 31 | ((d | 0) < 0 ? -1 : 0) << 1;
	                h = ((d | 0) < 0 ? -1 : 0) >> 31 | ((d | 0) < 0 ? -1 : 0) << 1;
	                i = XT(e ^ a, f ^ b, e, f) | 0;
	                b = G;
	                a = g ^ e;
	                e = h ^ f;
	                f = XT((pU(i, b, XT(g ^ c, h ^ d, g, h) | 0, G, 0) | 0) ^ a, G ^ e, a, e) | 0;
	                return f | 0
	            }

	            function lU(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0, h = 0, j = 0, k = 0, l = 0, m = 0;
	                f = i;
	                i = i + 8 | 0;
	                g = f | 0;
	                h = b >> 31 | ((b | 0) < 0 ? -1 : 0) << 1;
	                j = ((b | 0) < 0 ? -1 : 0) >> 31 | ((b | 0) < 0 ? -1 : 0) << 1;
	                k = e >> 31 | ((e | 0) < 0 ? -1 : 0) << 1;
	                l = ((e | 0) < 0 ? -1 : 0) >> 31 | ((e | 0) < 0 ? -1 : 0) << 1;
	                m = XT(h ^ a, j ^ b, h, j) | 0;
	                b = G;
	                pU(m, b, XT(k ^ d, l ^ e, k, l) | 0, G, g) | 0;
	                l = XT(c[g >> 2] ^ h, c[g + 4 >> 2] ^ j, h, j) | 0;
	                j = G;
	                i = f;
	                return (G = j, l) | 0
	            }

	            function mU(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                var e = 0, f = 0;
	                e = a;
	                a = c;
	                c = jU(e, a) | 0;
	                f = G;
	                return (G = (ca(b, a) | 0) + (ca(d, e) | 0) + f | f & 0, c | 0 | 0) | 0
	            }

	            function nU(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                var e = 0;
	                e = pU(a, b, c, d, 0) | 0;
	                return e | 0
	            }

	            function oU(a, b, d, e) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                var f = 0, g = 0;
	                f = i;
	                i = i + 8 | 0;
	                g = f | 0;
	                pU(a, b, d, e, g) | 0;
	                i = f;
	                return (G = c[g + 4 >> 2] | 0, c[g >> 2] | 0) | 0
	            }

	            function pU(a, b, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                var g = 0, h = 0, i = 0, j = 0, k = 0, l = 0, m = 0, n = 0, o = 0, p = 0, q = 0, r = 0, s = 0, t = 0, u = 0, v = 0, w = 0, x = 0, y = 0, z = 0, A = 0, B = 0, C = 0, D = 0, E = 0, F = 0, H = 0;
	                g = a;
	                h = b;
	                i = h;
	                j = d;
	                k = e;
	                l = k;
	                if (!i) {
	                    m = (f | 0) != 0;
	                    if (!l) {
	                        if (m) {
	                            c[f >> 2] = (g >>> 0) % (j >>> 0);
	                            c[f + 4 >> 2] = 0
	                        }
	                        n = 0;
	                        o = (g >>> 0) / (j >>> 0) >>> 0;
	                        return (G = n, o) | 0
	                    } else {
	                        if (!m) {
	                            n = 0;
	                            o = 0;
	                            return (G = n, o) | 0
	                        }
	                        c[f >> 2] = a | 0;
	                        c[f + 4 >> 2] = b & 0;
	                        n = 0;
	                        o = 0;
	                        return (G = n, o) | 0
	                    }
	                }
	                m = (l | 0) == 0;
	                do if (j) {
	                    if (!m) {
	                        p = (hU(l | 0) | 0) - (hU(i | 0) | 0) | 0;
	                        if (p >>> 0 <= 31) {
	                            q = p + 1 | 0;
	                            r = 31 - p | 0;
	                            s = p - 31 >> 31;
	                            t = q;
	                            u = g >>> (q >>> 0) & s | i << r;
	                            v = i >>> (q >>> 0) & s;
	                            w = 0;
	                            x = g << r;
	                            break
	                        }
	                        if (!f) {
	                            n = 0;
	                            o = 0;
	                            return (G = n, o) | 0
	                        }
	                        c[f >> 2] = a | 0;
	                        c[f + 4 >> 2] = h | b & 0;
	                        n = 0;
	                        o = 0;
	                        return (G = n, o) | 0
	                    }
	                    r = j - 1 | 0;
	                    if (r & j) {
	                        s = (hU(j | 0) | 0) + 33 - (hU(i | 0) | 0) | 0;
	                        q = 64 - s | 0;
	                        p = 32 - s | 0;
	                        y = p >> 31;
	                        z = s - 32 | 0;
	                        A = z >> 31;
	                        t = s;
	                        u = p - 1 >> 31 & i >>> (z >>> 0) | (i << p | g >>> (s >>> 0)) & A;
	                        v = A & i >>> (s >>> 0);
	                        w = g << q & y;
	                        x = (i << q | g >>> (z >>> 0)) & y | g << p & s - 33 >> 31;
	                        break
	                    }
	                    if (f) {
	                        c[f >> 2] = r & g;
	                        c[f + 4 >> 2] = 0
	                    }
	                    if ((j | 0) == 1) {
	                        n = h | b & 0;
	                        o = a | 0 | 0;
	                        return (G = n, o) | 0
	                    } else {
	                        r = iU(j | 0) | 0;
	                        n = i >>> (r >>> 0) | 0;
	                        o = i << 32 - r | g >>> (r >>> 0) | 0;
	                        return (G = n, o) | 0
	                    }
	                } else {
	                    if (m) {
	                        if (f) {
	                            c[f >> 2] = (i >>> 0) % (j >>> 0);
	                            c[f + 4 >> 2] = 0
	                        }
	                        n = 0;
	                        o = (i >>> 0) / (j >>> 0) >>> 0;
	                        return (G = n, o) | 0
	                    }
	                    if (!g) {
	                        if (f) {
	                            c[f >> 2] = 0;
	                            c[f + 4 >> 2] = (i >>> 0) % (l >>> 0)
	                        }
	                        n = 0;
	                        o = (i >>> 0) / (l >>> 0) >>> 0;
	                        return (G = n, o) | 0
	                    }
	                    r = l - 1 | 0;
	                    if (!(r & l)) {
	                        if (f) {
	                            c[f >> 2] = a | 0;
	                            c[f + 4 >> 2] = r & i | b & 0
	                        }
	                        n = 0;
	                        o = i >>> ((iU(l | 0) | 0) >>> 0);
	                        return (G = n, o) | 0
	                    }
	                    r = (hU(l | 0) | 0) - (hU(i | 0) | 0) | 0;
	                    if (r >>> 0 <= 30) {
	                        s = r + 1 | 0;
	                        p = 31 - r | 0;
	                        t = s;
	                        u = i << p | g >>> (s >>> 0);
	                        v = i >>> (s >>> 0);
	                        w = 0;
	                        x = g << p;
	                        break
	                    }
	                    if (!f) {
	                        n = 0;
	                        o = 0;
	                        return (G = n, o) | 0
	                    }
	                    c[f >> 2] = a | 0;
	                    c[f + 4 >> 2] = h | b & 0;
	                    n = 0;
	                    o = 0;
	                    return (G = n, o) | 0
	                } while (0);
	                if (!t) {
	                    B = x;
	                    C = w;
	                    D = v;
	                    E = u;
	                    F = 0;
	                    H = 0
	                } else {
	                    b = d | 0 | 0;
	                    d = k | e & 0;
	                    e = bU(b, d, -1, -1) | 0;
	                    k = G;
	                    h = x;
	                    x = w;
	                    w = v;
	                    v = u;
	                    u = t;
	                    t = 0;
	                    do {
	                        a = h;
	                        h = x >>> 31 | h << 1;
	                        x = t | x << 1;
	                        g = v << 1 | a >>> 31 | 0;
	                        a = v >>> 31 | w << 1 | 0;
	                        XT(e, k, g, a) | 0;
	                        i = G;
	                        l = i >> 31 | ((i | 0) < 0 ? -1 : 0) << 1;
	                        t = l & 1;
	                        v = XT(g, a, l & b, (((i | 0) < 0 ? -1 : 0) >> 31 | ((i | 0) < 0 ? -1 : 0) << 1) & d) | 0;
	                        w = G;
	                        u = u - 1 | 0
	                    } while ((u | 0) != 0);
	                    B = h;
	                    C = x;
	                    D = w;
	                    E = v;
	                    F = 0;
	                    H = t
	                }
	                t = C;
	                C = 0;
	                if (f) {
	                    c[f >> 2] = E;
	                    c[f + 4 >> 2] = D
	                }
	                n = (t | 0) >>> 31 | (B | C) << 1 | (C << 1 | t >>> 31) & 0 | F;
	                o = (t << 1 | 0 >>> 31) & -2 | H;
	                return (G = n, o) | 0
	            }

	            function qU(a, b, c, d, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                return ub[a & 511](b | 0, c | 0, d | 0, e | 0, f | 0, g | 0, h | 0) | 0
	            }

	            function rU(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return vb[a & 511](b | 0, c | 0, d | 0) | 0
	            }

	            function sU(a, b, c, d, e, f, g, h) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                wb[a & 511](b | 0, c | 0, d | 0, e | 0, f | 0, g | 0, h | 0)
	            }

	            function tU(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                xb[a & 511](b | 0, c | 0, d | 0, e | 0, f | 0)
	            }

	            function uU(a) {
	                a = a | 0;
	                return yb[a & 511]() | 0
	            }

	            function vU(a, b) {
	                a = a | 0;
	                b = b | 0;
	                zb[a & 511](b | 0)
	            }

	            function wU(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Ab[a & 511](b | 0, c | 0)
	            }

	            function xU(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return Bb[a & 511](b | 0, c | 0, d | 0, e | 0, f | 0, g | 0) | 0
	            }

	            function yU(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return Cb[a & 511](b | 0) | 0
	            }

	            function zU(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Db[a & 511](b | 0, c | 0, d | 0)
	            }

	            function AU(a, b, c, d, e, f, g, h, i, j) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                j = j | 0;
	                Eb[a & 511](b | 0, c | 0, d | 0, e | 0, f | 0, g | 0, h | 0, i | 0, j | 0)
	            }

	            function BU(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return Fb[a & 511](b | 0, c | 0, d | 0, e | 0) | 0
	            }

	            function CU(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Gb[a & 511](b | 0, c | 0, d | 0, e | 0, f | 0, g | 0)
	            }

	            function DU(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return Hb[a & 511](b | 0, c | 0) | 0
	            }

	            function EU(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return Ib[a & 511](b | 0, c | 0, d | 0, e | 0, f | 0) | 0
	            }

	            function FU(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Jb[a & 511](b | 0, c | 0, d | 0, e | 0)
	            }

	            function GU(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                da(0);
	                return 0
	            }

	            function HU(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function IU(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return vc(a | 0) | 0
	            }

	            function JU(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return wc(a | 0) | 0
	            }

	            function KU(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return xc(a | 0) | 0
	            }

	            function LU(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return yc(a | 0, b | 0, c | 0) | 0
	            }

	            function MU(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return zc(a | 0, b | 0) | 0
	            }

	            function NU(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function OU(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function PU(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function QU(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function RU(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function SU(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function TU(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function UU(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function VU(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function WU(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function XU(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function YU(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function ZU(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function _U(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function $U(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function aV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function bV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function cV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function dV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return Qc(a | 0, b | 0) | 0
	            }

	            function eV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function fV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function gV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function hV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function iV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return Xk(a | 0, b | 0, c | 0) | 0
	            }

	            function jV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function kV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return iT(a | 0) | 0
	            }

	            function lV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return kT(a | 0, b | 0) | 0
	            }

	            function mV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return my(a | 0) | 0
	            }

	            function nV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function oV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function pV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return PP(a | 0) | 0
	            }

	            function qV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return QP(a | 0) | 0
	            }

	            function rV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return RP(a | 0) | 0
	            }

	            function sV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return UP(a | 0, b | 0, c | 0) | 0
	            }

	            function tV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return VP(a | 0, b | 0) | 0
	            }

	            function uV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function vV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function wV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function xV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function yV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function zV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function AV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function BV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function CV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function DV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function EV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function FV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function GV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function HV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function IV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function JV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function KV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return WP(a | 0, b | 0) | 0
	            }

	            function LV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function MV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function NV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return LP(a | 0) | 0
	            }

	            function OV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return MP(a | 0) | 0
	            }

	            function PV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return NP(a | 0) | 0
	            }

	            function QV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return OP(a | 0) | 0
	            }

	            function RV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function SV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return NI(a | 0) | 0
	            }

	            function TV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return OI(a | 0) | 0
	            }

	            function UV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return PI(a | 0) | 0
	            }

	            function VV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return QI(a | 0) | 0
	            }

	            function WV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return RI(a | 0) | 0
	            }

	            function XV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return SI(a | 0) | 0
	            }

	            function YV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return TI(a | 0) | 0
	            }

	            function ZV(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return UI(a | 0) | 0
	            }

	            function _V(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return VI(a | 0) | 0
	            }

	            function $V(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return WI(a | 0) | 0
	            }

	            function aW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return XI(a | 0) | 0
	            }

	            function bW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return YI(a | 0) | 0
	            }

	            function cW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return ZI(a | 0) | 0
	            }

	            function dW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return _I(a | 0) | 0
	            }

	            function eW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return $I(a | 0) | 0
	            }

	            function fW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return aJ(a | 0) | 0
	            }

	            function gW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return bJ(a | 0) | 0
	            }

	            function hW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return cJ(a | 0) | 0
	            }

	            function iW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return dJ(a | 0) | 0
	            }

	            function jW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return eJ(a | 0) | 0
	            }

	            function kW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return fJ(a | 0) | 0
	            }

	            function lW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return gJ(a | 0) | 0
	            }

	            function mW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return hJ(a | 0) | 0
	            }

	            function nW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return iJ(a | 0) | 0
	            }

	            function oW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return jJ(a | 0) | 0
	            }

	            function pW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return kJ(a | 0) | 0
	            }

	            function qW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return lJ(a | 0) | 0
	            }

	            function rW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return mJ(a | 0) | 0
	            }

	            function sW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return nJ(a | 0) | 0
	            }

	            function tW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return oJ(a | 0) | 0
	            }

	            function uW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return pJ(a | 0) | 0
	            }

	            function vW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return qJ(a | 0) | 0
	            }

	            function wW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return rJ(a | 0) | 0
	            }

	            function xW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return sJ(a | 0) | 0
	            }

	            function yW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return tJ(a | 0) | 0
	            }

	            function zW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return uJ(a | 0) | 0
	            }

	            function AW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return vJ(a | 0) | 0
	            }

	            function BW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return wJ(a | 0) | 0
	            }

	            function CW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return xJ(a | 0) | 0
	            }

	            function DW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return yJ(a | 0) | 0
	            }

	            function EW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return zJ(a | 0) | 0
	            }

	            function FW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return AJ(a | 0) | 0
	            }

	            function GW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return BJ(a | 0) | 0
	            }

	            function HW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return CJ(a | 0) | 0
	            }

	            function IW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return DJ(a | 0) | 0
	            }

	            function JW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return EJ(a | 0) | 0
	            }

	            function KW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return FJ(a | 0) | 0
	            }

	            function LW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return GJ(a | 0) | 0
	            }

	            function MW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return HJ(a | 0) | 0
	            }

	            function NW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return IJ(a | 0) | 0
	            }

	            function OW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return JJ(a | 0) | 0
	            }

	            function PW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return KJ(a | 0) | 0
	            }

	            function QW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return LJ(a | 0) | 0
	            }

	            function RW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return MJ(a | 0) | 0
	            }

	            function SW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return NJ(a | 0) | 0
	            }

	            function TW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return OJ(a | 0) | 0
	            }

	            function UW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return PJ(a | 0) | 0
	            }

	            function VW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return QJ(a | 0) | 0
	            }

	            function WW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return RJ(a | 0) | 0
	            }

	            function XW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return SJ(a | 0) | 0
	            }

	            function YW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return TJ(a | 0) | 0
	            }

	            function ZW(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return UJ(a | 0) | 0
	            }

	            function _W(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return VJ(a | 0) | 0
	            }

	            function $W(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return WJ(a | 0) | 0
	            }

	            function aX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return XJ(a | 0) | 0
	            }

	            function bX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return YJ(a | 0) | 0
	            }

	            function cX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return ZJ(a | 0) | 0
	            }

	            function dX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return _J(a | 0) | 0
	            }

	            function eX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return $J(a | 0) | 0
	            }

	            function fX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return aK(a | 0) | 0
	            }

	            function gX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return bK(a | 0) | 0
	            }

	            function hX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return cK(a | 0) | 0
	            }

	            function iX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return dK(a | 0) | 0
	            }

	            function jX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return eK(a | 0) | 0
	            }

	            function kX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return fK(a | 0) | 0
	            }

	            function lX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return gK(a | 0) | 0
	            }

	            function mX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return hK(a | 0) | 0
	            }

	            function nX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return iK(a | 0) | 0
	            }

	            function oX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return jK(a | 0) | 0
	            }

	            function pX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return kK(a | 0) | 0
	            }

	            function qX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return lK(a | 0) | 0
	            }

	            function rX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return mK(a | 0) | 0
	            }

	            function sX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return nK(a | 0) | 0
	            }

	            function tX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return oK(a | 0) | 0
	            }

	            function uX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return pK(a | 0) | 0
	            }

	            function vX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return qK(a | 0) | 0
	            }

	            function wX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return rK(a | 0) | 0
	            }

	            function xX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return sK(a | 0) | 0
	            }

	            function yX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return tK(a | 0) | 0
	            }

	            function zX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return uK(a | 0) | 0
	            }

	            function AX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return vK(a | 0) | 0
	            }

	            function BX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return wK(a | 0) | 0
	            }

	            function CX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return xK(a | 0) | 0
	            }

	            function DX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return yK(a | 0) | 0
	            }

	            function EX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return zK(a | 0) | 0
	            }

	            function FX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return AK(a | 0) | 0
	            }

	            function GX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return BK(a | 0) | 0
	            }

	            function HX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return CK(a | 0) | 0
	            }

	            function IX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return DK(a | 0) | 0
	            }

	            function JX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return EK(a | 0) | 0
	            }

	            function KX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return FK(a | 0) | 0
	            }

	            function LX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return GK(a | 0) | 0
	            }

	            function MX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return HK(a | 0) | 0
	            }

	            function NX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return IK(a | 0) | 0
	            }

	            function OX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return JK(a | 0) | 0
	            }

	            function PX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return KK(a | 0) | 0
	            }

	            function QX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return LK(a | 0) | 0
	            }

	            function RX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return MK(a | 0) | 0
	            }

	            function SX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return NK(a | 0) | 0
	            }

	            function TX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return OK(a | 0) | 0
	            }

	            function UX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return PK(a | 0) | 0
	            }

	            function VX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return QK(a | 0) | 0
	            }

	            function WX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return RK(a | 0) | 0
	            }

	            function XX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return SK(a | 0) | 0
	            }

	            function YX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return TK(a | 0) | 0
	            }

	            function ZX(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return UK(a | 0) | 0
	            }

	            function _X(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return VK(a | 0) | 0
	            }

	            function $X(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return WK(a | 0) | 0
	            }

	            function aY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return XK(a | 0) | 0
	            }

	            function bY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return YK(a | 0) | 0
	            }

	            function cY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return ZK(a | 0) | 0
	            }

	            function dY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return _K(a | 0) | 0
	            }

	            function eY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return $K(a | 0) | 0
	            }

	            function fY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return aL(a | 0) | 0
	            }

	            function gY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return bL(a | 0) | 0
	            }

	            function hY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return cL(a | 0) | 0
	            }

	            function iY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return dL(a | 0) | 0
	            }

	            function jY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return eL(a | 0) | 0
	            }

	            function kY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return RT(a | 0, b | 0, c | 0) | 0
	            }

	            function lY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function mY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return Wb(a | 0) | 0
	            }

	            function nY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return Xb(a | 0, b | 0) | 0
	            }

	            function oY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return Yb(a | 0) | 0
	            }

	            function pY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return Wk(a | 0, b | 0, c | 0) | 0
	            }

	            function qY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function rY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function sY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return ac(a | 0, b | 0, c | 0) | 0
	            }

	            function tY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return Ka(a | 0, b | 0, c | 0) | 0
	            }

	            function uY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return gc(a | 0, b | 0, c | 0) | 0
	            }

	            function vY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function wY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function xY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function yY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function zY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function AY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return nc(a | 0) | 0
	            }

	            function BY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function CY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return nd(a | 0) | 0
	            }

	            function DY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return Kd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function EY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return Ld(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function FY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return Md(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function GY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return Nd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function HY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return Od(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function IY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return Pd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function JY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return qd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function KY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return rd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function LY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return Qd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function MY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return Rd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function NY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return fo(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function OY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function PY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function QY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function RY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return mk() | 0
	            }

	            function SY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function TY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function UY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return nk(a | 0) | 0
	            }

	            function VY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return ok(a | 0) | 0
	            }

	            function WY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return pk(a | 0, b | 0, c | 0) | 0
	            }

	            function XY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return qk(a | 0) | 0
	            }

	            function YY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return _k(a | 0) | 0
	            }

	            function ZY(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return $k(a | 0, b | 0, c | 0) | 0
	            }

	            function _Y(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return bl(a | 0) | 0
	            }

	            function $Y(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return cl(a | 0, b | 0, c | 0) | 0
	            }

	            function aZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return dl(a | 0) | 0
	            }

	            function bZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return el(a | 0, b | 0, c | 0) | 0
	            }

	            function cZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return fl(a | 0, b | 0, c | 0) | 0
	            }

	            function dZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return gl(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function eZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function fZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return on(a | 0) | 0
	            }

	            function gZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function hZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return vn(a | 0) | 0
	            }

	            function iZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function jZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return yn(a | 0) | 0
	            }

	            function kZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function lZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function mZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function nZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return Cn(a | 0, b | 0) | 0
	            }

	            function oZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function pZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function qZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function rZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function sZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function tZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function uZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return _n(a | 0, b | 0) | 0
	            }

	            function vZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function wZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function xZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function yZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function zZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function AZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function BZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function CZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function DZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function EZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function FZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function GZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function HZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function IZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function JZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function KZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function LZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function MZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function NZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function OZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function PZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function QZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function RZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function SZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function TZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function UZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function VZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function WZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function XZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function YZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function ZZ(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return uu(a | 0, b | 0, c | 0) | 0
	            }

	            function _Z(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return ds(a | 0, b | 0) | 0
	            }

	            function $Z(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return es(a | 0, b | 0) | 0
	            }

	            function a_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return js(a | 0, b | 0) | 0
	            }

	            function b_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return vu(a | 0, b | 0, c | 0) | 0
	            }

	            function c_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return wu(a | 0, b | 0) | 0
	            }

	            function d_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return $r(a | 0, b | 0) | 0
	            }

	            function e_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return as(a | 0, b | 0) | 0
	            }

	            function f_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return bs(a | 0, b | 0) | 0
	            }

	            function g_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return hs(a | 0, b | 0) | 0
	            }

	            function h_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return fs(a | 0, b | 0) | 0
	            }

	            function i_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return is(a | 0, b | 0) | 0
	            }

	            function j_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return cs(a | 0, b | 0) | 0
	            }

	            function k_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return xu(a | 0, b | 0) | 0
	            }

	            function l_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return gs(a | 0, b | 0) | 0
	            }

	            function m_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return _r(a | 0, b | 0) | 0
	            }

	            function n_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return dr(a | 0, b | 0) | 0
	            }

	            function o_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function p_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function q_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function r_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function s_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function t_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function u_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function v_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function w_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function x_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function y_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function z_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return Kx(a | 0, b | 0, c | 0) | 0
	            }

	            function A_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return $x(a | 0, b | 0) | 0
	            }

	            function B_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return dy(a | 0, b | 0) | 0
	            }

	            function C_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return fy(a | 0, b | 0) | 0
	            }

	            function D_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return jy(a | 0, b | 0) | 0
	            }

	            function E_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function F_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function G_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function H_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function I_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function J_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function K_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function L_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return RB(a | 0) | 0
	            }

	            function M_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return SB(a | 0) | 0
	            }

	            function N_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return TB(a | 0) | 0
	            }

	            function O_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return UB(a | 0, b | 0, c | 0) | 0
	            }

	            function P_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return VB(a | 0, b | 0) | 0
	            }

	            function Q_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function R_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function S_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function T_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function U_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function V_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function W_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function X_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function Y_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function Z_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function __(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function $_(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function a$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function b$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return hC(a | 0, b | 0) | 0
	            }

	            function c$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function d$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function e$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function f$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function g$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function h$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function i$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function j$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return rC(a | 0, b | 0, c | 0) | 0
	            }

	            function k$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function l$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function m$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function n$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function o$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function p$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function q$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function r$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function s$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function t$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function u$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function v$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function w$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function x$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return GM(a | 0, b | 0, c | 0) | 0
	            }

	            function y$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function z$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function A$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return nN(a | 0, b | 0) | 0
	            }

	            function B$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return oN(a | 0, b | 0, c | 0, d | 0, e | 0) | 0
	            }

	            function C$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return qN(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0) | 0
	            }

	            function D$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function E$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return tN(a | 0, b | 0) | 0
	            }

	            function F$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return uN(a | 0, b | 0, c | 0, d | 0, e | 0) | 0
	            }

	            function G$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function H$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function I$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function J$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function K$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function L$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function M$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function N$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function O$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return 0
	            }

	            function P$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return WR(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Q$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return QS(a | 0, b | 0) | 0
	            }

	            function R$(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                return hT(a | 0, b | 0, c | 0) | 0
	            }

	            function S$(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                da(1);
	                return 0
	            }

	            function T$(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function U$(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return vc(a | 0) | 0
	            }

	            function V$(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return wc(a | 0) | 0
	            }

	            function W$(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return xc(a | 0) | 0
	            }

	            function X$(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return zc(a | 0, b | 0) | 0
	            }

	            function Y$(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function Z$(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function _$(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function $$(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function a0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function b0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function c0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function d0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function e0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function f0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function g0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function h0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function i0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function j0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function k0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function l0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function m0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function n0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function o0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return Qc(a | 0, b | 0) | 0
	            }

	            function p0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function q0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function r0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function s0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function t0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function u0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return iT(a | 0) | 0
	            }

	            function v0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return kT(a | 0, b | 0) | 0
	            }

	            function w0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return my(a | 0) | 0
	            }

	            function x0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function y0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function z0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return PP(a | 0) | 0
	            }

	            function A0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return QP(a | 0) | 0
	            }

	            function B0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return RP(a | 0) | 0
	            }

	            function C0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return VP(a | 0, b | 0) | 0
	            }

	            function D0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function E0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function F0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function G0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function H0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function I0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function J0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function K0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function L0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function M0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function N0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function O0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function P0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function Q0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function R0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function S0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function T0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return WP(a | 0, b | 0) | 0
	            }

	            function U0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function V0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function W0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return LP(a | 0) | 0
	            }

	            function X0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return MP(a | 0) | 0
	            }

	            function Y0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return NP(a | 0) | 0
	            }

	            function Z0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return OP(a | 0) | 0
	            }

	            function _0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function $0(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return NI(a | 0) | 0
	            }

	            function a1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return OI(a | 0) | 0
	            }

	            function b1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return PI(a | 0) | 0
	            }

	            function c1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return QI(a | 0) | 0
	            }

	            function d1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return RI(a | 0) | 0
	            }

	            function e1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return SI(a | 0) | 0
	            }

	            function f1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return TI(a | 0) | 0
	            }

	            function g1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return UI(a | 0) | 0
	            }

	            function h1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return VI(a | 0) | 0
	            }

	            function i1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return WI(a | 0) | 0
	            }

	            function j1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return XI(a | 0) | 0
	            }

	            function k1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return YI(a | 0) | 0
	            }

	            function l1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return ZI(a | 0) | 0
	            }

	            function m1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return _I(a | 0) | 0
	            }

	            function n1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return $I(a | 0) | 0
	            }

	            function o1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return aJ(a | 0) | 0
	            }

	            function p1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return bJ(a | 0) | 0
	            }

	            function q1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return cJ(a | 0) | 0
	            }

	            function r1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return dJ(a | 0) | 0
	            }

	            function s1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return eJ(a | 0) | 0
	            }

	            function t1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return fJ(a | 0) | 0
	            }

	            function u1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return gJ(a | 0) | 0
	            }

	            function v1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return hJ(a | 0) | 0
	            }

	            function w1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return iJ(a | 0) | 0
	            }

	            function x1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return jJ(a | 0) | 0
	            }

	            function y1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return kJ(a | 0) | 0
	            }

	            function z1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return lJ(a | 0) | 0
	            }

	            function A1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return mJ(a | 0) | 0
	            }

	            function B1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return nJ(a | 0) | 0
	            }

	            function C1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return oJ(a | 0) | 0
	            }

	            function D1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return pJ(a | 0) | 0
	            }

	            function E1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return qJ(a | 0) | 0
	            }

	            function F1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return rJ(a | 0) | 0
	            }

	            function G1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return sJ(a | 0) | 0
	            }

	            function H1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return tJ(a | 0) | 0
	            }

	            function I1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return uJ(a | 0) | 0
	            }

	            function J1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return vJ(a | 0) | 0
	            }

	            function K1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return wJ(a | 0) | 0
	            }

	            function L1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return xJ(a | 0) | 0
	            }

	            function M1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return yJ(a | 0) | 0
	            }

	            function N1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return zJ(a | 0) | 0
	            }

	            function O1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return AJ(a | 0) | 0
	            }

	            function P1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return BJ(a | 0) | 0
	            }

	            function Q1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return CJ(a | 0) | 0
	            }

	            function R1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return DJ(a | 0) | 0
	            }

	            function S1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return EJ(a | 0) | 0
	            }

	            function T1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return FJ(a | 0) | 0
	            }

	            function U1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return GJ(a | 0) | 0
	            }

	            function V1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return HJ(a | 0) | 0
	            }

	            function W1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return IJ(a | 0) | 0
	            }

	            function X1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return JJ(a | 0) | 0
	            }

	            function Y1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return KJ(a | 0) | 0
	            }

	            function Z1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return LJ(a | 0) | 0
	            }

	            function _1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return MJ(a | 0) | 0
	            }

	            function $1(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return NJ(a | 0) | 0
	            }

	            function a2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return OJ(a | 0) | 0
	            }

	            function b2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return PJ(a | 0) | 0
	            }

	            function c2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return QJ(a | 0) | 0
	            }

	            function d2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return RJ(a | 0) | 0
	            }

	            function e2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return SJ(a | 0) | 0
	            }

	            function f2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return TJ(a | 0) | 0
	            }

	            function g2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return UJ(a | 0) | 0
	            }

	            function h2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return VJ(a | 0) | 0
	            }

	            function i2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return WJ(a | 0) | 0
	            }

	            function j2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return XJ(a | 0) | 0
	            }

	            function k2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return YJ(a | 0) | 0
	            }

	            function l2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return ZJ(a | 0) | 0
	            }

	            function m2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return _J(a | 0) | 0
	            }

	            function n2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return $J(a | 0) | 0
	            }

	            function o2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return aK(a | 0) | 0
	            }

	            function p2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return bK(a | 0) | 0
	            }

	            function q2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return cK(a | 0) | 0
	            }

	            function r2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return dK(a | 0) | 0
	            }

	            function s2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return eK(a | 0) | 0
	            }

	            function t2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return fK(a | 0) | 0
	            }

	            function u2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return gK(a | 0) | 0
	            }

	            function v2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return hK(a | 0) | 0
	            }

	            function w2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return iK(a | 0) | 0
	            }

	            function x2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return jK(a | 0) | 0
	            }

	            function y2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return kK(a | 0) | 0
	            }

	            function z2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return lK(a | 0) | 0
	            }

	            function A2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return mK(a | 0) | 0
	            }

	            function B2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return nK(a | 0) | 0
	            }

	            function C2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return oK(a | 0) | 0
	            }

	            function D2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return pK(a | 0) | 0
	            }

	            function E2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return qK(a | 0) | 0
	            }

	            function F2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return rK(a | 0) | 0
	            }

	            function G2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return sK(a | 0) | 0
	            }

	            function H2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return tK(a | 0) | 0
	            }

	            function I2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return uK(a | 0) | 0
	            }

	            function J2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return vK(a | 0) | 0
	            }

	            function K2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return wK(a | 0) | 0
	            }

	            function L2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return xK(a | 0) | 0
	            }

	            function M2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return yK(a | 0) | 0
	            }

	            function N2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return zK(a | 0) | 0
	            }

	            function O2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return AK(a | 0) | 0
	            }

	            function P2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return BK(a | 0) | 0
	            }

	            function Q2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return CK(a | 0) | 0
	            }

	            function R2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return DK(a | 0) | 0
	            }

	            function S2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return EK(a | 0) | 0
	            }

	            function T2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return FK(a | 0) | 0
	            }

	            function U2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return GK(a | 0) | 0
	            }

	            function V2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return HK(a | 0) | 0
	            }

	            function W2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return IK(a | 0) | 0
	            }

	            function X2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return JK(a | 0) | 0
	            }

	            function Y2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return KK(a | 0) | 0
	            }

	            function Z2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return LK(a | 0) | 0
	            }

	            function _2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return MK(a | 0) | 0
	            }

	            function $2(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return NK(a | 0) | 0
	            }

	            function a3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return OK(a | 0) | 0
	            }

	            function b3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return PK(a | 0) | 0
	            }

	            function c3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return QK(a | 0) | 0
	            }

	            function d3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return RK(a | 0) | 0
	            }

	            function e3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return SK(a | 0) | 0
	            }

	            function f3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return TK(a | 0) | 0
	            }

	            function g3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return UK(a | 0) | 0
	            }

	            function h3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return VK(a | 0) | 0
	            }

	            function i3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return WK(a | 0) | 0
	            }

	            function j3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return XK(a | 0) | 0
	            }

	            function k3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return YK(a | 0) | 0
	            }

	            function l3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return ZK(a | 0) | 0
	            }

	            function m3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return _K(a | 0) | 0
	            }

	            function n3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return $K(a | 0) | 0
	            }

	            function o3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return aL(a | 0) | 0
	            }

	            function p3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return bL(a | 0) | 0
	            }

	            function q3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return cL(a | 0) | 0
	            }

	            function r3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return dL(a | 0) | 0
	            }

	            function s3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return eL(a | 0) | 0
	            }

	            function t3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function u3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return Wb(a | 0) | 0
	            }

	            function v3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return Xb(a | 0, b | 0) | 0
	            }

	            function w3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return Yb(a | 0) | 0
	            }

	            function x3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function y3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function z3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return Ka(a | 0, b | 0, c | 0) | 0
	            }

	            function A3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function B3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function C3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function D3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function E3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function F3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return nc(a | 0) | 0
	            }

	            function G3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function H3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return nd(a | 0) | 0
	            }

	            function I3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return Kd(a | 0, b | 0, c | 0, 0) | 0
	            }

	            function J3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return Ld(a | 0, b | 0, c | 0, 0) | 0
	            }

	            function K3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return Md(a | 0, b | 0, c | 0, 0) | 0
	            }

	            function L3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return Nd(a | 0, b | 0, c | 0, 0) | 0
	            }

	            function M3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return Od(a | 0, b | 0, c | 0, 0) | 0
	            }

	            function N3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return Pd(a | 0, b | 0, c | 0, 0) | 0
	            }

	            function O3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return qd(a | 0, b | 0, c | 0, 0) | 0
	            }

	            function P3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return rd(a | 0, b | 0, c | 0, 0) | 0
	            }

	            function Q3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return Qd(a | 0, b | 0, c | 0, 0) | 0
	            }

	            function R3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return Rd(a | 0, b | 0, c | 0, 0) | 0
	            }

	            function S3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return fo(a | 0, b | 0, c | 0, 0) | 0
	            }

	            function T3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function U3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function V3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function W3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return mk() | 0
	            }

	            function X3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function Y3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function Z3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return nk(a | 0) | 0
	            }

	            function _3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return ok(a | 0) | 0
	            }

	            function $3(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return qk(a | 0) | 0
	            }

	            function a4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return _k(a | 0) | 0
	            }

	            function b4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return bl(a | 0) | 0
	            }

	            function c4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return dl(a | 0) | 0
	            }

	            function d4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return gl(a | 0, b | 0, c | 0, 0) | 0
	            }

	            function e4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function f4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return on(a | 0) | 0
	            }

	            function g4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function h4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return vn(a | 0) | 0
	            }

	            function i4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function j4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return yn(a | 0) | 0
	            }

	            function k4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function l4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function m4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function n4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return Cn(a | 0, b | 0) | 0
	            }

	            function o4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function p4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function q4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function r4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function s4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function t4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function u4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return _n(a | 0, b | 0) | 0
	            }

	            function v4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function w4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function x4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function y4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function z4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function A4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function B4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function C4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function D4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function E4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function F4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function G4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function H4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function I4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function J4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function K4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function L4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function M4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function N4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function O4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function P4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function Q4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function R4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function S4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function T4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function U4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function V4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function W4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function X4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function Y4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function Z4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return ds(a | 0, b | 0) | 0
	            }

	            function _4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return es(a | 0, b | 0) | 0
	            }

	            function $4(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return js(a | 0, b | 0) | 0
	            }

	            function a5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return wu(a | 0, b | 0) | 0
	            }

	            function b5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return $r(a | 0, b | 0) | 0
	            }

	            function c5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return as(a | 0, b | 0) | 0
	            }

	            function d5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return bs(a | 0, b | 0) | 0
	            }

	            function e5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return hs(a | 0, b | 0) | 0
	            }

	            function f5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return fs(a | 0, b | 0) | 0
	            }

	            function g5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return is(a | 0, b | 0) | 0
	            }

	            function h5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return cs(a | 0, b | 0) | 0
	            }

	            function i5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return xu(a | 0, b | 0) | 0
	            }

	            function j5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return gs(a | 0, b | 0) | 0
	            }

	            function k5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return _r(a | 0, b | 0) | 0
	            }

	            function l5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return dr(a | 0, b | 0) | 0
	            }

	            function m5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function n5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function o5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function p5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function q5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function r5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function s5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function t5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function u5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function v5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function w5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function x5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return $x(a | 0, b | 0) | 0
	            }

	            function y5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return dy(a | 0, b | 0) | 0
	            }

	            function z5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return fy(a | 0, b | 0) | 0
	            }

	            function A5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return jy(a | 0, b | 0) | 0
	            }

	            function B5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function C5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function D5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function E5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function F5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function G5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function H5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function I5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return RB(a | 0) | 0
	            }

	            function J5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return SB(a | 0) | 0
	            }

	            function K5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return TB(a | 0) | 0
	            }

	            function L5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return VB(a | 0, b | 0) | 0
	            }

	            function M5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function N5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function O5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function P5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function Q5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function R5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function S5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function T5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function U5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function V5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function W5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function X5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function Y5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function Z5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return hC(a | 0, b | 0) | 0
	            }

	            function _5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function $5(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function a6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function b6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function c6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function d6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function e6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function f6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function g6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function h6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function i6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function j6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function k6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function l6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function m6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function n6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function o6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function p6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function q6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function r6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function s6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function t6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function u6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return nN(a | 0, b | 0) | 0
	            }

	            function v6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return oN(a | 0, b | 0, c | 0, 0, 0) | 0
	            }

	            function w6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return pN(a | 0, b | 0, c | 0, 0, 0, 0, 0) | 0
	            }

	            function x6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return qN(a | 0, b | 0, c | 0, 0, 0, 0) | 0
	            }

	            function y6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function z6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return tN(a | 0, b | 0) | 0
	            }

	            function A6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return uN(a | 0, b | 0, c | 0, 0, 0) | 0
	            }

	            function B6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return vN(a | 0, b | 0, c | 0, 0, 0, 0, 0) | 0
	            }

	            function C6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function D6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function E6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function F6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function G6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function H6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function I6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function J6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function K6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return 0
	            }

	            function L6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return WR(a | 0, b | 0, c | 0, 0) | 0
	            }

	            function M6(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                return QS(a | 0, b | 0) | 0
	            }

	            function N6(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                da(2)
	            }

	            function O6(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                uc(a | 0, b | 0, c | 0, d | 0)
	            }

	            function P6(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                vc(a | 0) | 0
	            }

	            function Q6(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                wc(a | 0) | 0
	            }

	            function R6(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                xc(a | 0) | 0
	            }

	            function S6(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                yc(a | 0, b | 0, c | 0) | 0
	            }

	            function T6(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                zc(a | 0, b | 0) | 0
	            }

	            function U6(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Ac(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0)
	            }

	            function V6(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Bc(a | 0, b | 0, c | 0, d | 0)
	            }

	            function W6(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Dc(a | 0, b | 0, c | 0, d | 0)
	            }

	            function X6(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Ec(a | 0, b | 0, c | 0, d | 0, e | 0)
	            }

	            function Y6(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Fc(a | 0, b | 0)
	            }

	            function Z6(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Gc(a | 0)
	            }

	            function _6(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Hc(a | 0)
	            }

	            function $6(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Wc(a | 0, b | 0, c | 0)
	            }

	            function a7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Xc(a | 0, b | 0)
	            }

	            function b7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Ic(a | 0, b | 0)
	            }

	            function c7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Jc(a | 0, b | 0, c | 0)
	            }

	            function d7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Kc(a | 0, b | 0, c | 0)
	            }

	            function e7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Lc(a | 0, b | 0, c | 0)
	            }

	            function f7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Mc(a | 0, b | 0)
	            }

	            function g7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Nc(a | 0, b | 0, c | 0)
	            }

	            function h7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Oc(a | 0, b | 0, c | 0)
	            }

	            function i7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Pc(a | 0, b | 0, c | 0)
	            }

	            function j7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Qc(a | 0, b | 0) | 0
	            }

	            function k7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Rc(a | 0, b | 0, c | 0)
	            }

	            function l7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Sc(a | 0, b | 0, c | 0, d | 0)
	            }

	            function m7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Tc(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0, g | 0, 0, 0)
	            }

	            function n7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Uc(a | 0, b | 0, c | 0, d | 0)
	            }

	            function o7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Xk(a | 0, b | 0, c | 0) | 0
	            }

	            function p7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                jT(a | 0)
	            }

	            function q7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                iT(a | 0) | 0
	            }

	            function r7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                kT(a | 0, b | 0) | 0
	            }

	            function s7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                my(a | 0) | 0
	            }

	            function t7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Td(a | 0, b | 0, c | 0)
	            }

	            function u7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                SP(a | 0, b | 0, c | 0, d | 0)
	            }

	            function v7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                PP(a | 0) | 0
	            }

	            function w7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                QP(a | 0) | 0
	            }

	            function x7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                RP(a | 0) | 0
	            }

	            function y7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                UP(a | 0, b | 0, c | 0) | 0
	            }

	            function z7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                VP(a | 0, b | 0) | 0
	            }

	            function A7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                XP(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0)
	            }

	            function B7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                _P(a | 0, b | 0, c | 0, d | 0)
	            }

	            function C7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                ZP(a | 0, b | 0, c | 0, d | 0)
	            }

	            function D7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                $P(a | 0, b | 0, c | 0, d | 0, e | 0)
	            }

	            function E7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                aQ(a | 0, b | 0)
	            }

	            function F7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                bQ(a | 0)
	            }

	            function G7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                cQ(a | 0)
	            }

	            function H7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                dQ(a | 0, b | 0, c | 0)
	            }

	            function I7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                eQ(a | 0, b | 0)
	            }

	            function J7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                hQ(a | 0, b | 0)
	            }

	            function K7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                iQ(a | 0, b | 0, c | 0)
	            }

	            function L7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                kQ(a | 0, b | 0, c | 0)
	            }

	            function M7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                lQ(a | 0, b | 0)
	            }

	            function N7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                $d(a | 0, b | 0, c | 0)
	            }

	            function O7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                _d(a | 0, b | 0, c | 0)
	            }

	            function P7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                WP(a | 0, b | 0) | 0
	            }

	            function Q7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                mQ(a | 0, b | 0, c | 0)
	            }

	            function R7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                TP(a | 0, b | 0, c | 0, d | 0)
	            }

	            function S7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                LP(a | 0) | 0
	            }

	            function T7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                MP(a | 0) | 0
	            }

	            function U7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                NP(a | 0) | 0
	            }

	            function V7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                OP(a | 0) | 0
	            }

	            function W7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                jQ(a | 0, b | 0, c | 0)
	            }

	            function X7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                NI(a | 0) | 0
	            }

	            function Y7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                OI(a | 0) | 0
	            }

	            function Z7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                PI(a | 0) | 0
	            }

	            function _7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                QI(a | 0) | 0
	            }

	            function $7(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                RI(a | 0) | 0
	            }

	            function a8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                SI(a | 0) | 0
	            }

	            function b8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                TI(a | 0) | 0
	            }

	            function c8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                UI(a | 0) | 0
	            }

	            function d8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                VI(a | 0) | 0
	            }

	            function e8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                WI(a | 0) | 0
	            }

	            function f8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                XI(a | 0) | 0
	            }

	            function g8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                YI(a | 0) | 0
	            }

	            function h8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                ZI(a | 0) | 0
	            }

	            function i8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                _I(a | 0) | 0
	            }

	            function j8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                $I(a | 0) | 0
	            }

	            function k8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                aJ(a | 0) | 0
	            }

	            function l8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                bJ(a | 0) | 0
	            }

	            function m8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                cJ(a | 0) | 0
	            }

	            function n8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                dJ(a | 0) | 0
	            }

	            function o8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                eJ(a | 0) | 0
	            }

	            function p8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                fJ(a | 0) | 0
	            }

	            function q8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                gJ(a | 0) | 0
	            }

	            function r8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                hJ(a | 0) | 0
	            }

	            function s8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                iJ(a | 0) | 0
	            }

	            function t8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                jJ(a | 0) | 0
	            }

	            function u8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                kJ(a | 0) | 0
	            }

	            function v8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                lJ(a | 0) | 0
	            }

	            function w8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                mJ(a | 0) | 0
	            }

	            function x8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                nJ(a | 0) | 0
	            }

	            function y8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                oJ(a | 0) | 0
	            }

	            function z8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                pJ(a | 0) | 0
	            }

	            function A8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                qJ(a | 0) | 0
	            }

	            function B8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                rJ(a | 0) | 0
	            }

	            function C8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                sJ(a | 0) | 0
	            }

	            function D8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                tJ(a | 0) | 0
	            }

	            function E8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                uJ(a | 0) | 0
	            }

	            function F8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                vJ(a | 0) | 0
	            }

	            function G8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                wJ(a | 0) | 0
	            }

	            function H8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                xJ(a | 0) | 0
	            }

	            function I8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                yJ(a | 0) | 0
	            }

	            function J8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                zJ(a | 0) | 0
	            }

	            function K8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                AJ(a | 0) | 0
	            }

	            function L8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                BJ(a | 0) | 0
	            }

	            function M8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                CJ(a | 0) | 0
	            }

	            function N8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                DJ(a | 0) | 0
	            }

	            function O8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                EJ(a | 0) | 0
	            }

	            function P8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                FJ(a | 0) | 0
	            }

	            function Q8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                GJ(a | 0) | 0
	            }

	            function R8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                HJ(a | 0) | 0
	            }

	            function S8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                IJ(a | 0) | 0
	            }

	            function T8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                JJ(a | 0) | 0
	            }

	            function U8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                KJ(a | 0) | 0
	            }

	            function V8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                LJ(a | 0) | 0
	            }

	            function W8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                MJ(a | 0) | 0
	            }

	            function X8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                NJ(a | 0) | 0
	            }

	            function Y8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                OJ(a | 0) | 0
	            }

	            function Z8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                PJ(a | 0) | 0
	            }

	            function _8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                QJ(a | 0) | 0
	            }

	            function $8(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                RJ(a | 0) | 0
	            }

	            function a9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                SJ(a | 0) | 0
	            }

	            function b9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                TJ(a | 0) | 0
	            }

	            function c9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                UJ(a | 0) | 0
	            }

	            function d9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                VJ(a | 0) | 0
	            }

	            function e9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                WJ(a | 0) | 0
	            }

	            function f9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                XJ(a | 0) | 0
	            }

	            function g9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                YJ(a | 0) | 0
	            }

	            function h9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                ZJ(a | 0) | 0
	            }

	            function i9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                _J(a | 0) | 0
	            }

	            function j9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                $J(a | 0) | 0
	            }

	            function k9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                aK(a | 0) | 0
	            }

	            function l9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                bK(a | 0) | 0
	            }

	            function m9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                cK(a | 0) | 0
	            }

	            function n9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                dK(a | 0) | 0
	            }

	            function o9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                eK(a | 0) | 0
	            }

	            function p9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                fK(a | 0) | 0
	            }

	            function q9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                gK(a | 0) | 0
	            }

	            function r9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                hK(a | 0) | 0
	            }

	            function s9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                iK(a | 0) | 0
	            }

	            function t9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                jK(a | 0) | 0
	            }

	            function u9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                kK(a | 0) | 0
	            }

	            function v9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                lK(a | 0) | 0
	            }

	            function w9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                mK(a | 0) | 0
	            }

	            function x9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                nK(a | 0) | 0
	            }

	            function y9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                oK(a | 0) | 0
	            }

	            function z9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                pK(a | 0) | 0
	            }

	            function A9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                qK(a | 0) | 0
	            }

	            function B9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                rK(a | 0) | 0
	            }

	            function C9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                sK(a | 0) | 0
	            }

	            function D9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                tK(a | 0) | 0
	            }

	            function E9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                uK(a | 0) | 0
	            }

	            function F9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                vK(a | 0) | 0
	            }

	            function G9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                wK(a | 0) | 0
	            }

	            function H9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                xK(a | 0) | 0
	            }

	            function I9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                yK(a | 0) | 0
	            }

	            function J9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                zK(a | 0) | 0
	            }

	            function K9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                AK(a | 0) | 0
	            }

	            function L9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                BK(a | 0) | 0
	            }

	            function M9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                CK(a | 0) | 0
	            }

	            function N9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                DK(a | 0) | 0
	            }

	            function O9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                EK(a | 0) | 0
	            }

	            function P9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                FK(a | 0) | 0
	            }

	            function Q9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                GK(a | 0) | 0
	            }

	            function R9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                HK(a | 0) | 0
	            }

	            function S9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                IK(a | 0) | 0
	            }

	            function T9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                JK(a | 0) | 0
	            }

	            function U9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                KK(a | 0) | 0
	            }

	            function V9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                LK(a | 0) | 0
	            }

	            function W9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                MK(a | 0) | 0
	            }

	            function X9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                NK(a | 0) | 0
	            }

	            function Y9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                OK(a | 0) | 0
	            }

	            function Z9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                PK(a | 0) | 0
	            }

	            function _9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                QK(a | 0) | 0
	            }

	            function $9(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                RK(a | 0) | 0
	            }

	            function aaa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                SK(a | 0) | 0
	            }

	            function baa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                TK(a | 0) | 0
	            }

	            function caa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                UK(a | 0) | 0
	            }

	            function daa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                VK(a | 0) | 0
	            }

	            function eaa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                WK(a | 0) | 0
	            }

	            function faa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                XK(a | 0) | 0
	            }

	            function gaa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                YK(a | 0) | 0
	            }

	            function haa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                ZK(a | 0) | 0
	            }

	            function iaa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                _K(a | 0) | 0
	            }

	            function jaa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                $K(a | 0) | 0
	            }

	            function kaa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                aL(a | 0) | 0
	            }

	            function laa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                bL(a | 0) | 0
	            }

	            function maa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                cL(a | 0) | 0
	            }

	            function naa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                dL(a | 0) | 0
	            }

	            function oaa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                eL(a | 0) | 0
	            }

	            function paa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                RT(a | 0, b | 0, c | 0) | 0
	            }

	            function qaa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Vb(a | 0)
	            }

	            function raa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Wb(a | 0) | 0
	            }

	            function saa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Xb(a | 0, b | 0) | 0
	            }

	            function taa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Yb(a | 0) | 0
	            }

	            function uaa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Wk(a | 0, b | 0, c | 0) | 0
	            }

	            function vaa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                _b(a | 0)
	            }

	            function waa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                $b(a | 0)
	            }

	            function xaa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                ac(a | 0, b | 0, c | 0) | 0
	            }

	            function yaa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Ka(a | 0, b | 0, c | 0) | 0
	            }

	            function zaa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                gc(a | 0, b | 0, c | 0) | 0
	            }

	            function Aaa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                hc(a | 0)
	            }

	            function Baa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                ic(a | 0, b | 0, c | 0)
	            }

	            function Caa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                jc(a | 0, b | 0, c | 0)
	            }

	            function Daa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                kc(a | 0, b | 0, c | 0)
	            }

	            function Eaa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                lc(a | 0, b | 0, c | 0)
	            }

	            function Faa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                nc(a | 0) | 0
	            }

	            function Gaa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                md(a | 0, b | 0)
	            }

	            function Haa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                nd(a | 0) | 0
	            }

	            function Iaa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Kd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Jaa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Ld(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Kaa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Md(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Laa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Nd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Maa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Od(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Naa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Pd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Oaa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                qd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Paa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                rd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Qaa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Qd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Raa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Rd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Saa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                fo(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Taa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                ae(a | 0, b | 0, c | 0)
	            }

	            function Uaa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                be(a | 0, b | 0, c | 0)
	            }

	            function Vaa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                tg(a | 0)
	            }

	            function Waa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                mk() | 0
	            }

	            function Xaa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                sh(a | 0, b | 0, c | 0, d | 0, e | 0)
	            }

	            function Yaa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                gk(a | 0, b | 0, c | 0, d | 0, e | 0)
	            }

	            function Zaa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                nk(a | 0) | 0
	            }

	            function _aa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                ok(a | 0) | 0
	            }

	            function $aa(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                pk(a | 0, b | 0, c | 0) | 0
	            }

	            function aba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                qk(a | 0) | 0
	            }

	            function bba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                _k(a | 0) | 0
	            }

	            function cba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                $k(a | 0, b | 0, c | 0) | 0
	            }

	            function dba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                bl(a | 0) | 0
	            }

	            function eba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                cl(a | 0, b | 0, c | 0) | 0
	            }

	            function fba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                dl(a | 0) | 0
	            }

	            function gba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                el(a | 0, b | 0, c | 0) | 0
	            }

	            function hba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                fl(a | 0, b | 0, c | 0) | 0
	            }

	            function iba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                gl(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function jba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                nn(a | 0)
	            }

	            function kba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                on(a | 0) | 0
	            }

	            function lba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                sn(a | 0)
	            }

	            function mba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                vn(a | 0) | 0
	            }

	            function nba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                xn(a | 0)
	            }

	            function oba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                yn(a | 0) | 0
	            }

	            function pba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                zn(a | 0, b | 0)
	            }

	            function qba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                An(a | 0)
	            }

	            function rba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Bn(a | 0)
	            }

	            function sba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Cn(a | 0, b | 0) | 0
	            }

	            function tba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Dn(a | 0)
	            }

	            function uba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                In(a | 0, b | 0, c | 0)
	            }

	            function vba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Rn(a | 0, b | 0, c | 0)
	            }

	            function wba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Sn(a | 0, b | 0, c | 0)
	            }

	            function xba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Tn(a | 0, b | 0, c | 0)
	            }

	            function yba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Un(a | 0, b | 0, c | 0)
	            }

	            function zba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                _n(a | 0, b | 0) | 0
	            }

	            function Aba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                tq(a | 0, b | 0)
	            }

	            function Bba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Qq(a | 0)
	            }

	            function Cba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Bs(a | 0, b | 0)
	            }

	            function Dba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Is(a | 0, b | 0)
	            }

	            function Eba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                ns(a | 0, b | 0)
	            }

	            function Fba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                ts(a | 0, b | 0)
	            }

	            function Gba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                us(a | 0, b | 0)
	            }

	            function Hba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                os(a | 0, b | 0)
	            }

	            function Iba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Es(a | 0, b | 0)
	            }

	            function Jba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Hs(a | 0, b | 0)
	            }

	            function Kba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                ls(a | 0, b | 0)
	            }

	            function Lba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Fs(a | 0, b | 0)
	            }

	            function Mba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                ps(a | 0, b | 0)
	            }

	            function Nba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Cs(a | 0, b | 0)
	            }

	            function Oba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                nt(a | 0, b | 0)
	            }

	            function Pba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                qs(a | 0, b | 0)
	            }

	            function Qba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                zs(a | 0, b | 0)
	            }

	            function Rba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Tr(a | 0, b | 0)
	            }

	            function Sba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                ms(a | 0, b | 0)
	            }

	            function Tba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Js(a | 0, b | 0)
	            }

	            function Uba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                rs(a | 0, b | 0)
	            }

	            function Vba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                ss(a | 0, b | 0)
	            }

	            function Wba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                vs(a | 0, b | 0)
	            }

	            function Xba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                ws(a | 0, b | 0)
	            }

	            function Yba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                xs(a | 0, b | 0)
	            }

	            function Zba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                ys(a | 0, b | 0)
	            }

	            function _ba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Gs(a | 0, b | 0)
	            }

	            function $ba(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Ds(a | 0, b | 0)
	            }

	            function aca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                As(a | 0, b | 0)
	            }

	            function bca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                ot(a | 0, b | 0)
	            }

	            function cca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                uu(a | 0, b | 0, c | 0) | 0
	            }

	            function dca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                ds(a | 0, b | 0) | 0
	            }

	            function eca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                es(a | 0, b | 0) | 0
	            }

	            function fca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                js(a | 0, b | 0) | 0
	            }

	            function gca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                vu(a | 0, b | 0, c | 0) | 0
	            }

	            function hca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                wu(a | 0, b | 0) | 0
	            }

	            function ica(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                $r(a | 0, b | 0) | 0
	            }

	            function jca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                as(a | 0, b | 0) | 0
	            }

	            function kca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                bs(a | 0, b | 0) | 0
	            }

	            function lca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                hs(a | 0, b | 0) | 0
	            }

	            function mca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                fs(a | 0, b | 0) | 0
	            }

	            function nca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                is(a | 0, b | 0) | 0
	            }

	            function oca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                cs(a | 0, b | 0) | 0
	            }

	            function pca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                xu(a | 0, b | 0) | 0
	            }

	            function qca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                gs(a | 0, b | 0) | 0
	            }

	            function rca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                _r(a | 0, b | 0) | 0
	            }

	            function sca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                dr(a | 0, b | 0) | 0
	            }

	            function tca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                jv(a | 0, b | 0)
	            }

	            function uca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                pv(a | 0, b | 0)
	            }

	            function vca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                qv(a | 0, b | 0)
	            }

	            function wca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                rv(a | 0, b | 0)
	            }

	            function xca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                sv(a | 0, b | 0)
	            }

	            function yca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                tv(a | 0, b | 0)
	            }

	            function zca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                uv(a | 0, b | 0)
	            }

	            function Aca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                vv(a | 0, b | 0)
	            }

	            function Bca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                tw(a | 0, b | 0, c | 0)
	            }

	            function Cca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Mw(a | 0)
	            }

	            function Dca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Yw(a | 0)
	            }

	            function Eca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                Kx(a | 0, b | 0, c | 0) | 0
	            }

	            function Fca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                $x(a | 0, b | 0) | 0
	            }

	            function Gca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                dy(a | 0, b | 0) | 0
	            }

	            function Hca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                fy(a | 0, b | 0) | 0
	            }

	            function Ica(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                jy(a | 0, b | 0) | 0
	            }

	            function Jca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                qB(a | 0)
	            }

	            function Kca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                LB(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0, g | 0, 0, 0)
	            }

	            function Lca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                MB(a | 0, b | 0, c | 0, d | 0)
	            }

	            function Mca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                NB(a | 0, b | 0, c | 0)
	            }

	            function Nca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                OB(a | 0, b | 0, c | 0)
	            }

	            function Oca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                PB(a | 0, b | 0)
	            }

	            function Pca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                QB(a | 0, b | 0, c | 0, d | 0)
	            }

	            function Qca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                RB(a | 0) | 0
	            }

	            function Rca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                SB(a | 0) | 0
	            }

	            function Sca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                TB(a | 0) | 0
	            }

	            function Tca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                UB(a | 0, b | 0, c | 0) | 0
	            }

	            function Uca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                VB(a | 0, b | 0) | 0
	            }

	            function Vca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                WB(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0)
	            }

	            function Wca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                XB(a | 0, b | 0, c | 0, d | 0)
	            }

	            function Xca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                ZB(a | 0, b | 0, c | 0, d | 0)
	            }

	            function Yca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                _B(a | 0, b | 0, c | 0, d | 0, e | 0)
	            }

	            function Zca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                $B(a | 0, b | 0)
	            }

	            function _ca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                aC(a | 0)
	            }

	            function $ca(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                bC(a | 0)
	            }

	            function ada(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                cC(a | 0, b | 0, c | 0)
	            }

	            function bda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                dC(a | 0, b | 0)
	            }

	            function cda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                eC(a | 0, b | 0, c | 0)
	            }

	            function dda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                fC(a | 0, b | 0, c | 0)
	            }

	            function eda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                gC(a | 0, b | 0, c | 0)
	            }

	            function fda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                hC(a | 0, b | 0) | 0
	            }

	            function gda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                iC(a | 0, b | 0, c | 0, d | 0)
	            }

	            function hda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                jC(a | 0, b | 0, c | 0)
	            }

	            function ida(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                kC(a | 0, b | 0, c | 0)
	            }

	            function jda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                lC(a | 0, b | 0, c | 0)
	            }

	            function kda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                mC(a | 0, b | 0)
	            }

	            function lda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                nC(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0, g | 0, 0, 0)
	            }

	            function mda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                oC(a | 0, b | 0, c | 0, d | 0)
	            }

	            function nda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                rC(a | 0, b | 0, c | 0) | 0
	            }

	            function oda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                uC(a | 0)
	            }

	            function pda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                AD(a | 0, b | 0)
	            }

	            function qda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                lF(a | 0, b | 0, c | 0, d | 0)
	            }

	            function rda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                uF(a | 0, b | 0)
	            }

	            function sda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                VA(a | 0)
	            }

	            function tda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                wM(a | 0, b | 0, c | 0)
	            }

	            function uda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                xM(a | 0, b | 0)
	            }

	            function vda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                yM(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0, g | 0, 0, 0)
	            }

	            function wda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                zM(a | 0, b | 0, c | 0, d | 0)
	            }

	            function xda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                AM(a | 0, b | 0, c | 0)
	            }

	            function yda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                BM(a | 0, b | 0, c | 0)
	            }

	            function zda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                DM(a | 0, b | 0, c | 0)
	            }

	            function Ada(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                EM(a | 0, b | 0, c | 0)
	            }

	            function Bda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                GM(a | 0, b | 0, c | 0) | 0
	            }

	            function Cda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                FM(a | 0, b | 0)
	            }

	            function Dda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                UM(a | 0)
	            }

	            function Eda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                nN(a | 0, b | 0) | 0
	            }

	            function Fda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                oN(a | 0, b | 0, c | 0, d | 0, e | 0) | 0
	            }

	            function Gda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                pN(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0, g | 0) | 0
	            }

	            function Hda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                qN(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0) | 0
	            }

	            function Ida(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                rN(a | 0, b | 0)
	            }

	            function Jda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                tN(a | 0, b | 0) | 0
	            }

	            function Kda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                uN(a | 0, b | 0, c | 0, d | 0, e | 0) | 0
	            }

	            function Lda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                vN(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0, g | 0) | 0
	            }

	            function Mda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                wN(a | 0, b | 0)
	            }

	            function Nda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                CN(a | 0, b | 0, c | 0)
	            }

	            function Oda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                GN(a | 0, b | 0, c | 0, d | 0)
	            }

	            function Pda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                vO(a | 0, b | 0, c | 0)
	            }

	            function Qda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                wO(a | 0, b | 0, c | 0)
	            }

	            function Rda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                fP(a | 0, b | 0, c | 0, d | 0)
	            }

	            function Sda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                sP(a | 0, b | 0, c | 0)
	            }

	            function Tda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                fQ(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0, g | 0, 0, 0)
	            }

	            function Uda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                gQ(a | 0, b | 0, c | 0, d | 0)
	            }

	            function Vda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                WR(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Wda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                QS(a | 0, b | 0) | 0
	            }

	            function Xda(a, b, c, d, e, f, g) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                hT(a | 0, b | 0, c | 0) | 0
	            }

	            function Yda(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                da(3)
	            }

	            function Zda(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                uc(a | 0, b | 0, c | 0, d | 0)
	            }

	            function _da(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                vc(a | 0) | 0
	            }

	            function $da(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                wc(a | 0) | 0
	            }

	            function aea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                xc(a | 0) | 0
	            }

	            function bea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                yc(a | 0, b | 0, c | 0) | 0
	            }

	            function cea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                zc(a | 0, b | 0) | 0
	            }

	            function dea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Ac(a | 0, b | 0, c | 0, d | 0, e | 0, 0)
	            }

	            function eea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Bc(a | 0, b | 0, c | 0, d | 0)
	            }

	            function fea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Cc(a | 0, b | 0, c | 0, d | 0, e | 0, 0, 0)
	            }

	            function gea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Dc(a | 0, b | 0, c | 0, d | 0)
	            }

	            function hea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Fc(a | 0, b | 0)
	            }

	            function iea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Gc(a | 0)
	            }

	            function jea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Hc(a | 0)
	            }

	            function kea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Wc(a | 0, b | 0, c | 0)
	            }

	            function lea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Xc(a | 0, b | 0)
	            }

	            function mea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Ic(a | 0, b | 0)
	            }

	            function nea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Jc(a | 0, b | 0, c | 0)
	            }

	            function oea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Kc(a | 0, b | 0, c | 0)
	            }

	            function pea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Lc(a | 0, b | 0, c | 0)
	            }

	            function qea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Mc(a | 0, b | 0)
	            }

	            function rea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Nc(a | 0, b | 0, c | 0)
	            }

	            function sea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Oc(a | 0, b | 0, c | 0)
	            }

	            function tea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Pc(a | 0, b | 0, c | 0)
	            }

	            function uea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Qc(a | 0, b | 0) | 0
	            }

	            function vea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Rc(a | 0, b | 0, c | 0)
	            }

	            function wea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Sc(a | 0, b | 0, c | 0, d | 0)
	            }

	            function xea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Tc(a | 0, b | 0, c | 0, d | 0, e | 0, 0, 0, 0, 0)
	            }

	            function yea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Uc(a | 0, b | 0, c | 0, d | 0)
	            }

	            function zea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Xk(a | 0, b | 0, c | 0) | 0
	            }

	            function Aea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                jT(a | 0)
	            }

	            function Bea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                iT(a | 0) | 0
	            }

	            function Cea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                kT(a | 0, b | 0) | 0
	            }

	            function Dea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                my(a | 0) | 0
	            }

	            function Eea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Td(a | 0, b | 0, c | 0)
	            }

	            function Fea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                SP(a | 0, b | 0, c | 0, d | 0)
	            }

	            function Gea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                PP(a | 0) | 0
	            }

	            function Hea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                QP(a | 0) | 0
	            }

	            function Iea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                RP(a | 0) | 0
	            }

	            function Jea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                UP(a | 0, b | 0, c | 0) | 0
	            }

	            function Kea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                VP(a | 0, b | 0) | 0
	            }

	            function Lea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                XP(a | 0, b | 0, c | 0, d | 0, e | 0, 0)
	            }

	            function Mea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                _P(a | 0, b | 0, c | 0, d | 0)
	            }

	            function Nea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                YP(a | 0, b | 0, c | 0, d | 0, e | 0, 0, 0)
	            }

	            function Oea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                ZP(a | 0, b | 0, c | 0, d | 0)
	            }

	            function Pea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                aQ(a | 0, b | 0)
	            }

	            function Qea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                bQ(a | 0)
	            }

	            function Rea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                cQ(a | 0)
	            }

	            function Sea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                dQ(a | 0, b | 0, c | 0)
	            }

	            function Tea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                eQ(a | 0, b | 0)
	            }

	            function Uea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                hQ(a | 0, b | 0)
	            }

	            function Vea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                iQ(a | 0, b | 0, c | 0)
	            }

	            function Wea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                kQ(a | 0, b | 0, c | 0)
	            }

	            function Xea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                lQ(a | 0, b | 0)
	            }

	            function Yea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                $d(a | 0, b | 0, c | 0)
	            }

	            function Zea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                _d(a | 0, b | 0, c | 0)
	            }

	            function _ea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                WP(a | 0, b | 0) | 0
	            }

	            function $ea(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                mQ(a | 0, b | 0, c | 0)
	            }

	            function afa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                TP(a | 0, b | 0, c | 0, d | 0)
	            }

	            function bfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                LP(a | 0) | 0
	            }

	            function cfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                MP(a | 0) | 0
	            }

	            function dfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                NP(a | 0) | 0
	            }

	            function efa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                OP(a | 0) | 0
	            }

	            function ffa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                jQ(a | 0, b | 0, c | 0)
	            }

	            function gfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                NI(a | 0) | 0
	            }

	            function hfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                OI(a | 0) | 0
	            }

	            function ifa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                PI(a | 0) | 0
	            }

	            function jfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                QI(a | 0) | 0
	            }

	            function kfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                RI(a | 0) | 0
	            }

	            function lfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                SI(a | 0) | 0
	            }

	            function mfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                TI(a | 0) | 0
	            }

	            function nfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                UI(a | 0) | 0
	            }

	            function ofa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                VI(a | 0) | 0
	            }

	            function pfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                WI(a | 0) | 0
	            }

	            function qfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                XI(a | 0) | 0
	            }

	            function rfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                YI(a | 0) | 0
	            }

	            function sfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                ZI(a | 0) | 0
	            }

	            function tfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                _I(a | 0) | 0
	            }

	            function ufa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                $I(a | 0) | 0
	            }

	            function vfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                aJ(a | 0) | 0
	            }

	            function wfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                bJ(a | 0) | 0
	            }

	            function xfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                cJ(a | 0) | 0
	            }

	            function yfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                dJ(a | 0) | 0
	            }

	            function zfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                eJ(a | 0) | 0
	            }

	            function Afa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                fJ(a | 0) | 0
	            }

	            function Bfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                gJ(a | 0) | 0
	            }

	            function Cfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                hJ(a | 0) | 0
	            }

	            function Dfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                iJ(a | 0) | 0
	            }

	            function Efa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                jJ(a | 0) | 0
	            }

	            function Ffa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                kJ(a | 0) | 0
	            }

	            function Gfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                lJ(a | 0) | 0
	            }

	            function Hfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                mJ(a | 0) | 0
	            }

	            function Ifa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                nJ(a | 0) | 0
	            }

	            function Jfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                oJ(a | 0) | 0
	            }

	            function Kfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                pJ(a | 0) | 0
	            }

	            function Lfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                qJ(a | 0) | 0
	            }

	            function Mfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                rJ(a | 0) | 0
	            }

	            function Nfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                sJ(a | 0) | 0
	            }

	            function Ofa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                tJ(a | 0) | 0
	            }

	            function Pfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                uJ(a | 0) | 0
	            }

	            function Qfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                vJ(a | 0) | 0
	            }

	            function Rfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                wJ(a | 0) | 0
	            }

	            function Sfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                xJ(a | 0) | 0
	            }

	            function Tfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                yJ(a | 0) | 0
	            }

	            function Ufa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                zJ(a | 0) | 0
	            }

	            function Vfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                AJ(a | 0) | 0
	            }

	            function Wfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                BJ(a | 0) | 0
	            }

	            function Xfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                CJ(a | 0) | 0
	            }

	            function Yfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                DJ(a | 0) | 0
	            }

	            function Zfa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                EJ(a | 0) | 0
	            }

	            function _fa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                FJ(a | 0) | 0
	            }

	            function $fa(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                GJ(a | 0) | 0
	            }

	            function aga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                HJ(a | 0) | 0
	            }

	            function bga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                IJ(a | 0) | 0
	            }

	            function cga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                JJ(a | 0) | 0
	            }

	            function dga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                KJ(a | 0) | 0
	            }

	            function ega(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                LJ(a | 0) | 0
	            }

	            function fga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                MJ(a | 0) | 0
	            }

	            function gga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                NJ(a | 0) | 0
	            }

	            function hga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                OJ(a | 0) | 0
	            }

	            function iga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                PJ(a | 0) | 0
	            }

	            function jga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                QJ(a | 0) | 0
	            }

	            function kga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                RJ(a | 0) | 0
	            }

	            function lga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                SJ(a | 0) | 0
	            }

	            function mga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                TJ(a | 0) | 0
	            }

	            function nga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                UJ(a | 0) | 0
	            }

	            function oga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                VJ(a | 0) | 0
	            }

	            function pga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                WJ(a | 0) | 0
	            }

	            function qga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                XJ(a | 0) | 0
	            }

	            function rga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                YJ(a | 0) | 0
	            }

	            function sga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                ZJ(a | 0) | 0
	            }

	            function tga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                _J(a | 0) | 0
	            }

	            function uga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                $J(a | 0) | 0
	            }

	            function vga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                aK(a | 0) | 0
	            }

	            function wga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                bK(a | 0) | 0
	            }

	            function xga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                cK(a | 0) | 0
	            }

	            function yga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                dK(a | 0) | 0
	            }

	            function zga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                eK(a | 0) | 0
	            }

	            function Aga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                fK(a | 0) | 0
	            }

	            function Bga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                gK(a | 0) | 0
	            }

	            function Cga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                hK(a | 0) | 0
	            }

	            function Dga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                iK(a | 0) | 0
	            }

	            function Ega(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                jK(a | 0) | 0
	            }

	            function Fga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                kK(a | 0) | 0
	            }

	            function Gga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                lK(a | 0) | 0
	            }

	            function Hga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                mK(a | 0) | 0
	            }

	            function Iga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                nK(a | 0) | 0
	            }

	            function Jga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                oK(a | 0) | 0
	            }

	            function Kga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                pK(a | 0) | 0
	            }

	            function Lga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                qK(a | 0) | 0
	            }

	            function Mga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                rK(a | 0) | 0
	            }

	            function Nga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                sK(a | 0) | 0
	            }

	            function Oga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                tK(a | 0) | 0
	            }

	            function Pga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                uK(a | 0) | 0
	            }

	            function Qga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                vK(a | 0) | 0
	            }

	            function Rga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                wK(a | 0) | 0
	            }

	            function Sga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                xK(a | 0) | 0
	            }

	            function Tga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                yK(a | 0) | 0
	            }

	            function Uga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                zK(a | 0) | 0
	            }

	            function Vga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                AK(a | 0) | 0
	            }

	            function Wga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                BK(a | 0) | 0
	            }

	            function Xga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                CK(a | 0) | 0
	            }

	            function Yga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                DK(a | 0) | 0
	            }

	            function Zga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                EK(a | 0) | 0
	            }

	            function _ga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                FK(a | 0) | 0
	            }

	            function $ga(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                GK(a | 0) | 0
	            }

	            function aha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                HK(a | 0) | 0
	            }

	            function bha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                IK(a | 0) | 0
	            }

	            function cha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                JK(a | 0) | 0
	            }

	            function dha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                KK(a | 0) | 0
	            }

	            function eha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                LK(a | 0) | 0
	            }

	            function fha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                MK(a | 0) | 0
	            }

	            function gha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                NK(a | 0) | 0
	            }

	            function hha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                OK(a | 0) | 0
	            }

	            function iha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                PK(a | 0) | 0
	            }

	            function jha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                QK(a | 0) | 0
	            }

	            function kha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                RK(a | 0) | 0
	            }

	            function lha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                SK(a | 0) | 0
	            }

	            function mha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                TK(a | 0) | 0
	            }

	            function nha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                UK(a | 0) | 0
	            }

	            function oha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                VK(a | 0) | 0
	            }

	            function pha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                WK(a | 0) | 0
	            }

	            function qha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                XK(a | 0) | 0
	            }

	            function rha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                YK(a | 0) | 0
	            }

	            function sha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                ZK(a | 0) | 0
	            }

	            function tha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                _K(a | 0) | 0
	            }

	            function uha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                $K(a | 0) | 0
	            }

	            function vha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                aL(a | 0) | 0
	            }

	            function wha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                bL(a | 0) | 0
	            }

	            function xha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                cL(a | 0) | 0
	            }

	            function yha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                dL(a | 0) | 0
	            }

	            function zha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                eL(a | 0) | 0
	            }

	            function Aha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                RT(a | 0, b | 0, c | 0) | 0
	            }

	            function Bha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Vb(a | 0)
	            }

	            function Cha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Wb(a | 0) | 0
	            }

	            function Dha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Xb(a | 0, b | 0) | 0
	            }

	            function Eha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Yb(a | 0) | 0
	            }

	            function Fha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Wk(a | 0, b | 0, c | 0) | 0
	            }

	            function Gha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                _b(a | 0)
	            }

	            function Hha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                $b(a | 0)
	            }

	            function Iha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                ac(a | 0, b | 0, c | 0) | 0
	            }

	            function Jha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Ka(a | 0, b | 0, c | 0) | 0
	            }

	            function Kha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                gc(a | 0, b | 0, c | 0) | 0
	            }

	            function Lha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                hc(a | 0)
	            }

	            function Mha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                ic(a | 0, b | 0, c | 0)
	            }

	            function Nha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                jc(a | 0, b | 0, c | 0)
	            }

	            function Oha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                kc(a | 0, b | 0, c | 0)
	            }

	            function Pha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                lc(a | 0, b | 0, c | 0)
	            }

	            function Qha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                nc(a | 0) | 0
	            }

	            function Rha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                md(a | 0, b | 0)
	            }

	            function Sha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                nd(a | 0) | 0
	            }

	            function Tha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Kd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Uha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Ld(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Vha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Md(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Wha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Nd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Xha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Od(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Yha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Pd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Zha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                qd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function _ha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                rd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function $ha(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Qd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function aia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Rd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function bia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                fo(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function cia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                ae(a | 0, b | 0, c | 0)
	            }

	            function dia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                be(a | 0, b | 0, c | 0)
	            }

	            function eia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                tg(a | 0)
	            }

	            function fia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                mk() | 0
	            }

	            function gia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                nk(a | 0) | 0
	            }

	            function hia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                ok(a | 0) | 0
	            }

	            function iia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                pk(a | 0, b | 0, c | 0) | 0
	            }

	            function jia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                qk(a | 0) | 0
	            }

	            function kia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                _k(a | 0) | 0
	            }

	            function lia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                $k(a | 0, b | 0, c | 0) | 0
	            }

	            function mia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                bl(a | 0) | 0
	            }

	            function nia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                cl(a | 0, b | 0, c | 0) | 0
	            }

	            function oia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                dl(a | 0) | 0
	            }

	            function pia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                el(a | 0, b | 0, c | 0) | 0
	            }

	            function qia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                fl(a | 0, b | 0, c | 0) | 0
	            }

	            function ria(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                gl(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function sia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                nn(a | 0)
	            }

	            function tia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                on(a | 0) | 0
	            }

	            function uia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                sn(a | 0)
	            }

	            function via(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                vn(a | 0) | 0
	            }

	            function wia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                xn(a | 0)
	            }

	            function xia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                yn(a | 0) | 0
	            }

	            function yia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                zn(a | 0, b | 0)
	            }

	            function zia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                An(a | 0)
	            }

	            function Aia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Bn(a | 0)
	            }

	            function Bia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Cn(a | 0, b | 0) | 0
	            }

	            function Cia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Dn(a | 0)
	            }

	            function Dia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                In(a | 0, b | 0, c | 0)
	            }

	            function Eia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Rn(a | 0, b | 0, c | 0)
	            }

	            function Fia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Sn(a | 0, b | 0, c | 0)
	            }

	            function Gia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Tn(a | 0, b | 0, c | 0)
	            }

	            function Hia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Un(a | 0, b | 0, c | 0)
	            }

	            function Iia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                _n(a | 0, b | 0) | 0
	            }

	            function Jia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                tq(a | 0, b | 0)
	            }

	            function Kia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Qq(a | 0)
	            }

	            function Lia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Bs(a | 0, b | 0)
	            }

	            function Mia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Is(a | 0, b | 0)
	            }

	            function Nia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                ns(a | 0, b | 0)
	            }

	            function Oia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                ts(a | 0, b | 0)
	            }

	            function Pia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                us(a | 0, b | 0)
	            }

	            function Qia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                os(a | 0, b | 0)
	            }

	            function Ria(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Es(a | 0, b | 0)
	            }

	            function Sia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Hs(a | 0, b | 0)
	            }

	            function Tia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                ls(a | 0, b | 0)
	            }

	            function Uia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Fs(a | 0, b | 0)
	            }

	            function Via(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                ps(a | 0, b | 0)
	            }

	            function Wia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Cs(a | 0, b | 0)
	            }

	            function Xia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                nt(a | 0, b | 0)
	            }

	            function Yia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                qs(a | 0, b | 0)
	            }

	            function Zia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                zs(a | 0, b | 0)
	            }

	            function _ia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Tr(a | 0, b | 0)
	            }

	            function $ia(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                ms(a | 0, b | 0)
	            }

	            function aja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Js(a | 0, b | 0)
	            }

	            function bja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                rs(a | 0, b | 0)
	            }

	            function cja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                ss(a | 0, b | 0)
	            }

	            function dja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                vs(a | 0, b | 0)
	            }

	            function eja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                ws(a | 0, b | 0)
	            }

	            function fja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                xs(a | 0, b | 0)
	            }

	            function gja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                ys(a | 0, b | 0)
	            }

	            function hja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Gs(a | 0, b | 0)
	            }

	            function ija(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Ds(a | 0, b | 0)
	            }

	            function jja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                As(a | 0, b | 0)
	            }

	            function kja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                ot(a | 0, b | 0)
	            }

	            function lja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                uu(a | 0, b | 0, c | 0) | 0
	            }

	            function mja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                ds(a | 0, b | 0) | 0
	            }

	            function nja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                es(a | 0, b | 0) | 0
	            }

	            function oja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                js(a | 0, b | 0) | 0
	            }

	            function pja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                vu(a | 0, b | 0, c | 0) | 0
	            }

	            function qja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                wu(a | 0, b | 0) | 0
	            }

	            function rja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                $r(a | 0, b | 0) | 0
	            }

	            function sja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                as(a | 0, b | 0) | 0
	            }

	            function tja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                bs(a | 0, b | 0) | 0
	            }

	            function uja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                hs(a | 0, b | 0) | 0
	            }

	            function vja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                fs(a | 0, b | 0) | 0
	            }

	            function wja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                is(a | 0, b | 0) | 0
	            }

	            function xja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                cs(a | 0, b | 0) | 0
	            }

	            function yja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                xu(a | 0, b | 0) | 0
	            }

	            function zja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                gs(a | 0, b | 0) | 0
	            }

	            function Aja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                _r(a | 0, b | 0) | 0
	            }

	            function Bja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                dr(a | 0, b | 0) | 0
	            }

	            function Cja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                jv(a | 0, b | 0)
	            }

	            function Dja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                pv(a | 0, b | 0)
	            }

	            function Eja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                qv(a | 0, b | 0)
	            }

	            function Fja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                rv(a | 0, b | 0)
	            }

	            function Gja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                sv(a | 0, b | 0)
	            }

	            function Hja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                tv(a | 0, b | 0)
	            }

	            function Ija(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                uv(a | 0, b | 0)
	            }

	            function Jja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                vv(a | 0, b | 0)
	            }

	            function Kja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                tw(a | 0, b | 0, c | 0)
	            }

	            function Lja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Mw(a | 0)
	            }

	            function Mja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Yw(a | 0)
	            }

	            function Nja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                Kx(a | 0, b | 0, c | 0) | 0
	            }

	            function Oja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                $x(a | 0, b | 0) | 0
	            }

	            function Pja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                dy(a | 0, b | 0) | 0
	            }

	            function Qja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                fy(a | 0, b | 0) | 0
	            }

	            function Rja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                jy(a | 0, b | 0) | 0
	            }

	            function Sja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                qB(a | 0)
	            }

	            function Tja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                LB(a | 0, b | 0, c | 0, d | 0, e | 0, 0, 0, 0, 0)
	            }

	            function Uja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                MB(a | 0, b | 0, c | 0, d | 0)
	            }

	            function Vja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                NB(a | 0, b | 0, c | 0)
	            }

	            function Wja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                OB(a | 0, b | 0, c | 0)
	            }

	            function Xja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                PB(a | 0, b | 0)
	            }

	            function Yja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                QB(a | 0, b | 0, c | 0, d | 0)
	            }

	            function Zja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                RB(a | 0) | 0
	            }

	            function _ja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                SB(a | 0) | 0
	            }

	            function $ja(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                TB(a | 0) | 0
	            }

	            function aka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                UB(a | 0, b | 0, c | 0) | 0
	            }

	            function bka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                VB(a | 0, b | 0) | 0
	            }

	            function cka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                WB(a | 0, b | 0, c | 0, d | 0, e | 0, 0)
	            }

	            function dka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                XB(a | 0, b | 0, c | 0, d | 0)
	            }

	            function eka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                YB(a | 0, b | 0, c | 0, d | 0, e | 0, 0, 0)
	            }

	            function fka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                ZB(a | 0, b | 0, c | 0, d | 0)
	            }

	            function gka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                $B(a | 0, b | 0)
	            }

	            function hka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                aC(a | 0)
	            }

	            function ika(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                bC(a | 0)
	            }

	            function jka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                cC(a | 0, b | 0, c | 0)
	            }

	            function kka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                dC(a | 0, b | 0)
	            }

	            function lka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                eC(a | 0, b | 0, c | 0)
	            }

	            function mka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                fC(a | 0, b | 0, c | 0)
	            }

	            function nka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                gC(a | 0, b | 0, c | 0)
	            }

	            function oka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                hC(a | 0, b | 0) | 0
	            }

	            function pka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                iC(a | 0, b | 0, c | 0, d | 0)
	            }

	            function qka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                jC(a | 0, b | 0, c | 0)
	            }

	            function rka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                kC(a | 0, b | 0, c | 0)
	            }

	            function ska(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                lC(a | 0, b | 0, c | 0)
	            }

	            function tka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                mC(a | 0, b | 0)
	            }

	            function uka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                nC(a | 0, b | 0, c | 0, d | 0, e | 0, 0, 0, 0, 0)
	            }

	            function vka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                oC(a | 0, b | 0, c | 0, d | 0)
	            }

	            function wka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                rC(a | 0, b | 0, c | 0) | 0
	            }

	            function xka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                uC(a | 0)
	            }

	            function yka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                AD(a | 0, b | 0)
	            }

	            function zka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                lF(a | 0, b | 0, c | 0, d | 0)
	            }

	            function Aka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                uF(a | 0, b | 0)
	            }

	            function Bka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                VA(a | 0)
	            }

	            function Cka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                wM(a | 0, b | 0, c | 0)
	            }

	            function Dka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                xM(a | 0, b | 0)
	            }

	            function Eka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                yM(a | 0, b | 0, c | 0, d | 0, e | 0, 0, 0, 0, 0)
	            }

	            function Fka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                zM(a | 0, b | 0, c | 0, d | 0)
	            }

	            function Gka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                AM(a | 0, b | 0, c | 0)
	            }

	            function Hka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                BM(a | 0, b | 0, c | 0)
	            }

	            function Ika(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                DM(a | 0, b | 0, c | 0)
	            }

	            function Jka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                EM(a | 0, b | 0, c | 0)
	            }

	            function Kka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                GM(a | 0, b | 0, c | 0) | 0
	            }

	            function Lka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                FM(a | 0, b | 0)
	            }

	            function Mka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                UM(a | 0)
	            }

	            function Nka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                nN(a | 0, b | 0) | 0
	            }

	            function Oka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                oN(a | 0, b | 0, c | 0, d | 0, e | 0) | 0
	            }

	            function Pka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                pN(a | 0, b | 0, c | 0, d | 0, e | 0, 0, 0) | 0
	            }

	            function Qka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                qN(a | 0, b | 0, c | 0, d | 0, e | 0, 0) | 0
	            }

	            function Rka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                rN(a | 0, b | 0)
	            }

	            function Ska(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                tN(a | 0, b | 0) | 0
	            }

	            function Tka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                uN(a | 0, b | 0, c | 0, d | 0, e | 0) | 0
	            }

	            function Uka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                vN(a | 0, b | 0, c | 0, d | 0, e | 0, 0, 0) | 0
	            }

	            function Vka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                wN(a | 0, b | 0)
	            }

	            function Wka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                CN(a | 0, b | 0, c | 0)
	            }

	            function Xka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                GN(a | 0, b | 0, c | 0, d | 0)
	            }

	            function Yka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                vO(a | 0, b | 0, c | 0)
	            }

	            function Zka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                wO(a | 0, b | 0, c | 0)
	            }

	            function _ka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                fP(a | 0, b | 0, c | 0, d | 0)
	            }

	            function $ka(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                sP(a | 0, b | 0, c | 0)
	            }

	            function ala(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                fQ(a | 0, b | 0, c | 0, d | 0, e | 0, 0, 0, 0, 0)
	            }

	            function bla(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                gQ(a | 0, b | 0, c | 0, d | 0)
	            }

	            function cla(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                WR(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function dla(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                QS(a | 0, b | 0) | 0
	            }

	            function ela(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                hT(a | 0, b | 0, c | 0) | 0
	            }

	            function fla() {
	                da(4);
	                return 0
	            }

	            function gla() {
	                return 0
	            }

	            function hla() {
	                return vc(0) | 0
	            }

	            function ila() {
	                return wc(0) | 0
	            }

	            function jla() {
	                return xc(0) | 0
	            }

	            function kla() {
	                return yc(0, 0, 0) | 0
	            }

	            function lla() {
	                return zc(0, 0) | 0
	            }

	            function mla() {
	                return 0
	            }

	            function nla() {
	                return 0
	            }

	            function ola() {
	                return 0
	            }

	            function pla() {
	                return 0
	            }

	            function qla() {
	                return 0
	            }

	            function rla() {
	                return 0
	            }

	            function sla() {
	                return 0
	            }

	            function tla() {
	                return 0
	            }

	            function ula() {
	                return 0
	            }

	            function vla() {
	                return 0
	            }

	            function wla() {
	                return 0
	            }

	            function xla() {
	                return 0
	            }

	            function yla() {
	                return 0
	            }

	            function zla() {
	                return 0
	            }

	            function Ala() {
	                return 0
	            }

	            function Bla() {
	                return 0
	            }

	            function Cla() {
	                return 0
	            }

	            function Dla() {
	                return 0
	            }

	            function Ela() {
	                return Qc(0, 0) | 0
	            }

	            function Fla() {
	                return 0
	            }

	            function Gla() {
	                return 0
	            }

	            function Hla() {
	                return 0
	            }

	            function Ila() {
	                return 0
	            }

	            function Jla() {
	                return Xk(0, 0, 0) | 0
	            }

	            function Kla() {
	                return 0
	            }

	            function Lla() {
	                return iT(0) | 0
	            }

	            function Mla() {
	                return kT(0, 0) | 0
	            }

	            function Nla() {
	                return my(0) | 0
	            }

	            function Ola() {
	                return 0
	            }

	            function Pla() {
	                return 0
	            }

	            function Qla() {
	                return PP(0) | 0
	            }

	            function Rla() {
	                return QP(0) | 0
	            }

	            function Sla() {
	                return RP(0) | 0
	            }

	            function Tla() {
	                return UP(0, 0, 0) | 0
	            }

	            function Ula() {
	                return VP(0, 0) | 0
	            }

	            function Vla() {
	                return 0
	            }

	            function Wla() {
	                return 0
	            }

	            function Xla() {
	                return 0
	            }

	            function Yla() {
	                return 0
	            }

	            function Zla() {
	                return 0
	            }

	            function _la() {
	                return 0
	            }

	            function $la() {
	                return 0
	            }

	            function ama() {
	                return 0
	            }

	            function bma() {
	                return 0
	            }

	            function cma() {
	                return 0
	            }

	            function dma() {
	                return 0
	            }

	            function ema() {
	                return 0
	            }

	            function fma() {
	                return 0
	            }

	            function gma() {
	                return 0
	            }

	            function hma() {
	                return 0
	            }

	            function ima() {
	                return 0
	            }

	            function jma() {
	                return WP(0, 0) | 0
	            }

	            function kma() {
	                return 0
	            }

	            function lma() {
	                return 0
	            }

	            function mma() {
	                return LP(0) | 0
	            }

	            function nma() {
	                return MP(0) | 0
	            }

	            function oma() {
	                return NP(0) | 0
	            }

	            function pma() {
	                return OP(0) | 0
	            }

	            function qma() {
	                return 0
	            }

	            function rma() {
	                return NI(0) | 0
	            }

	            function sma() {
	                return OI(0) | 0
	            }

	            function tma() {
	                return PI(0) | 0
	            }

	            function uma() {
	                return QI(0) | 0
	            }

	            function vma() {
	                return RI(0) | 0
	            }

	            function wma() {
	                return SI(0) | 0
	            }

	            function xma() {
	                return TI(0) | 0
	            }

	            function yma() {
	                return UI(0) | 0
	            }

	            function zma() {
	                return VI(0) | 0
	            }

	            function Ama() {
	                return WI(0) | 0
	            }

	            function Bma() {
	                return XI(0) | 0
	            }

	            function Cma() {
	                return YI(0) | 0
	            }

	            function Dma() {
	                return ZI(0) | 0
	            }

	            function Ema() {
	                return _I(0) | 0
	            }

	            function Fma() {
	                return $I(0) | 0
	            }

	            function Gma() {
	                return aJ(0) | 0
	            }

	            function Hma() {
	                return bJ(0) | 0
	            }

	            function Ima() {
	                return cJ(0) | 0
	            }

	            function Jma() {
	                return dJ(0) | 0
	            }

	            function Kma() {
	                return eJ(0) | 0
	            }

	            function Lma() {
	                return fJ(0) | 0
	            }

	            function Mma() {
	                return gJ(0) | 0
	            }

	            function Nma() {
	                return hJ(0) | 0
	            }

	            function Oma() {
	                return iJ(0) | 0
	            }

	            function Pma() {
	                return jJ(0) | 0
	            }

	            function Qma() {
	                return kJ(0) | 0
	            }

	            function Rma() {
	                return lJ(0) | 0
	            }

	            function Sma() {
	                return mJ(0) | 0
	            }

	            function Tma() {
	                return nJ(0) | 0
	            }

	            function Uma() {
	                return oJ(0) | 0
	            }

	            function Vma() {
	                return pJ(0) | 0
	            }

	            function Wma() {
	                return qJ(0) | 0
	            }

	            function Xma() {
	                return rJ(0) | 0
	            }

	            function Yma() {
	                return sJ(0) | 0
	            }

	            function Zma() {
	                return tJ(0) | 0
	            }

	            function _ma() {
	                return uJ(0) | 0
	            }

	            function $ma() {
	                return vJ(0) | 0
	            }

	            function ana() {
	                return wJ(0) | 0
	            }

	            function bna() {
	                return xJ(0) | 0
	            }

	            function cna() {
	                return yJ(0) | 0
	            }

	            function dna() {
	                return zJ(0) | 0
	            }

	            function ena() {
	                return AJ(0) | 0
	            }

	            function fna() {
	                return BJ(0) | 0
	            }

	            function gna() {
	                return CJ(0) | 0
	            }

	            function hna() {
	                return DJ(0) | 0
	            }

	            function ina() {
	                return EJ(0) | 0
	            }

	            function jna() {
	                return FJ(0) | 0
	            }

	            function kna() {
	                return GJ(0) | 0
	            }

	            function lna() {
	                return HJ(0) | 0
	            }

	            function mna() {
	                return IJ(0) | 0
	            }

	            function nna() {
	                return JJ(0) | 0
	            }

	            function ona() {
	                return KJ(0) | 0
	            }

	            function pna() {
	                return LJ(0) | 0
	            }

	            function qna() {
	                return MJ(0) | 0
	            }

	            function rna() {
	                return NJ(0) | 0
	            }

	            function sna() {
	                return OJ(0) | 0
	            }

	            function tna() {
	                return PJ(0) | 0
	            }

	            function una() {
	                return QJ(0) | 0
	            }

	            function vna() {
	                return RJ(0) | 0
	            }

	            function wna() {
	                return SJ(0) | 0
	            }

	            function xna() {
	                return TJ(0) | 0
	            }

	            function yna() {
	                return UJ(0) | 0
	            }

	            function zna() {
	                return VJ(0) | 0
	            }

	            function Ana() {
	                return WJ(0) | 0
	            }

	            function Bna() {
	                return XJ(0) | 0
	            }

	            function Cna() {
	                return YJ(0) | 0
	            }

	            function Dna() {
	                return ZJ(0) | 0
	            }

	            function Ena() {
	                return _J(0) | 0
	            }

	            function Fna() {
	                return $J(0) | 0
	            }

	            function Gna() {
	                return aK(0) | 0
	            }

	            function Hna() {
	                return bK(0) | 0
	            }

	            function Ina() {
	                return cK(0) | 0
	            }

	            function Jna() {
	                return dK(0) | 0
	            }

	            function Kna() {
	                return eK(0) | 0
	            }

	            function Lna() {
	                return fK(0) | 0
	            }

	            function Mna() {
	                return gK(0) | 0
	            }

	            function Nna() {
	                return hK(0) | 0
	            }

	            function Ona() {
	                return iK(0) | 0
	            }

	            function Pna() {
	                return jK(0) | 0
	            }

	            function Qna() {
	                return kK(0) | 0
	            }

	            function Rna() {
	                return lK(0) | 0
	            }

	            function Sna() {
	                return mK(0) | 0
	            }

	            function Tna() {
	                return nK(0) | 0
	            }

	            function Una() {
	                return oK(0) | 0
	            }

	            function Vna() {
	                return pK(0) | 0
	            }

	            function Wna() {
	                return qK(0) | 0
	            }

	            function Xna() {
	                return rK(0) | 0
	            }

	            function Yna() {
	                return sK(0) | 0
	            }

	            function Zna() {
	                return tK(0) | 0
	            }

	            function _na() {
	                return uK(0) | 0
	            }

	            function $na() {
	                return vK(0) | 0
	            }

	            function aoa() {
	                return wK(0) | 0
	            }

	            function boa() {
	                return xK(0) | 0
	            }

	            function coa() {
	                return yK(0) | 0
	            }

	            function doa() {
	                return zK(0) | 0
	            }

	            function eoa() {
	                return AK(0) | 0
	            }

	            function foa() {
	                return BK(0) | 0
	            }

	            function goa() {
	                return CK(0) | 0
	            }

	            function hoa() {
	                return DK(0) | 0
	            }

	            function ioa() {
	                return EK(0) | 0
	            }

	            function joa() {
	                return FK(0) | 0
	            }

	            function koa() {
	                return GK(0) | 0
	            }

	            function loa() {
	                return HK(0) | 0
	            }

	            function moa() {
	                return IK(0) | 0
	            }

	            function noa() {
	                return JK(0) | 0
	            }

	            function ooa() {
	                return KK(0) | 0
	            }

	            function poa() {
	                return LK(0) | 0
	            }

	            function qoa() {
	                return MK(0) | 0
	            }

	            function roa() {
	                return NK(0) | 0
	            }

	            function soa() {
	                return OK(0) | 0
	            }

	            function toa() {
	                return PK(0) | 0
	            }

	            function uoa() {
	                return QK(0) | 0
	            }

	            function voa() {
	                return RK(0) | 0
	            }

	            function woa() {
	                return SK(0) | 0
	            }

	            function xoa() {
	                return TK(0) | 0
	            }

	            function yoa() {
	                return UK(0) | 0
	            }

	            function zoa() {
	                return VK(0) | 0
	            }

	            function Aoa() {
	                return WK(0) | 0
	            }

	            function Boa() {
	                return XK(0) | 0
	            }

	            function Coa() {
	                return YK(0) | 0
	            }

	            function Doa() {
	                return ZK(0) | 0
	            }

	            function Eoa() {
	                return _K(0) | 0
	            }

	            function Foa() {
	                return $K(0) | 0
	            }

	            function Goa() {
	                return aL(0) | 0
	            }

	            function Hoa() {
	                return bL(0) | 0
	            }

	            function Ioa() {
	                return cL(0) | 0
	            }

	            function Joa() {
	                return dL(0) | 0
	            }

	            function Koa() {
	                return eL(0) | 0
	            }

	            function Loa() {
	                return RT(0, 0, 0) | 0
	            }

	            function Moa() {
	                return 0
	            }

	            function Noa() {
	                return Wb(0) | 0
	            }

	            function Ooa() {
	                return Xb(0, 0) | 0
	            }

	            function Poa() {
	                return Yb(0) | 0
	            }

	            function Qoa() {
	                return Wk(0, 0, 0) | 0
	            }

	            function Roa() {
	                return 0
	            }

	            function Soa() {
	                return 0
	            }

	            function Toa() {
	                return ac(0, 0, 0) | 0
	            }

	            function Uoa() {
	                return Ka(0, 0, 0) | 0
	            }

	            function Voa() {
	                return gc(0, 0, 0) | 0
	            }

	            function Woa() {
	                return 0
	            }

	            function Xoa() {
	                return 0
	            }

	            function Yoa() {
	                return 0
	            }

	            function Zoa() {
	                return 0
	            }

	            function _oa() {
	                return 0
	            }

	            function $oa() {
	                return nc(0) | 0
	            }

	            function apa() {
	                return 0
	            }

	            function bpa() {
	                return nd(0) | 0
	            }

	            function cpa() {
	                return Kd(0, 0, 0, 0) | 0
	            }

	            function dpa() {
	                return Ld(0, 0, 0, 0) | 0
	            }

	            function epa() {
	                return Md(0, 0, 0, 0) | 0
	            }

	            function fpa() {
	                return Nd(0, 0, 0, 0) | 0
	            }

	            function gpa() {
	                return Od(0, 0, 0, 0) | 0
	            }

	            function hpa() {
	                return Pd(0, 0, 0, 0) | 0
	            }

	            function ipa() {
	                return qd(0, 0, 0, 0) | 0
	            }

	            function jpa() {
	                return rd(0, 0, 0, 0) | 0
	            }

	            function kpa() {
	                return Qd(0, 0, 0, 0) | 0
	            }

	            function lpa() {
	                return Rd(0, 0, 0, 0) | 0
	            }

	            function mpa() {
	                return fo(0, 0, 0, 0) | 0
	            }

	            function npa() {
	                return 0
	            }

	            function opa() {
	                return 0
	            }

	            function ppa() {
	                return 0
	            }

	            function qpa() {
	                return 0
	            }

	            function rpa() {
	                return 0
	            }

	            function spa() {
	                return nk(0) | 0
	            }

	            function tpa() {
	                return ok(0) | 0
	            }

	            function upa() {
	                return pk(0, 0, 0) | 0
	            }

	            function vpa() {
	                return qk(0) | 0
	            }

	            function wpa() {
	                return _k(0) | 0
	            }

	            function xpa() {
	                return $k(0, 0, 0) | 0
	            }

	            function ypa() {
	                return bl(0) | 0
	            }

	            function zpa() {
	                return cl(0, 0, 0) | 0
	            }

	            function Apa() {
	                return dl(0) | 0
	            }

	            function Bpa() {
	                return el(0, 0, 0) | 0
	            }

	            function Cpa() {
	                return fl(0, 0, 0) | 0
	            }

	            function Dpa() {
	                return gl(0, 0, 0, 0) | 0
	            }

	            function Epa() {
	                return 0
	            }

	            function Fpa() {
	                return on(0) | 0
	            }

	            function Gpa() {
	                return 0
	            }

	            function Hpa() {
	                return vn(0) | 0
	            }

	            function Ipa() {
	                return 0
	            }

	            function Jpa() {
	                return yn(0) | 0
	            }

	            function Kpa() {
	                return 0
	            }

	            function Lpa() {
	                return 0
	            }

	            function Mpa() {
	                return 0
	            }

	            function Npa() {
	                return Cn(0, 0) | 0
	            }

	            function Opa() {
	                return 0
	            }

	            function Ppa() {
	                return 0
	            }

	            function Qpa() {
	                return 0
	            }

	            function Rpa() {
	                return 0
	            }

	            function Spa() {
	                return 0
	            }

	            function Tpa() {
	                return 0
	            }

	            function Upa() {
	                return _n(0, 0) | 0
	            }

	            function Vpa() {
	                return 0
	            }

	            function Wpa() {
	                return 0
	            }

	            function Xpa() {
	                return 0
	            }

	            function Ypa() {
	                return 0
	            }

	            function Zpa() {
	                return 0
	            }

	            function _pa() {
	                return 0
	            }

	            function $pa() {
	                return 0
	            }

	            function aqa() {
	                return 0
	            }

	            function bqa() {
	                return 0
	            }

	            function cqa() {
	                return 0
	            }

	            function dqa() {
	                return 0
	            }

	            function eqa() {
	                return 0
	            }

	            function fqa() {
	                return 0
	            }

	            function gqa() {
	                return 0
	            }

	            function hqa() {
	                return 0
	            }

	            function iqa() {
	                return 0
	            }

	            function jqa() {
	                return 0
	            }

	            function kqa() {
	                return 0
	            }

	            function lqa() {
	                return 0
	            }

	            function mqa() {
	                return 0
	            }

	            function nqa() {
	                return 0
	            }

	            function oqa() {
	                return 0
	            }

	            function pqa() {
	                return 0
	            }

	            function qqa() {
	                return 0
	            }

	            function rqa() {
	                return 0
	            }

	            function sqa() {
	                return 0
	            }

	            function tqa() {
	                return 0
	            }

	            function uqa() {
	                return 0
	            }

	            function vqa() {
	                return 0
	            }

	            function wqa() {
	                return 0
	            }

	            function xqa() {
	                return uu(0, 0, 0) | 0
	            }

	            function yqa() {
	                return ds(0, 0) | 0
	            }

	            function zqa() {
	                return es(0, 0) | 0
	            }

	            function Aqa() {
	                return js(0, 0) | 0
	            }

	            function Bqa() {
	                return vu(0, 0, 0) | 0
	            }

	            function Cqa() {
	                return wu(0, 0) | 0
	            }

	            function Dqa() {
	                return $r(0, 0) | 0
	            }

	            function Eqa() {
	                return as(0, 0) | 0
	            }

	            function Fqa() {
	                return bs(0, 0) | 0
	            }

	            function Gqa() {
	                return hs(0, 0) | 0
	            }

	            function Hqa() {
	                return fs(0, 0) | 0
	            }

	            function Iqa() {
	                return is(0, 0) | 0
	            }

	            function Jqa() {
	                return cs(0, 0) | 0
	            }

	            function Kqa() {
	                return xu(0, 0) | 0
	            }

	            function Lqa() {
	                return gs(0, 0) | 0
	            }

	            function Mqa() {
	                return _r(0, 0) | 0
	            }

	            function Nqa() {
	                return dr(0, 0) | 0
	            }

	            function Oqa() {
	                return 0
	            }

	            function Pqa() {
	                return 0
	            }

	            function Qqa() {
	                return 0
	            }

	            function Rqa() {
	                return 0
	            }

	            function Sqa() {
	                return 0
	            }

	            function Tqa() {
	                return 0
	            }

	            function Uqa() {
	                return 0
	            }

	            function Vqa() {
	                return 0
	            }

	            function Wqa() {
	                return 0
	            }

	            function Xqa() {
	                return 0
	            }

	            function Yqa() {
	                return 0
	            }

	            function Zqa() {
	                return Kx(0, 0, 0) | 0
	            }

	            function _qa() {
	                return $x(0, 0) | 0
	            }

	            function $qa() {
	                return dy(0, 0) | 0
	            }

	            function ara() {
	                return fy(0, 0) | 0
	            }

	            function bra() {
	                return jy(0, 0) | 0
	            }

	            function cra() {
	                return 0
	            }

	            function dra() {
	                return 0
	            }

	            function era() {
	                return 0
	            }

	            function fra() {
	                return 0
	            }

	            function gra() {
	                return 0
	            }

	            function hra() {
	                return 0
	            }

	            function ira() {
	                return 0
	            }

	            function jra() {
	                return RB(0) | 0
	            }

	            function kra() {
	                return SB(0) | 0
	            }

	            function lra() {
	                return TB(0) | 0
	            }

	            function mra() {
	                return UB(0, 0, 0) | 0
	            }

	            function nra() {
	                return VB(0, 0) | 0
	            }

	            function ora() {
	                return 0
	            }

	            function pra() {
	                return 0
	            }

	            function qra() {
	                return 0
	            }

	            function rra() {
	                return 0
	            }

	            function sra() {
	                return 0
	            }

	            function tra() {
	                return 0
	            }

	            function ura() {
	                return 0
	            }

	            function vra() {
	                return 0
	            }

	            function wra() {
	                return 0
	            }

	            function xra() {
	                return 0
	            }

	            function yra() {
	                return 0
	            }

	            function zra() {
	                return 0
	            }

	            function Ara() {
	                return 0
	            }

	            function Bra() {
	                return hC(0, 0) | 0
	            }

	            function Cra() {
	                return 0
	            }

	            function Dra() {
	                return 0
	            }

	            function Era() {
	                return 0
	            }

	            function Fra() {
	                return 0
	            }

	            function Gra() {
	                return 0
	            }

	            function Hra() {
	                return 0
	            }

	            function Ira() {
	                return 0
	            }

	            function Jra() {
	                return rC(0, 0, 0) | 0
	            }

	            function Kra() {
	                return 0
	            }

	            function Lra() {
	                return 0
	            }

	            function Mra() {
	                return 0
	            }

	            function Nra() {
	                return 0
	            }

	            function Ora() {
	                return 0
	            }

	            function Pra() {
	                return 0
	            }

	            function Qra() {
	                return 0
	            }

	            function Rra() {
	                return 0
	            }

	            function Sra() {
	                return 0
	            }

	            function Tra() {
	                return 0
	            }

	            function Ura() {
	                return 0
	            }

	            function Vra() {
	                return 0
	            }

	            function Wra() {
	                return 0
	            }

	            function Xra() {
	                return GM(0, 0, 0) | 0
	            }

	            function Yra() {
	                return 0
	            }

	            function Zra() {
	                return 0
	            }

	            function _ra() {
	                return nN(0, 0) | 0
	            }

	            function $ra() {
	                return oN(0, 0, 0, 0, 0) | 0
	            }

	            function asa() {
	                return pN(0, 0, 0, 0, 0, 0, 0) | 0
	            }

	            function bsa() {
	                return qN(0, 0, 0, 0, 0, 0) | 0
	            }

	            function csa() {
	                return 0
	            }

	            function dsa() {
	                return tN(0, 0) | 0
	            }

	            function esa() {
	                return uN(0, 0, 0, 0, 0) | 0
	            }

	            function fsa() {
	                return vN(0, 0, 0, 0, 0, 0, 0) | 0
	            }

	            function gsa() {
	                return 0
	            }

	            function hsa() {
	                return 0
	            }

	            function isa() {
	                return 0
	            }

	            function jsa() {
	                return 0
	            }

	            function ksa() {
	                return 0
	            }

	            function lsa() {
	                return 0
	            }

	            function msa() {
	                return 0
	            }

	            function nsa() {
	                return 0
	            }

	            function osa() {
	                return 0
	            }

	            function psa() {
	                return WR(0, 0, 0, 0) | 0
	            }

	            function qsa() {
	                return QS(0, 0) | 0
	            }

	            function rsa() {
	                return hT(0, 0, 0) | 0
	            }

	            function ssa(a) {
	                a = a | 0;
	                da(5)
	            }

	            function tsa(a) {
	                a = a | 0;
	                uc(a | 0, 0, 0, 0)
	            }

	            function usa(a) {
	                a = a | 0;
	                vc(a | 0) | 0
	            }

	            function vsa(a) {
	                a = a | 0;
	                wc(a | 0) | 0
	            }

	            function wsa(a) {
	                a = a | 0;
	                xc(a | 0) | 0
	            }

	            function xsa(a) {
	                a = a | 0;
	                yc(a | 0, 0, 0) | 0
	            }

	            function ysa(a) {
	                a = a | 0;
	                zc(a | 0, 0) | 0
	            }

	            function zsa(a) {
	                a = a | 0;
	                Ac(a | 0, 0, 0, 0, 0, 0)
	            }

	            function Asa(a) {
	                a = a | 0;
	                Bc(a | 0, 0, 0, 0)
	            }

	            function Bsa(a) {
	                a = a | 0;
	                Cc(a | 0, 0, 0, 0, 0, 0, 0)
	            }

	            function Csa(a) {
	                a = a | 0;
	                Dc(a | 0, 0, 0, 0)
	            }

	            function Dsa(a) {
	                a = a | 0;
	                Ec(a | 0, 0, 0, 0, 0)
	            }

	            function Esa(a) {
	                a = a | 0;
	                Fc(a | 0, 0)
	            }

	            function Fsa(a) {
	                a = a | 0;
	                Wc(a | 0, 0, 0)
	            }

	            function Gsa(a) {
	                a = a | 0;
	                Xc(a | 0, 0)
	            }

	            function Hsa(a) {
	                a = a | 0;
	                Ic(a | 0, 0)
	            }

	            function Isa(a) {
	                a = a | 0;
	                Jc(a | 0, 0, 0)
	            }

	            function Jsa(a) {
	                a = a | 0;
	                Kc(a | 0, 0, 0)
	            }

	            function Ksa(a) {
	                a = a | 0;
	                Lc(a | 0, 0, 0)
	            }

	            function Lsa(a) {
	                a = a | 0;
	                Mc(a | 0, 0)
	            }

	            function Msa(a) {
	                a = a | 0;
	                Nc(a | 0, 0, 0)
	            }

	            function Nsa(a) {
	                a = a | 0;
	                Oc(a | 0, 0, 0)
	            }

	            function Osa(a) {
	                a = a | 0;
	                Pc(a | 0, 0, 0)
	            }

	            function Psa(a) {
	                a = a | 0;
	                Qc(a | 0, 0) | 0
	            }

	            function Qsa(a) {
	                a = a | 0;
	                Rc(a | 0, 0, 0)
	            }

	            function Rsa(a) {
	                a = a | 0;
	                Sc(a | 0, 0, 0, 0)
	            }

	            function Ssa(a) {
	                a = a | 0;
	                Tc(a | 0, 0, 0, 0, 0, 0, 0, 0, 0)
	            }

	            function Tsa(a) {
	                a = a | 0;
	                Uc(a | 0, 0, 0, 0)
	            }

	            function Usa(a) {
	                a = a | 0;
	                Xk(a | 0, 0, 0) | 0
	            }

	            function Vsa(a) {
	                a = a | 0;
	                iT(a | 0) | 0
	            }

	            function Wsa(a) {
	                a = a | 0;
	                kT(a | 0, 0) | 0
	            }

	            function Xsa(a) {
	                a = a | 0;
	                my(a | 0) | 0
	            }

	            function Ysa(a) {
	                a = a | 0;
	                Td(a | 0, 0, 0)
	            }

	            function Zsa(a) {
	                a = a | 0;
	                SP(a | 0, 0, 0, 0)
	            }

	            function _sa(a) {
	                a = a | 0;
	                PP(a | 0) | 0
	            }

	            function $sa(a) {
	                a = a | 0;
	                QP(a | 0) | 0
	            }

	            function ata(a) {
	                a = a | 0;
	                RP(a | 0) | 0
	            }

	            function bta(a) {
	                a = a | 0;
	                UP(a | 0, 0, 0) | 0
	            }

	            function cta(a) {
	                a = a | 0;
	                VP(a | 0, 0) | 0
	            }

	            function dta(a) {
	                a = a | 0;
	                XP(a | 0, 0, 0, 0, 0, 0)
	            }

	            function eta(a) {
	                a = a | 0;
	                _P(a | 0, 0, 0, 0)
	            }

	            function fta(a) {
	                a = a | 0;
	                YP(a | 0, 0, 0, 0, 0, 0, 0)
	            }

	            function gta(a) {
	                a = a | 0;
	                ZP(a | 0, 0, 0, 0)
	            }

	            function hta(a) {
	                a = a | 0;
	                $P(a | 0, 0, 0, 0, 0)
	            }

	            function ita(a) {
	                a = a | 0;
	                aQ(a | 0, 0)
	            }

	            function jta(a) {
	                a = a | 0;
	                dQ(a | 0, 0, 0)
	            }

	            function kta(a) {
	                a = a | 0;
	                eQ(a | 0, 0)
	            }

	            function lta(a) {
	                a = a | 0;
	                hQ(a | 0, 0)
	            }

	            function mta(a) {
	                a = a | 0;
	                iQ(a | 0, 0, 0)
	            }

	            function nta(a) {
	                a = a | 0;
	                kQ(a | 0, 0, 0)
	            }

	            function ota(a) {
	                a = a | 0;
	                lQ(a | 0, 0)
	            }

	            function pta(a) {
	                a = a | 0;
	                $d(a | 0, 0, 0)
	            }

	            function qta(a) {
	                a = a | 0;
	                _d(a | 0, 0, 0)
	            }

	            function rta(a) {
	                a = a | 0;
	                WP(a | 0, 0) | 0
	            }

	            function sta(a) {
	                a = a | 0;
	                mQ(a | 0, 0, 0)
	            }

	            function tta(a) {
	                a = a | 0;
	                TP(a | 0, 0, 0, 0)
	            }

	            function uta(a) {
	                a = a | 0;
	                LP(a | 0) | 0
	            }

	            function vta(a) {
	                a = a | 0;
	                MP(a | 0) | 0
	            }

	            function wta(a) {
	                a = a | 0;
	                NP(a | 0) | 0
	            }

	            function xta(a) {
	                a = a | 0;
	                OP(a | 0) | 0
	            }

	            function yta(a) {
	                a = a | 0;
	                jQ(a | 0, 0, 0)
	            }

	            function zta(a) {
	                a = a | 0;
	                NI(a | 0) | 0
	            }

	            function Ata(a) {
	                a = a | 0;
	                OI(a | 0) | 0
	            }

	            function Bta(a) {
	                a = a | 0;
	                PI(a | 0) | 0
	            }

	            function Cta(a) {
	                a = a | 0;
	                QI(a | 0) | 0
	            }

	            function Dta(a) {
	                a = a | 0;
	                RI(a | 0) | 0
	            }

	            function Eta(a) {
	                a = a | 0;
	                SI(a | 0) | 0
	            }

	            function Fta(a) {
	                a = a | 0;
	                TI(a | 0) | 0
	            }

	            function Gta(a) {
	                a = a | 0;
	                UI(a | 0) | 0
	            }

	            function Hta(a) {
	                a = a | 0;
	                VI(a | 0) | 0
	            }

	            function Ita(a) {
	                a = a | 0;
	                WI(a | 0) | 0
	            }

	            function Jta(a) {
	                a = a | 0;
	                XI(a | 0) | 0
	            }

	            function Kta(a) {
	                a = a | 0;
	                YI(a | 0) | 0
	            }

	            function Lta(a) {
	                a = a | 0;
	                ZI(a | 0) | 0
	            }

	            function Mta(a) {
	                a = a | 0;
	                _I(a | 0) | 0
	            }

	            function Nta(a) {
	                a = a | 0;
	                $I(a | 0) | 0
	            }

	            function Ota(a) {
	                a = a | 0;
	                aJ(a | 0) | 0
	            }

	            function Pta(a) {
	                a = a | 0;
	                bJ(a | 0) | 0
	            }

	            function Qta(a) {
	                a = a | 0;
	                cJ(a | 0) | 0
	            }

	            function Rta(a) {
	                a = a | 0;
	                dJ(a | 0) | 0
	            }

	            function Sta(a) {
	                a = a | 0;
	                eJ(a | 0) | 0
	            }

	            function Tta(a) {
	                a = a | 0;
	                fJ(a | 0) | 0
	            }

	            function Uta(a) {
	                a = a | 0;
	                gJ(a | 0) | 0
	            }

	            function Vta(a) {
	                a = a | 0;
	                hJ(a | 0) | 0
	            }

	            function Wta(a) {
	                a = a | 0;
	                iJ(a | 0) | 0
	            }

	            function Xta(a) {
	                a = a | 0;
	                jJ(a | 0) | 0
	            }

	            function Yta(a) {
	                a = a | 0;
	                kJ(a | 0) | 0
	            }

	            function Zta(a) {
	                a = a | 0;
	                lJ(a | 0) | 0
	            }

	            function _ta(a) {
	                a = a | 0;
	                mJ(a | 0) | 0
	            }

	            function $ta(a) {
	                a = a | 0;
	                nJ(a | 0) | 0
	            }

	            function aua(a) {
	                a = a | 0;
	                oJ(a | 0) | 0
	            }

	            function bua(a) {
	                a = a | 0;
	                pJ(a | 0) | 0
	            }

	            function cua(a) {
	                a = a | 0;
	                qJ(a | 0) | 0
	            }

	            function dua(a) {
	                a = a | 0;
	                rJ(a | 0) | 0
	            }

	            function eua(a) {
	                a = a | 0;
	                sJ(a | 0) | 0
	            }

	            function fua(a) {
	                a = a | 0;
	                tJ(a | 0) | 0
	            }

	            function gua(a) {
	                a = a | 0;
	                uJ(a | 0) | 0
	            }

	            function hua(a) {
	                a = a | 0;
	                vJ(a | 0) | 0
	            }

	            function iua(a) {
	                a = a | 0;
	                wJ(a | 0) | 0
	            }

	            function jua(a) {
	                a = a | 0;
	                xJ(a | 0) | 0
	            }

	            function kua(a) {
	                a = a | 0;
	                yJ(a | 0) | 0
	            }

	            function lua(a) {
	                a = a | 0;
	                zJ(a | 0) | 0
	            }

	            function mua(a) {
	                a = a | 0;
	                AJ(a | 0) | 0
	            }

	            function nua(a) {
	                a = a | 0;
	                BJ(a | 0) | 0
	            }

	            function oua(a) {
	                a = a | 0;
	                CJ(a | 0) | 0
	            }

	            function pua(a) {
	                a = a | 0;
	                DJ(a | 0) | 0
	            }

	            function qua(a) {
	                a = a | 0;
	                EJ(a | 0) | 0
	            }

	            function rua(a) {
	                a = a | 0;
	                FJ(a | 0) | 0
	            }

	            function sua(a) {
	                a = a | 0;
	                GJ(a | 0) | 0
	            }

	            function tua(a) {
	                a = a | 0;
	                HJ(a | 0) | 0
	            }

	            function uua(a) {
	                a = a | 0;
	                IJ(a | 0) | 0
	            }

	            function vua(a) {
	                a = a | 0;
	                JJ(a | 0) | 0
	            }

	            function wua(a) {
	                a = a | 0;
	                KJ(a | 0) | 0
	            }

	            function xua(a) {
	                a = a | 0;
	                LJ(a | 0) | 0
	            }

	            function yua(a) {
	                a = a | 0;
	                MJ(a | 0) | 0
	            }

	            function zua(a) {
	                a = a | 0;
	                NJ(a | 0) | 0
	            }

	            function Aua(a) {
	                a = a | 0;
	                OJ(a | 0) | 0
	            }

	            function Bua(a) {
	                a = a | 0;
	                PJ(a | 0) | 0
	            }

	            function Cua(a) {
	                a = a | 0;
	                QJ(a | 0) | 0
	            }

	            function Dua(a) {
	                a = a | 0;
	                RJ(a | 0) | 0
	            }

	            function Eua(a) {
	                a = a | 0;
	                SJ(a | 0) | 0
	            }

	            function Fua(a) {
	                a = a | 0;
	                TJ(a | 0) | 0
	            }

	            function Gua(a) {
	                a = a | 0;
	                UJ(a | 0) | 0
	            }

	            function Hua(a) {
	                a = a | 0;
	                VJ(a | 0) | 0
	            }

	            function Iua(a) {
	                a = a | 0;
	                WJ(a | 0) | 0
	            }

	            function Jua(a) {
	                a = a | 0;
	                XJ(a | 0) | 0
	            }

	            function Kua(a) {
	                a = a | 0;
	                YJ(a | 0) | 0
	            }

	            function Lua(a) {
	                a = a | 0;
	                ZJ(a | 0) | 0
	            }

	            function Mua(a) {
	                a = a | 0;
	                _J(a | 0) | 0
	            }

	            function Nua(a) {
	                a = a | 0;
	                $J(a | 0) | 0
	            }

	            function Oua(a) {
	                a = a | 0;
	                aK(a | 0) | 0
	            }

	            function Pua(a) {
	                a = a | 0;
	                bK(a | 0) | 0
	            }

	            function Qua(a) {
	                a = a | 0;
	                cK(a | 0) | 0
	            }

	            function Rua(a) {
	                a = a | 0;
	                dK(a | 0) | 0
	            }

	            function Sua(a) {
	                a = a | 0;
	                eK(a | 0) | 0
	            }

	            function Tua(a) {
	                a = a | 0;
	                fK(a | 0) | 0
	            }

	            function Uua(a) {
	                a = a | 0;
	                gK(a | 0) | 0
	            }

	            function Vua(a) {
	                a = a | 0;
	                hK(a | 0) | 0
	            }

	            function Wua(a) {
	                a = a | 0;
	                iK(a | 0) | 0
	            }

	            function Xua(a) {
	                a = a | 0;
	                jK(a | 0) | 0
	            }

	            function Yua(a) {
	                a = a | 0;
	                kK(a | 0) | 0
	            }

	            function Zua(a) {
	                a = a | 0;
	                lK(a | 0) | 0
	            }

	            function _ua(a) {
	                a = a | 0;
	                mK(a | 0) | 0
	            }

	            function $ua(a) {
	                a = a | 0;
	                nK(a | 0) | 0
	            }

	            function ava(a) {
	                a = a | 0;
	                oK(a | 0) | 0
	            }

	            function bva(a) {
	                a = a | 0;
	                pK(a | 0) | 0
	            }

	            function cva(a) {
	                a = a | 0;
	                qK(a | 0) | 0
	            }

	            function dva(a) {
	                a = a | 0;
	                rK(a | 0) | 0
	            }

	            function eva(a) {
	                a = a | 0;
	                sK(a | 0) | 0
	            }

	            function fva(a) {
	                a = a | 0;
	                tK(a | 0) | 0
	            }

	            function gva(a) {
	                a = a | 0;
	                uK(a | 0) | 0
	            }

	            function hva(a) {
	                a = a | 0;
	                vK(a | 0) | 0
	            }

	            function iva(a) {
	                a = a | 0;
	                wK(a | 0) | 0
	            }

	            function jva(a) {
	                a = a | 0;
	                xK(a | 0) | 0
	            }

	            function kva(a) {
	                a = a | 0;
	                yK(a | 0) | 0
	            }

	            function lva(a) {
	                a = a | 0;
	                zK(a | 0) | 0
	            }

	            function mva(a) {
	                a = a | 0;
	                AK(a | 0) | 0
	            }

	            function nva(a) {
	                a = a | 0;
	                BK(a | 0) | 0
	            }

	            function ova(a) {
	                a = a | 0;
	                CK(a | 0) | 0
	            }

	            function pva(a) {
	                a = a | 0;
	                DK(a | 0) | 0
	            }

	            function qva(a) {
	                a = a | 0;
	                EK(a | 0) | 0
	            }

	            function rva(a) {
	                a = a | 0;
	                FK(a | 0) | 0
	            }

	            function sva(a) {
	                a = a | 0;
	                GK(a | 0) | 0
	            }

	            function tva(a) {
	                a = a | 0;
	                HK(a | 0) | 0
	            }

	            function uva(a) {
	                a = a | 0;
	                IK(a | 0) | 0
	            }

	            function vva(a) {
	                a = a | 0;
	                JK(a | 0) | 0
	            }

	            function wva(a) {
	                a = a | 0;
	                KK(a | 0) | 0
	            }

	            function xva(a) {
	                a = a | 0;
	                LK(a | 0) | 0
	            }

	            function yva(a) {
	                a = a | 0;
	                MK(a | 0) | 0
	            }

	            function zva(a) {
	                a = a | 0;
	                NK(a | 0) | 0
	            }

	            function Ava(a) {
	                a = a | 0;
	                OK(a | 0) | 0
	            }

	            function Bva(a) {
	                a = a | 0;
	                PK(a | 0) | 0
	            }

	            function Cva(a) {
	                a = a | 0;
	                QK(a | 0) | 0
	            }

	            function Dva(a) {
	                a = a | 0;
	                RK(a | 0) | 0
	            }

	            function Eva(a) {
	                a = a | 0;
	                SK(a | 0) | 0
	            }

	            function Fva(a) {
	                a = a | 0;
	                TK(a | 0) | 0
	            }

	            function Gva(a) {
	                a = a | 0;
	                UK(a | 0) | 0
	            }

	            function Hva(a) {
	                a = a | 0;
	                VK(a | 0) | 0
	            }

	            function Iva(a) {
	                a = a | 0;
	                WK(a | 0) | 0
	            }

	            function Jva(a) {
	                a = a | 0;
	                XK(a | 0) | 0
	            }

	            function Kva(a) {
	                a = a | 0;
	                YK(a | 0) | 0
	            }

	            function Lva(a) {
	                a = a | 0;
	                ZK(a | 0) | 0
	            }

	            function Mva(a) {
	                a = a | 0;
	                _K(a | 0) | 0
	            }

	            function Nva(a) {
	                a = a | 0;
	                $K(a | 0) | 0
	            }

	            function Ova(a) {
	                a = a | 0;
	                aL(a | 0) | 0
	            }

	            function Pva(a) {
	                a = a | 0;
	                bL(a | 0) | 0
	            }

	            function Qva(a) {
	                a = a | 0;
	                cL(a | 0) | 0
	            }

	            function Rva(a) {
	                a = a | 0;
	                dL(a | 0) | 0
	            }

	            function Sva(a) {
	                a = a | 0;
	                eL(a | 0) | 0
	            }

	            function Tva(a) {
	                a = a | 0;
	                RT(a | 0, 0, 0) | 0
	            }

	            function Uva(a) {
	                a = a | 0;
	                Wb(a | 0) | 0
	            }

	            function Vva(a) {
	                a = a | 0;
	                Xb(a | 0, 0) | 0
	            }

	            function Wva(a) {
	                a = a | 0;
	                Yb(a | 0) | 0
	            }

	            function Xva(a) {
	                a = a | 0;
	                Wk(a | 0, 0, 0) | 0
	            }

	            function Yva(a) {
	                a = a | 0;
	                ac(a | 0, 0, 0) | 0
	            }

	            function Zva(a) {
	                a = a | 0;
	                Ka(a | 0, 0, 0) | 0
	            }

	            function _va(a) {
	                a = a | 0;
	                gc(a | 0, 0, 0) | 0
	            }

	            function $va(a) {
	                a = a | 0;
	                ic(a | 0, 0, 0)
	            }

	            function awa(a) {
	                a = a | 0;
	                jc(a | 0, 0, 0)
	            }

	            function bwa(a) {
	                a = a | 0;
	                kc(a | 0, 0, 0)
	            }

	            function cwa(a) {
	                a = a | 0;
	                lc(a | 0, 0, 0)
	            }

	            function dwa(a) {
	                a = a | 0;
	                nc(a | 0) | 0
	            }

	            function ewa(a) {
	                a = a | 0;
	                md(a | 0, 0)
	            }

	            function fwa(a) {
	                a = a | 0;
	                nd(a | 0) | 0
	            }

	            function gwa(a) {
	                a = a | 0;
	                Kd(a | 0, 0, 0, 0) | 0
	            }

	            function hwa(a) {
	                a = a | 0;
	                Ld(a | 0, 0, 0, 0) | 0
	            }

	            function iwa(a) {
	                a = a | 0;
	                Md(a | 0, 0, 0, 0) | 0
	            }

	            function jwa(a) {
	                a = a | 0;
	                Nd(a | 0, 0, 0, 0) | 0
	            }

	            function kwa(a) {
	                a = a | 0;
	                Od(a | 0, 0, 0, 0) | 0
	            }

	            function lwa(a) {
	                a = a | 0;
	                Pd(a | 0, 0, 0, 0) | 0
	            }

	            function mwa(a) {
	                a = a | 0;
	                qd(a | 0, 0, 0, 0) | 0
	            }

	            function nwa(a) {
	                a = a | 0;
	                rd(a | 0, 0, 0, 0) | 0
	            }

	            function owa(a) {
	                a = a | 0;
	                Qd(a | 0, 0, 0, 0) | 0
	            }

	            function pwa(a) {
	                a = a | 0;
	                Rd(a | 0, 0, 0, 0) | 0
	            }

	            function qwa(a) {
	                a = a | 0;
	                fo(a | 0, 0, 0, 0) | 0
	            }

	            function rwa(a) {
	                a = a | 0;
	                ae(a | 0, 0, 0)
	            }

	            function swa(a) {
	                a = a | 0;
	                be(a | 0, 0, 0)
	            }

	            function twa(a) {
	                a = a | 0;
	                mk() | 0
	            }

	            function uwa(a) {
	                a = a | 0;
	                sh(a | 0, 0, 0, 0, 0)
	            }

	            function vwa(a) {
	                a = a | 0;
	                gk(a | 0, 0, 0, 0, 0)
	            }

	            function wwa(a) {
	                a = a | 0;
	                nk(a | 0) | 0
	            }

	            function xwa(a) {
	                a = a | 0;
	                ok(a | 0) | 0
	            }

	            function ywa(a) {
	                a = a | 0;
	                pk(a | 0, 0, 0) | 0
	            }

	            function zwa(a) {
	                a = a | 0;
	                qk(a | 0) | 0
	            }

	            function Awa(a) {
	                a = a | 0;
	                _k(a | 0) | 0
	            }

	            function Bwa(a) {
	                a = a | 0;
	                $k(a | 0, 0, 0) | 0
	            }

	            function Cwa(a) {
	                a = a | 0;
	                bl(a | 0) | 0
	            }

	            function Dwa(a) {
	                a = a | 0;
	                cl(a | 0, 0, 0) | 0
	            }

	            function Ewa(a) {
	                a = a | 0;
	                dl(a | 0) | 0
	            }

	            function Fwa(a) {
	                a = a | 0;
	                el(a | 0, 0, 0) | 0
	            }

	            function Gwa(a) {
	                a = a | 0;
	                fl(a | 0, 0, 0) | 0
	            }

	            function Hwa(a) {
	                a = a | 0;
	                gl(a | 0, 0, 0, 0) | 0
	            }

	            function Iwa(a) {
	                a = a | 0;
	                on(a | 0) | 0
	            }

	            function Jwa(a) {
	                a = a | 0;
	                vn(a | 0) | 0
	            }

	            function Kwa(a) {
	                a = a | 0;
	                yn(a | 0) | 0
	            }

	            function Lwa(a) {
	                a = a | 0;
	                zn(a | 0, 0)
	            }

	            function Mwa(a) {
	                a = a | 0;
	                Cn(a | 0, 0) | 0
	            }

	            function Nwa(a) {
	                a = a | 0;
	                In(a | 0, 0, 0)
	            }

	            function Owa(a) {
	                a = a | 0;
	                Rn(a | 0, 0, 0)
	            }

	            function Pwa(a) {
	                a = a | 0;
	                Sn(a | 0, 0, 0)
	            }

	            function Qwa(a) {
	                a = a | 0;
	                Tn(a | 0, 0, 0)
	            }

	            function Rwa(a) {
	                a = a | 0;
	                Un(a | 0, 0, 0)
	            }

	            function Swa(a) {
	                a = a | 0;
	                _n(a | 0, 0) | 0
	            }

	            function Twa(a) {
	                a = a | 0;
	                tq(a | 0, 0)
	            }

	            function Uwa(a) {
	                a = a | 0;
	                Bs(a | 0, 0)
	            }

	            function Vwa(a) {
	                a = a | 0;
	                Is(a | 0, 0)
	            }

	            function Wwa(a) {
	                a = a | 0;
	                ns(a | 0, 0)
	            }

	            function Xwa(a) {
	                a = a | 0;
	                ts(a | 0, 0)
	            }

	            function Ywa(a) {
	                a = a | 0;
	                us(a | 0, 0)
	            }

	            function Zwa(a) {
	                a = a | 0;
	                os(a | 0, 0)
	            }

	            function _wa(a) {
	                a = a | 0;
	                Es(a | 0, 0)
	            }

	            function $wa(a) {
	                a = a | 0;
	                Hs(a | 0, 0)
	            }

	            function axa(a) {
	                a = a | 0;
	                ls(a | 0, 0)
	            }

	            function bxa(a) {
	                a = a | 0;
	                Fs(a | 0, 0)
	            }

	            function cxa(a) {
	                a = a | 0;
	                ps(a | 0, 0)
	            }

	            function dxa(a) {
	                a = a | 0;
	                Cs(a | 0, 0)
	            }

	            function exa(a) {
	                a = a | 0;
	                nt(a | 0, 0)
	            }

	            function fxa(a) {
	                a = a | 0;
	                qs(a | 0, 0)
	            }

	            function gxa(a) {
	                a = a | 0;
	                zs(a | 0, 0)
	            }

	            function hxa(a) {
	                a = a | 0;
	                Tr(a | 0, 0)
	            }

	            function ixa(a) {
	                a = a | 0;
	                ms(a | 0, 0)
	            }

	            function jxa(a) {
	                a = a | 0;
	                Js(a | 0, 0)
	            }

	            function kxa(a) {
	                a = a | 0;
	                rs(a | 0, 0)
	            }

	            function lxa(a) {
	                a = a | 0;
	                ss(a | 0, 0)
	            }

	            function mxa(a) {
	                a = a | 0;
	                vs(a | 0, 0)
	            }

	            function nxa(a) {
	                a = a | 0;
	                ws(a | 0, 0)
	            }

	            function oxa(a) {
	                a = a | 0;
	                xs(a | 0, 0)
	            }

	            function pxa(a) {
	                a = a | 0;
	                ys(a | 0, 0)
	            }

	            function qxa(a) {
	                a = a | 0;
	                Gs(a | 0, 0)
	            }

	            function rxa(a) {
	                a = a | 0;
	                Ds(a | 0, 0)
	            }

	            function sxa(a) {
	                a = a | 0;
	                As(a | 0, 0)
	            }

	            function txa(a) {
	                a = a | 0;
	                ot(a | 0, 0)
	            }

	            function uxa(a) {
	                a = a | 0;
	                uu(a | 0, 0, 0) | 0
	            }

	            function vxa(a) {
	                a = a | 0;
	                ds(a | 0, 0) | 0
	            }

	            function wxa(a) {
	                a = a | 0;
	                es(a | 0, 0) | 0
	            }

	            function xxa(a) {
	                a = a | 0;
	                js(a | 0, 0) | 0
	            }

	            function yxa(a) {
	                a = a | 0;
	                vu(a | 0, 0, 0) | 0
	            }

	            function zxa(a) {
	                a = a | 0;
	                wu(a | 0, 0) | 0
	            }

	            function Axa(a) {
	                a = a | 0;
	                $r(a | 0, 0) | 0
	            }

	            function Bxa(a) {
	                a = a | 0;
	                as(a | 0, 0) | 0
	            }

	            function Cxa(a) {
	                a = a | 0;
	                bs(a | 0, 0) | 0
	            }

	            function Dxa(a) {
	                a = a | 0;
	                hs(a | 0, 0) | 0
	            }

	            function Exa(a) {
	                a = a | 0;
	                fs(a | 0, 0) | 0
	            }

	            function Fxa(a) {
	                a = a | 0;
	                is(a | 0, 0) | 0
	            }

	            function Gxa(a) {
	                a = a | 0;
	                cs(a | 0, 0) | 0
	            }

	            function Hxa(a) {
	                a = a | 0;
	                xu(a | 0, 0) | 0
	            }

	            function Ixa(a) {
	                a = a | 0;
	                gs(a | 0, 0) | 0
	            }

	            function Jxa(a) {
	                a = a | 0;
	                _r(a | 0, 0) | 0
	            }

	            function Kxa(a) {
	                a = a | 0;
	                dr(a | 0, 0) | 0
	            }

	            function Lxa(a) {
	                a = a | 0;
	                jv(a | 0, 0)
	            }

	            function Mxa(a) {
	                a = a | 0;
	                pv(a | 0, 0)
	            }

	            function Nxa(a) {
	                a = a | 0;
	                qv(a | 0, 0)
	            }

	            function Oxa(a) {
	                a = a | 0;
	                rv(a | 0, 0)
	            }

	            function Pxa(a) {
	                a = a | 0;
	                sv(a | 0, 0)
	            }

	            function Qxa(a) {
	                a = a | 0;
	                tv(a | 0, 0)
	            }

	            function Rxa(a) {
	                a = a | 0;
	                uv(a | 0, 0)
	            }

	            function Sxa(a) {
	                a = a | 0;
	                vv(a | 0, 0)
	            }

	            function Txa(a) {
	                a = a | 0;
	                tw(a | 0, 0, 0)
	            }

	            function Uxa(a) {
	                a = a | 0;
	                Kx(a | 0, 0, 0) | 0
	            }

	            function Vxa(a) {
	                a = a | 0;
	                $x(a | 0, 0) | 0
	            }

	            function Wxa(a) {
	                a = a | 0;
	                dy(a | 0, 0) | 0
	            }

	            function Xxa(a) {
	                a = a | 0;
	                fy(a | 0, 0) | 0
	            }

	            function Yxa(a) {
	                a = a | 0;
	                jy(a | 0, 0) | 0
	            }

	            function Zxa(a) {
	                a = a | 0;
	                LB(a | 0, 0, 0, 0, 0, 0, 0, 0, 0)
	            }

	            function _xa(a) {
	                a = a | 0;
	                MB(a | 0, 0, 0, 0)
	            }

	            function $xa(a) {
	                a = a | 0;
	                NB(a | 0, 0, 0)
	            }

	            function aya(a) {
	                a = a | 0;
	                OB(a | 0, 0, 0)
	            }

	            function bya(a) {
	                a = a | 0;
	                PB(a | 0, 0)
	            }

	            function cya(a) {
	                a = a | 0;
	                QB(a | 0, 0, 0, 0)
	            }

	            function dya(a) {
	                a = a | 0;
	                RB(a | 0) | 0
	            }

	            function eya(a) {
	                a = a | 0;
	                SB(a | 0) | 0
	            }

	            function fya(a) {
	                a = a | 0;
	                TB(a | 0) | 0
	            }

	            function gya(a) {
	                a = a | 0;
	                UB(a | 0, 0, 0) | 0
	            }

	            function hya(a) {
	                a = a | 0;
	                VB(a | 0, 0) | 0
	            }

	            function iya(a) {
	                a = a | 0;
	                WB(a | 0, 0, 0, 0, 0, 0)
	            }

	            function jya(a) {
	                a = a | 0;
	                XB(a | 0, 0, 0, 0)
	            }

	            function kya(a) {
	                a = a | 0;
	                YB(a | 0, 0, 0, 0, 0, 0, 0)
	            }

	            function lya(a) {
	                a = a | 0;
	                ZB(a | 0, 0, 0, 0)
	            }

	            function mya(a) {
	                a = a | 0;
	                _B(a | 0, 0, 0, 0, 0)
	            }

	            function nya(a) {
	                a = a | 0;
	                $B(a | 0, 0)
	            }

	            function oya(a) {
	                a = a | 0;
	                cC(a | 0, 0, 0)
	            }

	            function pya(a) {
	                a = a | 0;
	                dC(a | 0, 0)
	            }

	            function qya(a) {
	                a = a | 0;
	                eC(a | 0, 0, 0)
	            }

	            function rya(a) {
	                a = a | 0;
	                fC(a | 0, 0, 0)
	            }

	            function sya(a) {
	                a = a | 0;
	                gC(a | 0, 0, 0)
	            }

	            function tya(a) {
	                a = a | 0;
	                hC(a | 0, 0) | 0
	            }

	            function uya(a) {
	                a = a | 0;
	                iC(a | 0, 0, 0, 0)
	            }

	            function vya(a) {
	                a = a | 0;
	                jC(a | 0, 0, 0)
	            }

	            function wya(a) {
	                a = a | 0;
	                kC(a | 0, 0, 0)
	            }

	            function xya(a) {
	                a = a | 0;
	                lC(a | 0, 0, 0)
	            }

	            function yya(a) {
	                a = a | 0;
	                mC(a | 0, 0)
	            }

	            function zya(a) {
	                a = a | 0;
	                nC(a | 0, 0, 0, 0, 0, 0, 0, 0, 0)
	            }

	            function Aya(a) {
	                a = a | 0;
	                oC(a | 0, 0, 0, 0)
	            }

	            function Bya(a) {
	                a = a | 0;
	                rC(a | 0, 0, 0) | 0
	            }

	            function Cya(a) {
	                a = a | 0;
	                AD(a | 0, 0)
	            }

	            function Dya(a) {
	                a = a | 0;
	                lF(a | 0, 0, 0, 0)
	            }

	            function Eya(a) {
	                a = a | 0;
	                uF(a | 0, 0)
	            }

	            function Fya(a) {
	                a = a | 0;
	                wM(a | 0, 0, 0)
	            }

	            function Gya(a) {
	                a = a | 0;
	                xM(a | 0, 0)
	            }

	            function Hya(a) {
	                a = a | 0;
	                yM(a | 0, 0, 0, 0, 0, 0, 0, 0, 0)
	            }

	            function Iya(a) {
	                a = a | 0;
	                zM(a | 0, 0, 0, 0)
	            }

	            function Jya(a) {
	                a = a | 0;
	                AM(a | 0, 0, 0)
	            }

	            function Kya(a) {
	                a = a | 0;
	                BM(a | 0, 0, 0)
	            }

	            function Lya(a) {
	                a = a | 0;
	                DM(a | 0, 0, 0)
	            }

	            function Mya(a) {
	                a = a | 0;
	                EM(a | 0, 0, 0)
	            }

	            function Nya(a) {
	                a = a | 0;
	                GM(a | 0, 0, 0) | 0
	            }

	            function Oya(a) {
	                a = a | 0;
	                FM(a | 0, 0)
	            }

	            function Pya(a) {
	                a = a | 0;
	                nN(a | 0, 0) | 0
	            }

	            function Qya(a) {
	                a = a | 0;
	                oN(a | 0, 0, 0, 0, 0) | 0
	            }

	            function Rya(a) {
	                a = a | 0;
	                pN(a | 0, 0, 0, 0, 0, 0, 0) | 0
	            }

	            function Sya(a) {
	                a = a | 0;
	                qN(a | 0, 0, 0, 0, 0, 0) | 0
	            }

	            function Tya(a) {
	                a = a | 0;
	                rN(a | 0, 0)
	            }

	            function Uya(a) {
	                a = a | 0;
	                tN(a | 0, 0) | 0
	            }

	            function Vya(a) {
	                a = a | 0;
	                uN(a | 0, 0, 0, 0, 0) | 0
	            }

	            function Wya(a) {
	                a = a | 0;
	                vN(a | 0, 0, 0, 0, 0, 0, 0) | 0
	            }

	            function Xya(a) {
	                a = a | 0;
	                wN(a | 0, 0)
	            }

	            function Yya(a) {
	                a = a | 0;
	                CN(a | 0, 0, 0)
	            }

	            function Zya(a) {
	                a = a | 0;
	                GN(a | 0, 0, 0, 0)
	            }

	            function _ya(a) {
	                a = a | 0;
	                vO(a | 0, 0, 0)
	            }

	            function $ya(a) {
	                a = a | 0;
	                wO(a | 0, 0, 0)
	            }

	            function aza(a) {
	                a = a | 0;
	                fP(a | 0, 0, 0, 0)
	            }

	            function bza(a) {
	                a = a | 0;
	                sP(a | 0, 0, 0)
	            }

	            function cza(a) {
	                a = a | 0;
	                fQ(a | 0, 0, 0, 0, 0, 0, 0, 0, 0)
	            }

	            function dza(a) {
	                a = a | 0;
	                gQ(a | 0, 0, 0, 0)
	            }

	            function eza(a) {
	                a = a | 0;
	                WR(a | 0, 0, 0, 0) | 0
	            }

	            function fza(a) {
	                a = a | 0;
	                QS(a | 0, 0) | 0
	            }

	            function gza(a) {
	                a = a | 0;
	                hT(a | 0, 0, 0) | 0
	            }

	            function hza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                da(6)
	            }

	            function iza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                uc(a | 0, b | 0, 0, 0)
	            }

	            function jza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                vc(a | 0) | 0
	            }

	            function kza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                wc(a | 0) | 0
	            }

	            function lza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                xc(a | 0) | 0
	            }

	            function mza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                yc(a | 0, b | 0, 0) | 0
	            }

	            function nza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                zc(a | 0, b | 0) | 0
	            }

	            function oza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Ac(a | 0, b | 0, 0, 0, 0, 0)
	            }

	            function pza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Bc(a | 0, b | 0, 0, 0)
	            }

	            function qza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Cc(a | 0, b | 0, 0, 0, 0, 0, 0)
	            }

	            function rza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Dc(a | 0, b | 0, 0, 0)
	            }

	            function sza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Ec(a | 0, b | 0, 0, 0, 0)
	            }

	            function tza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Gc(a | 0)
	            }

	            function uza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Hc(a | 0)
	            }

	            function vza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Wc(a | 0, b | 0, 0)
	            }

	            function wza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Jc(a | 0, b | 0, 0)
	            }

	            function xza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Kc(a | 0, b | 0, 0)
	            }

	            function yza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Lc(a | 0, b | 0, 0)
	            }

	            function zza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Nc(a | 0, b | 0, 0)
	            }

	            function Aza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Oc(a | 0, b | 0, 0)
	            }

	            function Bza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Pc(a | 0, b | 0, 0)
	            }

	            function Cza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Qc(a | 0, b | 0) | 0
	            }

	            function Dza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Rc(a | 0, b | 0, 0)
	            }

	            function Eza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Sc(a | 0, b | 0, 0, 0)
	            }

	            function Fza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Tc(a | 0, b | 0, 0, 0, 0, 0, 0, 0, 0)
	            }

	            function Gza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Uc(a | 0, b | 0, 0, 0)
	            }

	            function Hza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Xk(a | 0, b | 0, 0) | 0
	            }

	            function Iza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                jT(a | 0)
	            }

	            function Jza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                iT(a | 0) | 0
	            }

	            function Kza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                kT(a | 0, b | 0) | 0
	            }

	            function Lza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                my(a | 0) | 0
	            }

	            function Mza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Td(a | 0, b | 0, 0)
	            }

	            function Nza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                SP(a | 0, b | 0, 0, 0)
	            }

	            function Oza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                PP(a | 0) | 0
	            }

	            function Pza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                QP(a | 0) | 0
	            }

	            function Qza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                RP(a | 0) | 0
	            }

	            function Rza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                UP(a | 0, b | 0, 0) | 0
	            }

	            function Sza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                VP(a | 0, b | 0) | 0
	            }

	            function Tza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                XP(a | 0, b | 0, 0, 0, 0, 0)
	            }

	            function Uza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                _P(a | 0, b | 0, 0, 0)
	            }

	            function Vza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                YP(a | 0, b | 0, 0, 0, 0, 0, 0)
	            }

	            function Wza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                ZP(a | 0, b | 0, 0, 0)
	            }

	            function Xza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                $P(a | 0, b | 0, 0, 0, 0)
	            }

	            function Yza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                bQ(a | 0)
	            }

	            function Zza(a, b) {
	                a = a | 0;
	                b = b | 0;
	                cQ(a | 0)
	            }

	            function _za(a, b) {
	                a = a | 0;
	                b = b | 0;
	                dQ(a | 0, b | 0, 0)
	            }

	            function $za(a, b) {
	                a = a | 0;
	                b = b | 0;
	                iQ(a | 0, b | 0, 0)
	            }

	            function aAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                kQ(a | 0, b | 0, 0)
	            }

	            function bAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                $d(a | 0, b | 0, 0)
	            }

	            function cAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                _d(a | 0, b | 0, 0)
	            }

	            function dAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                WP(a | 0, b | 0) | 0
	            }

	            function eAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                mQ(a | 0, b | 0, 0)
	            }

	            function fAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                TP(a | 0, b | 0, 0, 0)
	            }

	            function gAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                LP(a | 0) | 0
	            }

	            function hAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                MP(a | 0) | 0
	            }

	            function iAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                NP(a | 0) | 0
	            }

	            function jAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                OP(a | 0) | 0
	            }

	            function kAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                jQ(a | 0, b | 0, 0)
	            }

	            function lAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                NI(a | 0) | 0
	            }

	            function mAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                OI(a | 0) | 0
	            }

	            function nAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                PI(a | 0) | 0
	            }

	            function oAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                QI(a | 0) | 0
	            }

	            function pAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                RI(a | 0) | 0
	            }

	            function qAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                SI(a | 0) | 0
	            }

	            function rAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                TI(a | 0) | 0
	            }

	            function sAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                UI(a | 0) | 0
	            }

	            function tAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                VI(a | 0) | 0
	            }

	            function uAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                WI(a | 0) | 0
	            }

	            function vAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                XI(a | 0) | 0
	            }

	            function wAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                YI(a | 0) | 0
	            }

	            function xAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                ZI(a | 0) | 0
	            }

	            function yAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                _I(a | 0) | 0
	            }

	            function zAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                $I(a | 0) | 0
	            }

	            function AAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                aJ(a | 0) | 0
	            }

	            function BAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                bJ(a | 0) | 0
	            }

	            function CAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                cJ(a | 0) | 0
	            }

	            function DAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                dJ(a | 0) | 0
	            }

	            function EAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                eJ(a | 0) | 0
	            }

	            function FAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                fJ(a | 0) | 0
	            }

	            function GAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                gJ(a | 0) | 0
	            }

	            function HAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                hJ(a | 0) | 0
	            }

	            function IAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                iJ(a | 0) | 0
	            }

	            function JAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                jJ(a | 0) | 0
	            }

	            function KAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                kJ(a | 0) | 0
	            }

	            function LAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                lJ(a | 0) | 0
	            }

	            function MAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                mJ(a | 0) | 0
	            }

	            function NAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                nJ(a | 0) | 0
	            }

	            function OAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                oJ(a | 0) | 0
	            }

	            function PAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                pJ(a | 0) | 0
	            }

	            function QAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                qJ(a | 0) | 0
	            }

	            function RAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                rJ(a | 0) | 0
	            }

	            function SAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                sJ(a | 0) | 0
	            }

	            function TAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                tJ(a | 0) | 0
	            }

	            function UAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                uJ(a | 0) | 0
	            }

	            function VAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                vJ(a | 0) | 0
	            }

	            function WAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                wJ(a | 0) | 0
	            }

	            function XAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                xJ(a | 0) | 0
	            }

	            function YAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                yJ(a | 0) | 0
	            }

	            function ZAa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                zJ(a | 0) | 0
	            }

	            function _Aa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                AJ(a | 0) | 0
	            }

	            function $Aa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                BJ(a | 0) | 0
	            }

	            function aBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                CJ(a | 0) | 0
	            }

	            function bBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                DJ(a | 0) | 0
	            }

	            function cBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                EJ(a | 0) | 0
	            }

	            function dBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                FJ(a | 0) | 0
	            }

	            function eBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                GJ(a | 0) | 0
	            }

	            function fBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                HJ(a | 0) | 0
	            }

	            function gBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                IJ(a | 0) | 0
	            }

	            function hBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                JJ(a | 0) | 0
	            }

	            function iBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                KJ(a | 0) | 0
	            }

	            function jBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                LJ(a | 0) | 0
	            }

	            function kBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                MJ(a | 0) | 0
	            }

	            function lBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                NJ(a | 0) | 0
	            }

	            function mBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                OJ(a | 0) | 0
	            }

	            function nBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                PJ(a | 0) | 0
	            }

	            function oBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                QJ(a | 0) | 0
	            }

	            function pBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                RJ(a | 0) | 0
	            }

	            function qBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                SJ(a | 0) | 0
	            }

	            function rBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                TJ(a | 0) | 0
	            }

	            function sBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                UJ(a | 0) | 0
	            }

	            function tBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                VJ(a | 0) | 0
	            }

	            function uBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                WJ(a | 0) | 0
	            }

	            function vBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                XJ(a | 0) | 0
	            }

	            function wBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                YJ(a | 0) | 0
	            }

	            function xBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                ZJ(a | 0) | 0
	            }

	            function yBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                _J(a | 0) | 0
	            }

	            function zBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                $J(a | 0) | 0
	            }

	            function ABa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                aK(a | 0) | 0
	            }

	            function BBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                bK(a | 0) | 0
	            }

	            function CBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                cK(a | 0) | 0
	            }

	            function DBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                dK(a | 0) | 0
	            }

	            function EBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                eK(a | 0) | 0
	            }

	            function FBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                fK(a | 0) | 0
	            }

	            function GBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                gK(a | 0) | 0
	            }

	            function HBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                hK(a | 0) | 0
	            }

	            function IBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                iK(a | 0) | 0
	            }

	            function JBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                jK(a | 0) | 0
	            }

	            function KBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                kK(a | 0) | 0
	            }

	            function LBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                lK(a | 0) | 0
	            }

	            function MBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                mK(a | 0) | 0
	            }

	            function NBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                nK(a | 0) | 0
	            }

	            function OBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                oK(a | 0) | 0
	            }

	            function PBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                pK(a | 0) | 0
	            }

	            function QBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                qK(a | 0) | 0
	            }

	            function RBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                rK(a | 0) | 0
	            }

	            function SBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                sK(a | 0) | 0
	            }

	            function TBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                tK(a | 0) | 0
	            }

	            function UBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                uK(a | 0) | 0
	            }

	            function VBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                vK(a | 0) | 0
	            }

	            function WBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                wK(a | 0) | 0
	            }

	            function XBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                xK(a | 0) | 0
	            }

	            function YBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                yK(a | 0) | 0
	            }

	            function ZBa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                zK(a | 0) | 0
	            }

	            function _Ba(a, b) {
	                a = a | 0;
	                b = b | 0;
	                AK(a | 0) | 0
	            }

	            function $Ba(a, b) {
	                a = a | 0;
	                b = b | 0;
	                BK(a | 0) | 0
	            }

	            function aCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                CK(a | 0) | 0
	            }

	            function bCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                DK(a | 0) | 0
	            }

	            function cCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                EK(a | 0) | 0
	            }

	            function dCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                FK(a | 0) | 0
	            }

	            function eCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                GK(a | 0) | 0
	            }

	            function fCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                HK(a | 0) | 0
	            }

	            function gCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                IK(a | 0) | 0
	            }

	            function hCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                JK(a | 0) | 0
	            }

	            function iCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                KK(a | 0) | 0
	            }

	            function jCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                LK(a | 0) | 0
	            }

	            function kCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                MK(a | 0) | 0
	            }

	            function lCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                NK(a | 0) | 0
	            }

	            function mCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                OK(a | 0) | 0
	            }

	            function nCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                PK(a | 0) | 0
	            }

	            function oCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                QK(a | 0) | 0
	            }

	            function pCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                RK(a | 0) | 0
	            }

	            function qCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                SK(a | 0) | 0
	            }

	            function rCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                TK(a | 0) | 0
	            }

	            function sCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                UK(a | 0) | 0
	            }

	            function tCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                VK(a | 0) | 0
	            }

	            function uCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                WK(a | 0) | 0
	            }

	            function vCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                XK(a | 0) | 0
	            }

	            function wCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                YK(a | 0) | 0
	            }

	            function xCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                ZK(a | 0) | 0
	            }

	            function yCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                _K(a | 0) | 0
	            }

	            function zCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                $K(a | 0) | 0
	            }

	            function ACa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                aL(a | 0) | 0
	            }

	            function BCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                bL(a | 0) | 0
	            }

	            function CCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                cL(a | 0) | 0
	            }

	            function DCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                dL(a | 0) | 0
	            }

	            function ECa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                eL(a | 0) | 0
	            }

	            function FCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                RT(a | 0, b | 0, 0) | 0
	            }

	            function GCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Vb(a | 0)
	            }

	            function HCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Wb(a | 0) | 0
	            }

	            function ICa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Xb(a | 0, b | 0) | 0
	            }

	            function JCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Yb(a | 0) | 0
	            }

	            function KCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Wk(a | 0, b | 0, 0) | 0
	            }

	            function LCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                _b(a | 0)
	            }

	            function MCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                $b(a | 0)
	            }

	            function NCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                ac(a | 0, b | 0, 0) | 0
	            }

	            function OCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Ka(a | 0, b | 0, 0) | 0
	            }

	            function PCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                gc(a | 0, b | 0, 0) | 0
	            }

	            function QCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                hc(a | 0)
	            }

	            function RCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                ic(a | 0, b | 0, 0)
	            }

	            function SCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                jc(a | 0, b | 0, 0)
	            }

	            function TCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                kc(a | 0, b | 0, 0)
	            }

	            function UCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                lc(a | 0, b | 0, 0)
	            }

	            function VCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                nc(a | 0) | 0
	            }

	            function WCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                nd(a | 0) | 0
	            }

	            function XCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Kd(a | 0, b | 0, 0, 0) | 0
	            }

	            function YCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Ld(a | 0, b | 0, 0, 0) | 0
	            }

	            function ZCa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Md(a | 0, b | 0, 0, 0) | 0
	            }

	            function _Ca(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Nd(a | 0, b | 0, 0, 0) | 0
	            }

	            function $Ca(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Od(a | 0, b | 0, 0, 0) | 0
	            }

	            function aDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Pd(a | 0, b | 0, 0, 0) | 0
	            }

	            function bDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                qd(a | 0, b | 0, 0, 0) | 0
	            }

	            function cDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                rd(a | 0, b | 0, 0, 0) | 0
	            }

	            function dDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Qd(a | 0, b | 0, 0, 0) | 0
	            }

	            function eDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Rd(a | 0, b | 0, 0, 0) | 0
	            }

	            function fDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                fo(a | 0, b | 0, 0, 0) | 0
	            }

	            function gDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                ae(a | 0, b | 0, 0)
	            }

	            function hDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                be(a | 0, b | 0, 0)
	            }

	            function iDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                tg(a | 0)
	            }

	            function jDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                mk() | 0
	            }

	            function kDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                sh(a | 0, b | 0, 0, 0, 0)
	            }

	            function lDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                gk(a | 0, b | 0, 0, 0, 0)
	            }

	            function mDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                nk(a | 0) | 0
	            }

	            function nDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                ok(a | 0) | 0
	            }

	            function oDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                pk(a | 0, b | 0, 0) | 0
	            }

	            function pDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                qk(a | 0) | 0
	            }

	            function qDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                _k(a | 0) | 0
	            }

	            function rDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                $k(a | 0, b | 0, 0) | 0
	            }

	            function sDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                bl(a | 0) | 0
	            }

	            function tDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                cl(a | 0, b | 0, 0) | 0
	            }

	            function uDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                dl(a | 0) | 0
	            }

	            function vDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                el(a | 0, b | 0, 0) | 0
	            }

	            function wDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                fl(a | 0, b | 0, 0) | 0
	            }

	            function xDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                gl(a | 0, b | 0, 0, 0) | 0
	            }

	            function yDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                nn(a | 0)
	            }

	            function zDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                on(a | 0) | 0
	            }

	            function ADa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                sn(a | 0)
	            }

	            function BDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                vn(a | 0) | 0
	            }

	            function CDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                xn(a | 0)
	            }

	            function DDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                yn(a | 0) | 0
	            }

	            function EDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                An(a | 0)
	            }

	            function FDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Bn(a | 0)
	            }

	            function GDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Cn(a | 0, b | 0) | 0
	            }

	            function HDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Dn(a | 0)
	            }

	            function IDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                In(a | 0, b | 0, 0)
	            }

	            function JDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Rn(a | 0, b | 0, 0)
	            }

	            function KDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Sn(a | 0, b | 0, 0)
	            }

	            function LDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Tn(a | 0, b | 0, 0)
	            }

	            function MDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Un(a | 0, b | 0, 0)
	            }

	            function NDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                _n(a | 0, b | 0) | 0
	            }

	            function ODa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Qq(a | 0)
	            }

	            function PDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                uu(a | 0, b | 0, 0) | 0
	            }

	            function QDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                ds(a | 0, b | 0) | 0
	            }

	            function RDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                es(a | 0, b | 0) | 0
	            }

	            function SDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                js(a | 0, b | 0) | 0
	            }

	            function TDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                vu(a | 0, b | 0, 0) | 0
	            }

	            function UDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                wu(a | 0, b | 0) | 0
	            }

	            function VDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                $r(a | 0, b | 0) | 0
	            }

	            function WDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                as(a | 0, b | 0) | 0
	            }

	            function XDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                bs(a | 0, b | 0) | 0
	            }

	            function YDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                hs(a | 0, b | 0) | 0
	            }

	            function ZDa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                fs(a | 0, b | 0) | 0
	            }

	            function _Da(a, b) {
	                a = a | 0;
	                b = b | 0;
	                is(a | 0, b | 0) | 0
	            }

	            function $Da(a, b) {
	                a = a | 0;
	                b = b | 0;
	                cs(a | 0, b | 0) | 0
	            }

	            function aEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                xu(a | 0, b | 0) | 0
	            }

	            function bEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                gs(a | 0, b | 0) | 0
	            }

	            function cEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                _r(a | 0, b | 0) | 0
	            }

	            function dEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                dr(a | 0, b | 0) | 0
	            }

	            function eEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                tw(a | 0, b | 0, 0)
	            }

	            function fEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Mw(a | 0)
	            }

	            function gEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Yw(a | 0)
	            }

	            function hEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                Kx(a | 0, b | 0, 0) | 0
	            }

	            function iEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                $x(a | 0, b | 0) | 0
	            }

	            function jEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                dy(a | 0, b | 0) | 0
	            }

	            function kEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                fy(a | 0, b | 0) | 0
	            }

	            function lEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                jy(a | 0, b | 0) | 0
	            }

	            function mEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                qB(a | 0)
	            }

	            function nEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                LB(a | 0, b | 0, 0, 0, 0, 0, 0, 0, 0)
	            }

	            function oEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                MB(a | 0, b | 0, 0, 0)
	            }

	            function pEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                NB(a | 0, b | 0, 0)
	            }

	            function qEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                OB(a | 0, b | 0, 0)
	            }

	            function rEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                QB(a | 0, b | 0, 0, 0)
	            }

	            function sEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                RB(a | 0) | 0
	            }

	            function tEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                SB(a | 0) | 0
	            }

	            function uEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                TB(a | 0) | 0
	            }

	            function vEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                UB(a | 0, b | 0, 0) | 0
	            }

	            function wEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                VB(a | 0, b | 0) | 0
	            }

	            function xEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                WB(a | 0, b | 0, 0, 0, 0, 0)
	            }

	            function yEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                XB(a | 0, b | 0, 0, 0)
	            }

	            function zEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                YB(a | 0, b | 0, 0, 0, 0, 0, 0)
	            }

	            function AEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                ZB(a | 0, b | 0, 0, 0)
	            }

	            function BEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                _B(a | 0, b | 0, 0, 0, 0)
	            }

	            function CEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                aC(a | 0)
	            }

	            function DEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                bC(a | 0)
	            }

	            function EEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                cC(a | 0, b | 0, 0)
	            }

	            function FEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                eC(a | 0, b | 0, 0)
	            }

	            function GEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                fC(a | 0, b | 0, 0)
	            }

	            function HEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                gC(a | 0, b | 0, 0)
	            }

	            function IEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                hC(a | 0, b | 0) | 0
	            }

	            function JEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                iC(a | 0, b | 0, 0, 0)
	            }

	            function KEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                jC(a | 0, b | 0, 0)
	            }

	            function LEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                kC(a | 0, b | 0, 0)
	            }

	            function MEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                lC(a | 0, b | 0, 0)
	            }

	            function NEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                nC(a | 0, b | 0, 0, 0, 0, 0, 0, 0, 0)
	            }

	            function OEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                oC(a | 0, b | 0, 0, 0)
	            }

	            function PEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                rC(a | 0, b | 0, 0) | 0
	            }

	            function QEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                uC(a | 0)
	            }

	            function REa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                lF(a | 0, b | 0, 0, 0)
	            }

	            function SEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                VA(a | 0)
	            }

	            function TEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                wM(a | 0, b | 0, 0)
	            }

	            function UEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                yM(a | 0, b | 0, 0, 0, 0, 0, 0, 0, 0)
	            }

	            function VEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                zM(a | 0, b | 0, 0, 0)
	            }

	            function WEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                AM(a | 0, b | 0, 0)
	            }

	            function XEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                BM(a | 0, b | 0, 0)
	            }

	            function YEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                DM(a | 0, b | 0, 0)
	            }

	            function ZEa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                EM(a | 0, b | 0, 0)
	            }

	            function _Ea(a, b) {
	                a = a | 0;
	                b = b | 0;
	                GM(a | 0, b | 0, 0) | 0
	            }

	            function $Ea(a, b) {
	                a = a | 0;
	                b = b | 0;
	                UM(a | 0)
	            }

	            function aFa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                nN(a | 0, b | 0) | 0
	            }

	            function bFa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                oN(a | 0, b | 0, 0, 0, 0) | 0
	            }

	            function cFa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                pN(a | 0, b | 0, 0, 0, 0, 0, 0) | 0
	            }

	            function dFa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                qN(a | 0, b | 0, 0, 0, 0, 0) | 0
	            }

	            function eFa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                tN(a | 0, b | 0) | 0
	            }

	            function fFa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                uN(a | 0, b | 0, 0, 0, 0) | 0
	            }

	            function gFa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                vN(a | 0, b | 0, 0, 0, 0, 0, 0) | 0
	            }

	            function hFa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                CN(a | 0, b | 0, 0)
	            }

	            function iFa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                GN(a | 0, b | 0, 0, 0)
	            }

	            function jFa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                vO(a | 0, b | 0, 0)
	            }

	            function kFa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                wO(a | 0, b | 0, 0)
	            }

	            function lFa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                fP(a | 0, b | 0, 0, 0)
	            }

	            function mFa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                sP(a | 0, b | 0, 0)
	            }

	            function nFa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                fQ(a | 0, b | 0, 0, 0, 0, 0, 0, 0, 0)
	            }

	            function oFa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                gQ(a | 0, b | 0, 0, 0)
	            }

	            function pFa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                WR(a | 0, b | 0, 0, 0) | 0
	            }

	            function qFa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                QS(a | 0, b | 0) | 0
	            }

	            function rFa(a, b) {
	                a = a | 0;
	                b = b | 0;
	                hT(a | 0, b | 0, 0) | 0
	            }

	            function sFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                da(7);
	                return 0
	            }

	            function tFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function uFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return vc(a | 0) | 0
	            }

	            function vFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return wc(a | 0) | 0
	            }

	            function wFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return xc(a | 0) | 0
	            }

	            function xFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return yc(a | 0, b | 0, c | 0) | 0
	            }

	            function yFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return zc(a | 0, b | 0) | 0
	            }

	            function zFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function AFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function BFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function CFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function DFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function EFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function FFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function GFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function HFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function IFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function JFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function KFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function LFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function MFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function NFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function OFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function PFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function QFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function RFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return Qc(a | 0, b | 0) | 0
	            }

	            function SFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function TFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function UFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function VFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function WFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return Xk(a | 0, b | 0, c | 0) | 0
	            }

	            function XFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function YFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return iT(a | 0) | 0
	            }

	            function ZFa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return kT(a | 0, b | 0) | 0
	            }

	            function _Fa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return my(a | 0) | 0
	            }

	            function $Fa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function aGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function bGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return PP(a | 0) | 0
	            }

	            function cGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return QP(a | 0) | 0
	            }

	            function dGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return RP(a | 0) | 0
	            }

	            function eGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return UP(a | 0, b | 0, c | 0) | 0
	            }

	            function fGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return VP(a | 0, b | 0) | 0
	            }

	            function gGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function hGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function iGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function jGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function kGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function lGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function mGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function nGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function oGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function pGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function qGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function rGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function sGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function tGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function uGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function vGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function wGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return WP(a | 0, b | 0) | 0
	            }

	            function xGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function yGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function zGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return LP(a | 0) | 0
	            }

	            function AGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return MP(a | 0) | 0
	            }

	            function BGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return NP(a | 0) | 0
	            }

	            function CGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return OP(a | 0) | 0
	            }

	            function DGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function EGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return NI(a | 0) | 0
	            }

	            function FGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return OI(a | 0) | 0
	            }

	            function GGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return PI(a | 0) | 0
	            }

	            function HGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return QI(a | 0) | 0
	            }

	            function IGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return RI(a | 0) | 0
	            }

	            function JGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return SI(a | 0) | 0
	            }

	            function KGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return TI(a | 0) | 0
	            }

	            function LGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return UI(a | 0) | 0
	            }

	            function MGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return VI(a | 0) | 0
	            }

	            function NGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return WI(a | 0) | 0
	            }

	            function OGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return XI(a | 0) | 0
	            }

	            function PGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return YI(a | 0) | 0
	            }

	            function QGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return ZI(a | 0) | 0
	            }

	            function RGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return _I(a | 0) | 0
	            }

	            function SGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return $I(a | 0) | 0
	            }

	            function TGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return aJ(a | 0) | 0
	            }

	            function UGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return bJ(a | 0) | 0
	            }

	            function VGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return cJ(a | 0) | 0
	            }

	            function WGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return dJ(a | 0) | 0
	            }

	            function XGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return eJ(a | 0) | 0
	            }

	            function YGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return fJ(a | 0) | 0
	            }

	            function ZGa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return gJ(a | 0) | 0
	            }

	            function _Ga(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return hJ(a | 0) | 0
	            }

	            function $Ga(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return iJ(a | 0) | 0
	            }

	            function aHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return jJ(a | 0) | 0
	            }

	            function bHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return kJ(a | 0) | 0
	            }

	            function cHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return lJ(a | 0) | 0
	            }

	            function dHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return mJ(a | 0) | 0
	            }

	            function eHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return nJ(a | 0) | 0
	            }

	            function fHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return oJ(a | 0) | 0
	            }

	            function gHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return pJ(a | 0) | 0
	            }

	            function hHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return qJ(a | 0) | 0
	            }

	            function iHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return rJ(a | 0) | 0
	            }

	            function jHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return sJ(a | 0) | 0
	            }

	            function kHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return tJ(a | 0) | 0
	            }

	            function lHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return uJ(a | 0) | 0
	            }

	            function mHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return vJ(a | 0) | 0
	            }

	            function nHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return wJ(a | 0) | 0
	            }

	            function oHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return xJ(a | 0) | 0
	            }

	            function pHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return yJ(a | 0) | 0
	            }

	            function qHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return zJ(a | 0) | 0
	            }

	            function rHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return AJ(a | 0) | 0
	            }

	            function sHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return BJ(a | 0) | 0
	            }

	            function tHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return CJ(a | 0) | 0
	            }

	            function uHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return DJ(a | 0) | 0
	            }

	            function vHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return EJ(a | 0) | 0
	            }

	            function wHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return FJ(a | 0) | 0
	            }

	            function xHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return GJ(a | 0) | 0
	            }

	            function yHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return HJ(a | 0) | 0
	            }

	            function zHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return IJ(a | 0) | 0
	            }

	            function AHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return JJ(a | 0) | 0
	            }

	            function BHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return KJ(a | 0) | 0
	            }

	            function CHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return LJ(a | 0) | 0
	            }

	            function DHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return MJ(a | 0) | 0
	            }

	            function EHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return NJ(a | 0) | 0
	            }

	            function FHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return OJ(a | 0) | 0
	            }

	            function GHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return PJ(a | 0) | 0
	            }

	            function HHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return QJ(a | 0) | 0
	            }

	            function IHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return RJ(a | 0) | 0
	            }

	            function JHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return SJ(a | 0) | 0
	            }

	            function KHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return TJ(a | 0) | 0
	            }

	            function LHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return UJ(a | 0) | 0
	            }

	            function MHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return VJ(a | 0) | 0
	            }

	            function NHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return WJ(a | 0) | 0
	            }

	            function OHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return XJ(a | 0) | 0
	            }

	            function PHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return YJ(a | 0) | 0
	            }

	            function QHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return ZJ(a | 0) | 0
	            }

	            function RHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return _J(a | 0) | 0
	            }

	            function SHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return $J(a | 0) | 0
	            }

	            function THa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return aK(a | 0) | 0
	            }

	            function UHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return bK(a | 0) | 0
	            }

	            function VHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return cK(a | 0) | 0
	            }

	            function WHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return dK(a | 0) | 0
	            }

	            function XHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return eK(a | 0) | 0
	            }

	            function YHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return fK(a | 0) | 0
	            }

	            function ZHa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return gK(a | 0) | 0
	            }

	            function _Ha(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return hK(a | 0) | 0
	            }

	            function $Ha(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return iK(a | 0) | 0
	            }

	            function aIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return jK(a | 0) | 0
	            }

	            function bIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return kK(a | 0) | 0
	            }

	            function cIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return lK(a | 0) | 0
	            }

	            function dIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return mK(a | 0) | 0
	            }

	            function eIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return nK(a | 0) | 0
	            }

	            function fIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return oK(a | 0) | 0
	            }

	            function gIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return pK(a | 0) | 0
	            }

	            function hIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return qK(a | 0) | 0
	            }

	            function iIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return rK(a | 0) | 0
	            }

	            function jIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return sK(a | 0) | 0
	            }

	            function kIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return tK(a | 0) | 0
	            }

	            function lIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return uK(a | 0) | 0
	            }

	            function mIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return vK(a | 0) | 0
	            }

	            function nIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return wK(a | 0) | 0
	            }

	            function oIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return xK(a | 0) | 0
	            }

	            function pIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return yK(a | 0) | 0
	            }

	            function qIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return zK(a | 0) | 0
	            }

	            function rIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return AK(a | 0) | 0
	            }

	            function sIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return BK(a | 0) | 0
	            }

	            function tIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return CK(a | 0) | 0
	            }

	            function uIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return DK(a | 0) | 0
	            }

	            function vIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return EK(a | 0) | 0
	            }

	            function wIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return FK(a | 0) | 0
	            }

	            function xIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return GK(a | 0) | 0
	            }

	            function yIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return HK(a | 0) | 0
	            }

	            function zIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return IK(a | 0) | 0
	            }

	            function AIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return JK(a | 0) | 0
	            }

	            function BIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return KK(a | 0) | 0
	            }

	            function CIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return LK(a | 0) | 0
	            }

	            function DIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return MK(a | 0) | 0
	            }

	            function EIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return NK(a | 0) | 0
	            }

	            function FIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return OK(a | 0) | 0
	            }

	            function GIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return PK(a | 0) | 0
	            }

	            function HIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return QK(a | 0) | 0
	            }

	            function IIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return RK(a | 0) | 0
	            }

	            function JIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return SK(a | 0) | 0
	            }

	            function KIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return TK(a | 0) | 0
	            }

	            function LIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return UK(a | 0) | 0
	            }

	            function MIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return VK(a | 0) | 0
	            }

	            function NIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return WK(a | 0) | 0
	            }

	            function OIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return XK(a | 0) | 0
	            }

	            function PIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return YK(a | 0) | 0
	            }

	            function QIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return ZK(a | 0) | 0
	            }

	            function RIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return _K(a | 0) | 0
	            }

	            function SIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return $K(a | 0) | 0
	            }

	            function TIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return aL(a | 0) | 0
	            }

	            function UIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return bL(a | 0) | 0
	            }

	            function VIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return cL(a | 0) | 0
	            }

	            function WIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return dL(a | 0) | 0
	            }

	            function XIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return eL(a | 0) | 0
	            }

	            function YIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return RT(a | 0, b | 0, c | 0) | 0
	            }

	            function ZIa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function _Ia(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return Wb(a | 0) | 0
	            }

	            function $Ia(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return Xb(a | 0, b | 0) | 0
	            }

	            function aJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return Yb(a | 0) | 0
	            }

	            function bJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return Wk(a | 0, b | 0, c | 0) | 0
	            }

	            function cJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function dJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function eJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return ac(a | 0, b | 0, c | 0) | 0
	            }

	            function fJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return Ka(a | 0, b | 0, c | 0) | 0
	            }

	            function gJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return gc(a | 0, b | 0, c | 0) | 0
	            }

	            function hJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function iJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function jJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function kJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function lJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function mJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return nc(a | 0) | 0
	            }

	            function nJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function oJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return nd(a | 0) | 0
	            }

	            function pJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return Kd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function qJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return Ld(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function rJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return Md(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function sJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return Nd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function tJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return Od(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function uJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return Pd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function vJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return qd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function wJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return rd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function xJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return Qd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function yJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return Rd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function zJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return fo(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function AJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function BJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function CJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function DJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return mk() | 0
	            }

	            function EJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function FJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function GJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return nk(a | 0) | 0
	            }

	            function HJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return ok(a | 0) | 0
	            }

	            function IJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return pk(a | 0, b | 0, c | 0) | 0
	            }

	            function JJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return qk(a | 0) | 0
	            }

	            function KJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return _k(a | 0) | 0
	            }

	            function LJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return $k(a | 0, b | 0, c | 0) | 0
	            }

	            function MJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return bl(a | 0) | 0
	            }

	            function NJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return cl(a | 0, b | 0, c | 0) | 0
	            }

	            function OJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return dl(a | 0) | 0
	            }

	            function PJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return el(a | 0, b | 0, c | 0) | 0
	            }

	            function QJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return fl(a | 0, b | 0, c | 0) | 0
	            }

	            function RJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return gl(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function SJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function TJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return on(a | 0) | 0
	            }

	            function UJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function VJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return vn(a | 0) | 0
	            }

	            function WJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function XJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return yn(a | 0) | 0
	            }

	            function YJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function ZJa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function _Ja(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function $Ja(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return Cn(a | 0, b | 0) | 0
	            }

	            function aKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function bKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function cKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function dKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function eKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function fKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function gKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return _n(a | 0, b | 0) | 0
	            }

	            function hKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function iKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function jKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function kKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function lKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function mKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function nKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function oKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function pKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function qKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function rKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function sKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function tKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function uKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function vKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function wKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function xKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function yKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function zKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function AKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function BKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function CKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function DKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function EKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function FKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function GKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function HKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function IKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function JKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function KKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function LKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return uu(a | 0, b | 0, c | 0) | 0
	            }

	            function MKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return ds(a | 0, b | 0) | 0
	            }

	            function NKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return es(a | 0, b | 0) | 0
	            }

	            function OKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return js(a | 0, b | 0) | 0
	            }

	            function PKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return vu(a | 0, b | 0, c | 0) | 0
	            }

	            function QKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return wu(a | 0, b | 0) | 0
	            }

	            function RKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return $r(a | 0, b | 0) | 0
	            }

	            function SKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return as(a | 0, b | 0) | 0
	            }

	            function TKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return bs(a | 0, b | 0) | 0
	            }

	            function UKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return hs(a | 0, b | 0) | 0
	            }

	            function VKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return fs(a | 0, b | 0) | 0
	            }

	            function WKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return is(a | 0, b | 0) | 0
	            }

	            function XKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return cs(a | 0, b | 0) | 0
	            }

	            function YKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return xu(a | 0, b | 0) | 0
	            }

	            function ZKa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return gs(a | 0, b | 0) | 0
	            }

	            function _Ka(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return _r(a | 0, b | 0) | 0
	            }

	            function $Ka(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return dr(a | 0, b | 0) | 0
	            }

	            function aLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function bLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function cLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function dLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function eLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function fLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function gLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function hLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function iLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function jLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function kLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function lLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return Kx(a | 0, b | 0, c | 0) | 0
	            }

	            function mLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return $x(a | 0, b | 0) | 0
	            }

	            function nLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return dy(a | 0, b | 0) | 0
	            }

	            function oLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return fy(a | 0, b | 0) | 0
	            }

	            function pLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return jy(a | 0, b | 0) | 0
	            }

	            function qLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function rLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function sLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function tLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function uLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function vLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function wLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function xLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return RB(a | 0) | 0
	            }

	            function yLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return SB(a | 0) | 0
	            }

	            function zLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return TB(a | 0) | 0
	            }

	            function ALa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return UB(a | 0, b | 0, c | 0) | 0
	            }

	            function BLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return VB(a | 0, b | 0) | 0
	            }

	            function CLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function DLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function ELa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function FLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function GLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function HLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function ILa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function JLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function KLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function LLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function MLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function NLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function OLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function PLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return hC(a | 0, b | 0) | 0
	            }

	            function QLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function RLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function SLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function TLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function ULa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function VLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function WLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function XLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return rC(a | 0, b | 0, c | 0) | 0
	            }

	            function YLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function ZLa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function _La(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function $La(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function aMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function bMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function cMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function dMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function eMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function fMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function gMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function hMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function iMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function jMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return GM(a | 0, b | 0, c | 0) | 0
	            }

	            function kMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function lMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function mMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return nN(a | 0, b | 0) | 0
	            }

	            function nMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return oN(a | 0, b | 0, c | 0, d | 0, e | 0) | 0
	            }

	            function oMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return pN(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0, 0) | 0
	            }

	            function pMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function qMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return tN(a | 0, b | 0) | 0
	            }

	            function rMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return uN(a | 0, b | 0, c | 0, d | 0, e | 0) | 0
	            }

	            function sMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return vN(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0, 0) | 0
	            }

	            function tMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function uMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function vMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function wMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function xMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function yMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function zMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function AMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function BMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return 0
	            }

	            function CMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return WR(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function DMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return QS(a | 0, b | 0) | 0
	            }

	            function EMa(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                return hT(a | 0, b | 0, c | 0) | 0
	            }

	            function FMa(a) {
	                a = a | 0;
	                da(8);
	                return 0
	            }

	            function GMa(a) {
	                a = a | 0;
	                return 0
	            }

	            function HMa(a) {
	                a = a | 0;
	                return yc(a | 0, 0, 0) | 0
	            }

	            function IMa(a) {
	                a = a | 0;
	                return zc(a | 0, 0) | 0
	            }

	            function JMa(a) {
	                a = a | 0;
	                return 0
	            }

	            function KMa(a) {
	                a = a | 0;
	                return 0
	            }

	            function LMa(a) {
	                a = a | 0;
	                return 0
	            }

	            function MMa(a) {
	                a = a | 0;
	                return 0
	            }

	            function NMa(a) {
	                a = a | 0;
	                return 0
	            }

	            function OMa(a) {
	                a = a | 0;
	                return 0
	            }

	            function PMa(a) {
	                a = a | 0;
	                return 0
	            }

	            function QMa(a) {
	                a = a | 0;
	                return 0
	            }

	            function RMa(a) {
	                a = a | 0;
	                return 0
	            }

	            function SMa(a) {
	                a = a | 0;
	                return 0
	            }

	            function TMa(a) {
	                a = a | 0;
	                return 0
	            }

	            function UMa(a) {
	                a = a | 0;
	                return 0
	            }

	            function VMa(a) {
	                a = a | 0;
	                return 0
	            }

	            function WMa(a) {
	                a = a | 0;
	                return 0
	            }

	            function XMa(a) {
	                a = a | 0;
	                return 0
	            }

	            function YMa(a) {
	                a = a | 0;
	                return 0
	            }

	            function ZMa(a) {
	                a = a | 0;
	                return 0
	            }

	            function _Ma(a) {
	                a = a | 0;
	                return 0
	            }

	            function $Ma(a) {
	                a = a | 0;
	                return Qc(a | 0, 0) | 0
	            }

	            function aNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function bNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function cNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function dNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function eNa(a) {
	                a = a | 0;
	                return Xk(a | 0, 0, 0) | 0
	            }

	            function fNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function gNa(a) {
	                a = a | 0;
	                return kT(a | 0, 0) | 0
	            }

	            function hNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function iNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function jNa(a) {
	                a = a | 0;
	                return UP(a | 0, 0, 0) | 0
	            }

	            function kNa(a) {
	                a = a | 0;
	                return VP(a | 0, 0) | 0
	            }

	            function lNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function mNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function nNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function oNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function pNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function qNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function rNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function sNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function tNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function uNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function vNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function wNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function xNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function yNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function zNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function ANa(a) {
	                a = a | 0;
	                return 0
	            }

	            function BNa(a) {
	                a = a | 0;
	                return WP(a | 0, 0) | 0
	            }

	            function CNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function DNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function ENa(a) {
	                a = a | 0;
	                return 0
	            }

	            function FNa(a) {
	                a = a | 0;
	                return RT(a | 0, 0, 0) | 0
	            }

	            function GNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function HNa(a) {
	                a = a | 0;
	                return Xb(a | 0, 0) | 0
	            }

	            function INa(a) {
	                a = a | 0;
	                return Wk(a | 0, 0, 0) | 0
	            }

	            function JNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function KNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function LNa(a) {
	                a = a | 0;
	                return ac(a | 0, 0, 0) | 0
	            }

	            function MNa(a) {
	                a = a | 0;
	                return Ka(a | 0, 0, 0) | 0
	            }

	            function NNa(a) {
	                a = a | 0;
	                return gc(a | 0, 0, 0) | 0
	            }

	            function ONa(a) {
	                a = a | 0;
	                return 0
	            }

	            function PNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function QNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function RNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function SNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function TNa(a) {
	                a = a | 0;
	                return 0
	            }

	            function UNa(a) {
	                a = a | 0;
	                return Kd(a | 0, 0, 0, 0) | 0
	            }

	            function VNa(a) {
	                a = a | 0;
	                return Ld(a | 0, 0, 0, 0) | 0
	            }

	            function WNa(a) {
	                a = a | 0;
	                return Md(a | 0, 0, 0, 0) | 0
	            }

	            function XNa(a) {
	                a = a | 0;
	                return Nd(a | 0, 0, 0, 0) | 0
	            }

	            function YNa(a) {
	                a = a | 0;
	                return Od(a | 0, 0, 0, 0) | 0
	            }

	            function ZNa(a) {
	                a = a | 0;
	                return Pd(a | 0, 0, 0, 0) | 0
	            }

	            function _Na(a) {
	                a = a | 0;
	                return qd(a | 0, 0, 0, 0) | 0
	            }

	            function $Na(a) {
	                a = a | 0;
	                return rd(a | 0, 0, 0, 0) | 0
	            }

	            function aOa(a) {
	                a = a | 0;
	                return Qd(a | 0, 0, 0, 0) | 0
	            }

	            function bOa(a) {
	                a = a | 0;
	                return Rd(a | 0, 0, 0, 0) | 0
	            }

	            function cOa(a) {
	                a = a | 0;
	                return fo(a | 0, 0, 0, 0) | 0
	            }

	            function dOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function eOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function fOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function gOa(a) {
	                a = a | 0;
	                return mk() | 0
	            }

	            function hOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function iOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function jOa(a) {
	                a = a | 0;
	                return pk(a | 0, 0, 0) | 0
	            }

	            function kOa(a) {
	                a = a | 0;
	                return $k(a | 0, 0, 0) | 0
	            }

	            function lOa(a) {
	                a = a | 0;
	                return cl(a | 0, 0, 0) | 0
	            }

	            function mOa(a) {
	                a = a | 0;
	                return el(a | 0, 0, 0) | 0
	            }

	            function nOa(a) {
	                a = a | 0;
	                return fl(a | 0, 0, 0) | 0
	            }

	            function oOa(a) {
	                a = a | 0;
	                return gl(a | 0, 0, 0, 0) | 0
	            }

	            function pOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function qOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function rOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function sOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function tOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function uOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function vOa(a) {
	                a = a | 0;
	                return Cn(a | 0, 0) | 0
	            }

	            function wOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function xOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function yOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function zOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function AOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function BOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function COa(a) {
	                a = a | 0;
	                return _n(a | 0, 0) | 0
	            }

	            function DOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function EOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function FOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function GOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function HOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function IOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function JOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function KOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function LOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function MOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function NOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function OOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function POa(a) {
	                a = a | 0;
	                return 0
	            }

	            function QOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function ROa(a) {
	                a = a | 0;
	                return 0
	            }

	            function SOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function TOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function UOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function VOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function WOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function XOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function YOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function ZOa(a) {
	                a = a | 0;
	                return 0
	            }

	            function _Oa(a) {
	                a = a | 0;
	                return 0
	            }

	            function $Oa(a) {
	                a = a | 0;
	                return 0
	            }

	            function aPa(a) {
	                a = a | 0;
	                return 0
	            }

	            function bPa(a) {
	                a = a | 0;
	                return 0
	            }

	            function cPa(a) {
	                a = a | 0;
	                return 0
	            }

	            function dPa(a) {
	                a = a | 0;
	                return 0
	            }

	            function ePa(a) {
	                a = a | 0;
	                return 0
	            }

	            function fPa(a) {
	                a = a | 0;
	                return uu(a | 0, 0, 0) | 0
	            }

	            function gPa(a) {
	                a = a | 0;
	                return ds(a | 0, 0) | 0
	            }

	            function hPa(a) {
	                a = a | 0;
	                return es(a | 0, 0) | 0
	            }

	            function iPa(a) {
	                a = a | 0;
	                return js(a | 0, 0) | 0
	            }

	            function jPa(a) {
	                a = a | 0;
	                return vu(a | 0, 0, 0) | 0
	            }

	            function kPa(a) {
	                a = a | 0;
	                return wu(a | 0, 0) | 0
	            }

	            function lPa(a) {
	                a = a | 0;
	                return $r(a | 0, 0) | 0
	            }

	            function mPa(a) {
	                a = a | 0;
	                return as(a | 0, 0) | 0
	            }

	            function nPa(a) {
	                a = a | 0;
	                return bs(a | 0, 0) | 0
	            }

	            function oPa(a) {
	                a = a | 0;
	                return hs(a | 0, 0) | 0
	            }

	            function pPa(a) {
	                a = a | 0;
	                return fs(a | 0, 0) | 0
	            }

	            function qPa(a) {
	                a = a | 0;
	                return is(a | 0, 0) | 0
	            }

	            function rPa(a) {
	                a = a | 0;
	                return cs(a | 0, 0) | 0
	            }

	            function sPa(a) {
	                a = a | 0;
	                return xu(a | 0, 0) | 0
	            }

	            function tPa(a) {
	                a = a | 0;
	                return gs(a | 0, 0) | 0
	            }

	            function uPa(a) {
	                a = a | 0;
	                return _r(a | 0, 0) | 0
	            }

	            function vPa(a) {
	                a = a | 0;
	                return dr(a | 0, 0) | 0
	            }

	            function wPa(a) {
	                a = a | 0;
	                return 0
	            }

	            function xPa(a) {
	                a = a | 0;
	                return 0
	            }

	            function yPa(a) {
	                a = a | 0;
	                return 0
	            }

	            function zPa(a) {
	                a = a | 0;
	                return 0
	            }

	            function APa(a) {
	                a = a | 0;
	                return 0
	            }

	            function BPa(a) {
	                a = a | 0;
	                return 0
	            }

	            function CPa(a) {
	                a = a | 0;
	                return 0
	            }

	            function DPa(a) {
	                a = a | 0;
	                return 0
	            }

	            function EPa(a) {
	                a = a | 0;
	                return 0
	            }

	            function FPa(a) {
	                a = a | 0;
	                return 0
	            }

	            function GPa(a) {
	                a = a | 0;
	                return 0
	            }

	            function HPa(a) {
	                a = a | 0;
	                return Kx(a | 0, 0, 0) | 0
	            }

	            function IPa(a) {
	                a = a | 0;
	                return $x(a | 0, 0) | 0
	            }

	            function JPa(a) {
	                a = a | 0;
	                return dy(a | 0, 0) | 0
	            }

	            function KPa(a) {
	                a = a | 0;
	                return fy(a | 0, 0) | 0
	            }

	            function LPa(a) {
	                a = a | 0;
	                return jy(a | 0, 0) | 0
	            }

	            function MPa(a) {
	                a = a | 0;
	                return 0
	            }

	            function NPa(a) {
	                a = a | 0;
	                return 0
	            }

	            function OPa(a) {
	                a = a | 0;
	                return 0
	            }

	            function PPa(a) {
	                a = a | 0;
	                return 0
	            }

	            function QPa(a) {
	                a = a | 0;
	                return 0
	            }

	            function RPa(a) {
	                a = a | 0;
	                return 0
	            }

	            function SPa(a) {
	                a = a | 0;
	                return 0
	            }

	            function TPa(a) {
	                a = a | 0;
	                return UB(a | 0, 0, 0) | 0
	            }

	            function UPa(a) {
	                a = a | 0;
	                return VB(a | 0, 0) | 0
	            }

	            function VPa(a) {
	                a = a | 0;
	                return 0
	            }

	            function WPa(a) {
	                a = a | 0;
	                return 0
	            }

	            function XPa(a) {
	                a = a | 0;
	                return 0
	            }

	            function YPa(a) {
	                a = a | 0;
	                return 0
	            }

	            function ZPa(a) {
	                a = a | 0;
	                return 0
	            }

	            function _Pa(a) {
	                a = a | 0;
	                return 0
	            }

	            function $Pa(a) {
	                a = a | 0;
	                return 0
	            }

	            function aQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function bQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function cQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function dQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function eQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function fQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function gQa(a) {
	                a = a | 0;
	                return hC(a | 0, 0) | 0
	            }

	            function hQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function iQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function jQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function kQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function lQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function mQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function nQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function oQa(a) {
	                a = a | 0;
	                return rC(a | 0, 0, 0) | 0
	            }

	            function pQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function qQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function rQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function sQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function tQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function uQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function vQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function wQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function xQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function yQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function zQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function AQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function BQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function CQa(a) {
	                a = a | 0;
	                return GM(a | 0, 0, 0) | 0
	            }

	            function DQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function EQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function FQa(a) {
	                a = a | 0;
	                return nN(a | 0, 0) | 0
	            }

	            function GQa(a) {
	                a = a | 0;
	                return oN(a | 0, 0, 0, 0, 0) | 0
	            }

	            function HQa(a) {
	                a = a | 0;
	                return pN(a | 0, 0, 0, 0, 0, 0, 0) | 0
	            }

	            function IQa(a) {
	                a = a | 0;
	                return qN(a | 0, 0, 0, 0, 0, 0) | 0
	            }

	            function JQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function KQa(a) {
	                a = a | 0;
	                return tN(a | 0, 0) | 0
	            }

	            function LQa(a) {
	                a = a | 0;
	                return uN(a | 0, 0, 0, 0, 0) | 0
	            }

	            function MQa(a) {
	                a = a | 0;
	                return vN(a | 0, 0, 0, 0, 0, 0, 0) | 0
	            }

	            function NQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function OQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function PQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function QQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function RQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function SQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function TQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function UQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function VQa(a) {
	                a = a | 0;
	                return 0
	            }

	            function WQa(a) {
	                a = a | 0;
	                return WR(a | 0, 0, 0, 0) | 0
	            }

	            function XQa(a) {
	                a = a | 0;
	                return QS(a | 0, 0) | 0
	            }

	            function YQa(a) {
	                a = a | 0;
	                return hT(a | 0, 0, 0) | 0
	            }

	            function ZQa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                da(9)
	            }

	            function _Qa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                uc(a | 0, b | 0, c | 0, 0)
	            }

	            function $Qa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                vc(a | 0) | 0
	            }

	            function aRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                wc(a | 0) | 0
	            }

	            function bRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                xc(a | 0) | 0
	            }

	            function cRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                yc(a | 0, b | 0, c | 0) | 0
	            }

	            function dRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                zc(a | 0, b | 0) | 0
	            }

	            function eRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Ac(a | 0, b | 0, c | 0, 0, 0, 0)
	            }

	            function fRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Bc(a | 0, b | 0, c | 0, 0)
	            }

	            function gRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Cc(a | 0, b | 0, c | 0, 0, 0, 0, 0)
	            }

	            function hRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Dc(a | 0, b | 0, c | 0, 0)
	            }

	            function iRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Ec(a | 0, b | 0, c | 0, 0, 0)
	            }

	            function jRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Fc(a | 0, b | 0)
	            }

	            function kRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Gc(a | 0)
	            }

	            function lRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Hc(a | 0)
	            }

	            function mRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Xc(a | 0, b | 0)
	            }

	            function nRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Ic(a | 0, b | 0)
	            }

	            function oRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Mc(a | 0, b | 0)
	            }

	            function pRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Qc(a | 0, b | 0) | 0
	            }

	            function qRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Sc(a | 0, b | 0, c | 0, 0)
	            }

	            function rRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Tc(a | 0, b | 0, c | 0, 0, 0, 0, 0, 0, 0)
	            }

	            function sRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Uc(a | 0, b | 0, c | 0, 0)
	            }

	            function tRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Xk(a | 0, b | 0, c | 0) | 0
	            }

	            function uRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                jT(a | 0)
	            }

	            function vRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                iT(a | 0) | 0
	            }

	            function wRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                kT(a | 0, b | 0) | 0
	            }

	            function xRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                my(a | 0) | 0
	            }

	            function yRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                SP(a | 0, b | 0, c | 0, 0)
	            }

	            function zRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                PP(a | 0) | 0
	            }

	            function ARa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                QP(a | 0) | 0
	            }

	            function BRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                RP(a | 0) | 0
	            }

	            function CRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                UP(a | 0, b | 0, c | 0) | 0
	            }

	            function DRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                VP(a | 0, b | 0) | 0
	            }

	            function ERa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                XP(a | 0, b | 0, c | 0, 0, 0, 0)
	            }

	            function FRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                _P(a | 0, b | 0, c | 0, 0)
	            }

	            function GRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                YP(a | 0, b | 0, c | 0, 0, 0, 0, 0)
	            }

	            function HRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                ZP(a | 0, b | 0, c | 0, 0)
	            }

	            function IRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                $P(a | 0, b | 0, c | 0, 0, 0)
	            }

	            function JRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                aQ(a | 0, b | 0)
	            }

	            function KRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                bQ(a | 0)
	            }

	            function LRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                cQ(a | 0)
	            }

	            function MRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                eQ(a | 0, b | 0)
	            }

	            function NRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                hQ(a | 0, b | 0)
	            }

	            function ORa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                lQ(a | 0, b | 0)
	            }

	            function PRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                WP(a | 0, b | 0) | 0
	            }

	            function QRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                TP(a | 0, b | 0, c | 0, 0)
	            }

	            function RRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                LP(a | 0) | 0
	            }

	            function SRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                MP(a | 0) | 0
	            }

	            function TRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                NP(a | 0) | 0
	            }

	            function URa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                OP(a | 0) | 0
	            }

	            function VRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                NI(a | 0) | 0
	            }

	            function WRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                OI(a | 0) | 0
	            }

	            function XRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                PI(a | 0) | 0
	            }

	            function YRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                QI(a | 0) | 0
	            }

	            function ZRa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                RI(a | 0) | 0
	            }

	            function _Ra(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                SI(a | 0) | 0
	            }

	            function $Ra(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                TI(a | 0) | 0
	            }

	            function aSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                UI(a | 0) | 0
	            }

	            function bSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                VI(a | 0) | 0
	            }

	            function cSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                WI(a | 0) | 0
	            }

	            function dSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                XI(a | 0) | 0
	            }

	            function eSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                YI(a | 0) | 0
	            }

	            function fSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                ZI(a | 0) | 0
	            }

	            function gSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                _I(a | 0) | 0
	            }

	            function hSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                $I(a | 0) | 0
	            }

	            function iSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                aJ(a | 0) | 0
	            }

	            function jSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                bJ(a | 0) | 0
	            }

	            function kSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                cJ(a | 0) | 0
	            }

	            function lSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                dJ(a | 0) | 0
	            }

	            function mSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                eJ(a | 0) | 0
	            }

	            function nSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                fJ(a | 0) | 0
	            }

	            function oSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                gJ(a | 0) | 0
	            }

	            function pSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                hJ(a | 0) | 0
	            }

	            function qSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                iJ(a | 0) | 0
	            }

	            function rSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                jJ(a | 0) | 0
	            }

	            function sSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                kJ(a | 0) | 0
	            }

	            function tSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                lJ(a | 0) | 0
	            }

	            function uSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                mJ(a | 0) | 0
	            }

	            function vSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                nJ(a | 0) | 0
	            }

	            function wSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                oJ(a | 0) | 0
	            }

	            function xSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                pJ(a | 0) | 0
	            }

	            function ySa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                qJ(a | 0) | 0
	            }

	            function zSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                rJ(a | 0) | 0
	            }

	            function ASa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                sJ(a | 0) | 0
	            }

	            function BSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                tJ(a | 0) | 0
	            }

	            function CSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                uJ(a | 0) | 0
	            }

	            function DSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                vJ(a | 0) | 0
	            }

	            function ESa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                wJ(a | 0) | 0
	            }

	            function FSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                xJ(a | 0) | 0
	            }

	            function GSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                yJ(a | 0) | 0
	            }

	            function HSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                zJ(a | 0) | 0
	            }

	            function ISa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                AJ(a | 0) | 0
	            }

	            function JSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                BJ(a | 0) | 0
	            }

	            function KSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                CJ(a | 0) | 0
	            }

	            function LSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                DJ(a | 0) | 0
	            }

	            function MSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                EJ(a | 0) | 0
	            }

	            function NSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                FJ(a | 0) | 0
	            }

	            function OSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                GJ(a | 0) | 0
	            }

	            function PSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                HJ(a | 0) | 0
	            }

	            function QSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                IJ(a | 0) | 0
	            }

	            function RSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                JJ(a | 0) | 0
	            }

	            function SSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                KJ(a | 0) | 0
	            }

	            function TSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                LJ(a | 0) | 0
	            }

	            function USa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                MJ(a | 0) | 0
	            }

	            function VSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                NJ(a | 0) | 0
	            }

	            function WSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                OJ(a | 0) | 0
	            }

	            function XSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                PJ(a | 0) | 0
	            }

	            function YSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                QJ(a | 0) | 0
	            }

	            function ZSa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                RJ(a | 0) | 0
	            }

	            function _Sa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                SJ(a | 0) | 0
	            }

	            function $Sa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                TJ(a | 0) | 0
	            }

	            function aTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                UJ(a | 0) | 0
	            }

	            function bTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                VJ(a | 0) | 0
	            }

	            function cTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                WJ(a | 0) | 0
	            }

	            function dTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                XJ(a | 0) | 0
	            }

	            function eTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                YJ(a | 0) | 0
	            }

	            function fTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                ZJ(a | 0) | 0
	            }

	            function gTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                _J(a | 0) | 0
	            }

	            function hTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                $J(a | 0) | 0
	            }

	            function iTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                aK(a | 0) | 0
	            }

	            function jTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                bK(a | 0) | 0
	            }

	            function kTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                cK(a | 0) | 0
	            }

	            function lTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                dK(a | 0) | 0
	            }

	            function mTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                eK(a | 0) | 0
	            }

	            function nTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                fK(a | 0) | 0
	            }

	            function oTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                gK(a | 0) | 0
	            }

	            function pTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                hK(a | 0) | 0
	            }

	            function qTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                iK(a | 0) | 0
	            }

	            function rTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                jK(a | 0) | 0
	            }

	            function sTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                kK(a | 0) | 0
	            }

	            function tTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                lK(a | 0) | 0
	            }

	            function uTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                mK(a | 0) | 0
	            }

	            function vTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                nK(a | 0) | 0
	            }

	            function wTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                oK(a | 0) | 0
	            }

	            function xTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                pK(a | 0) | 0
	            }

	            function yTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                qK(a | 0) | 0
	            }

	            function zTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                rK(a | 0) | 0
	            }

	            function ATa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                sK(a | 0) | 0
	            }

	            function BTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                tK(a | 0) | 0
	            }

	            function CTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                uK(a | 0) | 0
	            }

	            function DTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                vK(a | 0) | 0
	            }

	            function ETa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                wK(a | 0) | 0
	            }

	            function FTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                xK(a | 0) | 0
	            }

	            function GTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                yK(a | 0) | 0
	            }

	            function HTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                zK(a | 0) | 0
	            }

	            function ITa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                AK(a | 0) | 0
	            }

	            function JTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                BK(a | 0) | 0
	            }

	            function KTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                CK(a | 0) | 0
	            }

	            function LTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                DK(a | 0) | 0
	            }

	            function MTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                EK(a | 0) | 0
	            }

	            function NTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                FK(a | 0) | 0
	            }

	            function OTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                GK(a | 0) | 0
	            }

	            function PTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                HK(a | 0) | 0
	            }

	            function QTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                IK(a | 0) | 0
	            }

	            function RTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                JK(a | 0) | 0
	            }

	            function STa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                KK(a | 0) | 0
	            }

	            function TTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                LK(a | 0) | 0
	            }

	            function UTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                MK(a | 0) | 0
	            }

	            function VTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                NK(a | 0) | 0
	            }

	            function WTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                OK(a | 0) | 0
	            }

	            function XTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                PK(a | 0) | 0
	            }

	            function YTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                QK(a | 0) | 0
	            }

	            function ZTa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                RK(a | 0) | 0
	            }

	            function _Ta(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                SK(a | 0) | 0
	            }

	            function $Ta(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                TK(a | 0) | 0
	            }

	            function aUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                UK(a | 0) | 0
	            }

	            function bUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                VK(a | 0) | 0
	            }

	            function cUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                WK(a | 0) | 0
	            }

	            function dUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                XK(a | 0) | 0
	            }

	            function eUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                YK(a | 0) | 0
	            }

	            function fUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                ZK(a | 0) | 0
	            }

	            function gUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                _K(a | 0) | 0
	            }

	            function hUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                $K(a | 0) | 0
	            }

	            function iUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                aL(a | 0) | 0
	            }

	            function jUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                bL(a | 0) | 0
	            }

	            function kUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                cL(a | 0) | 0
	            }

	            function lUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                dL(a | 0) | 0
	            }

	            function mUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                eL(a | 0) | 0
	            }

	            function nUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                RT(a | 0, b | 0, c | 0) | 0
	            }

	            function oUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Vb(a | 0)
	            }

	            function pUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Wb(a | 0) | 0
	            }

	            function qUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Xb(a | 0, b | 0) | 0
	            }

	            function rUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Yb(a | 0) | 0
	            }

	            function sUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Wk(a | 0, b | 0, c | 0) | 0
	            }

	            function tUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                _b(a | 0)
	            }

	            function uUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                $b(a | 0)
	            }

	            function vUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                ac(a | 0, b | 0, c | 0) | 0
	            }

	            function wUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Ka(a | 0, b | 0, c | 0) | 0
	            }

	            function xUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                gc(a | 0, b | 0, c | 0) | 0
	            }

	            function yUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                hc(a | 0)
	            }

	            function zUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                nc(a | 0) | 0
	            }

	            function AUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                md(a | 0, b | 0)
	            }

	            function BUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                nd(a | 0) | 0
	            }

	            function CUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Kd(a | 0, b | 0, c | 0, 0) | 0
	            }

	            function DUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Ld(a | 0, b | 0, c | 0, 0) | 0
	            }

	            function EUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Md(a | 0, b | 0, c | 0, 0) | 0
	            }

	            function FUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Nd(a | 0, b | 0, c | 0, 0) | 0
	            }

	            function GUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Od(a | 0, b | 0, c | 0, 0) | 0
	            }

	            function HUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Pd(a | 0, b | 0, c | 0, 0) | 0
	            }

	            function IUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                qd(a | 0, b | 0, c | 0, 0) | 0
	            }

	            function JUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                rd(a | 0, b | 0, c | 0, 0) | 0
	            }

	            function KUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Qd(a | 0, b | 0, c | 0, 0) | 0
	            }

	            function LUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Rd(a | 0, b | 0, c | 0, 0) | 0
	            }

	            function MUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                fo(a | 0, b | 0, c | 0, 0) | 0
	            }

	            function NUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                tg(a | 0)
	            }

	            function OUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                mk() | 0
	            }

	            function PUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                sh(a | 0, b | 0, c | 0, 0, 0)
	            }

	            function QUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                gk(a | 0, b | 0, c | 0, 0, 0)
	            }

	            function RUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                nk(a | 0) | 0
	            }

	            function SUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                ok(a | 0) | 0
	            }

	            function TUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                pk(a | 0, b | 0, c | 0) | 0
	            }

	            function UUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                qk(a | 0) | 0
	            }

	            function VUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                _k(a | 0) | 0
	            }

	            function WUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                $k(a | 0, b | 0, c | 0) | 0
	            }

	            function XUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                bl(a | 0) | 0
	            }

	            function YUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                cl(a | 0, b | 0, c | 0) | 0
	            }

	            function ZUa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                dl(a | 0) | 0
	            }

	            function _Ua(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                el(a | 0, b | 0, c | 0) | 0
	            }

	            function $Ua(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                fl(a | 0, b | 0, c | 0) | 0
	            }

	            function aVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                gl(a | 0, b | 0, c | 0, 0) | 0
	            }

	            function bVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                nn(a | 0)
	            }

	            function cVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                on(a | 0) | 0
	            }

	            function dVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                sn(a | 0)
	            }

	            function eVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                vn(a | 0) | 0
	            }

	            function fVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                xn(a | 0)
	            }

	            function gVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                yn(a | 0) | 0
	            }

	            function hVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                zn(a | 0, b | 0)
	            }

	            function iVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                An(a | 0)
	            }

	            function jVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Bn(a | 0)
	            }

	            function kVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Cn(a | 0, b | 0) | 0
	            }

	            function lVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Dn(a | 0)
	            }

	            function mVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                _n(a | 0, b | 0) | 0
	            }

	            function nVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                tq(a | 0, b | 0)
	            }

	            function oVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Qq(a | 0)
	            }

	            function pVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Bs(a | 0, b | 0)
	            }

	            function qVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Is(a | 0, b | 0)
	            }

	            function rVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                ns(a | 0, b | 0)
	            }

	            function sVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                ts(a | 0, b | 0)
	            }

	            function tVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                us(a | 0, b | 0)
	            }

	            function uVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                os(a | 0, b | 0)
	            }

	            function vVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Es(a | 0, b | 0)
	            }

	            function wVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Hs(a | 0, b | 0)
	            }

	            function xVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                ls(a | 0, b | 0)
	            }

	            function yVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Fs(a | 0, b | 0)
	            }

	            function zVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                ps(a | 0, b | 0)
	            }

	            function AVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Cs(a | 0, b | 0)
	            }

	            function BVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                nt(a | 0, b | 0)
	            }

	            function CVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                qs(a | 0, b | 0)
	            }

	            function DVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                zs(a | 0, b | 0)
	            }

	            function EVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Tr(a | 0, b | 0)
	            }

	            function FVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                ms(a | 0, b | 0)
	            }

	            function GVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Js(a | 0, b | 0)
	            }

	            function HVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                rs(a | 0, b | 0)
	            }

	            function IVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                ss(a | 0, b | 0)
	            }

	            function JVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                vs(a | 0, b | 0)
	            }

	            function KVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                ws(a | 0, b | 0)
	            }

	            function LVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                xs(a | 0, b | 0)
	            }

	            function MVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                ys(a | 0, b | 0)
	            }

	            function NVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Gs(a | 0, b | 0)
	            }

	            function OVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Ds(a | 0, b | 0)
	            }

	            function PVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                As(a | 0, b | 0)
	            }

	            function QVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                ot(a | 0, b | 0)
	            }

	            function RVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                uu(a | 0, b | 0, c | 0) | 0
	            }

	            function SVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                ds(a | 0, b | 0) | 0
	            }

	            function TVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                es(a | 0, b | 0) | 0
	            }

	            function UVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                js(a | 0, b | 0) | 0
	            }

	            function VVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                vu(a | 0, b | 0, c | 0) | 0
	            }

	            function WVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                wu(a | 0, b | 0) | 0
	            }

	            function XVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                $r(a | 0, b | 0) | 0
	            }

	            function YVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                as(a | 0, b | 0) | 0
	            }

	            function ZVa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                bs(a | 0, b | 0) | 0
	            }

	            function _Va(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                hs(a | 0, b | 0) | 0
	            }

	            function $Va(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                fs(a | 0, b | 0) | 0
	            }

	            function aWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                is(a | 0, b | 0) | 0
	            }

	            function bWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                cs(a | 0, b | 0) | 0
	            }

	            function cWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                xu(a | 0, b | 0) | 0
	            }

	            function dWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                gs(a | 0, b | 0) | 0
	            }

	            function eWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                _r(a | 0, b | 0) | 0
	            }

	            function fWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                dr(a | 0, b | 0) | 0
	            }

	            function gWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                jv(a | 0, b | 0)
	            }

	            function hWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                pv(a | 0, b | 0)
	            }

	            function iWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                qv(a | 0, b | 0)
	            }

	            function jWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                rv(a | 0, b | 0)
	            }

	            function kWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                sv(a | 0, b | 0)
	            }

	            function lWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                tv(a | 0, b | 0)
	            }

	            function mWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                uv(a | 0, b | 0)
	            }

	            function nWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                vv(a | 0, b | 0)
	            }

	            function oWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Mw(a | 0)
	            }

	            function pWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Yw(a | 0)
	            }

	            function qWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                Kx(a | 0, b | 0, c | 0) | 0
	            }

	            function rWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                $x(a | 0, b | 0) | 0
	            }

	            function sWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                dy(a | 0, b | 0) | 0
	            }

	            function tWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                fy(a | 0, b | 0) | 0
	            }

	            function uWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                jy(a | 0, b | 0) | 0
	            }

	            function vWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                qB(a | 0)
	            }

	            function wWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                LB(a | 0, b | 0, c | 0, 0, 0, 0, 0, 0, 0)
	            }

	            function xWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                MB(a | 0, b | 0, c | 0, 0)
	            }

	            function yWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                PB(a | 0, b | 0)
	            }

	            function zWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                QB(a | 0, b | 0, c | 0, 0)
	            }

	            function AWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                RB(a | 0) | 0
	            }

	            function BWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                SB(a | 0) | 0
	            }

	            function CWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                TB(a | 0) | 0
	            }

	            function DWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                UB(a | 0, b | 0, c | 0) | 0
	            }

	            function EWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                VB(a | 0, b | 0) | 0
	            }

	            function FWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                WB(a | 0, b | 0, c | 0, 0, 0, 0)
	            }

	            function GWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                XB(a | 0, b | 0, c | 0, 0)
	            }

	            function HWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                YB(a | 0, b | 0, c | 0, 0, 0, 0, 0)
	            }

	            function IWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                ZB(a | 0, b | 0, c | 0, 0)
	            }

	            function JWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                _B(a | 0, b | 0, c | 0, 0, 0)
	            }

	            function KWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                $B(a | 0, b | 0)
	            }

	            function LWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                aC(a | 0)
	            }

	            function MWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                bC(a | 0)
	            }

	            function NWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                dC(a | 0, b | 0)
	            }

	            function OWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                hC(a | 0, b | 0) | 0
	            }

	            function PWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                iC(a | 0, b | 0, c | 0, 0)
	            }

	            function QWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                mC(a | 0, b | 0)
	            }

	            function RWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                nC(a | 0, b | 0, c | 0, 0, 0, 0, 0, 0, 0)
	            }

	            function SWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                oC(a | 0, b | 0, c | 0, 0)
	            }

	            function TWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                rC(a | 0, b | 0, c | 0) | 0
	            }

	            function UWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                uC(a | 0)
	            }

	            function VWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                AD(a | 0, b | 0)
	            }

	            function WWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                lF(a | 0, b | 0, c | 0, 0)
	            }

	            function XWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                uF(a | 0, b | 0)
	            }

	            function YWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                VA(a | 0)
	            }

	            function ZWa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                xM(a | 0, b | 0)
	            }

	            function _Wa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                yM(a | 0, b | 0, c | 0, 0, 0, 0, 0, 0, 0)
	            }

	            function $Wa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                zM(a | 0, b | 0, c | 0, 0)
	            }

	            function aXa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                GM(a | 0, b | 0, c | 0) | 0
	            }

	            function bXa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                FM(a | 0, b | 0)
	            }

	            function cXa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                UM(a | 0)
	            }

	            function dXa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                nN(a | 0, b | 0) | 0
	            }

	            function eXa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                oN(a | 0, b | 0, c | 0, 0, 0) | 0
	            }

	            function fXa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                pN(a | 0, b | 0, c | 0, 0, 0, 0, 0) | 0
	            }

	            function gXa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                qN(a | 0, b | 0, c | 0, 0, 0, 0) | 0
	            }

	            function hXa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                rN(a | 0, b | 0)
	            }

	            function iXa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                tN(a | 0, b | 0) | 0
	            }

	            function jXa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                uN(a | 0, b | 0, c | 0, 0, 0) | 0
	            }

	            function kXa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                vN(a | 0, b | 0, c | 0, 0, 0, 0, 0) | 0
	            }

	            function lXa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                wN(a | 0, b | 0)
	            }

	            function mXa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                GN(a | 0, b | 0, c | 0, 0)
	            }

	            function nXa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                fP(a | 0, b | 0, c | 0, 0)
	            }

	            function oXa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                fQ(a | 0, b | 0, c | 0, 0, 0, 0, 0, 0, 0)
	            }

	            function pXa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                gQ(a | 0, b | 0, c | 0, 0)
	            }

	            function qXa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                WR(a | 0, b | 0, c | 0, 0) | 0
	            }

	            function rXa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                QS(a | 0, b | 0) | 0
	            }

	            function sXa(a, b, c) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                hT(a | 0, b | 0, c | 0) | 0
	            }

	            function tXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                da(10)
	            }

	            function uXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                uc(a | 0, b | 0, c | 0, d | 0)
	            }

	            function vXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                vc(a | 0) | 0
	            }

	            function wXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                wc(a | 0) | 0
	            }

	            function xXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                xc(a | 0) | 0
	            }

	            function yXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                yc(a | 0, b | 0, c | 0) | 0
	            }

	            function zXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                zc(a | 0, b | 0) | 0
	            }

	            function AXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Ac(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0)
	            }

	            function BXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Bc(a | 0, b | 0, c | 0, d | 0)
	            }

	            function CXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Cc(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0, g | 0)
	            }

	            function DXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Dc(a | 0, b | 0, c | 0, d | 0)
	            }

	            function EXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Ec(a | 0, b | 0, c | 0, d | 0, e | 0)
	            }

	            function FXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Fc(a | 0, b | 0)
	            }

	            function GXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Gc(a | 0)
	            }

	            function HXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Hc(a | 0)
	            }

	            function IXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Wc(a | 0, b | 0, c | 0)
	            }

	            function JXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Xc(a | 0, b | 0)
	            }

	            function KXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Ic(a | 0, b | 0)
	            }

	            function LXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Jc(a | 0, b | 0, c | 0)
	            }

	            function MXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Kc(a | 0, b | 0, c | 0)
	            }

	            function NXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Lc(a | 0, b | 0, c | 0)
	            }

	            function OXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Mc(a | 0, b | 0)
	            }

	            function PXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Nc(a | 0, b | 0, c | 0)
	            }

	            function QXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Oc(a | 0, b | 0, c | 0)
	            }

	            function RXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Pc(a | 0, b | 0, c | 0)
	            }

	            function SXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Qc(a | 0, b | 0) | 0
	            }

	            function TXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Rc(a | 0, b | 0, c | 0)
	            }

	            function UXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Sc(a | 0, b | 0, c | 0, d | 0)
	            }

	            function VXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Uc(a | 0, b | 0, c | 0, d | 0)
	            }

	            function WXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Xk(a | 0, b | 0, c | 0) | 0
	            }

	            function XXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                jT(a | 0)
	            }

	            function YXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                iT(a | 0) | 0
	            }

	            function ZXa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                kT(a | 0, b | 0) | 0
	            }

	            function _Xa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                my(a | 0) | 0
	            }

	            function $Xa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Td(a | 0, b | 0, c | 0)
	            }

	            function aYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                SP(a | 0, b | 0, c | 0, d | 0)
	            }

	            function bYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                PP(a | 0) | 0
	            }

	            function cYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                QP(a | 0) | 0
	            }

	            function dYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                RP(a | 0) | 0
	            }

	            function eYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                UP(a | 0, b | 0, c | 0) | 0
	            }

	            function fYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                VP(a | 0, b | 0) | 0
	            }

	            function gYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                XP(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0)
	            }

	            function hYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                _P(a | 0, b | 0, c | 0, d | 0)
	            }

	            function iYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                YP(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0, g | 0)
	            }

	            function jYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                ZP(a | 0, b | 0, c | 0, d | 0)
	            }

	            function kYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                $P(a | 0, b | 0, c | 0, d | 0, e | 0)
	            }

	            function lYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                aQ(a | 0, b | 0)
	            }

	            function mYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                bQ(a | 0)
	            }

	            function nYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                cQ(a | 0)
	            }

	            function oYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                dQ(a | 0, b | 0, c | 0)
	            }

	            function pYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                eQ(a | 0, b | 0)
	            }

	            function qYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                hQ(a | 0, b | 0)
	            }

	            function rYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                iQ(a | 0, b | 0, c | 0)
	            }

	            function sYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                kQ(a | 0, b | 0, c | 0)
	            }

	            function tYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                lQ(a | 0, b | 0)
	            }

	            function uYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                $d(a | 0, b | 0, c | 0)
	            }

	            function vYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                _d(a | 0, b | 0, c | 0)
	            }

	            function wYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                WP(a | 0, b | 0) | 0
	            }

	            function xYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                mQ(a | 0, b | 0, c | 0)
	            }

	            function yYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                TP(a | 0, b | 0, c | 0, d | 0)
	            }

	            function zYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                LP(a | 0) | 0
	            }

	            function AYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                MP(a | 0) | 0
	            }

	            function BYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                NP(a | 0) | 0
	            }

	            function CYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                OP(a | 0) | 0
	            }

	            function DYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                jQ(a | 0, b | 0, c | 0)
	            }

	            function EYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                NI(a | 0) | 0
	            }

	            function FYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                OI(a | 0) | 0
	            }

	            function GYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                PI(a | 0) | 0
	            }

	            function HYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                QI(a | 0) | 0
	            }

	            function IYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                RI(a | 0) | 0
	            }

	            function JYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                SI(a | 0) | 0
	            }

	            function KYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                TI(a | 0) | 0
	            }

	            function LYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                UI(a | 0) | 0
	            }

	            function MYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                VI(a | 0) | 0
	            }

	            function NYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                WI(a | 0) | 0
	            }

	            function OYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                XI(a | 0) | 0
	            }

	            function PYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                YI(a | 0) | 0
	            }

	            function QYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                ZI(a | 0) | 0
	            }

	            function RYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                _I(a | 0) | 0
	            }

	            function SYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                $I(a | 0) | 0
	            }

	            function TYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                aJ(a | 0) | 0
	            }

	            function UYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                bJ(a | 0) | 0
	            }

	            function VYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                cJ(a | 0) | 0
	            }

	            function WYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                dJ(a | 0) | 0
	            }

	            function XYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                eJ(a | 0) | 0
	            }

	            function YYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                fJ(a | 0) | 0
	            }

	            function ZYa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                gJ(a | 0) | 0
	            }

	            function _Ya(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                hJ(a | 0) | 0
	            }

	            function $Ya(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                iJ(a | 0) | 0
	            }

	            function aZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                jJ(a | 0) | 0
	            }

	            function bZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                kJ(a | 0) | 0
	            }

	            function cZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                lJ(a | 0) | 0
	            }

	            function dZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                mJ(a | 0) | 0
	            }

	            function eZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                nJ(a | 0) | 0
	            }

	            function fZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                oJ(a | 0) | 0
	            }

	            function gZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                pJ(a | 0) | 0
	            }

	            function hZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                qJ(a | 0) | 0
	            }

	            function iZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                rJ(a | 0) | 0
	            }

	            function jZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                sJ(a | 0) | 0
	            }

	            function kZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                tJ(a | 0) | 0
	            }

	            function lZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                uJ(a | 0) | 0
	            }

	            function mZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                vJ(a | 0) | 0
	            }

	            function nZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                wJ(a | 0) | 0
	            }

	            function oZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                xJ(a | 0) | 0
	            }

	            function pZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                yJ(a | 0) | 0
	            }

	            function qZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                zJ(a | 0) | 0
	            }

	            function rZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                AJ(a | 0) | 0
	            }

	            function sZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                BJ(a | 0) | 0
	            }

	            function tZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                CJ(a | 0) | 0
	            }

	            function uZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                DJ(a | 0) | 0
	            }

	            function vZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                EJ(a | 0) | 0
	            }

	            function wZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                FJ(a | 0) | 0
	            }

	            function xZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                GJ(a | 0) | 0
	            }

	            function yZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                HJ(a | 0) | 0
	            }

	            function zZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                IJ(a | 0) | 0
	            }

	            function AZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                JJ(a | 0) | 0
	            }

	            function BZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                KJ(a | 0) | 0
	            }

	            function CZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                LJ(a | 0) | 0
	            }

	            function DZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                MJ(a | 0) | 0
	            }

	            function EZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                NJ(a | 0) | 0
	            }

	            function FZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                OJ(a | 0) | 0
	            }

	            function GZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                PJ(a | 0) | 0
	            }

	            function HZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                QJ(a | 0) | 0
	            }

	            function IZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                RJ(a | 0) | 0
	            }

	            function JZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                SJ(a | 0) | 0
	            }

	            function KZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                TJ(a | 0) | 0
	            }

	            function LZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                UJ(a | 0) | 0
	            }

	            function MZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                VJ(a | 0) | 0
	            }

	            function NZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                WJ(a | 0) | 0
	            }

	            function OZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                XJ(a | 0) | 0
	            }

	            function PZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                YJ(a | 0) | 0
	            }

	            function QZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                ZJ(a | 0) | 0
	            }

	            function RZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                _J(a | 0) | 0
	            }

	            function SZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                $J(a | 0) | 0
	            }

	            function TZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                aK(a | 0) | 0
	            }

	            function UZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                bK(a | 0) | 0
	            }

	            function VZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                cK(a | 0) | 0
	            }

	            function WZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                dK(a | 0) | 0
	            }

	            function XZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                eK(a | 0) | 0
	            }

	            function YZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                fK(a | 0) | 0
	            }

	            function ZZa(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                gK(a | 0) | 0
	            }

	            function _Za(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                hK(a | 0) | 0
	            }

	            function $Za(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                iK(a | 0) | 0
	            }

	            function a_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                jK(a | 0) | 0
	            }

	            function b_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                kK(a | 0) | 0
	            }

	            function c_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                lK(a | 0) | 0
	            }

	            function d_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                mK(a | 0) | 0
	            }

	            function e_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                nK(a | 0) | 0
	            }

	            function f_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                oK(a | 0) | 0
	            }

	            function g_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                pK(a | 0) | 0
	            }

	            function h_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                qK(a | 0) | 0
	            }

	            function i_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                rK(a | 0) | 0
	            }

	            function j_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                sK(a | 0) | 0
	            }

	            function k_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                tK(a | 0) | 0
	            }

	            function l_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                uK(a | 0) | 0
	            }

	            function m_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                vK(a | 0) | 0
	            }

	            function n_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                wK(a | 0) | 0
	            }

	            function o_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                xK(a | 0) | 0
	            }

	            function p_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                yK(a | 0) | 0
	            }

	            function q_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                zK(a | 0) | 0
	            }

	            function r_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                AK(a | 0) | 0
	            }

	            function s_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                BK(a | 0) | 0
	            }

	            function t_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                CK(a | 0) | 0
	            }

	            function u_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                DK(a | 0) | 0
	            }

	            function v_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                EK(a | 0) | 0
	            }

	            function w_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                FK(a | 0) | 0
	            }

	            function x_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                GK(a | 0) | 0
	            }

	            function y_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                HK(a | 0) | 0
	            }

	            function z_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                IK(a | 0) | 0
	            }

	            function A_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                JK(a | 0) | 0
	            }

	            function B_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                KK(a | 0) | 0
	            }

	            function C_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                LK(a | 0) | 0
	            }

	            function D_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                MK(a | 0) | 0
	            }

	            function E_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                NK(a | 0) | 0
	            }

	            function F_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                OK(a | 0) | 0
	            }

	            function G_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                PK(a | 0) | 0
	            }

	            function H_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                QK(a | 0) | 0
	            }

	            function I_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                RK(a | 0) | 0
	            }

	            function J_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                SK(a | 0) | 0
	            }

	            function K_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                TK(a | 0) | 0
	            }

	            function L_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                UK(a | 0) | 0
	            }

	            function M_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                VK(a | 0) | 0
	            }

	            function N_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                WK(a | 0) | 0
	            }

	            function O_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                XK(a | 0) | 0
	            }

	            function P_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                YK(a | 0) | 0
	            }

	            function Q_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                ZK(a | 0) | 0
	            }

	            function R_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                _K(a | 0) | 0
	            }

	            function S_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                $K(a | 0) | 0
	            }

	            function T_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                aL(a | 0) | 0
	            }

	            function U_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                bL(a | 0) | 0
	            }

	            function V_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                cL(a | 0) | 0
	            }

	            function W_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                dL(a | 0) | 0
	            }

	            function X_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                eL(a | 0) | 0
	            }

	            function Y_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                RT(a | 0, b | 0, c | 0) | 0
	            }

	            function Z_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Vb(a | 0)
	            }

	            function __a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Wb(a | 0) | 0
	            }

	            function $_a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Xb(a | 0, b | 0) | 0
	            }

	            function a$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Yb(a | 0) | 0
	            }

	            function b$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Wk(a | 0, b | 0, c | 0) | 0
	            }

	            function c$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                _b(a | 0)
	            }

	            function d$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                $b(a | 0)
	            }

	            function e$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                ac(a | 0, b | 0, c | 0) | 0
	            }

	            function f$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Ka(a | 0, b | 0, c | 0) | 0
	            }

	            function g$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                gc(a | 0, b | 0, c | 0) | 0
	            }

	            function h$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                hc(a | 0)
	            }

	            function i$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                ic(a | 0, b | 0, c | 0)
	            }

	            function j$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                jc(a | 0, b | 0, c | 0)
	            }

	            function k$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                kc(a | 0, b | 0, c | 0)
	            }

	            function l$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                lc(a | 0, b | 0, c | 0)
	            }

	            function m$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                nc(a | 0) | 0
	            }

	            function n$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                md(a | 0, b | 0)
	            }

	            function o$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                nd(a | 0) | 0
	            }

	            function p$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Kd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function q$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Ld(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function r$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Md(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function s$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Nd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function t$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Od(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function u$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Pd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function v$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                qd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function w$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                rd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function x$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Qd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function y$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Rd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function z$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                fo(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function A$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                ae(a | 0, b | 0, c | 0)
	            }

	            function B$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                be(a | 0, b | 0, c | 0)
	            }

	            function C$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                tg(a | 0)
	            }

	            function D$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                mk() | 0
	            }

	            function E$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                sh(a | 0, b | 0, c | 0, d | 0, e | 0)
	            }

	            function F$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                gk(a | 0, b | 0, c | 0, d | 0, e | 0)
	            }

	            function G$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                nk(a | 0) | 0
	            }

	            function H$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                ok(a | 0) | 0
	            }

	            function I$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                pk(a | 0, b | 0, c | 0) | 0
	            }

	            function J$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                qk(a | 0) | 0
	            }

	            function K$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                _k(a | 0) | 0
	            }

	            function L$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                $k(a | 0, b | 0, c | 0) | 0
	            }

	            function M$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                bl(a | 0) | 0
	            }

	            function N$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                cl(a | 0, b | 0, c | 0) | 0
	            }

	            function O$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                dl(a | 0) | 0
	            }

	            function P$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                el(a | 0, b | 0, c | 0) | 0
	            }

	            function Q$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                fl(a | 0, b | 0, c | 0) | 0
	            }

	            function R$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                gl(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function S$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                nn(a | 0)
	            }

	            function T$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                on(a | 0) | 0
	            }

	            function U$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                sn(a | 0)
	            }

	            function V$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                vn(a | 0) | 0
	            }

	            function W$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                xn(a | 0)
	            }

	            function X$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                yn(a | 0) | 0
	            }

	            function Y$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                zn(a | 0, b | 0)
	            }

	            function Z$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                An(a | 0)
	            }

	            function _$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Bn(a | 0)
	            }

	            function $$a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Cn(a | 0, b | 0) | 0
	            }

	            function a0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Dn(a | 0)
	            }

	            function b0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                In(a | 0, b | 0, c | 0)
	            }

	            function c0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Rn(a | 0, b | 0, c | 0)
	            }

	            function d0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Sn(a | 0, b | 0, c | 0)
	            }

	            function e0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Tn(a | 0, b | 0, c | 0)
	            }

	            function f0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Un(a | 0, b | 0, c | 0)
	            }

	            function g0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                _n(a | 0, b | 0) | 0
	            }

	            function h0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                tq(a | 0, b | 0)
	            }

	            function i0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Qq(a | 0)
	            }

	            function j0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Bs(a | 0, b | 0)
	            }

	            function k0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Is(a | 0, b | 0)
	            }

	            function l0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                ns(a | 0, b | 0)
	            }

	            function m0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                ts(a | 0, b | 0)
	            }

	            function n0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                us(a | 0, b | 0)
	            }

	            function o0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                os(a | 0, b | 0)
	            }

	            function p0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Es(a | 0, b | 0)
	            }

	            function q0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Hs(a | 0, b | 0)
	            }

	            function r0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                ls(a | 0, b | 0)
	            }

	            function s0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Fs(a | 0, b | 0)
	            }

	            function t0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                ps(a | 0, b | 0)
	            }

	            function u0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Cs(a | 0, b | 0)
	            }

	            function v0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                nt(a | 0, b | 0)
	            }

	            function w0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                qs(a | 0, b | 0)
	            }

	            function x0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                zs(a | 0, b | 0)
	            }

	            function y0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Tr(a | 0, b | 0)
	            }

	            function z0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                ms(a | 0, b | 0)
	            }

	            function A0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Js(a | 0, b | 0)
	            }

	            function B0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                rs(a | 0, b | 0)
	            }

	            function C0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                ss(a | 0, b | 0)
	            }

	            function D0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                vs(a | 0, b | 0)
	            }

	            function E0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                ws(a | 0, b | 0)
	            }

	            function F0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                xs(a | 0, b | 0)
	            }

	            function G0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                ys(a | 0, b | 0)
	            }

	            function H0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Gs(a | 0, b | 0)
	            }

	            function I0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Ds(a | 0, b | 0)
	            }

	            function J0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                As(a | 0, b | 0)
	            }

	            function K0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                ot(a | 0, b | 0)
	            }

	            function L0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                uu(a | 0, b | 0, c | 0) | 0
	            }

	            function M0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                ds(a | 0, b | 0) | 0
	            }

	            function N0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                es(a | 0, b | 0) | 0
	            }

	            function O0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                js(a | 0, b | 0) | 0
	            }

	            function P0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                vu(a | 0, b | 0, c | 0) | 0
	            }

	            function Q0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                wu(a | 0, b | 0) | 0
	            }

	            function R0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                $r(a | 0, b | 0) | 0
	            }

	            function S0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                as(a | 0, b | 0) | 0
	            }

	            function T0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                bs(a | 0, b | 0) | 0
	            }

	            function U0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                hs(a | 0, b | 0) | 0
	            }

	            function V0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                fs(a | 0, b | 0) | 0
	            }

	            function W0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                is(a | 0, b | 0) | 0
	            }

	            function X0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                cs(a | 0, b | 0) | 0
	            }

	            function Y0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                xu(a | 0, b | 0) | 0
	            }

	            function Z0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                gs(a | 0, b | 0) | 0
	            }

	            function _0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                _r(a | 0, b | 0) | 0
	            }

	            function $0a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                dr(a | 0, b | 0) | 0
	            }

	            function a1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                jv(a | 0, b | 0)
	            }

	            function b1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                pv(a | 0, b | 0)
	            }

	            function c1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                qv(a | 0, b | 0)
	            }

	            function d1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                rv(a | 0, b | 0)
	            }

	            function e1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                sv(a | 0, b | 0)
	            }

	            function f1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                tv(a | 0, b | 0)
	            }

	            function g1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                uv(a | 0, b | 0)
	            }

	            function h1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                vv(a | 0, b | 0)
	            }

	            function i1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                tw(a | 0, b | 0, c | 0)
	            }

	            function j1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Mw(a | 0)
	            }

	            function k1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Yw(a | 0)
	            }

	            function l1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                Kx(a | 0, b | 0, c | 0) | 0
	            }

	            function m1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                $x(a | 0, b | 0) | 0
	            }

	            function n1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                dy(a | 0, b | 0) | 0
	            }

	            function o1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                fy(a | 0, b | 0) | 0
	            }

	            function p1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                jy(a | 0, b | 0) | 0
	            }

	            function q1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                qB(a | 0)
	            }

	            function r1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                MB(a | 0, b | 0, c | 0, d | 0)
	            }

	            function s1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                NB(a | 0, b | 0, c | 0)
	            }

	            function t1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                OB(a | 0, b | 0, c | 0)
	            }

	            function u1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                PB(a | 0, b | 0)
	            }

	            function v1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                QB(a | 0, b | 0, c | 0, d | 0)
	            }

	            function w1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                RB(a | 0) | 0
	            }

	            function x1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                SB(a | 0) | 0
	            }

	            function y1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                TB(a | 0) | 0
	            }

	            function z1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                UB(a | 0, b | 0, c | 0) | 0
	            }

	            function A1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                VB(a | 0, b | 0) | 0
	            }

	            function B1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                WB(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0)
	            }

	            function C1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                XB(a | 0, b | 0, c | 0, d | 0)
	            }

	            function D1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                YB(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0, g | 0)
	            }

	            function E1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                ZB(a | 0, b | 0, c | 0, d | 0)
	            }

	            function F1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                _B(a | 0, b | 0, c | 0, d | 0, e | 0)
	            }

	            function G1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                $B(a | 0, b | 0)
	            }

	            function H1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                aC(a | 0)
	            }

	            function I1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                bC(a | 0)
	            }

	            function J1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                cC(a | 0, b | 0, c | 0)
	            }

	            function K1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                dC(a | 0, b | 0)
	            }

	            function L1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                eC(a | 0, b | 0, c | 0)
	            }

	            function M1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                fC(a | 0, b | 0, c | 0)
	            }

	            function N1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                gC(a | 0, b | 0, c | 0)
	            }

	            function O1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                hC(a | 0, b | 0) | 0
	            }

	            function P1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                iC(a | 0, b | 0, c | 0, d | 0)
	            }

	            function Q1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                jC(a | 0, b | 0, c | 0)
	            }

	            function R1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                kC(a | 0, b | 0, c | 0)
	            }

	            function S1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                lC(a | 0, b | 0, c | 0)
	            }

	            function T1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                mC(a | 0, b | 0)
	            }

	            function U1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                oC(a | 0, b | 0, c | 0, d | 0)
	            }

	            function V1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                rC(a | 0, b | 0, c | 0) | 0
	            }

	            function W1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                uC(a | 0)
	            }

	            function X1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                AD(a | 0, b | 0)
	            }

	            function Y1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                lF(a | 0, b | 0, c | 0, d | 0)
	            }

	            function Z1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                uF(a | 0, b | 0)
	            }

	            function _1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                VA(a | 0)
	            }

	            function $1a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                wM(a | 0, b | 0, c | 0)
	            }

	            function a2a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                xM(a | 0, b | 0)
	            }

	            function b2a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                zM(a | 0, b | 0, c | 0, d | 0)
	            }

	            function c2a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                AM(a | 0, b | 0, c | 0)
	            }

	            function d2a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                BM(a | 0, b | 0, c | 0)
	            }

	            function e2a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                DM(a | 0, b | 0, c | 0)
	            }

	            function f2a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                EM(a | 0, b | 0, c | 0)
	            }

	            function g2a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                GM(a | 0, b | 0, c | 0) | 0
	            }

	            function h2a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                FM(a | 0, b | 0)
	            }

	            function i2a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                UM(a | 0)
	            }

	            function j2a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                nN(a | 0, b | 0) | 0
	            }

	            function k2a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                oN(a | 0, b | 0, c | 0, d | 0, e | 0) | 0
	            }

	            function l2a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                pN(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0, g | 0) | 0
	            }

	            function m2a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                qN(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0) | 0
	            }

	            function n2a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                rN(a | 0, b | 0)
	            }

	            function o2a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                tN(a | 0, b | 0) | 0
	            }

	            function p2a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                uN(a | 0, b | 0, c | 0, d | 0, e | 0) | 0
	            }

	            function q2a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                vN(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0, g | 0) | 0
	            }

	            function r2a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                wN(a | 0, b | 0)
	            }

	            function s2a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                CN(a | 0, b | 0, c | 0)
	            }

	            function t2a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                GN(a | 0, b | 0, c | 0, d | 0)
	            }

	            function u2a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                vO(a | 0, b | 0, c | 0)
	            }

	            function v2a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                wO(a | 0, b | 0, c | 0)
	            }

	            function w2a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                fP(a | 0, b | 0, c | 0, d | 0)
	            }

	            function x2a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                sP(a | 0, b | 0, c | 0)
	            }

	            function y2a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                gQ(a | 0, b | 0, c | 0, d | 0)
	            }

	            function z2a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                WR(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function A2a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                QS(a | 0, b | 0) | 0
	            }

	            function B2a(a, b, c, d, e, f, g, h, i) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                g = g | 0;
	                h = h | 0;
	                i = i | 0;
	                hT(a | 0, b | 0, c | 0) | 0
	            }

	            function C2a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                da(11);
	                return 0
	            }

	            function D2a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function E2a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return vc(a | 0) | 0
	            }

	            function F2a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return wc(a | 0) | 0
	            }

	            function G2a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return xc(a | 0) | 0
	            }

	            function H2a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return yc(a | 0, b | 0, c | 0) | 0
	            }

	            function I2a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return zc(a | 0, b | 0) | 0
	            }

	            function J2a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function K2a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function L2a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function M2a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function N2a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function O2a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function P2a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function Q2a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function R2a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function S2a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function T2a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function U2a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function V2a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function W2a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function X2a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function Y2a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function Z2a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function _2a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function $2a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return Qc(a | 0, b | 0) | 0
	            }

	            function a3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function b3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function c3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function d3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function e3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return Xk(a | 0, b | 0, c | 0) | 0
	            }

	            function f3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function g3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return iT(a | 0) | 0
	            }

	            function h3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return kT(a | 0, b | 0) | 0
	            }

	            function i3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return my(a | 0) | 0
	            }

	            function j3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function k3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function l3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return PP(a | 0) | 0
	            }

	            function m3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return QP(a | 0) | 0
	            }

	            function n3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return RP(a | 0) | 0
	            }

	            function o3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return UP(a | 0, b | 0, c | 0) | 0
	            }

	            function p3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return VP(a | 0, b | 0) | 0
	            }

	            function q3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function r3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function s3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function t3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function u3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function v3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function w3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function x3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function y3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function z3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function A3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function B3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function C3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function D3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function E3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function F3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function G3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return WP(a | 0, b | 0) | 0
	            }

	            function H3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function I3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function J3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return LP(a | 0) | 0
	            }

	            function K3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return MP(a | 0) | 0
	            }

	            function L3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return NP(a | 0) | 0
	            }

	            function M3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return OP(a | 0) | 0
	            }

	            function N3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function O3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return NI(a | 0) | 0
	            }

	            function P3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return OI(a | 0) | 0
	            }

	            function Q3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return PI(a | 0) | 0
	            }

	            function R3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return QI(a | 0) | 0
	            }

	            function S3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return RI(a | 0) | 0
	            }

	            function T3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return SI(a | 0) | 0
	            }

	            function U3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return TI(a | 0) | 0
	            }

	            function V3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return UI(a | 0) | 0
	            }

	            function W3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return VI(a | 0) | 0
	            }

	            function X3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return WI(a | 0) | 0
	            }

	            function Y3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return XI(a | 0) | 0
	            }

	            function Z3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return YI(a | 0) | 0
	            }

	            function _3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return ZI(a | 0) | 0
	            }

	            function $3a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return _I(a | 0) | 0
	            }

	            function a4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return $I(a | 0) | 0
	            }

	            function b4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return aJ(a | 0) | 0
	            }

	            function c4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return bJ(a | 0) | 0
	            }

	            function d4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return cJ(a | 0) | 0
	            }

	            function e4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return dJ(a | 0) | 0
	            }

	            function f4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return eJ(a | 0) | 0
	            }

	            function g4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return fJ(a | 0) | 0
	            }

	            function h4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return gJ(a | 0) | 0
	            }

	            function i4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return hJ(a | 0) | 0
	            }

	            function j4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return iJ(a | 0) | 0
	            }

	            function k4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return jJ(a | 0) | 0
	            }

	            function l4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return kJ(a | 0) | 0
	            }

	            function m4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return lJ(a | 0) | 0
	            }

	            function n4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return mJ(a | 0) | 0
	            }

	            function o4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return nJ(a | 0) | 0
	            }

	            function p4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return oJ(a | 0) | 0
	            }

	            function q4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return pJ(a | 0) | 0
	            }

	            function r4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return qJ(a | 0) | 0
	            }

	            function s4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return rJ(a | 0) | 0
	            }

	            function t4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return sJ(a | 0) | 0
	            }

	            function u4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return tJ(a | 0) | 0
	            }

	            function v4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return uJ(a | 0) | 0
	            }

	            function w4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return vJ(a | 0) | 0
	            }

	            function x4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return wJ(a | 0) | 0
	            }

	            function y4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return xJ(a | 0) | 0
	            }

	            function z4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return yJ(a | 0) | 0
	            }

	            function A4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return zJ(a | 0) | 0
	            }

	            function B4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return AJ(a | 0) | 0
	            }

	            function C4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return BJ(a | 0) | 0
	            }

	            function D4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return CJ(a | 0) | 0
	            }

	            function E4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return DJ(a | 0) | 0
	            }

	            function F4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return EJ(a | 0) | 0
	            }

	            function G4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return FJ(a | 0) | 0
	            }

	            function H4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return GJ(a | 0) | 0
	            }

	            function I4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return HJ(a | 0) | 0
	            }

	            function J4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return IJ(a | 0) | 0
	            }

	            function K4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return JJ(a | 0) | 0
	            }

	            function L4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return KJ(a | 0) | 0
	            }

	            function M4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return LJ(a | 0) | 0
	            }

	            function N4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return MJ(a | 0) | 0
	            }

	            function O4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return NJ(a | 0) | 0
	            }

	            function P4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return OJ(a | 0) | 0
	            }

	            function Q4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return PJ(a | 0) | 0
	            }

	            function R4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return QJ(a | 0) | 0
	            }

	            function S4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return RJ(a | 0) | 0
	            }

	            function T4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return SJ(a | 0) | 0
	            }

	            function U4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return TJ(a | 0) | 0
	            }

	            function V4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return UJ(a | 0) | 0
	            }

	            function W4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return VJ(a | 0) | 0
	            }

	            function X4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return WJ(a | 0) | 0
	            }

	            function Y4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return XJ(a | 0) | 0
	            }

	            function Z4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return YJ(a | 0) | 0
	            }

	            function _4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return ZJ(a | 0) | 0
	            }

	            function $4a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return _J(a | 0) | 0
	            }

	            function a5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return $J(a | 0) | 0
	            }

	            function b5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return aK(a | 0) | 0
	            }

	            function c5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return bK(a | 0) | 0
	            }

	            function d5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return cK(a | 0) | 0
	            }

	            function e5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return dK(a | 0) | 0
	            }

	            function f5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return eK(a | 0) | 0
	            }

	            function g5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return fK(a | 0) | 0
	            }

	            function h5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return gK(a | 0) | 0
	            }

	            function i5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return hK(a | 0) | 0
	            }

	            function j5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return iK(a | 0) | 0
	            }

	            function k5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return jK(a | 0) | 0
	            }

	            function l5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return kK(a | 0) | 0
	            }

	            function m5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return lK(a | 0) | 0
	            }

	            function n5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return mK(a | 0) | 0
	            }

	            function o5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return nK(a | 0) | 0
	            }

	            function p5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return oK(a | 0) | 0
	            }

	            function q5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return pK(a | 0) | 0
	            }

	            function r5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return qK(a | 0) | 0
	            }

	            function s5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return rK(a | 0) | 0
	            }

	            function t5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return sK(a | 0) | 0
	            }

	            function u5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return tK(a | 0) | 0
	            }

	            function v5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return uK(a | 0) | 0
	            }

	            function w5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return vK(a | 0) | 0
	            }

	            function x5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return wK(a | 0) | 0
	            }

	            function y5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return xK(a | 0) | 0
	            }

	            function z5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return yK(a | 0) | 0
	            }

	            function A5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return zK(a | 0) | 0
	            }

	            function B5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return AK(a | 0) | 0
	            }

	            function C5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return BK(a | 0) | 0
	            }

	            function D5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return CK(a | 0) | 0
	            }

	            function E5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return DK(a | 0) | 0
	            }

	            function F5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return EK(a | 0) | 0
	            }

	            function G5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return FK(a | 0) | 0
	            }

	            function H5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return GK(a | 0) | 0
	            }

	            function I5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return HK(a | 0) | 0
	            }

	            function J5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return IK(a | 0) | 0
	            }

	            function K5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return JK(a | 0) | 0
	            }

	            function L5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return KK(a | 0) | 0
	            }

	            function M5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return LK(a | 0) | 0
	            }

	            function N5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return MK(a | 0) | 0
	            }

	            function O5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return NK(a | 0) | 0
	            }

	            function P5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return OK(a | 0) | 0
	            }

	            function Q5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return PK(a | 0) | 0
	            }

	            function R5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return QK(a | 0) | 0
	            }

	            function S5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return RK(a | 0) | 0
	            }

	            function T5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return SK(a | 0) | 0
	            }

	            function U5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return TK(a | 0) | 0
	            }

	            function V5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return UK(a | 0) | 0
	            }

	            function W5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return VK(a | 0) | 0
	            }

	            function X5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return WK(a | 0) | 0
	            }

	            function Y5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return XK(a | 0) | 0
	            }

	            function Z5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return YK(a | 0) | 0
	            }

	            function _5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return ZK(a | 0) | 0
	            }

	            function $5a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return _K(a | 0) | 0
	            }

	            function a6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return $K(a | 0) | 0
	            }

	            function b6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return aL(a | 0) | 0
	            }

	            function c6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return bL(a | 0) | 0
	            }

	            function d6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return cL(a | 0) | 0
	            }

	            function e6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return dL(a | 0) | 0
	            }

	            function f6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return eL(a | 0) | 0
	            }

	            function g6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return RT(a | 0, b | 0, c | 0) | 0
	            }

	            function h6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function i6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return Wb(a | 0) | 0
	            }

	            function j6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return Xb(a | 0, b | 0) | 0
	            }

	            function k6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return Yb(a | 0) | 0
	            }

	            function l6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return Wk(a | 0, b | 0, c | 0) | 0
	            }

	            function m6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function n6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function o6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return ac(a | 0, b | 0, c | 0) | 0
	            }

	            function p6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return Ka(a | 0, b | 0, c | 0) | 0
	            }

	            function q6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return gc(a | 0, b | 0, c | 0) | 0
	            }

	            function r6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function s6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function t6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function u6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function v6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function w6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return nc(a | 0) | 0
	            }

	            function x6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function y6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return nd(a | 0) | 0
	            }

	            function z6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function A6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function B6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function C6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return mk() | 0
	            }

	            function D6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function E6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function F6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return nk(a | 0) | 0
	            }

	            function G6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return ok(a | 0) | 0
	            }

	            function H6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return pk(a | 0, b | 0, c | 0) | 0
	            }

	            function I6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return qk(a | 0) | 0
	            }

	            function J6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return _k(a | 0) | 0
	            }

	            function K6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return $k(a | 0, b | 0, c | 0) | 0
	            }

	            function L6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return bl(a | 0) | 0
	            }

	            function M6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return cl(a | 0, b | 0, c | 0) | 0
	            }

	            function N6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return dl(a | 0) | 0
	            }

	            function O6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return el(a | 0, b | 0, c | 0) | 0
	            }

	            function P6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return fl(a | 0, b | 0, c | 0) | 0
	            }

	            function Q6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function R6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return on(a | 0) | 0
	            }

	            function S6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function T6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return vn(a | 0) | 0
	            }

	            function U6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function V6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return yn(a | 0) | 0
	            }

	            function W6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function X6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function Y6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function Z6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return Cn(a | 0, b | 0) | 0
	            }

	            function _6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function $6a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function a7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function b7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function c7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function d7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function e7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return _n(a | 0, b | 0) | 0
	            }

	            function f7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function g7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function h7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function i7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function j7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function k7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function l7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function m7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function n7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function o7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function p7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function q7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function r7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function s7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function t7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function u7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function v7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function w7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function x7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function y7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function z7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function A7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function B7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function C7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function D7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function E7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function F7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function G7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function H7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function I7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function J7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return uu(a | 0, b | 0, c | 0) | 0
	            }

	            function K7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return ds(a | 0, b | 0) | 0
	            }

	            function L7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return es(a | 0, b | 0) | 0
	            }

	            function M7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return js(a | 0, b | 0) | 0
	            }

	            function N7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return vu(a | 0, b | 0, c | 0) | 0
	            }

	            function O7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return wu(a | 0, b | 0) | 0
	            }

	            function P7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return $r(a | 0, b | 0) | 0
	            }

	            function Q7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return as(a | 0, b | 0) | 0
	            }

	            function R7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return bs(a | 0, b | 0) | 0
	            }

	            function S7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return hs(a | 0, b | 0) | 0
	            }

	            function T7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return fs(a | 0, b | 0) | 0
	            }

	            function U7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return is(a | 0, b | 0) | 0
	            }

	            function V7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return cs(a | 0, b | 0) | 0
	            }

	            function W7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return xu(a | 0, b | 0) | 0
	            }

	            function X7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return gs(a | 0, b | 0) | 0
	            }

	            function Y7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return _r(a | 0, b | 0) | 0
	            }

	            function Z7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return dr(a | 0, b | 0) | 0
	            }

	            function _7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function $7a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function a8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function b8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function c8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function d8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function e8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function f8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function g8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function h8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function i8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function j8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return Kx(a | 0, b | 0, c | 0) | 0
	            }

	            function k8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return $x(a | 0, b | 0) | 0
	            }

	            function l8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return dy(a | 0, b | 0) | 0
	            }

	            function m8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return fy(a | 0, b | 0) | 0
	            }

	            function n8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return jy(a | 0, b | 0) | 0
	            }

	            function o8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function p8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function q8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function r8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function s8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function t8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function u8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function v8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return RB(a | 0) | 0
	            }

	            function w8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return SB(a | 0) | 0
	            }

	            function x8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return TB(a | 0) | 0
	            }

	            function y8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return UB(a | 0, b | 0, c | 0) | 0
	            }

	            function z8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return VB(a | 0, b | 0) | 0
	            }

	            function A8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function B8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function C8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function D8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function E8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function F8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function G8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function H8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function I8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function J8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function K8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function L8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function M8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function N8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return hC(a | 0, b | 0) | 0
	            }

	            function O8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function P8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function Q8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function R8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function S8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function T8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function U8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function V8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return rC(a | 0, b | 0, c | 0) | 0
	            }

	            function W8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function X8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function Y8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function Z8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function _8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function $8a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function a9a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function b9a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function c9a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function d9a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function e9a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function f9a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function g9a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function h9a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return GM(a | 0, b | 0, c | 0) | 0
	            }

	            function i9a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function j9a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function k9a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return nN(a | 0, b | 0) | 0
	            }

	            function l9a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return oN(a | 0, b | 0, c | 0, d | 0, 0) | 0
	            }

	            function m9a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return pN(a | 0, b | 0, c | 0, d | 0, 0, 0, 0) | 0
	            }

	            function n9a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return qN(a | 0, b | 0, c | 0, d | 0, 0, 0) | 0
	            }

	            function o9a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function p9a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return tN(a | 0, b | 0) | 0
	            }

	            function q9a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return uN(a | 0, b | 0, c | 0, d | 0, 0) | 0
	            }

	            function r9a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return vN(a | 0, b | 0, c | 0, d | 0, 0, 0, 0) | 0
	            }

	            function s9a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function t9a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function u9a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function v9a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function w9a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function x9a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function y9a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function z9a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function A9a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return 0
	            }

	            function B9a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return QS(a | 0, b | 0) | 0
	            }

	            function C9a(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                return hT(a | 0, b | 0, c | 0) | 0
	            }

	            function D9a(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                da(12)
	            }

	            function E9a(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                uc(a | 0, b | 0, c | 0, d | 0)
	            }

	            function F9a(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                vc(a | 0) | 0
	            }

	            function G9a(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                wc(a | 0) | 0
	            }

	            function H9a(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                xc(a | 0) | 0
	            }

	            function I9a(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                yc(a | 0, b | 0, c | 0) | 0
	            }

	            function J9a(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                zc(a | 0, b | 0) | 0
	            }

	            function K9a(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Bc(a | 0, b | 0, c | 0, d | 0)
	            }

	            function L9a(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Cc(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0, 0)
	            }

	            function M9a(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Dc(a | 0, b | 0, c | 0, d | 0)
	            }

	            function N9a(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Ec(a | 0, b | 0, c | 0, d | 0, e | 0)
	            }

	            function O9a(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Fc(a | 0, b | 0)
	            }

	            function P9a(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Gc(a | 0)
	            }

	            function Q9a(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Hc(a | 0)
	            }

	            function R9a(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Wc(a | 0, b | 0, c | 0)
	            }

	            function S9a(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Xc(a | 0, b | 0)
	            }

	            function T9a(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Ic(a | 0, b | 0)
	            }

	            function U9a(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Jc(a | 0, b | 0, c | 0)
	            }

	            function V9a(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Kc(a | 0, b | 0, c | 0)
	            }

	            function W9a(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Lc(a | 0, b | 0, c | 0)
	            }

	            function X9a(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Mc(a | 0, b | 0)
	            }

	            function Y9a(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Nc(a | 0, b | 0, c | 0)
	            }

	            function Z9a(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Oc(a | 0, b | 0, c | 0)
	            }

	            function _9a(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Pc(a | 0, b | 0, c | 0)
	            }

	            function $9a(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Qc(a | 0, b | 0) | 0
	            }

	            function aab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Rc(a | 0, b | 0, c | 0)
	            }

	            function bab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Sc(a | 0, b | 0, c | 0, d | 0)
	            }

	            function cab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Tc(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0, 0, 0, 0)
	            }

	            function dab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Uc(a | 0, b | 0, c | 0, d | 0)
	            }

	            function eab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Xk(a | 0, b | 0, c | 0) | 0
	            }

	            function fab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                jT(a | 0)
	            }

	            function gab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                iT(a | 0) | 0
	            }

	            function hab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                kT(a | 0, b | 0) | 0
	            }

	            function iab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                my(a | 0) | 0
	            }

	            function jab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Td(a | 0, b | 0, c | 0)
	            }

	            function kab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                SP(a | 0, b | 0, c | 0, d | 0)
	            }

	            function lab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                PP(a | 0) | 0
	            }

	            function mab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                QP(a | 0) | 0
	            }

	            function nab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                RP(a | 0) | 0
	            }

	            function oab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                UP(a | 0, b | 0, c | 0) | 0
	            }

	            function pab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                VP(a | 0, b | 0) | 0
	            }

	            function qab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                _P(a | 0, b | 0, c | 0, d | 0)
	            }

	            function rab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                YP(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0, 0)
	            }

	            function sab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                ZP(a | 0, b | 0, c | 0, d | 0)
	            }

	            function tab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                $P(a | 0, b | 0, c | 0, d | 0, e | 0)
	            }

	            function uab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                aQ(a | 0, b | 0)
	            }

	            function vab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                bQ(a | 0)
	            }

	            function wab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                cQ(a | 0)
	            }

	            function xab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                dQ(a | 0, b | 0, c | 0)
	            }

	            function yab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                eQ(a | 0, b | 0)
	            }

	            function zab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                hQ(a | 0, b | 0)
	            }

	            function Aab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                iQ(a | 0, b | 0, c | 0)
	            }

	            function Bab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                kQ(a | 0, b | 0, c | 0)
	            }

	            function Cab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                lQ(a | 0, b | 0)
	            }

	            function Dab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                $d(a | 0, b | 0, c | 0)
	            }

	            function Eab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                _d(a | 0, b | 0, c | 0)
	            }

	            function Fab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                WP(a | 0, b | 0) | 0
	            }

	            function Gab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                mQ(a | 0, b | 0, c | 0)
	            }

	            function Hab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                TP(a | 0, b | 0, c | 0, d | 0)
	            }

	            function Iab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                LP(a | 0) | 0
	            }

	            function Jab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                MP(a | 0) | 0
	            }

	            function Kab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                NP(a | 0) | 0
	            }

	            function Lab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                OP(a | 0) | 0
	            }

	            function Mab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                jQ(a | 0, b | 0, c | 0)
	            }

	            function Nab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                NI(a | 0) | 0
	            }

	            function Oab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                OI(a | 0) | 0
	            }

	            function Pab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                PI(a | 0) | 0
	            }

	            function Qab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                QI(a | 0) | 0
	            }

	            function Rab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                RI(a | 0) | 0
	            }

	            function Sab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                SI(a | 0) | 0
	            }

	            function Tab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                TI(a | 0) | 0
	            }

	            function Uab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                UI(a | 0) | 0
	            }

	            function Vab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                VI(a | 0) | 0
	            }

	            function Wab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                WI(a | 0) | 0
	            }

	            function Xab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                XI(a | 0) | 0
	            }

	            function Yab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                YI(a | 0) | 0
	            }

	            function Zab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                ZI(a | 0) | 0
	            }

	            function _ab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                _I(a | 0) | 0
	            }

	            function $ab(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                $I(a | 0) | 0
	            }

	            function abb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                aJ(a | 0) | 0
	            }

	            function bbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                bJ(a | 0) | 0
	            }

	            function cbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                cJ(a | 0) | 0
	            }

	            function dbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                dJ(a | 0) | 0
	            }

	            function ebb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                eJ(a | 0) | 0
	            }

	            function fbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                fJ(a | 0) | 0
	            }

	            function gbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                gJ(a | 0) | 0
	            }

	            function hbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                hJ(a | 0) | 0
	            }

	            function ibb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                iJ(a | 0) | 0
	            }

	            function jbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                jJ(a | 0) | 0
	            }

	            function kbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                kJ(a | 0) | 0
	            }

	            function lbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                lJ(a | 0) | 0
	            }

	            function mbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                mJ(a | 0) | 0
	            }

	            function nbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                nJ(a | 0) | 0
	            }

	            function obb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                oJ(a | 0) | 0
	            }

	            function pbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                pJ(a | 0) | 0
	            }

	            function qbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                qJ(a | 0) | 0
	            }

	            function rbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                rJ(a | 0) | 0
	            }

	            function sbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                sJ(a | 0) | 0
	            }

	            function tbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                tJ(a | 0) | 0
	            }

	            function ubb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                uJ(a | 0) | 0
	            }

	            function vbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                vJ(a | 0) | 0
	            }

	            function wbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                wJ(a | 0) | 0
	            }

	            function xbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                xJ(a | 0) | 0
	            }

	            function ybb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                yJ(a | 0) | 0
	            }

	            function zbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                zJ(a | 0) | 0
	            }

	            function Abb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                AJ(a | 0) | 0
	            }

	            function Bbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                BJ(a | 0) | 0
	            }

	            function Cbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                CJ(a | 0) | 0
	            }

	            function Dbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                DJ(a | 0) | 0
	            }

	            function Ebb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                EJ(a | 0) | 0
	            }

	            function Fbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                FJ(a | 0) | 0
	            }

	            function Gbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                GJ(a | 0) | 0
	            }

	            function Hbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                HJ(a | 0) | 0
	            }

	            function Ibb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                IJ(a | 0) | 0
	            }

	            function Jbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                JJ(a | 0) | 0
	            }

	            function Kbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                KJ(a | 0) | 0
	            }

	            function Lbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                LJ(a | 0) | 0
	            }

	            function Mbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                MJ(a | 0) | 0
	            }

	            function Nbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                NJ(a | 0) | 0
	            }

	            function Obb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                OJ(a | 0) | 0
	            }

	            function Pbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                PJ(a | 0) | 0
	            }

	            function Qbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                QJ(a | 0) | 0
	            }

	            function Rbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                RJ(a | 0) | 0
	            }

	            function Sbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                SJ(a | 0) | 0
	            }

	            function Tbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                TJ(a | 0) | 0
	            }

	            function Ubb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                UJ(a | 0) | 0
	            }

	            function Vbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                VJ(a | 0) | 0
	            }

	            function Wbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                WJ(a | 0) | 0
	            }

	            function Xbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                XJ(a | 0) | 0
	            }

	            function Ybb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                YJ(a | 0) | 0
	            }

	            function Zbb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                ZJ(a | 0) | 0
	            }

	            function _bb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                _J(a | 0) | 0
	            }

	            function $bb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                $J(a | 0) | 0
	            }

	            function acb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                aK(a | 0) | 0
	            }

	            function bcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                bK(a | 0) | 0
	            }

	            function ccb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                cK(a | 0) | 0
	            }

	            function dcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                dK(a | 0) | 0
	            }

	            function ecb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                eK(a | 0) | 0
	            }

	            function fcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                fK(a | 0) | 0
	            }

	            function gcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                gK(a | 0) | 0
	            }

	            function hcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                hK(a | 0) | 0
	            }

	            function icb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                iK(a | 0) | 0
	            }

	            function jcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                jK(a | 0) | 0
	            }

	            function kcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                kK(a | 0) | 0
	            }

	            function lcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                lK(a | 0) | 0
	            }

	            function mcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                mK(a | 0) | 0
	            }

	            function ncb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                nK(a | 0) | 0
	            }

	            function ocb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                oK(a | 0) | 0
	            }

	            function pcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                pK(a | 0) | 0
	            }

	            function qcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                qK(a | 0) | 0
	            }

	            function rcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                rK(a | 0) | 0
	            }

	            function scb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                sK(a | 0) | 0
	            }

	            function tcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                tK(a | 0) | 0
	            }

	            function ucb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                uK(a | 0) | 0
	            }

	            function vcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                vK(a | 0) | 0
	            }

	            function wcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                wK(a | 0) | 0
	            }

	            function xcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                xK(a | 0) | 0
	            }

	            function ycb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                yK(a | 0) | 0
	            }

	            function zcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                zK(a | 0) | 0
	            }

	            function Acb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                AK(a | 0) | 0
	            }

	            function Bcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                BK(a | 0) | 0
	            }

	            function Ccb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                CK(a | 0) | 0
	            }

	            function Dcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                DK(a | 0) | 0
	            }

	            function Ecb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                EK(a | 0) | 0
	            }

	            function Fcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                FK(a | 0) | 0
	            }

	            function Gcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                GK(a | 0) | 0
	            }

	            function Hcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                HK(a | 0) | 0
	            }

	            function Icb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                IK(a | 0) | 0
	            }

	            function Jcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                JK(a | 0) | 0
	            }

	            function Kcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                KK(a | 0) | 0
	            }

	            function Lcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                LK(a | 0) | 0
	            }

	            function Mcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                MK(a | 0) | 0
	            }

	            function Ncb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                NK(a | 0) | 0
	            }

	            function Ocb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                OK(a | 0) | 0
	            }

	            function Pcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                PK(a | 0) | 0
	            }

	            function Qcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                QK(a | 0) | 0
	            }

	            function Rcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                RK(a | 0) | 0
	            }

	            function Scb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                SK(a | 0) | 0
	            }

	            function Tcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                TK(a | 0) | 0
	            }

	            function Ucb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                UK(a | 0) | 0
	            }

	            function Vcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                VK(a | 0) | 0
	            }

	            function Wcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                WK(a | 0) | 0
	            }

	            function Xcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                XK(a | 0) | 0
	            }

	            function Ycb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                YK(a | 0) | 0
	            }

	            function Zcb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                ZK(a | 0) | 0
	            }

	            function _cb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                _K(a | 0) | 0
	            }

	            function $cb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                $K(a | 0) | 0
	            }

	            function adb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                aL(a | 0) | 0
	            }

	            function bdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                bL(a | 0) | 0
	            }

	            function cdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                cL(a | 0) | 0
	            }

	            function ddb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                dL(a | 0) | 0
	            }

	            function edb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                eL(a | 0) | 0
	            }

	            function fdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                RT(a | 0, b | 0, c | 0) | 0
	            }

	            function gdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Vb(a | 0)
	            }

	            function hdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Wb(a | 0) | 0
	            }

	            function idb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Xb(a | 0, b | 0) | 0
	            }

	            function jdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Yb(a | 0) | 0
	            }

	            function kdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Wk(a | 0, b | 0, c | 0) | 0
	            }

	            function ldb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                _b(a | 0)
	            }

	            function mdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                $b(a | 0)
	            }

	            function ndb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                ac(a | 0, b | 0, c | 0) | 0
	            }

	            function odb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Ka(a | 0, b | 0, c | 0) | 0
	            }

	            function pdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                gc(a | 0, b | 0, c | 0) | 0
	            }

	            function qdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                hc(a | 0)
	            }

	            function rdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                ic(a | 0, b | 0, c | 0)
	            }

	            function sdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                jc(a | 0, b | 0, c | 0)
	            }

	            function tdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                kc(a | 0, b | 0, c | 0)
	            }

	            function udb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                lc(a | 0, b | 0, c | 0)
	            }

	            function vdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                nc(a | 0) | 0
	            }

	            function wdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                md(a | 0, b | 0)
	            }

	            function xdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                nd(a | 0) | 0
	            }

	            function ydb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Kd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function zdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Ld(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Adb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Md(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Bdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Nd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Cdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Od(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Ddb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Pd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Edb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                qd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Fdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                rd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Gdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Qd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Hdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Rd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Idb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                fo(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Jdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                ae(a | 0, b | 0, c | 0)
	            }

	            function Kdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                be(a | 0, b | 0, c | 0)
	            }

	            function Ldb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                tg(a | 0)
	            }

	            function Mdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                mk() | 0
	            }

	            function Ndb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                sh(a | 0, b | 0, c | 0, d | 0, e | 0)
	            }

	            function Odb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                gk(a | 0, b | 0, c | 0, d | 0, e | 0)
	            }

	            function Pdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                nk(a | 0) | 0
	            }

	            function Qdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                ok(a | 0) | 0
	            }

	            function Rdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                pk(a | 0, b | 0, c | 0) | 0
	            }

	            function Sdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                qk(a | 0) | 0
	            }

	            function Tdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                _k(a | 0) | 0
	            }

	            function Udb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                $k(a | 0, b | 0, c | 0) | 0
	            }

	            function Vdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                bl(a | 0) | 0
	            }

	            function Wdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                cl(a | 0, b | 0, c | 0) | 0
	            }

	            function Xdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                dl(a | 0) | 0
	            }

	            function Ydb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                el(a | 0, b | 0, c | 0) | 0
	            }

	            function Zdb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                fl(a | 0, b | 0, c | 0) | 0
	            }

	            function _db(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                gl(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function $db(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                nn(a | 0)
	            }

	            function aeb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                on(a | 0) | 0
	            }

	            function beb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                sn(a | 0)
	            }

	            function ceb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                vn(a | 0) | 0
	            }

	            function deb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                xn(a | 0)
	            }

	            function eeb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                yn(a | 0) | 0
	            }

	            function feb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                zn(a | 0, b | 0)
	            }

	            function geb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                An(a | 0)
	            }

	            function heb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Bn(a | 0)
	            }

	            function ieb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Cn(a | 0, b | 0) | 0
	            }

	            function jeb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Dn(a | 0)
	            }

	            function keb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                In(a | 0, b | 0, c | 0)
	            }

	            function leb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Rn(a | 0, b | 0, c | 0)
	            }

	            function meb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Sn(a | 0, b | 0, c | 0)
	            }

	            function neb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Tn(a | 0, b | 0, c | 0)
	            }

	            function oeb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Un(a | 0, b | 0, c | 0)
	            }

	            function peb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                _n(a | 0, b | 0) | 0
	            }

	            function qeb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                tq(a | 0, b | 0)
	            }

	            function reb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Qq(a | 0)
	            }

	            function seb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Bs(a | 0, b | 0)
	            }

	            function teb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Is(a | 0, b | 0)
	            }

	            function ueb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                ns(a | 0, b | 0)
	            }

	            function veb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                ts(a | 0, b | 0)
	            }

	            function web(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                us(a | 0, b | 0)
	            }

	            function xeb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                os(a | 0, b | 0)
	            }

	            function yeb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Es(a | 0, b | 0)
	            }

	            function zeb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Hs(a | 0, b | 0)
	            }

	            function Aeb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                ls(a | 0, b | 0)
	            }

	            function Beb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Fs(a | 0, b | 0)
	            }

	            function Ceb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                ps(a | 0, b | 0)
	            }

	            function Deb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Cs(a | 0, b | 0)
	            }

	            function Eeb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                nt(a | 0, b | 0)
	            }

	            function Feb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                qs(a | 0, b | 0)
	            }

	            function Geb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                zs(a | 0, b | 0)
	            }

	            function Heb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Tr(a | 0, b | 0)
	            }

	            function Ieb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                ms(a | 0, b | 0)
	            }

	            function Jeb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Js(a | 0, b | 0)
	            }

	            function Keb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                rs(a | 0, b | 0)
	            }

	            function Leb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                ss(a | 0, b | 0)
	            }

	            function Meb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                vs(a | 0, b | 0)
	            }

	            function Neb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                ws(a | 0, b | 0)
	            }

	            function Oeb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                xs(a | 0, b | 0)
	            }

	            function Peb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                ys(a | 0, b | 0)
	            }

	            function Qeb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Gs(a | 0, b | 0)
	            }

	            function Reb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Ds(a | 0, b | 0)
	            }

	            function Seb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                As(a | 0, b | 0)
	            }

	            function Teb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                ot(a | 0, b | 0)
	            }

	            function Ueb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                uu(a | 0, b | 0, c | 0) | 0
	            }

	            function Veb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                ds(a | 0, b | 0) | 0
	            }

	            function Web(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                es(a | 0, b | 0) | 0
	            }

	            function Xeb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                js(a | 0, b | 0) | 0
	            }

	            function Yeb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                vu(a | 0, b | 0, c | 0) | 0
	            }

	            function Zeb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                wu(a | 0, b | 0) | 0
	            }

	            function _eb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                $r(a | 0, b | 0) | 0
	            }

	            function $eb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                as(a | 0, b | 0) | 0
	            }

	            function afb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                bs(a | 0, b | 0) | 0
	            }

	            function bfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                hs(a | 0, b | 0) | 0
	            }

	            function cfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                fs(a | 0, b | 0) | 0
	            }

	            function dfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                is(a | 0, b | 0) | 0
	            }

	            function efb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                cs(a | 0, b | 0) | 0
	            }

	            function ffb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                xu(a | 0, b | 0) | 0
	            }

	            function gfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                gs(a | 0, b | 0) | 0
	            }

	            function hfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                _r(a | 0, b | 0) | 0
	            }

	            function ifb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                dr(a | 0, b | 0) | 0
	            }

	            function jfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                jv(a | 0, b | 0)
	            }

	            function kfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                pv(a | 0, b | 0)
	            }

	            function lfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                qv(a | 0, b | 0)
	            }

	            function mfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                rv(a | 0, b | 0)
	            }

	            function nfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                sv(a | 0, b | 0)
	            }

	            function ofb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                tv(a | 0, b | 0)
	            }

	            function pfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                uv(a | 0, b | 0)
	            }

	            function qfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                vv(a | 0, b | 0)
	            }

	            function rfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                tw(a | 0, b | 0, c | 0)
	            }

	            function sfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Mw(a | 0)
	            }

	            function tfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Yw(a | 0)
	            }

	            function ufb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                Kx(a | 0, b | 0, c | 0) | 0
	            }

	            function vfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                $x(a | 0, b | 0) | 0
	            }

	            function wfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                dy(a | 0, b | 0) | 0
	            }

	            function xfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                fy(a | 0, b | 0) | 0
	            }

	            function yfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                jy(a | 0, b | 0) | 0
	            }

	            function zfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                qB(a | 0)
	            }

	            function Afb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                LB(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0, 0, 0, 0)
	            }

	            function Bfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                MB(a | 0, b | 0, c | 0, d | 0)
	            }

	            function Cfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                NB(a | 0, b | 0, c | 0)
	            }

	            function Dfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                OB(a | 0, b | 0, c | 0)
	            }

	            function Efb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                PB(a | 0, b | 0)
	            }

	            function Ffb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                QB(a | 0, b | 0, c | 0, d | 0)
	            }

	            function Gfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                RB(a | 0) | 0
	            }

	            function Hfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                SB(a | 0) | 0
	            }

	            function Ifb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                TB(a | 0) | 0
	            }

	            function Jfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                UB(a | 0, b | 0, c | 0) | 0
	            }

	            function Kfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                VB(a | 0, b | 0) | 0
	            }

	            function Lfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                XB(a | 0, b | 0, c | 0, d | 0)
	            }

	            function Mfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                YB(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0, 0)
	            }

	            function Nfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                ZB(a | 0, b | 0, c | 0, d | 0)
	            }

	            function Ofb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                _B(a | 0, b | 0, c | 0, d | 0, e | 0)
	            }

	            function Pfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                $B(a | 0, b | 0)
	            }

	            function Qfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                aC(a | 0)
	            }

	            function Rfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                bC(a | 0)
	            }

	            function Sfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                cC(a | 0, b | 0, c | 0)
	            }

	            function Tfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                dC(a | 0, b | 0)
	            }

	            function Ufb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                eC(a | 0, b | 0, c | 0)
	            }

	            function Vfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                fC(a | 0, b | 0, c | 0)
	            }

	            function Wfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                gC(a | 0, b | 0, c | 0)
	            }

	            function Xfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                hC(a | 0, b | 0) | 0
	            }

	            function Yfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                iC(a | 0, b | 0, c | 0, d | 0)
	            }

	            function Zfb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                jC(a | 0, b | 0, c | 0)
	            }

	            function _fb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                kC(a | 0, b | 0, c | 0)
	            }

	            function $fb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                lC(a | 0, b | 0, c | 0)
	            }

	            function agb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                mC(a | 0, b | 0)
	            }

	            function bgb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                nC(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0, 0, 0, 0)
	            }

	            function cgb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                oC(a | 0, b | 0, c | 0, d | 0)
	            }

	            function dgb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                rC(a | 0, b | 0, c | 0) | 0
	            }

	            function egb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                uC(a | 0)
	            }

	            function fgb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                AD(a | 0, b | 0)
	            }

	            function ggb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                lF(a | 0, b | 0, c | 0, d | 0)
	            }

	            function hgb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                uF(a | 0, b | 0)
	            }

	            function igb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                VA(a | 0)
	            }

	            function jgb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                wM(a | 0, b | 0, c | 0)
	            }

	            function kgb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                xM(a | 0, b | 0)
	            }

	            function lgb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                yM(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0, 0, 0, 0)
	            }

	            function mgb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                zM(a | 0, b | 0, c | 0, d | 0)
	            }

	            function ngb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                AM(a | 0, b | 0, c | 0)
	            }

	            function ogb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                BM(a | 0, b | 0, c | 0)
	            }

	            function pgb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                DM(a | 0, b | 0, c | 0)
	            }

	            function qgb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                EM(a | 0, b | 0, c | 0)
	            }

	            function rgb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                GM(a | 0, b | 0, c | 0) | 0
	            }

	            function sgb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                FM(a | 0, b | 0)
	            }

	            function tgb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                UM(a | 0)
	            }

	            function ugb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                nN(a | 0, b | 0) | 0
	            }

	            function vgb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                oN(a | 0, b | 0, c | 0, d | 0, e | 0) | 0
	            }

	            function wgb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                pN(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0, 0) | 0
	            }

	            function xgb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                qN(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0) | 0
	            }

	            function ygb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                rN(a | 0, b | 0)
	            }

	            function zgb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                tN(a | 0, b | 0) | 0
	            }

	            function Agb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                uN(a | 0, b | 0, c | 0, d | 0, e | 0) | 0
	            }

	            function Bgb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                vN(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0, 0) | 0
	            }

	            function Cgb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                wN(a | 0, b | 0)
	            }

	            function Dgb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                CN(a | 0, b | 0, c | 0)
	            }

	            function Egb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                GN(a | 0, b | 0, c | 0, d | 0)
	            }

	            function Fgb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                vO(a | 0, b | 0, c | 0)
	            }

	            function Ggb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                wO(a | 0, b | 0, c | 0)
	            }

	            function Hgb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                fP(a | 0, b | 0, c | 0, d | 0)
	            }

	            function Igb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                sP(a | 0, b | 0, c | 0)
	            }

	            function Jgb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                fQ(a | 0, b | 0, c | 0, d | 0, e | 0, f | 0, 0, 0, 0)
	            }

	            function Kgb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                gQ(a | 0, b | 0, c | 0, d | 0)
	            }

	            function Lgb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                WR(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Mgb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                QS(a | 0, b | 0) | 0
	            }

	            function Ngb(a, b, c, d, e, f) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                f = f | 0;
	                hT(a | 0, b | 0, c | 0) | 0
	            }

	            function Ogb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                da(13);
	                return 0
	            }

	            function Pgb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Qgb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return vc(a | 0) | 0
	            }

	            function Rgb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return wc(a | 0) | 0
	            }

	            function Sgb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return xc(a | 0) | 0
	            }

	            function Tgb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return yc(a | 0, b | 0, 0) | 0
	            }

	            function Ugb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Vgb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Wgb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Xgb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Ygb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Zgb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function _gb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function $gb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function ahb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function bhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function chb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function dhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function ehb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function fhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function ghb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function hhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function ihb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function jhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function khb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function lhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function mhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function nhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function ohb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return Xk(a | 0, b | 0, 0) | 0
	            }

	            function phb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function qhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return iT(a | 0) | 0
	            }

	            function rhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return my(a | 0) | 0
	            }

	            function shb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function thb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function uhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return PP(a | 0) | 0
	            }

	            function vhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return QP(a | 0) | 0
	            }

	            function whb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return RP(a | 0) | 0
	            }

	            function xhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return UP(a | 0, b | 0, 0) | 0
	            }

	            function yhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function zhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Ahb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Bhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Chb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Dhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Ehb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Fhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Ghb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Hhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Ihb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Jhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Khb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Lhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Mhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Nhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Ohb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Phb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Qhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return LP(a | 0) | 0
	            }

	            function Rhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return MP(a | 0) | 0
	            }

	            function Shb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return NP(a | 0) | 0
	            }

	            function Thb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return OP(a | 0) | 0
	            }

	            function Uhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Vhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return NI(a | 0) | 0
	            }

	            function Whb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return OI(a | 0) | 0
	            }

	            function Xhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return PI(a | 0) | 0
	            }

	            function Yhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return QI(a | 0) | 0
	            }

	            function Zhb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return RI(a | 0) | 0
	            }

	            function _hb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return SI(a | 0) | 0
	            }

	            function $hb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return TI(a | 0) | 0
	            }

	            function aib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return UI(a | 0) | 0
	            }

	            function bib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return VI(a | 0) | 0
	            }

	            function cib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return WI(a | 0) | 0
	            }

	            function dib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return XI(a | 0) | 0
	            }

	            function eib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return YI(a | 0) | 0
	            }

	            function fib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return ZI(a | 0) | 0
	            }

	            function gib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return _I(a | 0) | 0
	            }

	            function hib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return $I(a | 0) | 0
	            }

	            function iib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return aJ(a | 0) | 0
	            }

	            function jib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return bJ(a | 0) | 0
	            }

	            function kib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return cJ(a | 0) | 0
	            }

	            function lib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return dJ(a | 0) | 0
	            }

	            function mib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return eJ(a | 0) | 0
	            }

	            function nib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return fJ(a | 0) | 0
	            }

	            function oib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return gJ(a | 0) | 0
	            }

	            function pib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return hJ(a | 0) | 0
	            }

	            function qib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return iJ(a | 0) | 0
	            }

	            function rib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return jJ(a | 0) | 0
	            }

	            function sib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return kJ(a | 0) | 0
	            }

	            function tib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return lJ(a | 0) | 0
	            }

	            function uib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return mJ(a | 0) | 0
	            }

	            function vib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return nJ(a | 0) | 0
	            }

	            function wib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return oJ(a | 0) | 0
	            }

	            function xib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return pJ(a | 0) | 0
	            }

	            function yib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return qJ(a | 0) | 0
	            }

	            function zib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return rJ(a | 0) | 0
	            }

	            function Aib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return sJ(a | 0) | 0
	            }

	            function Bib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return tJ(a | 0) | 0
	            }

	            function Cib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return uJ(a | 0) | 0
	            }

	            function Dib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return vJ(a | 0) | 0
	            }

	            function Eib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return wJ(a | 0) | 0
	            }

	            function Fib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return xJ(a | 0) | 0
	            }

	            function Gib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return yJ(a | 0) | 0
	            }

	            function Hib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return zJ(a | 0) | 0
	            }

	            function Iib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return AJ(a | 0) | 0
	            }

	            function Jib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return BJ(a | 0) | 0
	            }

	            function Kib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return CJ(a | 0) | 0
	            }

	            function Lib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return DJ(a | 0) | 0
	            }

	            function Mib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return EJ(a | 0) | 0
	            }

	            function Nib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return FJ(a | 0) | 0
	            }

	            function Oib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return GJ(a | 0) | 0
	            }

	            function Pib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return HJ(a | 0) | 0
	            }

	            function Qib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return IJ(a | 0) | 0
	            }

	            function Rib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return JJ(a | 0) | 0
	            }

	            function Sib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return KJ(a | 0) | 0
	            }

	            function Tib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return LJ(a | 0) | 0
	            }

	            function Uib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return MJ(a | 0) | 0
	            }

	            function Vib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return NJ(a | 0) | 0
	            }

	            function Wib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return OJ(a | 0) | 0
	            }

	            function Xib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return PJ(a | 0) | 0
	            }

	            function Yib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return QJ(a | 0) | 0
	            }

	            function Zib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return RJ(a | 0) | 0
	            }

	            function _ib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return SJ(a | 0) | 0
	            }

	            function $ib(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return TJ(a | 0) | 0
	            }

	            function ajb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return UJ(a | 0) | 0
	            }

	            function bjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return VJ(a | 0) | 0
	            }

	            function cjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return WJ(a | 0) | 0
	            }

	            function djb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return XJ(a | 0) | 0
	            }

	            function ejb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return YJ(a | 0) | 0
	            }

	            function fjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return ZJ(a | 0) | 0
	            }

	            function gjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return _J(a | 0) | 0
	            }

	            function hjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return $J(a | 0) | 0
	            }

	            function ijb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return aK(a | 0) | 0
	            }

	            function jjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return bK(a | 0) | 0
	            }

	            function kjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return cK(a | 0) | 0
	            }

	            function ljb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return dK(a | 0) | 0
	            }

	            function mjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return eK(a | 0) | 0
	            }

	            function njb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return fK(a | 0) | 0
	            }

	            function ojb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return gK(a | 0) | 0
	            }

	            function pjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return hK(a | 0) | 0
	            }

	            function qjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return iK(a | 0) | 0
	            }

	            function rjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return jK(a | 0) | 0
	            }

	            function sjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return kK(a | 0) | 0
	            }

	            function tjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return lK(a | 0) | 0
	            }

	            function ujb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return mK(a | 0) | 0
	            }

	            function vjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return nK(a | 0) | 0
	            }

	            function wjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return oK(a | 0) | 0
	            }

	            function xjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return pK(a | 0) | 0
	            }

	            function yjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return qK(a | 0) | 0
	            }

	            function zjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return rK(a | 0) | 0
	            }

	            function Ajb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return sK(a | 0) | 0
	            }

	            function Bjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return tK(a | 0) | 0
	            }

	            function Cjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return uK(a | 0) | 0
	            }

	            function Djb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return vK(a | 0) | 0
	            }

	            function Ejb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return wK(a | 0) | 0
	            }

	            function Fjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return xK(a | 0) | 0
	            }

	            function Gjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return yK(a | 0) | 0
	            }

	            function Hjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return zK(a | 0) | 0
	            }

	            function Ijb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return AK(a | 0) | 0
	            }

	            function Jjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return BK(a | 0) | 0
	            }

	            function Kjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return CK(a | 0) | 0
	            }

	            function Ljb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return DK(a | 0) | 0
	            }

	            function Mjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return EK(a | 0) | 0
	            }

	            function Njb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return FK(a | 0) | 0
	            }

	            function Ojb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return GK(a | 0) | 0
	            }

	            function Pjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return HK(a | 0) | 0
	            }

	            function Qjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return IK(a | 0) | 0
	            }

	            function Rjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return JK(a | 0) | 0
	            }

	            function Sjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return KK(a | 0) | 0
	            }

	            function Tjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return LK(a | 0) | 0
	            }

	            function Ujb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return MK(a | 0) | 0
	            }

	            function Vjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return NK(a | 0) | 0
	            }

	            function Wjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return OK(a | 0) | 0
	            }

	            function Xjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return PK(a | 0) | 0
	            }

	            function Yjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return QK(a | 0) | 0
	            }

	            function Zjb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return RK(a | 0) | 0
	            }

	            function _jb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return SK(a | 0) | 0
	            }

	            function $jb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return TK(a | 0) | 0
	            }

	            function akb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return UK(a | 0) | 0
	            }

	            function bkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return VK(a | 0) | 0
	            }

	            function ckb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return WK(a | 0) | 0
	            }

	            function dkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return XK(a | 0) | 0
	            }

	            function ekb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return YK(a | 0) | 0
	            }

	            function fkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return ZK(a | 0) | 0
	            }

	            function gkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return _K(a | 0) | 0
	            }

	            function hkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return $K(a | 0) | 0
	            }

	            function ikb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return aL(a | 0) | 0
	            }

	            function jkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return bL(a | 0) | 0
	            }

	            function kkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return cL(a | 0) | 0
	            }

	            function lkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return dL(a | 0) | 0
	            }

	            function mkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return eL(a | 0) | 0
	            }

	            function nkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return RT(a | 0, b | 0, 0) | 0
	            }

	            function okb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function pkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return Wb(a | 0) | 0
	            }

	            function qkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return Yb(a | 0) | 0
	            }

	            function rkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return Wk(a | 0, b | 0, 0) | 0
	            }

	            function skb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function tkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function ukb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return ac(a | 0, b | 0, 0) | 0
	            }

	            function vkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return Ka(a | 0, b | 0, 0) | 0
	            }

	            function wkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return gc(a | 0, b | 0, 0) | 0
	            }

	            function xkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function ykb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function zkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Akb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Bkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Ckb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return nc(a | 0) | 0
	            }

	            function Dkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Ekb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return nd(a | 0) | 0
	            }

	            function Fkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return Kd(a | 0, b | 0, 0, 0) | 0
	            }

	            function Gkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return Ld(a | 0, b | 0, 0, 0) | 0
	            }

	            function Hkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return Md(a | 0, b | 0, 0, 0) | 0
	            }

	            function Ikb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return Nd(a | 0, b | 0, 0, 0) | 0
	            }

	            function Jkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return Od(a | 0, b | 0, 0, 0) | 0
	            }

	            function Kkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return Pd(a | 0, b | 0, 0, 0) | 0
	            }

	            function Lkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return qd(a | 0, b | 0, 0, 0) | 0
	            }

	            function Mkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return rd(a | 0, b | 0, 0, 0) | 0
	            }

	            function Nkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return Qd(a | 0, b | 0, 0, 0) | 0
	            }

	            function Okb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return Rd(a | 0, b | 0, 0, 0) | 0
	            }

	            function Pkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return fo(a | 0, b | 0, 0, 0) | 0
	            }

	            function Qkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Rkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Skb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Tkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return mk() | 0
	            }

	            function Ukb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Vkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Wkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return nk(a | 0) | 0
	            }

	            function Xkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return ok(a | 0) | 0
	            }

	            function Ykb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return pk(a | 0, b | 0, 0) | 0
	            }

	            function Zkb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return qk(a | 0) | 0
	            }

	            function _kb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return _k(a | 0) | 0
	            }

	            function $kb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return $k(a | 0, b | 0, 0) | 0
	            }

	            function alb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return bl(a | 0) | 0
	            }

	            function blb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return cl(a | 0, b | 0, 0) | 0
	            }

	            function clb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return dl(a | 0) | 0
	            }

	            function dlb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return el(a | 0, b | 0, 0) | 0
	            }

	            function elb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return fl(a | 0, b | 0, 0) | 0
	            }

	            function flb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return gl(a | 0, b | 0, 0, 0) | 0
	            }

	            function glb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function hlb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return on(a | 0) | 0
	            }

	            function ilb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function jlb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return vn(a | 0) | 0
	            }

	            function klb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function llb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return yn(a | 0) | 0
	            }

	            function mlb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function nlb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function olb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function plb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function qlb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function rlb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function slb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function tlb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function ulb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function vlb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function wlb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function xlb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function ylb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function zlb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Alb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Blb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Clb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Dlb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Elb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Flb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Glb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Hlb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Ilb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Jlb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Klb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Llb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Mlb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Nlb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Olb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Plb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Qlb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Rlb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Slb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Tlb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Ulb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Vlb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Wlb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Xlb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Ylb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Zlb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return uu(a | 0, b | 0, 0) | 0
	            }

	            function _lb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return vu(a | 0, b | 0, 0) | 0
	            }

	            function $lb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function amb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function bmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function cmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function dmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function emb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function fmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function gmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function hmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function imb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function jmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function kmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return Kx(a | 0, b | 0, 0) | 0
	            }

	            function lmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function mmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function nmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function omb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function pmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function qmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function rmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function smb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return RB(a | 0) | 0
	            }

	            function tmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return SB(a | 0) | 0
	            }

	            function umb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return TB(a | 0) | 0
	            }

	            function vmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return UB(a | 0, b | 0, 0) | 0
	            }

	            function wmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function xmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function ymb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function zmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Amb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Bmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Cmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Dmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Emb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Fmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Gmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Hmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Imb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Jmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Kmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Lmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Mmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Nmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Omb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Pmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Qmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return rC(a | 0, b | 0, 0) | 0
	            }

	            function Rmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Smb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Tmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Umb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Vmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Wmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Xmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Ymb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function Zmb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function _mb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function $mb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function anb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function bnb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function cnb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return GM(a | 0, b | 0, 0) | 0
	            }

	            function dnb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function enb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function fnb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return oN(a | 0, b | 0, 0, 0, 0) | 0
	            }

	            function gnb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return pN(a | 0, b | 0, 0, 0, 0, 0, 0) | 0
	            }

	            function hnb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return qN(a | 0, b | 0, 0, 0, 0, 0) | 0
	            }

	            function inb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function jnb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return uN(a | 0, b | 0, 0, 0, 0) | 0
	            }

	            function knb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return vN(a | 0, b | 0, 0, 0, 0, 0, 0) | 0
	            }

	            function lnb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function mnb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function nnb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function onb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function pnb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function qnb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function rnb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function snb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function tnb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return 0
	            }

	            function unb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return WR(a | 0, b | 0, 0, 0) | 0
	            }

	            function vnb(a, b) {
	                a = a | 0;
	                b = b | 0;
	                return hT(a | 0, b | 0, 0) | 0
	            }

	            function wnb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                da(14);
	                return 0
	            }

	            function xnb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function ynb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return vc(a | 0) | 0
	            }

	            function znb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return wc(a | 0) | 0
	            }

	            function Anb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return xc(a | 0) | 0
	            }

	            function Bnb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return yc(a | 0, b | 0, c | 0) | 0
	            }

	            function Cnb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return zc(a | 0, b | 0) | 0
	            }

	            function Dnb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Enb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Fnb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Gnb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Hnb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Inb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Jnb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Knb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Lnb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Mnb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Nnb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Onb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Pnb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Qnb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Rnb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Snb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Tnb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Unb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Vnb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return Qc(a | 0, b | 0) | 0
	            }

	            function Wnb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Xnb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Ynb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Znb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function _nb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return Xk(a | 0, b | 0, c | 0) | 0
	            }

	            function $nb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function aob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return iT(a | 0) | 0
	            }

	            function bob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return kT(a | 0, b | 0) | 0
	            }

	            function cob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return my(a | 0) | 0
	            }

	            function dob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function eob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function fob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return PP(a | 0) | 0
	            }

	            function gob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return QP(a | 0) | 0
	            }

	            function hob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return RP(a | 0) | 0
	            }

	            function iob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return UP(a | 0, b | 0, c | 0) | 0
	            }

	            function job(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return VP(a | 0, b | 0) | 0
	            }

	            function kob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function lob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function mob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function nob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function oob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function pob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function qob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function rob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function sob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function tob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function uob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function vob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function wob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function xob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function yob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function zob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Aob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return WP(a | 0, b | 0) | 0
	            }

	            function Bob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Cob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Dob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return LP(a | 0) | 0
	            }

	            function Eob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return MP(a | 0) | 0
	            }

	            function Fob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return NP(a | 0) | 0
	            }

	            function Gob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return OP(a | 0) | 0
	            }

	            function Hob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Iob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return NI(a | 0) | 0
	            }

	            function Job(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return OI(a | 0) | 0
	            }

	            function Kob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return PI(a | 0) | 0
	            }

	            function Lob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return QI(a | 0) | 0
	            }

	            function Mob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return RI(a | 0) | 0
	            }

	            function Nob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return SI(a | 0) | 0
	            }

	            function Oob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return TI(a | 0) | 0
	            }

	            function Pob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return UI(a | 0) | 0
	            }

	            function Qob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return VI(a | 0) | 0
	            }

	            function Rob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return WI(a | 0) | 0
	            }

	            function Sob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return XI(a | 0) | 0
	            }

	            function Tob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return YI(a | 0) | 0
	            }

	            function Uob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return ZI(a | 0) | 0
	            }

	            function Vob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return _I(a | 0) | 0
	            }

	            function Wob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return $I(a | 0) | 0
	            }

	            function Xob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return aJ(a | 0) | 0
	            }

	            function Yob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return bJ(a | 0) | 0
	            }

	            function Zob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return cJ(a | 0) | 0
	            }

	            function _ob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return dJ(a | 0) | 0
	            }

	            function $ob(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return eJ(a | 0) | 0
	            }

	            function apb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return fJ(a | 0) | 0
	            }

	            function bpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return gJ(a | 0) | 0
	            }

	            function cpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return hJ(a | 0) | 0
	            }

	            function dpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return iJ(a | 0) | 0
	            }

	            function epb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return jJ(a | 0) | 0
	            }

	            function fpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return kJ(a | 0) | 0
	            }

	            function gpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return lJ(a | 0) | 0
	            }

	            function hpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return mJ(a | 0) | 0
	            }

	            function ipb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return nJ(a | 0) | 0
	            }

	            function jpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return oJ(a | 0) | 0
	            }

	            function kpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return pJ(a | 0) | 0
	            }

	            function lpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return qJ(a | 0) | 0
	            }

	            function mpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return rJ(a | 0) | 0
	            }

	            function npb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return sJ(a | 0) | 0
	            }

	            function opb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return tJ(a | 0) | 0
	            }

	            function ppb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return uJ(a | 0) | 0
	            }

	            function qpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return vJ(a | 0) | 0
	            }

	            function rpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return wJ(a | 0) | 0
	            }

	            function spb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return xJ(a | 0) | 0
	            }

	            function tpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return yJ(a | 0) | 0
	            }

	            function upb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return zJ(a | 0) | 0
	            }

	            function vpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return AJ(a | 0) | 0
	            }

	            function wpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return BJ(a | 0) | 0
	            }

	            function xpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return CJ(a | 0) | 0
	            }

	            function ypb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return DJ(a | 0) | 0
	            }

	            function zpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return EJ(a | 0) | 0
	            }

	            function Apb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return FJ(a | 0) | 0
	            }

	            function Bpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return GJ(a | 0) | 0
	            }

	            function Cpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return HJ(a | 0) | 0
	            }

	            function Dpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return IJ(a | 0) | 0
	            }

	            function Epb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return JJ(a | 0) | 0
	            }

	            function Fpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return KJ(a | 0) | 0
	            }

	            function Gpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return LJ(a | 0) | 0
	            }

	            function Hpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return MJ(a | 0) | 0
	            }

	            function Ipb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return NJ(a | 0) | 0
	            }

	            function Jpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return OJ(a | 0) | 0
	            }

	            function Kpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return PJ(a | 0) | 0
	            }

	            function Lpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return QJ(a | 0) | 0
	            }

	            function Mpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return RJ(a | 0) | 0
	            }

	            function Npb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return SJ(a | 0) | 0
	            }

	            function Opb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return TJ(a | 0) | 0
	            }

	            function Ppb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return UJ(a | 0) | 0
	            }

	            function Qpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return VJ(a | 0) | 0
	            }

	            function Rpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return WJ(a | 0) | 0
	            }

	            function Spb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return XJ(a | 0) | 0
	            }

	            function Tpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return YJ(a | 0) | 0
	            }

	            function Upb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return ZJ(a | 0) | 0
	            }

	            function Vpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return _J(a | 0) | 0
	            }

	            function Wpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return $J(a | 0) | 0
	            }

	            function Xpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return aK(a | 0) | 0
	            }

	            function Ypb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return bK(a | 0) | 0
	            }

	            function Zpb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return cK(a | 0) | 0
	            }

	            function _pb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return dK(a | 0) | 0
	            }

	            function $pb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return eK(a | 0) | 0
	            }

	            function aqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return fK(a | 0) | 0
	            }

	            function bqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return gK(a | 0) | 0
	            }

	            function cqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return hK(a | 0) | 0
	            }

	            function dqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return iK(a | 0) | 0
	            }

	            function eqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return jK(a | 0) | 0
	            }

	            function fqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return kK(a | 0) | 0
	            }

	            function gqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return lK(a | 0) | 0
	            }

	            function hqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return mK(a | 0) | 0
	            }

	            function iqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return nK(a | 0) | 0
	            }

	            function jqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return oK(a | 0) | 0
	            }

	            function kqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return pK(a | 0) | 0
	            }

	            function lqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return qK(a | 0) | 0
	            }

	            function mqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return rK(a | 0) | 0
	            }

	            function nqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return sK(a | 0) | 0
	            }

	            function oqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return tK(a | 0) | 0
	            }

	            function pqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return uK(a | 0) | 0
	            }

	            function qqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return vK(a | 0) | 0
	            }

	            function rqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return wK(a | 0) | 0
	            }

	            function sqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return xK(a | 0) | 0
	            }

	            function tqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return yK(a | 0) | 0
	            }

	            function uqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return zK(a | 0) | 0
	            }

	            function vqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return AK(a | 0) | 0
	            }

	            function wqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return BK(a | 0) | 0
	            }

	            function xqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return CK(a | 0) | 0
	            }

	            function yqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return DK(a | 0) | 0
	            }

	            function zqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return EK(a | 0) | 0
	            }

	            function Aqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return FK(a | 0) | 0
	            }

	            function Bqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return GK(a | 0) | 0
	            }

	            function Cqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return HK(a | 0) | 0
	            }

	            function Dqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return IK(a | 0) | 0
	            }

	            function Eqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return JK(a | 0) | 0
	            }

	            function Fqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return KK(a | 0) | 0
	            }

	            function Gqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return LK(a | 0) | 0
	            }

	            function Hqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return MK(a | 0) | 0
	            }

	            function Iqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return NK(a | 0) | 0
	            }

	            function Jqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return OK(a | 0) | 0
	            }

	            function Kqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return PK(a | 0) | 0
	            }

	            function Lqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return QK(a | 0) | 0
	            }

	            function Mqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return RK(a | 0) | 0
	            }

	            function Nqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return SK(a | 0) | 0
	            }

	            function Oqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return TK(a | 0) | 0
	            }

	            function Pqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return UK(a | 0) | 0
	            }

	            function Qqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return VK(a | 0) | 0
	            }

	            function Rqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return WK(a | 0) | 0
	            }

	            function Sqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return XK(a | 0) | 0
	            }

	            function Tqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return YK(a | 0) | 0
	            }

	            function Uqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return ZK(a | 0) | 0
	            }

	            function Vqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return _K(a | 0) | 0
	            }

	            function Wqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return $K(a | 0) | 0
	            }

	            function Xqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return aL(a | 0) | 0
	            }

	            function Yqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return bL(a | 0) | 0
	            }

	            function Zqb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return cL(a | 0) | 0
	            }

	            function _qb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return dL(a | 0) | 0
	            }

	            function $qb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return eL(a | 0) | 0
	            }

	            function arb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return RT(a | 0, b | 0, c | 0) | 0
	            }

	            function brb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function crb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return Wb(a | 0) | 0
	            }

	            function drb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return Xb(a | 0, b | 0) | 0
	            }

	            function erb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return Yb(a | 0) | 0
	            }

	            function frb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return Wk(a | 0, b | 0, c | 0) | 0
	            }

	            function grb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function hrb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function irb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return ac(a | 0, b | 0, c | 0) | 0
	            }

	            function jrb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return Ka(a | 0, b | 0, c | 0) | 0
	            }

	            function krb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return gc(a | 0, b | 0, c | 0) | 0
	            }

	            function lrb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function mrb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function nrb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function orb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function prb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function qrb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return nc(a | 0) | 0
	            }

	            function rrb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function srb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return nd(a | 0) | 0
	            }

	            function trb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return Kd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function urb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return Ld(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function vrb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return Md(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function wrb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return Nd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function xrb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return Od(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function yrb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return Pd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function zrb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return qd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Arb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return rd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Brb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return Qd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Crb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return Rd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Drb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return fo(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Erb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Frb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Grb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Hrb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return mk() | 0
	            }

	            function Irb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Jrb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Krb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return nk(a | 0) | 0
	            }

	            function Lrb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return ok(a | 0) | 0
	            }

	            function Mrb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return pk(a | 0, b | 0, c | 0) | 0
	            }

	            function Nrb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return qk(a | 0) | 0
	            }

	            function Orb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return _k(a | 0) | 0
	            }

	            function Prb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return $k(a | 0, b | 0, c | 0) | 0
	            }

	            function Qrb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return bl(a | 0) | 0
	            }

	            function Rrb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return cl(a | 0, b | 0, c | 0) | 0
	            }

	            function Srb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return dl(a | 0) | 0
	            }

	            function Trb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return el(a | 0, b | 0, c | 0) | 0
	            }

	            function Urb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return fl(a | 0, b | 0, c | 0) | 0
	            }

	            function Vrb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return gl(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Wrb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Xrb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return on(a | 0) | 0
	            }

	            function Yrb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Zrb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return vn(a | 0) | 0
	            }

	            function _rb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function $rb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return yn(a | 0) | 0
	            }

	            function asb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function bsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function csb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function dsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return Cn(a | 0, b | 0) | 0
	            }

	            function esb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function fsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function gsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function hsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function isb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function jsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function ksb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return _n(a | 0, b | 0) | 0
	            }

	            function lsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function msb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function nsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function osb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function psb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function qsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function rsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function ssb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function tsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function usb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function vsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function wsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function xsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function ysb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function zsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Asb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Bsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Csb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Dsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Esb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Fsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Gsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Hsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Isb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Jsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Ksb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Lsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Msb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Nsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Osb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Psb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return uu(a | 0, b | 0, c | 0) | 0
	            }

	            function Qsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return ds(a | 0, b | 0) | 0
	            }

	            function Rsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return es(a | 0, b | 0) | 0
	            }

	            function Ssb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return js(a | 0, b | 0) | 0
	            }

	            function Tsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return vu(a | 0, b | 0, c | 0) | 0
	            }

	            function Usb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return wu(a | 0, b | 0) | 0
	            }

	            function Vsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return $r(a | 0, b | 0) | 0
	            }

	            function Wsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return as(a | 0, b | 0) | 0
	            }

	            function Xsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return bs(a | 0, b | 0) | 0
	            }

	            function Ysb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return hs(a | 0, b | 0) | 0
	            }

	            function Zsb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return fs(a | 0, b | 0) | 0
	            }

	            function _sb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return is(a | 0, b | 0) | 0
	            }

	            function $sb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return cs(a | 0, b | 0) | 0
	            }

	            function atb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return xu(a | 0, b | 0) | 0
	            }

	            function btb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return gs(a | 0, b | 0) | 0
	            }

	            function ctb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return _r(a | 0, b | 0) | 0
	            }

	            function dtb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return dr(a | 0, b | 0) | 0
	            }

	            function etb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function ftb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function gtb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function htb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function itb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function jtb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function ktb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function ltb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function mtb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function ntb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function otb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function ptb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return Kx(a | 0, b | 0, c | 0) | 0
	            }

	            function qtb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return $x(a | 0, b | 0) | 0
	            }

	            function rtb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return dy(a | 0, b | 0) | 0
	            }

	            function stb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return fy(a | 0, b | 0) | 0
	            }

	            function ttb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return jy(a | 0, b | 0) | 0
	            }

	            function utb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function vtb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function wtb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function xtb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function ytb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function ztb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Atb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Btb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return RB(a | 0) | 0
	            }

	            function Ctb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return SB(a | 0) | 0
	            }

	            function Dtb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return TB(a | 0) | 0
	            }

	            function Etb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return UB(a | 0, b | 0, c | 0) | 0
	            }

	            function Ftb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return VB(a | 0, b | 0) | 0
	            }

	            function Gtb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Htb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Itb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Jtb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Ktb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Ltb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Mtb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Ntb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Otb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Ptb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Qtb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Rtb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Stb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Ttb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return hC(a | 0, b | 0) | 0
	            }

	            function Utb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Vtb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Wtb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Xtb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Ytb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Ztb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function _tb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function $tb(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return rC(a | 0, b | 0, c | 0) | 0
	            }

	            function aub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function bub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function cub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function dub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function eub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function fub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function gub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function hub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function iub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function jub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function kub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function lub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function mub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function nub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return GM(a | 0, b | 0, c | 0) | 0
	            }

	            function oub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function pub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function qub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return nN(a | 0, b | 0) | 0
	            }

	            function rub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return pN(a | 0, b | 0, c | 0, d | 0, e | 0, 0, 0) | 0
	            }

	            function sub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return qN(a | 0, b | 0, c | 0, d | 0, e | 0, 0) | 0
	            }

	            function tub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function uub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return tN(a | 0, b | 0) | 0
	            }

	            function vub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return vN(a | 0, b | 0, c | 0, d | 0, e | 0, 0, 0) | 0
	            }

	            function wub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function xub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function yub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function zub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Aub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Bub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Cub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Dub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Eub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return 0
	            }

	            function Fub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return WR(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Gub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return QS(a | 0, b | 0) | 0
	            }

	            function Hub(a, b, c, d, e) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                e = e | 0;
	                return hT(a | 0, b | 0, c | 0) | 0
	            }

	            function Iub(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                da(15)
	            }

	            function Jub(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                vc(a | 0) | 0
	            }

	            function Kub(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                wc(a | 0) | 0
	            }

	            function Lub(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                xc(a | 0) | 0
	            }

	            function Mub(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                yc(a | 0, b | 0, c | 0) | 0
	            }

	            function Nub(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                zc(a | 0, b | 0) | 0
	            }

	            function Oub(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Ac(a | 0, b | 0, c | 0, d | 0, 0, 0)
	            }

	            function Pub(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Cc(a | 0, b | 0, c | 0, d | 0, 0, 0, 0)
	            }

	            function Qub(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Ec(a | 0, b | 0, c | 0, d | 0, 0)
	            }

	            function Rub(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Fc(a | 0, b | 0)
	            }

	            function Sub(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Gc(a | 0)
	            }

	            function Tub(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Hc(a | 0)
	            }

	            function Uub(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Wc(a | 0, b | 0, c | 0)
	            }

	            function Vub(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Xc(a | 0, b | 0)
	            }

	            function Wub(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Ic(a | 0, b | 0)
	            }

	            function Xub(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Jc(a | 0, b | 0, c | 0)
	            }

	            function Yub(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Kc(a | 0, b | 0, c | 0)
	            }

	            function Zub(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Lc(a | 0, b | 0, c | 0)
	            }

	            function _ub(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Mc(a | 0, b | 0)
	            }

	            function $ub(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Nc(a | 0, b | 0, c | 0)
	            }

	            function avb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Oc(a | 0, b | 0, c | 0)
	            }

	            function bvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Pc(a | 0, b | 0, c | 0)
	            }

	            function cvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Qc(a | 0, b | 0) | 0
	            }

	            function dvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Rc(a | 0, b | 0, c | 0)
	            }

	            function evb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Tc(a | 0, b | 0, c | 0, d | 0, 0, 0, 0, 0, 0)
	            }

	            function fvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Xk(a | 0, b | 0, c | 0) | 0
	            }

	            function gvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                jT(a | 0)
	            }

	            function hvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                iT(a | 0) | 0
	            }

	            function ivb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                kT(a | 0, b | 0) | 0
	            }

	            function jvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                my(a | 0) | 0
	            }

	            function kvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Td(a | 0, b | 0, c | 0)
	            }

	            function lvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                PP(a | 0) | 0
	            }

	            function mvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                QP(a | 0) | 0
	            }

	            function nvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                RP(a | 0) | 0
	            }

	            function ovb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                UP(a | 0, b | 0, c | 0) | 0
	            }

	            function pvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                VP(a | 0, b | 0) | 0
	            }

	            function qvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                XP(a | 0, b | 0, c | 0, d | 0, 0, 0)
	            }

	            function rvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                YP(a | 0, b | 0, c | 0, d | 0, 0, 0, 0)
	            }

	            function svb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                $P(a | 0, b | 0, c | 0, d | 0, 0)
	            }

	            function tvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                aQ(a | 0, b | 0)
	            }

	            function uvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                bQ(a | 0)
	            }

	            function vvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                cQ(a | 0)
	            }

	            function wvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                dQ(a | 0, b | 0, c | 0)
	            }

	            function xvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                eQ(a | 0, b | 0)
	            }

	            function yvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                hQ(a | 0, b | 0)
	            }

	            function zvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                iQ(a | 0, b | 0, c | 0)
	            }

	            function Avb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                kQ(a | 0, b | 0, c | 0)
	            }

	            function Bvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                lQ(a | 0, b | 0)
	            }

	            function Cvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                $d(a | 0, b | 0, c | 0)
	            }

	            function Dvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                _d(a | 0, b | 0, c | 0)
	            }

	            function Evb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                WP(a | 0, b | 0) | 0
	            }

	            function Fvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                mQ(a | 0, b | 0, c | 0)
	            }

	            function Gvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                LP(a | 0) | 0
	            }

	            function Hvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                MP(a | 0) | 0
	            }

	            function Ivb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                NP(a | 0) | 0
	            }

	            function Jvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                OP(a | 0) | 0
	            }

	            function Kvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                jQ(a | 0, b | 0, c | 0)
	            }

	            function Lvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                NI(a | 0) | 0
	            }

	            function Mvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                OI(a | 0) | 0
	            }

	            function Nvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                PI(a | 0) | 0
	            }

	            function Ovb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                QI(a | 0) | 0
	            }

	            function Pvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                RI(a | 0) | 0
	            }

	            function Qvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                SI(a | 0) | 0
	            }

	            function Rvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                TI(a | 0) | 0
	            }

	            function Svb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                UI(a | 0) | 0
	            }

	            function Tvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                VI(a | 0) | 0
	            }

	            function Uvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                WI(a | 0) | 0
	            }

	            function Vvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                XI(a | 0) | 0
	            }

	            function Wvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                YI(a | 0) | 0
	            }

	            function Xvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                ZI(a | 0) | 0
	            }

	            function Yvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                _I(a | 0) | 0
	            }

	            function Zvb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                $I(a | 0) | 0
	            }

	            function _vb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                aJ(a | 0) | 0
	            }

	            function $vb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                bJ(a | 0) | 0
	            }

	            function awb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                cJ(a | 0) | 0
	            }

	            function bwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                dJ(a | 0) | 0
	            }

	            function cwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                eJ(a | 0) | 0
	            }

	            function dwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                fJ(a | 0) | 0
	            }

	            function ewb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                gJ(a | 0) | 0
	            }

	            function fwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                hJ(a | 0) | 0
	            }

	            function gwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                iJ(a | 0) | 0
	            }

	            function hwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                jJ(a | 0) | 0
	            }

	            function iwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                kJ(a | 0) | 0
	            }

	            function jwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                lJ(a | 0) | 0
	            }

	            function kwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                mJ(a | 0) | 0
	            }

	            function lwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                nJ(a | 0) | 0
	            }

	            function mwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                oJ(a | 0) | 0
	            }

	            function nwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                pJ(a | 0) | 0
	            }

	            function owb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                qJ(a | 0) | 0
	            }

	            function pwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                rJ(a | 0) | 0
	            }

	            function qwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                sJ(a | 0) | 0
	            }

	            function rwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                tJ(a | 0) | 0
	            }

	            function swb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                uJ(a | 0) | 0
	            }

	            function twb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                vJ(a | 0) | 0
	            }

	            function uwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                wJ(a | 0) | 0
	            }

	            function vwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                xJ(a | 0) | 0
	            }

	            function wwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                yJ(a | 0) | 0
	            }

	            function xwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                zJ(a | 0) | 0
	            }

	            function ywb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                AJ(a | 0) | 0
	            }

	            function zwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                BJ(a | 0) | 0
	            }

	            function Awb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                CJ(a | 0) | 0
	            }

	            function Bwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                DJ(a | 0) | 0
	            }

	            function Cwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                EJ(a | 0) | 0
	            }

	            function Dwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                FJ(a | 0) | 0
	            }

	            function Ewb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                GJ(a | 0) | 0
	            }

	            function Fwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                HJ(a | 0) | 0
	            }

	            function Gwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                IJ(a | 0) | 0
	            }

	            function Hwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                JJ(a | 0) | 0
	            }

	            function Iwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                KJ(a | 0) | 0
	            }

	            function Jwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                LJ(a | 0) | 0
	            }

	            function Kwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                MJ(a | 0) | 0
	            }

	            function Lwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                NJ(a | 0) | 0
	            }

	            function Mwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                OJ(a | 0) | 0
	            }

	            function Nwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                PJ(a | 0) | 0
	            }

	            function Owb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                QJ(a | 0) | 0
	            }

	            function Pwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                RJ(a | 0) | 0
	            }

	            function Qwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                SJ(a | 0) | 0
	            }

	            function Rwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                TJ(a | 0) | 0
	            }

	            function Swb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                UJ(a | 0) | 0
	            }

	            function Twb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                VJ(a | 0) | 0
	            }

	            function Uwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                WJ(a | 0) | 0
	            }

	            function Vwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                XJ(a | 0) | 0
	            }

	            function Wwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                YJ(a | 0) | 0
	            }

	            function Xwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                ZJ(a | 0) | 0
	            }

	            function Ywb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                _J(a | 0) | 0
	            }

	            function Zwb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                $J(a | 0) | 0
	            }

	            function _wb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                aK(a | 0) | 0
	            }

	            function $wb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                bK(a | 0) | 0
	            }

	            function axb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                cK(a | 0) | 0
	            }

	            function bxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                dK(a | 0) | 0
	            }

	            function cxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                eK(a | 0) | 0
	            }

	            function dxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                fK(a | 0) | 0
	            }

	            function exb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                gK(a | 0) | 0
	            }

	            function fxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                hK(a | 0) | 0
	            }

	            function gxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                iK(a | 0) | 0
	            }

	            function hxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                jK(a | 0) | 0
	            }

	            function ixb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                kK(a | 0) | 0
	            }

	            function jxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                lK(a | 0) | 0
	            }

	            function kxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                mK(a | 0) | 0
	            }

	            function lxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                nK(a | 0) | 0
	            }

	            function mxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                oK(a | 0) | 0
	            }

	            function nxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                pK(a | 0) | 0
	            }

	            function oxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                qK(a | 0) | 0
	            }

	            function pxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                rK(a | 0) | 0
	            }

	            function qxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                sK(a | 0) | 0
	            }

	            function rxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                tK(a | 0) | 0
	            }

	            function sxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                uK(a | 0) | 0
	            }

	            function txb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                vK(a | 0) | 0
	            }

	            function uxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                wK(a | 0) | 0
	            }

	            function vxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                xK(a | 0) | 0
	            }

	            function wxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                yK(a | 0) | 0
	            }

	            function xxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                zK(a | 0) | 0
	            }

	            function yxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                AK(a | 0) | 0
	            }

	            function zxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                BK(a | 0) | 0
	            }

	            function Axb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                CK(a | 0) | 0
	            }

	            function Bxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                DK(a | 0) | 0
	            }

	            function Cxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                EK(a | 0) | 0
	            }

	            function Dxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                FK(a | 0) | 0
	            }

	            function Exb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                GK(a | 0) | 0
	            }

	            function Fxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                HK(a | 0) | 0
	            }

	            function Gxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                IK(a | 0) | 0
	            }

	            function Hxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                JK(a | 0) | 0
	            }

	            function Ixb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                KK(a | 0) | 0
	            }

	            function Jxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                LK(a | 0) | 0
	            }

	            function Kxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                MK(a | 0) | 0
	            }

	            function Lxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                NK(a | 0) | 0
	            }

	            function Mxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                OK(a | 0) | 0
	            }

	            function Nxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                PK(a | 0) | 0
	            }

	            function Oxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                QK(a | 0) | 0
	            }

	            function Pxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                RK(a | 0) | 0
	            }

	            function Qxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                SK(a | 0) | 0
	            }

	            function Rxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                TK(a | 0) | 0
	            }

	            function Sxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                UK(a | 0) | 0
	            }

	            function Txb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                VK(a | 0) | 0
	            }

	            function Uxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                WK(a | 0) | 0
	            }

	            function Vxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                XK(a | 0) | 0
	            }

	            function Wxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                YK(a | 0) | 0
	            }

	            function Xxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                ZK(a | 0) | 0
	            }

	            function Yxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                _K(a | 0) | 0
	            }

	            function Zxb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                $K(a | 0) | 0
	            }

	            function _xb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                aL(a | 0) | 0
	            }

	            function $xb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                bL(a | 0) | 0
	            }

	            function ayb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                cL(a | 0) | 0
	            }

	            function byb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                dL(a | 0) | 0
	            }

	            function cyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                eL(a | 0) | 0
	            }

	            function dyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                RT(a | 0, b | 0, c | 0) | 0
	            }

	            function eyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Vb(a | 0)
	            }

	            function fyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Wb(a | 0) | 0
	            }

	            function gyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Xb(a | 0, b | 0) | 0
	            }

	            function hyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Yb(a | 0) | 0
	            }

	            function iyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Wk(a | 0, b | 0, c | 0) | 0
	            }

	            function jyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                _b(a | 0)
	            }

	            function kyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                $b(a | 0)
	            }

	            function lyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                ac(a | 0, b | 0, c | 0) | 0
	            }

	            function myb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Ka(a | 0, b | 0, c | 0) | 0
	            }

	            function nyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                gc(a | 0, b | 0, c | 0) | 0
	            }

	            function oyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                hc(a | 0)
	            }

	            function pyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                ic(a | 0, b | 0, c | 0)
	            }

	            function qyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                jc(a | 0, b | 0, c | 0)
	            }

	            function ryb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                kc(a | 0, b | 0, c | 0)
	            }

	            function syb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                lc(a | 0, b | 0, c | 0)
	            }

	            function tyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                nc(a | 0) | 0
	            }

	            function uyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                md(a | 0, b | 0)
	            }

	            function vyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                nd(a | 0) | 0
	            }

	            function wyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Kd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function xyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Ld(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function yyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Md(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function zyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Nd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Ayb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Od(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Byb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Pd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Cyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                qd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Dyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                rd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Eyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Qd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Fyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Rd(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Gyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                fo(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Hyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                ae(a | 0, b | 0, c | 0)
	            }

	            function Iyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                be(a | 0, b | 0, c | 0)
	            }

	            function Jyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                tg(a | 0)
	            }

	            function Kyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                mk() | 0
	            }

	            function Lyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                sh(a | 0, b | 0, c | 0, d | 0, 0)
	            }

	            function Myb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                gk(a | 0, b | 0, c | 0, d | 0, 0)
	            }

	            function Nyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                nk(a | 0) | 0
	            }

	            function Oyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                ok(a | 0) | 0
	            }

	            function Pyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                pk(a | 0, b | 0, c | 0) | 0
	            }

	            function Qyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                qk(a | 0) | 0
	            }

	            function Ryb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                _k(a | 0) | 0
	            }

	            function Syb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                $k(a | 0, b | 0, c | 0) | 0
	            }

	            function Tyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                bl(a | 0) | 0
	            }

	            function Uyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                cl(a | 0, b | 0, c | 0) | 0
	            }

	            function Vyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                dl(a | 0) | 0
	            }

	            function Wyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                el(a | 0, b | 0, c | 0) | 0
	            }

	            function Xyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                fl(a | 0, b | 0, c | 0) | 0
	            }

	            function Yyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                gl(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function Zyb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                nn(a | 0)
	            }

	            function _yb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                on(a | 0) | 0
	            }

	            function $yb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                sn(a | 0)
	            }

	            function azb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                vn(a | 0) | 0
	            }

	            function bzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                xn(a | 0)
	            }

	            function czb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                yn(a | 0) | 0
	            }

	            function dzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                zn(a | 0, b | 0)
	            }

	            function ezb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                An(a | 0)
	            }

	            function fzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Bn(a | 0)
	            }

	            function gzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Cn(a | 0, b | 0) | 0
	            }

	            function hzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Dn(a | 0)
	            }

	            function izb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                In(a | 0, b | 0, c | 0)
	            }

	            function jzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Rn(a | 0, b | 0, c | 0)
	            }

	            function kzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Sn(a | 0, b | 0, c | 0)
	            }

	            function lzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Tn(a | 0, b | 0, c | 0)
	            }

	            function mzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Un(a | 0, b | 0, c | 0)
	            }

	            function nzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                _n(a | 0, b | 0) | 0
	            }

	            function ozb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                tq(a | 0, b | 0)
	            }

	            function pzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Qq(a | 0)
	            }

	            function qzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Bs(a | 0, b | 0)
	            }

	            function rzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Is(a | 0, b | 0)
	            }

	            function szb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                ns(a | 0, b | 0)
	            }

	            function tzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                ts(a | 0, b | 0)
	            }

	            function uzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                us(a | 0, b | 0)
	            }

	            function vzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                os(a | 0, b | 0)
	            }

	            function wzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Es(a | 0, b | 0)
	            }

	            function xzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Hs(a | 0, b | 0)
	            }

	            function yzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                ls(a | 0, b | 0)
	            }

	            function zzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Fs(a | 0, b | 0)
	            }

	            function Azb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                ps(a | 0, b | 0)
	            }

	            function Bzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Cs(a | 0, b | 0)
	            }

	            function Czb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                nt(a | 0, b | 0)
	            }

	            function Dzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                qs(a | 0, b | 0)
	            }

	            function Ezb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                zs(a | 0, b | 0)
	            }

	            function Fzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Tr(a | 0, b | 0)
	            }

	            function Gzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                ms(a | 0, b | 0)
	            }

	            function Hzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Js(a | 0, b | 0)
	            }

	            function Izb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                rs(a | 0, b | 0)
	            }

	            function Jzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                ss(a | 0, b | 0)
	            }

	            function Kzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                vs(a | 0, b | 0)
	            }

	            function Lzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                ws(a | 0, b | 0)
	            }

	            function Mzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                xs(a | 0, b | 0)
	            }

	            function Nzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                ys(a | 0, b | 0)
	            }

	            function Ozb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Gs(a | 0, b | 0)
	            }

	            function Pzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Ds(a | 0, b | 0)
	            }

	            function Qzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                As(a | 0, b | 0)
	            }

	            function Rzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                ot(a | 0, b | 0)
	            }

	            function Szb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                uu(a | 0, b | 0, c | 0) | 0
	            }

	            function Tzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                ds(a | 0, b | 0) | 0
	            }

	            function Uzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                es(a | 0, b | 0) | 0
	            }

	            function Vzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                js(a | 0, b | 0) | 0
	            }

	            function Wzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                vu(a | 0, b | 0, c | 0) | 0
	            }

	            function Xzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                wu(a | 0, b | 0) | 0
	            }

	            function Yzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                $r(a | 0, b | 0) | 0
	            }

	            function Zzb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                as(a | 0, b | 0) | 0
	            }

	            function _zb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                bs(a | 0, b | 0) | 0
	            }

	            function $zb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                hs(a | 0, b | 0) | 0
	            }

	            function aAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                fs(a | 0, b | 0) | 0
	            }

	            function bAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                is(a | 0, b | 0) | 0
	            }

	            function cAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                cs(a | 0, b | 0) | 0
	            }

	            function dAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                xu(a | 0, b | 0) | 0
	            }

	            function eAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                gs(a | 0, b | 0) | 0
	            }

	            function fAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                _r(a | 0, b | 0) | 0
	            }

	            function gAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                dr(a | 0, b | 0) | 0
	            }

	            function hAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                jv(a | 0, b | 0)
	            }

	            function iAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                pv(a | 0, b | 0)
	            }

	            function jAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                qv(a | 0, b | 0)
	            }

	            function kAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                rv(a | 0, b | 0)
	            }

	            function lAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                sv(a | 0, b | 0)
	            }

	            function mAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                tv(a | 0, b | 0)
	            }

	            function nAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                uv(a | 0, b | 0)
	            }

	            function oAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                vv(a | 0, b | 0)
	            }

	            function pAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                tw(a | 0, b | 0, c | 0)
	            }

	            function qAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Mw(a | 0)
	            }

	            function rAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Yw(a | 0)
	            }

	            function sAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                Kx(a | 0, b | 0, c | 0) | 0
	            }

	            function tAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                $x(a | 0, b | 0) | 0
	            }

	            function uAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                dy(a | 0, b | 0) | 0
	            }

	            function vAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                fy(a | 0, b | 0) | 0
	            }

	            function wAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                jy(a | 0, b | 0) | 0
	            }

	            function xAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                qB(a | 0)
	            }

	            function yAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                LB(a | 0, b | 0, c | 0, d | 0, 0, 0, 0, 0, 0)
	            }

	            function zAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                NB(a | 0, b | 0, c | 0)
	            }

	            function AAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                OB(a | 0, b | 0, c | 0)
	            }

	            function BAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                PB(a | 0, b | 0)
	            }

	            function CAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                RB(a | 0) | 0
	            }

	            function DAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                SB(a | 0) | 0
	            }

	            function EAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                TB(a | 0) | 0
	            }

	            function FAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                UB(a | 0, b | 0, c | 0) | 0
	            }

	            function GAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                VB(a | 0, b | 0) | 0
	            }

	            function HAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                WB(a | 0, b | 0, c | 0, d | 0, 0, 0)
	            }

	            function IAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                YB(a | 0, b | 0, c | 0, d | 0, 0, 0, 0)
	            }

	            function JAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                _B(a | 0, b | 0, c | 0, d | 0, 0)
	            }

	            function KAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                $B(a | 0, b | 0)
	            }

	            function LAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                aC(a | 0)
	            }

	            function MAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                bC(a | 0)
	            }

	            function NAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                cC(a | 0, b | 0, c | 0)
	            }

	            function OAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                dC(a | 0, b | 0)
	            }

	            function PAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                eC(a | 0, b | 0, c | 0)
	            }

	            function QAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                fC(a | 0, b | 0, c | 0)
	            }

	            function RAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                gC(a | 0, b | 0, c | 0)
	            }

	            function SAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                hC(a | 0, b | 0) | 0
	            }

	            function TAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                jC(a | 0, b | 0, c | 0)
	            }

	            function UAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                kC(a | 0, b | 0, c | 0)
	            }

	            function VAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                lC(a | 0, b | 0, c | 0)
	            }

	            function WAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                mC(a | 0, b | 0)
	            }

	            function XAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                nC(a | 0, b | 0, c | 0, d | 0, 0, 0, 0, 0, 0)
	            }

	            function YAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                rC(a | 0, b | 0, c | 0) | 0
	            }

	            function ZAb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                uC(a | 0)
	            }

	            function _Ab(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                AD(a | 0, b | 0)
	            }

	            function $Ab(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                uF(a | 0, b | 0)
	            }

	            function aBb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                VA(a | 0)
	            }

	            function bBb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                wM(a | 0, b | 0, c | 0)
	            }

	            function cBb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                xM(a | 0, b | 0)
	            }

	            function dBb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                yM(a | 0, b | 0, c | 0, d | 0, 0, 0, 0, 0, 0)
	            }

	            function eBb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                AM(a | 0, b | 0, c | 0)
	            }

	            function fBb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                BM(a | 0, b | 0, c | 0)
	            }

	            function gBb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                DM(a | 0, b | 0, c | 0)
	            }

	            function hBb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                EM(a | 0, b | 0, c | 0)
	            }

	            function iBb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                GM(a | 0, b | 0, c | 0) | 0
	            }

	            function jBb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                FM(a | 0, b | 0)
	            }

	            function kBb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                UM(a | 0)
	            }

	            function lBb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                nN(a | 0, b | 0) | 0
	            }

	            function mBb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                oN(a | 0, b | 0, c | 0, d | 0, 0) | 0
	            }

	            function nBb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                pN(a | 0, b | 0, c | 0, d | 0, 0, 0, 0) | 0
	            }

	            function oBb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                qN(a | 0, b | 0, c | 0, d | 0, 0, 0) | 0
	            }

	            function pBb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                rN(a | 0, b | 0)
	            }

	            function qBb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                tN(a | 0, b | 0) | 0
	            }

	            function rBb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                uN(a | 0, b | 0, c | 0, d | 0, 0) | 0
	            }

	            function sBb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                vN(a | 0, b | 0, c | 0, d | 0, 0, 0, 0) | 0
	            }

	            function tBb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                wN(a | 0, b | 0)
	            }

	            function uBb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                CN(a | 0, b | 0, c | 0)
	            }

	            function vBb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                vO(a | 0, b | 0, c | 0)
	            }

	            function wBb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                wO(a | 0, b | 0, c | 0)
	            }

	            function xBb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                sP(a | 0, b | 0, c | 0)
	            }

	            function yBb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                fQ(a | 0, b | 0, c | 0, d | 0, 0, 0, 0, 0, 0)
	            }

	            function zBb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                WR(a | 0, b | 0, c | 0, d | 0) | 0
	            }

	            function ABb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                QS(a | 0, b | 0) | 0
	            }

	            function BBb(a, b, c, d) {
	                a = a | 0;
	                b = b | 0;
	                c = c | 0;
	                d = d | 0;
	                hT(a | 0, b | 0, c | 0) | 0
	            }

	// EMSCRIPTEN_END_FUNCS
	            var ub = [GU, HU, IU, JU, KU, LU, MU, NU, OU, PU, QU, RU, SU, TU, UU, VU, WU, XU, YU, ZU, _U, $U, aV, bV, cV, dV, eV, fV, gV, hV, iV, jV, kV, lV, mV, nV, oV, pV, qV, rV, sV, tV, uV, vV, wV, xV, yV, zV, AV, BV, CV, DV, EV, FV, GV, HV, IV, JV, KV, LV, MV, NV, OV, PV, QV, RV, SV, TV, UV, VV, WV, XV, YV, ZV, _V, $V, aW, bW, cW, dW, eW, fW, gW, hW, iW, jW, kW, lW, mW, nW, oW, pW, qW, rW, sW, tW, uW, vW, wW, xW, yW, zW, AW, BW, CW, DW, EW, FW, GW, HW, IW, JW, KW, LW, MW, NW, OW, PW, QW, RW, SW, TW, UW, VW, WW, XW, YW, ZW, _W, $W, aX, bX, cX, dX, eX, fX, gX, hX, iX, jX, kX, lX, mX, nX, oX, pX, qX, rX, sX, tX, uX, vX, wX, xX, yX, zX, AX, BX, CX, DX, EX, FX, GX, HX, IX, JX, KX, LX, MX, NX, OX, PX, QX, RX, SX, TX, UX, VX, WX, XX, YX, ZX, _X, $X, aY, bY, cY, dY, eY, fY, gY, hY, iY, jY, kY, lY, mY, nY, oY, pY, qY, rY, sY, tY, uY, vY, wY, xY, yY, zY, AY, BY, CY, DY, EY, FY, GY, HY, IY, JY, KY, LY, MY, NY, OY, PY, QY, RY, SY, TY, UY, VY, WY, XY, YY, ZY, _Y, $Y, aZ, bZ, cZ, dZ, eZ, fZ, gZ, hZ, iZ, jZ, kZ, lZ, mZ, nZ, oZ, pZ, qZ, rZ, sZ, tZ, uZ, vZ, wZ, xZ, yZ, zZ, AZ, BZ, CZ, DZ, EZ, FZ, GZ, HZ, IZ, JZ, KZ, LZ, MZ, NZ, OZ, PZ, QZ, RZ, SZ, TZ, UZ, VZ, WZ, XZ, YZ, ZZ, _Z, $Z, a_, b_, c_, d_, e_, f_, g_, h_, i_, j_, k_, l_, m_, n_, o_, p_, q_, r_, s_, t_, u_, v_, w_, x_, y_, z_, A_, B_, C_, D_, E_, F_, G_, H_, I_, J_, K_, L_, M_, N_, O_, P_, Q_, R_, S_, T_, U_, V_, W_, X_, Y_, Z_, __, $_, a$, b$, c$, d$, e$, f$, g$, h$, i$, j$, k$, l$, m$, n$, o$, p$, q$, r$, s$, t$, u$, v$, w$, x$, y$, z$, A$, B$, pN, C$, D$, E$, F$, vN, G$, H$, I$, J$, K$, L$, M$, N$, O$, P$, Q$, R$, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU, GU];
	            var vb = [S$, T$, U$, V$, W$, yc, X$, Y$, Z$, _$, $$, a0, b0, c0, d0, e0, f0, g0, h0, i0, j0, k0, l0, m0, n0, o0, p0, q0, r0, s0, Xk, t0, u0, v0, w0, x0, y0, z0, A0, B0, UP, C0, D0, E0, F0, G0, H0, I0, J0, K0, L0, M0, N0, O0, P0, Q0, R0, S0, T0, U0, V0, W0, X0, Y0, Z0, _0, $0, a1, b1, c1, d1, e1, f1, g1, h1, i1, j1, k1, l1, m1, n1, o1, p1, q1, r1, s1, t1, u1, v1, w1, x1, y1, z1, A1, B1, C1, D1, E1, F1, G1, H1, I1, J1, K1, L1, M1, N1, O1, P1, Q1, R1, S1, T1, U1, V1, W1, X1, Y1, Z1, _1, $1, a2, b2, c2, d2, e2, f2, g2, h2, i2, j2, k2, l2, m2, n2, o2, p2, q2, r2, s2, t2, u2, v2, w2, x2, y2, z2, A2, B2, C2, D2, E2, F2, G2, H2, I2, J2, K2, L2, M2, N2, O2, P2, Q2, R2, S2, T2, U2, V2, W2, X2, Y2, Z2, _2, $2, a3, b3, c3, d3, e3, f3, g3, h3, i3, j3, k3, l3, m3, n3, o3, p3, q3, r3, s3, RT, t3, u3, v3, w3, Wk, x3, y3, ac, z3, gc, A3, B3, C3, D3, E3, F3, G3, H3, I3, J3, K3, L3, M3, N3, O3, P3, Q3, R3, S3, T3, U3, V3, W3, X3, Y3, Z3, _3, pk, $3, a4, $k, b4, cl, c4, el, fl, d4, e4, f4, g4, h4, i4, j4, k4, l4, m4, n4, o4, p4, q4, r4, s4, t4, u4, v4, w4, x4, y4, z4, A4, B4, C4, D4, E4, F4, G4, H4, I4, J4, K4, L4, M4, N4, O4, P4, Q4, R4, S4, T4, U4, V4, W4, X4, Y4, uu, Z4, _4, $4, vu, a5, b5, c5, d5, e5, f5, g5, h5, i5, j5, k5, l5, m5, n5, o5, p5, q5, r5, s5, t5, u5, v5, w5, Kx, x5, y5, z5, A5, B5, C5, D5, E5, F5, G5, H5, I5, J5, K5, UB, L5, M5, N5, O5, P5, Q5, R5, S5, T5, U5, V5, W5, X5, Y5, Z5, _5, $5, a6, b6, c6, d6, e6, rC, f6, g6, h6, i6, j6, k6, l6, m6, n6, o6, p6, q6, r6, GM, s6, t6, u6, v6, w6, x6, y6, z6, A6, B6, C6, D6, E6, F6, G6, H6, I6, J6, K6, L6, M6, hT, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$, S$];
	            var wb = [N6, O6, P6, Q6, R6, S6, T6, U6, V6, Cc, W6, X6, Y6, Z6, _6, $6, a7, b7, c7, d7, e7, f7, g7, h7, i7, j7, k7, l7, m7, n7, o7, p7, q7, r7, s7, t7, u7, v7, w7, x7, y7, z7, A7, B7, YP, C7, D7, E7, F7, G7, H7, I7, J7, K7, L7, M7, N7, O7, P7, Q7, R7, S7, T7, U7, V7, W7, X7, Y7, Z7, _7, $7, a8, b8, c8, d8, e8, f8, g8, h8, i8, j8, k8, l8, m8, n8, o8, p8, q8, r8, s8, t8, u8, v8, w8, x8, y8, z8, A8, B8, C8, D8, E8, F8, G8, H8, I8, J8, K8, L8, M8, N8, O8, P8, Q8, R8, S8, T8, U8, V8, W8, X8, Y8, Z8, _8, $8, a9, b9, c9, d9, e9, f9, g9, h9, i9, j9, k9, l9, m9, n9, o9, p9, q9, r9, s9, t9, u9, v9, w9, x9, y9, z9, A9, B9, C9, D9, E9, F9, G9, H9, I9, J9, K9, L9, M9, N9, O9, P9, Q9, R9, S9, T9, U9, V9, W9, X9, Y9, Z9, _9, $9, aaa, baa, caa, daa, eaa, faa, gaa, haa, iaa, jaa, kaa, laa, maa, naa, oaa, paa, qaa, raa, saa, taa, uaa, vaa, waa, xaa, yaa, zaa, Aaa, Baa, Caa, Daa, Eaa, Faa, Gaa, Haa, Iaa, Jaa, Kaa, Laa, Maa, Naa, Oaa, Paa, Qaa, Raa, Saa, Taa, Uaa, Vaa, Waa, Xaa, Yaa, Zaa, _aa, $aa, aba, bba, cba, dba, eba, fba, gba, hba, iba, jba, kba, lba, mba, nba, oba, pba, qba, rba, sba, tba, uba, vba, wba, xba, yba, zba, Aba, Bba, Cba, Dba, Eba, Fba, Gba, Hba, Iba, Jba, Kba, Lba, Mba, Nba, Oba, Pba, Qba, Rba, Sba, Tba, Uba, Vba, Wba, Xba, Yba, Zba, _ba, $ba, aca, bca, cca, dca, eca, fca, gca, hca, ica, jca, kca, lca, mca, nca, oca, pca, qca, rca, sca, tca, uca, vca, wca, xca, yca, zca, Aca, Bca, Cca, Dca, Eca, Fca, Gca, Hca, Ica, Jca, Kca, Lca, Mca, Nca, Oca, Pca, Qca, Rca, Sca, Tca, Uca, Vca, Wca, YB, Xca, Yca, Zca, _ca, $ca, ada, bda, cda, dda, eda, fda, gda, hda, ida, jda, kda, lda, mda, nda, oda, pda, qda, rda, sda, tda, uda, vda, wda, xda, yda, zda, Ada, Bda, Cda, Dda, Eda, Fda, Gda, Hda, Ida, Jda, Kda, Lda, Mda, Nda, Oda, Pda, Qda, Rda, Sda, Tda, Uda, Vda, Wda, Xda, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6, N6];
	            var xb = [Yda, Zda, _da, $da, aea, bea, cea, dea, eea, fea, gea, Ec, hea, iea, jea, kea, lea, mea, nea, oea, pea, qea, rea, sea, tea, uea, vea, wea, xea, yea, zea, Aea, Bea, Cea, Dea, Eea, Fea, Gea, Hea, Iea, Jea, Kea, Lea, Mea, Nea, Oea, $P, Pea, Qea, Rea, Sea, Tea, Uea, Vea, Wea, Xea, Yea, Zea, _ea, $ea, afa, bfa, cfa, dfa, efa, ffa, gfa, hfa, ifa, jfa, kfa, lfa, mfa, nfa, ofa, pfa, qfa, rfa, sfa, tfa, ufa, vfa, wfa, xfa, yfa, zfa, Afa, Bfa, Cfa, Dfa, Efa, Ffa, Gfa, Hfa, Ifa, Jfa, Kfa, Lfa, Mfa, Nfa, Ofa, Pfa, Qfa, Rfa, Sfa, Tfa, Ufa, Vfa, Wfa, Xfa, Yfa, Zfa, _fa, $fa, aga, bga, cga, dga, ega, fga, gga, hga, iga, jga, kga, lga, mga, nga, oga, pga, qga, rga, sga, tga, uga, vga, wga, xga, yga, zga, Aga, Bga, Cga, Dga, Ega, Fga, Gga, Hga, Iga, Jga, Kga, Lga, Mga, Nga, Oga, Pga, Qga, Rga, Sga, Tga, Uga, Vga, Wga, Xga, Yga, Zga, _ga, $ga, aha, bha, cha, dha, eha, fha, gha, hha, iha, jha, kha, lha, mha, nha, oha, pha, qha, rha, sha, tha, uha, vha, wha, xha, yha, zha, Aha, Bha, Cha, Dha, Eha, Fha, Gha, Hha, Iha, Jha, Kha, Lha, Mha, Nha, Oha, Pha, Qha, Rha, Sha, Tha, Uha, Vha, Wha, Xha, Yha, Zha, _ha, $ha, aia, bia, cia, dia, eia, fia, sh, gk, gia, hia, iia, jia, kia, lia, mia, nia, oia, pia, qia, ria, sia, tia, uia, via, wia, xia, yia, zia, Aia, Bia, Cia, Dia, Eia, Fia, Gia, Hia, Iia, Jia, Kia, Lia, Mia, Nia, Oia, Pia, Qia, Ria, Sia, Tia, Uia, Via, Wia, Xia, Yia, Zia, _ia, $ia, aja, bja, cja, dja, eja, fja, gja, hja, ija, jja, kja, lja, mja, nja, oja, pja, qja, rja, sja, tja, uja, vja, wja, xja, yja, zja, Aja, Bja, Cja, Dja, Eja, Fja, Gja, Hja, Ija, Jja, Kja, Lja, Mja, Nja, Oja, Pja, Qja, Rja, Sja, Tja, Uja, Vja, Wja, Xja, Yja, Zja, _ja, $ja, aka, bka, cka, dka, eka, fka, _B, gka, hka, ika, jka, kka, lka, mka, nka, oka, pka, qka, rka, ska, tka, uka, vka, wka, xka, yka, zka, Aka, Bka, Cka, Dka, Eka, Fka, Gka, Hka, Ika, Jka, Kka, Lka, Mka, Nka, Oka, Pka, Qka, Rka, Ska, Tka, Uka, Vka, Wka, Xka, Yka, Zka, _ka, $ka, ala, bla, cla, dla, ela, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda, Yda];
	            var yb = [fla, gla, hla, ila, jla, kla, lla, mla, nla, ola, pla, qla, rla, sla, tla, ula, vla, wla, xla, yla, zla, Ala, Bla, Cla, Dla, Ela, Fla, Gla, Hla, Ila, Jla, Kla, Lla, Mla, Nla, Ola, Pla, Qla, Rla, Sla, Tla, Ula, Vla, Wla, Xla, Yla, Zla, _la, $la, ama, bma, cma, dma, ema, fma, gma, hma, ima, jma, kma, lma, mma, nma, oma, pma, qma, rma, sma, tma, uma, vma, wma, xma, yma, zma, Ama, Bma, Cma, Dma, Ema, Fma, Gma, Hma, Ima, Jma, Kma, Lma, Mma, Nma, Oma, Pma, Qma, Rma, Sma, Tma, Uma, Vma, Wma, Xma, Yma, Zma, _ma, $ma, ana, bna, cna, dna, ena, fna, gna, hna, ina, jna, kna, lna, mna, nna, ona, pna, qna, rna, sna, tna, una, vna, wna, xna, yna, zna, Ana, Bna, Cna, Dna, Ena, Fna, Gna, Hna, Ina, Jna, Kna, Lna, Mna, Nna, Ona, Pna, Qna, Rna, Sna, Tna, Una, Vna, Wna, Xna, Yna, Zna, _na, $na, aoa, boa, coa, doa, eoa, foa, goa, hoa, ioa, joa, koa, loa, moa, noa, ooa, poa, qoa, roa, soa, toa, uoa, voa, woa, xoa, yoa, zoa, Aoa, Boa, Coa, Doa, Eoa, Foa, Goa, Hoa, Ioa, Joa, Koa, Loa, Moa, Noa, Ooa, Poa, Qoa, Roa, Soa, Toa, Uoa, Voa, Woa, Xoa, Yoa, Zoa, _oa, $oa, apa, bpa, cpa, dpa, epa, fpa, gpa, hpa, ipa, jpa, kpa, lpa, mpa, npa, opa, ppa, mk, qpa, rpa, spa, tpa, upa, vpa, wpa, xpa, ypa, zpa, Apa, Bpa, Cpa, Dpa, Epa, Fpa, Gpa, Hpa, Ipa, Jpa, Kpa, Lpa, Mpa, Npa, Opa, Ppa, Qpa, Rpa, Spa, Tpa, Upa, Vpa, Wpa, Xpa, Ypa, Zpa, _pa, $pa, aqa, bqa, cqa, dqa, eqa, fqa, gqa, hqa, iqa, jqa, kqa, lqa, mqa, nqa, oqa, pqa, qqa, rqa, sqa, tqa, uqa, vqa, wqa, xqa, yqa, zqa, Aqa, Bqa, Cqa, Dqa, Eqa, Fqa, Gqa, Hqa, Iqa, Jqa, Kqa, Lqa, Mqa, Nqa, Oqa, Pqa, Qqa, Rqa, Sqa, Tqa, Uqa, Vqa, Wqa, Xqa, Yqa, Zqa, _qa, $qa, ara, bra, cra, dra, era, fra, gra, hra, ira, jra, kra, lra, mra, nra, ora, pra, qra, rra, sra, tra, ura, vra, wra, xra, yra, zra, Ara, Bra, Cra, Dra, Era, Fra, Gra, Hra, Ira, Jra, Kra, Lra, Mra, Nra, Ora, Pra, Qra, Rra, Sra, Tra, Ura, Vra, Wra, Xra, Yra, Zra, _ra, $ra, asa, bsa, csa, dsa, esa, fsa, gsa, hsa, isa, jsa, ksa, lsa, msa, nsa, osa, psa, qsa, rsa, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla, fla];
	            var zb = [ssa, tsa, usa, vsa, wsa, xsa, ysa, zsa, Asa, Bsa, Csa, Dsa, Esa, Gc, Hc, Fsa, Gsa, Hsa, Isa, Jsa, Ksa, Lsa, Msa, Nsa, Osa, Psa, Qsa, Rsa, Ssa, Tsa, Usa, jT, Vsa, Wsa, Xsa, Ysa, Zsa, _sa, $sa, ata, bta, cta, dta, eta, fta, gta, hta, ita, bQ, cQ, jta, kta, lta, mta, nta, ota, pta, qta, rta, sta, tta, uta, vta, wta, xta, yta, zta, Ata, Bta, Cta, Dta, Eta, Fta, Gta, Hta, Ita, Jta, Kta, Lta, Mta, Nta, Ota, Pta, Qta, Rta, Sta, Tta, Uta, Vta, Wta, Xta, Yta, Zta, _ta, $ta, aua, bua, cua, dua, eua, fua, gua, hua, iua, jua, kua, lua, mua, nua, oua, pua, qua, rua, sua, tua, uua, vua, wua, xua, yua, zua, Aua, Bua, Cua, Dua, Eua, Fua, Gua, Hua, Iua, Jua, Kua, Lua, Mua, Nua, Oua, Pua, Qua, Rua, Sua, Tua, Uua, Vua, Wua, Xua, Yua, Zua, _ua, $ua, ava, bva, cva, dva, eva, fva, gva, hva, iva, jva, kva, lva, mva, nva, ova, pva, qva, rva, sva, tva, uva, vva, wva, xva, yva, zva, Ava, Bva, Cva, Dva, Eva, Fva, Gva, Hva, Iva, Jva, Kva, Lva, Mva, Nva, Ova, Pva, Qva, Rva, Sva, Tva, Vb, Uva, Vva, Wva, Xva, _b, $b, Yva, Zva, _va, hc, $va, awa, bwa, cwa, dwa, ewa, fwa, gwa, hwa, iwa, jwa, kwa, lwa, mwa, nwa, owa, pwa, qwa, rwa, swa, tg, twa, uwa, vwa, wwa, xwa, ywa, zwa, Awa, Bwa, Cwa, Dwa, Ewa, Fwa, Gwa, Hwa, nn, Iwa, sn, Jwa, xn, Kwa, Lwa, An, Bn, Mwa, Dn, Nwa, Owa, Pwa, Qwa, Rwa, Swa, Twa, Qq, Uwa, Vwa, Wwa, Xwa, Ywa, Zwa, _wa, $wa, axa, bxa, cxa, dxa, exa, fxa, gxa, hxa, ixa, jxa, kxa, lxa, mxa, nxa, oxa, pxa, qxa, rxa, sxa, txa, uxa, vxa, wxa, xxa, yxa, zxa, Axa, Bxa, Cxa, Dxa, Exa, Fxa, Gxa, Hxa, Ixa, Jxa, Kxa, Lxa, Mxa, Nxa, Oxa, Pxa, Qxa, Rxa, Sxa, Txa, Mw, Yw, Uxa, Vxa, Wxa, Xxa, Yxa, qB, Zxa, _xa, $xa, aya, bya, cya, dya, eya, fya, gya, hya, iya, jya, kya, lya, mya, nya, aC, bC, oya, pya, qya, rya, sya, tya, uya, vya, wya, xya, yya, zya, Aya, Bya, uC, Cya, Dya, Eya, VA, Fya, Gya, Hya, Iya, Jya, Kya, Lya, Mya, Nya, Oya, UM, Pya, Qya, Rya, Sya, Tya, Uya, Vya, Wya, Xya, Yya, Zya, _ya, $ya, aza, bza, cza, dza, eza, fza, gza, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa, ssa];
	            var Ab = [hza, iza, jza, kza, lza, mza, nza, oza, pza, qza, rza, sza, Fc, tza, uza, vza, Xc, Ic, wza, xza, yza, Mc, zza, Aza, Bza, Cza, Dza, Eza, Fza, Gza, Hza, Iza, Jza, Kza, Lza, Mza, Nza, Oza, Pza, Qza, Rza, Sza, Tza, Uza, Vza, Wza, Xza, aQ, Yza, Zza, _za, eQ, hQ, $za, aAa, lQ, bAa, cAa, dAa, eAa, fAa, gAa, hAa, iAa, jAa, kAa, lAa, mAa, nAa, oAa, pAa, qAa, rAa, sAa, tAa, uAa, vAa, wAa, xAa, yAa, zAa, AAa, BAa, CAa, DAa, EAa, FAa, GAa, HAa, IAa, JAa, KAa, LAa, MAa, NAa, OAa, PAa, QAa, RAa, SAa, TAa, UAa, VAa, WAa, XAa, YAa, ZAa, _Aa, $Aa, aBa, bBa, cBa, dBa, eBa, fBa, gBa, hBa, iBa, jBa, kBa, lBa, mBa, nBa, oBa, pBa, qBa, rBa, sBa, tBa, uBa, vBa, wBa, xBa, yBa, zBa, ABa, BBa, CBa, DBa, EBa, FBa, GBa, HBa, IBa, JBa, KBa, LBa, MBa, NBa, OBa, PBa, QBa, RBa, SBa, TBa, UBa, VBa, WBa, XBa, YBa, ZBa, _Ba, $Ba, aCa, bCa, cCa, dCa, eCa, fCa, gCa, hCa, iCa, jCa, kCa, lCa, mCa, nCa, oCa, pCa, qCa, rCa, sCa, tCa, uCa, vCa, wCa, xCa, yCa, zCa, ACa, BCa, CCa, DCa, ECa, FCa, GCa, HCa, ICa, JCa, KCa, LCa, MCa, NCa, OCa, PCa, QCa, RCa, SCa, TCa, UCa, VCa, md, WCa, XCa, YCa, ZCa, _Ca, $Ca, aDa, bDa, cDa, dDa, eDa, fDa, gDa, hDa, iDa, jDa, kDa, lDa, mDa, nDa, oDa, pDa, qDa, rDa, sDa, tDa, uDa, vDa, wDa, xDa, yDa, zDa, ADa, BDa, CDa, DDa, zn, EDa, FDa, GDa, HDa, IDa, JDa, KDa, LDa, MDa, NDa, tq, ODa, Bs, Is, ns, ts, us, os, Es, Hs, ls, Fs, ps, Cs, nt, qs, zs, Tr, ms, Js, rs, ss, vs, ws, xs, ys, Gs, Ds, As, ot, PDa, QDa, RDa, SDa, TDa, UDa, VDa, WDa, XDa, YDa, ZDa, _Da, $Da, aEa, bEa, cEa, dEa, jv, pv, qv, rv, sv, tv, uv, vv, eEa, fEa, gEa, hEa, iEa, jEa, kEa, lEa, mEa, nEa, oEa, pEa, qEa, PB, rEa, sEa, tEa, uEa, vEa, wEa, xEa, yEa, zEa, AEa, BEa, $B, CEa, DEa, EEa, dC, FEa, GEa, HEa, IEa, JEa, KEa, LEa, MEa, mC, NEa, OEa, PEa, QEa, AD, REa, uF, SEa, TEa, xM, UEa, VEa, WEa, XEa, YEa, ZEa, _Ea, FM, $Ea, aFa, bFa, cFa, dFa, rN, eFa, fFa, gFa, wN, hFa, iFa, jFa, kFa, lFa, mFa, nFa, oFa, pFa, qFa, rFa, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza, hza];
	            var Bb = [sFa, tFa, uFa, vFa, wFa, xFa, yFa, zFa, AFa, BFa, CFa, DFa, EFa, FFa, GFa, HFa, IFa, JFa, KFa, LFa, MFa, NFa, OFa, PFa, QFa, RFa, SFa, TFa, UFa, VFa, WFa, XFa, YFa, ZFa, _Fa, $Fa, aGa, bGa, cGa, dGa, eGa, fGa, gGa, hGa, iGa, jGa, kGa, lGa, mGa, nGa, oGa, pGa, qGa, rGa, sGa, tGa, uGa, vGa, wGa, xGa, yGa, zGa, AGa, BGa, CGa, DGa, EGa, FGa, GGa, HGa, IGa, JGa, KGa, LGa, MGa, NGa, OGa, PGa, QGa, RGa, SGa, TGa, UGa, VGa, WGa, XGa, YGa, ZGa, _Ga, $Ga, aHa, bHa, cHa, dHa, eHa, fHa, gHa, hHa, iHa, jHa, kHa, lHa, mHa, nHa, oHa, pHa, qHa, rHa, sHa, tHa, uHa, vHa, wHa, xHa, yHa, zHa, AHa, BHa, CHa, DHa, EHa, FHa, GHa, HHa, IHa, JHa, KHa, LHa, MHa, NHa, OHa, PHa, QHa, RHa, SHa, THa, UHa, VHa, WHa, XHa, YHa, ZHa, _Ha, $Ha, aIa, bIa, cIa, dIa, eIa, fIa, gIa, hIa, iIa, jIa, kIa, lIa, mIa, nIa, oIa, pIa, qIa, rIa, sIa, tIa, uIa, vIa, wIa, xIa, yIa, zIa, AIa, BIa, CIa, DIa, EIa, FIa, GIa, HIa, IIa, JIa, KIa, LIa, MIa, NIa, OIa, PIa, QIa, RIa, SIa, TIa, UIa, VIa, WIa, XIa, YIa, ZIa, _Ia, $Ia, aJa, bJa, cJa, dJa, eJa, fJa, gJa, hJa, iJa, jJa, kJa, lJa, mJa, nJa, oJa, pJa, qJa, rJa, sJa, tJa, uJa, vJa, wJa, xJa, yJa, zJa, AJa, BJa, CJa, DJa, EJa, FJa, GJa, HJa, IJa, JJa, KJa, LJa, MJa, NJa, OJa, PJa, QJa, RJa, SJa, TJa, UJa, VJa, WJa, XJa, YJa, ZJa, _Ja, $Ja, aKa, bKa, cKa, dKa, eKa, fKa, gKa, hKa, iKa, jKa, kKa, lKa, mKa, nKa, oKa, pKa, qKa, rKa, sKa, tKa, uKa, vKa, wKa, xKa, yKa, zKa, AKa, BKa, CKa, DKa, EKa, FKa, GKa, HKa, IKa, JKa, KKa, LKa, MKa, NKa, OKa, PKa, QKa, RKa, SKa, TKa, UKa, VKa, WKa, XKa, YKa, ZKa, _Ka, $Ka, aLa, bLa, cLa, dLa, eLa, fLa, gLa, hLa, iLa, jLa, kLa, lLa, mLa, nLa, oLa, pLa, qLa, rLa, sLa, tLa, uLa, vLa, wLa, xLa, yLa, zLa, ALa, BLa, CLa, DLa, ELa, FLa, GLa, HLa, ILa, JLa, KLa, LLa, MLa, NLa, OLa, PLa, QLa, RLa, SLa, TLa, ULa, VLa, WLa, XLa, YLa, ZLa, _La, $La, aMa, bMa, cMa, dMa, eMa, fMa, gMa, hMa, iMa, jMa, kMa, lMa, mMa, nMa, oMa, qN, pMa, qMa, rMa, sMa, tMa, uMa, vMa, wMa, xMa, yMa, zMa, AMa, BMa, CMa, DMa, EMa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa, sFa];
	            var Cb = [FMa, GMa, vc, wc, xc, HMa, IMa, JMa, KMa, LMa, MMa, NMa, OMa, PMa, QMa, RMa, SMa, TMa, UMa, VMa, WMa, XMa, YMa, ZMa, _Ma, $Ma, aNa, bNa, cNa, dNa, eNa, fNa, iT, gNa, my, hNa, iNa, PP, QP, RP, jNa, kNa, lNa, mNa, nNa, oNa, pNa, qNa, rNa, sNa, tNa, uNa, vNa, wNa, xNa, yNa, zNa, ANa, BNa, CNa, DNa, LP, MP, NP, OP, ENa, NI, OI, PI, QI, RI, SI, TI, UI, VI, WI, XI, YI, ZI, _I, $I, aJ, bJ, cJ, dJ, eJ, fJ, gJ, hJ, iJ, jJ, kJ, lJ, mJ, nJ, oJ, pJ, qJ, rJ, sJ, tJ, uJ, vJ, wJ, xJ, yJ, zJ, AJ, BJ, CJ, DJ, EJ, FJ, GJ, HJ, IJ, JJ, KJ, LJ, MJ, NJ, OJ, PJ, QJ, RJ, SJ, TJ, UJ, VJ, WJ, XJ, YJ, ZJ, _J, $J, aK, bK, cK, dK, eK, fK, gK, hK, iK, jK, kK, lK, mK, nK, oK, pK, qK, rK, sK, tK, uK, vK, wK, xK, yK, zK, AK, BK, CK, DK, EK, FK, GK, HK, IK, JK, KK, LK, MK, NK, OK, PK, QK, RK, SK, TK, UK, VK, WK, XK, YK, ZK, _K, $K, aL, bL, cL, dL, eL, FNa, GNa, Wb, HNa, Yb, INa, JNa, KNa, LNa, MNa, NNa, ONa, PNa, QNa, RNa, SNa, nc, TNa, nd, UNa, VNa, WNa, XNa, YNa, ZNa, _Na, $Na, aOa, bOa, cOa, dOa, eOa, fOa, gOa, hOa, iOa, nk, ok, jOa, qk, _k, kOa, bl, lOa, dl, mOa, nOa, oOa, pOa, on, qOa, vn, rOa, yn, sOa, tOa, uOa, vOa, wOa, xOa, yOa, zOa, AOa, BOa, COa, DOa, EOa, FOa, GOa, HOa, IOa, JOa, KOa, LOa, MOa, NOa, OOa, POa, QOa, ROa, SOa, TOa, UOa, VOa, WOa, XOa, YOa, ZOa, _Oa, $Oa, aPa, bPa, cPa, dPa, ePa, fPa, gPa, hPa, iPa, jPa, kPa, lPa, mPa, nPa, oPa, pPa, qPa, rPa, sPa, tPa, uPa, vPa, wPa, xPa, yPa, zPa, APa, BPa, CPa, DPa, EPa, FPa, GPa, HPa, IPa, JPa, KPa, LPa, MPa, NPa, OPa, PPa, QPa, RPa, SPa, RB, SB, TB, TPa, UPa, VPa, WPa, XPa, YPa, ZPa, _Pa, $Pa, aQa, bQa, cQa, dQa, eQa, fQa, gQa, hQa, iQa, jQa, kQa, lQa, mQa, nQa, oQa, pQa, qQa, rQa, sQa, tQa, uQa, vQa, wQa, xQa, yQa, zQa, AQa, BQa, CQa, DQa, EQa, FQa, GQa, HQa, IQa, JQa, KQa, LQa, MQa, NQa, OQa, PQa, QQa, RQa, SQa, TQa, UQa, VQa, WQa, XQa, YQa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa, FMa];
	            var Db = [ZQa, _Qa, $Qa, aRa, bRa, cRa, dRa, eRa, fRa, gRa, hRa, iRa, jRa, kRa, lRa, Wc, mRa, nRa, Jc, Kc, Lc, oRa, Nc, Oc, Pc, pRa, Rc, qRa, rRa, sRa, tRa, uRa, vRa, wRa, xRa, Td, yRa, zRa, ARa, BRa, CRa, DRa, ERa, FRa, GRa, HRa, IRa, JRa, KRa, LRa, dQ, MRa, NRa, iQ, kQ, ORa, $d, _d, PRa, mQ, QRa, RRa, SRa, TRa, URa, jQ, VRa, WRa, XRa, YRa, ZRa, _Ra, $Ra, aSa, bSa, cSa, dSa, eSa, fSa, gSa, hSa, iSa, jSa, kSa, lSa, mSa, nSa, oSa, pSa, qSa, rSa, sSa, tSa, uSa, vSa, wSa, xSa, ySa, zSa, ASa, BSa, CSa, DSa, ESa, FSa, GSa, HSa, ISa, JSa, KSa, LSa, MSa, NSa, OSa, PSa, QSa, RSa, SSa, TSa, USa, VSa, WSa, XSa, YSa, ZSa, _Sa, $Sa, aTa, bTa, cTa, dTa, eTa, fTa, gTa, hTa, iTa, jTa, kTa, lTa, mTa, nTa, oTa, pTa, qTa, rTa, sTa, tTa, uTa, vTa, wTa, xTa, yTa, zTa, ATa, BTa, CTa, DTa, ETa, FTa, GTa, HTa, ITa, JTa, KTa, LTa, MTa, NTa, OTa, PTa, QTa, RTa, STa, TTa, UTa, VTa, WTa, XTa, YTa, ZTa, _Ta, $Ta, aUa, bUa, cUa, dUa, eUa, fUa, gUa, hUa, iUa, jUa, kUa, lUa, mUa, nUa, oUa, pUa, qUa, rUa, sUa, tUa, uUa, vUa, wUa, xUa, yUa, ic, jc, kc, lc, zUa, AUa, BUa, CUa, DUa, EUa, FUa, GUa, HUa, IUa, JUa, KUa, LUa, MUa, ae, be, NUa, OUa, PUa, QUa, RUa, SUa, TUa, UUa, VUa, WUa, XUa, YUa, ZUa, _Ua, $Ua, aVa, bVa, cVa, dVa, eVa, fVa, gVa, hVa, iVa, jVa, kVa, lVa, In, Rn, Sn, Tn, Un, mVa, nVa, oVa, pVa, qVa, rVa, sVa, tVa, uVa, vVa, wVa, xVa, yVa, zVa, AVa, BVa, CVa, DVa, EVa, FVa, GVa, HVa, IVa, JVa, KVa, LVa, MVa, NVa, OVa, PVa, QVa, RVa, SVa, TVa, UVa, VVa, WVa, XVa, YVa, ZVa, _Va, $Va, aWa, bWa, cWa, dWa, eWa, fWa, gWa, hWa, iWa, jWa, kWa, lWa, mWa, nWa, tw, oWa, pWa, qWa, rWa, sWa, tWa, uWa, vWa, wWa, xWa, NB, OB, yWa, zWa, AWa, BWa, CWa, DWa, EWa, FWa, GWa, HWa, IWa, JWa, KWa, LWa, MWa, cC, NWa, eC, fC, gC, OWa, PWa, jC, kC, lC, QWa, RWa, SWa, TWa, UWa, VWa, WWa, XWa, YWa, wM, ZWa, _Wa, $Wa, AM, BM, DM, EM, aXa, bXa, cXa, dXa, eXa, fXa, gXa, hXa, iXa, jXa, kXa, lXa, CN, mXa, vO, wO, nXa, sP, oXa, pXa, qXa, rXa, sXa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa, ZQa];
	            var Eb = [tXa, uXa, vXa, wXa, xXa, yXa, zXa, AXa, BXa, CXa, DXa, EXa, FXa, GXa, HXa, IXa, JXa, KXa, LXa, MXa, NXa, OXa, PXa, QXa, RXa, SXa, TXa, UXa, Tc, VXa, WXa, XXa, YXa, ZXa, _Xa, $Xa, aYa, bYa, cYa, dYa, eYa, fYa, gYa, hYa, iYa, jYa, kYa, lYa, mYa, nYa, oYa, pYa, qYa, rYa, sYa, tYa, uYa, vYa, wYa, xYa, yYa, zYa, AYa, BYa, CYa, DYa, EYa, FYa, GYa, HYa, IYa, JYa, KYa, LYa, MYa, NYa, OYa, PYa, QYa, RYa, SYa, TYa, UYa, VYa, WYa, XYa, YYa, ZYa, _Ya, $Ya, aZa, bZa, cZa, dZa, eZa, fZa, gZa, hZa, iZa, jZa, kZa, lZa, mZa, nZa, oZa, pZa, qZa, rZa, sZa, tZa, uZa, vZa, wZa, xZa, yZa, zZa, AZa, BZa, CZa, DZa, EZa, FZa, GZa, HZa, IZa, JZa, KZa, LZa, MZa, NZa, OZa, PZa, QZa, RZa, SZa, TZa, UZa, VZa, WZa, XZa, YZa, ZZa, _Za, $Za, a_a, b_a, c_a, d_a, e_a, f_a, g_a, h_a, i_a, j_a, k_a, l_a, m_a, n_a, o_a, p_a, q_a, r_a, s_a, t_a, u_a, v_a, w_a, x_a, y_a, z_a, A_a, B_a, C_a, D_a, E_a, F_a, G_a, H_a, I_a, J_a, K_a, L_a, M_a, N_a, O_a, P_a, Q_a, R_a, S_a, T_a, U_a, V_a, W_a, X_a, Y_a, Z_a, __a, $_a, a$a, b$a, c$a, d$a, e$a, f$a, g$a, h$a, i$a, j$a, k$a, l$a, m$a, n$a, o$a, p$a, q$a, r$a, s$a, t$a, u$a, v$a, w$a, x$a, y$a, z$a, A$a, B$a, C$a, D$a, E$a, F$a, G$a, H$a, I$a, J$a, K$a, L$a, M$a, N$a, O$a, P$a, Q$a, R$a, S$a, T$a, U$a, V$a, W$a, X$a, Y$a, Z$a, _$a, $$a, a0a, b0a, c0a, d0a, e0a, f0a, g0a, h0a, i0a, j0a, k0a, l0a, m0a, n0a, o0a, p0a, q0a, r0a, s0a, t0a, u0a, v0a, w0a, x0a, y0a, z0a, A0a, B0a, C0a, D0a, E0a, F0a, G0a, H0a, I0a, J0a, K0a, L0a, M0a, N0a, O0a, P0a, Q0a, R0a, S0a, T0a, U0a, V0a, W0a, X0a, Y0a, Z0a, _0a, $0a, a1a, b1a, c1a, d1a, e1a, f1a, g1a, h1a, i1a, j1a, k1a, l1a, m1a, n1a, o1a, p1a, q1a, LB, r1a, s1a, t1a, u1a, v1a, w1a, x1a, y1a, z1a, A1a, B1a, C1a, D1a, E1a, F1a, G1a, H1a, I1a, J1a, K1a, L1a, M1a, N1a, O1a, P1a, Q1a, R1a, S1a, T1a, nC, U1a, V1a, W1a, X1a, Y1a, Z1a, _1a, $1a, a2a, yM, b2a, c2a, d2a, e2a, f2a, g2a, h2a, i2a, j2a, k2a, l2a, m2a, n2a, o2a, p2a, q2a, r2a, s2a, t2a, u2a, v2a, w2a, x2a, fQ, y2a, z2a, A2a, B2a, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa, tXa];
	            var Fb = [C2a, D2a, E2a, F2a, G2a, H2a, I2a, J2a, K2a, L2a, M2a, N2a, O2a, P2a, Q2a, R2a, S2a, T2a, U2a, V2a, W2a, X2a, Y2a, Z2a, _2a, $2a, a3a, b3a, c3a, d3a, e3a, f3a, g3a, h3a, i3a, j3a, k3a, l3a, m3a, n3a, o3a, p3a, q3a, r3a, s3a, t3a, u3a, v3a, w3a, x3a, y3a, z3a, A3a, B3a, C3a, D3a, E3a, F3a, G3a, H3a, I3a, J3a, K3a, L3a, M3a, N3a, O3a, P3a, Q3a, R3a, S3a, T3a, U3a, V3a, W3a, X3a, Y3a, Z3a, _3a, $3a, a4a, b4a, c4a, d4a, e4a, f4a, g4a, h4a, i4a, j4a, k4a, l4a, m4a, n4a, o4a, p4a, q4a, r4a, s4a, t4a, u4a, v4a, w4a, x4a, y4a, z4a, A4a, B4a, C4a, D4a, E4a, F4a, G4a, H4a, I4a, J4a, K4a, L4a, M4a, N4a, O4a, P4a, Q4a, R4a, S4a, T4a, U4a, V4a, W4a, X4a, Y4a, Z4a, _4a, $4a, a5a, b5a, c5a, d5a, e5a, f5a, g5a, h5a, i5a, j5a, k5a, l5a, m5a, n5a, o5a, p5a, q5a, r5a, s5a, t5a, u5a, v5a, w5a, x5a, y5a, z5a, A5a, B5a, C5a, D5a, E5a, F5a, G5a, H5a, I5a, J5a, K5a, L5a, M5a, N5a, O5a, P5a, Q5a, R5a, S5a, T5a, U5a, V5a, W5a, X5a, Y5a, Z5a, _5a, $5a, a6a, b6a, c6a, d6a, e6a, f6a, g6a, h6a, i6a, j6a, k6a, l6a, m6a, n6a, o6a, p6a, q6a, r6a, s6a, t6a, u6a, v6a, w6a, x6a, y6a, Kd, Ld, Md, Nd, Od, Pd, qd, rd, Qd, Rd, fo, z6a, A6a, B6a, C6a, D6a, E6a, F6a, G6a, H6a, I6a, J6a, K6a, L6a, M6a, N6a, O6a, P6a, gl, Q6a, R6a, S6a, T6a, U6a, V6a, W6a, X6a, Y6a, Z6a, _6a, $6a, a7a, b7a, c7a, d7a, e7a, f7a, g7a, h7a, i7a, j7a, k7a, l7a, m7a, n7a, o7a, p7a, q7a, r7a, s7a, t7a, u7a, v7a, w7a, x7a, y7a, z7a, A7a, B7a, C7a, D7a, E7a, F7a, G7a, H7a, I7a, J7a, K7a, L7a, M7a, N7a, O7a, P7a, Q7a, R7a, S7a, T7a, U7a, V7a, W7a, X7a, Y7a, Z7a, _7a, $7a, a8a, b8a, c8a, d8a, e8a, f8a, g8a, h8a, i8a, j8a, k8a, l8a, m8a, n8a, o8a, p8a, q8a, r8a, s8a, t8a, u8a, v8a, w8a, x8a, y8a, z8a, A8a, B8a, C8a, D8a, E8a, F8a, G8a, H8a, I8a, J8a, K8a, L8a, M8a, N8a, O8a, P8a, Q8a, R8a, S8a, T8a, U8a, V8a, W8a, X8a, Y8a, Z8a, _8a, $8a, a9a, b9a, c9a, d9a, e9a, f9a, g9a, h9a, i9a, j9a, k9a, l9a, m9a, n9a, o9a, p9a, q9a, r9a, s9a, t9a, u9a, v9a, w9a, x9a, y9a, z9a, A9a, WR, B9a, C9a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a, C2a];
	            var Gb = [D9a, E9a, F9a, G9a, H9a, I9a, J9a, Ac, K9a, L9a, M9a, N9a, O9a, P9a, Q9a, R9a, S9a, T9a, U9a, V9a, W9a, X9a, Y9a, Z9a, _9a, $9a, aab, bab, cab, dab, eab, fab, gab, hab, iab, jab, kab, lab, mab, nab, oab, pab, XP, qab, rab, sab, tab, uab, vab, wab, xab, yab, zab, Aab, Bab, Cab, Dab, Eab, Fab, Gab, Hab, Iab, Jab, Kab, Lab, Mab, Nab, Oab, Pab, Qab, Rab, Sab, Tab, Uab, Vab, Wab, Xab, Yab, Zab, _ab, $ab, abb, bbb, cbb, dbb, ebb, fbb, gbb, hbb, ibb, jbb, kbb, lbb, mbb, nbb, obb, pbb, qbb, rbb, sbb, tbb, ubb, vbb, wbb, xbb, ybb, zbb, Abb, Bbb, Cbb, Dbb, Ebb, Fbb, Gbb, Hbb, Ibb, Jbb, Kbb, Lbb, Mbb, Nbb, Obb, Pbb, Qbb, Rbb, Sbb, Tbb, Ubb, Vbb, Wbb, Xbb, Ybb, Zbb, _bb, $bb, acb, bcb, ccb, dcb, ecb, fcb, gcb, hcb, icb, jcb, kcb, lcb, mcb, ncb, ocb, pcb, qcb, rcb, scb, tcb, ucb, vcb, wcb, xcb, ycb, zcb, Acb, Bcb, Ccb, Dcb, Ecb, Fcb, Gcb, Hcb, Icb, Jcb, Kcb, Lcb, Mcb, Ncb, Ocb, Pcb, Qcb, Rcb, Scb, Tcb, Ucb, Vcb, Wcb, Xcb, Ycb, Zcb, _cb, $cb, adb, bdb, cdb, ddb, edb, fdb, gdb, hdb, idb, jdb, kdb, ldb, mdb, ndb, odb, pdb, qdb, rdb, sdb, tdb, udb, vdb, wdb, xdb, ydb, zdb, Adb, Bdb, Cdb, Ddb, Edb, Fdb, Gdb, Hdb, Idb, Jdb, Kdb, Ldb, Mdb, Ndb, Odb, Pdb, Qdb, Rdb, Sdb, Tdb, Udb, Vdb, Wdb, Xdb, Ydb, Zdb, _db, $db, aeb, beb, ceb, deb, eeb, feb, geb, heb, ieb, jeb, keb, leb, meb, neb, oeb, peb, qeb, reb, seb, teb, ueb, veb, web, xeb, yeb, zeb, Aeb, Beb, Ceb, Deb, Eeb, Feb, Geb, Heb, Ieb, Jeb, Keb, Leb, Meb, Neb, Oeb, Peb, Qeb, Reb, Seb, Teb, Ueb, Veb, Web, Xeb, Yeb, Zeb, _eb, $eb, afb, bfb, cfb, dfb, efb, ffb, gfb, hfb, ifb, jfb, kfb, lfb, mfb, nfb, ofb, pfb, qfb, rfb, sfb, tfb, ufb, vfb, wfb, xfb, yfb, zfb, Afb, Bfb, Cfb, Dfb, Efb, Ffb, Gfb, Hfb, Ifb, Jfb, Kfb, WB, Lfb, Mfb, Nfb, Ofb, Pfb, Qfb, Rfb, Sfb, Tfb, Ufb, Vfb, Wfb, Xfb, Yfb, Zfb, _fb, $fb, agb, bgb, cgb, dgb, egb, fgb, ggb, hgb, igb, jgb, kgb, lgb, mgb, ngb, ogb, pgb, qgb, rgb, sgb, tgb, ugb, vgb, wgb, xgb, ygb, zgb, Agb, Bgb, Cgb, Dgb, Egb, Fgb, Ggb, Hgb, Igb, Jgb, Kgb, Lgb, Mgb, Ngb, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a, D9a];
	            var Hb = [Ogb, Pgb, Qgb, Rgb, Sgb, Tgb, zc, Ugb, Vgb, Wgb, Xgb, Ygb, Zgb, _gb, $gb, ahb, bhb, chb, dhb, ehb, fhb, ghb, hhb, ihb, jhb, Qc, khb, lhb, mhb, nhb, ohb, phb, qhb, kT, rhb, shb, thb, uhb, vhb, whb, xhb, VP, yhb, zhb, Ahb, Bhb, Chb, Dhb, Ehb, Fhb, Ghb, Hhb, Ihb, Jhb, Khb, Lhb, Mhb, Nhb, WP, Ohb, Phb, Qhb, Rhb, Shb, Thb, Uhb, Vhb, Whb, Xhb, Yhb, Zhb, _hb, $hb, aib, bib, cib, dib, eib, fib, gib, hib, iib, jib, kib, lib, mib, nib, oib, pib, qib, rib, sib, tib, uib, vib, wib, xib, yib, zib, Aib, Bib, Cib, Dib, Eib, Fib, Gib, Hib, Iib, Jib, Kib, Lib, Mib, Nib, Oib, Pib, Qib, Rib, Sib, Tib, Uib, Vib, Wib, Xib, Yib, Zib, _ib, $ib, ajb, bjb, cjb, djb, ejb, fjb, gjb, hjb, ijb, jjb, kjb, ljb, mjb, njb, ojb, pjb, qjb, rjb, sjb, tjb, ujb, vjb, wjb, xjb, yjb, zjb, Ajb, Bjb, Cjb, Djb, Ejb, Fjb, Gjb, Hjb, Ijb, Jjb, Kjb, Ljb, Mjb, Njb, Ojb, Pjb, Qjb, Rjb, Sjb, Tjb, Ujb, Vjb, Wjb, Xjb, Yjb, Zjb, _jb, $jb, akb, bkb, ckb, dkb, ekb, fkb, gkb, hkb, ikb, jkb, kkb, lkb, mkb, nkb, okb, pkb, Xb, qkb, rkb, skb, tkb, ukb, vkb, wkb, xkb, ykb, zkb, Akb, Bkb, Ckb, Dkb, Ekb, Fkb, Gkb, Hkb, Ikb, Jkb, Kkb, Lkb, Mkb, Nkb, Okb, Pkb, Qkb, Rkb, Skb, Tkb, Ukb, Vkb, Wkb, Xkb, Ykb, Zkb, _kb, $kb, alb, blb, clb, dlb, elb, flb, glb, hlb, ilb, jlb, klb, llb, mlb, nlb, olb, Cn, plb, qlb, rlb, slb, tlb, ulb, _n, vlb, wlb, xlb, ylb, zlb, Alb, Blb, Clb, Dlb, Elb, Flb, Glb, Hlb, Ilb, Jlb, Klb, Llb, Mlb, Nlb, Olb, Plb, Qlb, Rlb, Slb, Tlb, Ulb, Vlb, Wlb, Xlb, Ylb, Zlb, ds, es, js, _lb, wu, $r, as, bs, hs, fs, is, cs, xu, gs, _r, dr, $lb, amb, bmb, cmb, dmb, emb, fmb, gmb, hmb, imb, jmb, kmb, $x, dy, fy, jy, lmb, mmb, nmb, omb, pmb, qmb, rmb, smb, tmb, umb, vmb, VB, wmb, xmb, ymb, zmb, Amb, Bmb, Cmb, Dmb, Emb, Fmb, Gmb, Hmb, Imb, hC, Jmb, Kmb, Lmb, Mmb, Nmb, Omb, Pmb, Qmb, Rmb, Smb, Tmb, Umb, Vmb, Wmb, Xmb, Ymb, Zmb, _mb, $mb, anb, bnb, cnb, dnb, enb, nN, fnb, gnb, hnb, inb, tN, jnb, knb, lnb, mnb, nnb, onb, pnb, qnb, rnb, snb, tnb, unb, QS, vnb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb, Ogb];
	            var Ib = [wnb, xnb, ynb, znb, Anb, Bnb, Cnb, Dnb, Enb, Fnb, Gnb, Hnb, Inb, Jnb, Knb, Lnb, Mnb, Nnb, Onb, Pnb, Qnb, Rnb, Snb, Tnb, Unb, Vnb, Wnb, Xnb, Ynb, Znb, _nb, $nb, aob, bob, cob, dob, eob, fob, gob, hob, iob, job, kob, lob, mob, nob, oob, pob, qob, rob, sob, tob, uob, vob, wob, xob, yob, zob, Aob, Bob, Cob, Dob, Eob, Fob, Gob, Hob, Iob, Job, Kob, Lob, Mob, Nob, Oob, Pob, Qob, Rob, Sob, Tob, Uob, Vob, Wob, Xob, Yob, Zob, _ob, $ob, apb, bpb, cpb, dpb, epb, fpb, gpb, hpb, ipb, jpb, kpb, lpb, mpb, npb, opb, ppb, qpb, rpb, spb, tpb, upb, vpb, wpb, xpb, ypb, zpb, Apb, Bpb, Cpb, Dpb, Epb, Fpb, Gpb, Hpb, Ipb, Jpb, Kpb, Lpb, Mpb, Npb, Opb, Ppb, Qpb, Rpb, Spb, Tpb, Upb, Vpb, Wpb, Xpb, Ypb, Zpb, _pb, $pb, aqb, bqb, cqb, dqb, eqb, fqb, gqb, hqb, iqb, jqb, kqb, lqb, mqb, nqb, oqb, pqb, qqb, rqb, sqb, tqb, uqb, vqb, wqb, xqb, yqb, zqb, Aqb, Bqb, Cqb, Dqb, Eqb, Fqb, Gqb, Hqb, Iqb, Jqb, Kqb, Lqb, Mqb, Nqb, Oqb, Pqb, Qqb, Rqb, Sqb, Tqb, Uqb, Vqb, Wqb, Xqb, Yqb, Zqb, _qb, $qb, arb, brb, crb, drb, erb, frb, grb, hrb, irb, jrb, krb, lrb, mrb, nrb, orb, prb, qrb, rrb, srb, trb, urb, vrb, wrb, xrb, yrb, zrb, Arb, Brb, Crb, Drb, Erb, Frb, Grb, Hrb, Irb, Jrb, Krb, Lrb, Mrb, Nrb, Orb, Prb, Qrb, Rrb, Srb, Trb, Urb, Vrb, Wrb, Xrb, Yrb, Zrb, _rb, $rb, asb, bsb, csb, dsb, esb, fsb, gsb, hsb, isb, jsb, ksb, lsb, msb, nsb, osb, psb, qsb, rsb, ssb, tsb, usb, vsb, wsb, xsb, ysb, zsb, Asb, Bsb, Csb, Dsb, Esb, Fsb, Gsb, Hsb, Isb, Jsb, Ksb, Lsb, Msb, Nsb, Osb, Psb, Qsb, Rsb, Ssb, Tsb, Usb, Vsb, Wsb, Xsb, Ysb, Zsb, _sb, $sb, atb, btb, ctb, dtb, etb, ftb, gtb, htb, itb, jtb, ktb, ltb, mtb, ntb, otb, ptb, qtb, rtb, stb, ttb, utb, vtb, wtb, xtb, ytb, ztb, Atb, Btb, Ctb, Dtb, Etb, Ftb, Gtb, Htb, Itb, Jtb, Ktb, Ltb, Mtb, Ntb, Otb, Ptb, Qtb, Rtb, Stb, Ttb, Utb, Vtb, Wtb, Xtb, Ytb, Ztb, _tb, $tb, aub, bub, cub, dub, eub, fub, gub, hub, iub, jub, kub, lub, mub, nub, oub, pub, qub, oN, rub, sub, tub, uub, uN, vub, wub, xub, yub, zub, Aub, Bub, Cub, Dub, Eub, Fub, Gub, Hub, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb, wnb];
	            var Jb = [Iub, uc, Jub, Kub, Lub, Mub, Nub, Oub, Bc, Pub, Dc, Qub, Rub, Sub, Tub, Uub, Vub, Wub, Xub, Yub, Zub, _ub, $ub, avb, bvb, cvb, dvb, Sc, evb, Uc, fvb, gvb, hvb, ivb, jvb, kvb, SP, lvb, mvb, nvb, ovb, pvb, qvb, _P, rvb, ZP, svb, tvb, uvb, vvb, wvb, xvb, yvb, zvb, Avb, Bvb, Cvb, Dvb, Evb, Fvb, TP, Gvb, Hvb, Ivb, Jvb, Kvb, Lvb, Mvb, Nvb, Ovb, Pvb, Qvb, Rvb, Svb, Tvb, Uvb, Vvb, Wvb, Xvb, Yvb, Zvb, _vb, $vb, awb, bwb, cwb, dwb, ewb, fwb, gwb, hwb, iwb, jwb, kwb, lwb, mwb, nwb, owb, pwb, qwb, rwb, swb, twb, uwb, vwb, wwb, xwb, ywb, zwb, Awb, Bwb, Cwb, Dwb, Ewb, Fwb, Gwb, Hwb, Iwb, Jwb, Kwb, Lwb, Mwb, Nwb, Owb, Pwb, Qwb, Rwb, Swb, Twb, Uwb, Vwb, Wwb, Xwb, Ywb, Zwb, _wb, $wb, axb, bxb, cxb, dxb, exb, fxb, gxb, hxb, ixb, jxb, kxb, lxb, mxb, nxb, oxb, pxb, qxb, rxb, sxb, txb, uxb, vxb, wxb, xxb, yxb, zxb, Axb, Bxb, Cxb, Dxb, Exb, Fxb, Gxb, Hxb, Ixb, Jxb, Kxb, Lxb, Mxb, Nxb, Oxb, Pxb, Qxb, Rxb, Sxb, Txb, Uxb, Vxb, Wxb, Xxb, Yxb, Zxb, _xb, $xb, ayb, byb, cyb, dyb, eyb, fyb, gyb, hyb, iyb, jyb, kyb, lyb, myb, nyb, oyb, pyb, qyb, ryb, syb, tyb, uyb, vyb, wyb, xyb, yyb, zyb, Ayb, Byb, Cyb, Dyb, Eyb, Fyb, Gyb, Hyb, Iyb, Jyb, Kyb, Lyb, Myb, Nyb, Oyb, Pyb, Qyb, Ryb, Syb, Tyb, Uyb, Vyb, Wyb, Xyb, Yyb, Zyb, _yb, $yb, azb, bzb, czb, dzb, ezb, fzb, gzb, hzb, izb, jzb, kzb, lzb, mzb, nzb, ozb, pzb, qzb, rzb, szb, tzb, uzb, vzb, wzb, xzb, yzb, zzb, Azb, Bzb, Czb, Dzb, Ezb, Fzb, Gzb, Hzb, Izb, Jzb, Kzb, Lzb, Mzb, Nzb, Ozb, Pzb, Qzb, Rzb, Szb, Tzb, Uzb, Vzb, Wzb, Xzb, Yzb, Zzb, _zb, $zb, aAb, bAb, cAb, dAb, eAb, fAb, gAb, hAb, iAb, jAb, kAb, lAb, mAb, nAb, oAb, pAb, qAb, rAb, sAb, tAb, uAb, vAb, wAb, xAb, yAb, MB, zAb, AAb, BAb, QB, CAb, DAb, EAb, FAb, GAb, HAb, XB, IAb, ZB, JAb, KAb, LAb, MAb, NAb, OAb, PAb, QAb, RAb, SAb, iC, TAb, UAb, VAb, WAb, XAb, oC, YAb, ZAb, _Ab, lF, $Ab, aBb, bBb, cBb, dBb, zM, eBb, fBb, gBb, hBb, iBb, jBb, kBb, lBb, mBb, nBb, oBb, pBb, qBb, rBb, sBb, tBb, uBb, GN, vBb, wBb, fP, xBb, yBb, gQ, zBb, ABb, BBb, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub, Iub];
	            return {
	                _i64Subtract: XT,
	                _strcat: _T,
	                _free: jT,
	                _main: Sb,
	                _realloc: kT,
	                _strncpy: aU,
	                _memmove: fU,
	                _bitshift64Ashr: YT,
	                _strlen: ZT,
	                _memset: cU,
	                _malloc: iT,
	                _i64Add: bU,
	                _memcpy: eU,
	                _llvm_ctlz_i32: hU,
	                _bitshift64Lshr: dU,
	                _strcpy: gU,
	                _bitshift64Shl: $T,
	                runPostSets: WT,
	                stackAlloc: Kb,
	                stackSave: Lb,
	                stackRestore: Mb,
	                setThrew: Nb,
	                setTempRet0: Qb,
	                getTempRet0: Rb,
	                dynCall_iiiiiiii: qU,
	                dynCall_iiii: rU,
	                dynCall_viiiiiii: sU,
	                dynCall_viiiii: tU,
	                dynCall_i: uU,
	                dynCall_vi: vU,
	                dynCall_vii: wU,
	                dynCall_iiiiiii: xU,
	                dynCall_ii: yU,
	                dynCall_viii: zU,
	                dynCall_viiiiiiiii: AU,
	                dynCall_iiiii: BU,
	                dynCall_viiiiii: CU,
	                dynCall_iii: DU,
	                dynCall_iiiiii: EU,
	                dynCall_viiii: FU
	            }
	        })


	        // EMSCRIPTEN_END_ASM
	        (Module.asmGlobalArg, Module.asmLibraryArg, buffer);
	        var _i64Subtract = Module["_i64Subtract"] = asm["_i64Subtract"];
	        var _strcat = Module["_strcat"] = asm["_strcat"];
	        var _free = Module["_free"] = asm["_free"];
	        var _main = Module["_main"] = asm["_main"];
	        var _realloc = Module["_realloc"] = asm["_realloc"];
	        var _strncpy = Module["_strncpy"] = asm["_strncpy"];
	        var _memmove = Module["_memmove"] = asm["_memmove"];
	        var _bitshift64Ashr = Module["_bitshift64Ashr"] = asm["_bitshift64Ashr"];
	        var _strlen = Module["_strlen"] = asm["_strlen"];
	        var _memset = Module["_memset"] = asm["_memset"];
	        var _malloc = Module["_malloc"] = asm["_malloc"];
	        var _i64Add = Module["_i64Add"] = asm["_i64Add"];
	        var _memcpy = Module["_memcpy"] = asm["_memcpy"];
	        var _llvm_ctlz_i32 = Module["_llvm_ctlz_i32"] = asm["_llvm_ctlz_i32"];
	        var _bitshift64Lshr = Module["_bitshift64Lshr"] = asm["_bitshift64Lshr"];
	        var _strcpy = Module["_strcpy"] = asm["_strcpy"];
	        var _bitshift64Shl = Module["_bitshift64Shl"] = asm["_bitshift64Shl"];
	        var runPostSets = Module["runPostSets"] = asm["runPostSets"];
	        var dynCall_iiiiiiii = Module["dynCall_iiiiiiii"] = asm["dynCall_iiiiiiii"];
	        var dynCall_iiii = Module["dynCall_iiii"] = asm["dynCall_iiii"];
	        var dynCall_viiiiiii = Module["dynCall_viiiiiii"] = asm["dynCall_viiiiiii"];
	        var dynCall_viiiii = Module["dynCall_viiiii"] = asm["dynCall_viiiii"];
	        var dynCall_i = Module["dynCall_i"] = asm["dynCall_i"];
	        var dynCall_vi = Module["dynCall_vi"] = asm["dynCall_vi"];
	        var dynCall_vii = Module["dynCall_vii"] = asm["dynCall_vii"];
	        var dynCall_iiiiiii = Module["dynCall_iiiiiii"] = asm["dynCall_iiiiiii"];
	        var dynCall_ii = Module["dynCall_ii"] = asm["dynCall_ii"];
	        var dynCall_viii = Module["dynCall_viii"] = asm["dynCall_viii"];
	        var dynCall_viiiiiiiii = Module["dynCall_viiiiiiiii"] = asm["dynCall_viiiiiiiii"];
	        var dynCall_iiiii = Module["dynCall_iiiii"] = asm["dynCall_iiiii"];
	        var dynCall_viiiiii = Module["dynCall_viiiiii"] = asm["dynCall_viiiiii"];
	        var dynCall_iii = Module["dynCall_iii"] = asm["dynCall_iii"];
	        var dynCall_iiiiii = Module["dynCall_iiiiii"] = asm["dynCall_iiiiii"];
	        var dynCall_viiii = Module["dynCall_viiii"] = asm["dynCall_viiii"];
	        Runtime.stackAlloc = asm["stackAlloc"];
	        Runtime.stackSave = asm["stackSave"];
	        Runtime.stackRestore = asm["stackRestore"];
	        Runtime.setTempRet0 = asm["setTempRet0"];
	        Runtime.getTempRet0 = asm["getTempRet0"];
	        var i64Math = (function () {
	            var goog = {math: {}};
	            goog.math.Long = (function (low, high) {
	                this.low_ = low | 0;
	                this.high_ = high | 0
	            });
	            goog.math.Long.IntCache_ = {};
	            goog.math.Long.fromInt = (function (value) {
	                if (-128 <= value && value < 128) {
	                    var cachedObj = goog.math.Long.IntCache_[value];
	                    if (cachedObj) {
	                        return cachedObj
	                    }
	                }
	                var obj = new goog.math.Long(value | 0, value < 0 ? -1 : 0);
	                if (-128 <= value && value < 128) {
	                    goog.math.Long.IntCache_[value] = obj
	                }
	                return obj
	            });
	            goog.math.Long.fromNumber = (function (value) {
	                if (isNaN(value) || !isFinite(value)) {
	                    return goog.math.Long.ZERO
	                } else if (value <= -goog.math.Long.TWO_PWR_63_DBL_) {
	                    return goog.math.Long.MIN_VALUE
	                } else if (value + 1 >= goog.math.Long.TWO_PWR_63_DBL_) {
	                    return goog.math.Long.MAX_VALUE
	                } else if (value < 0) {
	                    return goog.math.Long.fromNumber(-value).negate()
	                } else {
	                    return new goog.math.Long(value % goog.math.Long.TWO_PWR_32_DBL_ | 0, value / goog.math.Long.TWO_PWR_32_DBL_ | 0)
	                }
	            });
	            goog.math.Long.fromBits = (function (lowBits, highBits) {
	                return new goog.math.Long(lowBits, highBits)
	            });
	            goog.math.Long.fromString = (function (str, opt_radix) {
	                if (str.length == 0) {
	                    throw Error("number format error: empty string")
	                }
	                var radix = opt_radix || 10;
	                if (radix < 2 || 36 < radix) {
	                    throw Error("radix out of range: " + radix)
	                }
	                if (str.charAt(0) == "-") {
	                    return goog.math.Long.fromString(str.substring(1), radix).negate()
	                } else if (str.indexOf("-") >= 0) {
	                    throw Error('number format error: interior "-" character: ' + str)
	                }
	                var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 8));
	                var result = goog.math.Long.ZERO;
	                for (var i = 0; i < str.length; i += 8) {
	                    var size = Math.min(8, str.length - i);
	                    var value = parseInt(str.substring(i, i + size), radix);
	                    if (size < 8) {
	                        var power = goog.math.Long.fromNumber(Math.pow(radix, size));
	                        result = result.multiply(power).add(goog.math.Long.fromNumber(value))
	                    } else {
	                        result = result.multiply(radixToPower);
	                        result = result.add(goog.math.Long.fromNumber(value))
	                    }
	                }
	                return result
	            });
	            goog.math.Long.TWO_PWR_16_DBL_ = 1 << 16;
	            goog.math.Long.TWO_PWR_24_DBL_ = 1 << 24;
	            goog.math.Long.TWO_PWR_32_DBL_ = goog.math.Long.TWO_PWR_16_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;
	            goog.math.Long.TWO_PWR_31_DBL_ = goog.math.Long.TWO_PWR_32_DBL_ / 2;
	            goog.math.Long.TWO_PWR_48_DBL_ = goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;
	            goog.math.Long.TWO_PWR_64_DBL_ = goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_32_DBL_;
	            goog.math.Long.TWO_PWR_63_DBL_ = goog.math.Long.TWO_PWR_64_DBL_ / 2;
	            goog.math.Long.ZERO = goog.math.Long.fromInt(0);
	            goog.math.Long.ONE = goog.math.Long.fromInt(1);
	            goog.math.Long.NEG_ONE = goog.math.Long.fromInt(-1);
	            goog.math.Long.MAX_VALUE = goog.math.Long.fromBits(4294967295 | 0, 2147483647 | 0);
	            goog.math.Long.MIN_VALUE = goog.math.Long.fromBits(0, 2147483648 | 0);
	            goog.math.Long.TWO_PWR_24_ = goog.math.Long.fromInt(1 << 24);
	            goog.math.Long.prototype.toInt = (function () {
	                return this.low_
	            });
	            goog.math.Long.prototype.toNumber = (function () {
	                return this.high_ * goog.math.Long.TWO_PWR_32_DBL_ + this.getLowBitsUnsigned()
	            });
	            goog.math.Long.prototype.toString = (function (opt_radix) {
	                var radix = opt_radix || 10;
	                if (radix < 2 || 36 < radix) {
	                    throw Error("radix out of range: " + radix)
	                }
	                if (this.isZero()) {
	                    return "0"
	                }
	                if (this.isNegative()) {
	                    if (this.equals(goog.math.Long.MIN_VALUE)) {
	                        var radixLong = goog.math.Long.fromNumber(radix);
	                        var div = this.div(radixLong);
	                        var rem = div.multiply(radixLong).subtract(this);
	                        return div.toString(radix) + rem.toInt().toString(radix)
	                    } else {
	                        return "-" + this.negate().toString(radix)
	                    }
	                }
	                var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 6));
	                var rem = this;
	                var result = "";
	                while (true) {
	                    var remDiv = rem.div(radixToPower);
	                    var intval = rem.subtract(remDiv.multiply(radixToPower)).toInt();
	                    var digits = intval.toString(radix);
	                    rem = remDiv;
	                    if (rem.isZero()) {
	                        return digits + result
	                    } else {
	                        while (digits.length < 6) {
	                            digits = "0" + digits
	                        }
	                        result = "" + digits + result
	                    }
	                }
	            });
	            goog.math.Long.prototype.getHighBits = (function () {
	                return this.high_
	            });
	            goog.math.Long.prototype.getLowBits = (function () {
	                return this.low_
	            });
	            goog.math.Long.prototype.getLowBitsUnsigned = (function () {
	                return this.low_ >= 0 ? this.low_ : goog.math.Long.TWO_PWR_32_DBL_ + this.low_
	            });
	            goog.math.Long.prototype.getNumBitsAbs = (function () {
	                if (this.isNegative()) {
	                    if (this.equals(goog.math.Long.MIN_VALUE)) {
	                        return 64
	                    } else {
	                        return this.negate().getNumBitsAbs()
	                    }
	                } else {
	                    var val = this.high_ != 0 ? this.high_ : this.low_;
	                    for (var bit = 31; bit > 0; bit--) {
	                        if ((val & 1 << bit) != 0) {
	                            break
	                        }
	                    }
	                    return this.high_ != 0 ? bit + 33 : bit + 1
	                }
	            });
	            goog.math.Long.prototype.isZero = (function () {
	                return this.high_ == 0 && this.low_ == 0
	            });
	            goog.math.Long.prototype.isNegative = (function () {
	                return this.high_ < 0
	            });
	            goog.math.Long.prototype.isOdd = (function () {
	                return (this.low_ & 1) == 1
	            });
	            goog.math.Long.prototype.equals = (function (other) {
	                return this.high_ == other.high_ && this.low_ == other.low_
	            });
	            goog.math.Long.prototype.notEquals = (function (other) {
	                return this.high_ != other.high_ || this.low_ != other.low_
	            });
	            goog.math.Long.prototype.lessThan = (function (other) {
	                return this.compare(other) < 0
	            });
	            goog.math.Long.prototype.lessThanOrEqual = (function (other) {
	                return this.compare(other) <= 0
	            });
	            goog.math.Long.prototype.greaterThan = (function (other) {
	                return this.compare(other) > 0
	            });
	            goog.math.Long.prototype.greaterThanOrEqual = (function (other) {
	                return this.compare(other) >= 0
	            });
	            goog.math.Long.prototype.compare = (function (other) {
	                if (this.equals(other)) {
	                    return 0
	                }
	                var thisNeg = this.isNegative();
	                var otherNeg = other.isNegative();
	                if (thisNeg && !otherNeg) {
	                    return -1
	                }
	                if (!thisNeg && otherNeg) {
	                    return 1
	                }
	                if (this.subtract(other).isNegative()) {
	                    return -1
	                } else {
	                    return 1
	                }
	            });
	            goog.math.Long.prototype.negate = (function () {
	                if (this.equals(goog.math.Long.MIN_VALUE)) {
	                    return goog.math.Long.MIN_VALUE
	                } else {
	                    return this.not().add(goog.math.Long.ONE)
	                }
	            });
	            goog.math.Long.prototype.add = (function (other) {
	                var a48 = this.high_ >>> 16;
	                var a32 = this.high_ & 65535;
	                var a16 = this.low_ >>> 16;
	                var a00 = this.low_ & 65535;
	                var b48 = other.high_ >>> 16;
	                var b32 = other.high_ & 65535;
	                var b16 = other.low_ >>> 16;
	                var b00 = other.low_ & 65535;
	                var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
	                c00 += a00 + b00;
	                c16 += c00 >>> 16;
	                c00 &= 65535;
	                c16 += a16 + b16;
	                c32 += c16 >>> 16;
	                c16 &= 65535;
	                c32 += a32 + b32;
	                c48 += c32 >>> 16;
	                c32 &= 65535;
	                c48 += a48 + b48;
	                c48 &= 65535;
	                return goog.math.Long.fromBits(c16 << 16 | c00, c48 << 16 | c32)
	            });
	            goog.math.Long.prototype.subtract = (function (other) {
	                return this.add(other.negate())
	            });
	            goog.math.Long.prototype.multiply = (function (other) {
	                if (this.isZero()) {
	                    return goog.math.Long.ZERO
	                } else if (other.isZero()) {
	                    return goog.math.Long.ZERO
	                }
	                if (this.equals(goog.math.Long.MIN_VALUE)) {
	                    return other.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO
	                } else if (other.equals(goog.math.Long.MIN_VALUE)) {
	                    return this.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO
	                }
	                if (this.isNegative()) {
	                    if (other.isNegative()) {
	                        return this.negate().multiply(other.negate())
	                    } else {
	                        return this.negate().multiply(other).negate()
	                    }
	                } else if (other.isNegative()) {
	                    return this.multiply(other.negate()).negate()
	                }
	                if (this.lessThan(goog.math.Long.TWO_PWR_24_) && other.lessThan(goog.math.Long.TWO_PWR_24_)) {
	                    return goog.math.Long.fromNumber(this.toNumber() * other.toNumber())
	                }
	                var a48 = this.high_ >>> 16;
	                var a32 = this.high_ & 65535;
	                var a16 = this.low_ >>> 16;
	                var a00 = this.low_ & 65535;
	                var b48 = other.high_ >>> 16;
	                var b32 = other.high_ & 65535;
	                var b16 = other.low_ >>> 16;
	                var b00 = other.low_ & 65535;
	                var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
	                c00 += a00 * b00;
	                c16 += c00 >>> 16;
	                c00 &= 65535;
	                c16 += a16 * b00;
	                c32 += c16 >>> 16;
	                c16 &= 65535;
	                c16 += a00 * b16;
	                c32 += c16 >>> 16;
	                c16 &= 65535;
	                c32 += a32 * b00;
	                c48 += c32 >>> 16;
	                c32 &= 65535;
	                c32 += a16 * b16;
	                c48 += c32 >>> 16;
	                c32 &= 65535;
	                c32 += a00 * b32;
	                c48 += c32 >>> 16;
	                c32 &= 65535;
	                c48 += a48 * b00 + a32 * b16 + a16 * b32 + a00 * b48;
	                c48 &= 65535;
	                return goog.math.Long.fromBits(c16 << 16 | c00, c48 << 16 | c32)
	            });
	            goog.math.Long.prototype.div = (function (other) {
	                if (other.isZero()) {
	                    throw Error("division by zero")
	                } else if (this.isZero()) {
	                    return goog.math.Long.ZERO
	                }
	                if (this.equals(goog.math.Long.MIN_VALUE)) {
	                    if (other.equals(goog.math.Long.ONE) || other.equals(goog.math.Long.NEG_ONE)) {
	                        return goog.math.Long.MIN_VALUE
	                    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
	                        return goog.math.Long.ONE
	                    } else {
	                        var halfThis = this.shiftRight(1);
	                        var approx = halfThis.div(other).shiftLeft(1);
	                        if (approx.equals(goog.math.Long.ZERO)) {
	                            return other.isNegative() ? goog.math.Long.ONE : goog.math.Long.NEG_ONE
	                        } else {
	                            var rem = this.subtract(other.multiply(approx));
	                            var result = approx.add(rem.div(other));
	                            return result
	                        }
	                    }
	                } else if (other.equals(goog.math.Long.MIN_VALUE)) {
	                    return goog.math.Long.ZERO
	                }
	                if (this.isNegative()) {
	                    if (other.isNegative()) {
	                        return this.negate().div(other.negate())
	                    } else {
	                        return this.negate().div(other).negate()
	                    }
	                } else if (other.isNegative()) {
	                    return this.div(other.negate()).negate()
	                }
	                var res = goog.math.Long.ZERO;
	                var rem = this;
	                while (rem.greaterThanOrEqual(other)) {
	                    var approx = Math.max(1, Math.floor(rem.toNumber() / other.toNumber()));
	                    var log2 = Math.ceil(Math.log(approx) / Math.LN2);
	                    var delta = log2 <= 48 ? 1 : Math.pow(2, log2 - 48);
	                    var approxRes = goog.math.Long.fromNumber(approx);
	                    var approxRem = approxRes.multiply(other);
	                    while (approxRem.isNegative() || approxRem.greaterThan(rem)) {
	                        approx -= delta;
	                        approxRes = goog.math.Long.fromNumber(approx);
	                        approxRem = approxRes.multiply(other)
	                    }
	                    if (approxRes.isZero()) {
	                        approxRes = goog.math.Long.ONE
	                    }
	                    res = res.add(approxRes);
	                    rem = rem.subtract(approxRem)
	                }
	                return res
	            });
	            goog.math.Long.prototype.modulo = (function (other) {
	                return this.subtract(this.div(other).multiply(other))
	            });
	            goog.math.Long.prototype.not = (function () {
	                return goog.math.Long.fromBits(~this.low_, ~this.high_)
	            });
	            goog.math.Long.prototype.and = (function (other) {
	                return goog.math.Long.fromBits(this.low_ & other.low_, this.high_ & other.high_)
	            });
	            goog.math.Long.prototype.or = (function (other) {
	                return goog.math.Long.fromBits(this.low_ | other.low_, this.high_ | other.high_)
	            });
	            goog.math.Long.prototype.xor = (function (other) {
	                return goog.math.Long.fromBits(this.low_ ^ other.low_, this.high_ ^ other.high_)
	            });
	            goog.math.Long.prototype.shiftLeft = (function (numBits) {
	                numBits &= 63;
	                if (numBits == 0) {
	                    return this
	                } else {
	                    var low = this.low_;
	                    if (numBits < 32) {
	                        var high = this.high_;
	                        return goog.math.Long.fromBits(low << numBits, high << numBits | low >>> 32 - numBits)
	                    } else {
	                        return goog.math.Long.fromBits(0, low << numBits - 32)
	                    }
	                }
	            });
	            goog.math.Long.prototype.shiftRight = (function (numBits) {
	                numBits &= 63;
	                if (numBits == 0) {
	                    return this
	                } else {
	                    var high = this.high_;
	                    if (numBits < 32) {
	                        var low = this.low_;
	                        return goog.math.Long.fromBits(low >>> numBits | high << 32 - numBits, high >> numBits)
	                    } else {
	                        return goog.math.Long.fromBits(high >> numBits - 32, high >= 0 ? 0 : -1)
	                    }
	                }
	            });
	            goog.math.Long.prototype.shiftRightUnsigned = (function (numBits) {
	                numBits &= 63;
	                if (numBits == 0) {
	                    return this
	                } else {
	                    var high = this.high_;
	                    if (numBits < 32) {
	                        var low = this.low_;
	                        return goog.math.Long.fromBits(low >>> numBits | high << 32 - numBits, high >>> numBits)
	                    } else if (numBits == 32) {
	                        return goog.math.Long.fromBits(high, 0)
	                    } else {
	                        return goog.math.Long.fromBits(high >>> numBits - 32, 0)
	                    }
	                }
	            });
	            var navigator = {appName: "Modern Browser"};
	            var dbits;
	            var canary = 0xdeadbeefcafe;
	            var j_lm = (canary & 16777215) == 15715070;

	            function BigInteger(a, b, c) {
	                if (a != null)if ("number" == typeof a)this.fromNumber(a, b, c); else if (b == null && "string" != typeof a)this.fromString(a, 256); else this.fromString(a, b)
	            }

	            function nbi() {
	                return new BigInteger(null)
	            }

	            function am1(i, x, w, j, c, n) {
	                while (--n >= 0) {
	                    var v = x * this[i++] + w[j] + c;
	                    c = Math.floor(v / 67108864);
	                    w[j++] = v & 67108863
	                }
	                return c
	            }

	            function am2(i, x, w, j, c, n) {
	                var xl = x & 32767, xh = x >> 15;
	                while (--n >= 0) {
	                    var l = this[i] & 32767;
	                    var h = this[i++] >> 15;
	                    var m = xh * l + h * xl;
	                    l = xl * l + ((m & 32767) << 15) + w[j] + (c & 1073741823);
	                    c = (l >>> 30) + (m >>> 15) + xh * h + (c >>> 30);
	                    w[j++] = l & 1073741823
	                }
	                return c
	            }

	            function am3(i, x, w, j, c, n) {
	                var xl = x & 16383, xh = x >> 14;
	                while (--n >= 0) {
	                    var l = this[i] & 16383;
	                    var h = this[i++] >> 14;
	                    var m = xh * l + h * xl;
	                    l = xl * l + ((m & 16383) << 14) + w[j] + c;
	                    c = (l >> 28) + (m >> 14) + xh * h;
	                    w[j++] = l & 268435455
	                }
	                return c
	            }

	            if (j_lm && navigator.appName == "Microsoft Internet Explorer") {
	                BigInteger.prototype.am = am2;
	                dbits = 30
	            } else if (j_lm && navigator.appName != "Netscape") {
	                BigInteger.prototype.am = am1;
	                dbits = 26
	            } else {
	                BigInteger.prototype.am = am3;
	                dbits = 28
	            }
	            BigInteger.prototype.DB = dbits;
	            BigInteger.prototype.DM = (1 << dbits) - 1;
	            BigInteger.prototype.DV = 1 << dbits;
	            var BI_FP = 52;
	            BigInteger.prototype.FV = Math.pow(2, BI_FP);
	            BigInteger.prototype.F1 = BI_FP - dbits;
	            BigInteger.prototype.F2 = 2 * dbits - BI_FP;
	            var BI_RM = "0123456789abcdefghijklmnopqrstuvwxyz";
	            var BI_RC = new Array;
	            var rr, vv;
	            rr = "0".charCodeAt(0);
	            for (vv = 0; vv <= 9; ++vv)BI_RC[rr++] = vv;
	            rr = "a".charCodeAt(0);
	            for (vv = 10; vv < 36; ++vv)BI_RC[rr++] = vv;
	            rr = "A".charCodeAt(0);
	            for (vv = 10; vv < 36; ++vv)BI_RC[rr++] = vv;
	            function int2char(n) {
	                return BI_RM.charAt(n)
	            }

	            function intAt(s, i) {
	                var c = BI_RC[s.charCodeAt(i)];
	                return c == null ? -1 : c
	            }

	            function bnpCopyTo(r) {
	                for (var i = this.t - 1; i >= 0; --i)r[i] = this[i];
	                r.t = this.t;
	                r.s = this.s
	            }

	            function bnpFromInt(x) {
	                this.t = 1;
	                this.s = x < 0 ? -1 : 0;
	                if (x > 0)this[0] = x; else if (x < -1)this[0] = x + DV; else this.t = 0
	            }

	            function nbv(i) {
	                var r = nbi();
	                r.fromInt(i);
	                return r
	            }

	            function bnpFromString(s, b) {
	                var k;
	                if (b == 16)k = 4; else if (b == 8)k = 3; else if (b == 256)k = 8; else if (b == 2)k = 1; else if (b == 32)k = 5; else if (b == 4)k = 2; else {
	                    this.fromRadix(s, b);
	                    return
	                }
	                this.t = 0;
	                this.s = 0;
	                var i = s.length, mi = false, sh = 0;
	                while (--i >= 0) {
	                    var x = k == 8 ? s[i] & 255 : intAt(s, i);
	                    if (x < 0) {
	                        if (s.charAt(i) == "-")mi = true;
	                        continue
	                    }
	                    mi = false;
	                    if (sh == 0)this[this.t++] = x; else if (sh + k > this.DB) {
	                        this[this.t - 1] |= (x & (1 << this.DB - sh) - 1) << sh;
	                        this[this.t++] = x >> this.DB - sh
	                    } else this[this.t - 1] |= x << sh;
	                    sh += k;
	                    if (sh >= this.DB)sh -= this.DB
	                }
	                if (k == 8 && (s[0] & 128) != 0) {
	                    this.s = -1;
	                    if (sh > 0)this[this.t - 1] |= (1 << this.DB - sh) - 1 << sh
	                }
	                this.clamp();
	                if (mi)BigInteger.ZERO.subTo(this, this)
	            }

	            function bnpClamp() {
	                var c = this.s & this.DM;
	                while (this.t > 0 && this[this.t - 1] == c)--this.t
	            }

	            function bnToString(b) {
	                if (this.s < 0)return "-" + this.negate().toString(b);
	                var k;
	                if (b == 16)k = 4; else if (b == 8)k = 3; else if (b == 2)k = 1; else if (b == 32)k = 5; else if (b == 4)k = 2; else return this.toRadix(b);
	                var km = (1 << k) - 1, d, m = false, r = "", i = this.t;
	                var p = this.DB - i * this.DB % k;
	                if (i-- > 0) {
	                    if (p < this.DB && (d = this[i] >> p) > 0) {
	                        m = true;
	                        r = int2char(d)
	                    }
	                    while (i >= 0) {
	                        if (p < k) {
	                            d = (this[i] & (1 << p) - 1) << k - p;
	                            d |= this[--i] >> (p += this.DB - k)
	                        } else {
	                            d = this[i] >> (p -= k) & km;
	                            if (p <= 0) {
	                                p += this.DB;
	                                --i
	                            }
	                        }
	                        if (d > 0)m = true;
	                        if (m)r += int2char(d)
	                    }
	                }
	                return m ? r : "0"
	            }

	            function bnNegate() {
	                var r = nbi();
	                BigInteger.ZERO.subTo(this, r);
	                return r
	            }

	            function bnAbs() {
	                return this.s < 0 ? this.negate() : this
	            }

	            function bnCompareTo(a) {
	                var r = this.s - a.s;
	                if (r != 0)return r;
	                var i = this.t;
	                r = i - a.t;
	                if (r != 0)return this.s < 0 ? -r : r;
	                while (--i >= 0)if ((r = this[i] - a[i]) != 0)return r;
	                return 0
	            }

	            function nbits(x) {
	                var r = 1, t;
	                if ((t = x >>> 16) != 0) {
	                    x = t;
	                    r += 16
	                }
	                if ((t = x >> 8) != 0) {
	                    x = t;
	                    r += 8
	                }
	                if ((t = x >> 4) != 0) {
	                    x = t;
	                    r += 4
	                }
	                if ((t = x >> 2) != 0) {
	                    x = t;
	                    r += 2
	                }
	                if ((t = x >> 1) != 0) {
	                    x = t;
	                    r += 1
	                }
	                return r
	            }

	            function bnBitLength() {
	                if (this.t <= 0)return 0;
	                return this.DB * (this.t - 1) + nbits(this[this.t - 1] ^ this.s & this.DM)
	            }

	            function bnpDLShiftTo(n, r) {
	                var i;
	                for (i = this.t - 1; i >= 0; --i)r[i + n] = this[i];
	                for (i = n - 1; i >= 0; --i)r[i] = 0;
	                r.t = this.t + n;
	                r.s = this.s
	            }

	            function bnpDRShiftTo(n, r) {
	                for (var i = n; i < this.t; ++i)r[i - n] = this[i];
	                r.t = Math.max(this.t - n, 0);
	                r.s = this.s
	            }

	            function bnpLShiftTo(n, r) {
	                var bs = n % this.DB;
	                var cbs = this.DB - bs;
	                var bm = (1 << cbs) - 1;
	                var ds = Math.floor(n / this.DB), c = this.s << bs & this.DM, i;
	                for (i = this.t - 1; i >= 0; --i) {
	                    r[i + ds + 1] = this[i] >> cbs | c;
	                    c = (this[i] & bm) << bs
	                }
	                for (i = ds - 1; i >= 0; --i)r[i] = 0;
	                r[ds] = c;
	                r.t = this.t + ds + 1;
	                r.s = this.s;
	                r.clamp()
	            }

	            function bnpRShiftTo(n, r) {
	                r.s = this.s;
	                var ds = Math.floor(n / this.DB);
	                if (ds >= this.t) {
	                    r.t = 0;
	                    return
	                }
	                var bs = n % this.DB;
	                var cbs = this.DB - bs;
	                var bm = (1 << bs) - 1;
	                r[0] = this[ds] >> bs;
	                for (var i = ds + 1; i < this.t; ++i) {
	                    r[i - ds - 1] |= (this[i] & bm) << cbs;
	                    r[i - ds] = this[i] >> bs
	                }
	                if (bs > 0)r[this.t - ds - 1] |= (this.s & bm) << cbs;
	                r.t = this.t - ds;
	                r.clamp()
	            }

	            function bnpSubTo(a, r) {
	                var i = 0, c = 0, m = Math.min(a.t, this.t);
	                while (i < m) {
	                    c += this[i] - a[i];
	                    r[i++] = c & this.DM;
	                    c >>= this.DB
	                }
	                if (a.t < this.t) {
	                    c -= a.s;
	                    while (i < this.t) {
	                        c += this[i];
	                        r[i++] = c & this.DM;
	                        c >>= this.DB
	                    }
	                    c += this.s
	                } else {
	                    c += this.s;
	                    while (i < a.t) {
	                        c -= a[i];
	                        r[i++] = c & this.DM;
	                        c >>= this.DB
	                    }
	                    c -= a.s
	                }
	                r.s = c < 0 ? -1 : 0;
	                if (c < -1)r[i++] = this.DV + c; else if (c > 0)r[i++] = c;
	                r.t = i;
	                r.clamp()
	            }

	            function bnpMultiplyTo(a, r) {
	                var x = this.abs(), y = a.abs();
	                var i = x.t;
	                r.t = i + y.t;
	                while (--i >= 0)r[i] = 0;
	                for (i = 0; i < y.t; ++i)r[i + x.t] = x.am(0, y[i], r, i, 0, x.t);
	                r.s = 0;
	                r.clamp();
	                if (this.s != a.s)BigInteger.ZERO.subTo(r, r)
	            }

	            function bnpSquareTo(r) {
	                var x = this.abs();
	                var i = r.t = 2 * x.t;
	                while (--i >= 0)r[i] = 0;
	                for (i = 0; i < x.t - 1; ++i) {
	                    var c = x.am(i, x[i], r, 2 * i, 0, 1);
	                    if ((r[i + x.t] += x.am(i + 1, 2 * x[i], r, 2 * i + 1, c, x.t - i - 1)) >= x.DV) {
	                        r[i + x.t] -= x.DV;
	                        r[i + x.t + 1] = 1
	                    }
	                }
	                if (r.t > 0)r[r.t - 1] += x.am(i, x[i], r, 2 * i, 0, 1);
	                r.s = 0;
	                r.clamp()
	            }

	            function bnpDivRemTo(m, q, r) {
	                var pm = m.abs();
	                if (pm.t <= 0)return;
	                var pt = this.abs();
	                if (pt.t < pm.t) {
	                    if (q != null)q.fromInt(0);
	                    if (r != null)this.copyTo(r);
	                    return
	                }
	                if (r == null)r = nbi();
	                var y = nbi(), ts = this.s, ms = m.s;
	                var nsh = this.DB - nbits(pm[pm.t - 1]);
	                if (nsh > 0) {
	                    pm.lShiftTo(nsh, y);
	                    pt.lShiftTo(nsh, r)
	                } else {
	                    pm.copyTo(y);
	                    pt.copyTo(r)
	                }
	                var ys = y.t;
	                var y0 = y[ys - 1];
	                if (y0 == 0)return;
	                var yt = y0 * (1 << this.F1) + (ys > 1 ? y[ys - 2] >> this.F2 : 0);
	                var d1 = this.FV / yt, d2 = (1 << this.F1) / yt, e = 1 << this.F2;
	                var i = r.t, j = i - ys, t = q == null ? nbi() : q;
	                y.dlShiftTo(j, t);
	                if (r.compareTo(t) >= 0) {
	                    r[r.t++] = 1;
	                    r.subTo(t, r)
	                }
	                BigInteger.ONE.dlShiftTo(ys, t);
	                t.subTo(y, y);
	                while (y.t < ys)y[y.t++] = 0;
	                while (--j >= 0) {
	                    var qd = r[--i] == y0 ? this.DM : Math.floor(r[i] * d1 + (r[i - 1] + e) * d2);
	                    if ((r[i] += y.am(0, qd, r, j, 0, ys)) < qd) {
	                        y.dlShiftTo(j, t);
	                        r.subTo(t, r);
	                        while (r[i] < --qd)r.subTo(t, r)
	                    }
	                }
	                if (q != null) {
	                    r.drShiftTo(ys, q);
	                    if (ts != ms)BigInteger.ZERO.subTo(q, q)
	                }
	                r.t = ys;
	                r.clamp();
	                if (nsh > 0)r.rShiftTo(nsh, r);
	                if (ts < 0)BigInteger.ZERO.subTo(r, r)
	            }

	            function bnMod(a) {
	                var r = nbi();
	                this.abs().divRemTo(a, null, r);
	                if (this.s < 0 && r.compareTo(BigInteger.ZERO) > 0)a.subTo(r, r);
	                return r
	            }

	            function Classic(m) {
	                this.m = m
	            }

	            function cConvert(x) {
	                if (x.s < 0 || x.compareTo(this.m) >= 0)return x.mod(this.m); else return x
	            }

	            function cRevert(x) {
	                return x
	            }

	            function cReduce(x) {
	                x.divRemTo(this.m, null, x)
	            }

	            function cMulTo(x, y, r) {
	                x.multiplyTo(y, r);
	                this.reduce(r)
	            }

	            function cSqrTo(x, r) {
	                x.squareTo(r);
	                this.reduce(r)
	            }

	            Classic.prototype.convert = cConvert;
	            Classic.prototype.revert = cRevert;
	            Classic.prototype.reduce = cReduce;
	            Classic.prototype.mulTo = cMulTo;
	            Classic.prototype.sqrTo = cSqrTo;
	            function bnpInvDigit() {
	                if (this.t < 1)return 0;
	                var x = this[0];
	                if ((x & 1) == 0)return 0;
	                var y = x & 3;
	                y = y * (2 - (x & 15) * y) & 15;
	                y = y * (2 - (x & 255) * y) & 255;
	                y = y * (2 - ((x & 65535) * y & 65535)) & 65535;
	                y = y * (2 - x * y % this.DV) % this.DV;
	                return y > 0 ? this.DV - y : -y
	            }

	            function Montgomery(m) {
	                this.m = m;
	                this.mp = m.invDigit();
	                this.mpl = this.mp & 32767;
	                this.mph = this.mp >> 15;
	                this.um = (1 << m.DB - 15) - 1;
	                this.mt2 = 2 * m.t
	            }

	            function montConvert(x) {
	                var r = nbi();
	                x.abs().dlShiftTo(this.m.t, r);
	                r.divRemTo(this.m, null, r);
	                if (x.s < 0 && r.compareTo(BigInteger.ZERO) > 0)this.m.subTo(r, r);
	                return r
	            }

	            function montRevert(x) {
	                var r = nbi();
	                x.copyTo(r);
	                this.reduce(r);
	                return r
	            }

	            function montReduce(x) {
	                while (x.t <= this.mt2)x[x.t++] = 0;
	                for (var i = 0; i < this.m.t; ++i) {
	                    var j = x[i] & 32767;
	                    var u0 = j * this.mpl + ((j * this.mph + (x[i] >> 15) * this.mpl & this.um) << 15) & x.DM;
	                    j = i + this.m.t;
	                    x[j] += this.m.am(0, u0, x, i, 0, this.m.t);
	                    while (x[j] >= x.DV) {
	                        x[j] -= x.DV;
	                        x[++j]++
	                    }
	                }
	                x.clamp();
	                x.drShiftTo(this.m.t, x);
	                if (x.compareTo(this.m) >= 0)x.subTo(this.m, x)
	            }

	            function montSqrTo(x, r) {
	                x.squareTo(r);
	                this.reduce(r)
	            }

	            function montMulTo(x, y, r) {
	                x.multiplyTo(y, r);
	                this.reduce(r)
	            }

	            Montgomery.prototype.convert = montConvert;
	            Montgomery.prototype.revert = montRevert;
	            Montgomery.prototype.reduce = montReduce;
	            Montgomery.prototype.mulTo = montMulTo;
	            Montgomery.prototype.sqrTo = montSqrTo;
	            function bnpIsEven() {
	                return (this.t > 0 ? this[0] & 1 : this.s) == 0
	            }

	            function bnpExp(e, z) {
	                if (e > 4294967295 || e < 1)return BigInteger.ONE;
	                var r = nbi(), r2 = nbi(), g = z.convert(this), i = nbits(e) - 1;
	                g.copyTo(r);
	                while (--i >= 0) {
	                    z.sqrTo(r, r2);
	                    if ((e & 1 << i) > 0)z.mulTo(r2, g, r); else {
	                        var t = r;
	                        r = r2;
	                        r2 = t
	                    }
	                }
	                return z.revert(r)
	            }

	            function bnModPowInt(e, m) {
	                var z;
	                if (e < 256 || m.isEven())z = new Classic(m); else z = new Montgomery(m);
	                return this.exp(e, z)
	            }

	            BigInteger.prototype.copyTo = bnpCopyTo;
	            BigInteger.prototype.fromInt = bnpFromInt;
	            BigInteger.prototype.fromString = bnpFromString;
	            BigInteger.prototype.clamp = bnpClamp;
	            BigInteger.prototype.dlShiftTo = bnpDLShiftTo;
	            BigInteger.prototype.drShiftTo = bnpDRShiftTo;
	            BigInteger.prototype.lShiftTo = bnpLShiftTo;
	            BigInteger.prototype.rShiftTo = bnpRShiftTo;
	            BigInteger.prototype.subTo = bnpSubTo;
	            BigInteger.prototype.multiplyTo = bnpMultiplyTo;
	            BigInteger.prototype.squareTo = bnpSquareTo;
	            BigInteger.prototype.divRemTo = bnpDivRemTo;
	            BigInteger.prototype.invDigit = bnpInvDigit;
	            BigInteger.prototype.isEven = bnpIsEven;
	            BigInteger.prototype.exp = bnpExp;
	            BigInteger.prototype.toString = bnToString;
	            BigInteger.prototype.negate = bnNegate;
	            BigInteger.prototype.abs = bnAbs;
	            BigInteger.prototype.compareTo = bnCompareTo;
	            BigInteger.prototype.bitLength = bnBitLength;
	            BigInteger.prototype.mod = bnMod;
	            BigInteger.prototype.modPowInt = bnModPowInt;
	            BigInteger.ZERO = nbv(0);
	            BigInteger.ONE = nbv(1);
	            function bnpFromRadix(s, b) {
	                this.fromInt(0);
	                if (b == null)b = 10;
	                var cs = this.chunkSize(b);
	                var d = Math.pow(b, cs), mi = false, j = 0, w = 0;
	                for (var i = 0; i < s.length; ++i) {
	                    var x = intAt(s, i);
	                    if (x < 0) {
	                        if (s.charAt(i) == "-" && this.signum() == 0)mi = true;
	                        continue
	                    }
	                    w = b * w + x;
	                    if (++j >= cs) {
	                        this.dMultiply(d);
	                        this.dAddOffset(w, 0);
	                        j = 0;
	                        w = 0
	                    }
	                }
	                if (j > 0) {
	                    this.dMultiply(Math.pow(b, j));
	                    this.dAddOffset(w, 0)
	                }
	                if (mi)BigInteger.ZERO.subTo(this, this)
	            }

	            function bnpChunkSize(r) {
	                return Math.floor(Math.LN2 * this.DB / Math.log(r))
	            }

	            function bnSigNum() {
	                if (this.s < 0)return -1; else if (this.t <= 0 || this.t == 1 && this[0] <= 0)return 0; else return 1
	            }

	            function bnpDMultiply(n) {
	                this[this.t] = this.am(0, n - 1, this, 0, 0, this.t);
	                ++this.t;
	                this.clamp()
	            }

	            function bnpDAddOffset(n, w) {
	                if (n == 0)return;
	                while (this.t <= w)this[this.t++] = 0;
	                this[w] += n;
	                while (this[w] >= this.DV) {
	                    this[w] -= this.DV;
	                    if (++w >= this.t)this[this.t++] = 0;
	                    ++this[w]
	                }
	            }

	            function bnpToRadix(b) {
	                if (b == null)b = 10;
	                if (this.signum() == 0 || b < 2 || b > 36)return "0";
	                var cs = this.chunkSize(b);
	                var a = Math.pow(b, cs);
	                var d = nbv(a), y = nbi(), z = nbi(), r = "";
	                this.divRemTo(d, y, z);
	                while (y.signum() > 0) {
	                    r = (a + z.intValue()).toString(b).substr(1) + r;
	                    y.divRemTo(d, y, z)
	                }
	                return z.intValue().toString(b) + r
	            }

	            function bnIntValue() {
	                if (this.s < 0) {
	                    if (this.t == 1)return this[0] - this.DV; else if (this.t == 0)return -1
	                } else if (this.t == 1)return this[0]; else if (this.t == 0)return 0;
	                return (this[1] & (1 << 32 - this.DB) - 1) << this.DB | this[0]
	            }

	            function bnpAddTo(a, r) {
	                var i = 0, c = 0, m = Math.min(a.t, this.t);
	                while (i < m) {
	                    c += this[i] + a[i];
	                    r[i++] = c & this.DM;
	                    c >>= this.DB
	                }
	                if (a.t < this.t) {
	                    c += a.s;
	                    while (i < this.t) {
	                        c += this[i];
	                        r[i++] = c & this.DM;
	                        c >>= this.DB
	                    }
	                    c += this.s
	                } else {
	                    c += this.s;
	                    while (i < a.t) {
	                        c += a[i];
	                        r[i++] = c & this.DM;
	                        c >>= this.DB
	                    }
	                    c += a.s
	                }
	                r.s = c < 0 ? -1 : 0;
	                if (c > 0)r[i++] = c; else if (c < -1)r[i++] = this.DV + c;
	                r.t = i;
	                r.clamp()
	            }

	            BigInteger.prototype.fromRadix = bnpFromRadix;
	            BigInteger.prototype.chunkSize = bnpChunkSize;
	            BigInteger.prototype.signum = bnSigNum;
	            BigInteger.prototype.dMultiply = bnpDMultiply;
	            BigInteger.prototype.dAddOffset = bnpDAddOffset;
	            BigInteger.prototype.toRadix = bnpToRadix;
	            BigInteger.prototype.intValue = bnIntValue;
	            BigInteger.prototype.addTo = bnpAddTo;
	            var Wrapper = {
	                abs: (function (l, h) {
	                    var x = new goog.math.Long(l, h);
	                    var ret;
	                    if (x.isNegative()) {
	                        ret = x.negate()
	                    } else {
	                        ret = x
	                    }
	                    HEAP32[tempDoublePtr >> 2] = ret.low_;
	                    HEAP32[tempDoublePtr + 4 >> 2] = ret.high_
	                }), ensureTemps: (function () {
	                    if (Wrapper.ensuredTemps)return;
	                    Wrapper.ensuredTemps = true;
	                    Wrapper.two32 = new BigInteger;
	                    Wrapper.two32.fromString("4294967296", 10);
	                    Wrapper.two64 = new BigInteger;
	                    Wrapper.two64.fromString("18446744073709551616", 10);
	                    Wrapper.temp1 = new BigInteger;
	                    Wrapper.temp2 = new BigInteger
	                }), lh2bignum: (function (l, h) {
	                    var a = new BigInteger;
	                    a.fromString(h.toString(), 10);
	                    var b = new BigInteger;
	                    a.multiplyTo(Wrapper.two32, b);
	                    var c = new BigInteger;
	                    c.fromString(l.toString(), 10);
	                    var d = new BigInteger;
	                    c.addTo(b, d);
	                    return d
	                }), stringify: (function (l, h, unsigned) {
	                    var ret = (new goog.math.Long(l, h)).toString();
	                    if (unsigned && ret[0] == "-") {
	                        Wrapper.ensureTemps();
	                        var bignum = new BigInteger;
	                        bignum.fromString(ret, 10);
	                        ret = new BigInteger;
	                        Wrapper.two64.addTo(bignum, ret);
	                        ret = ret.toString(10)
	                    }
	                    return ret
	                }), fromString: (function (str, base, min, max, unsigned) {
	                    Wrapper.ensureTemps();
	                    var bignum = new BigInteger;
	                    bignum.fromString(str, base);
	                    var bigmin = new BigInteger;
	                    bigmin.fromString(min, 10);
	                    var bigmax = new BigInteger;
	                    bigmax.fromString(max, 10);
	                    if (unsigned && bignum.compareTo(BigInteger.ZERO) < 0) {
	                        var temp = new BigInteger;
	                        bignum.addTo(Wrapper.two64, temp);
	                        bignum = temp
	                    }
	                    var error = false;
	                    if (bignum.compareTo(bigmin) < 0) {
	                        bignum = bigmin;
	                        error = true
	                    } else if (bignum.compareTo(bigmax) > 0) {
	                        bignum = bigmax;
	                        error = true
	                    }
	                    var ret = goog.math.Long.fromString(bignum.toString());
	                    HEAP32[tempDoublePtr >> 2] = ret.low_;
	                    HEAP32[tempDoublePtr + 4 >> 2] = ret.high_;
	                    if (error)throw"range error"
	                })
	            };
	            return Wrapper
	        })();
	        if (memoryInitializer) {
	            if (typeof Module["locateFile"] === "function") {
	                memoryInitializer = Module["locateFile"](memoryInitializer)
	            } else if (Module["memoryInitializerPrefixURL"]) {
	                memoryInitializer = Module["memoryInitializerPrefixURL"] + memoryInitializer
	            }
	            
	                addRunDependency("memory initializer");
	                Browser.asyncLoad(memoryInitializer, (function (data) {
	                    HEAPU8.set(data, STATIC_BASE);
	                    removeRunDependency("memory initializer")
	                }), (function (data) {
	                    throw"could not load memory initializer " + memoryInitializer
	                }))
	            
	        }
	        function ExitStatus(status) {
	            this.name = "ExitStatus";
	            this.message = "Program terminated with exit(" + status + ")";
	            this.status = status
	        }

	        ExitStatus.prototype = new Error;
	        ExitStatus.prototype.constructor = ExitStatus;
	        var initialStackTop;
	        var preloadStartTime = null;
	        var calledMain = false;
	        dependenciesFulfilled = function runCaller() {
	            if (!Module["calledRun"] && shouldRunNow)run();
	            if (!Module["calledRun"])dependenciesFulfilled = runCaller
	        };
	        Module["callMain"] = Module.callMain = function callMain(args) {
	            assert(runDependencies == 0, "cannot call main when async dependencies remain! (listen on __ATMAIN__)");
	            assert(__ATPRERUN__.length == 0, "cannot call main when preRun functions remain to be called");
	            args = args || [];
	            ensureInitRuntime();
	            var argc = args.length + 1;

	            function pad() {
	                for (var i = 0; i < 4 - 1; i++) {
	                    argv.push(0)
	                }
	            }

	            var argv = [allocate(intArrayFromString(Module["thisProgram"]), "i8", ALLOC_NORMAL)];
	            pad();
	            for (var i = 0; i < argc - 1; i = i + 1) {
	                argv.push(allocate(intArrayFromString(args[i]), "i8", ALLOC_NORMAL));
	                pad()
	            }
	            argv.push(0);
	            argv = allocate(argv, "i32", ALLOC_NORMAL);
	            initialStackTop = STACKTOP;
	            try {
	                var ret = Module["_main"](argc, argv, 0);
	                exit(ret)
	            } catch (e) {
	                if (e instanceof ExitStatus) {
	                    return
	                } else if (e == "SimulateInfiniteLoop") {
	                    Module["noExitRuntime"] = true;
	                    return
	                } else {
	                    if (e && typeof e === "object" && e.stack)Module.printErr("exception thrown: " + [e, e.stack]);
	                    throw e
	                }
	            } finally {
	                calledMain = true
	            }
	        };
	        function run(args) {
	            args = args || Module["arguments"];
	            if (preloadStartTime === null)preloadStartTime = Date.now();
	            if (runDependencies > 0) {
	                return
	            }
	            preRun();
	            if (runDependencies > 0)return;
	            if (Module["calledRun"])return;
	            function doRun() {
	                if (Module["calledRun"])return;
	                Module["calledRun"] = true;
	                if (ABORT)return;
	                ensureInitRuntime();
	                preMain();
	                if (preloadStartTime !== null) {
	                    if ((Date.now() - preloadStartTime)>15) {
	                        Module.printErr("pre-main prep time: " + (Date.now() - preloadStartTime) + " ms")
	                    }
	                }
	                if (Module["onRuntimeInitialized"])Module["onRuntimeInitialized"]();
	                if (Module["_main"] && shouldRunNow)Module["callMain"](args);
	                postRun()
	            }

	            if (Module["setStatus"]) {
	                Module["setStatus"]("Running...");
	                setTimeout((function () {
	                    setTimeout((function () {
	                        Module["setStatus"]("")
	                    }), 1);
	                    doRun()
	                }), 1)
	            } else {
	                doRun()
	            }
	        }

	        Module["run"] = Module.run = run;
	        function exit(status) {
	            if (Module["noExitRuntime"]) {
	                return
	            }
	            ABORT = true;
	            EXITSTATUS = status;
	            STACKTOP = initialStackTop;
	            exitRuntime();
	            
	            throw new ExitStatus(status)
	        }

	        Module["exit"] = Module.exit = exit;
	        function abort(text) {
	            if (text) {
	                Module.print(text);
	                Module.printErr(text)
	            }
	            ABORT = true;
	            EXITSTATUS = 1;
	            var extra = "\nIf this abort() is unexpected, build with -s ASSERTIONS=1 which can give more information.";
	            throw"abort() at " + stackTrace() + extra
	        }

	        Module["abort"] = Module.abort = abort;
	        if (Module["preInit"]) {
	            if (typeof Module["preInit"] == "function")Module["preInit"] = [Module["preInit"]];
	            while (Module["preInit"].length > 0) {
	                Module["preInit"].pop()()
	            }
	        }
	        var shouldRunNow = true;
	        if (Module["noInitialRun"]) {
	            shouldRunNow = false
	        }
	        run()


	        Module['return'] = Module['return'].split('\n').slice(0, -2);

	        // Do this in a JSLint style way...
	        return {
	            errors: Module['return'].length ? Module['return'] : null
	        };
	    }
	})();

	if(true) {module.exports = xmllint}
	/* WEBPACK VAR INJECTION */}.call(exports, __webpack_require__(87).Buffer))

/***/ },
/* 198 */
/***/ function(module, exports, __webpack_require__) {

	//[4]   	NameStartChar	   ::=   	":" | [A-Z] | "_" | [a-z] | [#xC0-#xD6] | [#xD8-#xF6] | [#xF8-#x2FF] | [#x370-#x37D] | [#x37F-#x1FFF] | [#x200C-#x200D] | [#x2070-#x218F] | [#x2C00-#x2FEF] | [#x3001-#xD7FF] | [#xF900-#xFDCF] | [#xFDF0-#xFFFD] | [#x10000-#xEFFFF]
	//[4a]   	NameChar	   ::=   	NameStartChar | "-" | "." | [0-9] | #xB7 | [#x0300-#x036F] | [#x203F-#x2040]
	//[5]   	Name	   ::=   	NameStartChar (NameChar)*
	var nameStartChar = /[A-Z_a-z\xC0-\xD6\xD8-\xF6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD]///\u10000-\uEFFFF
	var nameChar = new RegExp("[\\-\\.0-9"+nameStartChar.source.slice(1,-1)+"\u00B7\u0300-\u036F\\u203F-\u2040]");
	var tagNamePattern = new RegExp('^'+nameStartChar.source+nameChar.source+'*(?:\:'+nameStartChar.source+nameChar.source+'*)?$');
	//var tagNamePattern = /^[a-zA-Z_][\w\-\.]*(?:\:[a-zA-Z_][\w\-\.]*)?$/
	//var handlers = 'resolveEntity,getExternalSubset,characters,endDocument,endElement,endPrefixMapping,ignorableWhitespace,processingInstruction,setDocumentLocator,skippedEntity,startDocument,startElement,startPrefixMapping,notationDecl,unparsedEntityDecl,error,fatalError,warning,attributeDecl,elementDecl,externalEntityDecl,internalEntityDecl,comment,endCDATA,endDTD,endEntity,startCDATA,startDTD,startEntity'.split(',')

	//S_TAG,	S_ATTR,	S_EQ,	S_V
	//S_ATTR_S,	S_E,	S_S,	S_C
	var S_TAG = 0;//tag name offerring
	var S_ATTR = 1;//attr name offerring 
	var S_ATTR_S=2;//attr name end and space offer
	var S_EQ = 3;//=space?
	var S_V = 4;//attr value(no quot value only)
	var S_E = 5;//attr value end and no space(quot end)
	var S_S = 6;//(attr value end || tag end ) && (space offer)
	var S_C = 7;//closed el<el />

	function XMLReader(){
		
	}

	XMLReader.prototype = {
		parse:function(source,defaultNSMap,entityMap){
			var domBuilder = this.domBuilder;
			domBuilder.startDocument();
			_copy(defaultNSMap ,defaultNSMap = {})
			parse(source,defaultNSMap,entityMap,
					domBuilder,this.errorHandler);
			domBuilder.endDocument();
		}
	}
	function parse(source,defaultNSMapCopy,entityMap,domBuilder,errorHandler){
	  function fixedFromCharCode(code) {
			// String.prototype.fromCharCode does not supports
			// > 2 bytes unicode chars directly
			if (code > 0xffff) {
				code -= 0x10000;
				var surrogate1 = 0xd800 + (code >> 10)
					, surrogate2 = 0xdc00 + (code & 0x3ff);

				return String.fromCharCode(surrogate1, surrogate2);
			} else {
				return String.fromCharCode(code);
			}
		}
		function entityReplacer(a){
			var k = a.slice(1,-1);
			if(k in entityMap){
				return entityMap[k]; 
			}else if(k.charAt(0) === '#'){
				return fixedFromCharCode(parseInt(k.substr(1).replace('x','0x')))
			}else{
				errorHandler.error('entity not found:'+a);
				return a;
			}
		}
		function appendText(end){//has some bugs
			if(end>start){
				var xt = source.substring(start,end).replace(/&#?\w+;/g,entityReplacer);
				locator&&position(start);
				domBuilder.characters(xt,0,end-start);
				start = end
			}
		}
		function position(p,m){
			while(p>=lineEnd && (m = linePattern.exec(source))){
				lineStart = m.index;
				lineEnd = lineStart + m[0].length;
				locator.lineNumber++;
				//console.log('line++:',locator,startPos,endPos)
			}
			locator.columnNumber = p-lineStart+1;
		}
		var lineStart = 0;
		var lineEnd = 0;
		var linePattern = /.+(?:\r\n?|\n)|.*$/g
		var locator = domBuilder.locator;
		
		var parseStack = [{currentNSMap:defaultNSMapCopy}]
		var closeMap = {};
		var start = 0;
		while(true){
			try{
				var tagStart = source.indexOf('<',start);
				if(tagStart<0){
					if(!source.substr(start).match(/^\s*$/)){
						var doc = domBuilder.document;
		    			var text = doc.createTextNode(source.substr(start));
		    			doc.appendChild(text);
		    			domBuilder.currentElement = text;
					}
					return;
				}
				if(tagStart>start){
					appendText(tagStart);
				}
				switch(source.charAt(tagStart+1)){
				case '/':
					var end = source.indexOf('>',tagStart+3);
					var tagName = source.substring(tagStart+2,end);
					var config = parseStack.pop();
					var localNSMap = config.localNSMap;
			        if(config.tagName != tagName){
			            errorHandler.fatalError("end tag name: "+tagName+' is not match the current start tagName:'+config.tagName );
			        }
					domBuilder.endElement(config.uri,config.localName,tagName);
					if(localNSMap){
						for(var prefix in localNSMap){
							domBuilder.endPrefixMapping(prefix) ;
						}
					}
					end++;
					break;
					// end elment
				case '?':// <?...?>
					locator&&position(tagStart);
					end = parseInstruction(source,tagStart,domBuilder);
					break;
				case '!':// <!doctype,<![CDATA,<!--
					locator&&position(tagStart);
					end = parseDCC(source,tagStart,domBuilder,errorHandler);
					break;
				default:
				
					locator&&position(tagStart);
					
					var el = new ElementAttributes();
					
					//elStartEnd
					var end = parseElementStartPart(source,tagStart,el,entityReplacer,errorHandler);
					var len = el.length;
					
					if(locator){
						if(len){
							//attribute position fixed
							for(var i = 0;i<len;i++){
								var a = el[i];
								position(a.offset);
								a.offset = copyLocator(locator,{});
							}
						}
						position(end);
					}
					if(!el.closed && fixSelfClosed(source,end,el.tagName,closeMap)){
						el.closed = true;
						if(!entityMap.nbsp){
							errorHandler.warning('unclosed xml attribute');
						}
					}
					appendElement(el,domBuilder,parseStack);
					
					
					if(el.uri === 'http://www.w3.org/1999/xhtml' && !el.closed){
						end = parseHtmlSpecialContent(source,end,el.tagName,entityReplacer,domBuilder)
					}else{
						end++;
					}
				}
			}catch(e){
				errorHandler.error('element parse error: '+e);
				end = -1;
			}
			if(end>start){
				start = end;
			}else{
				//TODO: 这里有可能sax回退，有位置错误风险
				appendText(Math.max(tagStart,start)+1);
			}
		}
	}
	function copyLocator(f,t){
		t.lineNumber = f.lineNumber;
		t.columnNumber = f.columnNumber;
		return t;
	}

	/**
	 * @see #appendElement(source,elStartEnd,el,selfClosed,entityReplacer,domBuilder,parseStack);
	 * @return end of the elementStartPart(end of elementEndPart for selfClosed el)
	 */
	function parseElementStartPart(source,start,el,entityReplacer,errorHandler){
		var attrName;
		var value;
		var p = ++start;
		var s = S_TAG;//status
		while(true){
			var c = source.charAt(p);
			switch(c){
			case '=':
				if(s === S_ATTR){//attrName
					attrName = source.slice(start,p);
					s = S_EQ;
				}else if(s === S_ATTR_S){
					s = S_EQ;
				}else{
					//fatalError: equal must after attrName or space after attrName
					throw new Error('attribute equal must after attrName');
				}
				break;
			case '\'':
			case '"':
				if(s === S_EQ){//equal
					start = p+1;
					p = source.indexOf(c,start)
					if(p>0){
						value = source.slice(start,p).replace(/&#?\w+;/g,entityReplacer);
						el.add(attrName,value,start-1);
						s = S_E;
					}else{
						//fatalError: no end quot match
						throw new Error('attribute value no end \''+c+'\' match');
					}
				}else if(s == S_V){
					value = source.slice(start,p).replace(/&#?\w+;/g,entityReplacer);
					//console.log(attrName,value,start,p)
					el.add(attrName,value,start);
					//console.dir(el)
					errorHandler.warning('attribute "'+attrName+'" missed start quot('+c+')!!');
					start = p+1;
					s = S_E
				}else{
					//fatalError: no equal before
					throw new Error('attribute value must after "="');
				}
				break;
			case '/':
				switch(s){
				case S_TAG:
					el.setTagName(source.slice(start,p));
				case S_E:
				case S_S:
				case S_C:
					s = S_C;
					el.closed = true;
				case S_V:
				case S_ATTR:
				case S_ATTR_S:
					break;
				//case S_EQ:
				default:
					throw new Error("attribute invalid close char('/')")
				}
				break;
			case ''://end document
				//throw new Error('unexpected end of input')
				errorHandler.error('unexpected end of input');
			case '>':
				switch(s){
				case S_TAG:
					el.setTagName(source.slice(start,p));
				case S_E:
				case S_S:
				case S_C:
					break;//normal
				case S_V://Compatible state
				case S_ATTR:
					value = source.slice(start,p);
					if(value.slice(-1) === '/'){
						el.closed  = true;
						value = value.slice(0,-1)
					}
				case S_ATTR_S:
					if(s === S_ATTR_S){
						value = attrName;
					}
					if(s == S_V){
						errorHandler.warning('attribute "'+value+'" missed quot(")!!');
						el.add(attrName,value.replace(/&#?\w+;/g,entityReplacer),start)
					}else{
						errorHandler.warning('attribute "'+value+'" missed value!! "'+value+'" instead!!')
						el.add(value,value,start)
					}
					break;
				case S_EQ:
					throw new Error('attribute value missed!!');
				}
	//			console.log(tagName,tagNamePattern,tagNamePattern.test(tagName))
				return p;
			/*xml space '\x20' | #x9 | #xD | #xA; */
			case '\u0080':
				c = ' ';
			default:
				if(c<= ' '){//space
					switch(s){
					case S_TAG:
						el.setTagName(source.slice(start,p));//tagName
						s = S_S;
						break;
					case S_ATTR:
						attrName = source.slice(start,p)
						s = S_ATTR_S;
						break;
					case S_V:
						var value = source.slice(start,p).replace(/&#?\w+;/g,entityReplacer);
						errorHandler.warning('attribute "'+value+'" missed quot(")!!');
						el.add(attrName,value,start)
					case S_E:
						s = S_S;
						break;
					//case S_S:
					//case S_EQ:
					//case S_ATTR_S:
					//	void();break;
					//case S_C:
						//ignore warning
					}
				}else{//not space
	//S_TAG,	S_ATTR,	S_EQ,	S_V
	//S_ATTR_S,	S_E,	S_S,	S_C
					switch(s){
					//case S_TAG:void();break;
					//case S_ATTR:void();break;
					//case S_V:void();break;
					case S_ATTR_S:
						errorHandler.warning('attribute "'+attrName+'" missed value!! "'+attrName+'" instead!!')
						el.add(attrName,attrName,start);
						start = p;
						s = S_ATTR;
						break;
					case S_E:
						errorHandler.warning('attribute space is required"'+attrName+'"!!')
					case S_S:
						s = S_ATTR;
						start = p;
						break;
					case S_EQ:
						s = S_V;
						start = p;
						break;
					case S_C:
						throw new Error("elements closed character '/' and '>' must be connected to");
					}
				}
			}
			p++;
		}
	}
	/**
	 * @return end of the elementStartPart(end of elementEndPart for selfClosed el)
	 */
	function appendElement(el,domBuilder,parseStack){
		var tagName = el.tagName;
		var localNSMap = null;
		var currentNSMap = parseStack[parseStack.length-1].currentNSMap;
		var i = el.length;
		while(i--){
			var a = el[i];
			var qName = a.qName;
			var value = a.value;
			var nsp = qName.indexOf(':');
			if(nsp>0){
				var prefix = a.prefix = qName.slice(0,nsp);
				var localName = qName.slice(nsp+1);
				var nsPrefix = prefix === 'xmlns' && localName
			}else{
				localName = qName;
				prefix = null
				nsPrefix = qName === 'xmlns' && ''
			}
			//can not set prefix,because prefix !== ''
			a.localName = localName ;
			//prefix == null for no ns prefix attribute 
			if(nsPrefix !== false){//hack!!
				if(localNSMap == null){
					localNSMap = {}
					//console.log(currentNSMap,0)
					_copy(currentNSMap,currentNSMap={})
					//console.log(currentNSMap,1)
				}
				currentNSMap[nsPrefix] = localNSMap[nsPrefix] = value;
				a.uri = 'http://www.w3.org/2000/xmlns/'
				domBuilder.startPrefixMapping(nsPrefix, value) 
			}
		}
		var i = el.length;
		while(i--){
			a = el[i];
			var prefix = a.prefix;
			if(prefix){//no prefix attribute has no namespace
				if(prefix === 'xml'){
					a.uri = 'http://www.w3.org/XML/1998/namespace';
				}if(prefix !== 'xmlns'){
					a.uri = currentNSMap[prefix]
					
					//{console.log('###'+a.qName,domBuilder.locator.systemId+'',currentNSMap,a.uri)}
				}
			}
		}
		var nsp = tagName.indexOf(':');
		if(nsp>0){
			prefix = el.prefix = tagName.slice(0,nsp);
			localName = el.localName = tagName.slice(nsp+1);
		}else{
			prefix = null;//important!!
			localName = el.localName = tagName;
		}
		//no prefix element has default namespace
		var ns = el.uri = currentNSMap[prefix || ''];
		domBuilder.startElement(ns,localName,tagName,el);
		//endPrefixMapping and startPrefixMapping have not any help for dom builder
		//localNSMap = null
		if(el.closed){
			domBuilder.endElement(ns,localName,tagName);
			if(localNSMap){
				for(prefix in localNSMap){
					domBuilder.endPrefixMapping(prefix) 
				}
			}
		}else{
			el.currentNSMap = currentNSMap;
			el.localNSMap = localNSMap;
			parseStack.push(el);
		}
	}
	function parseHtmlSpecialContent(source,elStartEnd,tagName,entityReplacer,domBuilder){
		if(/^(?:script|textarea)$/i.test(tagName)){
			var elEndStart =  source.indexOf('</'+tagName+'>',elStartEnd);
			var text = source.substring(elStartEnd+1,elEndStart);
			if(/[&<]/.test(text)){
				if(/^script$/i.test(tagName)){
					//if(!/\]\]>/.test(text)){
						//lexHandler.startCDATA();
						domBuilder.characters(text,0,text.length);
						//lexHandler.endCDATA();
						return elEndStart;
					//}
				}//}else{//text area
					text = text.replace(/&#?\w+;/g,entityReplacer);
					domBuilder.characters(text,0,text.length);
					return elEndStart;
				//}
				
			}
		}
		return elStartEnd+1;
	}
	function fixSelfClosed(source,elStartEnd,tagName,closeMap){
		//if(tagName in closeMap){
		var pos = closeMap[tagName];
		if(pos == null){
			//console.log(tagName)
			pos = closeMap[tagName] = source.lastIndexOf('</'+tagName+'>')
		}
		return pos<elStartEnd;
		//} 
	}
	function _copy(source,target){
		for(var n in source){target[n] = source[n]}
	}
	function parseDCC(source,start,domBuilder,errorHandler){//sure start with '<!'
		var next= source.charAt(start+2)
		switch(next){
		case '-':
			if(source.charAt(start + 3) === '-'){
				var end = source.indexOf('-->',start+4);
				//append comment source.substring(4,end)//<!--
				if(end>start){
					domBuilder.comment(source,start+4,end-start-4);
					return end+3;
				}else{
					errorHandler.error("Unclosed comment");
					return -1;
				}
			}else{
				//error
				return -1;
			}
		default:
			if(source.substr(start+3,6) == 'CDATA['){
				var end = source.indexOf(']]>',start+9);
				domBuilder.startCDATA();
				domBuilder.characters(source,start+9,end-start-9);
				domBuilder.endCDATA() 
				return end+3;
			}
			//<!DOCTYPE
			//startDTD(java.lang.String name, java.lang.String publicId, java.lang.String systemId) 
			var matchs = split(source,start);
			var len = matchs.length;
			if(len>1 && /!doctype/i.test(matchs[0][0])){
				var name = matchs[1][0];
				var pubid = len>3 && /^public$/i.test(matchs[2][0]) && matchs[3][0]
				var sysid = len>4 && matchs[4][0];
				var lastMatch = matchs[len-1]
				domBuilder.startDTD(name,pubid && pubid.replace(/^(['"])(.*?)\1$/,'$2'),
						sysid && sysid.replace(/^(['"])(.*?)\1$/,'$2'));
				domBuilder.endDTD();
				
				return lastMatch.index+lastMatch[0].length
			}
		}
		return -1;
	}



	function parseInstruction(source,start,domBuilder){
		var end = source.indexOf('?>',start);
		if(end){
			var match = source.substring(start,end).match(/^<\?(\S*)\s*([\s\S]*?)\s*$/);
			if(match){
				var len = match[0].length;
				domBuilder.processingInstruction(match[1], match[2]) ;
				return end+2;
			}else{//error
				return -1;
			}
		}
		return -1;
	}

	/**
	 * @param source
	 */
	function ElementAttributes(source){
		
	}
	ElementAttributes.prototype = {
		setTagName:function(tagName){
			if(!tagNamePattern.test(tagName)){
				throw new Error('invalid tagName:'+tagName)
			}
			this.tagName = tagName
		},
		add:function(qName,value,offset){
			if(!tagNamePattern.test(qName)){
				throw new Error('invalid attribute:'+qName)
			}
			this[this.length++] = {qName:qName,value:value,offset:offset}
		},
		length:0,
		getLocalName:function(i){return this[i].localName},
		getOffset:function(i){return this[i].offset},
		getQName:function(i){return this[i].qName},
		getURI:function(i){return this[i].uri},
		getValue:function(i){return this[i].value}
	//	,getIndex:function(uri, localName)){
	//		if(localName){
	//			
	//		}else{
	//			var qName = uri
	//		}
	//	},
	//	getValue:function(){return this.getValue(this.getIndex.apply(this,arguments))},
	//	getType:function(uri,localName){}
	//	getType:function(i){},
	}




	function _set_proto_(thiz,parent){
		thiz.__proto__ = parent;
		return thiz;
	}
	if(!(_set_proto_({},_set_proto_.prototype) instanceof _set_proto_)){
		_set_proto_ = function(thiz,parent){
			function p(){};
			p.prototype = parent;
			p = new p();
			for(parent in thiz){
				p[parent] = thiz[parent];
			}
			return p;
		}
	}

	function split(source,start){
		var match;
		var buf = [];
		var reg = /'[^']+'|"[^"]+"|[^\s<>\/=]+=?|(\/?\s*>|<)/g;
		reg.lastIndex = start;
		reg.exec(source);//skip <
		while(match = reg.exec(source)){
			buf.push(match);
			if(match[1])return buf;
		}
	}

	if(true){
		exports.XMLReader = XMLReader;
	}



/***/ },
/* 199 */
/***/ function(module, exports, __webpack_require__) {

	/*
	 * DOM Level 2
	 * Object DOMException
	 * @see http://www.w3.org/TR/REC-DOM-Level-1/ecma-script-language-binding.html
	 * @see http://www.w3.org/TR/2000/REC-DOM-Level-2-Core-20001113/ecma-script-binding.html
	 */

	function copy(src,dest){
		for(var p in src){
			dest[p] = src[p];
		}
	}
	/**
	^\w+\.prototype\.([_\w]+)\s*=\s*((?:.*\{\s*?[\r\n][\s\S]*?^})|\S.*?(?=[;\r\n]));?
	^\w+\.prototype\.([_\w]+)\s*=\s*(\S.*?(?=[;\r\n]));?
	 */
	function _extends(Class,Super){
		var pt = Class.prototype;
		if(Object.create){
			var ppt = Object.create(Super.prototype)
			pt.__proto__ = ppt;
		}
		if(!(pt instanceof Super)){
			function t(){};
			t.prototype = Super.prototype;
			t = new t();
			copy(pt,t);
			Class.prototype = pt = t;
		}
		if(pt.constructor != Class){
			if(typeof Class != 'function'){
				console.error("unknow Class:"+Class)
			}
			pt.constructor = Class
		}
	}
	var htmlns = 'http://www.w3.org/1999/xhtml' ;
	// Node Types
	var NodeType = {}
	var ELEMENT_NODE                = NodeType.ELEMENT_NODE                = 1;
	var ATTRIBUTE_NODE              = NodeType.ATTRIBUTE_NODE              = 2;
	var TEXT_NODE                   = NodeType.TEXT_NODE                   = 3;
	var CDATA_SECTION_NODE          = NodeType.CDATA_SECTION_NODE          = 4;
	var ENTITY_REFERENCE_NODE       = NodeType.ENTITY_REFERENCE_NODE       = 5;
	var ENTITY_NODE                 = NodeType.ENTITY_NODE                 = 6;
	var PROCESSING_INSTRUCTION_NODE = NodeType.PROCESSING_INSTRUCTION_NODE = 7;
	var COMMENT_NODE                = NodeType.COMMENT_NODE                = 8;
	var DOCUMENT_NODE               = NodeType.DOCUMENT_NODE               = 9;
	var DOCUMENT_TYPE_NODE          = NodeType.DOCUMENT_TYPE_NODE          = 10;
	var DOCUMENT_FRAGMENT_NODE      = NodeType.DOCUMENT_FRAGMENT_NODE      = 11;
	var NOTATION_NODE               = NodeType.NOTATION_NODE               = 12;

	// ExceptionCode
	var ExceptionCode = {}
	var ExceptionMessage = {};
	var INDEX_SIZE_ERR              = ExceptionCode.INDEX_SIZE_ERR              = ((ExceptionMessage[1]="Index size error"),1);
	var DOMSTRING_SIZE_ERR          = ExceptionCode.DOMSTRING_SIZE_ERR          = ((ExceptionMessage[2]="DOMString size error"),2);
	var HIERARCHY_REQUEST_ERR       = ExceptionCode.HIERARCHY_REQUEST_ERR       = ((ExceptionMessage[3]="Hierarchy request error"),3);
	var WRONG_DOCUMENT_ERR          = ExceptionCode.WRONG_DOCUMENT_ERR          = ((ExceptionMessage[4]="Wrong document"),4);
	var INVALID_CHARACTER_ERR       = ExceptionCode.INVALID_CHARACTER_ERR       = ((ExceptionMessage[5]="Invalid character"),5);
	var NO_DATA_ALLOWED_ERR         = ExceptionCode.NO_DATA_ALLOWED_ERR         = ((ExceptionMessage[6]="No data allowed"),6);
	var NO_MODIFICATION_ALLOWED_ERR = ExceptionCode.NO_MODIFICATION_ALLOWED_ERR = ((ExceptionMessage[7]="No modification allowed"),7);
	var NOT_FOUND_ERR               = ExceptionCode.NOT_FOUND_ERR               = ((ExceptionMessage[8]="Not found"),8);
	var NOT_SUPPORTED_ERR           = ExceptionCode.NOT_SUPPORTED_ERR           = ((ExceptionMessage[9]="Not supported"),9);
	var INUSE_ATTRIBUTE_ERR         = ExceptionCode.INUSE_ATTRIBUTE_ERR         = ((ExceptionMessage[10]="Attribute in use"),10);
	//level2
	var INVALID_STATE_ERR        	= ExceptionCode.INVALID_STATE_ERR        	= ((ExceptionMessage[11]="Invalid state"),11);
	var SYNTAX_ERR               	= ExceptionCode.SYNTAX_ERR               	= ((ExceptionMessage[12]="Syntax error"),12);
	var INVALID_MODIFICATION_ERR 	= ExceptionCode.INVALID_MODIFICATION_ERR 	= ((ExceptionMessage[13]="Invalid modification"),13);
	var NAMESPACE_ERR            	= ExceptionCode.NAMESPACE_ERR           	= ((ExceptionMessage[14]="Invalid namespace"),14);
	var INVALID_ACCESS_ERR       	= ExceptionCode.INVALID_ACCESS_ERR      	= ((ExceptionMessage[15]="Invalid access"),15);


	function DOMException(code, message) {
		if(message instanceof Error){
			var error = message;
		}else{
			error = this;
			Error.call(this, ExceptionMessage[code]);
			this.message = ExceptionMessage[code];
			if(Error.captureStackTrace) Error.captureStackTrace(this, DOMException);
		}
		error.code = code;
		if(message) this.message = this.message + ": " + message;
		return error;
	};
	DOMException.prototype = Error.prototype;
	copy(ExceptionCode,DOMException)
	/**
	 * @see http://www.w3.org/TR/2000/REC-DOM-Level-2-Core-20001113/core.html#ID-536297177
	 * The NodeList interface provides the abstraction of an ordered collection of nodes, without defining or constraining how this collection is implemented. NodeList objects in the DOM are live.
	 * The items in the NodeList are accessible via an integral index, starting from 0.
	 */
	function NodeList() {
	};
	NodeList.prototype = {
		/**
		 * The number of nodes in the list. The range of valid child node indices is 0 to length-1 inclusive.
		 * @standard level1
		 */
		length:0, 
		/**
		 * Returns the indexth item in the collection. If index is greater than or equal to the number of nodes in the list, this returns null.
		 * @standard level1
		 * @param index  unsigned long 
		 *   Index into the collection.
		 * @return Node
		 * 	The node at the indexth position in the NodeList, or null if that is not a valid index. 
		 */
		item: function(index) {
			return this[index] || null;
		},
		toString:function(){
			for(var buf = [], i = 0;i<this.length;i++){
				serializeToString(this[i],buf);
			}
			return buf.join('');
		}
	};
	function LiveNodeList(node,refresh){
		this._node = node;
		this._refresh = refresh
		_updateLiveList(this);
	}
	function _updateLiveList(list){
		var inc = list._node._inc || list._node.ownerDocument._inc;
		if(list._inc != inc){
			var ls = list._refresh(list._node);
			//console.log(ls.length)
			__set__(list,'length',ls.length);
			copy(ls,list);
			list._inc = inc;
		}
	}
	LiveNodeList.prototype.item = function(i){
		_updateLiveList(this);
		return this[i];
	}

	_extends(LiveNodeList,NodeList);
	/**
	 * 
	 * Objects implementing the NamedNodeMap interface are used to represent collections of nodes that can be accessed by name. Note that NamedNodeMap does not inherit from NodeList; NamedNodeMaps are not maintained in any particular order. Objects contained in an object implementing NamedNodeMap may also be accessed by an ordinal index, but this is simply to allow convenient enumeration of the contents of a NamedNodeMap, and does not imply that the DOM specifies an order to these Nodes.
	 * NamedNodeMap objects in the DOM are live.
	 * used for attributes or DocumentType entities 
	 */
	function NamedNodeMap() {
	};

	function _findNodeIndex(list,node){
		var i = list.length;
		while(i--){
			if(list[i] === node){return i}
		}
	}

	function _addNamedNode(el,list,newAttr,oldAttr){
		if(oldAttr){
			list[_findNodeIndex(list,oldAttr)] = newAttr;
		}else{
			list[list.length++] = newAttr;
		}
		if(el){
			newAttr.ownerElement = el;
			var doc = el.ownerDocument;
			if(doc){
				oldAttr && _onRemoveAttribute(doc,el,oldAttr);
				_onAddAttribute(doc,el,newAttr);
			}
		}
	}
	function _removeNamedNode(el,list,attr){
		var i = _findNodeIndex(list,attr);
		if(i>=0){
			var lastIndex = list.length-1
			while(i<lastIndex){
				list[i] = list[++i]
			}
			list.length = lastIndex;
			if(el){
				var doc = el.ownerDocument;
				if(doc){
					_onRemoveAttribute(doc,el,attr);
					attr.ownerElement = null;
				}
			}
		}else{
			throw DOMException(NOT_FOUND_ERR,new Error())
		}
	}
	NamedNodeMap.prototype = {
		length:0,
		item:NodeList.prototype.item,
		getNamedItem: function(key) {
	//		if(key.indexOf(':')>0 || key == 'xmlns'){
	//			return null;
	//		}
			var i = this.length;
			while(i--){
				var attr = this[i];
				if(attr.nodeName == key){
					return attr;
				}
			}
		},
		setNamedItem: function(attr) {
			var el = attr.ownerElement;
			if(el && el!=this._ownerElement){
				throw new DOMException(INUSE_ATTRIBUTE_ERR);
			}
			var oldAttr = this.getNamedItem(attr.nodeName);
			_addNamedNode(this._ownerElement,this,attr,oldAttr);
			return oldAttr;
		},
		/* returns Node */
		setNamedItemNS: function(attr) {// raises: WRONG_DOCUMENT_ERR,NO_MODIFICATION_ALLOWED_ERR,INUSE_ATTRIBUTE_ERR
			var el = attr.ownerElement, oldAttr;
			if(el && el!=this._ownerElement){
				throw new DOMException(INUSE_ATTRIBUTE_ERR);
			}
			oldAttr = this.getNamedItemNS(attr.namespaceURI,attr.localName);
			_addNamedNode(this._ownerElement,this,attr,oldAttr);
			return oldAttr;
		},

		/* returns Node */
		removeNamedItem: function(key) {
			var attr = this.getNamedItem(key);
			_removeNamedNode(this._ownerElement,this,attr);
			return attr;
			
			
		},// raises: NOT_FOUND_ERR,NO_MODIFICATION_ALLOWED_ERR
		
		//for level2
		removeNamedItemNS:function(namespaceURI,localName){
			var attr = this.getNamedItemNS(namespaceURI,localName);
			_removeNamedNode(this._ownerElement,this,attr);
			return attr;
		},
		getNamedItemNS: function(namespaceURI, localName) {
			var i = this.length;
			while(i--){
				var node = this[i];
				if(node.localName == localName && node.namespaceURI == namespaceURI){
					return node;
				}
			}
			return null;
		}
	};
	/**
	 * @see http://www.w3.org/TR/REC-DOM-Level-1/level-one-core.html#ID-102161490
	 */
	function DOMImplementation(/* Object */ features) {
		this._features = {};
		if (features) {
			for (var feature in features) {
				 this._features = features[feature];
			}
		}
	};

	DOMImplementation.prototype = {
		hasFeature: function(/* string */ feature, /* string */ version) {
			var versions = this._features[feature.toLowerCase()];
			if (versions && (!version || version in versions)) {
				return true;
			} else {
				return false;
			}
		},
		// Introduced in DOM Level 2:
		createDocument:function(namespaceURI,  qualifiedName, doctype){// raises:INVALID_CHARACTER_ERR,NAMESPACE_ERR,WRONG_DOCUMENT_ERR
			var doc = new Document();
			doc.implementation = this;
			doc.childNodes = new NodeList();
			doc.doctype = doctype;
			if(doctype){
				doc.appendChild(doctype);
			}
			if(qualifiedName){
				var root = doc.createElementNS(namespaceURI,qualifiedName);
				doc.appendChild(root);
			}
			return doc;
		},
		// Introduced in DOM Level 2:
		createDocumentType:function(qualifiedName, publicId, systemId){// raises:INVALID_CHARACTER_ERR,NAMESPACE_ERR
			var node = new DocumentType();
			node.name = qualifiedName;
			node.nodeName = qualifiedName;
			node.publicId = publicId;
			node.systemId = systemId;
			// Introduced in DOM Level 2:
			//readonly attribute DOMString        internalSubset;
			
			//TODO:..
			//  readonly attribute NamedNodeMap     entities;
			//  readonly attribute NamedNodeMap     notations;
			return node;
		}
	};


	/**
	 * @see http://www.w3.org/TR/2000/REC-DOM-Level-2-Core-20001113/core.html#ID-1950641247
	 */

	function Node() {
	};

	Node.prototype = {
		firstChild : null,
		lastChild : null,
		previousSibling : null,
		nextSibling : null,
		attributes : null,
		parentNode : null,
		childNodes : null,
		ownerDocument : null,
		nodeValue : null,
		namespaceURI : null,
		prefix : null,
		localName : null,
		// Modified in DOM Level 2:
		insertBefore:function(newChild, refChild){//raises 
			return _insertBefore(this,newChild,refChild);
		},
		replaceChild:function(newChild, oldChild){//raises 
			this.insertBefore(newChild,oldChild);
			if(oldChild){
				this.removeChild(oldChild);
			}
		},
		removeChild:function(oldChild){
			return _removeChild(this,oldChild);
		},
		appendChild:function(newChild){
			return this.insertBefore(newChild,null);
		},
		hasChildNodes:function(){
			return this.firstChild != null;
		},
		cloneNode:function(deep){
			return cloneNode(this.ownerDocument||this,this,deep);
		},
		// Modified in DOM Level 2:
		normalize:function(){
			var child = this.firstChild;
			while(child){
				var next = child.nextSibling;
				if(next && next.nodeType == TEXT_NODE && child.nodeType == TEXT_NODE){
					this.removeChild(next);
					child.appendData(next.data);
				}else{
					child.normalize();
					child = next;
				}
			}
		},
	  	// Introduced in DOM Level 2:
		isSupported:function(feature, version){
			return this.ownerDocument.implementation.hasFeature(feature,version);
		},
	    // Introduced in DOM Level 2:
	    hasAttributes:function(){
	    	return this.attributes.length>0;
	    },
	    lookupPrefix:function(namespaceURI){
	    	var el = this;
	    	while(el){
	    		var map = el._nsMap;
	    		//console.dir(map)
	    		if(map){
	    			for(var n in map){
	    				if(map[n] == namespaceURI){
	    					return n;
	    				}
	    			}
	    		}
	    		el = el.nodeType == 2?el.ownerDocument : el.parentNode;
	    	}
	    	return null;
	    },
	    // Introduced in DOM Level 3:
	    lookupNamespaceURI:function(prefix){
	    	var el = this;
	    	while(el){
	    		var map = el._nsMap;
	    		//console.dir(map)
	    		if(map){
	    			if(prefix in map){
	    				return map[prefix] ;
	    			}
	    		}
	    		el = el.nodeType == 2?el.ownerDocument : el.parentNode;
	    	}
	    	return null;
	    },
	    // Introduced in DOM Level 3:
	    isDefaultNamespace:function(namespaceURI){
	    	var prefix = this.lookupPrefix(namespaceURI);
	    	return prefix == null;
	    }
	};


	function _xmlEncoder(c){
		return c == '<' && '&lt;' ||
	         c == '>' && '&gt;' ||
	         c == '&' && '&amp;' ||
	         c == '"' && '&quot;' ||
	         '&#'+c.charCodeAt()+';'
	}


	copy(NodeType,Node);
	copy(NodeType,Node.prototype);

	/**
	 * @param callback return true for continue,false for break
	 * @return boolean true: break visit;
	 */
	function _visitNode(node,callback){
		if(callback(node)){
			return true;
		}
		if(node = node.firstChild){
			do{
				if(_visitNode(node,callback)){return true}
	        }while(node=node.nextSibling)
	    }
	}



	function Document(){
	}
	function _onAddAttribute(doc,el,newAttr){
		doc && doc._inc++;
		var ns = newAttr.namespaceURI ;
		if(ns == 'http://www.w3.org/2000/xmlns/'){
			//update namespace
			el._nsMap[newAttr.prefix?newAttr.localName:''] = newAttr.value
		}
	}
	function _onRemoveAttribute(doc,el,newAttr,remove){
		doc && doc._inc++;
		var ns = newAttr.namespaceURI ;
		if(ns == 'http://www.w3.org/2000/xmlns/'){
			//update namespace
			delete el._nsMap[newAttr.prefix?newAttr.localName:'']
		}
	}
	function _onUpdateChild(doc,el,newChild){
		if(doc && doc._inc){
			doc._inc++;
			//update childNodes
			var cs = el.childNodes;
			if(newChild){
				cs[cs.length++] = newChild;
			}else{
				//console.log(1)
				var child = el.firstChild;
				var i = 0;
				while(child){
					cs[i++] = child;
					child =child.nextSibling;
				}
				cs.length = i;
			}
		}
	}

	/**
	 * attributes;
	 * children;
	 * 
	 * writeable properties:
	 * nodeValue,Attr:value,CharacterData:data
	 * prefix
	 */
	function _removeChild(parentNode,child){
		var previous = child.previousSibling;
		var next = child.nextSibling;
		if(previous){
			previous.nextSibling = next;
		}else{
			parentNode.firstChild = next
		}
		if(next){
			next.previousSibling = previous;
		}else{
			parentNode.lastChild = previous;
		}
		_onUpdateChild(parentNode.ownerDocument,parentNode);
		return child;
	}
	/**
	 * preformance key(refChild == null)
	 */
	function _insertBefore(parentNode,newChild,nextChild){
		var cp = newChild.parentNode;
		if(cp){
			cp.removeChild(newChild);//remove and update
		}
		if(newChild.nodeType === DOCUMENT_FRAGMENT_NODE){
			var newFirst = newChild.firstChild;
			if (newFirst == null) {
				return newChild;
			}
			var newLast = newChild.lastChild;
		}else{
			newFirst = newLast = newChild;
		}
		var pre = nextChild ? nextChild.previousSibling : parentNode.lastChild;

		newFirst.previousSibling = pre;
		newLast.nextSibling = nextChild;
		
		
		if(pre){
			pre.nextSibling = newFirst;
		}else{
			parentNode.firstChild = newFirst;
		}
		if(nextChild == null){
			parentNode.lastChild = newLast;
		}else{
			nextChild.previousSibling = newLast;
		}
		do{
			newFirst.parentNode = parentNode;
		}while(newFirst !== newLast && (newFirst= newFirst.nextSibling))
		_onUpdateChild(parentNode.ownerDocument||parentNode,parentNode);
		//console.log(parentNode.lastChild.nextSibling == null)
		if (newChild.nodeType == DOCUMENT_FRAGMENT_NODE) {
			newChild.firstChild = newChild.lastChild = null;
		}
		return newChild;
	}
	function _appendSingleChild(parentNode,newChild){
		var cp = newChild.parentNode;
		if(cp){
			var pre = parentNode.lastChild;
			cp.removeChild(newChild);//remove and update
			var pre = parentNode.lastChild;
		}
		var pre = parentNode.lastChild;
		newChild.parentNode = parentNode;
		newChild.previousSibling = pre;
		newChild.nextSibling = null;
		if(pre){
			pre.nextSibling = newChild;
		}else{
			parentNode.firstChild = newChild;
		}
		parentNode.lastChild = newChild;
		_onUpdateChild(parentNode.ownerDocument,parentNode,newChild);
		return newChild;
		//console.log("__aa",parentNode.lastChild.nextSibling == null)
	}
	Document.prototype = {
		//implementation : null,
		nodeName :  '#document',
		nodeType :  DOCUMENT_NODE,
		doctype :  null,
		documentElement :  null,
		_inc : 1,
		
		insertBefore :  function(newChild, refChild){//raises 
			if(newChild.nodeType == DOCUMENT_FRAGMENT_NODE){
				var child = newChild.firstChild;
				while(child){
					var next = child.nextSibling;
					this.insertBefore(child,refChild);
					child = next;
				}
				return newChild;
			}
			if(this.documentElement == null && newChild.nodeType == 1){
				this.documentElement = newChild;
			}
			
			return _insertBefore(this,newChild,refChild),(newChild.ownerDocument = this),newChild;
		},
		removeChild :  function(oldChild){
			if(this.documentElement == oldChild){
				this.documentElement = null;
			}
			return _removeChild(this,oldChild);
		},
		// Introduced in DOM Level 2:
		importNode : function(importedNode,deep){
			return importNode(this,importedNode,deep);
		},
		// Introduced in DOM Level 2:
		getElementById :	function(id){
			var rtv = null;
			_visitNode(this.documentElement,function(node){
				if(node.nodeType == 1){
					if(node.getAttribute('id') == id){
						rtv = node;
						return true;
					}
				}
			})
			return rtv;
		},
		
		//document factory method:
		createElement :	function(tagName){
			var node = new Element();
			node.ownerDocument = this;
			node.nodeName = tagName;
			node.tagName = tagName;
			node.childNodes = new NodeList();
			var attrs	= node.attributes = new NamedNodeMap();
			attrs._ownerElement = node;
			return node;
		},
		createDocumentFragment :	function(){
			var node = new DocumentFragment();
			node.ownerDocument = this;
			node.childNodes = new NodeList();
			return node;
		},
		createTextNode :	function(data){
			var node = new Text();
			node.ownerDocument = this;
			node.appendData(data)
			return node;
		},
		createComment :	function(data){
			var node = new Comment();
			node.ownerDocument = this;
			node.appendData(data)
			return node;
		},
		createCDATASection :	function(data){
			var node = new CDATASection();
			node.ownerDocument = this;
			node.appendData(data)
			return node;
		},
		createProcessingInstruction :	function(target,data){
			var node = new ProcessingInstruction();
			node.ownerDocument = this;
			node.tagName = node.target = target;
			node.nodeValue= node.data = data;
			return node;
		},
		createAttribute :	function(name){
			var node = new Attr();
			node.ownerDocument	= this;
			node.name = name;
			node.nodeName	= name;
			node.localName = name;
			node.specified = true;
			return node;
		},
		createEntityReference :	function(name){
			var node = new EntityReference();
			node.ownerDocument	= this;
			node.nodeName	= name;
			return node;
		},
		// Introduced in DOM Level 2:
		createElementNS :	function(namespaceURI,qualifiedName){
			var node = new Element();
			var pl = qualifiedName.split(':');
			var attrs	= node.attributes = new NamedNodeMap();
			node.childNodes = new NodeList();
			node.ownerDocument = this;
			node.nodeName = qualifiedName;
			node.tagName = qualifiedName;
			node.namespaceURI = namespaceURI;
			if(pl.length == 2){
				node.prefix = pl[0];
				node.localName = pl[1];
			}else{
				//el.prefix = null;
				node.localName = qualifiedName;
			}
			attrs._ownerElement = node;
			return node;
		},
		// Introduced in DOM Level 2:
		createAttributeNS :	function(namespaceURI,qualifiedName){
			var node = new Attr();
			var pl = qualifiedName.split(':');
			node.ownerDocument = this;
			node.nodeName = qualifiedName;
			node.name = qualifiedName;
			node.namespaceURI = namespaceURI;
			node.specified = true;
			if(pl.length == 2){
				node.prefix = pl[0];
				node.localName = pl[1];
			}else{
				//el.prefix = null;
				node.localName = qualifiedName;
			}
			return node;
		}
	};
	_extends(Document,Node);


	function Element() {
		this._nsMap = {};
	};
	Element.prototype = {
		nodeType : ELEMENT_NODE,
		hasAttribute : function(name){
			return this.getAttributeNode(name)!=null;
		},
		getAttribute : function(name){
			var attr = this.getAttributeNode(name);
			return attr && attr.value || '';
		},
		getAttributeNode : function(name){
			return this.attributes.getNamedItem(name);
		},
		setAttribute : function(name, value){
			var attr = this.ownerDocument.createAttribute(name);
			attr.value = attr.nodeValue = "" + value;
			this.setAttributeNode(attr)
		},
		removeAttribute : function(name){
			var attr = this.getAttributeNode(name)
			attr && this.removeAttributeNode(attr);
		},
		
		//four real opeartion method
		appendChild:function(newChild){
			if(newChild.nodeType === DOCUMENT_FRAGMENT_NODE){
				return this.insertBefore(newChild,null);
			}else{
				return _appendSingleChild(this,newChild);
			}
		},
		setAttributeNode : function(newAttr){
			return this.attributes.setNamedItem(newAttr);
		},
		setAttributeNodeNS : function(newAttr){
			return this.attributes.setNamedItemNS(newAttr);
		},
		removeAttributeNode : function(oldAttr){
			return this.attributes.removeNamedItem(oldAttr.nodeName);
		},
		//get real attribute name,and remove it by removeAttributeNode
		removeAttributeNS : function(namespaceURI, localName){
			var old = this.getAttributeNodeNS(namespaceURI, localName);
			old && this.removeAttributeNode(old);
		},
		
		hasAttributeNS : function(namespaceURI, localName){
			return this.getAttributeNodeNS(namespaceURI, localName)!=null;
		},
		getAttributeNS : function(namespaceURI, localName){
			var attr = this.getAttributeNodeNS(namespaceURI, localName);
			return attr && attr.value || '';
		},
		setAttributeNS : function(namespaceURI, qualifiedName, value){
			var attr = this.ownerDocument.createAttributeNS(namespaceURI, qualifiedName);
			attr.value = attr.nodeValue = "" + value;
			this.setAttributeNode(attr)
		},
		getAttributeNodeNS : function(namespaceURI, localName){
			return this.attributes.getNamedItemNS(namespaceURI, localName);
		},
		
		getElementsByTagName : function(tagName){
			return new LiveNodeList(this,function(base){
				var ls = [];
				_visitNode(base,function(node){
					if(node !== base && node.nodeType == ELEMENT_NODE && (tagName === '*' || node.tagName == tagName)){
						ls.push(node);
					}
				});
				return ls;
			});
		},
		getElementsByTagNameNS : function(namespaceURI, localName){
			return new LiveNodeList(this,function(base){
				var ls = [];
				_visitNode(base,function(node){
					if(node !== base && node.nodeType === ELEMENT_NODE && (namespaceURI === '*' || node.namespaceURI === namespaceURI) && (localName === '*' || node.localName == localName)){
						ls.push(node);
					}
				});
				return ls;
			});
		}
	};
	Document.prototype.getElementsByTagName = Element.prototype.getElementsByTagName;
	Document.prototype.getElementsByTagNameNS = Element.prototype.getElementsByTagNameNS;


	_extends(Element,Node);
	function Attr() {
	};
	Attr.prototype.nodeType = ATTRIBUTE_NODE;
	_extends(Attr,Node);


	function CharacterData() {
	};
	CharacterData.prototype = {
		data : '',
		substringData : function(offset, count) {
			return this.data.substring(offset, offset+count);
		},
		appendData: function(text) {
			text = this.data+text;
			this.nodeValue = this.data = text;
			this.length = text.length;
		},
		insertData: function(offset,text) {
			this.replaceData(offset,0,text);
		
		},
		appendChild:function(newChild){
			//if(!(newChild instanceof CharacterData)){
				throw new Error(ExceptionMessage[3])
			//}
			return Node.prototype.appendChild.apply(this,arguments)
		},
		deleteData: function(offset, count) {
			this.replaceData(offset,count,"");
		},
		replaceData: function(offset, count, text) {
			var start = this.data.substring(0,offset);
			var end = this.data.substring(offset+count);
			text = start + text + end;
			this.nodeValue = this.data = text;
			this.length = text.length;
		}
	}
	_extends(CharacterData,Node);
	function Text() {
	};
	Text.prototype = {
		nodeName : "#text",
		nodeType : TEXT_NODE,
		splitText : function(offset) {
			var text = this.data;
			var newText = text.substring(offset);
			text = text.substring(0, offset);
			this.data = this.nodeValue = text;
			this.length = text.length;
			var newNode = this.ownerDocument.createTextNode(newText);
			if(this.parentNode){
				this.parentNode.insertBefore(newNode, this.nextSibling);
			}
			return newNode;
		}
	}
	_extends(Text,CharacterData);
	function Comment() {
	};
	Comment.prototype = {
		nodeName : "#comment",
		nodeType : COMMENT_NODE
	}
	_extends(Comment,CharacterData);

	function CDATASection() {
	};
	CDATASection.prototype = {
		nodeName : "#cdata-section",
		nodeType : CDATA_SECTION_NODE
	}
	_extends(CDATASection,CharacterData);


	function DocumentType() {
	};
	DocumentType.prototype.nodeType = DOCUMENT_TYPE_NODE;
	_extends(DocumentType,Node);

	function Notation() {
	};
	Notation.prototype.nodeType = NOTATION_NODE;
	_extends(Notation,Node);

	function Entity() {
	};
	Entity.prototype.nodeType = ENTITY_NODE;
	_extends(Entity,Node);

	function EntityReference() {
	};
	EntityReference.prototype.nodeType = ENTITY_REFERENCE_NODE;
	_extends(EntityReference,Node);

	function DocumentFragment() {
	};
	DocumentFragment.prototype.nodeName =	"#document-fragment";
	DocumentFragment.prototype.nodeType =	DOCUMENT_FRAGMENT_NODE;
	_extends(DocumentFragment,Node);


	function ProcessingInstruction() {
	}
	ProcessingInstruction.prototype.nodeType = PROCESSING_INSTRUCTION_NODE;
	_extends(ProcessingInstruction,Node);
	function XMLSerializer(){}
	XMLSerializer.prototype.serializeToString = function(node,attributeSorter){
		return node.toString(attributeSorter);
	}
	Node.prototype.toString =function(attributeSorter){
		var buf = [];
		serializeToString(this,buf,attributeSorter);
		return buf.join('');
	}
	function serializeToString(node,buf,attributeSorter,isHTML){
		switch(node.nodeType){
		case ELEMENT_NODE:
			var attrs = node.attributes;
			var len = attrs.length;
			var child = node.firstChild;
			var nodeName = node.tagName;
			isHTML =  (htmlns === node.namespaceURI) ||isHTML 
			buf.push('<',nodeName);
			if(attributeSorter){
				buf.sort.apply(attrs, attributeSorter);
			}
			for(var i=0;i<len;i++){
				serializeToString(attrs.item(i),buf,attributeSorter,isHTML);
			}
			if(child || isHTML && !/^(?:meta|link|img|br|hr|input|button)$/i.test(nodeName)){
				buf.push('>');
				//if is cdata child node
				if(isHTML && /^script$/i.test(nodeName)){
					if(child){
						buf.push(child.data);
					}
				}else{
					while(child){
						serializeToString(child,buf,attributeSorter,isHTML);
						child = child.nextSibling;
					}
				}
				buf.push('</',nodeName,'>');
			}else{
				buf.push('/>');
			}
			return;
		case DOCUMENT_NODE:
		case DOCUMENT_FRAGMENT_NODE:
			var child = node.firstChild;
			while(child){
				serializeToString(child,buf,attributeSorter,isHTML);
				child = child.nextSibling;
			}
			return;
		case ATTRIBUTE_NODE:
			return buf.push(' ',node.name,'="',node.value.replace(/[<&"]/g,_xmlEncoder),'"');
		case TEXT_NODE:
			return buf.push(node.data.replace(/[<&]/g,_xmlEncoder));
		case CDATA_SECTION_NODE:
			return buf.push( '<![CDATA[',node.data,']]>');
		case COMMENT_NODE:
			return buf.push( "<!--",node.data,"-->");
		case DOCUMENT_TYPE_NODE:
			var pubid = node.publicId;
			var sysid = node.systemId;
			buf.push('<!DOCTYPE ',node.name);
			if(pubid){
				buf.push(' PUBLIC "',pubid);
				if (sysid && sysid!='.') {
					buf.push( '" "',sysid);
				}
				buf.push('">');
			}else if(sysid && sysid!='.'){
				buf.push(' SYSTEM "',sysid,'">');
			}else{
				var sub = node.internalSubset;
				if(sub){
					buf.push(" [",sub,"]");
				}
				buf.push(">");
			}
			return;
		case PROCESSING_INSTRUCTION_NODE:
			return buf.push( "<?",node.target," ",node.data,"?>");
		case ENTITY_REFERENCE_NODE:
			return buf.push( '&',node.nodeName,';');
		//case ENTITY_NODE:
		//case NOTATION_NODE:
		default:
			buf.push('??',node.nodeName);
		}
	}
	function importNode(doc,node,deep){
		var node2;
		switch (node.nodeType) {
		case ELEMENT_NODE:
			node2 = node.cloneNode(false);
			node2.ownerDocument = doc;
			//var attrs = node2.attributes;
			//var len = attrs.length;
			//for(var i=0;i<len;i++){
				//node2.setAttributeNodeNS(importNode(doc,attrs.item(i),deep));
			//}
		case DOCUMENT_FRAGMENT_NODE:
			break;
		case ATTRIBUTE_NODE:
			deep = true;
			break;
		//case ENTITY_REFERENCE_NODE:
		//case PROCESSING_INSTRUCTION_NODE:
		////case TEXT_NODE:
		//case CDATA_SECTION_NODE:
		//case COMMENT_NODE:
		//	deep = false;
		//	break;
		//case DOCUMENT_NODE:
		//case DOCUMENT_TYPE_NODE:
		//cannot be imported.
		//case ENTITY_NODE:
		//case NOTATION_NODE：
		//can not hit in level3
		//default:throw e;
		}
		if(!node2){
			node2 = node.cloneNode(false);//false
		}
		node2.ownerDocument = doc;
		node2.parentNode = null;
		if(deep){
			var child = node.firstChild;
			while(child){
				node2.appendChild(importNode(doc,child,deep));
				child = child.nextSibling;
			}
		}
		return node2;
	}
	//
	//var _relationMap = {firstChild:1,lastChild:1,previousSibling:1,nextSibling:1,
	//					attributes:1,childNodes:1,parentNode:1,documentElement:1,doctype,};
	function cloneNode(doc,node,deep){
		var node2 = new node.constructor();
		for(var n in node){
			var v = node[n];
			if(typeof v != 'object' ){
				if(v != node2[n]){
					node2[n] = v;
				}
			}
		}
		if(node.childNodes){
			node2.childNodes = new NodeList();
		}
		node2.ownerDocument = doc;
		switch (node2.nodeType) {
		case ELEMENT_NODE:
			var attrs	= node.attributes;
			var attrs2	= node2.attributes = new NamedNodeMap();
			var len = attrs.length
			attrs2._ownerElement = node2;
			for(var i=0;i<len;i++){
				node2.setAttributeNode(cloneNode(doc,attrs.item(i),true));
			}
			break;;
		case ATTRIBUTE_NODE:
			deep = true;
		}
		if(deep){
			var child = node.firstChild;
			while(child){
				node2.appendChild(cloneNode(doc,child,deep));
				child = child.nextSibling;
			}
		}
		return node2;
	}

	function __set__(object,key,value){
		object[key] = value
	}
	//do dynamic
	try{
		if(Object.defineProperty){
			Object.defineProperty(LiveNodeList.prototype,'length',{
				get:function(){
					_updateLiveList(this);
					return this.$$length;
				}
			});
			Object.defineProperty(Node.prototype,'textContent',{
				get:function(){
					return getTextContent(this);
				},
				set:function(data){
					switch(this.nodeType){
					case 1:
					case 11:
						while(this.firstChild){
							this.removeChild(this.firstChild);
						}
						if(data || String(data)){
							this.appendChild(this.ownerDocument.createTextNode(data));
						}
						break;
					default:
						//TODO:
						this.data = data;
						this.value = value;
						this.nodeValue = data;
					}
				}
			})
			
			function getTextContent(node){
				switch(node.nodeType){
				case 1:
				case 11:
					var buf = [];
					node = node.firstChild;
					while(node){
						if(node.nodeType!==7 && node.nodeType !==8){
							buf.push(getTextContent(node));
						}
						node = node.nextSibling;
					}
					return buf.join('');
				default:
					return node.nodeValue;
				}
			}
			__set__ = function(object,key,value){
				//console.log(value)
				object['$$'+key] = value
			}
		}
	}catch(e){//ie8
	}

	if(true){
		exports.DOMImplementation = DOMImplementation;
		exports.XMLSerializer = XMLSerializer;
	}


/***/ },
/* 200 */
/***/ function(module, exports, __webpack_require__) {

	// Generated by CoffeeScript 1.10.0
	(function() {
	  "use strict";
	  var bom, builder, escapeCDATA, events, isEmpty, processName, processors, requiresCDATA, sax, setImmediate, wrapCDATA,
	    extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
	    hasProp = {}.hasOwnProperty,
	    bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; };

	  sax = __webpack_require__(255);

	  events = __webpack_require__(194);

	  builder = __webpack_require__(256);

	  bom = __webpack_require__(227);

	  processors = __webpack_require__(228);

	  setImmediate = __webpack_require__(253).setImmediate;

	  isEmpty = function(thing) {
	    return typeof thing === "object" && (thing != null) && Object.keys(thing).length === 0;
	  };

	  processName = function(processors, processedName) {
	    var i, len, process;
	    for (i = 0, len = processors.length; i < len; i++) {
	      process = processors[i];
	      processedName = process(processedName);
	    }
	    return processedName;
	  };

	  requiresCDATA = function(entry) {
	    return entry.indexOf('&') >= 0 || entry.indexOf('>') >= 0 || entry.indexOf('<') >= 0;
	  };

	  wrapCDATA = function(entry) {
	    return "<![CDATA[" + (escapeCDATA(entry)) + "]]>";
	  };

	  escapeCDATA = function(entry) {
	    return entry.replace(']]>', ']]]]><![CDATA[>');
	  };

	  exports.processors = processors;

	  exports.defaults = {
	    "0.1": {
	      explicitCharkey: false,
	      trim: true,
	      normalize: true,
	      normalizeTags: false,
	      attrkey: "@",
	      charkey: "#",
	      explicitArray: false,
	      ignoreAttrs: false,
	      mergeAttrs: false,
	      explicitRoot: false,
	      validator: null,
	      xmlns: false,
	      explicitChildren: false,
	      childkey: '@@',
	      charsAsChildren: false,
	      async: false,
	      strict: true,
	      attrNameProcessors: null,
	      attrValueProcessors: null,
	      tagNameProcessors: null,
	      valueProcessors: null,
	      emptyTag: ''
	    },
	    "0.2": {
	      explicitCharkey: false,
	      trim: false,
	      normalize: false,
	      normalizeTags: false,
	      attrkey: "$",
	      charkey: "_",
	      explicitArray: true,
	      ignoreAttrs: false,
	      mergeAttrs: false,
	      explicitRoot: true,
	      validator: null,
	      xmlns: false,
	      explicitChildren: false,
	      preserveChildrenOrder: false,
	      childkey: '$$',
	      charsAsChildren: false,
	      async: false,
	      strict: true,
	      attrNameProcessors: null,
	      attrValueProcessors: null,
	      tagNameProcessors: null,
	      valueProcessors: null,
	      rootName: 'root',
	      xmldec: {
	        'version': '1.0',
	        'encoding': 'UTF-8',
	        'standalone': true
	      },
	      doctype: null,
	      renderOpts: {
	        'pretty': true,
	        'indent': '  ',
	        'newline': '\n'
	      },
	      headless: false,
	      chunkSize: 10000,
	      emptyTag: '',
	      cdata: false
	    }
	  };

	  exports.ValidationError = (function(superClass) {
	    extend(ValidationError, superClass);

	    function ValidationError(message) {
	      this.message = message;
	    }

	    return ValidationError;

	  })(Error);

	  exports.Builder = (function() {
	    function Builder(opts) {
	      var key, ref, value;
	      this.options = {};
	      ref = exports.defaults["0.2"];
	      for (key in ref) {
	        if (!hasProp.call(ref, key)) continue;
	        value = ref[key];
	        this.options[key] = value;
	      }
	      for (key in opts) {
	        if (!hasProp.call(opts, key)) continue;
	        value = opts[key];
	        this.options[key] = value;
	      }
	    }

	    Builder.prototype.buildObject = function(rootObj) {
	      var attrkey, charkey, render, rootElement, rootName;
	      attrkey = this.options.attrkey;
	      charkey = this.options.charkey;
	      if ((Object.keys(rootObj).length === 1) && (this.options.rootName === exports.defaults['0.2'].rootName)) {
	        rootName = Object.keys(rootObj)[0];
	        rootObj = rootObj[rootName];
	      } else {
	        rootName = this.options.rootName;
	      }
	      render = (function(_this) {
	        return function(element, obj) {
	          var attr, child, entry, index, key, value;
	          if (typeof obj !== 'object') {
	            if (_this.options.cdata && requiresCDATA(obj)) {
	              element.raw(wrapCDATA(obj));
	            } else {
	              element.txt(obj);
	            }
	          } else {
	            for (key in obj) {
	              if (!hasProp.call(obj, key)) continue;
	              child = obj[key];
	              if (key === attrkey) {
	                if (typeof child === "object") {
	                  for (attr in child) {
	                    value = child[attr];
	                    element = element.att(attr, value);
	                  }
	                }
	              } else if (key === charkey) {
	                if (_this.options.cdata && requiresCDATA(child)) {
	                  element = element.raw(wrapCDATA(child));
	                } else {
	                  element = element.txt(child);
	                }
	              } else if (Array.isArray(child)) {
	                for (index in child) {
	                  if (!hasProp.call(child, index)) continue;
	                  entry = child[index];
	                  if (typeof entry === 'string') {
	                    if (_this.options.cdata && requiresCDATA(entry)) {
	                      element = element.ele(key).raw(wrapCDATA(entry)).up();
	                    } else {
	                      element = element.ele(key, entry).up();
	                    }
	                  } else {
	                    element = render(element.ele(key), entry).up();
	                  }
	                }
	              } else if (typeof child === "object") {
	                element = render(element.ele(key), child).up();
	              } else {
	                if (typeof child === 'string' && _this.options.cdata && requiresCDATA(child)) {
	                  element = element.ele(key).raw(wrapCDATA(child)).up();
	                } else {
	                  if (child == null) {
	                    child = '';
	                  }
	                  element = element.ele(key, child.toString()).up();
	                }
	              }
	            }
	          }
	          return element;
	        };
	      })(this);
	      rootElement = builder.create(rootName, this.options.xmldec, this.options.doctype, {
	        headless: this.options.headless,
	        allowSurrogateChars: this.options.allowSurrogateChars
	      });
	      return render(rootElement, rootObj).end(this.options.renderOpts);
	    };

	    return Builder;

	  })();

	  exports.Parser = (function(superClass) {
	    extend(Parser, superClass);

	    function Parser(opts) {
	      this.parseString = bind(this.parseString, this);
	      this.reset = bind(this.reset, this);
	      this.assignOrPush = bind(this.assignOrPush, this);
	      this.processAsync = bind(this.processAsync, this);
	      var key, ref, value;
	      if (!(this instanceof exports.Parser)) {
	        return new exports.Parser(opts);
	      }
	      this.options = {};
	      ref = exports.defaults["0.2"];
	      for (key in ref) {
	        if (!hasProp.call(ref, key)) continue;
	        value = ref[key];
	        this.options[key] = value;
	      }
	      for (key in opts) {
	        if (!hasProp.call(opts, key)) continue;
	        value = opts[key];
	        this.options[key] = value;
	      }
	      if (this.options.xmlns) {
	        this.options.xmlnskey = this.options.attrkey + "ns";
	      }
	      if (this.options.normalizeTags) {
	        if (!this.options.tagNameProcessors) {
	          this.options.tagNameProcessors = [];
	        }
	        this.options.tagNameProcessors.unshift(processors.normalize);
	      }
	      this.reset();
	    }

	    Parser.prototype.processAsync = function() {
	      var chunk, err, error1;
	      try {
	        if (this.remaining.length <= this.options.chunkSize) {
	          chunk = this.remaining;
	          this.remaining = '';
	          this.saxParser = this.saxParser.write(chunk);
	          return this.saxParser.close();
	        } else {
	          chunk = this.remaining.substr(0, this.options.chunkSize);
	          this.remaining = this.remaining.substr(this.options.chunkSize, this.remaining.length);
	          this.saxParser = this.saxParser.write(chunk);
	          return setImmediate(this.processAsync);
	        }
	      } catch (error1) {
	        err = error1;
	        if (!this.saxParser.errThrown) {
	          this.saxParser.errThrown = true;
	          return this.emit(err);
	        }
	      }
	    };

	    Parser.prototype.assignOrPush = function(obj, key, newValue) {
	      if (!(key in obj)) {
	        if (!this.options.explicitArray) {
	          return obj[key] = newValue;
	        } else {
	          return obj[key] = [newValue];
	        }
	      } else {
	        if (!(obj[key] instanceof Array)) {
	          obj[key] = [obj[key]];
	        }
	        return obj[key].push(newValue);
	      }
	    };

	    Parser.prototype.reset = function() {
	      var attrkey, charkey, ontext, stack;
	      this.removeAllListeners();
	      this.saxParser = sax.parser(this.options.strict, {
	        trim: false,
	        normalize: false,
	        xmlns: this.options.xmlns
	      });
	      this.saxParser.errThrown = false;
	      this.saxParser.onerror = (function(_this) {
	        return function(error) {
	          _this.saxParser.resume();
	          if (!_this.saxParser.errThrown) {
	            _this.saxParser.errThrown = true;
	            return _this.emit("error", error);
	          }
	        };
	      })(this);
	      this.saxParser.onend = (function(_this) {
	        return function() {
	          if (!_this.saxParser.ended) {
	            _this.saxParser.ended = true;
	            return _this.emit("end", _this.resultObject);
	          }
	        };
	      })(this);
	      this.saxParser.ended = false;
	      this.EXPLICIT_CHARKEY = this.options.explicitCharkey;
	      this.resultObject = null;
	      stack = [];
	      attrkey = this.options.attrkey;
	      charkey = this.options.charkey;
	      this.saxParser.onopentag = (function(_this) {
	        return function(node) {
	          var key, newValue, obj, processedKey, ref;
	          obj = {};
	          obj[charkey] = "";
	          if (!_this.options.ignoreAttrs) {
	            ref = node.attributes;
	            for (key in ref) {
	              if (!hasProp.call(ref, key)) continue;
	              if (!(attrkey in obj) && !_this.options.mergeAttrs) {
	                obj[attrkey] = {};
	              }
	              newValue = _this.options.attrValueProcessors ? processName(_this.options.attrValueProcessors, node.attributes[key]) : node.attributes[key];
	              processedKey = _this.options.attrNameProcessors ? processName(_this.options.attrNameProcessors, key) : key;
	              if (_this.options.mergeAttrs) {
	                _this.assignOrPush(obj, processedKey, newValue);
	              } else {
	                obj[attrkey][processedKey] = newValue;
	              }
	            }
	          }
	          obj["#name"] = _this.options.tagNameProcessors ? processName(_this.options.tagNameProcessors, node.name) : node.name;
	          if (_this.options.xmlns) {
	            obj[_this.options.xmlnskey] = {
	              uri: node.uri,
	              local: node.local
	            };
	          }
	          return stack.push(obj);
	        };
	      })(this);
	      this.saxParser.onclosetag = (function(_this) {
	        return function() {
	          var cdata, emptyStr, err, error1, key, node, nodeName, obj, objClone, old, s, xpath;
	          obj = stack.pop();
	          nodeName = obj["#name"];
	          if (!_this.options.explicitChildren || !_this.options.preserveChildrenOrder) {
	            delete obj["#name"];
	          }
	          if (obj.cdata === true) {
	            cdata = obj.cdata;
	            delete obj.cdata;
	          }
	          s = stack[stack.length - 1];
	          if (obj[charkey].match(/^\s*$/) && !cdata) {
	            emptyStr = obj[charkey];
	            delete obj[charkey];
	          } else {
	            if (_this.options.trim) {
	              obj[charkey] = obj[charkey].trim();
	            }
	            if (_this.options.normalize) {
	              obj[charkey] = obj[charkey].replace(/\s{2,}/g, " ").trim();
	            }
	            obj[charkey] = _this.options.valueProcessors ? processName(_this.options.valueProcessors, obj[charkey]) : obj[charkey];
	            if (Object.keys(obj).length === 1 && charkey in obj && !_this.EXPLICIT_CHARKEY) {
	              obj = obj[charkey];
	            }
	          }
	          if (isEmpty(obj)) {
	            obj = _this.options.emptyTag !== '' ? _this.options.emptyTag : emptyStr;
	          }
	          if (_this.options.validator != null) {
	            xpath = "/" + ((function() {
	              var i, len, results;
	              results = [];
	              for (i = 0, len = stack.length; i < len; i++) {
	                node = stack[i];
	                results.push(node["#name"]);
	              }
	              return results;
	            })()).concat(nodeName).join("/");
	            try {
	              obj = _this.options.validator(xpath, s && s[nodeName], obj);
	            } catch (error1) {
	              err = error1;
	              _this.emit("error", err);
	            }
	          }
	          if (_this.options.explicitChildren && !_this.options.mergeAttrs && typeof obj === 'object') {
	            if (!_this.options.preserveChildrenOrder) {
	              node = {};
	              if (_this.options.attrkey in obj) {
	                node[_this.options.attrkey] = obj[_this.options.attrkey];
	                delete obj[_this.options.attrkey];
	              }
	              if (!_this.options.charsAsChildren && _this.options.charkey in obj) {
	                node[_this.options.charkey] = obj[_this.options.charkey];
	                delete obj[_this.options.charkey];
	              }
	              if (Object.getOwnPropertyNames(obj).length > 0) {
	                node[_this.options.childkey] = obj;
	              }
	              obj = node;
	            } else if (s) {
	              s[_this.options.childkey] = s[_this.options.childkey] || [];
	              objClone = {};
	              for (key in obj) {
	                if (!hasProp.call(obj, key)) continue;
	                objClone[key] = obj[key];
	              }
	              s[_this.options.childkey].push(objClone);
	              delete obj["#name"];
	              if (Object.keys(obj).length === 1 && charkey in obj && !_this.EXPLICIT_CHARKEY) {
	                obj = obj[charkey];
	              }
	            }
	          }
	          if (stack.length > 0) {
	            return _this.assignOrPush(s, nodeName, obj);
	          } else {
	            if (_this.options.explicitRoot) {
	              old = obj;
	              obj = {};
	              obj[nodeName] = old;
	            }
	            _this.resultObject = obj;
	            _this.saxParser.ended = true;
	            return _this.emit("end", _this.resultObject);
	          }
	        };
	      })(this);
	      ontext = (function(_this) {
	        return function(text) {
	          var charChild, s;
	          s = stack[stack.length - 1];
	          if (s) {
	            s[charkey] += text;
	            if (_this.options.explicitChildren && _this.options.preserveChildrenOrder && _this.options.charsAsChildren && text.replace(/\\n/g, '').trim() !== '') {
	              s[_this.options.childkey] = s[_this.options.childkey] || [];
	              charChild = {
	                '#name': '__text__'
	              };
	              charChild[charkey] = text;
	              s[_this.options.childkey].push(charChild);
	            }
	            return s;
	          }
	        };
	      })(this);
	      this.saxParser.ontext = ontext;
	      return this.saxParser.oncdata = (function(_this) {
	        return function(text) {
	          var s;
	          s = ontext(text);
	          if (s) {
	            return s.cdata = true;
	          }
	        };
	      })(this);
	    };

	    Parser.prototype.parseString = function(str, cb) {
	      var err, error1;
	      if ((cb != null) && typeof cb === "function") {
	        this.on("end", function(result) {
	          this.reset();
	          return cb(null, result);
	        });
	        this.on("error", function(err) {
	          this.reset();
	          return cb(err);
	        });
	      }
	      try {
	        str = str.toString();
	        if (str.trim() === '') {
	          this.emit("end", null);
	          return true;
	        }
	        str = bom.stripBOM(str);
	        if (this.options.async) {
	          this.remaining = str;
	          setImmediate(this.processAsync);
	          return this.saxParser;
	        }
	        return this.saxParser.write(str).close();
	      } catch (error1) {
	        err = error1;
	        if (!(this.saxParser.errThrown || this.saxParser.ended)) {
	          this.emit('error', err);
	          return this.saxParser.errThrown = true;
	        } else if (this.saxParser.ended) {
	          throw err;
	        }
	      }
	    };

	    return Parser;

	  })(events.EventEmitter);

	  exports.parseString = function(str, a, b) {
	    var cb, options, parser;
	    if (b != null) {
	      if (typeof b === 'function') {
	        cb = b;
	      }
	      if (typeof a === 'object') {
	        options = a;
	      }
	    } else {
	      if (typeof a === 'function') {
	        cb = a;
	      }
	      options = {};
	    }
	    parser = new exports.Parser(options);
	    return parser.parseString(str, cb);
	  };

	}).call(this);


/***/ },
/* 201 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(global) {
	/**
	 * Module exports.
	 */

	module.exports = deprecate;

	/**
	 * Mark that a method should not be used.
	 * Returns a modified function which warns once by default.
	 *
	 * If `localStorage.noDeprecation = true` is set, then it is a no-op.
	 *
	 * If `localStorage.throwDeprecation = true` is set, then deprecated functions
	 * will throw an Error when invoked.
	 *
	 * If `localStorage.traceDeprecation = true` is set, then deprecated functions
	 * will invoke `console.trace()` instead of `console.error()`.
	 *
	 * @param {Function} fn - the function to deprecate
	 * @param {String} msg - the string to print to the console when `fn` is invoked
	 * @returns {Function} a new "deprecated" version of `fn`
	 * @api public
	 */

	function deprecate (fn, msg) {
	  if (config('noDeprecation')) {
	    return fn;
	  }

	  var warned = false;
	  function deprecated() {
	    if (!warned) {
	      if (config('throwDeprecation')) {
	        throw new Error(msg);
	      } else if (config('traceDeprecation')) {
	        console.trace(msg);
	      } else {
	        console.warn(msg);
	      }
	      warned = true;
	    }
	    return fn.apply(this, arguments);
	  }

	  return deprecated;
	}

	/**
	 * Checks `localStorage` for boolean values for the given `name`.
	 *
	 * @param {String} name
	 * @returns {Boolean}
	 * @api private
	 */

	function config (name) {
	  // accessing global.localStorage can trigger a DOMException in sandboxed iframes
	  try {
	    if (!global.localStorage) return false;
	  } catch (_) {
	    return false;
	  }
	  var val = global.localStorage[name];
	  if (null == val) return false;
	  return String(val).toLowerCase() === 'true';
	}
	
	/* WEBPACK VAR INJECTION */}.call(exports, (function() { return this; }())))

/***/ },
/* 202 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';
	var Schema = __webpack_require__(149);
	module.exports = new Schema({
	    explicit: [
	        __webpack_require__(224),
	        __webpack_require__(225),
	        __webpack_require__(226)
	    ]
	});
	//# sourceMappingURL=failsafe.js.map

/***/ },
/* 203 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';
	var Type = __webpack_require__(185);
	function resolveYamlNull(data) {
	    if (null === data) {
	        return true;
	    }
	    var max = data.length;
	    return (max === 1 && data === '~') ||
	        (max === 4 && (data === 'null' || data === 'Null' || data === 'NULL'));
	}
	function constructYamlNull() {
	    return null;
	}
	function isNull(object) {
	    return null === object;
	}
	module.exports = new Type('tag:yaml.org,2002:null', {
	    kind: 'scalar',
	    resolve: resolveYamlNull,
	    construct: constructYamlNull,
	    predicate: isNull,
	    represent: {
	        canonical: function () { return '~'; },
	        lowercase: function () { return 'null'; },
	        uppercase: function () { return 'NULL'; },
	        camelcase: function () { return 'Null'; }
	    },
	    defaultStyle: 'lowercase'
	});
	//# sourceMappingURL=null.js.map

/***/ },
/* 204 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";
	'use strict';
	var Type = __webpack_require__(185);
	function resolveYamlBoolean(data) {
	    if (null === data) {
	        return false;
	    }
	    var max = data.length;
	    return (max === 4 && (data === 'true' || data === 'True' || data === 'TRUE')) ||
	        (max === 5 && (data === 'false' || data === 'False' || data === 'FALSE'));
	}
	function constructYamlBoolean(data) {
	    return data === 'true' ||
	        data === 'True' ||
	        data === 'TRUE';
	}
	function isBoolean(object) {
	    return '[object Boolean]' === Object.prototype.toString.call(object);
	}
	module.exports = new Type('tag:yaml.org,2002:bool', {
	    kind: 'scalar',
	    resolve: resolveYamlBoolean,
	    construct: constructYamlBoolean,
	    predicate: isBoolean,
	    represent: {
	        lowercase: function (object) { return object ? 'true' : 'false'; },
	        uppercase: function (object) { return object ? 'TRUE' : 'FALSE'; },
	        camelcase: function (object) { return object ? 'True' : 'False'; }
	    },
	    defaultStyle: 'lowercase'
	});
	//# sourceMappingURL=bool.js.map

/***/ },
/* 205 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';
	var common = __webpack_require__(106);
	var Type = __webpack_require__(185);
	function isHexCode(c) {
	    return ((0x30 <= c) && (c <= 0x39)) ||
	        ((0x41 <= c) && (c <= 0x46)) ||
	        ((0x61 <= c) && (c <= 0x66));
	}
	function isOctCode(c) {
	    return ((0x30 <= c) && (c <= 0x37));
	}
	function isDecCode(c) {
	    return ((0x30 <= c) && (c <= 0x39));
	}
	function resolveYamlInteger(data) {
	    if (null === data) {
	        return false;
	    }
	    var max = data.length, index = 0, hasDigits = false, ch;
	    if (!max) {
	        return false;
	    }
	    ch = data[index];
	    if (ch === '-' || ch === '+') {
	        ch = data[++index];
	    }
	    if (ch === '0') {
	        if (index + 1 === max) {
	            return true;
	        }
	        ch = data[++index];
	        if (ch === 'b') {
	            index++;
	            for (; index < max; index++) {
	                ch = data[index];
	                if (ch === '_') {
	                    continue;
	                }
	                if (ch !== '0' && ch !== '1') {
	                    return false;
	                }
	                hasDigits = true;
	            }
	            return hasDigits;
	        }
	        if (ch === 'x') {
	            index++;
	            for (; index < max; index++) {
	                ch = data[index];
	                if (ch === '_') {
	                    continue;
	                }
	                if (!isHexCode(data.charCodeAt(index))) {
	                    return false;
	                }
	                hasDigits = true;
	            }
	            return hasDigits;
	        }
	        for (; index < max; index++) {
	            ch = data[index];
	            if (ch === '_') {
	                continue;
	            }
	            if (!isOctCode(data.charCodeAt(index))) {
	                return false;
	            }
	            hasDigits = true;
	        }
	        return hasDigits;
	    }
	    for (; index < max; index++) {
	        ch = data[index];
	        if (ch === '_') {
	            continue;
	        }
	        if (ch === ':') {
	            break;
	        }
	        if (!isDecCode(data.charCodeAt(index))) {
	            return false;
	        }
	        hasDigits = true;
	    }
	    if (!hasDigits) {
	        return false;
	    }
	    if (ch !== ':') {
	        return true;
	    }
	    return /^(:[0-5]?[0-9])+$/.test(data.slice(index));
	}
	function constructYamlInteger(data) {
	    var value = data, sign = 1, ch, base, digits = [];
	    if (value.indexOf('_') !== -1) {
	        value = value.replace(/_/g, '');
	    }
	    ch = value[0];
	    if (ch === '-' || ch === '+') {
	        if (ch === '-') {
	            sign = -1;
	        }
	        value = value.slice(1);
	        ch = value[0];
	    }
	    if ('0' === value) {
	        return 0;
	    }
	    if (ch === '0') {
	        if (value[1] === 'b') {
	            return sign * parseInt(value.slice(2), 2);
	        }
	        if (value[1] === 'x') {
	            return sign * parseInt(value, 16);
	        }
	        return sign * parseInt(value, 8);
	    }
	    if (value.indexOf(':') !== -1) {
	        value.split(':').forEach(function (v) {
	            digits.unshift(parseInt(v, 10));
	        });
	        value = 0;
	        base = 1;
	        digits.forEach(function (d) {
	            value += (d * base);
	            base *= 60;
	        });
	        return sign * value;
	    }
	    return sign * parseInt(value, 10);
	}
	function isInteger(object) {
	    return ('[object Number]' === Object.prototype.toString.call(object)) &&
	        (0 === object % 1 && !common.isNegativeZero(object));
	}
	module.exports = new Type('tag:yaml.org,2002:int', {
	    kind: 'scalar',
	    resolve: resolveYamlInteger,
	    construct: constructYamlInteger,
	    predicate: isInteger,
	    represent: {
	        binary: function (object) { return '0b' + object.toString(2); },
	        octal: function (object) { return '0' + object.toString(8); },
	        decimal: function (object) { return object.toString(10); },
	        hexadecimal: function (object) { return '0x' + object.toString(16).toUpperCase(); }
	    },
	    defaultStyle: 'decimal',
	    styleAliases: {
	        binary: [2, 'bin'],
	        octal: [8, 'oct'],
	        decimal: [10, 'dec'],
	        hexadecimal: [16, 'hex']
	    }
	});
	//# sourceMappingURL=int.js.map

/***/ },
/* 206 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';
	var common = __webpack_require__(106);
	var Type = __webpack_require__(185);
	var YAML_FLOAT_PATTERN = new RegExp('^(?:[-+]?(?:[0-9][0-9_]*)\\.[0-9_]*(?:[eE][-+][0-9]+)?' +
	    '|\\.[0-9_]+(?:[eE][-+][0-9]+)?' +
	    '|[-+]?[0-9][0-9_]*(?::[0-5]?[0-9])+\\.[0-9_]*' +
	    '|[-+]?\\.(?:inf|Inf|INF)' +
	    '|\\.(?:nan|NaN|NAN))$');
	function resolveYamlFloat(data) {
	    if (null === data) {
	        return false;
	    }
	    var value, sign, base, digits;
	    if (!YAML_FLOAT_PATTERN.test(data)) {
	        return false;
	    }
	    return true;
	}
	function constructYamlFloat(data) {
	    var value, sign, base, digits;
	    value = data.replace(/_/g, '').toLowerCase();
	    sign = '-' === value[0] ? -1 : 1;
	    digits = [];
	    if (0 <= '+-'.indexOf(value[0])) {
	        value = value.slice(1);
	    }
	    if ('.inf' === value) {
	        return (1 === sign) ? Number.POSITIVE_INFINITY : Number.NEGATIVE_INFINITY;
	    }
	    else if ('.nan' === value) {
	        return NaN;
	    }
	    else if (0 <= value.indexOf(':')) {
	        value.split(':').forEach(function (v) {
	            digits.unshift(parseFloat(v, 10));
	        });
	        value = 0.0;
	        base = 1;
	        digits.forEach(function (d) {
	            value += d * base;
	            base *= 60;
	        });
	        return sign * value;
	    }
	    return sign * parseFloat(value, 10);
	}
	function representYamlFloat(object, style) {
	    if (isNaN(object)) {
	        switch (style) {
	            case 'lowercase':
	                return '.nan';
	            case 'uppercase':
	                return '.NAN';
	            case 'camelcase':
	                return '.NaN';
	        }
	    }
	    else if (Number.POSITIVE_INFINITY === object) {
	        switch (style) {
	            case 'lowercase':
	                return '.inf';
	            case 'uppercase':
	                return '.INF';
	            case 'camelcase':
	                return '.Inf';
	        }
	    }
	    else if (Number.NEGATIVE_INFINITY === object) {
	        switch (style) {
	            case 'lowercase':
	                return '-.inf';
	            case 'uppercase':
	                return '-.INF';
	            case 'camelcase':
	                return '-.Inf';
	        }
	    }
	    else if (common.isNegativeZero(object)) {
	        return '-0.0';
	    }
	    return object.toString(10);
	}
	function isFloat(object) {
	    return ('[object Number]' === Object.prototype.toString.call(object)) &&
	        (0 !== object % 1 || common.isNegativeZero(object));
	}
	module.exports = new Type('tag:yaml.org,2002:float', {
	    kind: 'scalar',
	    resolve: resolveYamlFloat,
	    construct: constructYamlFloat,
	    predicate: isFloat,
	    represent: representYamlFloat,
	    defaultStyle: 'lowercase'
	});
	//# sourceMappingURL=float.js.map

/***/ },
/* 207 */
/***/ function(module, exports, __webpack_require__) {

	// Number.isFinite polyfill
	// http://people.mozilla.org/~jorendorff/es6-draft.html#sec-number.isfinite
	if (typeof Number.isFinite !== "function") {
	    Number.isFinite = function isFinite(value) {
	        // 1. If Type(number) is not Number, return false.
	        if (typeof value !== "number") {
	            return false;
	        }
	        // 2. If number is NaN, +∞, or −∞, return false.
	        if (value !== value || value === Infinity || value === -Infinity) {
	            return false;
	        }
	        // 3. Otherwise, return true.
	        return true;
	    };
	}


/***/ },
/* 208 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(process) {"use strict";

	var get    = __webpack_require__(230);
	var Errors = __webpack_require__(229);
	var Utils  = __webpack_require__(214);

	function Report(parentOrOptions, reportOptions) {
	    this.parentReport = parentOrOptions instanceof Report ?
	                            parentOrOptions :
	                            undefined;

	    this.options = parentOrOptions instanceof Report ?
	                       parentOrOptions.options :
	                       parentOrOptions || {};

	    this.reportOptions = reportOptions || {};

	    this.errors = [];
	    this.path = [];
	    this.asyncTasks = [];
	}

	Report.prototype.isValid = function () {
	    if (this.asyncTasks.length > 0) {
	        throw new Error("Async tasks pending, can't answer isValid");
	    }
	    return this.errors.length === 0;
	};

	Report.prototype.addAsyncTask = function (fn, args, asyncTaskResultProcessFn) {
	    this.asyncTasks.push([fn, args, asyncTaskResultProcessFn]);
	};

	Report.prototype.processAsyncTasks = function (timeout, callback) {

	    var validationTimeout = timeout || 2000,
	        tasksCount        = this.asyncTasks.length,
	        idx               = tasksCount,
	        timedOut          = false,
	        self              = this;

	    function finish() {
	        process.nextTick(function () {
	            var valid = self.errors.length === 0,
	                err   = valid ? undefined : self.errors;
	            callback(err, valid);
	        });
	    }

	    function respond(asyncTaskResultProcessFn) {
	        return function (asyncTaskResult) {
	            if (timedOut) { return; }
	            asyncTaskResultProcessFn(asyncTaskResult);
	            if (--tasksCount === 0) {
	                finish();
	            }
	        };
	    }

	    if (tasksCount === 0 || this.errors.length > 0) {
	        finish();
	        return;
	    }

	    while (idx--) {
	        var task = this.asyncTasks[idx];
	        task[0].apply(null, task[1].concat(respond(task[2])));
	    }

	    setTimeout(function () {
	        if (tasksCount > 0) {
	            timedOut = true;
	            self.addError("ASYNC_TIMEOUT", [tasksCount, validationTimeout]);
	            callback(self.errors, false);
	        }
	    }, validationTimeout);

	};

	Report.prototype.getPath = function (returnPathAsString) {
	    var path = [];
	    if (this.parentReport) {
	        path = path.concat(this.parentReport.path);
	    }
	    path = path.concat(this.path);

	    if (returnPathAsString !== true) {
	        // Sanitize the path segments (http://tools.ietf.org/html/rfc6901#section-4)
	        path = "#/" + path.map(function (segment) {

	            if (Utils.isAbsoluteUri(segment)) {
	                return "uri(" + segment + ")";
	            }

	            return segment.replace(/\~/g, "~0").replace(/\//g, "~1");
	        }).join("/");
	    }
	    return path;
	};

	Report.prototype.getSchemaId = function () {

	    if (!this.rootSchema) {
	        return null;
	    }

	    // get the error path as an array
	    var path = [];
	    if (this.parentReport) {
	        path = path.concat(this.parentReport.path);
	    }
	    path = path.concat(this.path);

	    // try to find id in the error path
	    while (path.length > 0) {
	        var obj = get(this.rootSchema, path);
	        if (obj && obj.id) { return obj.id; }
	        path.pop();
	    }

	    // return id of the root
	    return this.rootSchema.id;
	};

	Report.prototype.hasError = function (errorCode, params) {
	    var idx = this.errors.length;
	    while (idx--) {
	        if (this.errors[idx].code === errorCode) {
	            // assume match
	            var match = true;

	            // check the params too
	            var idx2 = this.errors[idx].params.length;
	            while (idx2--) {
	                if (this.errors[idx].params[idx2] !== params[idx2]) {
	                    match = false;
	                }
	            }

	            // if match, return true
	            if (match) { return match; }
	        }
	    }
	    return false;
	};

	Report.prototype.addError = function (errorCode, params, subReports, schemaDescription) {
	    if (!errorCode) { throw new Error("No errorCode passed into addError()"); }

	    this.addCustomError(errorCode, Errors[errorCode], params, subReports, schemaDescription);
	};

	Report.prototype.addCustomError = function (errorCode, errorMessage, params, subReports, schemaDescription) {
	    if (this.errors.length >= this.reportOptions.maxErrors) {
	        return;
	    }

	    if (!errorMessage) { throw new Error("No errorMessage known for code " + errorCode); }

	    params = params || [];

	    var idx = params.length;
	    while (idx--) {
	        var whatIs = Utils.whatIs(params[idx]);
	        var param = (whatIs === "object" || whatIs === "null") ? JSON.stringify(params[idx]) : params[idx];
	        errorMessage = errorMessage.replace("{" + idx + "}", param);
	    }

	    var err = {
	        code: errorCode,
	        params: params,
	        message: errorMessage,
	        path: this.getPath(this.options.reportPathAsArray),
	        schemaId: this.getSchemaId()
	    };

	    if (schemaDescription) {
	        err.description = schemaDescription;
	    }

	    if (subReports != null) {
	        if (!Array.isArray(subReports)) {
	            subReports = [subReports];
	        }
	        err.inner = [];
	        idx = subReports.length;
	        while (idx--) {
	            var subReport = subReports[idx],
	                idx2 = subReport.errors.length;
	            while (idx2--) {
	                err.inner.push(subReport.errors[idx2]);
	            }
	        }
	        if (err.inner.length === 0) {
	            err.inner = undefined;
	        }
	    }

	    this.errors.push(err);
	};

	module.exports = Report;
	
	/* WEBPACK VAR INJECTION */}.call(exports, __webpack_require__(56)))

/***/ },
/* 209 */
/***/ function(module, exports, __webpack_require__) {

	/*jshint maxlen: false*/

	var validator = __webpack_require__(254);

	var FormatValidators = {
	    "date": function (date) {
	        if (typeof date !== "string") {
	            return true;
	        }
	        // full-date from http://tools.ietf.org/html/rfc3339#section-5.6
	        var matches = /^([0-9]{4})-([0-9]{2})-([0-9]{2})$/.exec(date);
	        if (matches === null) {
	            return false;
	        }
	        // var year = matches[1];
	        // var month = matches[2];
	        // var day = matches[3];
	        if (matches[2] < "01" || matches[2] > "12" || matches[3] < "01" || matches[3] > "31") {
	            return false;
	        }
	        return true;
	    },
	    "date-time": function (dateTime) {
	        if (typeof dateTime !== "string") {
	            return true;
	        }
	        // date-time from http://tools.ietf.org/html/rfc3339#section-5.6
	        var s = dateTime.toLowerCase().split("t");
	        if (!FormatValidators.date(s[0])) {
	            return false;
	        }
	        var matches = /^([0-9]{2}):([0-9]{2}):([0-9]{2})(.[0-9]+)?(z|([+-][0-9]{2}:[0-9]{2}))$/.exec(s[1]);
	        if (matches === null) {
	            return false;
	        }
	        // var hour = matches[1];
	        // var minute = matches[2];
	        // var second = matches[3];
	        // var fraction = matches[4];
	        // var timezone = matches[5];
	        if (matches[1] > "23" || matches[2] > "59" || matches[3] > "59") {
	            return false;
	        }
	        return true;
	    },
	    "email": function (email) {
	        if (typeof email !== "string") {
	            return true;
	        }
	        return validator.isEmail(email, { "require_tld": true });
	    },
	    "hostname": function (hostname) {
	        if (typeof hostname !== "string") {
	            return true;
	        }
	        /*
	            http://json-schema.org/latest/json-schema-validation.html#anchor114
	            A string instance is valid against this attribute if it is a valid
	            representation for an Internet host name, as defined by RFC 1034, section 3.1 [RFC1034].

	            http://tools.ietf.org/html/rfc1034#section-3.5

	            <digit> ::= any one of the ten digits 0 through 9
	            var digit = /[0-9]/;

	            <letter> ::= any one of the 52 alphabetic characters A through Z in upper case and a through z in lower case
	            var letter = /[a-zA-Z]/;

	            <let-dig> ::= <letter> | <digit>
	            var letDig = /[0-9a-zA-Z]/;

	            <let-dig-hyp> ::= <let-dig> | "-"
	            var letDigHyp = /[-0-9a-zA-Z]/;

	            <ldh-str> ::= <let-dig-hyp> | <let-dig-hyp> <ldh-str>
	            var ldhStr = /[-0-9a-zA-Z]+/;

	            <label> ::= <letter> [ [ <ldh-str> ] <let-dig> ]
	            var label = /[a-zA-Z](([-0-9a-zA-Z]+)?[0-9a-zA-Z])?/;

	            <subdomain> ::= <label> | <subdomain> "." <label>
	            var subdomain = /^[a-zA-Z](([-0-9a-zA-Z]+)?[0-9a-zA-Z])?(\.[a-zA-Z](([-0-9a-zA-Z]+)?[0-9a-zA-Z])?)*$/;

	            <domain> ::= <subdomain> | " "
	            var domain = null;
	        */
	        var valid = /^[a-zA-Z](([-0-9a-zA-Z]+)?[0-9a-zA-Z])?(\.[a-zA-Z](([-0-9a-zA-Z]+)?[0-9a-zA-Z])?)*$/.test(hostname);
	        if (valid) {
	            // the sum of all label octets and label lengths is limited to 255.
	            if (hostname.length > 255) { return false; }
	            // Each node has a label, which is zero to 63 octets in length
	            var labels = hostname.split(".");
	            for (var i = 0; i < labels.length; i++) { if (labels[i].length > 63) { return false; } }
	        }
	        return valid;
	    },
	    "host-name": function (hostname) {
	        return FormatValidators.hostname.call(this, hostname);
	    },
	    "ipv4": function (ipv4) {
	        if (typeof ipv4 !== "string") { return true; }
	        return validator.isIP(ipv4, 4);
	    },
	    "ipv6": function (ipv6) {
	        if (typeof ipv6 !== "string") { return true; }
	        return validator.isIP(ipv6, 6);
	    },
	    "regex": function (str) {
	        try {
	            RegExp(str);
	            return true;
	        } catch (e) {
	            return false;
	        }
	    },
	    "uri": function (uri) {
	        if (this.options.strictUris) {
	            return FormatValidators["strict-uri"].apply(this, arguments);
	        }
	        // https://github.com/zaggino/z-schema/issues/18
	        // RegExp from http://tools.ietf.org/html/rfc3986#appendix-B
	        return typeof uri !== "string" || RegExp("^(([^:/?#]+):)?(//([^/?#]*))?([^?#]*)(\\?([^#]*))?(#(.*))?").test(uri);
	    },
	    "strict-uri": function (uri) {
	        return typeof uri !== "string" || validator.isURL(uri);
	    }
	};

	module.exports = FormatValidators;


/***/ },
/* 210 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";

	var FormatValidators  = __webpack_require__(209),
	    Report            = __webpack_require__(208),
	    Utils             = __webpack_require__(214);

	var JsonValidators = {
	    multipleOf: function (report, schema, json) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.1.1.2
	        if (typeof json !== "number") {
	            return;
	        }
	        if (Utils.whatIs(json / schema.multipleOf) !== "integer") {
	            report.addError("MULTIPLE_OF", [json, schema.multipleOf], null, schema.description);
	        }
	    },
	    maximum: function (report, schema, json) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.1.2.2
	        if (typeof json !== "number") {
	            return;
	        }
	        if (schema.exclusiveMaximum !== true) {
	            if (json > schema.maximum) {
	                report.addError("MAXIMUM", [json, schema.maximum], null, schema.description);
	            }
	        } else {
	            if (json >= schema.maximum) {
	                report.addError("MAXIMUM_EXCLUSIVE", [json, schema.maximum], null, schema.description);
	            }
	        }
	    },
	    exclusiveMaximum: function () {
	        // covered in maximum
	    },
	    minimum: function (report, schema, json) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.1.3.2
	        if (typeof json !== "number") {
	            return;
	        }
	        if (schema.exclusiveMinimum !== true) {
	            if (json < schema.minimum) {
	                report.addError("MINIMUM", [json, schema.minimum], null, schema.description);
	            }
	        } else {
	            if (json <= schema.minimum) {
	                report.addError("MINIMUM_EXCLUSIVE", [json, schema.minimum], null, schema.description);
	            }
	        }
	    },
	    exclusiveMinimum: function () {
	        // covered in minimum
	    },
	    maxLength: function (report, schema, json) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.2.1.2
	        if (typeof json !== "string") {
	            return;
	        }
	        if (Utils.ucs2decode(json).length > schema.maxLength) {
	            report.addError("MAX_LENGTH", [json.length, schema.maxLength], null, schema.description);
	        }
	    },
	    minLength: function (report, schema, json) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.2.2.2
	        if (typeof json !== "string") {
	            return;
	        }
	        if (Utils.ucs2decode(json).length < schema.minLength) {
	            report.addError("MIN_LENGTH", [json.length, schema.minLength], null, schema.description);
	        }
	    },
	    pattern: function (report, schema, json) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.2.3.2
	        if (typeof json !== "string") {
	            return;
	        }
	        if (RegExp(schema.pattern).test(json) === false) {
	            report.addError("PATTERN", [schema.pattern, json], null, schema.description);
	        }
	    },
	    additionalItems: function (report, schema, json) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.3.1.2
	        if (!Array.isArray(json)) {
	            return;
	        }
	        // if the value of "additionalItems" is boolean value false and the value of "items" is an array,
	        // the json is valid if its size is less than, or equal to, the size of "items".
	        if (schema.additionalItems === false && Array.isArray(schema.items)) {
	            if (json.length > schema.items.length) {
	                report.addError("ARRAY_ADDITIONAL_ITEMS", null, null, schema.description);
	            }
	        }
	    },
	    items: function () { /*report, schema, json*/
	        // covered in additionalItems
	    },
	    maxItems: function (report, schema, json) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.3.2.2
	        if (!Array.isArray(json)) {
	            return;
	        }
	        if (json.length > schema.maxItems) {
	            report.addError("ARRAY_LENGTH_LONG", [json.length, schema.maxItems], null, schema.description);
	        }
	    },
	    minItems: function (report, schema, json) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.3.3.2
	        if (!Array.isArray(json)) {
	            return;
	        }
	        if (json.length < schema.minItems) {
	            report.addError("ARRAY_LENGTH_SHORT", [json.length, schema.minItems], null, schema.description);
	        }
	    },
	    uniqueItems: function (report, schema, json) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.3.4.2
	        if (!Array.isArray(json)) {
	            return;
	        }
	        if (schema.uniqueItems === true) {
	            var matches = [];
	            if (Utils.isUniqueArray(json, matches) === false) {
	                report.addError("ARRAY_UNIQUE", matches, null, schema.description);
	            }
	        }
	    },
	    maxProperties: function (report, schema, json) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.4.1.2
	        if (Utils.whatIs(json) !== "object") {
	            return;
	        }
	        var keysCount = Object.keys(json).length;
	        if (keysCount > schema.maxProperties) {
	            report.addError("OBJECT_PROPERTIES_MAXIMUM", [keysCount, schema.maxProperties], null, schema.description);
	        }
	    },
	    minProperties: function (report, schema, json) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.4.2.2
	        if (Utils.whatIs(json) !== "object") {
	            return;
	        }
	        var keysCount = Object.keys(json).length;
	        if (keysCount < schema.minProperties) {
	            report.addError("OBJECT_PROPERTIES_MINIMUM", [keysCount, schema.minProperties], null, schema.description);
	        }
	    },
	    required: function (report, schema, json) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.4.3.2
	        if (Utils.whatIs(json) !== "object") {
	            return;
	        }
	        var idx = schema.required.length;
	        while (idx--) {
	            var requiredPropertyName = schema.required[idx];
	            if (json[requiredPropertyName] === undefined) {
	                report.addError("OBJECT_MISSING_REQUIRED_PROPERTY", [requiredPropertyName], null, schema.description);
	            }
	        }
	    },
	    additionalProperties: function (report, schema, json) {
	        // covered in properties and patternProperties
	        if (schema.properties === undefined && schema.patternProperties === undefined) {
	            return JsonValidators.properties.call(this, report, schema, json);
	        }
	    },
	    patternProperties: function (report, schema, json) {
	        // covered in properties
	        if (schema.properties === undefined) {
	            return JsonValidators.properties.call(this, report, schema, json);
	        }
	    },
	    properties: function (report, schema, json) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.4.4.2
	        if (Utils.whatIs(json) !== "object") {
	            return;
	        }
	        var properties = schema.properties !== undefined ? schema.properties : {};
	        var patternProperties = schema.patternProperties !== undefined ? schema.patternProperties : {};
	        if (schema.additionalProperties === false) {
	            // The property set of the json to validate.
	            var s = Object.keys(json);
	            // The property set from "properties".
	            var p = Object.keys(properties);
	            // The property set from "patternProperties".
	            var pp = Object.keys(patternProperties);
	            // remove from "s" all elements of "p", if any;
	            s = Utils.difference(s, p);
	            // for each regex in "pp", remove all elements of "s" which this regex matches.
	            var idx = pp.length;
	            while (idx--) {
	                var regExp = RegExp(pp[idx]),
	                    idx2 = s.length;
	                while (idx2--) {
	                    if (regExp.test(s[idx2]) === true) {
	                        s.splice(idx2, 1);
	                    }
	                }
	            }
	            // Validation of the json succeeds if, after these two steps, set "s" is empty.
	            if (s.length > 0) {
	                // assumeAdditional can be an array of allowed properties
	                var idx3 = this.options.assumeAdditional.length;
	                if (idx3) {
	                    while (idx3--) {
	                        var io = s.indexOf(this.options.assumeAdditional[idx3]);
	                        if (io !== -1) {
	                            s.splice(io, 1);
	                        }
	                    }
	                }
	                if (s.length > 0) {
	                    report.addError("OBJECT_ADDITIONAL_PROPERTIES", [s], null, schema.description);
	                }
	            }
	        }
	    },
	    dependencies: function (report, schema, json) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.4.5.2
	        if (Utils.whatIs(json) !== "object") {
	            return;
	        }

	        var keys = Object.keys(schema.dependencies),
	            idx = keys.length;

	        while (idx--) {
	            // iterate all dependencies
	            var dependencyName = keys[idx];
	            if (json[dependencyName]) {
	                var dependencyDefinition = schema.dependencies[dependencyName];
	                if (Utils.whatIs(dependencyDefinition) === "object") {
	                    // if dependency is a schema, validate against this schema
	                    exports.validate.call(this, report, dependencyDefinition, json);
	                } else { // Array
	                    // if dependency is an array, object needs to have all properties in this array
	                    var idx2 = dependencyDefinition.length;
	                    while (idx2--) {
	                        var requiredPropertyName = dependencyDefinition[idx2];
	                        if (json[requiredPropertyName] === undefined) {
	                            report.addError("OBJECT_DEPENDENCY_KEY", [requiredPropertyName, dependencyName], null, schema.description);
	                        }
	                    }
	                }
	            }
	        }
	    },
	    enum: function (report, schema, json) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.5.1.2
	        var match = false,
	            idx = schema.enum.length;
	        while (idx--) {
	            if (Utils.areEqual(json, schema.enum[idx])) {
	                match = true;
	                break;
	            }
	        }
	        if (match === false) {
	            report.addError("ENUM_MISMATCH", [json], null, schema.description);
	        }
	    },
	    /*
	    type: function (report, schema, json) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.5.2.2
	        // type is handled before this is called so ignore
	    },
	    */
	    allOf: function (report, schema, json) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.5.3.2
	        var idx = schema.allOf.length;
	        while (idx--) {
	            var validateResult = exports.validate.call(this, report, schema.allOf[idx], json);
	            if (this.options.breakOnFirstError && validateResult === false) {
	                break;
	            }
	        }
	    },
	    anyOf: function (report, schema, json) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.5.4.2
	        var subReports = [],
	            passed = false,
	            idx = schema.anyOf.length;

	        while (idx-- && passed === false) {
	            var subReport = new Report(report);
	            subReports.push(subReport);
	            passed = exports.validate.call(this, subReport, schema.anyOf[idx], json);
	        }

	        if (passed === false) {
	            report.addError("ANY_OF_MISSING", undefined, subReports, schema.description);
	        }
	    },
	    oneOf: function (report, schema, json) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.5.5.2
	        var passes = 0,
	            subReports = [],
	            idx = schema.oneOf.length;

	        while (idx--) {
	            var subReport = new Report(report, { maxErrors: 1 });
	            subReports.push(subReport);
	            if (exports.validate.call(this, subReport, schema.oneOf[idx], json) === true) {
	                passes++;
	            }
	        }

	        if (passes === 0) {
	            report.addError("ONE_OF_MISSING", undefined, subReports, schema.description);
	        } else if (passes > 1) {
	            report.addError("ONE_OF_MULTIPLE", null, null, schema.description);
	        }
	    },
	    not: function (report, schema, json) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.5.6.2
	        var subReport = new Report(report);
	        if (exports.validate.call(this, subReport, schema.not, json) === true) {
	            report.addError("NOT_PASSED", null, null, schema.description);
	        }
	    },
	    definitions: function () { /*report, schema, json*/
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.5.7.2
	        // nothing to do here
	    },
	    format: function (report, schema, json) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.7.2
	        var formatValidatorFn = FormatValidators[schema.format];
	        if (typeof formatValidatorFn === "function") {
	            if (formatValidatorFn.length === 2) {
	                // async
	                report.addAsyncTask(formatValidatorFn, [json], function (result) {
	                    if (result !== true) {
	                        report.addError("INVALID_FORMAT", [schema.format, json], null, schema.description);
	                    }
	                });
	            } else {
	                // sync
	                if (formatValidatorFn.call(this, json) !== true) {
	                    report.addError("INVALID_FORMAT", [schema.format, json], null, schema.description);
	                }
	            }
	        } else if (this.options.ignoreUnknownFormats !== true) {
	            report.addError("UNKNOWN_FORMAT", [schema.format], null, schema.description);
	        }
	    }
	};

	var recurseArray = function (report, schema, json) {
	    // http://json-schema.org/latest/json-schema-validation.html#rfc.section.8.2

	    var idx = json.length;

	    // If "items" is an array, this situation, the schema depends on the index:
	    // if the index is less than, or equal to, the size of "items",
	    // the child instance must be valid against the corresponding schema in the "items" array;
	    // otherwise, it must be valid against the schema defined by "additionalItems".
	    if (Array.isArray(schema.items)) {

	        while (idx--) {
	            // equal to doesnt make sense here
	            if (idx < schema.items.length) {
	                report.path.push(idx.toString());
	                exports.validate.call(this, report, schema.items[idx], json[idx]);
	                report.path.pop();
	            } else {
	                // might be boolean, so check that it's an object
	                if (typeof schema.additionalItems === "object") {
	                    report.path.push(idx.toString());
	                    exports.validate.call(this, report, schema.additionalItems, json[idx]);
	                    report.path.pop();
	                }
	            }
	        }

	    } else if (typeof schema.items === "object") {

	        // If items is a schema, then the child instance must be valid against this schema,
	        // regardless of its index, and regardless of the value of "additionalItems".
	        while (idx--) {
	            report.path.push(idx.toString());
	            exports.validate.call(this, report, schema.items, json[idx]);
	            report.path.pop();
	        }

	    }
	};

	var recurseObject = function (report, schema, json) {
	    // http://json-schema.org/latest/json-schema-validation.html#rfc.section.8.3

	    // If "additionalProperties" is absent, it is considered present with an empty schema as a value.
	    // In addition, boolean value true is considered equivalent to an empty schema.
	    var additionalProperties = schema.additionalProperties;
	    if (additionalProperties === true || additionalProperties === undefined) {
	        additionalProperties = {};
	    }

	    // p - The property set from "properties".
	    var p = schema.properties ? Object.keys(schema.properties) : [];

	    // pp - The property set from "patternProperties". Elements of this set will be called regexes for convenience.
	    var pp = schema.patternProperties ? Object.keys(schema.patternProperties) : [];

	    // m - The property name of the child.
	    var keys = Object.keys(json),
	        idx = keys.length;

	    while (idx--) {
	        var m = keys[idx],
	            propertyValue = json[m];

	        // s - The set of schemas for the child instance.
	        var s = [];

	        // 1. If set "p" contains value "m", then the corresponding schema in "properties" is added to "s".
	        if (p.indexOf(m) !== -1) {
	            s.push(schema.properties[m]);
	        }

	        // 2. For each regex in "pp", if it matches "m" successfully, the corresponding schema in "patternProperties" is added to "s".
	        var idx2 = pp.length;
	        while (idx2--) {
	            var regexString = pp[idx2];
	            if (RegExp(regexString).test(m) === true) {
	                s.push(schema.patternProperties[regexString]);
	            }
	        }

	        // 3. The schema defined by "additionalProperties" is added to "s" if and only if, at this stage, "s" is empty.
	        if (s.length === 0 && additionalProperties !== false) {
	            s.push(additionalProperties);
	        }

	        // we are passing tests even without this assert because this is covered by properties check
	        // if s is empty in this stage, no additionalProperties are allowed
	        // report.expect(s.length !== 0, 'E001', m);

	        // Instance property value must pass all schemas from s
	        idx2 = s.length;
	        while (idx2--) {
	            report.path.push(m);
	            exports.validate.call(this, report, s[idx2], propertyValue);
	            report.path.pop();
	        }
	    }
	};

	exports.validate = function (report, schema, json) {

	    report.commonErrorMessage = "JSON_OBJECT_VALIDATION_FAILED";

	    // check if schema is an object
	    var to = Utils.whatIs(schema);
	    if (to !== "object") {
	        report.addError("SCHEMA_NOT_AN_OBJECT", [to], null, schema.description);
	        return false;
	    }

	    // check if schema is empty, everything is valid against empty schema
	    var keys = Object.keys(schema);
	    if (keys.length === 0) {
	        return true;
	    }

	    // this method can be called recursively, so we need to remember our root
	    var isRoot = false;
	    if (!report.rootSchema) {
	        report.rootSchema = schema;
	        isRoot = true;
	    }

	    // follow schema.$ref keys
	    if (schema.$ref !== undefined) {
	        // avoid infinite loop with maxRefs
	        var maxRefs = 99;
	        while (schema.$ref && maxRefs > 0) {
	            if (!schema.__$refResolved) {
	                report.addError("REF_UNRESOLVED", [schema.$ref], null, schema.description);
	                break;
	            } else if (schema.__$refResolved === schema) {
	                break;
	            } else {
	                schema = schema.__$refResolved;
	                keys = Object.keys(schema);
	            }
	            maxRefs--;
	        }
	        if (maxRefs === 0) {
	            throw new Error("Circular dependency by $ref references!");
	        }
	    }

	    // type checking first
	    // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.5.2.2
	    var jsonType = Utils.whatIs(json);
	    if (schema.type) {
	        if (typeof schema.type === "string") {
	            if (jsonType !== schema.type && (jsonType !== "integer" || schema.type !== "number")) {
	                report.addError("INVALID_TYPE", [schema.type, jsonType], null, schema.description);
	                if (this.options.breakOnFirstError) {
	                    return false;
	                }
	            }
	        } else {
	            if (schema.type.indexOf(jsonType) === -1 && (jsonType !== "integer" || schema.type.indexOf("number") === -1)) {
	                report.addError("INVALID_TYPE", [schema.type, jsonType], null, schema.description);
	                if (this.options.breakOnFirstError) {
	                    return false;
	                }
	            }
	        }
	    }

	    // now iterate all the keys in schema and execute validation methods
	    var idx = keys.length;
	    while (idx--) {
	        if (JsonValidators[keys[idx]]) {
	            JsonValidators[keys[idx]].call(this, report, schema, json);
	            if (report.errors.length && this.options.breakOnFirstError) { break; }
	        }
	    }

	    if (report.errors.length === 0 || this.options.breakOnFirstError === false) {
	        if (jsonType === "array") {
	            recurseArray.call(this, report, schema, json);
	        } else if (jsonType === "object") {
	            recurseObject.call(this, report, schema, json);
	        }
	    }

	    if (typeof this.options.customValidator === "function") {
	        this.options.customValidator(report, schema, json);
	    }

	    // we don't need the root pointer anymore
	    if (isRoot) {
	        report.rootSchema = undefined;
	    }

	    // return valid just to be able to break at some code points
	    return report.errors.length === 0;

	};


/***/ },
/* 211 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";

	var Report              = __webpack_require__(208);
	var SchemaCompilation   = __webpack_require__(212);
	var SchemaValidation    = __webpack_require__(213);
	var Utils               = __webpack_require__(214);

	function decodeJSONPointer(str) {
	    // http://tools.ietf.org/html/draft-ietf-appsawg-json-pointer-07#section-3
	    return decodeURIComponent(str).replace(/~[0-1]/g, function (x) {
	        return x === "~1" ? "/" : "~";
	    });
	}

	function getRemotePath(uri) {
	    var io = uri.indexOf("#");
	    return io === -1 ? uri : uri.slice(0, io);
	}

	function getQueryPath(uri) {
	    var io = uri.indexOf("#");
	    var res = io === -1 ? undefined : uri.slice(io + 1);
	    // WARN: do not slice slash, #/ means take root and go down from it
	    // if (res && res[0] === "/") { res = res.slice(1); }
	    return res;
	}

	function findId(schema, id) {
	    // process only arrays and objects
	    if (typeof schema !== "object" || schema === null) {
	        return;
	    }

	    // no id means root so return itself
	    if (!id) {
	        return schema;
	    }

	    if (schema.id) {
	        if (schema.id === id || schema.id[0] === "#" && schema.id.substring(1) === id) {
	            return schema;
	        }
	    }

	    var idx, result;
	    if (Array.isArray(schema)) {
	        idx = schema.length;
	        while (idx--) {
	            result = findId(schema[idx], id);
	            if (result) { return result; }
	        }
	    } else {
	        var keys = Object.keys(schema);
	        idx = keys.length;
	        while (idx--) {
	            var k = keys[idx];
	            if (k.indexOf("__$") === 0) {
	                continue;
	            }
	            result = findId(schema[k], id);
	            if (result) { return result; }
	        }
	    }
	}

	exports.cacheSchemaByUri = function (uri, schema) {
	    var remotePath = getRemotePath(uri);
	    if (remotePath) {
	        this.cache[remotePath] = schema;
	    }
	};

	exports.removeFromCacheByUri = function (uri) {
	    var remotePath = getRemotePath(uri);
	    if (remotePath) {
	        delete this.cache[remotePath];
	    }
	};

	exports.checkCacheForUri = function (uri) {
	    var remotePath = getRemotePath(uri);
	    return remotePath ? this.cache[remotePath] != null : false;
	};

	exports.getSchema = function (report, schema) {
	    if (typeof schema === "object") {
	        schema = exports.getSchemaByReference.call(this, report, schema);
	    }
	    if (typeof schema === "string") {
	        schema = exports.getSchemaByUri.call(this, report, schema);
	    }
	    return schema;
	};

	exports.getSchemaByReference = function (report, key) {
	    var i = this.referenceCache.length;
	    while (i--) {
	        if (this.referenceCache[i][0] === key) {
	            return this.referenceCache[i][1];
	        }
	    }
	    // not found
	    var schema = Utils.cloneDeep(key);
	    this.referenceCache.push([key, schema]);
	    return schema;
	};

	exports.getSchemaByUri = function (report, uri, root) {
	    var remotePath = getRemotePath(uri),
	        queryPath = getQueryPath(uri),
	        result = remotePath ? this.cache[remotePath] : root;

	    if (result && remotePath) {
	        // we need to avoid compiling schemas in a recursive loop
	        var compileRemote = result !== root;
	        // now we need to compile and validate resolved schema (in case it's not already)
	        if (compileRemote) {

	            report.path.push(remotePath);

	            var remoteReport = new Report(report);
	            if (SchemaCompilation.compileSchema.call(this, remoteReport, result)) {
	                SchemaValidation.validateSchema.call(this, remoteReport, result);
	            }
	            var remoteReportIsValid = remoteReport.isValid();
	            if (!remoteReportIsValid) {
	                report.addError("REMOTE_NOT_VALID", [uri], remoteReport);
	            }

	            report.path.pop();

	            if (!remoteReportIsValid) {
	                return undefined;
	            }
	        }
	    }

	    if (result && queryPath) {
	        var parts = queryPath.split("/");
	        for (var idx = 0, lim = parts.length; result && idx < lim; idx++) {
	            var key = decodeJSONPointer(parts[idx]);
	            if (idx === 0) { // it's an id
	                result = findId(result, key);
	            } else { // it's a path behind id
	                result = result[key];
	            }
	        }
	    }

	    return result;
	};

	exports.getRemotePath = getRemotePath;


/***/ },
/* 212 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";

	var Report      = __webpack_require__(208);
	var SchemaCache = __webpack_require__(211);
	var Utils       = __webpack_require__(214);

	function mergeReference(scope, ref) {
	    if (Utils.isAbsoluteUri(ref)) {
	        return ref;
	    }

	    var joinedScope = scope.join(""),
	        isScopeAbsolute = Utils.isAbsoluteUri(joinedScope),
	        isScopeRelative = Utils.isRelativeUri(joinedScope),
	        isRefRelative = Utils.isRelativeUri(ref),
	        toRemove;

	    if (isScopeAbsolute && isRefRelative) {
	        toRemove = joinedScope.match(/\/[^\/]*$/);
	        if (toRemove) {
	            joinedScope = joinedScope.slice(0, toRemove.index + 1);
	        }
	    } else if (isScopeRelative && isRefRelative) {
	        joinedScope = "";
	    } else {
	        toRemove = joinedScope.match(/[^#/]+$/);
	        if (toRemove) {
	            joinedScope = joinedScope.slice(0, toRemove.index);
	        }
	    }

	    var res = joinedScope + ref;
	    res = res.replace(/##/, "#");
	    return res;
	}

	function collectReferences(obj, results, scope, path) {
	    results = results || [];
	    scope = scope || [];
	    path = path || [];

	    if (typeof obj !== "object" || obj === null) {
	        return results;
	    }

	    if (typeof obj.id === "string") {
	        scope.push(obj.id);
	    }

	    if (typeof obj.$ref === "string" && typeof obj.__$refResolved === "undefined") {
	        results.push({
	            ref: mergeReference(scope, obj.$ref),
	            key: "$ref",
	            obj: obj,
	            path: path.slice(0)
	        });
	    }
	    if (typeof obj.$schema === "string" && typeof obj.__$schemaResolved === "undefined") {
	        results.push({
	            ref: mergeReference(scope, obj.$schema),
	            key: "$schema",
	            obj: obj,
	            path: path.slice(0)
	        });
	    }

	    var idx;
	    if (Array.isArray(obj)) {
	        idx = obj.length;
	        while (idx--) {
	            path.push(idx.toString());
	            collectReferences(obj[idx], results, scope, path);
	            path.pop();
	        }
	    } else {
	        var keys = Object.keys(obj);
	        idx = keys.length;
	        while (idx--) {
	            // do not recurse through resolved references and other z-schema props
	            if (keys[idx].indexOf("__$") === 0) { continue; }
	            path.push(keys[idx]);
	            collectReferences(obj[keys[idx]], results, scope, path);
	            path.pop();
	        }
	    }

	    if (typeof obj.id === "string") {
	        scope.pop();
	    }

	    return results;
	}

	var compileArrayOfSchemasLoop = function (mainReport, arr) {
	    var idx = arr.length,
	        compiledCount = 0;

	    while (idx--) {

	        // try to compile each schema separately
	        var report = new Report(mainReport);
	        var isValid = exports.compileSchema.call(this, report, arr[idx]);
	        if (isValid) { compiledCount++; }

	        // copy errors to report
	        mainReport.errors = mainReport.errors.concat(report.errors);

	    }

	    return compiledCount;
	};

	function findId(arr, id) {
	    var idx = arr.length;
	    while (idx--) {
	        if (arr[idx].id === id) {
	            return arr[idx];
	        }
	    }
	    return null;
	}

	var compileArrayOfSchemas = function (report, arr) {

	    var compiled = 0,
	        lastLoopCompiled;

	    do {

	        // remove all UNRESOLVABLE_REFERENCE errors before compiling array again
	        var idx = report.errors.length;
	        while (idx--) {
	            if (report.errors[idx].code === "UNRESOLVABLE_REFERENCE") {
	                report.errors.splice(idx, 1);
	            }
	        }

	        // remember how many were compiled in the last loop
	        lastLoopCompiled = compiled;

	        // count how many are compiled now
	        compiled = compileArrayOfSchemasLoop.call(this, report, arr);

	        // fix __$missingReferences if possible
	        idx = arr.length;
	        while (idx--) {
	            var sch = arr[idx];
	            if (sch.__$missingReferences) {
	                var idx2 = sch.__$missingReferences.length;
	                while (idx2--) {
	                    var refObj = sch.__$missingReferences[idx2];
	                    var response = findId(arr, refObj.ref);
	                    if (response) {
	                        // this might create circular references
	                        refObj.obj["__" + refObj.key + "Resolved"] = response;
	                        // it's resolved now so delete it
	                        sch.__$missingReferences.splice(idx2, 1);
	                    }
	                }
	                if (sch.__$missingReferences.length === 0) {
	                    delete sch.__$missingReferences;
	                }
	            }
	        }

	        // keep repeating if not all compiled and at least one more was compiled in the last loop
	    } while (compiled !== arr.length && compiled !== lastLoopCompiled);

	    return report.isValid();

	};

	exports.compileSchema = function (report, schema) {

	    report.commonErrorMessage = "SCHEMA_COMPILATION_FAILED";

	    // if schema is a string, assume it's a uri
	    if (typeof schema === "string") {
	        var loadedSchema = SchemaCache.getSchemaByUri.call(this, report, schema);
	        if (!loadedSchema) {
	            report.addError("SCHEMA_NOT_REACHABLE", [schema]);
	            return false;
	        }
	        schema = loadedSchema;
	    }

	    // if schema is an array, assume it's an array of schemas
	    if (Array.isArray(schema)) {
	        return compileArrayOfSchemas.call(this, report, schema);
	    }

	    // if we have an id than it should be cached already (if this instance has compiled it)
	    if (schema.__$compiled && schema.id && SchemaCache.checkCacheForUri.call(this, schema.id) === false) {
	        schema.__$compiled = undefined;
	    }

	    // do not re-compile schemas
	    if (schema.__$compiled) {
	        return true;
	    }

	    if (schema.id && typeof schema.id === "string") {
	        // add this to our schemaCache (before compilation in case we have references including id)
	        SchemaCache.cacheSchemaByUri.call(this, schema.id, schema);
	    }

	    // this method can be called recursively, so we need to remember our root
	    var isRoot = false;
	    if (!report.rootSchema) {
	        report.rootSchema = schema;
	        isRoot = true;
	    }

	    // delete all __$missingReferences from previous compilation attempts
	    var isValidExceptReferences = report.isValid();
	    delete schema.__$missingReferences;

	    // collect all references that need to be resolved - $ref and $schema
	    var refs = collectReferences.call(this, schema),
	        idx = refs.length;
	    while (idx--) {
	        // resolve all the collected references into __xxxResolved pointer
	        var refObj = refs[idx];
	        var response = SchemaCache.getSchemaByUri.call(this, report, refObj.ref, schema);

	        // we can try to use custom schemaReader if available
	        if (!response) {
	            var schemaReader = this.getSchemaReader();
	            if (schemaReader) {
	                // it's supposed to return a valid schema
	                var s = schemaReader(refObj.ref);
	                if (s) {
	                    // it needs to have the id
	                    s.id = refObj.ref;
	                    // try to compile the schema
	                    var subreport = new Report(report);
	                    if (!exports.compileSchema.call(this, subreport, s)) {
	                        // copy errors to report
	                        report.errors = report.errors.concat(subreport.errors);
	                    } else {
	                        response = SchemaCache.getSchemaByUri.call(this, report, refObj.ref, schema);
	                    }
	                }
	            }
	        }

	        if (!response) {

	            var hasNotValid = report.hasError("REMOTE_NOT_VALID", [refObj.ref]);
	            var isAbsolute = Utils.isAbsoluteUri(refObj.ref);
	            var isDownloaded = false;
	            var ignoreUnresolvableRemotes = this.options.ignoreUnresolvableReferences === true;

	            if (isAbsolute) {
	                // we shouldn't add UNRESOLVABLE_REFERENCE for schemas we already have downloaded
	                // and set through setRemoteReference method
	                isDownloaded = SchemaCache.checkCacheForUri.call(this, refObj.ref);
	            }

	            if (hasNotValid) {
	                // already has REMOTE_NOT_VALID error for this one
	            } else if (ignoreUnresolvableRemotes && isAbsolute) {
	                // ignoreUnresolvableRemotes is on and remote isAbsolute
	            } else if (isDownloaded) {
	                // remote is downloaded, so no UNRESOLVABLE_REFERENCE
	            } else {
	                Array.prototype.push.apply(report.path, refObj.path);
	                report.addError("UNRESOLVABLE_REFERENCE", [refObj.ref]);
	                report.path = report.path.slice(0, -refObj.path.length);

	                // pusblish unresolved references out
	                if (isValidExceptReferences) {
	                    schema.__$missingReferences = schema.__$missingReferences || [];
	                    schema.__$missingReferences.push(refObj);
	                }
	            }
	        }
	        // this might create circular references
	        refObj.obj["__" + refObj.key + "Resolved"] = response;
	    }

	    var isValid = report.isValid();
	    if (isValid) {
	        schema.__$compiled = true;
	    } else {
	        if (schema.id && typeof schema.id === "string") {
	            // remove this schema from schemaCache because it failed to compile
	            SchemaCache.removeFromCacheByUri.call(this, schema.id);
	        }
	    }

	    // we don't need the root pointer anymore
	    if (isRoot) {
	        report.rootSchema = undefined;
	    }

	    return isValid;

	};


/***/ },
/* 213 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";

	var FormatValidators = __webpack_require__(209),
	    JsonValidation   = __webpack_require__(210),
	    Report           = __webpack_require__(208),
	    Utils            = __webpack_require__(214);

	var SchemaValidators = {
	    $ref: function (report, schema) {
	        // http://tools.ietf.org/html/draft-ietf-appsawg-json-pointer-07
	        // http://tools.ietf.org/html/draft-pbryan-zyp-json-ref-03
	        if (typeof schema.$ref !== "string") {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["$ref", "string"]);
	        }
	    },
	    $schema: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-core.html#rfc.section.6
	        if (typeof schema.$schema !== "string") {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["$schema", "string"]);
	        }
	    },
	    multipleOf: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.1.1.1
	        if (typeof schema.multipleOf !== "number") {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["multipleOf", "number"]);
	        } else if (schema.multipleOf <= 0) {
	            report.addError("KEYWORD_MUST_BE", ["multipleOf", "strictly greater than 0"]);
	        }
	    },
	    maximum: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.1.2.1
	        if (typeof schema.maximum !== "number") {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["maximum", "number"]);
	        }
	    },
	    exclusiveMaximum: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.1.2.1
	        if (typeof schema.exclusiveMaximum !== "boolean") {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["exclusiveMaximum", "boolean"]);
	        } else if (schema.maximum === undefined) {
	            report.addError("KEYWORD_DEPENDENCY", ["exclusiveMaximum", "maximum"]);
	        }
	    },
	    minimum: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.1.3.1
	        if (typeof schema.minimum !== "number") {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["minimum", "number"]);
	        }
	    },
	    exclusiveMinimum: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.1.3.1
	        if (typeof schema.exclusiveMinimum !== "boolean") {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["exclusiveMinimum", "boolean"]);
	        } else if (schema.minimum === undefined) {
	            report.addError("KEYWORD_DEPENDENCY", ["exclusiveMinimum", "minimum"]);
	        }
	    },
	    maxLength: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.2.1.1
	        if (Utils.whatIs(schema.maxLength) !== "integer") {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["maxLength", "integer"]);
	        } else if (schema.maxLength < 0) {
	            report.addError("KEYWORD_MUST_BE", ["maxLength", "greater than, or equal to 0"]);
	        }
	    },
	    minLength: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.2.2.1
	        if (Utils.whatIs(schema.minLength) !== "integer") {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["minLength", "integer"]);
	        } else if (schema.minLength < 0) {
	            report.addError("KEYWORD_MUST_BE", ["minLength", "greater than, or equal to 0"]);
	        }
	    },
	    pattern: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.2.3.1
	        if (typeof schema.pattern !== "string") {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["pattern", "string"]);
	        } else {
	            try {
	                RegExp(schema.pattern);
	            } catch (e) {
	                report.addError("KEYWORD_PATTERN", ["pattern", schema.pattern]);
	            }
	        }
	    },
	    additionalItems: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.3.1.1
	        var type = Utils.whatIs(schema.additionalItems);
	        if (type !== "boolean" && type !== "object") {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["additionalItems", ["boolean", "object"]]);
	        } else if (type === "object") {
	            report.path.push("additionalItems");
	            exports.validateSchema.call(this, report, schema.additionalItems);
	            report.path.pop();
	        }
	    },
	    items: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.3.1.1
	        var type = Utils.whatIs(schema.items);

	        if (type === "object") {
	            report.path.push("items");
	            exports.validateSchema.call(this, report, schema.items);
	            report.path.pop();
	        } else if (type === "array") {
	            var idx = schema.items.length;
	            while (idx--) {
	                report.path.push("items");
	                report.path.push(idx.toString());
	                exports.validateSchema.call(this, report, schema.items[idx]);
	                report.path.pop();
	                report.path.pop();
	            }
	        } else {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["items", ["array", "object"]]);
	        }

	        // custom - strict mode
	        if (this.options.forceAdditional === true && schema.additionalItems === undefined && Array.isArray(schema.items)) {
	            report.addError("KEYWORD_UNDEFINED_STRICT", ["additionalItems"]);
	        }
	        // custome - assume defined false mode
	        if (this.options.assumeAdditional && schema.additionalItems === undefined && Array.isArray(schema.items)) {
	            schema.additionalItems = false;
	        }
	    },
	    maxItems: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.3.2.1
	        if (typeof schema.maxItems !== "number") {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["maxItems", "integer"]);
	        } else if (schema.maxItems < 0) {
	            report.addError("KEYWORD_MUST_BE", ["maxItems", "greater than, or equal to 0"]);
	        }
	    },
	    minItems: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.3.3.1
	        if (Utils.whatIs(schema.minItems) !== "integer") {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["minItems", "integer"]);
	        } else if (schema.minItems < 0) {
	            report.addError("KEYWORD_MUST_BE", ["minItems", "greater than, or equal to 0"]);
	        }
	    },
	    uniqueItems: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.3.4.1
	        if (typeof schema.uniqueItems !== "boolean") {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["uniqueItems", "boolean"]);
	        }
	    },
	    maxProperties: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.4.1.1
	        if (Utils.whatIs(schema.maxProperties) !== "integer") {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["maxProperties", "integer"]);
	        } else if (schema.maxProperties < 0) {
	            report.addError("KEYWORD_MUST_BE", ["maxProperties", "greater than, or equal to 0"]);
	        }
	    },
	    minProperties: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.4.2.1
	        if (Utils.whatIs(schema.minProperties) !== "integer") {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["minProperties", "integer"]);
	        } else if (schema.minProperties < 0) {
	            report.addError("KEYWORD_MUST_BE", ["minProperties", "greater than, or equal to 0"]);
	        }
	    },
	    required: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.4.3.1
	        if (Utils.whatIs(schema.required) !== "array") {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["required", "array"]);
	        } else if (schema.required.length === 0) {
	            report.addError("KEYWORD_MUST_BE", ["required", "an array with at least one element"]);
	        } else {
	            var idx = schema.required.length;
	            while (idx--) {
	                if (typeof schema.required[idx] !== "string") {
	                    report.addError("KEYWORD_VALUE_TYPE", ["required", "string"]);
	                }
	            }
	            if (Utils.isUniqueArray(schema.required) === false) {
	                report.addError("KEYWORD_MUST_BE", ["required", "an array with unique items"]);
	            }
	        }
	    },
	    additionalProperties: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.4.4.1
	        var type = Utils.whatIs(schema.additionalProperties);
	        if (type !== "boolean" && type !== "object") {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["additionalProperties", ["boolean", "object"]]);
	        } else if (type === "object") {
	            report.path.push("additionalProperties");
	            exports.validateSchema.call(this, report, schema.additionalProperties);
	            report.path.pop();
	        }
	    },
	    properties: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.4.4.1
	        if (Utils.whatIs(schema.properties) !== "object") {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["properties", "object"]);
	            return;
	        }

	        var keys = Object.keys(schema.properties),
	            idx = keys.length;
	        while (idx--) {
	            var key = keys[idx],
	                val = schema.properties[key];
	            report.path.push("properties");
	            report.path.push(key);
	            exports.validateSchema.call(this, report, val);
	            report.path.pop();
	            report.path.pop();
	        }

	        // custom - strict mode
	        if (this.options.forceAdditional === true && schema.additionalProperties === undefined) {
	            report.addError("KEYWORD_UNDEFINED_STRICT", ["additionalProperties"]);
	        }
	        // custome - assume defined false mode
	        if (this.options.assumeAdditional && schema.additionalProperties === undefined) {
	            schema.additionalProperties = false;
	        }
	        // custom - forceProperties
	        if (this.options.forceProperties === true && keys.length === 0) {
	            report.addError("CUSTOM_MODE_FORCE_PROPERTIES", ["properties"]);
	        }
	    },
	    patternProperties: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.4.4.1
	        if (Utils.whatIs(schema.patternProperties) !== "object") {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["patternProperties", "object"]);
	            return;
	        }

	        var keys = Object.keys(schema.patternProperties),
	            idx = keys.length;
	        while (idx--) {
	            var key = keys[idx],
	                val = schema.patternProperties[key];
	            try {
	                RegExp(key);
	            } catch (e) {
	                report.addError("KEYWORD_PATTERN", ["patternProperties", key]);
	            }
	            report.path.push("patternProperties");
	            report.path.push(key.toString());
	            exports.validateSchema.call(this, report, val);
	            report.path.pop();
	            report.path.pop();
	        }

	        // custom - forceProperties
	        if (this.options.forceProperties === true && keys.length === 0) {
	            report.addError("CUSTOM_MODE_FORCE_PROPERTIES", ["patternProperties"]);
	        }
	    },
	    dependencies: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.4.5.1
	        if (Utils.whatIs(schema.dependencies) !== "object") {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["dependencies", "object"]);
	        } else {
	            var keys = Object.keys(schema.dependencies),
	                idx = keys.length;
	            while (idx--) {
	                var schemaKey = keys[idx],
	                    schemaDependency = schema.dependencies[schemaKey],
	                    type = Utils.whatIs(schemaDependency);

	                if (type === "object") {
	                    report.path.push("dependencies");
	                    report.path.push(schemaKey);
	                    exports.validateSchema.call(this, report, schemaDependency);
	                    report.path.pop();
	                    report.path.pop();
	                } else if (type === "array") {
	                    var idx2 = schemaDependency.length;
	                    if (idx2 === 0) {
	                        report.addError("KEYWORD_MUST_BE", ["dependencies", "not empty array"]);
	                    }
	                    while (idx2--) {
	                        if (typeof schemaDependency[idx2] !== "string") {
	                            report.addError("KEYWORD_VALUE_TYPE", ["dependensices", "string"]);
	                        }
	                    }
	                    if (Utils.isUniqueArray(schemaDependency) === false) {
	                        report.addError("KEYWORD_MUST_BE", ["dependencies", "an array with unique items"]);
	                    }
	                } else {
	                    report.addError("KEYWORD_VALUE_TYPE", ["dependencies", "object or array"]);
	                }
	            }
	        }
	    },
	    enum: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.5.1.1
	        if (Array.isArray(schema.enum) === false) {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["enum", "array"]);
	        } else if (schema.enum.length === 0) {
	            report.addError("KEYWORD_MUST_BE", ["enum", "an array with at least one element"]);
	        } else if (Utils.isUniqueArray(schema.enum) === false) {
	            report.addError("KEYWORD_MUST_BE", ["enum", "an array with unique elements"]);
	        }
	    },
	    type: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.5.2.1
	        var primitiveTypes = ["array", "boolean", "integer", "number", "null", "object", "string"],
	            primitiveTypeStr = primitiveTypes.join(","),
	            isArray = Array.isArray(schema.type);

	        if (isArray) {
	            var idx = schema.type.length;
	            while (idx--) {
	                if (primitiveTypes.indexOf(schema.type[idx]) === -1) {
	                    report.addError("KEYWORD_TYPE_EXPECTED", ["type", primitiveTypeStr]);
	                }
	            }
	            if (Utils.isUniqueArray(schema.type) === false) {
	                report.addError("KEYWORD_MUST_BE", ["type", "an object with unique properties"]);
	            }
	        } else if (typeof schema.type === "string") {
	            if (primitiveTypes.indexOf(schema.type) === -1) {
	                report.addError("KEYWORD_TYPE_EXPECTED", ["type", primitiveTypeStr]);
	            }
	        } else {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["type", ["string", "array"]]);
	        }

	        if (this.options.noEmptyStrings === true) {
	            if (schema.type === "string" || isArray && schema.type.indexOf("string") !== -1) {
	                if (schema.minLength === undefined &&
	                    schema.enum === undefined &&
	                    schema.format === undefined) {

	                    schema.minLength = 1;
	                }
	            }
	        }
	        if (this.options.noEmptyArrays === true) {
	            if (schema.type === "array" || isArray && schema.type.indexOf("array") !== -1) {
	                if (schema.minItems === undefined) {
	                    schema.minItems = 1;
	                }
	            }
	        }
	        if (this.options.forceProperties === true) {
	            if (schema.type === "object" || isArray && schema.type.indexOf("object") !== -1) {
	                if (schema.properties === undefined && schema.patternProperties === undefined) {
	                    report.addError("KEYWORD_UNDEFINED_STRICT", ["properties"]);
	                }
	            }
	        }
	        if (this.options.forceItems === true) {
	            if (schema.type === "array" || isArray && schema.type.indexOf("array") !== -1) {
	                if (schema.items === undefined) {
	                    report.addError("KEYWORD_UNDEFINED_STRICT", ["items"]);
	                }
	            }
	        }
	        if (this.options.forceMinItems === true) {
	            if (schema.type === "array" || isArray && schema.type.indexOf("array") !== -1) {
	                if (schema.minItems === undefined) {
	                    report.addError("KEYWORD_UNDEFINED_STRICT", ["minItems"]);
	                }
	            }
	        }
	        if (this.options.forceMaxItems === true) {
	            if (schema.type === "array" || isArray && schema.type.indexOf("array") !== -1) {
	                if (schema.maxItems === undefined) {
	                    report.addError("KEYWORD_UNDEFINED_STRICT", ["maxItems"]);
	                }
	            }
	        }
	        if (this.options.forceMinLength === true) {
	            if (schema.type === "string" || isArray && schema.type.indexOf("string") !== -1) {
	                if (schema.minLength === undefined &&
	                    schema.format === undefined &&
	                    schema.enum === undefined &&
	                    schema.pattern === undefined) {
	                    report.addError("KEYWORD_UNDEFINED_STRICT", ["minLength"]);
	                }
	            }
	        }
	        if (this.options.forceMaxLength === true) {
	            if (schema.type === "string" || isArray && schema.type.indexOf("string") !== -1) {
	                if (schema.maxLength === undefined &&
	                    schema.format === undefined &&
	                    schema.enum === undefined &&
	                    schema.pattern === undefined) {
	                    report.addError("KEYWORD_UNDEFINED_STRICT", ["maxLength"]);
	                }
	            }
	        }
	    },
	    allOf: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.5.3.1
	        if (Array.isArray(schema.allOf) === false) {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["allOf", "array"]);
	        } else if (schema.allOf.length === 0) {
	            report.addError("KEYWORD_MUST_BE", ["allOf", "an array with at least one element"]);
	        } else {
	            var idx = schema.allOf.length;
	            while (idx--) {
	                report.path.push("allOf");
	                report.path.push(idx.toString());
	                exports.validateSchema.call(this, report, schema.allOf[idx]);
	                report.path.pop();
	                report.path.pop();
	            }
	        }
	    },
	    anyOf: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.5.4.1
	        if (Array.isArray(schema.anyOf) === false) {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["anyOf", "array"]);
	        } else if (schema.anyOf.length === 0) {
	            report.addError("KEYWORD_MUST_BE", ["anyOf", "an array with at least one element"]);
	        } else {
	            var idx = schema.anyOf.length;
	            while (idx--) {
	                report.path.push("anyOf");
	                report.path.push(idx.toString());
	                exports.validateSchema.call(this, report, schema.anyOf[idx]);
	                report.path.pop();
	                report.path.pop();
	            }
	        }
	    },
	    oneOf: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.5.5.1
	        if (Array.isArray(schema.oneOf) === false) {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["oneOf", "array"]);
	        } else if (schema.oneOf.length === 0) {
	            report.addError("KEYWORD_MUST_BE", ["oneOf", "an array with at least one element"]);
	        } else {
	            var idx = schema.oneOf.length;
	            while (idx--) {
	                report.path.push("oneOf");
	                report.path.push(idx.toString());
	                exports.validateSchema.call(this, report, schema.oneOf[idx]);
	                report.path.pop();
	                report.path.pop();
	            }
	        }
	    },
	    not: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.5.6.1
	        if (Utils.whatIs(schema.not) !== "object") {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["not", "object"]);
	        } else {
	            report.path.push("not");
	            exports.validateSchema.call(this, report, schema.not);
	            report.path.pop();
	        }
	    },
	    definitions: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.5.5.7.1
	        if (Utils.whatIs(schema.definitions) !== "object") {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["definitions", "object"]);
	        } else {
	            var keys = Object.keys(schema.definitions),
	                idx = keys.length;
	            while (idx--) {
	                var key = keys[idx],
	                    val = schema.definitions[key];
	                report.path.push("definitions");
	                report.path.push(key);
	                exports.validateSchema.call(this, report, val);
	                report.path.pop();
	                report.path.pop();
	            }
	        }
	    },
	    format: function (report, schema) {
	        if (typeof schema.format !== "string") {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["format", "string"]);
	        } else {
	            if (FormatValidators[schema.format] === undefined && this.options.ignoreUnknownFormats !== true) {
	                report.addError("UNKNOWN_FORMAT", [schema.format]);
	            }
	        }
	    },
	    id: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-core.html#rfc.section.7.2
	        if (typeof schema.id !== "string") {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["id", "string"]);
	        }
	    },
	    title: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.6.1
	        if (typeof schema.title !== "string") {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["title", "string"]);
	        }
	    },
	    description: function (report, schema) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.6.1
	        if (typeof schema.description !== "string") {
	            report.addError("KEYWORD_TYPE_EXPECTED", ["description", "string"]);
	        }
	    },
	    "default": function (/* report, schema */) {
	        // http://json-schema.org/latest/json-schema-validation.html#rfc.section.6.2
	        // There are no restrictions placed on the value of this keyword.
	    }
	};

	var validateArrayOfSchemas = function (report, arr) {
	    var idx = arr.length;
	    while (idx--) {
	        exports.validateSchema.call(this, report, arr[idx]);
	    }
	    return report.isValid();
	};

	exports.validateSchema = function (report, schema) {

	    report.commonErrorMessage = "SCHEMA_VALIDATION_FAILED";

	    // if schema is an array, assume it's an array of schemas
	    if (Array.isArray(schema)) {
	        return validateArrayOfSchemas.call(this, report, schema);
	    }

	    // do not revalidate schema that has already been validated once
	    if (schema.__$validated) {
	        return true;
	    }

	    // if $schema is present, this schema should validate against that $schema
	    var hasParentSchema = schema.$schema && schema.id !== schema.$schema;
	    if (hasParentSchema) {
	        if (schema.__$schemaResolved && schema.__$schemaResolved !== schema) {
	            var subReport = new Report(report);
	            var valid = JsonValidation.validate.call(this, subReport, schema.__$schemaResolved, schema);
	            if (valid === false) {
	                report.addError("PARENT_SCHEMA_VALIDATION_FAILED", null, subReport);
	            }
	        } else {
	            if (this.options.ignoreUnresolvableReferences !== true) {
	                report.addError("REF_UNRESOLVED", [schema.$schema]);
	            }
	        }
	    }

	    if (this.options.noTypeless === true) {
	        // issue #36 - inherit type to anyOf, oneOf, allOf if noTypeless is defined
	        if (schema.type !== undefined) {
	            var schemas = [];
	            if (Array.isArray(schema.anyOf)) { schemas = schemas.concat(schema.anyOf); }
	            if (Array.isArray(schema.oneOf)) { schemas = schemas.concat(schema.oneOf); }
	            if (Array.isArray(schema.allOf)) { schemas = schemas.concat(schema.allOf); }
	            schemas.forEach(function (sch) {
	                if (!sch.type) { sch.type = schema.type; }
	            });
	        }
	        // end issue #36
	        if (schema.enum === undefined &&
	            schema.type === undefined &&
	            schema.anyOf === undefined &&
	            schema.oneOf === undefined &&
	            schema.not === undefined &&
	            schema.$ref === undefined) {
	            report.addError("KEYWORD_UNDEFINED_STRICT", ["type"]);
	        }
	    }

	    var keys = Object.keys(schema),
	        idx = keys.length;
	    while (idx--) {
	        var key = keys[idx];
	        if (key.indexOf("__") === 0) { continue; }
	        if (SchemaValidators[key] !== undefined) {
	            SchemaValidators[key].call(this, report, schema);
	        } else if (!hasParentSchema) {
	            if (this.options.noExtraKeywords === true) {
	                report.addError("KEYWORD_UNEXPECTED", [key]);
	            }
	        }
	    }

	    if (this.options.pedanticCheck === true) {
	        if (schema.enum) {
	            // break recursion
	            var tmpSchema = Utils.clone(schema);
	            delete tmpSchema.enum;
	            delete tmpSchema.default;

	            report.path.push("enum");
	            idx = schema.enum.length;
	            while (idx--) {
	                report.path.push(idx.toString());
	                JsonValidation.validate.call(this, report, tmpSchema, schema.enum[idx]);
	                report.path.pop();
	            }
	            report.path.pop();
	        }

	        if (schema.default) {
	            report.path.push("default");
	            JsonValidation.validate.call(this, report, schema, schema.default);
	            report.path.pop();
	        }
	    }

	    var isValid = report.isValid();
	    if (isValid) {
	        schema.__$validated = true;
	    }
	    return isValid;
	};


/***/ },
/* 214 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";

	exports.isAbsoluteUri = function (uri) {
	    return /^https?:\/\//.test(uri);
	};

	exports.isRelativeUri = function (uri) {
	    // relative URIs that end with a hash sign, issue #56
	    return /.+#/.test(uri);
	};

	exports.whatIs = function (what) {

	    var to = typeof what;

	    if (to === "object") {
	        if (what === null) {
	            return "null";
	        }
	        if (Array.isArray(what)) {
	            return "array";
	        }
	        return "object"; // typeof what === 'object' && what === Object(what) && !Array.isArray(what);
	    }

	    if (to === "number") {
	        if (Number.isFinite(what)) {
	            if (what % 1 === 0) {
	                return "integer";
	            } else {
	                return "number";
	            }
	        }
	        if (Number.isNaN(what)) {
	            return "not-a-number";
	        }
	        return "unknown-number";
	    }

	    return to; // undefined, boolean, string, function

	};

	exports.areEqual = function areEqual(json1, json2) {
	    // http://json-schema.org/latest/json-schema-core.html#rfc.section.3.6

	    // Two JSON values are said to be equal if and only if:
	    // both are nulls; or
	    // both are booleans, and have the same value; or
	    // both are strings, and have the same value; or
	    // both are numbers, and have the same mathematical value; or
	    if (json1 === json2) {
	        return true;
	    }

	    var i, len;

	    // both are arrays, and:
	    if (Array.isArray(json1) && Array.isArray(json2)) {
	        // have the same number of items; and
	        if (json1.length !== json2.length) {
	            return false;
	        }
	        // items at the same index are equal according to this definition; or
	        len = json1.length;
	        for (i = 0; i < len; i++) {
	            if (!areEqual(json1[i], json2[i])) {
	                return false;
	            }
	        }
	        return true;
	    }

	    // both are objects, and:
	    if (exports.whatIs(json1) === "object" && exports.whatIs(json2) === "object") {
	        // have the same set of property names; and
	        var keys1 = Object.keys(json1);
	        var keys2 = Object.keys(json2);
	        if (!areEqual(keys1, keys2)) {
	            return false;
	        }
	        // values for a same property name are equal according to this definition.
	        len = keys1.length;
	        for (i = 0; i < len; i++) {
	            if (!areEqual(json1[keys1[i]], json2[keys1[i]])) {
	                return false;
	            }
	        }
	        return true;
	    }

	    return false;
	};

	exports.isUniqueArray = function (arr, indexes) {
	    var i, j, l = arr.length;
	    for (i = 0; i < l; i++) {
	        for (j = i + 1; j < l; j++) {
	            if (exports.areEqual(arr[i], arr[j])) {
	                if (indexes) { indexes.push(i, j); }
	                return false;
	            }
	        }
	    }
	    return true;
	};

	exports.difference = function (bigSet, subSet) {
	    var arr = [],
	        idx = bigSet.length;
	    while (idx--) {
	        if (subSet.indexOf(bigSet[idx]) === -1) {
	            arr.push(bigSet[idx]);
	        }
	    }
	    return arr;
	};

	// NOT a deep version of clone
	exports.clone = function (src) {
	    if (typeof src === "undefined") { return void 0; }
	    if (typeof src !== "object" || src === null) { return src; }
	    var res, idx;
	    if (Array.isArray(src)) {
	        res = [];
	        idx = src.length;
	        while (idx--) {
	            res[idx] = src[idx];
	        }
	    } else {
	        res = {};
	        var keys = Object.keys(src);
	        idx = keys.length;
	        while (idx--) {
	            var key = keys[idx];
	            res[key] = src[key];
	        }
	    }
	    return res;
	};

	exports.cloneDeep = function (src) {
	    var visited = [], cloned = [];
	    function cloneDeep(src) {
	        if (typeof src !== "object" || src === null) { return src; }
	        var res, idx, cidx;

	        cidx = visited.indexOf(src);
	        if (cidx !== -1) { return cloned[cidx]; }

	        visited.push(src);
	        if (Array.isArray(src)) {
	            res = [];
	            cloned.push(res);
	            idx = src.length;
	            while (idx--) {
	                res[idx] = cloneDeep(src[idx]);
	            }
	        } else {
	            res = {};
	            cloned.push(res);
	            var keys = Object.keys(src);
	            idx = keys.length;
	            while (idx--) {
	                var key = keys[idx];
	                res[key] = cloneDeep(src[key]);
	            }
	        }
	        return res;
	    }
	    return cloneDeep(src);
	};

	/*
	  following function comes from punycode.js library
	  see: https://github.com/bestiejs/punycode.js
	*/
	/*jshint -W016*/
	/**
	 * Creates an array containing the numeric code points of each Unicode
	 * character in the string. While JavaScript uses UCS-2 internally,
	 * this function will convert a pair of surrogate halves (each of which
	 * UCS-2 exposes as separate characters) into a single code point,
	 * matching UTF-16.
	 * @see `punycode.ucs2.encode`
	 * @see <https://mathiasbynens.be/notes/javascript-encoding>
	 * @memberOf punycode.ucs2
	 * @name decode
	 * @param {String} string The Unicode input string (UCS-2).
	 * @returns {Array} The new array of code points.
	 */
	exports.ucs2decode = function (string) {
	    var output = [],
	        counter = 0,
	        length = string.length,
	        value,
	        extra;
	    while (counter < length) {
	        value = string.charCodeAt(counter++);
	        if (value >= 0xD800 && value <= 0xDBFF && counter < length) {
	            // high surrogate, and there is a next character
	            extra = string.charCodeAt(counter++);
	            if ((extra & 0xFC00) == 0xDC00) { // low surrogate
	                output.push(((value & 0x3FF) << 10) + (extra & 0x3FF) + 0x10000);
	            } else {
	                // unmatched surrogate; only append this code unit, in case the next
	                // code unit is the high surrogate of a surrogate pair
	                output.push(value);
	                counter--;
	            }
	        } else {
	            output.push(value);
	        }
	    }
	    return output;
	};
	/*jshint +W016*/


/***/ },
/* 215 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(Buffer) {// Copyright Joyent, Inc. and other Node contributors.
	//
	// Permission is hereby granted, free of charge, to any person obtaining a
	// copy of this software and associated documentation files (the
	// "Software"), to deal in the Software without restriction, including
	// without limitation the rights to use, copy, modify, merge, publish,
	// distribute, sublicense, and/or sell copies of the Software, and to permit
	// persons to whom the Software is furnished to do so, subject to the
	// following conditions:
	//
	// The above copyright notice and this permission notice shall be included
	// in all copies or substantial portions of the Software.
	//
	// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
	// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
	// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
	// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
	// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
	// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
	// USE OR OTHER DEALINGS IN THE SOFTWARE.

	// NOTE: These type checking functions intentionally don't use `instanceof`
	// because it is fragile and can be easily faked with `Object.create()`.

	function isArray(arg) {
	  if (Array.isArray) {
	    return Array.isArray(arg);
	  }
	  return objectToString(arg) === '[object Array]';
	}
	exports.isArray = isArray;

	function isBoolean(arg) {
	  return typeof arg === 'boolean';
	}
	exports.isBoolean = isBoolean;

	function isNull(arg) {
	  return arg === null;
	}
	exports.isNull = isNull;

	function isNullOrUndefined(arg) {
	  return arg == null;
	}
	exports.isNullOrUndefined = isNullOrUndefined;

	function isNumber(arg) {
	  return typeof arg === 'number';
	}
	exports.isNumber = isNumber;

	function isString(arg) {
	  return typeof arg === 'string';
	}
	exports.isString = isString;

	function isSymbol(arg) {
	  return typeof arg === 'symbol';
	}
	exports.isSymbol = isSymbol;

	function isUndefined(arg) {
	  return arg === void 0;
	}
	exports.isUndefined = isUndefined;

	function isRegExp(re) {
	  return objectToString(re) === '[object RegExp]';
	}
	exports.isRegExp = isRegExp;

	function isObject(arg) {
	  return typeof arg === 'object' && arg !== null;
	}
	exports.isObject = isObject;

	function isDate(d) {
	  return objectToString(d) === '[object Date]';
	}
	exports.isDate = isDate;

	function isError(e) {
	  return (objectToString(e) === '[object Error]' || e instanceof Error);
	}
	exports.isError = isError;

	function isFunction(arg) {
	  return typeof arg === 'function';
	}
	exports.isFunction = isFunction;

	function isPrimitive(arg) {
	  return arg === null ||
	         typeof arg === 'boolean' ||
	         typeof arg === 'number' ||
	         typeof arg === 'string' ||
	         typeof arg === 'symbol' ||  // ES6 symbol
	         typeof arg === 'undefined';
	}
	exports.isPrimitive = isPrimitive;

	exports.isBuffer = Buffer.isBuffer;

	function objectToString(o) {
	  return Object.prototype.toString.call(o);
	}
	
	/* WEBPACK VAR INJECTION */}.call(exports, __webpack_require__(87).Buffer))

/***/ },
/* 216 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	var hexTable = (function () {
	    var array = new Array(256);
	    for (var i = 0; i < 256; ++i) {
	        array[i] = '%' + ((i < 16 ? '0' : '') + i.toString(16)).toUpperCase();
	    }

	    return array;
	}());

	exports.arrayToObject = function (source, options) {
	    var obj = options.plainObjects ? Object.create(null) : {};
	    for (var i = 0; i < source.length; ++i) {
	        if (typeof source[i] !== 'undefined') {
	            obj[i] = source[i];
	        }
	    }

	    return obj;
	};

	exports.merge = function (target, source, options) {
	    if (!source) {
	        return target;
	    }

	    if (typeof source !== 'object') {
	        if (Array.isArray(target)) {
	            target.push(source);
	        } else if (typeof target === 'object') {
	            target[source] = true;
	        } else {
	            return [target, source];
	        }

	        return target;
	    }

	    if (typeof target !== 'object') {
	        return [target].concat(source);
	    }

	    var mergeTarget = target;
	    if (Array.isArray(target) && !Array.isArray(source)) {
	        mergeTarget = exports.arrayToObject(target, options);
	    }

		return Object.keys(source).reduce(function (acc, key) {
	        var value = source[key];

	        if (Object.prototype.hasOwnProperty.call(acc, key)) {
	            acc[key] = exports.merge(acc[key], value, options);
	        } else {
	            acc[key] = value;
	        }
			return acc;
	    }, mergeTarget);
	};

	exports.decode = function (str) {
	    try {
	        return decodeURIComponent(str.replace(/\+/g, ' '));
	    } catch (e) {
	        return str;
	    }
	};

	exports.encode = function (str) {
	    // This code was originally written by Brian White (mscdex) for the io.js core querystring library.
	    // It has been adapted here for stricter adherence to RFC 3986
	    if (str.length === 0) {
	        return str;
	    }

	    var string = typeof str === 'string' ? str : String(str);

	    var out = '';
	    for (var i = 0; i < string.length; ++i) {
	        var c = string.charCodeAt(i);

	        if (
	            c === 0x2D || // -
	            c === 0x2E || // .
	            c === 0x5F || // _
	            c === 0x7E || // ~
	            (c >= 0x30 && c <= 0x39) || // 0-9
	            (c >= 0x41 && c <= 0x5A) || // a-z
	            (c >= 0x61 && c <= 0x7A) // A-Z
	        ) {
	            out += string.charAt(i);
	            continue;
	        }

	        if (c < 0x80) {
	            out = out + hexTable[c];
	            continue;
	        }

	        if (c < 0x800) {
	            out = out + (hexTable[0xC0 | (c >> 6)] + hexTable[0x80 | (c & 0x3F)]);
	            continue;
	        }

	        if (c < 0xD800 || c >= 0xE000) {
	            out = out + (hexTable[0xE0 | (c >> 12)] + hexTable[0x80 | ((c >> 6) & 0x3F)] + hexTable[0x80 | (c & 0x3F)]);
	            continue;
	        }

	        i += 1;
	        c = 0x10000 + (((c & 0x3FF) << 10) | (string.charCodeAt(i) & 0x3FF));
	        out += (hexTable[0xF0 | (c >> 18)] + hexTable[0x80 | ((c >> 12) & 0x3F)] + hexTable[0x80 | ((c >> 6) & 0x3F)] + hexTable[0x80 | (c & 0x3F)]);
	    }

	    return out;
	};

	exports.compact = function (obj, references) {
	    if (typeof obj !== 'object' || obj === null) {
	        return obj;
	    }

	    var refs = references || [];
	    var lookup = refs.indexOf(obj);
	    if (lookup !== -1) {
	        return refs[lookup];
	    }

	    refs.push(obj);

	    if (Array.isArray(obj)) {
	        var compacted = [];

	        for (var i = 0; i < obj.length; ++i) {
	            if (typeof obj[i] !== 'undefined') {
	                compacted.push(obj[i]);
	            }
	        }

	        return compacted;
	    }

	    var keys = Object.keys(obj);
	    for (var j = 0; j < keys.length; ++j) {
	        var key = keys[j];
	        obj[key] = exports.compact(obj[key], refs);
	    }

	    return obj;
	};

	exports.isRegExp = function (obj) {
	    return Object.prototype.toString.call(obj) === '[object RegExp]';
	};

	exports.isBuffer = function (obj) {
	    if (obj === null || typeof obj === 'undefined') {
	        return false;
	    }

	    return !!(obj.constructor && obj.constructor.isBuffer && obj.constructor.isBuffer(obj));
	};


/***/ },
/* 217 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(process) {exports = module.exports = __webpack_require__(248);
	exports.Stream = __webpack_require__(165);
	exports.Readable = exports;
	exports.Writable = __webpack_require__(249);
	exports.Duplex = __webpack_require__(250);
	exports.Transform = __webpack_require__(251);
	exports.PassThrough = __webpack_require__(252);
	if (!process.browser && process.env.READABLE_STREAM === 'disable') {
	  module.exports = __webpack_require__(165);
	}
	
	/* WEBPACK VAR INJECTION */}.call(exports, __webpack_require__(56)))

/***/ },
/* 218 */
/***/ function(module, exports, __webpack_require__) {

	module.exports = __webpack_require__(249)


/***/ },
/* 219 */
/***/ function(module, exports, __webpack_require__) {

	module.exports = __webpack_require__(250)


/***/ },
/* 220 */
/***/ function(module, exports, __webpack_require__) {

	module.exports = __webpack_require__(251)


/***/ },
/* 221 */
/***/ function(module, exports, __webpack_require__) {

	module.exports = __webpack_require__(252)


/***/ },
/* 222 */
/***/ function(module, exports, __webpack_require__) {

	var map = {
		"./ar": 234,
		"./ar.js": 234,
		"./bn": 235,
		"./bn.js": 235,
		"./de": 236,
		"./de.js": 236,
		"./es": 237,
		"./es.js": 237,
		"./fr": 238,
		"./fr.js": 238,
		"./hi": 239,
		"./hi.js": 239,
		"./it": 240,
		"./it.js": 240,
		"./ja": 241,
		"./ja.js": 241,
		"./ko": 242,
		"./ko.js": 242,
		"./pt": 243,
		"./pt.js": 243,
		"./ru": 244,
		"./ru.js": 244,
		"./zh-cn": 245,
		"./zh-cn.js": 245,
		"./zh-tw": 246,
		"./zh-tw.js": 246
	};
	function webpackContext(req) {
		return __webpack_require__(webpackContextResolve(req));
	};
	function webpackContextResolve(req) {
		return map[req] || (function() { throw new Error("Cannot find module '" + req + "'.") }());
	};
	webpackContext.id = 222;
	webpackContext.keys = function webpackContextKeys() {
		return Object.keys(map);
	};
	webpackContext.resolve = webpackContextResolve;
	module.exports = webpackContext;


/***/ },
/* 223 */
/***/ function(module, exports, __webpack_require__) {

	if (typeof Object.create === 'function') {
	  // implementation from standard node.js 'util' module
	  module.exports = function inherits(ctor, superCtor) {
	    ctor.super_ = superCtor
	    ctor.prototype = Object.create(superCtor.prototype, {
	      constructor: {
	        value: ctor,
	        enumerable: false,
	        writable: true,
	        configurable: true
	      }
	    });
	  };
	} else {
	  // old school shim for old browsers
	  module.exports = function inherits(ctor, superCtor) {
	    ctor.super_ = superCtor
	    var TempCtor = function () {}
	    TempCtor.prototype = superCtor.prototype
	    ctor.prototype = new TempCtor()
	    ctor.prototype.constructor = ctor
	  }
	}


/***/ },
/* 224 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';
	var Type = __webpack_require__(185);
	module.exports = new Type('tag:yaml.org,2002:str', {
	    kind: 'scalar',
	    construct: function (data) { return null !== data ? data : ''; }
	});
	//# sourceMappingURL=str.js.map

/***/ },
/* 225 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';
	var Type = __webpack_require__(185);
	module.exports = new Type('tag:yaml.org,2002:seq', {
	    kind: 'sequence',
	    construct: function (data) { return null !== data ? data : []; }
	});
	//# sourceMappingURL=seq.js.map

/***/ },
/* 226 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';
	var Type = __webpack_require__(185);
	module.exports = new Type('tag:yaml.org,2002:map', {
	    kind: 'mapping',
	    construct: function (data) { return null !== data ? data : {}; }
	});
	//# sourceMappingURL=map.js.map

/***/ },
/* 227 */
/***/ function(module, exports, __webpack_require__) {

	// Generated by CoffeeScript 1.10.0
	(function() {
	  "use strict";
	  var xml2js;

	  xml2js = __webpack_require__(200);

	  exports.stripBOM = function(str) {
	    if (str[0] === '\uFEFF') {
	      return str.substring(1);
	    } else {
	      return str;
	    }
	  };

	}).call(this);


/***/ },
/* 228 */
/***/ function(module, exports, __webpack_require__) {

	// Generated by CoffeeScript 1.10.0
	(function() {
	  "use strict";
	  var prefixMatch;

	  prefixMatch = new RegExp(/(?!xmlns)^.*:/);

	  exports.normalize = function(str) {
	    return str.toLowerCase();
	  };

	  exports.firstCharLowerCase = function(str) {
	    return str.charAt(0).toLowerCase() + str.slice(1);
	  };

	  exports.stripPrefix = function(str) {
	    return str.replace(prefixMatch, '');
	  };

	  exports.parseNumbers = function(str) {
	    if (!isNaN(str)) {
	      str = str % 1 === 0 ? parseInt(str, 10) : parseFloat(str);
	    }
	    return str;
	  };

	  exports.parseBooleans = function(str) {
	    if (/^(?:true|false)$/i.test(str)) {
	      str = str.toLowerCase() === 'true';
	    }
	    return str;
	  };

	}).call(this);


/***/ },
/* 229 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";

	module.exports = {

	    INVALID_TYPE:                           "Expected type {0} but found type {1}",
	    INVALID_FORMAT:                         "Object didn't pass validation for format {0}: {1}",
	    ENUM_MISMATCH:                          "No enum match for: {0}",
	    ANY_OF_MISSING:                         "Data does not match any schemas from 'anyOf'",
	    ONE_OF_MISSING:                         "Data does not match any schemas from 'oneOf'",
	    ONE_OF_MULTIPLE:                        "Data is valid against more than one schema from 'oneOf'",
	    NOT_PASSED:                             "Data matches schema from 'not'",

	    // Array errors
	    ARRAY_LENGTH_SHORT:                     "Array is too short ({0}), minimum {1}",
	    ARRAY_LENGTH_LONG:                      "Array is too long ({0}), maximum {1}",
	    ARRAY_UNIQUE:                           "Array items are not unique (indexes {0} and {1})",
	    ARRAY_ADDITIONAL_ITEMS:                 "Additional items not allowed",

	    // Numeric errors
	    MULTIPLE_OF:                            "Value {0} is not a multiple of {1}",
	    MINIMUM:                                "Value {0} is less than minimum {1}",
	    MINIMUM_EXCLUSIVE:                      "Value {0} is equal or less than exclusive minimum {1}",
	    MAXIMUM:                                "Value {0} is greater than maximum {1}",
	    MAXIMUM_EXCLUSIVE:                      "Value {0} is equal or greater than exclusive maximum {1}",

	    // Object errors
	    OBJECT_PROPERTIES_MINIMUM:              "Too few properties defined ({0}), minimum {1}",
	    OBJECT_PROPERTIES_MAXIMUM:              "Too many properties defined ({0}), maximum {1}",
	    OBJECT_MISSING_REQUIRED_PROPERTY:       "Missing required property: {0}",
	    OBJECT_ADDITIONAL_PROPERTIES:           "Additional properties not allowed: {0}",
	    OBJECT_DEPENDENCY_KEY:                  "Dependency failed - key must exist: {0} (due to key: {1})",

	    // String errors
	    MIN_LENGTH:                             "String is too short ({0} chars), minimum {1}",
	    MAX_LENGTH:                             "String is too long ({0} chars), maximum {1}",
	    PATTERN:                                "String does not match pattern {0}: {1}",

	    // Schema validation errors
	    KEYWORD_TYPE_EXPECTED:                  "Keyword '{0}' is expected to be of type '{1}'",
	    KEYWORD_UNDEFINED_STRICT:               "Keyword '{0}' must be defined in strict mode",
	    KEYWORD_UNEXPECTED:                     "Keyword '{0}' is not expected to appear in the schema",
	    KEYWORD_MUST_BE:                        "Keyword '{0}' must be {1}",
	    KEYWORD_DEPENDENCY:                     "Keyword '{0}' requires keyword '{1}'",
	    KEYWORD_PATTERN:                        "Keyword '{0}' is not a valid RegExp pattern: {1}",
	    KEYWORD_VALUE_TYPE:                     "Each element of keyword '{0}' array must be a '{1}'",
	    UNKNOWN_FORMAT:                         "There is no validation function for format '{0}'",
	    CUSTOM_MODE_FORCE_PROPERTIES:           "{0} must define at least one property if present",

	    // Remote errors
	    REF_UNRESOLVED:                         "Reference has not been resolved during compilation: {0}",
	    UNRESOLVABLE_REFERENCE:                 "Reference could not be resolved: {0}",
	    SCHEMA_NOT_REACHABLE:                   "Validator was not able to read schema with uri: {0}",
	    SCHEMA_TYPE_EXPECTED:                   "Schema is expected to be of type 'object'",
	    SCHEMA_NOT_AN_OBJECT:                   "Schema is not an object: {0}",
	    ASYNC_TIMEOUT:                          "{0} asynchronous task(s) have timed out after {1} ms",
	    PARENT_SCHEMA_VALIDATION_FAILED:        "Schema failed to validate against its parent schema, see inner errors for details.",
	    REMOTE_NOT_VALID:                       "Remote reference didn't compile successfully: {0}"

	};


/***/ },
/* 230 */
/***/ function(module, exports, __webpack_require__) {

	/**
	 * lodash 4.2.1 (Custom Build) <https://lodash.com/>
	 * Build: `lodash modularize exports="npm" -o ./`
	 * Copyright jQuery Foundation and other contributors <https://jquery.org/>
	 * Released under MIT license <https://lodash.com/license>
	 * Based on Underscore.js 1.8.3 <http://underscorejs.org/LICENSE>
	 * Copyright Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
	 */
	var stringToPath = __webpack_require__(318);

	/** `Object#toString` result references. */
	var symbolTag = '[object Symbol]';

	/** Used to match property names within property paths. */
	var reIsDeepProp = /\.|\[(?:[^[\]]*|(["'])(?:(?!\1)[^\\]|\\.)*?\1)\]/,
	    reIsPlainProp = /^\w*$/;

	/** Used for built-in method references. */
	var objectProto = Object.prototype;

	/**
	 * Used to resolve the
	 * [`toStringTag`](http://ecma-international.org/ecma-262/6.0/#sec-object.prototype.tostring)
	 * of values.
	 */
	var objectToString = objectProto.toString;

	/**
	 * The base implementation of `_.get` without support for default values.
	 *
	 * @private
	 * @param {Object} object The object to query.
	 * @param {Array|string} path The path of the property to get.
	 * @returns {*} Returns the resolved value.
	 */
	function baseGet(object, path) {
	  path = isKey(path, object) ? [path] : castPath(path);

	  var index = 0,
	      length = path.length;

	  while (object != null && index < length) {
	    object = object[path[index++]];
	  }
	  return (index && index == length) ? object : undefined;
	}

	/**
	 * Casts `value` to a path array if it's not one.
	 *
	 * @private
	 * @param {*} value The value to inspect.
	 * @returns {Array} Returns the cast property path array.
	 */
	function castPath(value) {
	  return isArray(value) ? value : stringToPath(value);
	}

	/**
	 * Checks if `value` is a property name and not a property path.
	 *
	 * @private
	 * @param {*} value The value to check.
	 * @param {Object} [object] The object to query keys on.
	 * @returns {boolean} Returns `true` if `value` is a property name, else `false`.
	 */
	function isKey(value, object) {
	  var type = typeof value;
	  if (type == 'number' || type == 'symbol') {
	    return true;
	  }
	  return !isArray(value) &&
	    (isSymbol(value) || reIsPlainProp.test(value) || !reIsDeepProp.test(value) ||
	      (object != null && value in Object(object)));
	}

	/**
	 * Checks if `value` is classified as an `Array` object.
	 *
	 * @static
	 * @memberOf _
	 * @since 0.1.0
	 * @type {Function}
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is correctly classified,
	 *  else `false`.
	 * @example
	 *
	 * _.isArray([1, 2, 3]);
	 * // => true
	 *
	 * _.isArray(document.body.children);
	 * // => false
	 *
	 * _.isArray('abc');
	 * // => false
	 *
	 * _.isArray(_.noop);
	 * // => false
	 */
	var isArray = Array.isArray;

	/**
	 * Checks if `value` is object-like. A value is object-like if it's not `null`
	 * and has a `typeof` result of "object".
	 *
	 * @static
	 * @memberOf _
	 * @since 4.0.0
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is object-like, else `false`.
	 * @example
	 *
	 * _.isObjectLike({});
	 * // => true
	 *
	 * _.isObjectLike([1, 2, 3]);
	 * // => true
	 *
	 * _.isObjectLike(_.noop);
	 * // => false
	 *
	 * _.isObjectLike(null);
	 * // => false
	 */
	function isObjectLike(value) {
	  return !!value && typeof value == 'object';
	}

	/**
	 * Checks if `value` is classified as a `Symbol` primitive or object.
	 *
	 * @static
	 * @memberOf _
	 * @since 4.0.0
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is correctly classified,
	 *  else `false`.
	 * @example
	 *
	 * _.isSymbol(Symbol.iterator);
	 * // => true
	 *
	 * _.isSymbol('abc');
	 * // => false
	 */
	function isSymbol(value) {
	  return typeof value == 'symbol' ||
	    (isObjectLike(value) && objectToString.call(value) == symbolTag);
	}

	/**
	 * Gets the value at `path` of `object`. If the resolved value is
	 * `undefined`, the `defaultValue` is used in its place.
	 *
	 * @static
	 * @memberOf _
	 * @since 3.7.0
	 * @category Object
	 * @param {Object} object The object to query.
	 * @param {Array|string} path The path of the property to get.
	 * @param {*} [defaultValue] The value returned for `undefined` resolved values.
	 * @returns {*} Returns the resolved value.
	 * @example
	 *
	 * var object = { 'a': [{ 'b': { 'c': 3 } }] };
	 *
	 * _.get(object, 'a[0].b.c');
	 * // => 3
	 *
	 * _.get(object, ['a', '0', 'b', 'c']);
	 * // => 3
	 *
	 * _.get(object, 'a.b.c', 'default');
	 * // => 'default'
	 */
	function get(object, path, defaultValue) {
	  var result = object == null ? undefined : baseGet(object, path);
	  return result === undefined ? defaultValue : result;
	}

	module.exports = get;


/***/ },
/* 231 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(global) {"use strict";

	// Use the fastest means possible to execute a task in its own turn, with
	// priority over other events including IO, animation, reflow, and redraw
	// events in browsers.
	//
	// An exception thrown by a task will permanently interrupt the processing of
	// subsequent tasks. The higher level `asap` function ensures that if an
	// exception is thrown by a task, that the task queue will continue flushing as
	// soon as possible, but if you use `rawAsap` directly, you are responsible to
	// either ensure that no exceptions are thrown from your task, or to manually
	// call `rawAsap.requestFlush` if an exception is thrown.
	module.exports = rawAsap;
	function rawAsap(task) {
	    if (!queue.length) {
	        requestFlush();
	        flushing = true;
	    }
	    // Equivalent to push, but avoids a function call.
	    queue[queue.length] = task;
	}

	var queue = [];
	// Once a flush has been requested, no further calls to `requestFlush` are
	// necessary until the next `flush` completes.
	var flushing = false;
	// `requestFlush` is an implementation-specific method that attempts to kick
	// off a `flush` event as quickly as possible. `flush` will attempt to exhaust
	// the event queue before yielding to the browser's own event loop.
	var requestFlush;
	// The position of the next task to execute in the task queue. This is
	// preserved between calls to `flush` so that it can be resumed if
	// a task throws an exception.
	var index = 0;
	// If a task schedules additional tasks recursively, the task queue can grow
	// unbounded. To prevent memory exhaustion, the task queue will periodically
	// truncate already-completed tasks.
	var capacity = 1024;

	// The flush function processes all tasks that have been scheduled with
	// `rawAsap` unless and until one of those tasks throws an exception.
	// If a task throws an exception, `flush` ensures that its state will remain
	// consistent and will resume where it left off when called again.
	// However, `flush` does not make any arrangements to be called again if an
	// exception is thrown.
	function flush() {
	    while (index < queue.length) {
	        var currentIndex = index;
	        // Advance the index before calling the task. This ensures that we will
	        // begin flushing on the next task the task throws an error.
	        index = index + 1;
	        queue[currentIndex].call();
	        // Prevent leaking memory for long chains of recursive calls to `asap`.
	        // If we call `asap` within tasks scheduled by `asap`, the queue will
	        // grow, but to avoid an O(n) walk for every task we execute, we don't
	        // shift tasks off the queue after they have been executed.
	        // Instead, we periodically shift 1024 tasks off the queue.
	        if (index > capacity) {
	            // Manually shift all values starting at the index back to the
	            // beginning of the queue.
	            for (var scan = 0, newLength = queue.length - index; scan < newLength; scan++) {
	                queue[scan] = queue[scan + index];
	            }
	            queue.length -= index;
	            index = 0;
	        }
	    }
	    queue.length = 0;
	    index = 0;
	    flushing = false;
	}

	// `requestFlush` is implemented using a strategy based on data collected from
	// every available SauceLabs Selenium web driver worker at time of writing.
	// https://docs.google.com/spreadsheets/d/1mG-5UYGup5qxGdEMWkhP6BWCz053NUb2E1QoUTU16uA/edit#gid=783724593

	// Safari 6 and 6.1 for desktop, iPad, and iPhone are the only browsers that
	// have WebKitMutationObserver but not un-prefixed MutationObserver.
	// Must use `global` instead of `window` to work in both frames and web
	// workers. `global` is a provision of Browserify, Mr, Mrs, or Mop.
	var BrowserMutationObserver = global.MutationObserver || global.WebKitMutationObserver;

	// MutationObservers are desirable because they have high priority and work
	// reliably everywhere they are implemented.
	// They are implemented in all modern browsers.
	//
	// - Android 4-4.3
	// - Chrome 26-34
	// - Firefox 14-29
	// - Internet Explorer 11
	// - iPad Safari 6-7.1
	// - iPhone Safari 7-7.1
	// - Safari 6-7
	if (typeof BrowserMutationObserver === "function") {
	    requestFlush = makeRequestCallFromMutationObserver(flush);

	// MessageChannels are desirable because they give direct access to the HTML
	// task queue, are implemented in Internet Explorer 10, Safari 5.0-1, and Opera
	// 11-12, and in web workers in many engines.
	// Although message channels yield to any queued rendering and IO tasks, they
	// would be better than imposing the 4ms delay of timers.
	// However, they do not work reliably in Internet Explorer or Safari.

	// Internet Explorer 10 is the only browser that has setImmediate but does
	// not have MutationObservers.
	// Although setImmediate yields to the browser's renderer, it would be
	// preferrable to falling back to setTimeout since it does not have
	// the minimum 4ms penalty.
	// Unfortunately there appears to be a bug in Internet Explorer 10 Mobile (and
	// Desktop to a lesser extent) that renders both setImmediate and
	// MessageChannel useless for the purposes of ASAP.
	// https://github.com/kriskowal/q/issues/396

	// Timers are implemented universally.
	// We fall back to timers in workers in most engines, and in foreground
	// contexts in the following browsers.
	// However, note that even this simple case requires nuances to operate in a
	// broad spectrum of browsers.
	//
	// - Firefox 3-13
	// - Internet Explorer 6-9
	// - iPad Safari 4.3
	// - Lynx 2.8.7
	} else {
	    requestFlush = makeRequestCallFromTimer(flush);
	}

	// `requestFlush` requests that the high priority event queue be flushed as
	// soon as possible.
	// This is useful to prevent an error thrown in a task from stalling the event
	// queue if the exception handled by Node.js’s
	// `process.on("uncaughtException")` or by a domain.
	rawAsap.requestFlush = requestFlush;

	// To request a high priority event, we induce a mutation observer by toggling
	// the text of a text node between "1" and "-1".
	function makeRequestCallFromMutationObserver(callback) {
	    var toggle = 1;
	    var observer = new BrowserMutationObserver(callback);
	    var node = document.createTextNode("");
	    observer.observe(node, {characterData: true});
	    return function requestCall() {
	        toggle = -toggle;
	        node.data = toggle;
	    };
	}

	// The message channel technique was discovered by Malte Ubl and was the
	// original foundation for this library.
	// http://www.nonblocking.io/2011/06/windownexttick.html

	// Safari 6.0.5 (at least) intermittently fails to create message ports on a
	// page's first load. Thankfully, this version of Safari supports
	// MutationObservers, so we don't need to fall back in that case.

	// function makeRequestCallFromMessageChannel(callback) {
	//     var channel = new MessageChannel();
	//     channel.port1.onmessage = callback;
	//     return function requestCall() {
	//         channel.port2.postMessage(0);
	//     };
	// }

	// For reasons explained above, we are also unable to use `setImmediate`
	// under any circumstances.
	// Even if we were, there is another bug in Internet Explorer 10.
	// It is not sufficient to assign `setImmediate` to `requestFlush` because
	// `setImmediate` must be called *by name* and therefore must be wrapped in a
	// closure.
	// Never forget.

	// function makeRequestCallFromSetImmediate(callback) {
	//     return function requestCall() {
	//         setImmediate(callback);
	//     };
	// }

	// Safari 6.0 has a problem where timers will get lost while the user is
	// scrolling. This problem does not impact ASAP because Safari 6.0 supports
	// mutation observers, so that implementation is used instead.
	// However, if we ever elect to use timers in Safari, the prevalent work-around
	// is to add a scroll event listener that calls for a flush.

	// `setTimeout` does not call the passed callback if the delay is less than
	// approximately 7 in web workers in Firefox 8 through 18, and sometimes not
	// even then.

	function makeRequestCallFromTimer(callback) {
	    return function requestCall() {
	        // We dispatch a timeout with a specified delay of 0 for engines that
	        // can reliably accommodate that request. This will usually be snapped
	        // to a 4 milisecond delay, but once we're flushing, there's no delay
	        // between events.
	        var timeoutHandle = setTimeout(handleTimer, 0);
	        // However, since this timer gets frequently dropped in Firefox
	        // workers, we enlist an interval handle that will try to fire
	        // an event 20 times per second until it succeeds.
	        var intervalHandle = setInterval(handleTimer, 50);

	        function handleTimer() {
	            // Whichever timer succeeds will cancel both timers and
	            // execute the callback.
	            clearTimeout(timeoutHandle);
	            clearInterval(intervalHandle);
	            callback();
	        }
	    };
	}

	// This is for `asap.js` only.
	// Its name will be periodically randomized to break any code that depends on
	// its existence.
	rawAsap.makeRequestCallFromTimer = makeRequestCallFromTimer;

	// ASAP was originally a nextTick shim included in Q. This was factored out
	// into this ASAP package. It was later adapted to RSVP which made further
	// amendments. These decisions, particularly to marginalize MessageChannel and
	// to capture the MutationObserver implementation in a closure, were integrated
	// back into ASAP proper.
	// https://github.com/tildeio/rsvp.js/blob/cddf7232546a9cf858524b75cde6f9edf72620a7/lib/rsvp/asap.js
	
	/* WEBPACK VAR INJECTION */}.call(exports, (function() { return this; }())))

/***/ },
/* 232 */
/***/ function(module, exports, __webpack_require__) {

	module.exports = {
		"id": "http://json-schema.org/draft-04/schema#",
		"$schema": "http://json-schema.org/draft-04/schema#",
		"description": "Core schema meta-schema",
		"definitions": {
			"schemaArray": {
				"type": "array",
				"minItems": 1,
				"items": {
					"$ref": "#"
				}
			},
			"positiveInteger": {
				"type": "integer",
				"minimum": 0
			},
			"positiveIntegerDefault0": {
				"allOf": [
					{
						"$ref": "#/definitions/positiveInteger"
					},
					{
						"default": 0
					}
				]
			},
			"simpleTypes": {
				"enum": [
					"array",
					"boolean",
					"integer",
					"null",
					"number",
					"object",
					"string"
				]
			},
			"stringArray": {
				"type": "array",
				"items": {
					"type": "string"
				},
				"minItems": 1,
				"uniqueItems": true
			}
		},
		"type": "object",
		"properties": {
			"id": {
				"type": "string",
				"format": "uri"
			},
			"$schema": {
				"type": "string",
				"format": "uri"
			},
			"title": {
				"type": "string"
			},
			"description": {
				"type": "string"
			},
			"default": {},
			"multipleOf": {
				"type": "number",
				"minimum": 0,
				"exclusiveMinimum": true
			},
			"maximum": {
				"type": "number"
			},
			"exclusiveMaximum": {
				"type": "boolean",
				"default": false
			},
			"minimum": {
				"type": "number"
			},
			"exclusiveMinimum": {
				"type": "boolean",
				"default": false
			},
			"maxLength": {
				"$ref": "#/definitions/positiveInteger"
			},
			"minLength": {
				"$ref": "#/definitions/positiveIntegerDefault0"
			},
			"pattern": {
				"type": "string",
				"format": "regex"
			},
			"additionalItems": {
				"anyOf": [
					{
						"type": "boolean"
					},
					{
						"$ref": "#"
					}
				],
				"default": {}
			},
			"items": {
				"anyOf": [
					{
						"$ref": "#"
					},
					{
						"$ref": "#/definitions/schemaArray"
					}
				],
				"default": {}
			},
			"maxItems": {
				"$ref": "#/definitions/positiveInteger"
			},
			"minItems": {
				"$ref": "#/definitions/positiveIntegerDefault0"
			},
			"uniqueItems": {
				"type": "boolean",
				"default": false
			},
			"maxProperties": {
				"$ref": "#/definitions/positiveInteger"
			},
			"minProperties": {
				"$ref": "#/definitions/positiveIntegerDefault0"
			},
			"required": {
				"$ref": "#/definitions/stringArray"
			},
			"additionalProperties": {
				"anyOf": [
					{
						"type": "boolean"
					},
					{
						"$ref": "#"
					}
				],
				"default": {}
			},
			"definitions": {
				"type": "object",
				"additionalProperties": {
					"$ref": "#"
				},
				"default": {}
			},
			"properties": {
				"type": "object",
				"additionalProperties": {
					"$ref": "#"
				},
				"default": {}
			},
			"patternProperties": {
				"type": "object",
				"additionalProperties": {
					"$ref": "#"
				},
				"default": {}
			},
			"dependencies": {
				"type": "object",
				"additionalProperties": {
					"anyOf": [
						{
							"$ref": "#"
						},
						{
							"$ref": "#/definitions/stringArray"
						}
					]
				}
			},
			"enum": {
				"type": "array",
				"minItems": 1,
				"uniqueItems": true
			},
			"type": {
				"anyOf": [
					{
						"$ref": "#/definitions/simpleTypes"
					},
					{
						"type": "array",
						"items": {
							"$ref": "#/definitions/simpleTypes"
						},
						"minItems": 1,
						"uniqueItems": true
					}
				]
			},
			"format": {
				"type": "string"
			},
			"allOf": {
				"$ref": "#/definitions/schemaArray"
			},
			"anyOf": {
				"$ref": "#/definitions/schemaArray"
			},
			"oneOf": {
				"$ref": "#/definitions/schemaArray"
			},
			"not": {
				"$ref": "#"
			}
		},
		"dependencies": {
			"exclusiveMaximum": [
				"maximum"
			],
			"exclusiveMinimum": [
				"minimum"
			]
		},
		"default": {}
	};

/***/ },
/* 233 */
/***/ function(module, exports, __webpack_require__) {

	module.exports = {
		"$schema": "http://json-schema.org/draft-04/hyper-schema#",
		"id": "http://json-schema.org/draft-04/hyper-schema#",
		"title": "JSON Hyper-Schema",
		"allOf": [
			{
				"$ref": "http://json-schema.org/draft-04/schema#"
			}
		],
		"properties": {
			"additionalItems": {
				"anyOf": [
					{
						"type": "boolean"
					},
					{
						"$ref": "#"
					}
				]
			},
			"additionalProperties": {
				"anyOf": [
					{
						"type": "boolean"
					},
					{
						"$ref": "#"
					}
				]
			},
			"dependencies": {
				"additionalProperties": {
					"anyOf": [
						{
							"$ref": "#"
						},
						{
							"type": "array"
						}
					]
				}
			},
			"items": {
				"anyOf": [
					{
						"$ref": "#"
					},
					{
						"$ref": "#/definitions/schemaArray"
					}
				]
			},
			"definitions": {
				"additionalProperties": {
					"$ref": "#"
				}
			},
			"patternProperties": {
				"additionalProperties": {
					"$ref": "#"
				}
			},
			"properties": {
				"additionalProperties": {
					"$ref": "#"
				}
			},
			"allOf": {
				"$ref": "#/definitions/schemaArray"
			},
			"anyOf": {
				"$ref": "#/definitions/schemaArray"
			},
			"oneOf": {
				"$ref": "#/definitions/schemaArray"
			},
			"not": {
				"$ref": "#"
			},
			"links": {
				"type": "array",
				"items": {
					"$ref": "#/definitions/linkDescription"
				}
			},
			"fragmentResolution": {
				"type": "string"
			},
			"media": {
				"type": "object",
				"properties": {
					"type": {
						"description": "A media type, as described in RFC 2046",
						"type": "string"
					},
					"binaryEncoding": {
						"description": "A content encoding scheme, as described in RFC 2045",
						"type": "string"
					}
				}
			},
			"pathStart": {
				"description": "Instances' URIs must start with this value for this schema to apply to them",
				"type": "string",
				"format": "uri"
			}
		},
		"definitions": {
			"schemaArray": {
				"type": "array",
				"items": {
					"$ref": "#"
				}
			},
			"linkDescription": {
				"title": "Link Description Object",
				"type": "object",
				"required": [
					"href",
					"rel"
				],
				"properties": {
					"href": {
						"description": "a URI template, as defined by RFC 6570, with the addition of the $, ( and ) characters for pre-processing",
						"type": "string"
					},
					"rel": {
						"description": "relation to the target resource of the link",
						"type": "string"
					},
					"title": {
						"description": "a title for the link",
						"type": "string"
					},
					"targetSchema": {
						"description": "JSON Schema describing the link target",
						"$ref": "#"
					},
					"mediaType": {
						"description": "media type (as defined by RFC 2046) describing the link target",
						"type": "string"
					},
					"method": {
						"description": "method for requesting the target of the link (e.g. for HTTP this might be \"GET\" or \"DELETE\")",
						"type": "string"
					},
					"encType": {
						"description": "The media type in which to submit data along with the request",
						"type": "string",
						"default": "application/json"
					},
					"schema": {
						"description": "Schema describing the data to submit along with the request",
						"$ref": "#"
					}
				}
			}
		}
	};

/***/ },
/* 234 */
/***/ function(module, exports, __webpack_require__) {

	var __WEBPACK_AMD_DEFINE_FACTORY__, __WEBPACK_AMD_DEFINE_ARRAY__, __WEBPACK_AMD_DEFINE_RESULT__;/**
	 * @preserve date-and-time.js locale configuration
	 * @preserve Arabic (ar)
	 * @preserve It is using moment.js locale configuration as a reference.
	 */
	(function (global) {
	    'use strict';

	    var locale = function (date) {
	        var num = ['٠', '١', '٢', '٣', '٤', '٥', '٦', '٧', '٨', '٩'],
	            map = { '٠': 0, '١': 1, '٢': 2, '٣': 3, '٤': 4, '٥': 5, '٦': 6, '٧': 7, '٨': 8, '٩': 9 };

	        date.setLocales('ar', {
	            MMMM: ['كانون الثاني يناير', 'شباط فبراير', 'آذار مارس', 'نيسان أبريل', 'أيار مايو', 'حزيران يونيو', 'تموز يوليو', 'آب أغسطس', 'أيلول سبتمبر', 'تشرين الأول أكتوبر', 'تشرين الثاني نوفمبر', 'كانون الأول ديسمبر'],
	            MMM: ['كانون الثاني يناير', 'شباط فبراير', 'آذار مارس', 'نيسان أبريل', 'أيار مايو', 'حزيران يونيو', 'تموز يوليو', 'آب أغسطس', 'أيلول سبتمبر', 'تشرين الأول أكتوبر', 'تشرين الثاني نوفمبر', 'كانون الأول ديسمبر'],
	            dddd: ['الأحد', 'الإثنين', 'الثلاثاء', 'الأربعاء', 'الخميس', 'الجمعة', 'السبت'],
	            ddd: ['أحد', 'إثنين', 'ثلاثاء', 'أربعاء', 'خميس', 'جمعة', 'سبت'],
	            dd: ['ح', 'ن', 'ث', 'ر', 'خ', 'ج', 'س'],
	            A: ['ص', 'م'],
	            formats: {
	                post: function (str) {
	                    return str.replace(/\d/g, function (i) {
	                        return num[i | 0];
	                    });
	                }
	            },
	            parsers: {
	                pre: function (str) {
	                    return str.replace(/[٠١٢٣٤٥٦٧٨٩]/g, function (i) {
	                        return '' + map[i];
	                    });
	                }
	            }
	        });
	    };

	    if (typeof module === 'object' && typeof module.exports === 'object') {
	        locale(__webpack_require__(192));
	    } else if (true) {
	        !(__WEBPACK_AMD_DEFINE_ARRAY__ = [__webpack_require__(192)], __WEBPACK_AMD_DEFINE_FACTORY__ = (locale), __WEBPACK_AMD_DEFINE_RESULT__ = (typeof __WEBPACK_AMD_DEFINE_FACTORY__ === 'function' ? (__WEBPACK_AMD_DEFINE_FACTORY__.apply(exports, __WEBPACK_AMD_DEFINE_ARRAY__)) : __WEBPACK_AMD_DEFINE_FACTORY__), __WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
	    } else {
	        locale(global.date);
	    }

	}(this));



/***/ },
/* 235 */
/***/ function(module, exports, __webpack_require__) {

	var __WEBPACK_AMD_DEFINE_FACTORY__, __WEBPACK_AMD_DEFINE_ARRAY__, __WEBPACK_AMD_DEFINE_RESULT__;/**
	 * @preserve date-and-time.js locale configuration
	 * @preserve Bengali (bn)
	 * @preserve It is using moment.js locale configuration as a reference.
	 */
	(function (global) {
	    'use strict';

	    var locale = function (date) {
	        date.setLocales('bn', {
	            MMMM: ['জানুয়ারী', 'ফেবুয়ারী', 'মার্চ', 'এপ্রিল', 'মে', 'জুন', 'জুলাই', 'অগাস্ট', 'সেপ্টেম্বর', 'অক্টোবর', 'নভেম্বর', 'ডিসেম্বর'],
	            MMM: ['জানু', 'ফেব', 'মার্চ', 'এপর', 'মে', 'জুন', 'জুল', 'অগ', 'সেপ্ট', 'অক্টো', 'নভ', 'ডিসেম্'],
	            dddd: ['রবিবার', 'সোমবার', 'মঙ্গলবার', 'বুধবার', 'বৃহস্পত্তিবার', 'শুক্রবার', 'শনিবার'],
	            ddd: ['রবি', 'সোম', 'মঙ্গল', 'বুধ', 'বৃহস্পত্তি', 'শুক্র', 'শনি'],
	            dd: ['রব', 'সম', 'মঙ্গ', 'বু', 'ব্রিহ', 'শু', 'শনি'],
	            A: ['রাত', 'সকাল', 'দুপুর', 'বিকাল'],
	            formats: {
	                A: function (d) {
	                    var h = d.getHours();
	                    if (h < 4) {
	                        return this.A[0];   // রাত
	                    } else if (h < 10) {
	                        return this.A[1];   // সকাল
	                    } else if (h < 17) {
	                        return this.A[2];   // দুপুর
	                    } else if (h < 20) {
	                        return this.A[3];   // বিকাল
	                    }
	                    return this.A[0];       // রাত
	                }
	            },
	            parsers: {
	                h: function (h, a) {
	                    if (a < 1) {
	                        return h < 4 || h > 11 ? h : h + 12;    // রাত
	                    } else if (a < 2) {
	                        return h;                               // সকাল
	                    } else if (a < 3) {
	                        return h > 9 ? h : h + 12;              // দুপুর
	                    }
	                    return h + 12;                              // বিকাল
	                }
	            }
	        });
	    };

	    if (typeof module === 'object' && typeof module.exports === 'object') {
	        locale(__webpack_require__(192));
	    } else if (true) {
	        !(__WEBPACK_AMD_DEFINE_ARRAY__ = [__webpack_require__(192)], __WEBPACK_AMD_DEFINE_FACTORY__ = (locale), __WEBPACK_AMD_DEFINE_RESULT__ = (typeof __WEBPACK_AMD_DEFINE_FACTORY__ === 'function' ? (__WEBPACK_AMD_DEFINE_FACTORY__.apply(exports, __WEBPACK_AMD_DEFINE_ARRAY__)) : __WEBPACK_AMD_DEFINE_FACTORY__), __WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
	    } else {
	        locale(global.date);
	    }

	}(this));



/***/ },
/* 236 */
/***/ function(module, exports, __webpack_require__) {

	var __WEBPACK_AMD_DEFINE_FACTORY__, __WEBPACK_AMD_DEFINE_ARRAY__, __WEBPACK_AMD_DEFINE_RESULT__;/**
	 * @preserve date-and-time.js locale configuration
	 * @preserve German (de)
	 * @preserve It is using moment.js locale configuration as a reference.
	 */
	(function (global) {
	    'use strict';

	    var locale = function (date) {
	        date.setLocales('de', {
	            MMMM: ['Januar', 'Februar', 'März', 'April', 'Mai', 'Juni', 'Juli', 'August', 'September', 'Oktober', 'November', 'Dezember'],
	            MMM: ['Jan.', 'Febr.', 'Mrz.', 'Apr.', 'Mai', 'Jun.', 'Jul.', 'Aug.', 'Sept.', 'Okt.', 'Nov.', 'Dez.'],
	            dddd: ['Sonntag', 'Montag', 'Dienstag', 'Mittwoch', 'Donnerstag', 'Freitag', 'Samstag'],
	            ddd: ['So.', 'Mo.', 'Di.', 'Mi.', 'Do.', 'Fr.', 'Sa.'],
	            dd: ['So', 'Mo', 'Di', 'Mi', 'Do', 'Fr', 'Sa'],
	            A: ['Uhr nachmittags', 'Uhr morgens']
	        });
	    };

	    if (typeof module === 'object' && typeof module.exports === 'object') {
	        locale(__webpack_require__(192));
	    } else if (true) {
	        !(__WEBPACK_AMD_DEFINE_ARRAY__ = [__webpack_require__(192)], __WEBPACK_AMD_DEFINE_FACTORY__ = (locale), __WEBPACK_AMD_DEFINE_RESULT__ = (typeof __WEBPACK_AMD_DEFINE_FACTORY__ === 'function' ? (__WEBPACK_AMD_DEFINE_FACTORY__.apply(exports, __WEBPACK_AMD_DEFINE_ARRAY__)) : __WEBPACK_AMD_DEFINE_FACTORY__), __WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
	    } else {
	        locale(global.date);
	    }

	}(this));



/***/ },
/* 237 */
/***/ function(module, exports, __webpack_require__) {

	var __WEBPACK_AMD_DEFINE_FACTORY__, __WEBPACK_AMD_DEFINE_ARRAY__, __WEBPACK_AMD_DEFINE_RESULT__;/**
	 * @preserve date-and-time.js locale configuration
	 * @preserve Spanish (es)
	 * @preserve It is using moment.js locale configuration as a reference.
	 */
	(function (global) {
	    'use strict';

	    var locale = function (date) {
	        date.setLocales('es', {
	            MMMM: ['enero', 'febrero', 'marzo', 'abril', 'mayo', 'junio', 'julio', 'agosto', 'septiembre', 'octubre', 'noviembre', 'diciembre'],
	            MMM: ['ene.', 'feb.', 'mar.', 'abr.', 'may.', 'jun.', 'jul.', 'ago.', 'sep.', 'oct.', 'nov.', 'dic.'],
	            dddd: ['domingo', 'lunes', 'martes', 'miércoles', 'jueves', 'viernes', 'sábado'],
	            ddd: ['dom.', 'lun.', 'mar.', 'mié.', 'jue.', 'vie.', 'sáb.'],
	            dd: ['do', 'lu', 'ma', 'mi', 'ju', 'vi', 'sá'],
	            A: ['de la mañana', 'de la tarde', 'de la noche'],
	            formats: {
	                A: function (d) {
	                    var h = d.getHours();
	                    if (h < 12) {
	                        return this.A[0];   // de la mañana
	                    } else if (h < 19) {
	                        return this.A[1];   // de la tarde
	                    }
	                    return this.A[2];       // de la noche
	                }
	            },
	            parsers: {
	                h: function (h, a) {
	                    if (a < 1) {    // de la mañana
	                        return h;
	                    }
	                    return h > 11 ? h : h + 12; // de la tarde, de la noche
	                }
	            }
	        });
	    };

	    if (typeof module === 'object' && typeof module.exports === 'object') {
	        locale(__webpack_require__(192));
	    } else if (true) {
	        !(__WEBPACK_AMD_DEFINE_ARRAY__ = [__webpack_require__(192)], __WEBPACK_AMD_DEFINE_FACTORY__ = (locale), __WEBPACK_AMD_DEFINE_RESULT__ = (typeof __WEBPACK_AMD_DEFINE_FACTORY__ === 'function' ? (__WEBPACK_AMD_DEFINE_FACTORY__.apply(exports, __WEBPACK_AMD_DEFINE_ARRAY__)) : __WEBPACK_AMD_DEFINE_FACTORY__), __WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
	    } else {
	        locale(global.date);
	    }

	}(this));



/***/ },
/* 238 */
/***/ function(module, exports, __webpack_require__) {

	var __WEBPACK_AMD_DEFINE_FACTORY__, __WEBPACK_AMD_DEFINE_ARRAY__, __WEBPACK_AMD_DEFINE_RESULT__;/**
	 * @preserve date-and-time.js locale configuration
	 * @preserve French (fr)
	 * @preserve It is using moment.js locale configuration as a reference.
	 */
	(function (global) {
	    'use strict';

	    var locale = function (date) {
	        date.setLocales('fr', {
	            MMMM: ['janvier', 'février', 'mars', 'avril', 'mai', 'juin', 'juillet', 'août', 'septembre', 'octobre', 'novembre', 'décembre'],
	            MMM: ['janv.', 'févr.', 'mars', 'avr.', 'mai', 'juin', 'juil.', 'août', 'sept.', 'oct.', 'nov.', 'déc.'],
	            dddd: ['dimanche', 'lundi', 'mardi', 'mercredi', 'jeudi', 'vendredi', 'samedi'],
	            ddd: ['dim.', 'lun.', 'mar.', 'mer.', 'jeu.', 'ven.', 'sam.'],
	            dd: ['Di', 'Lu', 'Ma', 'Me', 'Je', 'Ve', 'Sa'],
	            A: ['matin', 'l\'après-midi']
	        });
	    };

	    if (typeof module === 'object' && typeof module.exports === 'object') {
	        locale(__webpack_require__(192));
	    } else if (true) {
	        !(__WEBPACK_AMD_DEFINE_ARRAY__ = [__webpack_require__(192)], __WEBPACK_AMD_DEFINE_FACTORY__ = (locale), __WEBPACK_AMD_DEFINE_RESULT__ = (typeof __WEBPACK_AMD_DEFINE_FACTORY__ === 'function' ? (__WEBPACK_AMD_DEFINE_FACTORY__.apply(exports, __WEBPACK_AMD_DEFINE_ARRAY__)) : __WEBPACK_AMD_DEFINE_FACTORY__), __WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
	    } else {
	        locale(global.date);
	    }

	}(this));



/***/ },
/* 239 */
/***/ function(module, exports, __webpack_require__) {

	var __WEBPACK_AMD_DEFINE_FACTORY__, __WEBPACK_AMD_DEFINE_ARRAY__, __WEBPACK_AMD_DEFINE_RESULT__;/**
	 * @preserve date-and-time.js locale configuration
	 * @preserve Hindi (hi)
	 * @preserve It is using moment.js locale configuration as a reference.
	 */
	(function (global) {
	    'use strict';

	    var locale = function (date) {
	        date.setLocales('hi', {
	            MMMM: ['जनवरी', 'फ़रवरी', 'मार्च', 'अप्रैल', 'मई', 'जून', 'जुलाई', 'अगस्त', 'सितम्बर', 'अक्टूबर', 'नवम्बर', 'दिसम्बर'],
	            MMM: ['जन.', 'फ़र.', 'मार्च', 'अप्रै.', 'मई', 'जून', 'जुल.', 'अग.', 'सित.', 'अक्टू.', 'नव.', 'दिस.'],
	            dddd: ['रविवार', 'सोमवार', 'मंगलवार', 'बुधवार', 'गुरूवार', 'शुक्रवार', 'शनिवार'],
	            ddd: ['रवि', 'सोम', 'मंगल', 'बुध', 'गुरू', 'शुक्र', 'शनि'],
	            dd: ['र', 'सो', 'मं', 'बु', 'गु', 'शु', 'श'],
	            A: ['रात', 'सुबह', 'दोपहर', 'शाम'],
	            formats: {
	                A: function (d) {
	                    var h = d.getHours();
	                    if (h < 4) {
	                        return this.A[0];   // रात
	                    } else if (h < 10) {
	                        return this.A[1];   // सुबह
	                    } else if (h < 17) {
	                        return this.A[2];   // दोपहर
	                    } else if (h < 20) {
	                        return this.A[3];   // शाम
	                    }
	                    return this.A[0];       // रात
	                }
	            },
	            parsers: {
	                h: function (h, a) {
	                    if (a < 1) {
	                        return h < 4 || h > 11 ? h : h + 12;    // रात
	                    } else if (a < 2) {
	                        return h;                               // सुबह
	                    } else if (a < 3) {
	                        return h > 9 ? h : h + 12;              // दोपहर
	                    }
	                    return h + 12;                              // शाम
	                }
	            }
	        });
	    };

	    if (typeof module === 'object' && typeof module.exports === 'object') {
	        locale(__webpack_require__(192));
	    } else if (true) {
	        !(__WEBPACK_AMD_DEFINE_ARRAY__ = [__webpack_require__(192)], __WEBPACK_AMD_DEFINE_FACTORY__ = (locale), __WEBPACK_AMD_DEFINE_RESULT__ = (typeof __WEBPACK_AMD_DEFINE_FACTORY__ === 'function' ? (__WEBPACK_AMD_DEFINE_FACTORY__.apply(exports, __WEBPACK_AMD_DEFINE_ARRAY__)) : __WEBPACK_AMD_DEFINE_FACTORY__), __WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
	    } else {
	        locale(global.date);
	    }

	}(this));



/***/ },
/* 240 */
/***/ function(module, exports, __webpack_require__) {

	var __WEBPACK_AMD_DEFINE_FACTORY__, __WEBPACK_AMD_DEFINE_ARRAY__, __WEBPACK_AMD_DEFINE_RESULT__;/**
	 * @preserve date-and-time.js locale configuration
	 * @preserve Italian (it)
	 * @preserve It is using moment.js locale configuration as a reference.
	 */
	(function (global) {
	    'use strict';

	    var locale = function (date) {
	        date.setLocales('it', {
	            MMMM: ['gennaio', 'febbraio', 'marzo', 'aprile', 'maggio', 'giugno', 'luglio', 'agosto', 'settembre', 'ottobre', 'novembre', 'dicembre'],
	            MMM: ['gen', 'feb', 'mar', 'apr', 'mag', 'giu', 'lug', 'ago', 'set', 'ott', 'nov', 'dic'],
	            dddd: ['Domenica', 'Lunedì', 'Martedì', 'Mercoledì', 'Giovedì', 'Venerdì', 'Sabato'],
	            ddd: ['Dom', 'Lun', 'Mar', 'Mer', 'Gio', 'Ven', 'Sab'],
	            dd: ['Do', 'Lu', 'Ma', 'Me', 'Gi', 'Ve', 'Sa'],
	            A: ['di mattina', 'di pomerrigio']
	        });
	    };

	    if (typeof module === 'object' && typeof module.exports === 'object') {
	        locale(__webpack_require__(192));
	    } else if (true) {
	        !(__WEBPACK_AMD_DEFINE_ARRAY__ = [__webpack_require__(192)], __WEBPACK_AMD_DEFINE_FACTORY__ = (locale), __WEBPACK_AMD_DEFINE_RESULT__ = (typeof __WEBPACK_AMD_DEFINE_FACTORY__ === 'function' ? (__WEBPACK_AMD_DEFINE_FACTORY__.apply(exports, __WEBPACK_AMD_DEFINE_ARRAY__)) : __WEBPACK_AMD_DEFINE_FACTORY__), __WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
	    } else {
	        locale(global.date);
	    }

	}(this));



/***/ },
/* 241 */
/***/ function(module, exports, __webpack_require__) {

	var __WEBPACK_AMD_DEFINE_FACTORY__, __WEBPACK_AMD_DEFINE_ARRAY__, __WEBPACK_AMD_DEFINE_RESULT__;/**
	 * @preserve date-and-time.js locale configuration
	 * @preserve Japanese (ja)
	 * @preserve It is using moment.js locale configuration as a reference.
	 */
	(function (global) {
	    'use strict';

	    var locale = function (date) {
	        date.setLocales('ja', {
	            MMMM: ['1月', '2月', '3月', '4月', '5月', '6月', '7月', '8月', '9月', '10月', '11月', '12月'],
	            MMM: ['1月', '2月', '3月', '4月', '5月', '6月', '7月', '8月', '9月', '10月', '11月', '12月'],
	            dddd: ['日曜日', '月曜日', '火曜日', '水曜日', '木曜日', '金曜日', '土曜日'],
	            ddd: ['日', '月', '火', '水', '木', '金', '土'],
	            dd: ['日', '月', '火', '水', '木', '金', '土'],
	            A: ['午前', '午後'],
	            formats: {
	                hh: function (d) {
	                    return ('0' + d.getHours() % 12).slice(-2);
	                },
	                h: function (d) {
	                    return d.getHours() % 12;
	                }
	            }
	        });
	    };

	    if (typeof module === 'object' && typeof module.exports === 'object') {
	        locale(__webpack_require__(192));
	    } else if (true) {
	        !(__WEBPACK_AMD_DEFINE_ARRAY__ = [__webpack_require__(192)], __WEBPACK_AMD_DEFINE_FACTORY__ = (locale), __WEBPACK_AMD_DEFINE_RESULT__ = (typeof __WEBPACK_AMD_DEFINE_FACTORY__ === 'function' ? (__WEBPACK_AMD_DEFINE_FACTORY__.apply(exports, __WEBPACK_AMD_DEFINE_ARRAY__)) : __WEBPACK_AMD_DEFINE_FACTORY__), __WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
	    } else {
	        locale(global.date);
	    }

	}(this));



/***/ },
/* 242 */
/***/ function(module, exports, __webpack_require__) {

	var __WEBPACK_AMD_DEFINE_FACTORY__, __WEBPACK_AMD_DEFINE_ARRAY__, __WEBPACK_AMD_DEFINE_RESULT__;/**
	 * @preserve date-and-time.js locale configuration
	 * @preserve Korean (ko)
	 * @preserve It is using moment.js locale configuration as a reference.
	 */
	(function (global) {
	    'use strict';

	    var locale = function (date) {
	        date.setLocales('ko', {
	            MMMM: ['1월', '2월', '3월', '4월', '5월', '6월', '7월', '8월', '9월', '10월', '11월', '12월'],
	            MMM: ['1월', '2월', '3월', '4월', '5월', '6월', '7월', '8월', '9월', '10월', '11월', '12월'],
	            dddd: ['일요일', '월요일', '화요일', '수요일', '목요일', '금요일', '토요일'],
	            ddd: ['일', '월', '화', '수', '목', '금', '토'],
	            dd: ['일', '월', '화', '수', '목', '금', '토'],
	            A: ['오전', '오후']
	        });
	    };

	    if (typeof module === 'object' && typeof module.exports === 'object') {
	        locale(__webpack_require__(192));
	    } else if (true) {
	        !(__WEBPACK_AMD_DEFINE_ARRAY__ = [__webpack_require__(192)], __WEBPACK_AMD_DEFINE_FACTORY__ = (locale), __WEBPACK_AMD_DEFINE_RESULT__ = (typeof __WEBPACK_AMD_DEFINE_FACTORY__ === 'function' ? (__WEBPACK_AMD_DEFINE_FACTORY__.apply(exports, __WEBPACK_AMD_DEFINE_ARRAY__)) : __WEBPACK_AMD_DEFINE_FACTORY__), __WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
	    } else {
	        locale(global.date);
	    }

	}(this));



/***/ },
/* 243 */
/***/ function(module, exports, __webpack_require__) {

	var __WEBPACK_AMD_DEFINE_FACTORY__, __WEBPACK_AMD_DEFINE_ARRAY__, __WEBPACK_AMD_DEFINE_RESULT__;/**
	 * @preserve date-and-time.js locale configuration
	 * @preserve Portuguese (pt)
	 * @preserve It is using moment.js locale configuration as a reference.
	 */
	(function (global) {
	    'use strict';

	    var locale = function (date) {
	        date.setLocales('pt', {
	            MMMM: ['Janeiro', 'Fevereiro', 'Março', 'Abril', 'Maio', 'Junho', 'Julho', 'Agosto', 'Setembro', 'Outubro', 'Novembro', 'Dezembro'],
	            MMM: ['Jan', 'Fev', 'Mar', 'Abr', 'Mai', 'Jun', 'Jul', 'Ago', 'Set', 'Out', 'Nov', 'Dez'],
	            dddd: ['Domingo', 'Segunda-Feira', 'Terça-Feira', 'Quarta-Feira', 'Quinta-Feira', 'Sexta-Feira', 'Sábado'],
	            ddd: ['Dom', 'Seg', 'Ter', 'Qua', 'Qui', 'Sex', 'Sáb'],
	            dd: ['Dom', '2ª', '3ª', '4ª', '5ª', '6ª', 'Sáb'],
	            A: ['da madrugada', 'da manhã', 'da tarde', 'da noite'],
	            formats: {
	                A: function (d) {
	                    var h = d.getHours();
	                    if (h < 5) {
	                        return this.A[0];   // da madrugada
	                    } else if (h < 12) {
	                        return this.A[1];   // da manhã
	                    } else if (h < 19) {
	                        return this.A[2];   // da tarde
	                    }
	                    return this.A[3];       // da noite
	                }
	            },
	            parsers: {
	                h: function (h, a) {
	                    if (a < 2) {    // da madrugada, da manhã
	                        return h;
	                    }
	                    return h > 11 ? h : h + 12; // da tarde, da noite
	                }
	            }
	        });
	    };

	    if (typeof module === 'object' && typeof module.exports === 'object') {
	        locale(__webpack_require__(192));
	    } else if (true) {
	        !(__WEBPACK_AMD_DEFINE_ARRAY__ = [__webpack_require__(192)], __WEBPACK_AMD_DEFINE_FACTORY__ = (locale), __WEBPACK_AMD_DEFINE_RESULT__ = (typeof __WEBPACK_AMD_DEFINE_FACTORY__ === 'function' ? (__WEBPACK_AMD_DEFINE_FACTORY__.apply(exports, __WEBPACK_AMD_DEFINE_ARRAY__)) : __WEBPACK_AMD_DEFINE_FACTORY__), __WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
	    } else {
	        locale(global.date);
	    }

	}(this));



/***/ },
/* 244 */
/***/ function(module, exports, __webpack_require__) {

	var __WEBPACK_AMD_DEFINE_FACTORY__, __WEBPACK_AMD_DEFINE_ARRAY__, __WEBPACK_AMD_DEFINE_RESULT__;/**
	 * @preserve date-and-time.js locale configuration
	 * @preserve Russian (ru)
	 * @preserve It is using moment.js locale configuration as a reference.
	 */
	(function (global) {
	    'use strict';

	    var locale = function (date) {
	        date.setLocales('ru', {
	            MMMM: ['Января', 'Февраля', 'Марта', 'Апреля', 'Мая', 'Июня', 'Июля', 'Августа', 'Сентября', 'Октября', 'Ноября', 'Декабря'],
	            MMM: ['янв', 'фев', 'мар', 'апр', 'мая', 'июня', 'июля', 'авг', 'сен', 'окт', 'ноя', 'дек'],
	            dddd: ['Воскресенье', 'Понедельник', 'Вторник', 'Среду', 'Четверг', 'Пятницу', 'Субботу'],
	            ddd: ['Вс', 'Пн', 'Вт', 'Ср', 'Чт', 'Пт', 'Сб'],
	            dd: ['Вс', 'Пн', 'Вт', 'Ср', 'Чт', 'Пт', 'Сб'],
	            A: ['ночи', 'утра', 'дня', 'вечера'],
	            formats: {
	                A: function (d) {
	                    var h = d.getHours();
	                    if (h < 4) {
	                        return this.A[0];   // ночи
	                    } else if (h < 12) {
	                        return this.A[1];   // утра
	                    } else if (h < 17) {
	                        return this.A[2];   // дня
	                    }
	                    return this.A[3];       // вечера
	                }
	            },
	            parsers: {
	                h: function (h, a) {
	                    if (a < 2) {    // ночи, утра
	                        return h;
	                    }
	                    return h > 11 ? h : h + 12; // дня, вечера
	                }
	            }
	        });
	    };

	    if (typeof module === 'object' && typeof module.exports === 'object') {
	        locale(__webpack_require__(192));
	    } else if (true) {
	        !(__WEBPACK_AMD_DEFINE_ARRAY__ = [__webpack_require__(192)], __WEBPACK_AMD_DEFINE_FACTORY__ = (locale), __WEBPACK_AMD_DEFINE_RESULT__ = (typeof __WEBPACK_AMD_DEFINE_FACTORY__ === 'function' ? (__WEBPACK_AMD_DEFINE_FACTORY__.apply(exports, __WEBPACK_AMD_DEFINE_ARRAY__)) : __WEBPACK_AMD_DEFINE_FACTORY__), __WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
	    } else {
	        locale(global.date);
	    }

	}(this));



/***/ },
/* 245 */
/***/ function(module, exports, __webpack_require__) {

	var __WEBPACK_AMD_DEFINE_FACTORY__, __WEBPACK_AMD_DEFINE_ARRAY__, __WEBPACK_AMD_DEFINE_RESULT__;/**
	 * @preserve date-and-time.js locale configuration
	 * @preserve Chinese (zh-cn)
	 * @preserve It is using moment.js locale configuration as a reference.
	 */
	(function (global) {
	    'use strict';

	    var locale = function (date) {
	        date.setLocales('zh-cn', {
	            MMMM: ['一月', '二月', '三月', '四月', '五月', '六月', '七月', '八月', '九月', '十月', '十一月', '十二月'],
	            MMM: ['1月', '2月', '3月', '4月', '5月', '6月', '7月', '8月', '9月', '10月', '11月', '12月'],
	            dddd: ['星期日', '星期一', '星期二', '星期三', '星期四', '星期五', '星期六'],
	            ddd: ['周日', '周一', '周二', '周三', '周四', '周五', '周六'],
	            dd: ['日', '一', '二', '三', '四', '五', '六'],
	            A: ['凌晨', '早上', '上午', '中午', '下午', '晚上'],
	            formats: {
	                A: function (d) {
	                    var hm = d.getHours() * 100 + d.getMinutes();
	                    if (hm < 600) {
	                        return this.A[0];   // 凌晨
	                    } else if (hm < 900) {
	                        return this.A[1];   // 早上
	                    } else if (hm < 1130) {
	                        return this.A[2];   // 上午
	                    } else if (hm < 1230) {
	                        return this.A[3];   // 中午
	                    } else if (hm < 1800) {
	                        return this.A[4];   // 下午
	                    }
	                    return this.A[5];       // 晚上
	                }
	            },
	            parsers: {
	                h: function (h, a) {
	                    if (a < 4) {    // 凌晨, 早上, 上午, 中午
	                        return h;
	                    }
	                    return h > 11 ? h : h + 12; // 下午, 晚上
	                }
	            }
	        });
	    };

	    if (typeof module === 'object' && typeof module.exports === 'object') {
	        locale(__webpack_require__(192));
	    } else if (true) {
	        !(__WEBPACK_AMD_DEFINE_ARRAY__ = [__webpack_require__(192)], __WEBPACK_AMD_DEFINE_FACTORY__ = (locale), __WEBPACK_AMD_DEFINE_RESULT__ = (typeof __WEBPACK_AMD_DEFINE_FACTORY__ === 'function' ? (__WEBPACK_AMD_DEFINE_FACTORY__.apply(exports, __WEBPACK_AMD_DEFINE_ARRAY__)) : __WEBPACK_AMD_DEFINE_FACTORY__), __WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
	    } else {
	        locale(global.date);
	    }

	}(this));



/***/ },
/* 246 */
/***/ function(module, exports, __webpack_require__) {

	var __WEBPACK_AMD_DEFINE_FACTORY__, __WEBPACK_AMD_DEFINE_ARRAY__, __WEBPACK_AMD_DEFINE_RESULT__;/**
	 * @preserve date-and-time.js locale configuration
	 * @preserve Chinese (zh-tw)
	 * @preserve It is using moment.js locale configuration as a reference.
	 */
	(function (global) {
	    'use strict';

	    var locale = function (date) {
	        date.setLocales('zh-tw', {
	            MMMM: ['一月', '二月', '三月', '四月', '五月', '六月', '七月', '八月', '九月', '十月', '十一月', '十二月'],
	            MMM: ['1月', '2月', '3月', '4月', '5月', '6月', '7月', '8月', '9月', '10月', '11月', '12月'],
	            dddd: ['星期日', '星期一', '星期二', '星期三', '星期四', '星期五', '星期六'],
	            ddd: ['周日', '周一', '周二', '周三', '周四', '周五', '周六'],
	            dd: ['日', '一', '二', '三', '四', '五', '六'],
	            A: ['早上', '上午', '中午', '下午', '晚上'],
	            formats: {
	                A: function (d) {
	                    var hm = d.getHours() * 100 + d.getMinutes();
	                    if (hm < 900) {
	                        return this.A[0];   // 早上
	                    } else if (hm < 1130) {
	                        return this.A[1];   // 上午
	                    } else if (hm < 1230) {
	                        return this.A[2];   // 中午
	                    } else if (hm < 1800) {
	                        return this.A[3];   // 下午
	                    }
	                    return this.A[4];       // 晚上
	                }
	            },
	            parsers: {
	                h: function (h, a) {
	                    if (a < 3) {    // 早上, 上午, 中午
	                        return h;
	                    }
	                    return h > 11 ? h : h + 12; // 下午, 晚上
	                }
	            }
	        });
	    };

	    if (typeof module === 'object' && typeof module.exports === 'object') {
	        locale(__webpack_require__(192));
	    } else if (true) {
	        !(__WEBPACK_AMD_DEFINE_ARRAY__ = [__webpack_require__(192)], __WEBPACK_AMD_DEFINE_FACTORY__ = (locale), __WEBPACK_AMD_DEFINE_RESULT__ = (typeof __WEBPACK_AMD_DEFINE_FACTORY__ === 'function' ? (__WEBPACK_AMD_DEFINE_FACTORY__.apply(exports, __WEBPACK_AMD_DEFINE_ARRAY__)) : __WEBPACK_AMD_DEFINE_FACTORY__), __WEBPACK_AMD_DEFINE_RESULT__ !== undefined && (module.exports = __WEBPACK_AMD_DEFINE_RESULT__));
	    } else {
	        locale(global.date);
	    }

	}(this));



/***/ },
/* 247 */
/***/ function(module, exports, __webpack_require__) {

	"use strict";

	// rawAsap provides everything we need except exception management.
	var rawAsap = __webpack_require__(231);
	// RawTasks are recycled to reduce GC churn.
	var freeTasks = [];
	// We queue errors to ensure they are thrown in right order (FIFO).
	// Array-as-queue is good enough here, since we are just dealing with exceptions.
	var pendingErrors = [];
	var requestErrorThrow = rawAsap.makeRequestCallFromTimer(throwFirstError);

	function throwFirstError() {
	    if (pendingErrors.length) {
	        throw pendingErrors.shift();
	    }
	}

	/**
	 * Calls a task as soon as possible after returning, in its own event, with priority
	 * over other events like animation, reflow, and repaint. An error thrown from an
	 * event will not interrupt, nor even substantially slow down the processing of
	 * other events, but will be rather postponed to a lower priority event.
	 * @param {{call}} task A callable object, typically a function that takes no
	 * arguments.
	 */
	module.exports = asap;
	function asap(task) {
	    var rawTask;
	    if (freeTasks.length) {
	        rawTask = freeTasks.pop();
	    } else {
	        rawTask = new RawTask();
	    }
	    rawTask.task = task;
	    rawAsap(rawTask);
	}

	// We wrap tasks with recyclable task objects.  A task object implements
	// `call`, just like a function.
	function RawTask() {
	    this.task = null;
	}

	// The sole purpose of wrapping the task is to catch the exception and recycle
	// the task object after its single use.
	RawTask.prototype.call = function () {
	    try {
	        this.task.call();
	    } catch (error) {
	        if (asap.onerror) {
	            // This hook exists purely for testing purposes.
	            // Its name will be periodically randomized to break any code that
	            // depends on its existence.
	            asap.onerror(error);
	        } else {
	            // In a web browser, exceptions are not fatal. However, to avoid
	            // slowing down the queue of pending tasks, we rethrow the error in a
	            // lower priority turn.
	            pendingErrors.push(error);
	            requestErrorThrow();
	        }
	    } finally {
	        this.task = null;
	        freeTasks[freeTasks.length] = this;
	    }
	};


/***/ },
/* 248 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(process) {// Copyright Joyent, Inc. and other Node contributors.
	//
	// Permission is hereby granted, free of charge, to any person obtaining a
	// copy of this software and associated documentation files (the
	// "Software"), to deal in the Software without restriction, including
	// without limitation the rights to use, copy, modify, merge, publish,
	// distribute, sublicense, and/or sell copies of the Software, and to permit
	// persons to whom the Software is furnished to do so, subject to the
	// following conditions:
	//
	// The above copyright notice and this permission notice shall be included
	// in all copies or substantial portions of the Software.
	//
	// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
	// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
	// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
	// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
	// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
	// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
	// USE OR OTHER DEALINGS IN THE SOFTWARE.

	module.exports = Readable;

	/*<replacement>*/
	var isArray = __webpack_require__(320);
	/*</replacement>*/


	/*<replacement>*/
	var Buffer = __webpack_require__(87).Buffer;
	/*</replacement>*/

	Readable.ReadableState = ReadableState;

	var EE = __webpack_require__(194).EventEmitter;

	/*<replacement>*/
	if (!EE.listenerCount) EE.listenerCount = function(emitter, type) {
	  return emitter.listeners(type).length;
	};
	/*</replacement>*/

	var Stream = __webpack_require__(165);

	/*<replacement>*/
	var util = __webpack_require__(322);
	util.inherits = __webpack_require__(321);
	/*</replacement>*/

	var StringDecoder;


	/*<replacement>*/
	var debug = __webpack_require__(257);
	if (debug && debug.debuglog) {
	  debug = debug.debuglog('stream');
	} else {
	  debug = function () {};
	}
	/*</replacement>*/


	util.inherits(Readable, Stream);

	function ReadableState(options, stream) {
	  var Duplex = __webpack_require__(250);

	  options = options || {};

	  // the point at which it stops calling _read() to fill the buffer
	  // Note: 0 is a valid value, means "don't call _read preemptively ever"
	  var hwm = options.highWaterMark;
	  var defaultHwm = options.objectMode ? 16 : 16 * 1024;
	  this.highWaterMark = (hwm || hwm === 0) ? hwm : defaultHwm;

	  // cast to ints.
	  this.highWaterMark = ~~this.highWaterMark;

	  this.buffer = [];
	  this.length = 0;
	  this.pipes = null;
	  this.pipesCount = 0;
	  this.flowing = null;
	  this.ended = false;
	  this.endEmitted = false;
	  this.reading = false;

	  // a flag to be able to tell if the onwrite cb is called immediately,
	  // or on a later tick.  We set this to true at first, because any
	  // actions that shouldn't happen until "later" should generally also
	  // not happen before the first write call.
	  this.sync = true;

	  // whenever we return null, then we set a flag to say
	  // that we're awaiting a 'readable' event emission.
	  this.needReadable = false;
	  this.emittedReadable = false;
	  this.readableListening = false;


	  // object stream flag. Used to make read(n) ignore n and to
	  // make all the buffer merging and length checks go away
	  this.objectMode = !!options.objectMode;

	  if (stream instanceof Duplex)
	    this.objectMode = this.objectMode || !!options.readableObjectMode;

	  // Crypto is kind of old and crusty.  Historically, its default string
	  // encoding is 'binary' so we have to make this configurable.
	  // Everything else in the universe uses 'utf8', though.
	  this.defaultEncoding = options.defaultEncoding || 'utf8';

	  // when piping, we only care about 'readable' events that happen
	  // after read()ing all the bytes and not getting any pushback.
	  this.ranOut = false;

	  // the number of writers that are awaiting a drain event in .pipe()s
	  this.awaitDrain = 0;

	  // if true, a maybeReadMore has been scheduled
	  this.readingMore = false;

	  this.decoder = null;
	  this.encoding = null;
	  if (options.encoding) {
	    if (!StringDecoder)
	      StringDecoder = __webpack_require__(258).StringDecoder;
	    this.decoder = new StringDecoder(options.encoding);
	    this.encoding = options.encoding;
	  }
	}

	function Readable(options) {
	  var Duplex = __webpack_require__(250);

	  if (!(this instanceof Readable))
	    return new Readable(options);

	  this._readableState = new ReadableState(options, this);

	  // legacy
	  this.readable = true;

	  Stream.call(this);
	}

	// Manually shove something into the read() buffer.
	// This returns true if the highWaterMark has not been hit yet,
	// similar to how Writable.write() returns true if you should
	// write() some more.
	Readable.prototype.push = function(chunk, encoding) {
	  var state = this._readableState;

	  if (util.isString(chunk) && !state.objectMode) {
	    encoding = encoding || state.defaultEncoding;
	    if (encoding !== state.encoding) {
	      chunk = new Buffer(chunk, encoding);
	      encoding = '';
	    }
	  }

	  return readableAddChunk(this, state, chunk, encoding, false);
	};

	// Unshift should *always* be something directly out of read()
	Readable.prototype.unshift = function(chunk) {
	  var state = this._readableState;
	  return readableAddChunk(this, state, chunk, '', true);
	};

	function readableAddChunk(stream, state, chunk, encoding, addToFront) {
	  var er = chunkInvalid(state, chunk);
	  if (er) {
	    stream.emit('error', er);
	  } else if (util.isNullOrUndefined(chunk)) {
	    state.reading = false;
	    if (!state.ended)
	      onEofChunk(stream, state);
	  } else if (state.objectMode || chunk && chunk.length > 0) {
	    if (state.ended && !addToFront) {
	      var e = new Error('stream.push() after EOF');
	      stream.emit('error', e);
	    } else if (state.endEmitted && addToFront) {
	      var e = new Error('stream.unshift() after end event');
	      stream.emit('error', e);
	    } else {
	      if (state.decoder && !addToFront && !encoding)
	        chunk = state.decoder.write(chunk);

	      if (!addToFront)
	        state.reading = false;

	      // if we want the data now, just emit it.
	      if (state.flowing && state.length === 0 && !state.sync) {
	        stream.emit('data', chunk);
	        stream.read(0);
	      } else {
	        // update the buffer info.
	        state.length += state.objectMode ? 1 : chunk.length;
	        if (addToFront)
	          state.buffer.unshift(chunk);
	        else
	          state.buffer.push(chunk);

	        if (state.needReadable)
	          emitReadable(stream);
	      }

	      maybeReadMore(stream, state);
	    }
	  } else if (!addToFront) {
	    state.reading = false;
	  }

	  return needMoreData(state);
	}



	// if it's past the high water mark, we can push in some more.
	// Also, if we have no data yet, we can stand some
	// more bytes.  This is to work around cases where hwm=0,
	// such as the repl.  Also, if the push() triggered a
	// readable event, and the user called read(largeNumber) such that
	// needReadable was set, then we ought to push more, so that another
	// 'readable' event will be triggered.
	function needMoreData(state) {
	  return !state.ended &&
	         (state.needReadable ||
	          state.length < state.highWaterMark ||
	          state.length === 0);
	}

	// backwards compatibility.
	Readable.prototype.setEncoding = function(enc) {
	  if (!StringDecoder)
	    StringDecoder = __webpack_require__(258).StringDecoder;
	  this._readableState.decoder = new StringDecoder(enc);
	  this._readableState.encoding = enc;
	  return this;
	};

	// Don't raise the hwm > 128MB
	var MAX_HWM = 0x800000;
	function roundUpToNextPowerOf2(n) {
	  if (n >= MAX_HWM) {
	    n = MAX_HWM;
	  } else {
	    // Get the next highest power of 2
	    n--;
	    for (var p = 1; p < 32; p <<= 1) n |= n >> p;
	    n++;
	  }
	  return n;
	}

	function howMuchToRead(n, state) {
	  if (state.length === 0 && state.ended)
	    return 0;

	  if (state.objectMode)
	    return n === 0 ? 0 : 1;

	  if (isNaN(n) || util.isNull(n)) {
	    // only flow one buffer at a time
	    if (state.flowing && state.buffer.length)
	      return state.buffer[0].length;
	    else
	      return state.length;
	  }

	  if (n <= 0)
	    return 0;

	  // If we're asking for more than the target buffer level,
	  // then raise the water mark.  Bump up to the next highest
	  // power of 2, to prevent increasing it excessively in tiny
	  // amounts.
	  if (n > state.highWaterMark)
	    state.highWaterMark = roundUpToNextPowerOf2(n);

	  // don't have that much.  return null, unless we've ended.
	  if (n > state.length) {
	    if (!state.ended) {
	      state.needReadable = true;
	      return 0;
	    } else
	      return state.length;
	  }

	  return n;
	}

	// you can override either this method, or the async _read(n) below.
	Readable.prototype.read = function(n) {
	  debug('read', n);
	  var state = this._readableState;
	  var nOrig = n;

	  if (!util.isNumber(n) || n > 0)
	    state.emittedReadable = false;

	  // if we're doing read(0) to trigger a readable event, but we
	  // already have a bunch of data in the buffer, then just trigger
	  // the 'readable' event and move on.
	  if (n === 0 &&
	      state.needReadable &&
	      (state.length >= state.highWaterMark || state.ended)) {
	    debug('read: emitReadable', state.length, state.ended);
	    if (state.length === 0 && state.ended)
	      endReadable(this);
	    else
	      emitReadable(this);
	    return null;
	  }

	  n = howMuchToRead(n, state);

	  // if we've ended, and we're now clear, then finish it up.
	  if (n === 0 && state.ended) {
	    if (state.length === 0)
	      endReadable(this);
	    return null;
	  }

	  // All the actual chunk generation logic needs to be
	  // *below* the call to _read.  The reason is that in certain
	  // synthetic stream cases, such as passthrough streams, _read
	  // may be a completely synchronous operation which may change
	  // the state of the read buffer, providing enough data when
	  // before there was *not* enough.
	  //
	  // So, the steps are:
	  // 1. Figure out what the state of things will be after we do
	  // a read from the buffer.
	  //
	  // 2. If that resulting state will trigger a _read, then call _read.
	  // Note that this may be asynchronous, or synchronous.  Yes, it is
	  // deeply ugly to write APIs this way, but that still doesn't mean
	  // that the Readable class should behave improperly, as streams are
	  // designed to be sync/async agnostic.
	  // Take note if the _read call is sync or async (ie, if the read call
	  // has returned yet), so that we know whether or not it's safe to emit
	  // 'readable' etc.
	  //
	  // 3. Actually pull the requested chunks out of the buffer and return.

	  // if we need a readable event, then we need to do some reading.
	  var doRead = state.needReadable;
	  debug('need readable', doRead);

	  // if we currently have less than the highWaterMark, then also read some
	  if (state.length === 0 || state.length - n < state.highWaterMark) {
	    doRead = true;
	    debug('length less than watermark', doRead);
	  }

	  // however, if we've ended, then there's no point, and if we're already
	  // reading, then it's unnecessary.
	  if (state.ended || state.reading) {
	    doRead = false;
	    debug('reading or ended', doRead);
	  }

	  if (doRead) {
	    debug('do read');
	    state.reading = true;
	    state.sync = true;
	    // if the length is currently zero, then we *need* a readable event.
	    if (state.length === 0)
	      state.needReadable = true;
	    // call internal read method
	    this._read(state.highWaterMark);
	    state.sync = false;
	  }

	  // If _read pushed data synchronously, then `reading` will be false,
	  // and we need to re-evaluate how much data we can return to the user.
	  if (doRead && !state.reading)
	    n = howMuchToRead(nOrig, state);

	  var ret;
	  if (n > 0)
	    ret = fromList(n, state);
	  else
	    ret = null;

	  if (util.isNull(ret)) {
	    state.needReadable = true;
	    n = 0;
	  }

	  state.length -= n;

	  // If we have nothing in the buffer, then we want to know
	  // as soon as we *do* get something into the buffer.
	  if (state.length === 0 && !state.ended)
	    state.needReadable = true;

	  // If we tried to read() past the EOF, then emit end on the next tick.
	  if (nOrig !== n && state.ended && state.length === 0)
	    endReadable(this);

	  if (!util.isNull(ret))
	    this.emit('data', ret);

	  return ret;
	};

	function chunkInvalid(state, chunk) {
	  var er = null;
	  if (!util.isBuffer(chunk) &&
	      !util.isString(chunk) &&
	      !util.isNullOrUndefined(chunk) &&
	      !state.objectMode) {
	    er = new TypeError('Invalid non-string/buffer chunk');
	  }
	  return er;
	}


	function onEofChunk(stream, state) {
	  if (state.decoder && !state.ended) {
	    var chunk = state.decoder.end();
	    if (chunk && chunk.length) {
	      state.buffer.push(chunk);
	      state.length += state.objectMode ? 1 : chunk.length;
	    }
	  }
	  state.ended = true;

	  // emit 'readable' now to make sure it gets picked up.
	  emitReadable(stream);
	}

	// Don't emit readable right away in sync mode, because this can trigger
	// another read() call => stack overflow.  This way, it might trigger
	// a nextTick recursion warning, but that's not so bad.
	function emitReadable(stream) {
	  var state = stream._readableState;
	  state.needReadable = false;
	  if (!state.emittedReadable) {
	    debug('emitReadable', state.flowing);
	    state.emittedReadable = true;
	    if (state.sync)
	      process.nextTick(function() {
	        emitReadable_(stream);
	      });
	    else
	      emitReadable_(stream);
	  }
	}

	function emitReadable_(stream) {
	  debug('emit readable');
	  stream.emit('readable');
	  flow(stream);
	}


	// at this point, the user has presumably seen the 'readable' event,
	// and called read() to consume some data.  that may have triggered
	// in turn another _read(n) call, in which case reading = true if
	// it's in progress.
	// However, if we're not ended, or reading, and the length < hwm,
	// then go ahead and try to read some more preemptively.
	function maybeReadMore(stream, state) {
	  if (!state.readingMore) {
	    state.readingMore = true;
	    process.nextTick(function() {
	      maybeReadMore_(stream, state);
	    });
	  }
	}

	function maybeReadMore_(stream, state) {
	  var len = state.length;
	  while (!state.reading && !state.flowing && !state.ended &&
	         state.length < state.highWaterMark) {
	    debug('maybeReadMore read 0');
	    stream.read(0);
	    if (len === state.length)
	      // didn't get any data, stop spinning.
	      break;
	    else
	      len = state.length;
	  }
	  state.readingMore = false;
	}

	// abstract method.  to be overridden in specific implementation classes.
	// call cb(er, data) where data is <= n in length.
	// for virtual (non-string, non-buffer) streams, "length" is somewhat
	// arbitrary, and perhaps not very meaningful.
	Readable.prototype._read = function(n) {
	  this.emit('error', new Error('not implemented'));
	};

	Readable.prototype.pipe = function(dest, pipeOpts) {
	  var src = this;
	  var state = this._readableState;

	  switch (state.pipesCount) {
	    case 0:
	      state.pipes = dest;
	      break;
	    case 1:
	      state.pipes = [state.pipes, dest];
	      break;
	    default:
	      state.pipes.push(dest);
	      break;
	  }
	  state.pipesCount += 1;
	  debug('pipe count=%d opts=%j', state.pipesCount, pipeOpts);

	  var doEnd = (!pipeOpts || pipeOpts.end !== false) &&
	              dest !== process.stdout &&
	              dest !== process.stderr;

	  var endFn = doEnd ? onend : cleanup;
	  if (state.endEmitted)
	    process.nextTick(endFn);
	  else
	    src.once('end', endFn);

	  dest.on('unpipe', onunpipe);
	  function onunpipe(readable) {
	    debug('onunpipe');
	    if (readable === src) {
	      cleanup();
	    }
	  }

	  function onend() {
	    debug('onend');
	    dest.end();
	  }

	  // when the dest drains, it reduces the awaitDrain counter
	  // on the source.  This would be more elegant with a .once()
	  // handler in flow(), but adding and removing repeatedly is
	  // too slow.
	  var ondrain = pipeOnDrain(src);
	  dest.on('drain', ondrain);

	  function cleanup() {
	    debug('cleanup');
	    // cleanup event handlers once the pipe is broken
	    dest.removeListener('close', onclose);
	    dest.removeListener('finish', onfinish);
	    dest.removeListener('drain', ondrain);
	    dest.removeListener('error', onerror);
	    dest.removeListener('unpipe', onunpipe);
	    src.removeListener('end', onend);
	    src.removeListener('end', cleanup);
	    src.removeListener('data', ondata);

	    // if the reader is waiting for a drain event from this
	    // specific writer, then it would cause it to never start
	    // flowing again.
	    // So, if this is awaiting a drain, then we just call it now.
	    // If we don't know, then assume that we are waiting for one.
	    if (state.awaitDrain &&
	        (!dest._writableState || dest._writableState.needDrain))
	      ondrain();
	  }

	  src.on('data', ondata);
	  function ondata(chunk) {
	    debug('ondata');
	    var ret = dest.write(chunk);
	    if (false === ret) {
	      debug('false write response, pause',
	            src._readableState.awaitDrain);
	      src._readableState.awaitDrain++;
	      src.pause();
	    }
	  }

	  // if the dest has an error, then stop piping into it.
	  // however, don't suppress the throwing behavior for this.
	  function onerror(er) {
	    debug('onerror', er);
	    unpipe();
	    dest.removeListener('error', onerror);
	    if (EE.listenerCount(dest, 'error') === 0)
	      dest.emit('error', er);
	  }
	  // This is a brutally ugly hack to make sure that our error handler
	  // is attached before any userland ones.  NEVER DO THIS.
	  if (!dest._events || !dest._events.error)
	    dest.on('error', onerror);
	  else if (isArray(dest._events.error))
	    dest._events.error.unshift(onerror);
	  else
	    dest._events.error = [onerror, dest._events.error];



	  // Both close and finish should trigger unpipe, but only once.
	  function onclose() {
	    dest.removeListener('finish', onfinish);
	    unpipe();
	  }
	  dest.once('close', onclose);
	  function onfinish() {
	    debug('onfinish');
	    dest.removeListener('close', onclose);
	    unpipe();
	  }
	  dest.once('finish', onfinish);

	  function unpipe() {
	    debug('unpipe');
	    src.unpipe(dest);
	  }

	  // tell the dest that it's being piped to
	  dest.emit('pipe', src);

	  // start the flow if it hasn't been started already.
	  if (!state.flowing) {
	    debug('pipe resume');
	    src.resume();
	  }

	  return dest;
	};

	function pipeOnDrain(src) {
	  return function() {
	    var state = src._readableState;
	    debug('pipeOnDrain', state.awaitDrain);
	    if (state.awaitDrain)
	      state.awaitDrain--;
	    if (state.awaitDrain === 0 && EE.listenerCount(src, 'data')) {
	      state.flowing = true;
	      flow(src);
	    }
	  };
	}


	Readable.prototype.unpipe = function(dest) {
	  var state = this._readableState;

	  // if we're not piping anywhere, then do nothing.
	  if (state.pipesCount === 0)
	    return this;

	  // just one destination.  most common case.
	  if (state.pipesCount === 1) {
	    // passed in one, but it's not the right one.
	    if (dest && dest !== state.pipes)
	      return this;

	    if (!dest)
	      dest = state.pipes;

	    // got a match.
	    state.pipes = null;
	    state.pipesCount = 0;
	    state.flowing = false;
	    if (dest)
	      dest.emit('unpipe', this);
	    return this;
	  }

	  // slow case. multiple pipe destinations.

	  if (!dest) {
	    // remove all.
	    var dests = state.pipes;
	    var len = state.pipesCount;
	    state.pipes = null;
	    state.pipesCount = 0;
	    state.flowing = false;

	    for (var i = 0; i < len; i++)
	      dests[i].emit('unpipe', this);
	    return this;
	  }

	  // try to find the right one.
	  var i = indexOf(state.pipes, dest);
	  if (i === -1)
	    return this;

	  state.pipes.splice(i, 1);
	  state.pipesCount -= 1;
	  if (state.pipesCount === 1)
	    state.pipes = state.pipes[0];

	  dest.emit('unpipe', this);

	  return this;
	};

	// set up data events if they are asked for
	// Ensure readable listeners eventually get something
	Readable.prototype.on = function(ev, fn) {
	  var res = Stream.prototype.on.call(this, ev, fn);

	  // If listening to data, and it has not explicitly been paused,
	  // then call resume to start the flow of data on the next tick.
	  if (ev === 'data' && false !== this._readableState.flowing) {
	    this.resume();
	  }

	  if (ev === 'readable' && this.readable) {
	    var state = this._readableState;
	    if (!state.readableListening) {
	      state.readableListening = true;
	      state.emittedReadable = false;
	      state.needReadable = true;
	      if (!state.reading) {
	        var self = this;
	        process.nextTick(function() {
	          debug('readable nexttick read 0');
	          self.read(0);
	        });
	      } else if (state.length) {
	        emitReadable(this, state);
	      }
	    }
	  }

	  return res;
	};
	Readable.prototype.addListener = Readable.prototype.on;

	// pause() and resume() are remnants of the legacy readable stream API
	// If the user uses them, then switch into old mode.
	Readable.prototype.resume = function() {
	  var state = this._readableState;
	  if (!state.flowing) {
	    debug('resume');
	    state.flowing = true;
	    if (!state.reading) {
	      debug('resume read 0');
	      this.read(0);
	    }
	    resume(this, state);
	  }
	  return this;
	};

	function resume(stream, state) {
	  if (!state.resumeScheduled) {
	    state.resumeScheduled = true;
	    process.nextTick(function() {
	      resume_(stream, state);
	    });
	  }
	}

	function resume_(stream, state) {
	  state.resumeScheduled = false;
	  stream.emit('resume');
	  flow(stream);
	  if (state.flowing && !state.reading)
	    stream.read(0);
	}

	Readable.prototype.pause = function() {
	  debug('call pause flowing=%j', this._readableState.flowing);
	  if (false !== this._readableState.flowing) {
	    debug('pause');
	    this._readableState.flowing = false;
	    this.emit('pause');
	  }
	  return this;
	};

	function flow(stream) {
	  var state = stream._readableState;
	  debug('flow', state.flowing);
	  if (state.flowing) {
	    do {
	      var chunk = stream.read();
	    } while (null !== chunk && state.flowing);
	  }
	}

	// wrap an old-style stream as the async data source.
	// This is *not* part of the readable stream interface.
	// It is an ugly unfortunate mess of history.
	Readable.prototype.wrap = function(stream) {
	  var state = this._readableState;
	  var paused = false;

	  var self = this;
	  stream.on('end', function() {
	    debug('wrapped end');
	    if (state.decoder && !state.ended) {
	      var chunk = state.decoder.end();
	      if (chunk && chunk.length)
	        self.push(chunk);
	    }

	    self.push(null);
	  });

	  stream.on('data', function(chunk) {
	    debug('wrapped data');
	    if (state.decoder)
	      chunk = state.decoder.write(chunk);
	    if (!chunk || !state.objectMode && !chunk.length)
	      return;

	    var ret = self.push(chunk);
	    if (!ret) {
	      paused = true;
	      stream.pause();
	    }
	  });

	  // proxy all the other methods.
	  // important when wrapping filters and duplexes.
	  for (var i in stream) {
	    if (util.isFunction(stream[i]) && util.isUndefined(this[i])) {
	      this[i] = function(method) { return function() {
	        return stream[method].apply(stream, arguments);
	      }}(i);
	    }
	  }

	  // proxy certain important events.
	  var events = ['error', 'close', 'destroy', 'pause', 'resume'];
	  forEach(events, function(ev) {
	    stream.on(ev, self.emit.bind(self, ev));
	  });

	  // when we try to consume some more bytes, simply unpause the
	  // underlying stream.
	  self._read = function(n) {
	    debug('wrapped _read', n);
	    if (paused) {
	      paused = false;
	      stream.resume();
	    }
	  };

	  return self;
	};



	// exposed for testing purposes only.
	Readable._fromList = fromList;

	// Pluck off n bytes from an array of buffers.
	// Length is the combined lengths of all the buffers in the list.
	function fromList(n, state) {
	  var list = state.buffer;
	  var length = state.length;
	  var stringMode = !!state.decoder;
	  var objectMode = !!state.objectMode;
	  var ret;

	  // nothing in the list, definitely empty.
	  if (list.length === 0)
	    return null;

	  if (length === 0)
	    ret = null;
	  else if (objectMode)
	    ret = list.shift();
	  else if (!n || n >= length) {
	    // read it all, truncate the array.
	    if (stringMode)
	      ret = list.join('');
	    else
	      ret = Buffer.concat(list, length);
	    list.length = 0;
	  } else {
	    // read just some of it.
	    if (n < list[0].length) {
	      // just take a part of the first list item.
	      // slice is the same for buffers and strings.
	      var buf = list[0];
	      ret = buf.slice(0, n);
	      list[0] = buf.slice(n);
	    } else if (n === list[0].length) {
	      // first list is a perfect match
	      ret = list.shift();
	    } else {
	      // complex case.
	      // we have enough to cover it, but it spans past the first buffer.
	      if (stringMode)
	        ret = '';
	      else
	        ret = new Buffer(n);

	      var c = 0;
	      for (var i = 0, l = list.length; i < l && c < n; i++) {
	        var buf = list[0];
	        var cpy = Math.min(n - c, buf.length);

	        if (stringMode)
	          ret += buf.slice(0, cpy);
	        else
	          buf.copy(ret, c, 0, cpy);

	        if (cpy < buf.length)
	          list[0] = buf.slice(cpy);
	        else
	          list.shift();

	        c += cpy;
	      }
	    }
	  }

	  return ret;
	}

	function endReadable(stream) {
	  var state = stream._readableState;

	  // If we get here before consuming all the bytes, then that is a
	  // bug in node.  Should never happen.
	  if (state.length > 0)
	    throw new Error('endReadable called on non-empty stream');

	  if (!state.endEmitted) {
	    state.ended = true;
	    process.nextTick(function() {
	      // Check that we didn't get one last unshift.
	      if (!state.endEmitted && state.length === 0) {
	        state.endEmitted = true;
	        stream.readable = false;
	        stream.emit('end');
	      }
	    });
	  }
	}

	function forEach (xs, f) {
	  for (var i = 0, l = xs.length; i < l; i++) {
	    f(xs[i], i);
	  }
	}

	function indexOf (xs, x) {
	  for (var i = 0, l = xs.length; i < l; i++) {
	    if (xs[i] === x) return i;
	  }
	  return -1;
	}
	
	/* WEBPACK VAR INJECTION */}.call(exports, __webpack_require__(56)))

/***/ },
/* 249 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(process) {// Copyright Joyent, Inc. and other Node contributors.
	//
	// Permission is hereby granted, free of charge, to any person obtaining a
	// copy of this software and associated documentation files (the
	// "Software"), to deal in the Software without restriction, including
	// without limitation the rights to use, copy, modify, merge, publish,
	// distribute, sublicense, and/or sell copies of the Software, and to permit
	// persons to whom the Software is furnished to do so, subject to the
	// following conditions:
	//
	// The above copyright notice and this permission notice shall be included
	// in all copies or substantial portions of the Software.
	//
	// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
	// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
	// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
	// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
	// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
	// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
	// USE OR OTHER DEALINGS IN THE SOFTWARE.

	// A bit simpler than readable streams.
	// Implement an async ._write(chunk, cb), and it'll handle all
	// the drain event emission and buffering.

	module.exports = Writable;

	/*<replacement>*/
	var Buffer = __webpack_require__(87).Buffer;
	/*</replacement>*/

	Writable.WritableState = WritableState;


	/*<replacement>*/
	var util = __webpack_require__(322);
	util.inherits = __webpack_require__(321);
	/*</replacement>*/

	var Stream = __webpack_require__(165);

	util.inherits(Writable, Stream);

	function WriteReq(chunk, encoding, cb) {
	  this.chunk = chunk;
	  this.encoding = encoding;
	  this.callback = cb;
	}

	function WritableState(options, stream) {
	  var Duplex = __webpack_require__(250);

	  options = options || {};

	  // the point at which write() starts returning false
	  // Note: 0 is a valid value, means that we always return false if
	  // the entire buffer is not flushed immediately on write()
	  var hwm = options.highWaterMark;
	  var defaultHwm = options.objectMode ? 16 : 16 * 1024;
	  this.highWaterMark = (hwm || hwm === 0) ? hwm : defaultHwm;

	  // object stream flag to indicate whether or not this stream
	  // contains buffers or objects.
	  this.objectMode = !!options.objectMode;

	  if (stream instanceof Duplex)
	    this.objectMode = this.objectMode || !!options.writableObjectMode;

	  // cast to ints.
	  this.highWaterMark = ~~this.highWaterMark;

	  this.needDrain = false;
	  // at the start of calling end()
	  this.ending = false;
	  // when end() has been called, and returned
	  this.ended = false;
	  // when 'finish' is emitted
	  this.finished = false;

	  // should we decode strings into buffers before passing to _write?
	  // this is here so that some node-core streams can optimize string
	  // handling at a lower level.
	  var noDecode = options.decodeStrings === false;
	  this.decodeStrings = !noDecode;

	  // Crypto is kind of old and crusty.  Historically, its default string
	  // encoding is 'binary' so we have to make this configurable.
	  // Everything else in the universe uses 'utf8', though.
	  this.defaultEncoding = options.defaultEncoding || 'utf8';

	  // not an actual buffer we keep track of, but a measurement
	  // of how much we're waiting to get pushed to some underlying
	  // socket or file.
	  this.length = 0;

	  // a flag to see when we're in the middle of a write.
	  this.writing = false;

	  // when true all writes will be buffered until .uncork() call
	  this.corked = 0;

	  // a flag to be able to tell if the onwrite cb is called immediately,
	  // or on a later tick.  We set this to true at first, because any
	  // actions that shouldn't happen until "later" should generally also
	  // not happen before the first write call.
	  this.sync = true;

	  // a flag to know if we're processing previously buffered items, which
	  // may call the _write() callback in the same tick, so that we don't
	  // end up in an overlapped onwrite situation.
	  this.bufferProcessing = false;

	  // the callback that's passed to _write(chunk,cb)
	  this.onwrite = function(er) {
	    onwrite(stream, er);
	  };

	  // the callback that the user supplies to write(chunk,encoding,cb)
	  this.writecb = null;

	  // the amount that is being written when _write is called.
	  this.writelen = 0;

	  this.buffer = [];

	  // number of pending user-supplied write callbacks
	  // this must be 0 before 'finish' can be emitted
	  this.pendingcb = 0;

	  // emit prefinish if the only thing we're waiting for is _write cbs
	  // This is relevant for synchronous Transform streams
	  this.prefinished = false;

	  // True if the error was already emitted and should not be thrown again
	  this.errorEmitted = false;
	}

	function Writable(options) {
	  var Duplex = __webpack_require__(250);

	  // Writable ctor is applied to Duplexes, though they're not
	  // instanceof Writable, they're instanceof Readable.
	  if (!(this instanceof Writable) && !(this instanceof Duplex))
	    return new Writable(options);

	  this._writableState = new WritableState(options, this);

	  // legacy.
	  this.writable = true;

	  Stream.call(this);
	}

	// Otherwise people can pipe Writable streams, which is just wrong.
	Writable.prototype.pipe = function() {
	  this.emit('error', new Error('Cannot pipe. Not readable.'));
	};


	function writeAfterEnd(stream, state, cb) {
	  var er = new Error('write after end');
	  // TODO: defer error events consistently everywhere, not just the cb
	  stream.emit('error', er);
	  process.nextTick(function() {
	    cb(er);
	  });
	}

	// If we get something that is not a buffer, string, null, or undefined,
	// and we're not in objectMode, then that's an error.
	// Otherwise stream chunks are all considered to be of length=1, and the
	// watermarks determine how many objects to keep in the buffer, rather than
	// how many bytes or characters.
	function validChunk(stream, state, chunk, cb) {
	  var valid = true;
	  if (!util.isBuffer(chunk) &&
	      !util.isString(chunk) &&
	      !util.isNullOrUndefined(chunk) &&
	      !state.objectMode) {
	    var er = new TypeError('Invalid non-string/buffer chunk');
	    stream.emit('error', er);
	    process.nextTick(function() {
	      cb(er);
	    });
	    valid = false;
	  }
	  return valid;
	}

	Writable.prototype.write = function(chunk, encoding, cb) {
	  var state = this._writableState;
	  var ret = false;

	  if (util.isFunction(encoding)) {
	    cb = encoding;
	    encoding = null;
	  }

	  if (util.isBuffer(chunk))
	    encoding = 'buffer';
	  else if (!encoding)
	    encoding = state.defaultEncoding;

	  if (!util.isFunction(cb))
	    cb = function() {};

	  if (state.ended)
	    writeAfterEnd(this, state, cb);
	  else if (validChunk(this, state, chunk, cb)) {
	    state.pendingcb++;
	    ret = writeOrBuffer(this, state, chunk, encoding, cb);
	  }

	  return ret;
	};

	Writable.prototype.cork = function() {
	  var state = this._writableState;

	  state.corked++;
	};

	Writable.prototype.uncork = function() {
	  var state = this._writableState;

	  if (state.corked) {
	    state.corked--;

	    if (!state.writing &&
	        !state.corked &&
	        !state.finished &&
	        !state.bufferProcessing &&
	        state.buffer.length)
	      clearBuffer(this, state);
	  }
	};

	function decodeChunk(state, chunk, encoding) {
	  if (!state.objectMode &&
	      state.decodeStrings !== false &&
	      util.isString(chunk)) {
	    chunk = new Buffer(chunk, encoding);
	  }
	  return chunk;
	}

	// if we're already writing something, then just put this
	// in the queue, and wait our turn.  Otherwise, call _write
	// If we return false, then we need a drain event, so set that flag.
	function writeOrBuffer(stream, state, chunk, encoding, cb) {
	  chunk = decodeChunk(state, chunk, encoding);
	  if (util.isBuffer(chunk))
	    encoding = 'buffer';
	  var len = state.objectMode ? 1 : chunk.length;

	  state.length += len;

	  var ret = state.length < state.highWaterMark;
	  // we must ensure that previous needDrain will not be reset to false.
	  if (!ret)
	    state.needDrain = true;

	  if (state.writing || state.corked)
	    state.buffer.push(new WriteReq(chunk, encoding, cb));
	  else
	    doWrite(stream, state, false, len, chunk, encoding, cb);

	  return ret;
	}

	function doWrite(stream, state, writev, len, chunk, encoding, cb) {
	  state.writelen = len;
	  state.writecb = cb;
	  state.writing = true;
	  state.sync = true;
	  if (writev)
	    stream._writev(chunk, state.onwrite);
	  else
	    stream._write(chunk, encoding, state.onwrite);
	  state.sync = false;
	}

	function onwriteError(stream, state, sync, er, cb) {
	  if (sync)
	    process.nextTick(function() {
	      state.pendingcb--;
	      cb(er);
	    });
	  else {
	    state.pendingcb--;
	    cb(er);
	  }

	  stream._writableState.errorEmitted = true;
	  stream.emit('error', er);
	}

	function onwriteStateUpdate(state) {
	  state.writing = false;
	  state.writecb = null;
	  state.length -= state.writelen;
	  state.writelen = 0;
	}

	function onwrite(stream, er) {
	  var state = stream._writableState;
	  var sync = state.sync;
	  var cb = state.writecb;

	  onwriteStateUpdate(state);

	  if (er)
	    onwriteError(stream, state, sync, er, cb);
	  else {
	    // Check if we're actually ready to finish, but don't emit yet
	    var finished = needFinish(stream, state);

	    if (!finished &&
	        !state.corked &&
	        !state.bufferProcessing &&
	        state.buffer.length) {
	      clearBuffer(stream, state);
	    }

	    if (sync) {
	      process.nextTick(function() {
	        afterWrite(stream, state, finished, cb);
	      });
	    } else {
	      afterWrite(stream, state, finished, cb);
	    }
	  }
	}

	function afterWrite(stream, state, finished, cb) {
	  if (!finished)
	    onwriteDrain(stream, state);
	  state.pendingcb--;
	  cb();
	  finishMaybe(stream, state);
	}

	// Must force callback to be called on nextTick, so that we don't
	// emit 'drain' before the write() consumer gets the 'false' return
	// value, and has a chance to attach a 'drain' listener.
	function onwriteDrain(stream, state) {
	  if (state.length === 0 && state.needDrain) {
	    state.needDrain = false;
	    stream.emit('drain');
	  }
	}


	// if there's something in the buffer waiting, then process it
	function clearBuffer(stream, state) {
	  state.bufferProcessing = true;

	  if (stream._writev && state.buffer.length > 1) {
	    // Fast case, write everything using _writev()
	    var cbs = [];
	    for (var c = 0; c < state.buffer.length; c++)
	      cbs.push(state.buffer[c].callback);

	    // count the one we are adding, as well.
	    // TODO(isaacs) clean this up
	    state.pendingcb++;
	    doWrite(stream, state, true, state.length, state.buffer, '', function(err) {
	      for (var i = 0; i < cbs.length; i++) {
	        state.pendingcb--;
	        cbs[i](err);
	      }
	    });

	    // Clear buffer
	    state.buffer = [];
	  } else {
	    // Slow case, write chunks one-by-one
	    for (var c = 0; c < state.buffer.length; c++) {
	      var entry = state.buffer[c];
	      var chunk = entry.chunk;
	      var encoding = entry.encoding;
	      var cb = entry.callback;
	      var len = state.objectMode ? 1 : chunk.length;

	      doWrite(stream, state, false, len, chunk, encoding, cb);

	      // if we didn't call the onwrite immediately, then
	      // it means that we need to wait until it does.
	      // also, that means that the chunk and cb are currently
	      // being processed, so move the buffer counter past them.
	      if (state.writing) {
	        c++;
	        break;
	      }
	    }

	    if (c < state.buffer.length)
	      state.buffer = state.buffer.slice(c);
	    else
	      state.buffer.length = 0;
	  }

	  state.bufferProcessing = false;
	}

	Writable.prototype._write = function(chunk, encoding, cb) {
	  cb(new Error('not implemented'));

	};

	Writable.prototype._writev = null;

	Writable.prototype.end = function(chunk, encoding, cb) {
	  var state = this._writableState;

	  if (util.isFunction(chunk)) {
	    cb = chunk;
	    chunk = null;
	    encoding = null;
	  } else if (util.isFunction(encoding)) {
	    cb = encoding;
	    encoding = null;
	  }

	  if (!util.isNullOrUndefined(chunk))
	    this.write(chunk, encoding);

	  // .end() fully uncorks
	  if (state.corked) {
	    state.corked = 1;
	    this.uncork();
	  }

	  // ignore unnecessary end() calls.
	  if (!state.ending && !state.finished)
	    endWritable(this, state, cb);
	};


	function needFinish(stream, state) {
	  return (state.ending &&
	          state.length === 0 &&
	          !state.finished &&
	          !state.writing);
	}

	function prefinish(stream, state) {
	  if (!state.prefinished) {
	    state.prefinished = true;
	    stream.emit('prefinish');
	  }
	}

	function finishMaybe(stream, state) {
	  var need = needFinish(stream, state);
	  if (need) {
	    if (state.pendingcb === 0) {
	      prefinish(stream, state);
	      state.finished = true;
	      stream.emit('finish');
	    } else
	      prefinish(stream, state);
	  }
	  return need;
	}

	function endWritable(stream, state, cb) {
	  state.ending = true;
	  finishMaybe(stream, state);
	  if (cb) {
	    if (state.finished)
	      process.nextTick(cb);
	    else
	      stream.once('finish', cb);
	  }
	  state.ended = true;
	}
	
	/* WEBPACK VAR INJECTION */}.call(exports, __webpack_require__(56)))

/***/ },
/* 250 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(process) {// Copyright Joyent, Inc. and other Node contributors.
	//
	// Permission is hereby granted, free of charge, to any person obtaining a
	// copy of this software and associated documentation files (the
	// "Software"), to deal in the Software without restriction, including
	// without limitation the rights to use, copy, modify, merge, publish,
	// distribute, sublicense, and/or sell copies of the Software, and to permit
	// persons to whom the Software is furnished to do so, subject to the
	// following conditions:
	//
	// The above copyright notice and this permission notice shall be included
	// in all copies or substantial portions of the Software.
	//
	// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
	// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
	// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
	// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
	// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
	// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
	// USE OR OTHER DEALINGS IN THE SOFTWARE.

	// a duplex stream is just a stream that is both readable and writable.
	// Since JS doesn't have multiple prototypal inheritance, this class
	// prototypally inherits from Readable, and then parasitically from
	// Writable.

	module.exports = Duplex;

	/*<replacement>*/
	var objectKeys = Object.keys || function (obj) {
	  var keys = [];
	  for (var key in obj) keys.push(key);
	  return keys;
	}
	/*</replacement>*/


	/*<replacement>*/
	var util = __webpack_require__(322);
	util.inherits = __webpack_require__(321);
	/*</replacement>*/

	var Readable = __webpack_require__(248);
	var Writable = __webpack_require__(249);

	util.inherits(Duplex, Readable);

	forEach(objectKeys(Writable.prototype), function(method) {
	  if (!Duplex.prototype[method])
	    Duplex.prototype[method] = Writable.prototype[method];
	});

	function Duplex(options) {
	  if (!(this instanceof Duplex))
	    return new Duplex(options);

	  Readable.call(this, options);
	  Writable.call(this, options);

	  if (options && options.readable === false)
	    this.readable = false;

	  if (options && options.writable === false)
	    this.writable = false;

	  this.allowHalfOpen = true;
	  if (options && options.allowHalfOpen === false)
	    this.allowHalfOpen = false;

	  this.once('end', onend);
	}

	// the no-half-open enforcer
	function onend() {
	  // if we allow half-open state, or if the writable side ended,
	  // then we're ok.
	  if (this.allowHalfOpen || this._writableState.ended)
	    return;

	  // no more data can be written.
	  // But allow more writes to happen in this tick.
	  process.nextTick(this.end.bind(this));
	}

	function forEach (xs, f) {
	  for (var i = 0, l = xs.length; i < l; i++) {
	    f(xs[i], i);
	  }
	}
	
	/* WEBPACK VAR INJECTION */}.call(exports, __webpack_require__(56)))

/***/ },
/* 251 */
/***/ function(module, exports, __webpack_require__) {

	// Copyright Joyent, Inc. and other Node contributors.
	//
	// Permission is hereby granted, free of charge, to any person obtaining a
	// copy of this software and associated documentation files (the
	// "Software"), to deal in the Software without restriction, including
	// without limitation the rights to use, copy, modify, merge, publish,
	// distribute, sublicense, and/or sell copies of the Software, and to permit
	// persons to whom the Software is furnished to do so, subject to the
	// following conditions:
	//
	// The above copyright notice and this permission notice shall be included
	// in all copies or substantial portions of the Software.
	//
	// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
	// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
	// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
	// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
	// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
	// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
	// USE OR OTHER DEALINGS IN THE SOFTWARE.


	// a transform stream is a readable/writable stream where you do
	// something with the data.  Sometimes it's called a "filter",
	// but that's not a great name for it, since that implies a thing where
	// some bits pass through, and others are simply ignored.  (That would
	// be a valid example of a transform, of course.)
	//
	// While the output is causally related to the input, it's not a
	// necessarily symmetric or synchronous transformation.  For example,
	// a zlib stream might take multiple plain-text writes(), and then
	// emit a single compressed chunk some time in the future.
	//
	// Here's how this works:
	//
	// The Transform stream has all the aspects of the readable and writable
	// stream classes.  When you write(chunk), that calls _write(chunk,cb)
	// internally, and returns false if there's a lot of pending writes
	// buffered up.  When you call read(), that calls _read(n) until
	// there's enough pending readable data buffered up.
	//
	// In a transform stream, the written data is placed in a buffer.  When
	// _read(n) is called, it transforms the queued up data, calling the
	// buffered _write cb's as it consumes chunks.  If consuming a single
	// written chunk would result in multiple output chunks, then the first
	// outputted bit calls the readcb, and subsequent chunks just go into
	// the read buffer, and will cause it to emit 'readable' if necessary.
	//
	// This way, back-pressure is actually determined by the reading side,
	// since _read has to be called to start processing a new chunk.  However,
	// a pathological inflate type of transform can cause excessive buffering
	// here.  For example, imagine a stream where every byte of input is
	// interpreted as an integer from 0-255, and then results in that many
	// bytes of output.  Writing the 4 bytes {ff,ff,ff,ff} would result in
	// 1kb of data being output.  In this case, you could write a very small
	// amount of input, and end up with a very large amount of output.  In
	// such a pathological inflating mechanism, there'd be no way to tell
	// the system to stop doing the transform.  A single 4MB write could
	// cause the system to run out of memory.
	//
	// However, even in such a pathological case, only a single written chunk
	// would be consumed, and then the rest would wait (un-transformed) until
	// the results of the previous transformed chunk were consumed.

	module.exports = Transform;

	var Duplex = __webpack_require__(250);

	/*<replacement>*/
	var util = __webpack_require__(322);
	util.inherits = __webpack_require__(321);
	/*</replacement>*/

	util.inherits(Transform, Duplex);


	function TransformState(options, stream) {
	  this.afterTransform = function(er, data) {
	    return afterTransform(stream, er, data);
	  };

	  this.needTransform = false;
	  this.transforming = false;
	  this.writecb = null;
	  this.writechunk = null;
	}

	function afterTransform(stream, er, data) {
	  var ts = stream._transformState;
	  ts.transforming = false;

	  var cb = ts.writecb;

	  if (!cb)
	    return stream.emit('error', new Error('no writecb in Transform class'));

	  ts.writechunk = null;
	  ts.writecb = null;

	  if (!util.isNullOrUndefined(data))
	    stream.push(data);

	  if (cb)
	    cb(er);

	  var rs = stream._readableState;
	  rs.reading = false;
	  if (rs.needReadable || rs.length < rs.highWaterMark) {
	    stream._read(rs.highWaterMark);
	  }
	}


	function Transform(options) {
	  if (!(this instanceof Transform))
	    return new Transform(options);

	  Duplex.call(this, options);

	  this._transformState = new TransformState(options, this);

	  // when the writable side finishes, then flush out anything remaining.
	  var stream = this;

	  // start out asking for a readable event once data is transformed.
	  this._readableState.needReadable = true;

	  // we have implemented the _read method, and done the other things
	  // that Readable wants before the first _read call, so unset the
	  // sync guard flag.
	  this._readableState.sync = false;

	  this.once('prefinish', function() {
	    if (util.isFunction(this._flush))
	      this._flush(function(er) {
	        done(stream, er);
	      });
	    else
	      done(stream);
	  });
	}

	Transform.prototype.push = function(chunk, encoding) {
	  this._transformState.needTransform = false;
	  return Duplex.prototype.push.call(this, chunk, encoding);
	};

	// This is the part where you do stuff!
	// override this function in implementation classes.
	// 'chunk' is an input chunk.
	//
	// Call `push(newChunk)` to pass along transformed output
	// to the readable side.  You may call 'push' zero or more times.
	//
	// Call `cb(err)` when you are done with this chunk.  If you pass
	// an error, then that'll put the hurt on the whole operation.  If you
	// never call cb(), then you'll never get another chunk.
	Transform.prototype._transform = function(chunk, encoding, cb) {
	  throw new Error('not implemented');
	};

	Transform.prototype._write = function(chunk, encoding, cb) {
	  var ts = this._transformState;
	  ts.writecb = cb;
	  ts.writechunk = chunk;
	  ts.writeencoding = encoding;
	  if (!ts.transforming) {
	    var rs = this._readableState;
	    if (ts.needTransform ||
	        rs.needReadable ||
	        rs.length < rs.highWaterMark)
	      this._read(rs.highWaterMark);
	  }
	};

	// Doesn't matter what the args are here.
	// _transform does all the work.
	// That we got here means that the readable side wants more data.
	Transform.prototype._read = function(n) {
	  var ts = this._transformState;

	  if (!util.isNull(ts.writechunk) && ts.writecb && !ts.transforming) {
	    ts.transforming = true;
	    this._transform(ts.writechunk, ts.writeencoding, ts.afterTransform);
	  } else {
	    // mark that we need a transform, so that any data that comes in
	    // will get processed, now that we've asked for it.
	    ts.needTransform = true;
	  }
	};


	function done(stream, er) {
	  if (er)
	    return stream.emit('error', er);

	  // if there's nothing in the write buffer, then that means
	  // that nothing more will ever be provided
	  var ws = stream._writableState;
	  var ts = stream._transformState;

	  if (ws.length)
	    throw new Error('calling transform done when ws.length != 0');

	  if (ts.transforming)
	    throw new Error('calling transform done when still transforming');

	  return stream.push(null);
	}


/***/ },
/* 252 */
/***/ function(module, exports, __webpack_require__) {

	// Copyright Joyent, Inc. and other Node contributors.
	//
	// Permission is hereby granted, free of charge, to any person obtaining a
	// copy of this software and associated documentation files (the
	// "Software"), to deal in the Software without restriction, including
	// without limitation the rights to use, copy, modify, merge, publish,
	// distribute, sublicense, and/or sell copies of the Software, and to permit
	// persons to whom the Software is furnished to do so, subject to the
	// following conditions:
	//
	// The above copyright notice and this permission notice shall be included
	// in all copies or substantial portions of the Software.
	//
	// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
	// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
	// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
	// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
	// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
	// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
	// USE OR OTHER DEALINGS IN THE SOFTWARE.

	// a passthrough stream.
	// basically just the most minimal sort of Transform stream.
	// Every written chunk gets output as-is.

	module.exports = PassThrough;

	var Transform = __webpack_require__(251);

	/*<replacement>*/
	var util = __webpack_require__(322);
	util.inherits = __webpack_require__(321);
	/*</replacement>*/

	util.inherits(PassThrough, Transform);

	function PassThrough(options) {
	  if (!(this instanceof PassThrough))
	    return new PassThrough(options);

	  Transform.call(this, options);
	}

	PassThrough.prototype._transform = function(chunk, encoding, cb) {
	  cb(null, chunk);
	};


/***/ },
/* 253 */
/***/ function(module, exports, __webpack_require__) {

	var nextTick = __webpack_require__(323).nextTick;
	var apply = Function.prototype.apply;
	var slice = Array.prototype.slice;
	var immediateIds = {};
	var nextImmediateId = 0;

	// DOM APIs, for completeness

	exports.setTimeout = function() {
	  return new Timeout(apply.call(setTimeout, window, arguments), clearTimeout);
	};
	exports.setInterval = function() {
	  return new Timeout(apply.call(setInterval, window, arguments), clearInterval);
	};
	exports.clearTimeout =
	exports.clearInterval = function(timeout) { timeout.close(); };

	function Timeout(id, clearFn) {
	  this._id = id;
	  this._clearFn = clearFn;
	}
	Timeout.prototype.unref = Timeout.prototype.ref = function() {};
	Timeout.prototype.close = function() {
	  this._clearFn.call(window, this._id);
	};

	// Does not start the time, just sets up the members needed.
	exports.enroll = function(item, msecs) {
	  clearTimeout(item._idleTimeoutId);
	  item._idleTimeout = msecs;
	};

	exports.unenroll = function(item) {
	  clearTimeout(item._idleTimeoutId);
	  item._idleTimeout = -1;
	};

	exports._unrefActive = exports.active = function(item) {
	  clearTimeout(item._idleTimeoutId);

	  var msecs = item._idleTimeout;
	  if (msecs >= 0) {
	    item._idleTimeoutId = setTimeout(function onTimeout() {
	      if (item._onTimeout)
	        item._onTimeout();
	    }, msecs);
	  }
	};

	// That's not how node.js implements it but the exposed api is the same.
	exports.setImmediate = typeof setImmediate === "function" ? setImmediate : function(fn) {
	  var id = nextImmediateId++;
	  var args = arguments.length < 2 ? false : slice.call(arguments, 1);

	  immediateIds[id] = true;

	  nextTick(function onNextTick() {
	    if (immediateIds[id]) {
	      // fn.call() is faster so we optimize for the common use-case
	      // @see http://jsperf.com/call-apply-segu
	      if (args) {
	        fn.apply(null, args);
	      } else {
	        fn.call(null);
	      }
	      // Prevent ids from leaking
	      exports.clearImmediate(id);
	    }
	  });

	  return id;
	};

	exports.clearImmediate = typeof clearImmediate === "function" ? clearImmediate : function(id) {
	  delete immediateIds[id];
	};

/***/ },
/* 254 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});

	var _toDate = __webpack_require__(259);

	var _toDate2 = _interopRequireDefault(_toDate);

	var _toFloat = __webpack_require__(260);

	var _toFloat2 = _interopRequireDefault(_toFloat);

	var _toInt = __webpack_require__(261);

	var _toInt2 = _interopRequireDefault(_toInt);

	var _toBoolean = __webpack_require__(262);

	var _toBoolean2 = _interopRequireDefault(_toBoolean);

	var _equals = __webpack_require__(263);

	var _equals2 = _interopRequireDefault(_equals);

	var _contains = __webpack_require__(264);

	var _contains2 = _interopRequireDefault(_contains);

	var _matches = __webpack_require__(265);

	var _matches2 = _interopRequireDefault(_matches);

	var _isEmail = __webpack_require__(266);

	var _isEmail2 = _interopRequireDefault(_isEmail);

	var _isURL = __webpack_require__(267);

	var _isURL2 = _interopRequireDefault(_isURL);

	var _isMACAddress = __webpack_require__(268);

	var _isMACAddress2 = _interopRequireDefault(_isMACAddress);

	var _isIP = __webpack_require__(269);

	var _isIP2 = _interopRequireDefault(_isIP);

	var _isFQDN = __webpack_require__(270);

	var _isFQDN2 = _interopRequireDefault(_isFQDN);

	var _isBoolean = __webpack_require__(271);

	var _isBoolean2 = _interopRequireDefault(_isBoolean);

	var _isAlpha = __webpack_require__(272);

	var _isAlpha2 = _interopRequireDefault(_isAlpha);

	var _isAlphanumeric = __webpack_require__(273);

	var _isAlphanumeric2 = _interopRequireDefault(_isAlphanumeric);

	var _isNumeric = __webpack_require__(274);

	var _isNumeric2 = _interopRequireDefault(_isNumeric);

	var _isLowercase = __webpack_require__(275);

	var _isLowercase2 = _interopRequireDefault(_isLowercase);

	var _isUppercase = __webpack_require__(276);

	var _isUppercase2 = _interopRequireDefault(_isUppercase);

	var _isAscii = __webpack_require__(277);

	var _isAscii2 = _interopRequireDefault(_isAscii);

	var _isFullWidth = __webpack_require__(278);

	var _isFullWidth2 = _interopRequireDefault(_isFullWidth);

	var _isHalfWidth = __webpack_require__(279);

	var _isHalfWidth2 = _interopRequireDefault(_isHalfWidth);

	var _isVariableWidth = __webpack_require__(280);

	var _isVariableWidth2 = _interopRequireDefault(_isVariableWidth);

	var _isMultibyte = __webpack_require__(281);

	var _isMultibyte2 = _interopRequireDefault(_isMultibyte);

	var _isSurrogatePair = __webpack_require__(282);

	var _isSurrogatePair2 = _interopRequireDefault(_isSurrogatePair);

	var _isInt = __webpack_require__(283);

	var _isInt2 = _interopRequireDefault(_isInt);

	var _isFloat = __webpack_require__(284);

	var _isFloat2 = _interopRequireDefault(_isFloat);

	var _isDecimal = __webpack_require__(285);

	var _isDecimal2 = _interopRequireDefault(_isDecimal);

	var _isHexadecimal = __webpack_require__(286);

	var _isHexadecimal2 = _interopRequireDefault(_isHexadecimal);

	var _isDivisibleBy = __webpack_require__(287);

	var _isDivisibleBy2 = _interopRequireDefault(_isDivisibleBy);

	var _isHexColor = __webpack_require__(288);

	var _isHexColor2 = _interopRequireDefault(_isHexColor);

	var _isJSON = __webpack_require__(289);

	var _isJSON2 = _interopRequireDefault(_isJSON);

	var _isNull = __webpack_require__(290);

	var _isNull2 = _interopRequireDefault(_isNull);

	var _isLength = __webpack_require__(291);

	var _isLength2 = _interopRequireDefault(_isLength);

	var _isByteLength = __webpack_require__(292);

	var _isByteLength2 = _interopRequireDefault(_isByteLength);

	var _isUUID = __webpack_require__(293);

	var _isUUID2 = _interopRequireDefault(_isUUID);

	var _isMongoId = __webpack_require__(294);

	var _isMongoId2 = _interopRequireDefault(_isMongoId);

	var _isDate = __webpack_require__(295);

	var _isDate2 = _interopRequireDefault(_isDate);

	var _isAfter = __webpack_require__(296);

	var _isAfter2 = _interopRequireDefault(_isAfter);

	var _isBefore = __webpack_require__(297);

	var _isBefore2 = _interopRequireDefault(_isBefore);

	var _isIn = __webpack_require__(298);

	var _isIn2 = _interopRequireDefault(_isIn);

	var _isCreditCard = __webpack_require__(299);

	var _isCreditCard2 = _interopRequireDefault(_isCreditCard);

	var _isISIN = __webpack_require__(300);

	var _isISIN2 = _interopRequireDefault(_isISIN);

	var _isISBN = __webpack_require__(301);

	var _isISBN2 = _interopRequireDefault(_isISBN);

	var _isMobilePhone = __webpack_require__(302);

	var _isMobilePhone2 = _interopRequireDefault(_isMobilePhone);

	var _isCurrency = __webpack_require__(303);

	var _isCurrency2 = _interopRequireDefault(_isCurrency);

	var _isISO = __webpack_require__(304);

	var _isISO2 = _interopRequireDefault(_isISO);

	var _isBase = __webpack_require__(305);

	var _isBase2 = _interopRequireDefault(_isBase);

	var _isDataURI = __webpack_require__(306);

	var _isDataURI2 = _interopRequireDefault(_isDataURI);

	var _ltrim = __webpack_require__(307);

	var _ltrim2 = _interopRequireDefault(_ltrim);

	var _rtrim = __webpack_require__(308);

	var _rtrim2 = _interopRequireDefault(_rtrim);

	var _trim = __webpack_require__(309);

	var _trim2 = _interopRequireDefault(_trim);

	var _escape = __webpack_require__(310);

	var _escape2 = _interopRequireDefault(_escape);

	var _unescape = __webpack_require__(311);

	var _unescape2 = _interopRequireDefault(_unescape);

	var _stripLow = __webpack_require__(312);

	var _stripLow2 = _interopRequireDefault(_stripLow);

	var _whitelist = __webpack_require__(313);

	var _whitelist2 = _interopRequireDefault(_whitelist);

	var _blacklist = __webpack_require__(314);

	var _blacklist2 = _interopRequireDefault(_blacklist);

	var _isWhitelisted = __webpack_require__(315);

	var _isWhitelisted2 = _interopRequireDefault(_isWhitelisted);

	var _normalizeEmail = __webpack_require__(316);

	var _normalizeEmail2 = _interopRequireDefault(_normalizeEmail);

	var _toString = __webpack_require__(317);

	var _toString2 = _interopRequireDefault(_toString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	var version = '5.2.0';

	var validator = {
	  version: version,
	  toDate: _toDate2.default,
	  toFloat: _toFloat2.default, toInt: _toInt2.default,
	  toBoolean: _toBoolean2.default,
	  equals: _equals2.default, contains: _contains2.default, matches: _matches2.default,
	  isEmail: _isEmail2.default, isURL: _isURL2.default, isMACAddress: _isMACAddress2.default, isIP: _isIP2.default, isFQDN: _isFQDN2.default,
	  isBoolean: _isBoolean2.default,
	  isAlpha: _isAlpha2.default, isAlphanumeric: _isAlphanumeric2.default, isNumeric: _isNumeric2.default, isLowercase: _isLowercase2.default, isUppercase: _isUppercase2.default,
	  isAscii: _isAscii2.default, isFullWidth: _isFullWidth2.default, isHalfWidth: _isHalfWidth2.default, isVariableWidth: _isVariableWidth2.default,
	  isMultibyte: _isMultibyte2.default, isSurrogatePair: _isSurrogatePair2.default,
	  isInt: _isInt2.default, isFloat: _isFloat2.default, isDecimal: _isDecimal2.default, isHexadecimal: _isHexadecimal2.default, isDivisibleBy: _isDivisibleBy2.default,
	  isHexColor: _isHexColor2.default,
	  isJSON: _isJSON2.default,
	  isNull: _isNull2.default,
	  isLength: _isLength2.default, isByteLength: _isByteLength2.default,
	  isUUID: _isUUID2.default, isMongoId: _isMongoId2.default,
	  isDate: _isDate2.default, isAfter: _isAfter2.default, isBefore: _isBefore2.default,
	  isIn: _isIn2.default,
	  isCreditCard: _isCreditCard2.default,
	  isISIN: _isISIN2.default, isISBN: _isISBN2.default,
	  isMobilePhone: _isMobilePhone2.default,
	  isCurrency: _isCurrency2.default,
	  isISO8601: _isISO2.default,
	  isBase64: _isBase2.default, isDataURI: _isDataURI2.default,
	  ltrim: _ltrim2.default, rtrim: _rtrim2.default, trim: _trim2.default,
	  escape: _escape2.default, unescape: _unescape2.default, stripLow: _stripLow2.default,
	  whitelist: _whitelist2.default, blacklist: _blacklist2.default,
	  isWhitelisted: _isWhitelisted2.default,
	  normalizeEmail: _normalizeEmail2.default,
	  toString: _toString2.default
	};

	exports.default = validator;
	module.exports = exports['default'];

/***/ },
/* 255 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(Buffer) {;(function (sax) { // wrapper for non-node envs
	  sax.parser = function (strict, opt) { return new SAXParser(strict, opt) }
	  sax.SAXParser = SAXParser
	  sax.SAXStream = SAXStream
	  sax.createStream = createStream

	  // When we pass the MAX_BUFFER_LENGTH position, start checking for buffer overruns.
	  // When we check, schedule the next check for MAX_BUFFER_LENGTH - (max(buffer lengths)),
	  // since that's the earliest that a buffer overrun could occur.  This way, checks are
	  // as rare as required, but as often as necessary to ensure never crossing this bound.
	  // Furthermore, buffers are only tested at most once per write(), so passing a very
	  // large string into write() might have undesirable effects, but this is manageable by
	  // the caller, so it is assumed to be safe.  Thus, a call to write() may, in the extreme
	  // edge case, result in creating at most one complete copy of the string passed in.
	  // Set to Infinity to have unlimited buffers.
	  sax.MAX_BUFFER_LENGTH = 64 * 1024

	  var buffers = [
	    'comment', 'sgmlDecl', 'textNode', 'tagName', 'doctype',
	    'procInstName', 'procInstBody', 'entity', 'attribName',
	    'attribValue', 'cdata', 'script'
	  ]

	  sax.EVENTS = [
	    'text',
	    'processinginstruction',
	    'sgmldeclaration',
	    'doctype',
	    'comment',
	    'opentagstart',
	    'attribute',
	    'opentag',
	    'closetag',
	    'opencdata',
	    'cdata',
	    'closecdata',
	    'error',
	    'end',
	    'ready',
	    'script',
	    'opennamespace',
	    'closenamespace'
	  ]

	  function SAXParser (strict, opt) {
	    if (!(this instanceof SAXParser)) {
	      return new SAXParser(strict, opt)
	    }

	    var parser = this
	    clearBuffers(parser)
	    parser.q = parser.c = ''
	    parser.bufferCheckPosition = sax.MAX_BUFFER_LENGTH
	    parser.opt = opt || {}
	    parser.opt.lowercase = parser.opt.lowercase || parser.opt.lowercasetags
	    parser.looseCase = parser.opt.lowercase ? 'toLowerCase' : 'toUpperCase'
	    parser.tags = []
	    parser.closed = parser.closedRoot = parser.sawRoot = false
	    parser.tag = parser.error = null
	    parser.strict = !!strict
	    parser.noscript = !!(strict || parser.opt.noscript)
	    parser.state = S.BEGIN
	    parser.strictEntities = parser.opt.strictEntities
	    parser.ENTITIES = parser.strictEntities ? Object.create(sax.XML_ENTITIES) : Object.create(sax.ENTITIES)
	    parser.attribList = []

	    // namespaces form a prototype chain.
	    // it always points at the current tag,
	    // which protos to its parent tag.
	    if (parser.opt.xmlns) {
	      parser.ns = Object.create(rootNS)
	    }

	    // mostly just for error reporting
	    parser.trackPosition = parser.opt.position !== false
	    if (parser.trackPosition) {
	      parser.position = parser.line = parser.column = 0
	    }
	    emit(parser, 'onready')
	  }

	  if (!Object.create) {
	    Object.create = function (o) {
	      function F () {}
	      F.prototype = o
	      var newf = new F()
	      return newf
	    }
	  }

	  if (!Object.keys) {
	    Object.keys = function (o) {
	      var a = []
	      for (var i in o) if (o.hasOwnProperty(i)) a.push(i)
	      return a
	    }
	  }

	  function checkBufferLength (parser) {
	    var maxAllowed = Math.max(sax.MAX_BUFFER_LENGTH, 10)
	    var maxActual = 0
	    for (var i = 0, l = buffers.length; i < l; i++) {
	      var len = parser[buffers[i]].length
	      if (len > maxAllowed) {
	        // Text/cdata nodes can get big, and since they're buffered,
	        // we can get here under normal conditions.
	        // Avoid issues by emitting the text node now,
	        // so at least it won't get any bigger.
	        switch (buffers[i]) {
	          case 'textNode':
	            closeText(parser)
	            break

	          case 'cdata':
	            emitNode(parser, 'oncdata', parser.cdata)
	            parser.cdata = ''
	            break

	          case 'script':
	            emitNode(parser, 'onscript', parser.script)
	            parser.script = ''
	            break

	          default:
	            error(parser, 'Max buffer length exceeded: ' + buffers[i])
	        }
	      }
	      maxActual = Math.max(maxActual, len)
	    }
	    // schedule the next check for the earliest possible buffer overrun.
	    var m = sax.MAX_BUFFER_LENGTH - maxActual
	    parser.bufferCheckPosition = m + parser.position
	  }

	  function clearBuffers (parser) {
	    for (var i = 0, l = buffers.length; i < l; i++) {
	      parser[buffers[i]] = ''
	    }
	  }

	  function flushBuffers (parser) {
	    closeText(parser)
	    if (parser.cdata !== '') {
	      emitNode(parser, 'oncdata', parser.cdata)
	      parser.cdata = ''
	    }
	    if (parser.script !== '') {
	      emitNode(parser, 'onscript', parser.script)
	      parser.script = ''
	    }
	  }

	  SAXParser.prototype = {
	    end: function () { end(this) },
	    write: write,
	    resume: function () { this.error = null; return this },
	    close: function () { return this.write(null) },
	    flush: function () { flushBuffers(this) }
	  }

	  var Stream
	  try {
	    Stream = __webpack_require__(165).Stream
	  } catch (ex) {
	    Stream = function () {}
	  }

	  var streamWraps = sax.EVENTS.filter(function (ev) {
	    return ev !== 'error' && ev !== 'end'
	  })

	  function createStream (strict, opt) {
	    return new SAXStream(strict, opt)
	  }

	  function SAXStream (strict, opt) {
	    if (!(this instanceof SAXStream)) {
	      return new SAXStream(strict, opt)
	    }

	    Stream.apply(this)

	    this._parser = new SAXParser(strict, opt)
	    this.writable = true
	    this.readable = true

	    var me = this

	    this._parser.onend = function () {
	      me.emit('end')
	    }

	    this._parser.onerror = function (er) {
	      me.emit('error', er)

	      // if didn't throw, then means error was handled.
	      // go ahead and clear error, so we can write again.
	      me._parser.error = null
	    }

	    this._decoder = null

	    streamWraps.forEach(function (ev) {
	      Object.defineProperty(me, 'on' + ev, {
	        get: function () {
	          return me._parser['on' + ev]
	        },
	        set: function (h) {
	          if (!h) {
	            me.removeAllListeners(ev)
	            me._parser['on' + ev] = h
	            return h
	          }
	          me.on(ev, h)
	        },
	        enumerable: true,
	        configurable: false
	      })
	    })
	  }

	  SAXStream.prototype = Object.create(Stream.prototype, {
	    constructor: {
	      value: SAXStream
	    }
	  })

	  SAXStream.prototype.write = function (data) {
	    if (typeof Buffer === 'function' &&
	      typeof Buffer.isBuffer === 'function' &&
	      Buffer.isBuffer(data)) {
	      if (!this._decoder) {
	        var SD = __webpack_require__(258).StringDecoder
	        this._decoder = new SD('utf8')
	      }
	      data = this._decoder.write(data)
	    }

	    this._parser.write(data.toString())
	    this.emit('data', data)
	    return true
	  }

	  SAXStream.prototype.end = function (chunk) {
	    if (chunk && chunk.length) {
	      this.write(chunk)
	    }
	    this._parser.end()
	    return true
	  }

	  SAXStream.prototype.on = function (ev, handler) {
	    var me = this
	    if (!me._parser['on' + ev] && streamWraps.indexOf(ev) !== -1) {
	      me._parser['on' + ev] = function () {
	        var args = arguments.length === 1 ? [arguments[0]] : Array.apply(null, arguments)
	        args.splice(0, 0, ev)
	        me.emit.apply(me, args)
	      }
	    }

	    return Stream.prototype.on.call(me, ev, handler)
	  }

	  // character classes and tokens
	  var whitespace = '\r\n\t '

	  // this really needs to be replaced with character classes.
	  // XML allows all manner of ridiculous numbers and digits.
	  var number = '0124356789'
	  var letter = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ'

	  // (Letter | "_" | ":")
	  var quote = '\'"'
	  var attribEnd = whitespace + '>'
	  var CDATA = '[CDATA['
	  var DOCTYPE = 'DOCTYPE'
	  var XML_NAMESPACE = 'http://www.w3.org/XML/1998/namespace'
	  var XMLNS_NAMESPACE = 'http://www.w3.org/2000/xmlns/'
	  var rootNS = { xml: XML_NAMESPACE, xmlns: XMLNS_NAMESPACE }

	  // turn all the string character sets into character class objects.
	  whitespace = charClass(whitespace)
	  number = charClass(number)
	  letter = charClass(letter)

	  // http://www.w3.org/TR/REC-xml/#NT-NameStartChar
	  // This implementation works on strings, a single character at a time
	  // as such, it cannot ever support astral-plane characters (10000-EFFFF)
	  // without a significant breaking change to either this  parser, or the
	  // JavaScript language.  Implementation of an emoji-capable xml parser
	  // is left as an exercise for the reader.
	  var nameStart = /[:_A-Za-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD]/

	  var nameBody = /[:_A-Za-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD\u00B7\u0300-\u036F\u203F-\u2040\.\d-]/

	  var entityStart = /[#:_A-Za-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD]/
	  var entityBody = /[#:_A-Za-z\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02FF\u0370-\u037D\u037F-\u1FFF\u200C-\u200D\u2070-\u218F\u2C00-\u2FEF\u3001-\uD7FF\uF900-\uFDCF\uFDF0-\uFFFD\u00B7\u0300-\u036F\u203F-\u2040\.\d-]/

	  quote = charClass(quote)
	  attribEnd = charClass(attribEnd)

	  function charClass (str) {
	    return str.split('').reduce(function (s, c) {
	      s[c] = true
	      return s
	    }, {})
	  }

	  function isRegExp (c) {
	    return Object.prototype.toString.call(c) === '[object RegExp]'
	  }

	  function is (charclass, c) {
	    return isRegExp(charclass) ? !!c.match(charclass) : charclass[c]
	  }

	  function not (charclass, c) {
	    return !is(charclass, c)
	  }

	  var S = 0
	  sax.STATE = {
	    BEGIN: S++, // leading byte order mark or whitespace
	    BEGIN_WHITESPACE: S++, // leading whitespace
	    TEXT: S++, // general stuff
	    TEXT_ENTITY: S++, // &amp and such.
	    OPEN_WAKA: S++, // <
	    SGML_DECL: S++, // <!BLARG
	    SGML_DECL_QUOTED: S++, // <!BLARG foo "bar
	    DOCTYPE: S++, // <!DOCTYPE
	    DOCTYPE_QUOTED: S++, // <!DOCTYPE "//blah
	    DOCTYPE_DTD: S++, // <!DOCTYPE "//blah" [ ...
	    DOCTYPE_DTD_QUOTED: S++, // <!DOCTYPE "//blah" [ "foo
	    COMMENT_STARTING: S++, // <!-
	    COMMENT: S++, // <!--
	    COMMENT_ENDING: S++, // <!-- blah -
	    COMMENT_ENDED: S++, // <!-- blah --
	    CDATA: S++, // <![CDATA[ something
	    CDATA_ENDING: S++, // ]
	    CDATA_ENDING_2: S++, // ]]
	    PROC_INST: S++, // <?hi
	    PROC_INST_BODY: S++, // <?hi there
	    PROC_INST_ENDING: S++, // <?hi "there" ?
	    OPEN_TAG: S++, // <strong
	    OPEN_TAG_SLASH: S++, // <strong /
	    ATTRIB: S++, // <a
	    ATTRIB_NAME: S++, // <a foo
	    ATTRIB_NAME_SAW_WHITE: S++, // <a foo _
	    ATTRIB_VALUE: S++, // <a foo=
	    ATTRIB_VALUE_QUOTED: S++, // <a foo="bar
	    ATTRIB_VALUE_CLOSED: S++, // <a foo="bar"
	    ATTRIB_VALUE_UNQUOTED: S++, // <a foo=bar
	    ATTRIB_VALUE_ENTITY_Q: S++, // <foo bar="&quot;"
	    ATTRIB_VALUE_ENTITY_U: S++, // <foo bar=&quot
	    CLOSE_TAG: S++, // </a
	    CLOSE_TAG_SAW_WHITE: S++, // </a   >
	    SCRIPT: S++, // <script> ...
	    SCRIPT_ENDING: S++ // <script> ... <
	  }

	  sax.XML_ENTITIES = {
	    'amp': '&',
	    'gt': '>',
	    'lt': '<',
	    'quot': '"',
	    'apos': "'"
	  }

	  sax.ENTITIES = {
	    'amp': '&',
	    'gt': '>',
	    'lt': '<',
	    'quot': '"',
	    'apos': "'",
	    'AElig': 198,
	    'Aacute': 193,
	    'Acirc': 194,
	    'Agrave': 192,
	    'Aring': 197,
	    'Atilde': 195,
	    'Auml': 196,
	    'Ccedil': 199,
	    'ETH': 208,
	    'Eacute': 201,
	    'Ecirc': 202,
	    'Egrave': 200,
	    'Euml': 203,
	    'Iacute': 205,
	    'Icirc': 206,
	    'Igrave': 204,
	    'Iuml': 207,
	    'Ntilde': 209,
	    'Oacute': 211,
	    'Ocirc': 212,
	    'Ograve': 210,
	    'Oslash': 216,
	    'Otilde': 213,
	    'Ouml': 214,
	    'THORN': 222,
	    'Uacute': 218,
	    'Ucirc': 219,
	    'Ugrave': 217,
	    'Uuml': 220,
	    'Yacute': 221,
	    'aacute': 225,
	    'acirc': 226,
	    'aelig': 230,
	    'agrave': 224,
	    'aring': 229,
	    'atilde': 227,
	    'auml': 228,
	    'ccedil': 231,
	    'eacute': 233,
	    'ecirc': 234,
	    'egrave': 232,
	    'eth': 240,
	    'euml': 235,
	    'iacute': 237,
	    'icirc': 238,
	    'igrave': 236,
	    'iuml': 239,
	    'ntilde': 241,
	    'oacute': 243,
	    'ocirc': 244,
	    'ograve': 242,
	    'oslash': 248,
	    'otilde': 245,
	    'ouml': 246,
	    'szlig': 223,
	    'thorn': 254,
	    'uacute': 250,
	    'ucirc': 251,
	    'ugrave': 249,
	    'uuml': 252,
	    'yacute': 253,
	    'yuml': 255,
	    'copy': 169,
	    'reg': 174,
	    'nbsp': 160,
	    'iexcl': 161,
	    'cent': 162,
	    'pound': 163,
	    'curren': 164,
	    'yen': 165,
	    'brvbar': 166,
	    'sect': 167,
	    'uml': 168,
	    'ordf': 170,
	    'laquo': 171,
	    'not': 172,
	    'shy': 173,
	    'macr': 175,
	    'deg': 176,
	    'plusmn': 177,
	    'sup1': 185,
	    'sup2': 178,
	    'sup3': 179,
	    'acute': 180,
	    'micro': 181,
	    'para': 182,
	    'middot': 183,
	    'cedil': 184,
	    'ordm': 186,
	    'raquo': 187,
	    'frac14': 188,
	    'frac12': 189,
	    'frac34': 190,
	    'iquest': 191,
	    'times': 215,
	    'divide': 247,
	    'OElig': 338,
	    'oelig': 339,
	    'Scaron': 352,
	    'scaron': 353,
	    'Yuml': 376,
	    'fnof': 402,
	    'circ': 710,
	    'tilde': 732,
	    'Alpha': 913,
	    'Beta': 914,
	    'Gamma': 915,
	    'Delta': 916,
	    'Epsilon': 917,
	    'Zeta': 918,
	    'Eta': 919,
	    'Theta': 920,
	    'Iota': 921,
	    'Kappa': 922,
	    'Lambda': 923,
	    'Mu': 924,
	    'Nu': 925,
	    'Xi': 926,
	    'Omicron': 927,
	    'Pi': 928,
	    'Rho': 929,
	    'Sigma': 931,
	    'Tau': 932,
	    'Upsilon': 933,
	    'Phi': 934,
	    'Chi': 935,
	    'Psi': 936,
	    'Omega': 937,
	    'alpha': 945,
	    'beta': 946,
	    'gamma': 947,
	    'delta': 948,
	    'epsilon': 949,
	    'zeta': 950,
	    'eta': 951,
	    'theta': 952,
	    'iota': 953,
	    'kappa': 954,
	    'lambda': 955,
	    'mu': 956,
	    'nu': 957,
	    'xi': 958,
	    'omicron': 959,
	    'pi': 960,
	    'rho': 961,
	    'sigmaf': 962,
	    'sigma': 963,
	    'tau': 964,
	    'upsilon': 965,
	    'phi': 966,
	    'chi': 967,
	    'psi': 968,
	    'omega': 969,
	    'thetasym': 977,
	    'upsih': 978,
	    'piv': 982,
	    'ensp': 8194,
	    'emsp': 8195,
	    'thinsp': 8201,
	    'zwnj': 8204,
	    'zwj': 8205,
	    'lrm': 8206,
	    'rlm': 8207,
	    'ndash': 8211,
	    'mdash': 8212,
	    'lsquo': 8216,
	    'rsquo': 8217,
	    'sbquo': 8218,
	    'ldquo': 8220,
	    'rdquo': 8221,
	    'bdquo': 8222,
	    'dagger': 8224,
	    'Dagger': 8225,
	    'bull': 8226,
	    'hellip': 8230,
	    'permil': 8240,
	    'prime': 8242,
	    'Prime': 8243,
	    'lsaquo': 8249,
	    'rsaquo': 8250,
	    'oline': 8254,
	    'frasl': 8260,
	    'euro': 8364,
	    'image': 8465,
	    'weierp': 8472,
	    'real': 8476,
	    'trade': 8482,
	    'alefsym': 8501,
	    'larr': 8592,
	    'uarr': 8593,
	    'rarr': 8594,
	    'darr': 8595,
	    'harr': 8596,
	    'crarr': 8629,
	    'lArr': 8656,
	    'uArr': 8657,
	    'rArr': 8658,
	    'dArr': 8659,
	    'hArr': 8660,
	    'forall': 8704,
	    'part': 8706,
	    'exist': 8707,
	    'empty': 8709,
	    'nabla': 8711,
	    'isin': 8712,
	    'notin': 8713,
	    'ni': 8715,
	    'prod': 8719,
	    'sum': 8721,
	    'minus': 8722,
	    'lowast': 8727,
	    'radic': 8730,
	    'prop': 8733,
	    'infin': 8734,
	    'ang': 8736,
	    'and': 8743,
	    'or': 8744,
	    'cap': 8745,
	    'cup': 8746,
	    'int': 8747,
	    'there4': 8756,
	    'sim': 8764,
	    'cong': 8773,
	    'asymp': 8776,
	    'ne': 8800,
	    'equiv': 8801,
	    'le': 8804,
	    'ge': 8805,
	    'sub': 8834,
	    'sup': 8835,
	    'nsub': 8836,
	    'sube': 8838,
	    'supe': 8839,
	    'oplus': 8853,
	    'otimes': 8855,
	    'perp': 8869,
	    'sdot': 8901,
	    'lceil': 8968,
	    'rceil': 8969,
	    'lfloor': 8970,
	    'rfloor': 8971,
	    'lang': 9001,
	    'rang': 9002,
	    'loz': 9674,
	    'spades': 9824,
	    'clubs': 9827,
	    'hearts': 9829,
	    'diams': 9830
	  }

	  Object.keys(sax.ENTITIES).forEach(function (key) {
	    var e = sax.ENTITIES[key]
	    var s = typeof e === 'number' ? String.fromCharCode(e) : e
	    sax.ENTITIES[key] = s
	  })

	  for (var s in sax.STATE) {
	    sax.STATE[sax.STATE[s]] = s
	  }

	  // shorthand
	  S = sax.STATE

	  function emit (parser, event, data) {
	    parser[event] && parser[event](data)
	  }

	  function emitNode (parser, nodeType, data) {
	    if (parser.textNode) closeText(parser)
	    emit(parser, nodeType, data)
	  }

	  function closeText (parser) {
	    parser.textNode = textopts(parser.opt, parser.textNode)
	    if (parser.textNode) emit(parser, 'ontext', parser.textNode)
	    parser.textNode = ''
	  }

	  function textopts (opt, text) {
	    if (opt.trim) text = text.trim()
	    if (opt.normalize) text = text.replace(/\s+/g, ' ')
	    return text
	  }

	  function error (parser, er) {
	    closeText(parser)
	    if (parser.trackPosition) {
	      er += '\nLine: ' + parser.line +
	        '\nColumn: ' + parser.column +
	        '\nChar: ' + parser.c
	    }
	    er = new Error(er)
	    parser.error = er
	    emit(parser, 'onerror', er)
	    return parser
	  }

	  function end (parser) {
	    if (parser.sawRoot && !parser.closedRoot) strictFail(parser, 'Unclosed root tag')
	    if ((parser.state !== S.BEGIN) &&
	      (parser.state !== S.BEGIN_WHITESPACE) &&
	      (parser.state !== S.TEXT)) {
	      error(parser, 'Unexpected end')
	    }
	    closeText(parser)
	    parser.c = ''
	    parser.closed = true
	    emit(parser, 'onend')
	    SAXParser.call(parser, parser.strict, parser.opt)
	    return parser
	  }

	  function strictFail (parser, message) {
	    if (typeof parser !== 'object' || !(parser instanceof SAXParser)) {
	      throw new Error('bad call to strictFail')
	    }
	    if (parser.strict) {
	      error(parser, message)
	    }
	  }

	  function newTag (parser) {
	    if (!parser.strict) parser.tagName = parser.tagName[parser.looseCase]()
	    var parent = parser.tags[parser.tags.length - 1] || parser
	    var tag = parser.tag = { name: parser.tagName, attributes: {} }

	    // will be overridden if tag contails an xmlns="foo" or xmlns:foo="bar"
	    if (parser.opt.xmlns) {
	      tag.ns = parent.ns
	    }
	    parser.attribList.length = 0
	    emitNode(parser, 'onopentagstart', tag)
	  }

	  function qname (name, attribute) {
	    var i = name.indexOf(':')
	    var qualName = i < 0 ? [ '', name ] : name.split(':')
	    var prefix = qualName[0]
	    var local = qualName[1]

	    // <x "xmlns"="http://foo">
	    if (attribute && name === 'xmlns') {
	      prefix = 'xmlns'
	      local = ''
	    }

	    return { prefix: prefix, local: local }
	  }

	  function attrib (parser) {
	    if (!parser.strict) {
	      parser.attribName = parser.attribName[parser.looseCase]()
	    }

	    if (parser.attribList.indexOf(parser.attribName) !== -1 ||
	      parser.tag.attributes.hasOwnProperty(parser.attribName)) {
	      parser.attribName = parser.attribValue = ''
	      return
	    }

	    if (parser.opt.xmlns) {
	      var qn = qname(parser.attribName, true)
	      var prefix = qn.prefix
	      var local = qn.local

	      if (prefix === 'xmlns') {
	        // namespace binding attribute. push the binding into scope
	        if (local === 'xml' && parser.attribValue !== XML_NAMESPACE) {
	          strictFail(parser,
	            'xml: prefix must be bound to ' + XML_NAMESPACE + '\n' +
	            'Actual: ' + parser.attribValue)
	        } else if (local === 'xmlns' && parser.attribValue !== XMLNS_NAMESPACE) {
	          strictFail(parser,
	            'xmlns: prefix must be bound to ' + XMLNS_NAMESPACE + '\n' +
	            'Actual: ' + parser.attribValue)
	        } else {
	          var tag = parser.tag
	          var parent = parser.tags[parser.tags.length - 1] || parser
	          if (tag.ns === parent.ns) {
	            tag.ns = Object.create(parent.ns)
	          }
	          tag.ns[local] = parser.attribValue
	        }
	      }

	      // defer onattribute events until all attributes have been seen
	      // so any new bindings can take effect. preserve attribute order
	      // so deferred events can be emitted in document order
	      parser.attribList.push([parser.attribName, parser.attribValue])
	    } else {
	      // in non-xmlns mode, we can emit the event right away
	      parser.tag.attributes[parser.attribName] = parser.attribValue
	      emitNode(parser, 'onattribute', {
	        name: parser.attribName,
	        value: parser.attribValue
	      })
	    }

	    parser.attribName = parser.attribValue = ''
	  }

	  function openTag (parser, selfClosing) {
	    if (parser.opt.xmlns) {
	      // emit namespace binding events
	      var tag = parser.tag

	      // add namespace info to tag
	      var qn = qname(parser.tagName)
	      tag.prefix = qn.prefix
	      tag.local = qn.local
	      tag.uri = tag.ns[qn.prefix] || ''

	      if (tag.prefix && !tag.uri) {
	        strictFail(parser, 'Unbound namespace prefix: ' +
	          JSON.stringify(parser.tagName))
	        tag.uri = qn.prefix
	      }

	      var parent = parser.tags[parser.tags.length - 1] || parser
	      if (tag.ns && parent.ns !== tag.ns) {
	        Object.keys(tag.ns).forEach(function (p) {
	          emitNode(parser, 'onopennamespace', {
	            prefix: p,
	            uri: tag.ns[p]
	          })
	        })
	      }

	      // handle deferred onattribute events
	      // Note: do not apply default ns to attributes:
	      //   http://www.w3.org/TR/REC-xml-names/#defaulting
	      for (var i = 0, l = parser.attribList.length; i < l; i++) {
	        var nv = parser.attribList[i]
	        var name = nv[0]
	        var value = nv[1]
	        var qualName = qname(name, true)
	        var prefix = qualName.prefix
	        var local = qualName.local
	        var uri = prefix === '' ? '' : (tag.ns[prefix] || '')
	        var a = {
	          name: name,
	          value: value,
	          prefix: prefix,
	          local: local,
	          uri: uri
	        }

	        // if there's any attributes with an undefined namespace,
	        // then fail on them now.
	        if (prefix && prefix !== 'xmlns' && !uri) {
	          strictFail(parser, 'Unbound namespace prefix: ' +
	            JSON.stringify(prefix))
	          a.uri = prefix
	        }
	        parser.tag.attributes[name] = a
	        emitNode(parser, 'onattribute', a)
	      }
	      parser.attribList.length = 0
	    }

	    parser.tag.isSelfClosing = !!selfClosing

	    // process the tag
	    parser.sawRoot = true
	    parser.tags.push(parser.tag)
	    emitNode(parser, 'onopentag', parser.tag)
	    if (!selfClosing) {
	      // special case for <script> in non-strict mode.
	      if (!parser.noscript && parser.tagName.toLowerCase() === 'script') {
	        parser.state = S.SCRIPT
	      } else {
	        parser.state = S.TEXT
	      }
	      parser.tag = null
	      parser.tagName = ''
	    }
	    parser.attribName = parser.attribValue = ''
	    parser.attribList.length = 0
	  }

	  function closeTag (parser) {
	    if (!parser.tagName) {
	      strictFail(parser, 'Weird empty close tag.')
	      parser.textNode += '</>'
	      parser.state = S.TEXT
	      return
	    }

	    if (parser.script) {
	      if (parser.tagName !== 'script') {
	        parser.script += '</' + parser.tagName + '>'
	        parser.tagName = ''
	        parser.state = S.SCRIPT
	        return
	      }
	      emitNode(parser, 'onscript', parser.script)
	      parser.script = ''
	    }

	    // first make sure that the closing tag actually exists.
	    // <a><b></c></b></a> will close everything, otherwise.
	    var t = parser.tags.length
	    var tagName = parser.tagName
	    if (!parser.strict) {
	      tagName = tagName[parser.looseCase]()
	    }
	    var closeTo = tagName
	    while (t--) {
	      var close = parser.tags[t]
	      if (close.name !== closeTo) {
	        // fail the first time in strict mode
	        strictFail(parser, 'Unexpected close tag')
	      } else {
	        break
	      }
	    }

	    // didn't find it.  we already failed for strict, so just abort.
	    if (t < 0) {
	      strictFail(parser, 'Unmatched closing tag: ' + parser.tagName)
	      parser.textNode += '</' + parser.tagName + '>'
	      parser.state = S.TEXT
	      return
	    }
	    parser.tagName = tagName
	    var s = parser.tags.length
	    while (s-- > t) {
	      var tag = parser.tag = parser.tags.pop()
	      parser.tagName = parser.tag.name
	      emitNode(parser, 'onclosetag', parser.tagName)

	      var x = {}
	      for (var i in tag.ns) {
	        x[i] = tag.ns[i]
	      }

	      var parent = parser.tags[parser.tags.length - 1] || parser
	      if (parser.opt.xmlns && tag.ns !== parent.ns) {
	        // remove namespace bindings introduced by tag
	        Object.keys(tag.ns).forEach(function (p) {
	          var n = tag.ns[p]
	          emitNode(parser, 'onclosenamespace', { prefix: p, uri: n })
	        })
	      }
	    }
	    if (t === 0) parser.closedRoot = true
	    parser.tagName = parser.attribValue = parser.attribName = ''
	    parser.attribList.length = 0
	    parser.state = S.TEXT
	  }

	  function parseEntity (parser) {
	    var entity = parser.entity
	    var entityLC = entity.toLowerCase()
	    var num
	    var numStr = ''

	    if (parser.ENTITIES[entity]) {
	      return parser.ENTITIES[entity]
	    }
	    if (parser.ENTITIES[entityLC]) {
	      return parser.ENTITIES[entityLC]
	    }
	    entity = entityLC
	    if (entity.charAt(0) === '#') {
	      if (entity.charAt(1) === 'x') {
	        entity = entity.slice(2)
	        num = parseInt(entity, 16)
	        numStr = num.toString(16)
	      } else {
	        entity = entity.slice(1)
	        num = parseInt(entity, 10)
	        numStr = num.toString(10)
	      }
	    }
	    entity = entity.replace(/^0+/, '')
	    if (numStr.toLowerCase() !== entity) {
	      strictFail(parser, 'Invalid character entity')
	      return '&' + parser.entity + ';'
	    }

	    return String.fromCodePoint(num)
	  }

	  function beginWhiteSpace (parser, c) {
	    if (c === '<') {
	      parser.state = S.OPEN_WAKA
	      parser.startTagPosition = parser.position
	    } else if (not(whitespace, c)) {
	      // have to process this as a text node.
	      // weird, but happens.
	      strictFail(parser, 'Non-whitespace before first tag.')
	      parser.textNode = c
	      parser.state = S.TEXT
	    }
	  }

	  function charAt (chunk, i) {
	    var result = ''
	    if (i < chunk.length) {
	      result = chunk.charAt(i)
	    }
	    return result
	  }

	  function write (chunk) {
	    var parser = this
	    if (this.error) {
	      throw this.error
	    }
	    if (parser.closed) {
	      return error(parser,
	        'Cannot write after close. Assign an onready handler.')
	    }
	    if (chunk === null) {
	      return end(parser)
	    }
	    if (typeof chunk === 'object') {
	      chunk = chunk.toString()
	    }
	    var i = 0
	    var c = ''
	    while (true) {
	      c = charAt(chunk, i++)
	      parser.c = c
	      if (!c) {
	        break
	      }
	      if (parser.trackPosition) {
	        parser.position++
	        if (c === '\n') {
	          parser.line++
	          parser.column = 0
	        } else {
	          parser.column++
	        }
	      }
	      switch (parser.state) {
	        case S.BEGIN:
	          parser.state = S.BEGIN_WHITESPACE
	          if (c === '\uFEFF') {
	            continue
	          }
	          beginWhiteSpace(parser, c)
	          continue

	        case S.BEGIN_WHITESPACE:
	          beginWhiteSpace(parser, c)
	          continue

	        case S.TEXT:
	          if (parser.sawRoot && !parser.closedRoot) {
	            var starti = i - 1
	            while (c && c !== '<' && c !== '&') {
	              c = charAt(chunk, i++)
	              if (c && parser.trackPosition) {
	                parser.position++
	                if (c === '\n') {
	                  parser.line++
	                  parser.column = 0
	                } else {
	                  parser.column++
	                }
	              }
	            }
	            parser.textNode += chunk.substring(starti, i - 1)
	          }
	          if (c === '<' && !(parser.sawRoot && parser.closedRoot && !parser.strict)) {
	            parser.state = S.OPEN_WAKA
	            parser.startTagPosition = parser.position
	          } else {
	            if (not(whitespace, c) && (!parser.sawRoot || parser.closedRoot)) {
	              strictFail(parser, 'Text data outside of root node.')
	            }
	            if (c === '&') {
	              parser.state = S.TEXT_ENTITY
	            } else {
	              parser.textNode += c
	            }
	          }
	          continue

	        case S.SCRIPT:
	          // only non-strict
	          if (c === '<') {
	            parser.state = S.SCRIPT_ENDING
	          } else {
	            parser.script += c
	          }
	          continue

	        case S.SCRIPT_ENDING:
	          if (c === '/') {
	            parser.state = S.CLOSE_TAG
	          } else {
	            parser.script += '<' + c
	            parser.state = S.SCRIPT
	          }
	          continue

	        case S.OPEN_WAKA:
	          // either a /, ?, !, or text is coming next.
	          if (c === '!') {
	            parser.state = S.SGML_DECL
	            parser.sgmlDecl = ''
	          } else if (is(whitespace, c)) {
	            // wait for it...
	          } else if (is(nameStart, c)) {
	            parser.state = S.OPEN_TAG
	            parser.tagName = c
	          } else if (c === '/') {
	            parser.state = S.CLOSE_TAG
	            parser.tagName = ''
	          } else if (c === '?') {
	            parser.state = S.PROC_INST
	            parser.procInstName = parser.procInstBody = ''
	          } else {
	            strictFail(parser, 'Unencoded <')
	            // if there was some whitespace, then add that in.
	            if (parser.startTagPosition + 1 < parser.position) {
	              var pad = parser.position - parser.startTagPosition
	              c = new Array(pad).join(' ') + c
	            }
	            parser.textNode += '<' + c
	            parser.state = S.TEXT
	          }
	          continue

	        case S.SGML_DECL:
	          if ((parser.sgmlDecl + c).toUpperCase() === CDATA) {
	            emitNode(parser, 'onopencdata')
	            parser.state = S.CDATA
	            parser.sgmlDecl = ''
	            parser.cdata = ''
	          } else if (parser.sgmlDecl + c === '--') {
	            parser.state = S.COMMENT
	            parser.comment = ''
	            parser.sgmlDecl = ''
	          } else if ((parser.sgmlDecl + c).toUpperCase() === DOCTYPE) {
	            parser.state = S.DOCTYPE
	            if (parser.doctype || parser.sawRoot) {
	              strictFail(parser,
	                'Inappropriately located doctype declaration')
	            }
	            parser.doctype = ''
	            parser.sgmlDecl = ''
	          } else if (c === '>') {
	            emitNode(parser, 'onsgmldeclaration', parser.sgmlDecl)
	            parser.sgmlDecl = ''
	            parser.state = S.TEXT
	          } else if (is(quote, c)) {
	            parser.state = S.SGML_DECL_QUOTED
	            parser.sgmlDecl += c
	          } else {
	            parser.sgmlDecl += c
	          }
	          continue

	        case S.SGML_DECL_QUOTED:
	          if (c === parser.q) {
	            parser.state = S.SGML_DECL
	            parser.q = ''
	          }
	          parser.sgmlDecl += c
	          continue

	        case S.DOCTYPE:
	          if (c === '>') {
	            parser.state = S.TEXT
	            emitNode(parser, 'ondoctype', parser.doctype)
	            parser.doctype = true // just remember that we saw it.
	          } else {
	            parser.doctype += c
	            if (c === '[') {
	              parser.state = S.DOCTYPE_DTD
	            } else if (is(quote, c)) {
	              parser.state = S.DOCTYPE_QUOTED
	              parser.q = c
	            }
	          }
	          continue

	        case S.DOCTYPE_QUOTED:
	          parser.doctype += c
	          if (c === parser.q) {
	            parser.q = ''
	            parser.state = S.DOCTYPE
	          }
	          continue

	        case S.DOCTYPE_DTD:
	          parser.doctype += c
	          if (c === ']') {
	            parser.state = S.DOCTYPE
	          } else if (is(quote, c)) {
	            parser.state = S.DOCTYPE_DTD_QUOTED
	            parser.q = c
	          }
	          continue

	        case S.DOCTYPE_DTD_QUOTED:
	          parser.doctype += c
	          if (c === parser.q) {
	            parser.state = S.DOCTYPE_DTD
	            parser.q = ''
	          }
	          continue

	        case S.COMMENT:
	          if (c === '-') {
	            parser.state = S.COMMENT_ENDING
	          } else {
	            parser.comment += c
	          }
	          continue

	        case S.COMMENT_ENDING:
	          if (c === '-') {
	            parser.state = S.COMMENT_ENDED
	            parser.comment = textopts(parser.opt, parser.comment)
	            if (parser.comment) {
	              emitNode(parser, 'oncomment', parser.comment)
	            }
	            parser.comment = ''
	          } else {
	            parser.comment += '-' + c
	            parser.state = S.COMMENT
	          }
	          continue

	        case S.COMMENT_ENDED:
	          if (c !== '>') {
	            strictFail(parser, 'Malformed comment')
	            // allow <!-- blah -- bloo --> in non-strict mode,
	            // which is a comment of " blah -- bloo "
	            parser.comment += '--' + c
	            parser.state = S.COMMENT
	          } else {
	            parser.state = S.TEXT
	          }
	          continue

	        case S.CDATA:
	          if (c === ']') {
	            parser.state = S.CDATA_ENDING
	          } else {
	            parser.cdata += c
	          }
	          continue

	        case S.CDATA_ENDING:
	          if (c === ']') {
	            parser.state = S.CDATA_ENDING_2
	          } else {
	            parser.cdata += ']' + c
	            parser.state = S.CDATA
	          }
	          continue

	        case S.CDATA_ENDING_2:
	          if (c === '>') {
	            if (parser.cdata) {
	              emitNode(parser, 'oncdata', parser.cdata)
	            }
	            emitNode(parser, 'onclosecdata')
	            parser.cdata = ''
	            parser.state = S.TEXT
	          } else if (c === ']') {
	            parser.cdata += ']'
	          } else {
	            parser.cdata += ']]' + c
	            parser.state = S.CDATA
	          }
	          continue

	        case S.PROC_INST:
	          if (c === '?') {
	            parser.state = S.PROC_INST_ENDING
	          } else if (is(whitespace, c)) {
	            parser.state = S.PROC_INST_BODY
	          } else {
	            parser.procInstName += c
	          }
	          continue

	        case S.PROC_INST_BODY:
	          if (!parser.procInstBody && is(whitespace, c)) {
	            continue
	          } else if (c === '?') {
	            parser.state = S.PROC_INST_ENDING
	          } else {
	            parser.procInstBody += c
	          }
	          continue

	        case S.PROC_INST_ENDING:
	          if (c === '>') {
	            emitNode(parser, 'onprocessinginstruction', {
	              name: parser.procInstName,
	              body: parser.procInstBody
	            })
	            parser.procInstName = parser.procInstBody = ''
	            parser.state = S.TEXT
	          } else {
	            parser.procInstBody += '?' + c
	            parser.state = S.PROC_INST_BODY
	          }
	          continue

	        case S.OPEN_TAG:
	          if (is(nameBody, c)) {
	            parser.tagName += c
	          } else {
	            newTag(parser)
	            if (c === '>') {
	              openTag(parser)
	            } else if (c === '/') {
	              parser.state = S.OPEN_TAG_SLASH
	            } else {
	              if (not(whitespace, c)) {
	                strictFail(parser, 'Invalid character in tag name')
	              }
	              parser.state = S.ATTRIB
	            }
	          }
	          continue

	        case S.OPEN_TAG_SLASH:
	          if (c === '>') {
	            openTag(parser, true)
	            closeTag(parser)
	          } else {
	            strictFail(parser, 'Forward-slash in opening tag not followed by >')
	            parser.state = S.ATTRIB
	          }
	          continue

	        case S.ATTRIB:
	          // haven't read the attribute name yet.
	          if (is(whitespace, c)) {
	            continue
	          } else if (c === '>') {
	            openTag(parser)
	          } else if (c === '/') {
	            parser.state = S.OPEN_TAG_SLASH
	          } else if (is(nameStart, c)) {
	            parser.attribName = c
	            parser.attribValue = ''
	            parser.state = S.ATTRIB_NAME
	          } else {
	            strictFail(parser, 'Invalid attribute name')
	          }
	          continue

	        case S.ATTRIB_NAME:
	          if (c === '=') {
	            parser.state = S.ATTRIB_VALUE
	          } else if (c === '>') {
	            strictFail(parser, 'Attribute without value')
	            parser.attribValue = parser.attribName
	            attrib(parser)
	            openTag(parser)
	          } else if (is(whitespace, c)) {
	            parser.state = S.ATTRIB_NAME_SAW_WHITE
	          } else if (is(nameBody, c)) {
	            parser.attribName += c
	          } else {
	            strictFail(parser, 'Invalid attribute name')
	          }
	          continue

	        case S.ATTRIB_NAME_SAW_WHITE:
	          if (c === '=') {
	            parser.state = S.ATTRIB_VALUE
	          } else if (is(whitespace, c)) {
	            continue
	          } else {
	            strictFail(parser, 'Attribute without value')
	            parser.tag.attributes[parser.attribName] = ''
	            parser.attribValue = ''
	            emitNode(parser, 'onattribute', {
	              name: parser.attribName,
	              value: ''
	            })
	            parser.attribName = ''
	            if (c === '>') {
	              openTag(parser)
	            } else if (is(nameStart, c)) {
	              parser.attribName = c
	              parser.state = S.ATTRIB_NAME
	            } else {
	              strictFail(parser, 'Invalid attribute name')
	              parser.state = S.ATTRIB
	            }
	          }
	          continue

	        case S.ATTRIB_VALUE:
	          if (is(whitespace, c)) {
	            continue
	          } else if (is(quote, c)) {
	            parser.q = c
	            parser.state = S.ATTRIB_VALUE_QUOTED
	          } else {
	            strictFail(parser, 'Unquoted attribute value')
	            parser.state = S.ATTRIB_VALUE_UNQUOTED
	            parser.attribValue = c
	          }
	          continue

	        case S.ATTRIB_VALUE_QUOTED:
	          if (c !== parser.q) {
	            if (c === '&') {
	              parser.state = S.ATTRIB_VALUE_ENTITY_Q
	            } else {
	              parser.attribValue += c
	            }
	            continue
	          }
	          attrib(parser)
	          parser.q = ''
	          parser.state = S.ATTRIB_VALUE_CLOSED
	          continue

	        case S.ATTRIB_VALUE_CLOSED:
	          if (is(whitespace, c)) {
	            parser.state = S.ATTRIB
	          } else if (c === '>') {
	            openTag(parser)
	          } else if (c === '/') {
	            parser.state = S.OPEN_TAG_SLASH
	          } else if (is(nameStart, c)) {
	            strictFail(parser, 'No whitespace between attributes')
	            parser.attribName = c
	            parser.attribValue = ''
	            parser.state = S.ATTRIB_NAME
	          } else {
	            strictFail(parser, 'Invalid attribute name')
	          }
	          continue

	        case S.ATTRIB_VALUE_UNQUOTED:
	          if (not(attribEnd, c)) {
	            if (c === '&') {
	              parser.state = S.ATTRIB_VALUE_ENTITY_U
	            } else {
	              parser.attribValue += c
	            }
	            continue
	          }
	          attrib(parser)
	          if (c === '>') {
	            openTag(parser)
	          } else {
	            parser.state = S.ATTRIB
	          }
	          continue

	        case S.CLOSE_TAG:
	          if (!parser.tagName) {
	            if (is(whitespace, c)) {
	              continue
	            } else if (not(nameStart, c)) {
	              if (parser.script) {
	                parser.script += '</' + c
	                parser.state = S.SCRIPT
	              } else {
	                strictFail(parser, 'Invalid tagname in closing tag.')
	              }
	            } else {
	              parser.tagName = c
	            }
	          } else if (c === '>') {
	            closeTag(parser)
	          } else if (is(nameBody, c)) {
	            parser.tagName += c
	          } else if (parser.script) {
	            parser.script += '</' + parser.tagName
	            parser.tagName = ''
	            parser.state = S.SCRIPT
	          } else {
	            if (not(whitespace, c)) {
	              strictFail(parser, 'Invalid tagname in closing tag')
	            }
	            parser.state = S.CLOSE_TAG_SAW_WHITE
	          }
	          continue

	        case S.CLOSE_TAG_SAW_WHITE:
	          if (is(whitespace, c)) {
	            continue
	          }
	          if (c === '>') {
	            closeTag(parser)
	          } else {
	            strictFail(parser, 'Invalid characters in closing tag')
	          }
	          continue

	        case S.TEXT_ENTITY:
	        case S.ATTRIB_VALUE_ENTITY_Q:
	        case S.ATTRIB_VALUE_ENTITY_U:
	          var returnState
	          var buffer
	          switch (parser.state) {
	            case S.TEXT_ENTITY:
	              returnState = S.TEXT
	              buffer = 'textNode'
	              break

	            case S.ATTRIB_VALUE_ENTITY_Q:
	              returnState = S.ATTRIB_VALUE_QUOTED
	              buffer = 'attribValue'
	              break

	            case S.ATTRIB_VALUE_ENTITY_U:
	              returnState = S.ATTRIB_VALUE_UNQUOTED
	              buffer = 'attribValue'
	              break
	          }

	          if (c === ';') {
	            parser[buffer] += parseEntity(parser)
	            parser.entity = ''
	            parser.state = returnState
	          } else if (is(parser.entity.length ? entityBody : entityStart, c)) {
	            parser.entity += c
	          } else {
	            strictFail(parser, 'Invalid character in entity name')
	            parser[buffer] += '&' + parser.entity + c
	            parser.entity = ''
	            parser.state = returnState
	          }

	          continue

	        default:
	          throw new Error(parser, 'Unknown state: ' + parser.state)
	      }
	    } // while

	    if (parser.position >= parser.bufferCheckPosition) {
	      checkBufferLength(parser)
	    }
	    return parser
	  }

	  /*! http://mths.be/fromcodepoint v0.1.0 by @mathias */
	  if (!String.fromCodePoint) {
	    (function () {
	      var stringFromCharCode = String.fromCharCode
	      var floor = Math.floor
	      var fromCodePoint = function () {
	        var MAX_SIZE = 0x4000
	        var codeUnits = []
	        var highSurrogate
	        var lowSurrogate
	        var index = -1
	        var length = arguments.length
	        if (!length) {
	          return ''
	        }
	        var result = ''
	        while (++index < length) {
	          var codePoint = Number(arguments[index])
	          if (
	            !isFinite(codePoint) || // `NaN`, `+Infinity`, or `-Infinity`
	            codePoint < 0 || // not a valid Unicode code point
	            codePoint > 0x10FFFF || // not a valid Unicode code point
	            floor(codePoint) !== codePoint // not an integer
	          ) {
	            throw RangeError('Invalid code point: ' + codePoint)
	          }
	          if (codePoint <= 0xFFFF) { // BMP code point
	            codeUnits.push(codePoint)
	          } else { // Astral code point; split in surrogate halves
	            // http://mathiasbynens.be/notes/javascript-encoding#surrogate-formulae
	            codePoint -= 0x10000
	            highSurrogate = (codePoint >> 10) + 0xD800
	            lowSurrogate = (codePoint % 0x400) + 0xDC00
	            codeUnits.push(highSurrogate, lowSurrogate)
	          }
	          if (index + 1 === length || codeUnits.length > MAX_SIZE) {
	            result += stringFromCharCode.apply(null, codeUnits)
	            codeUnits.length = 0
	          }
	        }
	        return result
	      }
	      if (Object.defineProperty) {
	        Object.defineProperty(String, 'fromCodePoint', {
	          value: fromCodePoint,
	          configurable: true,
	          writable: true
	        })
	      } else {
	        String.fromCodePoint = fromCodePoint
	      }
	    }())
	  }
	})(typeof exports === 'undefined' ? this.sax = {} : exports)
	
	/* WEBPACK VAR INJECTION */}.call(exports, __webpack_require__(87).Buffer))

/***/ },
/* 256 */
/***/ function(module, exports, __webpack_require__) {

	// Generated by CoffeeScript 1.9.1
	(function() {
	  var XMLBuilder, assign;

	  assign = __webpack_require__(331);

	  XMLBuilder = __webpack_require__(319);

	  module.exports.create = function(name, xmldec, doctype, options) {
	    options = assign({}, xmldec, doctype, options);
	    return new XMLBuilder(name, options).root();
	  };

	}).call(this);


/***/ },
/* 257 */
/***/ function(module, exports, __webpack_require__) {

	/* (ignored) */

/***/ },
/* 258 */
/***/ function(module, exports, __webpack_require__) {

	// Copyright Joyent, Inc. and other Node contributors.
	//
	// Permission is hereby granted, free of charge, to any person obtaining a
	// copy of this software and associated documentation files (the
	// "Software"), to deal in the Software without restriction, including
	// without limitation the rights to use, copy, modify, merge, publish,
	// distribute, sublicense, and/or sell copies of the Software, and to permit
	// persons to whom the Software is furnished to do so, subject to the
	// following conditions:
	//
	// The above copyright notice and this permission notice shall be included
	// in all copies or substantial portions of the Software.
	//
	// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
	// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
	// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
	// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
	// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
	// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
	// USE OR OTHER DEALINGS IN THE SOFTWARE.

	var Buffer = __webpack_require__(87).Buffer;

	var isBufferEncoding = Buffer.isEncoding
	  || function(encoding) {
	       switch (encoding && encoding.toLowerCase()) {
	         case 'hex': case 'utf8': case 'utf-8': case 'ascii': case 'binary': case 'base64': case 'ucs2': case 'ucs-2': case 'utf16le': case 'utf-16le': case 'raw': return true;
	         default: return false;
	       }
	     }


	function assertEncoding(encoding) {
	  if (encoding && !isBufferEncoding(encoding)) {
	    throw new Error('Unknown encoding: ' + encoding);
	  }
	}

	// StringDecoder provides an interface for efficiently splitting a series of
	// buffers into a series of JS strings without breaking apart multi-byte
	// characters. CESU-8 is handled as part of the UTF-8 encoding.
	//
	// @TODO Handling all encodings inside a single object makes it very difficult
	// to reason about this code, so it should be split up in the future.
	// @TODO There should be a utf8-strict encoding that rejects invalid UTF-8 code
	// points as used by CESU-8.
	var StringDecoder = exports.StringDecoder = function(encoding) {
	  this.encoding = (encoding || 'utf8').toLowerCase().replace(/[-_]/, '');
	  assertEncoding(encoding);
	  switch (this.encoding) {
	    case 'utf8':
	      // CESU-8 represents each of Surrogate Pair by 3-bytes
	      this.surrogateSize = 3;
	      break;
	    case 'ucs2':
	    case 'utf16le':
	      // UTF-16 represents each of Surrogate Pair by 2-bytes
	      this.surrogateSize = 2;
	      this.detectIncompleteChar = utf16DetectIncompleteChar;
	      break;
	    case 'base64':
	      // Base-64 stores 3 bytes in 4 chars, and pads the remainder.
	      this.surrogateSize = 3;
	      this.detectIncompleteChar = base64DetectIncompleteChar;
	      break;
	    default:
	      this.write = passThroughWrite;
	      return;
	  }

	  // Enough space to store all bytes of a single character. UTF-8 needs 4
	  // bytes, but CESU-8 may require up to 6 (3 bytes per surrogate).
	  this.charBuffer = new Buffer(6);
	  // Number of bytes received for the current incomplete multi-byte character.
	  this.charReceived = 0;
	  // Number of bytes expected for the current incomplete multi-byte character.
	  this.charLength = 0;
	};


	// write decodes the given buffer and returns it as JS string that is
	// guaranteed to not contain any partial multi-byte characters. Any partial
	// character found at the end of the buffer is buffered up, and will be
	// returned when calling write again with the remaining bytes.
	//
	// Note: Converting a Buffer containing an orphan surrogate to a String
	// currently works, but converting a String to a Buffer (via `new Buffer`, or
	// Buffer#write) will replace incomplete surrogates with the unicode
	// replacement character. See https://codereview.chromium.org/121173009/ .
	StringDecoder.prototype.write = function(buffer) {
	  var charStr = '';
	  // if our last write ended with an incomplete multibyte character
	  while (this.charLength) {
	    // determine how many remaining bytes this buffer has to offer for this char
	    var available = (buffer.length >= this.charLength - this.charReceived) ?
	        this.charLength - this.charReceived :
	        buffer.length;

	    // add the new bytes to the char buffer
	    buffer.copy(this.charBuffer, this.charReceived, 0, available);
	    this.charReceived += available;

	    if (this.charReceived < this.charLength) {
	      // still not enough chars in this buffer? wait for more ...
	      return '';
	    }

	    // remove bytes belonging to the current character from the buffer
	    buffer = buffer.slice(available, buffer.length);

	    // get the character that was split
	    charStr = this.charBuffer.slice(0, this.charLength).toString(this.encoding);

	    // CESU-8: lead surrogate (D800-DBFF) is also the incomplete character
	    var charCode = charStr.charCodeAt(charStr.length - 1);
	    if (charCode >= 0xD800 && charCode <= 0xDBFF) {
	      this.charLength += this.surrogateSize;
	      charStr = '';
	      continue;
	    }
	    this.charReceived = this.charLength = 0;

	    // if there are no more bytes in this buffer, just emit our char
	    if (buffer.length === 0) {
	      return charStr;
	    }
	    break;
	  }

	  // determine and set charLength / charReceived
	  this.detectIncompleteChar(buffer);

	  var end = buffer.length;
	  if (this.charLength) {
	    // buffer the incomplete character bytes we got
	    buffer.copy(this.charBuffer, 0, buffer.length - this.charReceived, end);
	    end -= this.charReceived;
	  }

	  charStr += buffer.toString(this.encoding, 0, end);

	  var end = charStr.length - 1;
	  var charCode = charStr.charCodeAt(end);
	  // CESU-8: lead surrogate (D800-DBFF) is also the incomplete character
	  if (charCode >= 0xD800 && charCode <= 0xDBFF) {
	    var size = this.surrogateSize;
	    this.charLength += size;
	    this.charReceived += size;
	    this.charBuffer.copy(this.charBuffer, size, 0, size);
	    buffer.copy(this.charBuffer, 0, 0, size);
	    return charStr.substring(0, end);
	  }

	  // or just emit the charStr
	  return charStr;
	};

	// detectIncompleteChar determines if there is an incomplete UTF-8 character at
	// the end of the given buffer. If so, it sets this.charLength to the byte
	// length that character, and sets this.charReceived to the number of bytes
	// that are available for this character.
	StringDecoder.prototype.detectIncompleteChar = function(buffer) {
	  // determine how many bytes we have to check at the end of this buffer
	  var i = (buffer.length >= 3) ? 3 : buffer.length;

	  // Figure out if one of the last i bytes of our buffer announces an
	  // incomplete char.
	  for (; i > 0; i--) {
	    var c = buffer[buffer.length - i];

	    // See http://en.wikipedia.org/wiki/UTF-8#Description

	    // 110XXXXX
	    if (i == 1 && c >> 5 == 0x06) {
	      this.charLength = 2;
	      break;
	    }

	    // 1110XXXX
	    if (i <= 2 && c >> 4 == 0x0E) {
	      this.charLength = 3;
	      break;
	    }

	    // 11110XXX
	    if (i <= 3 && c >> 3 == 0x1E) {
	      this.charLength = 4;
	      break;
	    }
	  }
	  this.charReceived = i;
	};

	StringDecoder.prototype.end = function(buffer) {
	  var res = '';
	  if (buffer && buffer.length)
	    res = this.write(buffer);

	  if (this.charReceived) {
	    var cr = this.charReceived;
	    var buf = this.charBuffer;
	    var enc = this.encoding;
	    res += buf.slice(0, cr).toString(enc);
	  }

	  return res;
	};

	function passThroughWrite(buffer) {
	  return buffer.toString(this.encoding);
	}

	function utf16DetectIncompleteChar(buffer) {
	  this.charReceived = buffer.length % 2;
	  this.charLength = this.charReceived ? 2 : 0;
	}

	function base64DetectIncompleteChar(buffer) {
	  this.charReceived = buffer.length % 3;
	  this.charLength = this.charReceived ? 3 : 0;
	}


/***/ },
/* 259 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = toDate;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function toDate(date) {
	  (0, _assertString2.default)(date);
	  date = Date.parse(date);
	  return !isNaN(date) ? new Date(date) : null;
	}
	module.exports = exports['default'];

/***/ },
/* 260 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = toFloat;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function toFloat(str) {
	  (0, _assertString2.default)(str);
	  return parseFloat(str);
	}
	module.exports = exports['default'];

/***/ },
/* 261 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = toInt;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function toInt(str, radix) {
	  (0, _assertString2.default)(str);
	  return parseInt(str, radix || 10);
	}
	module.exports = exports['default'];

/***/ },
/* 262 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = toBoolean;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function toBoolean(str, strict) {
	  (0, _assertString2.default)(str);
	  if (strict) {
	    return str === '1' || str === 'true';
	  }
	  return str !== '0' && str !== 'false' && str !== '';
	}
	module.exports = exports['default'];

/***/ },
/* 263 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = equals;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function equals(str, comparison) {
	  (0, _assertString2.default)(str);
	  return str === comparison;
	}
	module.exports = exports['default'];

/***/ },
/* 264 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = contains;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	var _toString = __webpack_require__(317);

	var _toString2 = _interopRequireDefault(_toString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function contains(str, elem) {
	  (0, _assertString2.default)(str);
	  return str.indexOf((0, _toString2.default)(elem)) >= 0;
	}
	module.exports = exports['default'];

/***/ },
/* 265 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = matches;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function matches(str, pattern, modifiers) {
	  (0, _assertString2.default)(str);
	  if (Object.prototype.toString.call(pattern) !== '[object RegExp]') {
	    pattern = new RegExp(pattern, modifiers);
	  }
	  return pattern.test(str);
	}
	module.exports = exports['default'];

/***/ },
/* 266 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isEmail;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	var _merge = __webpack_require__(325);

	var _merge2 = _interopRequireDefault(_merge);

	var _isByteLength = __webpack_require__(292);

	var _isByteLength2 = _interopRequireDefault(_isByteLength);

	var _isFQDN = __webpack_require__(270);

	var _isFQDN2 = _interopRequireDefault(_isFQDN);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	var default_email_options = {
	  allow_display_name: false,
	  allow_utf8_local_part: true,
	  require_tld: true
	};

	/* eslint-disable max-len */
	var displayName = /^[a-z\d!#\$%&'\*\+\-\/=\?\^_`{\|}~\.\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]+[a-z\d!#\$%&'\*\+\-\/=\?\^_`{\|}~\.\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF\s]*<(.+)>$/i;
	var emailUserPart = /^[a-z\d!#\$%&'\*\+\-\/=\?\^_`{\|}~]+$/i;
	var quotedEmailUser = /^([\s\x01-\x08\x0b\x0c\x0e-\x1f\x7f\x21\x23-\x5b\x5d-\x7e]|(\\[\x01-\x09\x0b\x0c\x0d-\x7f]))*$/i;
	var emailUserUtf8Part = /^[a-z\d!#\$%&'\*\+\-\/=\?\^_`{\|}~\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]+$/i;
	var quotedEmailUserUtf8 = /^([\s\x01-\x08\x0b\x0c\x0e-\x1f\x7f\x21\x23-\x5b\x5d-\x7e\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]|(\\[\x01-\x09\x0b\x0c\x0d-\x7f\u00A0-\uD7FF\uF900-\uFDCF\uFDF0-\uFFEF]))*$/i;
	/* eslint-enable max-len */

	function isEmail(str, options) {
	  (0, _assertString2.default)(str);
	  options = (0, _merge2.default)(options, default_email_options);

	  if (options.allow_display_name) {
	    var display_email = str.match(displayName);
	    if (display_email) {
	      str = display_email[1];
	    }
	  }

	  var parts = str.split('@');
	  var domain = parts.pop();
	  var user = parts.join('@');

	  var lower_domain = domain.toLowerCase();
	  if (lower_domain === 'gmail.com' || lower_domain === 'googlemail.com') {
	    user = user.replace(/\./g, '').toLowerCase();
	  }

	  if (!(0, _isByteLength2.default)(user, { max: 64 }) || !(0, _isByteLength2.default)(domain, { max: 256 })) {
	    return false;
	  }

	  if (!(0, _isFQDN2.default)(domain, { require_tld: options.require_tld })) {
	    return false;
	  }

	  if (user[0] === '"') {
	    user = user.slice(1, user.length - 1);
	    return options.allow_utf8_local_part ? quotedEmailUserUtf8.test(user) : quotedEmailUser.test(user);
	  }

	  var pattern = options.allow_utf8_local_part ? emailUserUtf8Part : emailUserPart;

	  var user_parts = user.split('.');
	  for (var i = 0; i < user_parts.length; i++) {
	    if (!pattern.test(user_parts[i])) {
	      return false;
	    }
	  }

	  return true;
	}
	module.exports = exports['default'];

/***/ },
/* 267 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isURL;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	var _isFQDN = __webpack_require__(270);

	var _isFQDN2 = _interopRequireDefault(_isFQDN);

	var _isIP = __webpack_require__(269);

	var _isIP2 = _interopRequireDefault(_isIP);

	var _merge = __webpack_require__(325);

	var _merge2 = _interopRequireDefault(_merge);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	var default_url_options = {
	  protocols: ['http', 'https', 'ftp'],
	  require_tld: true,
	  require_protocol: false,
	  require_valid_protocol: true,
	  allow_underscores: false,
	  allow_trailing_dot: false,
	  allow_protocol_relative_urls: false
	};

	function isURL(url, options) {
	  (0, _assertString2.default)(url);
	  if (!url || url.length >= 2083 || /\s/.test(url)) {
	    return false;
	  }
	  if (url.indexOf('mailto:') === 0) {
	    return false;
	  }
	  options = (0, _merge2.default)(options, default_url_options);
	  var protocol = void 0,
	      auth = void 0,
	      host = void 0,
	      hostname = void 0,
	      port = void 0,
	      port_str = void 0,
	      split = void 0;

	  split = url.split('#');
	  url = split.shift();

	  split = url.split('?');
	  url = split.shift();

	  split = url.split('://');
	  if (split.length > 1) {
	    protocol = split.shift();
	    if (options.require_valid_protocol && options.protocols.indexOf(protocol) === -1) {
	      return false;
	    }
	  } else if (options.require_protocol) {
	    return false;
	  } else if (options.allow_protocol_relative_urls && url.substr(0, 2) === '//') {
	    split[0] = url.substr(2);
	  }
	  url = split.join('://');

	  split = url.split('/');
	  url = split.shift();
	  split = url.split('@');
	  if (split.length > 1) {
	    auth = split.shift();
	    if (auth.indexOf(':') >= 0 && auth.split(':').length > 2) {
	      return false;
	    }
	  }
	  hostname = split.join('@');
	  split = hostname.split(':');
	  host = split.shift();
	  if (split.length) {
	    port_str = split.join(':');
	    port = parseInt(port_str, 10);
	    if (!/^[0-9]+$/.test(port_str) || port <= 0 || port > 65535) {
	      return false;
	    }
	  }
	  if (!(0, _isIP2.default)(host) && !(0, _isFQDN2.default)(host, options) && host !== 'localhost') {
	    return false;
	  }
	  if (options.host_whitelist && options.host_whitelist.indexOf(host) === -1) {
	    return false;
	  }
	  if (options.host_blacklist && options.host_blacklist.indexOf(host) !== -1) {
	    return false;
	  }
	  return true;
	}
	module.exports = exports['default'];

/***/ },
/* 268 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isMACAddress;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	var macAddress = /^([0-9a-fA-F][0-9a-fA-F]:){5}([0-9a-fA-F][0-9a-fA-F])$/;

	function isMACAddress(str) {
	  (0, _assertString2.default)(str);
	  return macAddress.test(str);
	}
	module.exports = exports['default'];

/***/ },
/* 269 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isIP;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	var ipv4Maybe = /^(\d{1,3})\.(\d{1,3})\.(\d{1,3})\.(\d{1,3})$/;
	var ipv6Block = /^[0-9A-F]{1,4}$/i;

	function isIP(str) {
	  var version = arguments.length <= 1 || arguments[1] === undefined ? '' : arguments[1];

	  (0, _assertString2.default)(str);
	  version = String(version);
	  if (!version) {
	    return isIP(str, 4) || isIP(str, 6);
	  } else if (version === '4') {
	    if (!ipv4Maybe.test(str)) {
	      return false;
	    }
	    var parts = str.split('.').sort(function (a, b) {
	      return a - b;
	    });
	    return parts[3] <= 255;
	  } else if (version === '6') {
	    var blocks = str.split(':');
	    var foundOmissionBlock = false; // marker to indicate ::

	    // At least some OS accept the last 32 bits of an IPv6 address
	    // (i.e. 2 of the blocks) in IPv4 notation, and RFC 3493 says
	    // that '::ffff:a.b.c.d' is valid for IPv4-mapped IPv6 addresses,
	    // and '::a.b.c.d' is deprecated, but also valid.
	    var foundIPv4TransitionBlock = isIP(blocks[blocks.length - 1], 4);
	    var expectedNumberOfBlocks = foundIPv4TransitionBlock ? 7 : 8;

	    if (blocks.length > expectedNumberOfBlocks) {
	      return false;
	    }
	    // initial or final ::
	    if (str === '::') {
	      return true;
	    } else if (str.substr(0, 2) === '::') {
	      blocks.shift();
	      blocks.shift();
	      foundOmissionBlock = true;
	    } else if (str.substr(str.length - 2) === '::') {
	      blocks.pop();
	      blocks.pop();
	      foundOmissionBlock = true;
	    }

	    for (var i = 0; i < blocks.length; ++i) {
	      // test for a :: which can not be at the string start/end
	      // since those cases have been handled above
	      if (blocks[i] === '' && i > 0 && i < blocks.length - 1) {
	        if (foundOmissionBlock) {
	          return false; // multiple :: in address
	        }
	        foundOmissionBlock = true;
	      } else if (foundIPv4TransitionBlock && i === blocks.length - 1) {
	        // it has been checked before that the last
	        // block is a valid IPv4 address
	      } else if (!ipv6Block.test(blocks[i])) {
	          return false;
	        }
	    }
	    if (foundOmissionBlock) {
	      return blocks.length >= 1;
	    }
	    return blocks.length === expectedNumberOfBlocks;
	  }
	  return false;
	}
	module.exports = exports['default'];

/***/ },
/* 270 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isFDQN;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	var _merge = __webpack_require__(325);

	var _merge2 = _interopRequireDefault(_merge);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	var default_fqdn_options = {
	  require_tld: true,
	  allow_underscores: false,
	  allow_trailing_dot: false
	};

	function isFDQN(str, options) {
	  (0, _assertString2.default)(str);
	  options = (0, _merge2.default)(options, default_fqdn_options);

	  /* Remove the optional trailing dot before checking validity */
	  if (options.allow_trailing_dot && str[str.length - 1] === '.') {
	    str = str.substring(0, str.length - 1);
	  }
	  var parts = str.split('.');
	  if (options.require_tld) {
	    var tld = parts.pop();
	    if (!parts.length || !/^([a-z\u00a1-\uffff]{2,}|xn[a-z0-9-]{2,})$/i.test(tld)) {
	      return false;
	    }
	  }
	  for (var part, i = 0; i < parts.length; i++) {
	    part = parts[i];
	    if (options.allow_underscores) {
	      part = part.replace(/_/g, '');
	    }
	    if (!/^[a-z\u00a1-\uffff0-9-]+$/i.test(part)) {
	      return false;
	    }
	    if (/[\uff01-\uff5e]/.test(part)) {
	      // disallow full-width chars
	      return false;
	    }
	    if (part[0] === '-' || part[part.length - 1] === '-') {
	      return false;
	    }
	  }
	  return true;
	}
	module.exports = exports['default'];

/***/ },
/* 271 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isBoolean;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function isBoolean(str) {
	  (0, _assertString2.default)(str);
	  return ['true', 'false', '1', '0'].indexOf(str) >= 0;
	}
	module.exports = exports['default'];

/***/ },
/* 272 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isAlpha;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	var _alpha = __webpack_require__(326);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function isAlpha(str) {
	  var locale = arguments.length <= 1 || arguments[1] === undefined ? 'en-US' : arguments[1];

	  (0, _assertString2.default)(str);
	  if (locale in _alpha.alpha) {
	    return _alpha.alpha[locale].test(str);
	  }
	  throw new Error('Invalid locale \'' + locale + '\'');
	}
	module.exports = exports['default'];

/***/ },
/* 273 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isAlphanumeric;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	var _alpha = __webpack_require__(326);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function isAlphanumeric(str) {
	  var locale = arguments.length <= 1 || arguments[1] === undefined ? 'en-US' : arguments[1];

	  (0, _assertString2.default)(str);
	  if (locale in _alpha.alphanumeric) {
	    return _alpha.alphanumeric[locale].test(str);
	  }
	  throw new Error('Invalid locale \'' + locale + '\'');
	}
	module.exports = exports['default'];

/***/ },
/* 274 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isNumeric;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	var numeric = /^[-+]?[0-9]+$/;

	function isNumeric(str) {
	  (0, _assertString2.default)(str);
	  return numeric.test(str);
	}
	module.exports = exports['default'];

/***/ },
/* 275 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isLowercase;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function isLowercase(str) {
	  (0, _assertString2.default)(str);
	  return str === str.toLowerCase();
	}
	module.exports = exports['default'];

/***/ },
/* 276 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isUppercase;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function isUppercase(str) {
	  (0, _assertString2.default)(str);
	  return str === str.toUpperCase();
	}
	module.exports = exports['default'];

/***/ },
/* 277 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isAscii;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	var ascii = /^[\x00-\x7F]+$/;

	function isAscii(str) {
	  (0, _assertString2.default)(str);
	  return ascii.test(str);
	}
	module.exports = exports['default'];

/***/ },
/* 278 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.fullWidth = undefined;
	exports.default = isFullWidth;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	var fullWidth = exports.fullWidth = /[^\u0020-\u007E\uFF61-\uFF9F\uFFA0-\uFFDC\uFFE8-\uFFEE0-9a-zA-Z]/;

	function isFullWidth(str) {
	  (0, _assertString2.default)(str);
	  return fullWidth.test(str);
	}

/***/ },
/* 279 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.halfWidth = undefined;
	exports.default = isHalfWidth;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	var halfWidth = exports.halfWidth = /[\u0020-\u007E\uFF61-\uFF9F\uFFA0-\uFFDC\uFFE8-\uFFEE0-9a-zA-Z]/;

	function isHalfWidth(str) {
	  (0, _assertString2.default)(str);
	  return halfWidth.test(str);
	}

/***/ },
/* 280 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isVariableWidth;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	var _isFullWidth = __webpack_require__(278);

	var _isHalfWidth = __webpack_require__(279);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function isVariableWidth(str) {
	  (0, _assertString2.default)(str);
	  return _isFullWidth.fullWidth.test(str) && _isHalfWidth.halfWidth.test(str);
	}
	module.exports = exports['default'];

/***/ },
/* 281 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isMultibyte;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	var multibyte = /[^\x00-\x7F]/;

	function isMultibyte(str) {
	  (0, _assertString2.default)(str);
	  return multibyte.test(str);
	}
	module.exports = exports['default'];

/***/ },
/* 282 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isSurrogatePair;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	var surrogatePair = /[\uD800-\uDBFF][\uDC00-\uDFFF]/;

	function isSurrogatePair(str) {
	  (0, _assertString2.default)(str);
	  return surrogatePair.test(str);
	}
	module.exports = exports['default'];

/***/ },
/* 283 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isInt;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	var int = /^(?:[-+]?(?:0|[1-9][0-9]*))$/;

	function isInt(str, options) {
	  (0, _assertString2.default)(str);
	  options = options || {};
	  return int.test(str) && (!options.hasOwnProperty('min') || str >= options.min) && (!options.hasOwnProperty('max') || str <= options.max);
	}
	module.exports = exports['default'];

/***/ },
/* 284 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isFloat;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	var float = /^(?:[-+]?(?:[0-9]+))?(?:\.[0-9]*)?(?:[eE][\+\-]?(?:[0-9]+))?$/;

	function isFloat(str, options) {
	  (0, _assertString2.default)(str);
	  options = options || {};
	  if (str === '' || str === '.') {
	    return false;
	  }
	  return float.test(str) && (!options.hasOwnProperty('min') || str >= options.min) && (!options.hasOwnProperty('max') || str <= options.max);
	}
	module.exports = exports['default'];

/***/ },
/* 285 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isDecimal;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	var decimal = /^[-+]?([0-9]+|\.[0-9]+|[0-9]+\.[0-9]+)$/;

	function isDecimal(str) {
	  (0, _assertString2.default)(str);
	  return str !== '' && decimal.test(str);
	}
	module.exports = exports['default'];

/***/ },
/* 286 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isHexadecimal;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	var hexadecimal = /^[0-9A-F]+$/i;

	function isHexadecimal(str) {
	  (0, _assertString2.default)(str);
	  return hexadecimal.test(str);
	}
	module.exports = exports['default'];

/***/ },
/* 287 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isDivisibleBy;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	var _toFloat = __webpack_require__(260);

	var _toFloat2 = _interopRequireDefault(_toFloat);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function isDivisibleBy(str, num) {
	  (0, _assertString2.default)(str);
	  return (0, _toFloat2.default)(str) % parseInt(num, 10) === 0;
	}
	module.exports = exports['default'];

/***/ },
/* 288 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isHexColor;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	var hexcolor = /^#?([0-9A-F]{3}|[0-9A-F]{6})$/i;

	function isHexColor(str) {
	  (0, _assertString2.default)(str);
	  return hexcolor.test(str);
	}
	module.exports = exports['default'];

/***/ },
/* 289 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});

	var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol ? "symbol" : typeof obj; };

	exports.default = isJSON;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function isJSON(str) {
	  (0, _assertString2.default)(str);
	  try {
	    var obj = JSON.parse(str);
	    return !!obj && (typeof obj === 'undefined' ? 'undefined' : _typeof(obj)) === 'object';
	  } catch (e) {/* ignore */}
	  return false;
	}
	module.exports = exports['default'];

/***/ },
/* 290 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isNull;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function isNull(str) {
	  (0, _assertString2.default)(str);
	  return str.length === 0;
	}
	module.exports = exports['default'];

/***/ },
/* 291 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});

	var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol ? "symbol" : typeof obj; };

	exports.default = isLength;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	/* eslint-disable prefer-rest-params */
	function isLength(str, options) {
	  (0, _assertString2.default)(str);
	  var min = void 0;
	  var max = void 0;
	  if ((typeof options === 'undefined' ? 'undefined' : _typeof(options)) === 'object') {
	    min = options.min || 0;
	    max = options.max;
	  } else {
	    // backwards compatibility: isLength(str, min [, max])
	    min = arguments[1];
	    max = arguments[2];
	  }
	  var surrogatePairs = str.match(/[\uD800-\uDBFF][\uDC00-\uDFFF]/g) || [];
	  var len = str.length - surrogatePairs.length;
	  return len >= min && (typeof max === 'undefined' || len <= max);
	}
	module.exports = exports['default'];

/***/ },
/* 292 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});

	var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol ? "symbol" : typeof obj; };

	exports.default = isByteLength;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	/* eslint-disable prefer-rest-params */
	function isByteLength(str, options) {
	  (0, _assertString2.default)(str);
	  var min = void 0;
	  var max = void 0;
	  if ((typeof options === 'undefined' ? 'undefined' : _typeof(options)) === 'object') {
	    min = options.min || 0;
	    max = options.max;
	  } else {
	    // backwards compatibility: isByteLength(str, min [, max])
	    min = arguments[1];
	    max = arguments[2];
	  }
	  var len = encodeURI(str).split(/%..|./).length - 1;
	  return len >= min && (typeof max === 'undefined' || len <= max);
	}
	module.exports = exports['default'];

/***/ },
/* 293 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isUUID;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	var uuid = {
	  3: /^[0-9A-F]{8}-[0-9A-F]{4}-3[0-9A-F]{3}-[0-9A-F]{4}-[0-9A-F]{12}$/i,
	  4: /^[0-9A-F]{8}-[0-9A-F]{4}-4[0-9A-F]{3}-[89AB][0-9A-F]{3}-[0-9A-F]{12}$/i,
	  5: /^[0-9A-F]{8}-[0-9A-F]{4}-5[0-9A-F]{3}-[89AB][0-9A-F]{3}-[0-9A-F]{12}$/i,
	  all: /^[0-9A-F]{8}-[0-9A-F]{4}-[0-9A-F]{4}-[0-9A-F]{4}-[0-9A-F]{12}$/i
	};

	function isUUID(str) {
	  var version = arguments.length <= 1 || arguments[1] === undefined ? 'all' : arguments[1];

	  (0, _assertString2.default)(str);
	  var pattern = uuid[version];
	  return pattern && pattern.test(str);
	}
	module.exports = exports['default'];

/***/ },
/* 294 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isMongoId;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	var _isHexadecimal = __webpack_require__(286);

	var _isHexadecimal2 = _interopRequireDefault(_isHexadecimal);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function isMongoId(str) {
	  (0, _assertString2.default)(str);
	  return (0, _isHexadecimal2.default)(str) && str.length === 24;
	}
	module.exports = exports['default'];

/***/ },
/* 295 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isDate;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	var _isISO = __webpack_require__(304);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function getTimezoneOffset(str) {
	  var iso8601Parts = str.match(_isISO.iso8601);
	  var timezone = void 0,
	      sign = void 0,
	      hours = void 0,
	      minutes = void 0;
	  if (!iso8601Parts) {
	    str = str.toLowerCase();
	    timezone = str.match(/(?:\s|gmt\s*)(-|\+)(\d{1,4})(\s|$)/);
	    if (!timezone) {
	      return str.indexOf('gmt') !== -1 ? 0 : null;
	    }
	    sign = timezone[1];
	    var offset = timezone[2];
	    if (offset.length === 3) {
	      offset = '0' + offset;
	    }
	    if (offset.length <= 2) {
	      hours = 0;
	      minutes = parseInt(offset, 10);
	    } else {
	      hours = parseInt(offset.slice(0, 2), 10);
	      minutes = parseInt(offset.slice(2, 4), 10);
	    }
	  } else {
	    timezone = iso8601Parts[21];
	    if (!timezone) {
	      // if no hour/minute was provided, the date is GMT
	      return !iso8601Parts[12] ? 0 : null;
	    }
	    if (timezone === 'z' || timezone === 'Z') {
	      return 0;
	    }
	    sign = iso8601Parts[22];
	    if (timezone.indexOf(':') !== -1) {
	      hours = parseInt(iso8601Parts[23], 10);
	      minutes = parseInt(iso8601Parts[24], 10);
	    } else {
	      hours = 0;
	      minutes = parseInt(iso8601Parts[23], 10);
	    }
	  }
	  return (hours * 60 + minutes) * (sign === '-' ? 1 : -1);
	}

	function isDate(str) {
	  (0, _assertString2.default)(str);
	  var normalizedDate = new Date(Date.parse(str));
	  if (isNaN(normalizedDate)) {
	    return false;
	  }

	  // normalizedDate is in the user's timezone. Apply the input
	  // timezone offset to the date so that the year and day match
	  // the input
	  var timezoneOffset = getTimezoneOffset(str);
	  if (timezoneOffset !== null) {
	    var timezoneDifference = normalizedDate.getTimezoneOffset() - timezoneOffset;
	    normalizedDate = new Date(normalizedDate.getTime() + 60000 * timezoneDifference);
	  }

	  var day = String(normalizedDate.getDate());
	  var dayOrYear = void 0,
	      dayOrYearMatches = void 0,
	      year = void 0;
	  // check for valid double digits that could be late days
	  // check for all matches since a string like '12/23' is a valid date
	  // ignore everything with nearby colons
	  dayOrYearMatches = str.match(/(^|[^:\d])[23]\d([^:\d]|$)/g);
	  if (!dayOrYearMatches) {
	    return true;
	  }
	  dayOrYear = dayOrYearMatches.map(function (digitString) {
	    return digitString.match(/\d+/g)[0];
	  }).join('/');

	  year = String(normalizedDate.getFullYear()).slice(-2);
	  if (dayOrYear === day || dayOrYear === year) {
	    return true;
	  } else if (dayOrYear === '' + day / year || dayOrYear === '' + year / day) {
	    return true;
	  }
	  return false;
	}
	module.exports = exports['default'];

/***/ },
/* 296 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isAfter;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	var _toDate = __webpack_require__(259);

	var _toDate2 = _interopRequireDefault(_toDate);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function isAfter(str) {
	  var date = arguments.length <= 1 || arguments[1] === undefined ? String(new Date()) : arguments[1];

	  (0, _assertString2.default)(str);
	  var comparison = (0, _toDate2.default)(date);
	  var original = (0, _toDate2.default)(str);
	  return !!(original && comparison && original > comparison);
	}
	module.exports = exports['default'];

/***/ },
/* 297 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isBefore;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	var _toDate = __webpack_require__(259);

	var _toDate2 = _interopRequireDefault(_toDate);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function isBefore(str) {
	  var date = arguments.length <= 1 || arguments[1] === undefined ? String(new Date()) : arguments[1];

	  (0, _assertString2.default)(str);
	  var comparison = (0, _toDate2.default)(date);
	  var original = (0, _toDate2.default)(str);
	  return !!(original && comparison && original < comparison);
	}
	module.exports = exports['default'];

/***/ },
/* 298 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});

	var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol ? "symbol" : typeof obj; };

	exports.default = isIn;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	var _toString = __webpack_require__(317);

	var _toString2 = _interopRequireDefault(_toString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function isIn(str, options) {
	  (0, _assertString2.default)(str);
	  var i = void 0;
	  if (Object.prototype.toString.call(options) === '[object Array]') {
	    var array = [];
	    for (i in options) {
	      if ({}.hasOwnProperty.call(options, i)) {
	        array[i] = (0, _toString2.default)(options[i]);
	      }
	    }
	    return array.indexOf(str) >= 0;
	  } else if ((typeof options === 'undefined' ? 'undefined' : _typeof(options)) === 'object') {
	    return options.hasOwnProperty(str);
	  } else if (options && typeof options.indexOf === 'function') {
	    return options.indexOf(str) >= 0;
	  }
	  return false;
	}
	module.exports = exports['default'];

/***/ },
/* 299 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isCreditCard;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	/* eslint-disable max-len */
	var creditCard = /^(?:4[0-9]{12}(?:[0-9]{3})?|5[1-5][0-9]{14}|6(?:011|5[0-9][0-9])[0-9]{12}|3[47][0-9]{13}|3(?:0[0-5]|[68][0-9])[0-9]{11}|(?:2131|1800|35\d{3})\d{11})$/;
	/* eslint-enable max-len */

	function isCreditCard(str) {
	  (0, _assertString2.default)(str);
	  var sanitized = str.replace(/[^0-9]+/g, '');
	  if (!creditCard.test(sanitized)) {
	    return false;
	  }
	  var sum = 0;
	  var digit = void 0;
	  var tmpNum = void 0;
	  var shouldDouble = void 0;
	  for (var i = sanitized.length - 1; i >= 0; i--) {
	    digit = sanitized.substring(i, i + 1);
	    tmpNum = parseInt(digit, 10);
	    if (shouldDouble) {
	      tmpNum *= 2;
	      if (tmpNum >= 10) {
	        sum += tmpNum % 10 + 1;
	      } else {
	        sum += tmpNum;
	      }
	    } else {
	      sum += tmpNum;
	    }
	    shouldDouble = !shouldDouble;
	  }
	  return !!(sum % 10 === 0 ? sanitized : false);
	}
	module.exports = exports['default'];

/***/ },
/* 300 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isISIN;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	var isin = /^[A-Z]{2}[0-9A-Z]{9}[0-9]$/;

	function isISIN(str) {
	  (0, _assertString2.default)(str);
	  if (!isin.test(str)) {
	    return false;
	  }

	  var checksumStr = str.replace(/[A-Z]/g, function (character) {
	    return parseInt(character, 36);
	  });

	  var sum = 0;
	  var digit = void 0;
	  var tmpNum = void 0;
	  var shouldDouble = true;
	  for (var i = checksumStr.length - 2; i >= 0; i--) {
	    digit = checksumStr.substring(i, i + 1);
	    tmpNum = parseInt(digit, 10);
	    if (shouldDouble) {
	      tmpNum *= 2;
	      if (tmpNum >= 10) {
	        sum += tmpNum + 1;
	      } else {
	        sum += tmpNum;
	      }
	    } else {
	      sum += tmpNum;
	    }
	    shouldDouble = !shouldDouble;
	  }

	  return parseInt(str.substr(str.length - 1), 10) === (10000 - sum) % 10;
	}
	module.exports = exports['default'];

/***/ },
/* 301 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isISBN;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	var isbn10Maybe = /^(?:[0-9]{9}X|[0-9]{10})$/;
	var isbn13Maybe = /^(?:[0-9]{13})$/;
	var factor = [1, 3];

	function isISBN(str) {
	  var version = arguments.length <= 1 || arguments[1] === undefined ? '' : arguments[1];

	  (0, _assertString2.default)(str);
	  version = String(version);
	  if (!version) {
	    return isISBN(str, 10) || isISBN(str, 13);
	  }
	  var sanitized = str.replace(/[\s-]+/g, '');
	  var checksum = 0;
	  var i = void 0;
	  if (version === '10') {
	    if (!isbn10Maybe.test(sanitized)) {
	      return false;
	    }
	    for (i = 0; i < 9; i++) {
	      checksum += (i + 1) * sanitized.charAt(i);
	    }
	    if (sanitized.charAt(9) === 'X') {
	      checksum += 10 * 10;
	    } else {
	      checksum += 10 * sanitized.charAt(9);
	    }
	    if (checksum % 11 === 0) {
	      return !!sanitized;
	    }
	  } else if (version === '13') {
	    if (!isbn13Maybe.test(sanitized)) {
	      return false;
	    }
	    for (i = 0; i < 12; i++) {
	      checksum += factor[i % 2] * sanitized.charAt(i);
	    }
	    if (sanitized.charAt(12) - (10 - checksum % 10) % 10 === 0) {
	      return !!sanitized;
	    }
	  }
	  return false;
	}
	module.exports = exports['default'];

/***/ },
/* 302 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isMobilePhone;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	/* eslint-disable max-len */
	var phones = {
	  'ar-SY': /^(!?(\+?963)|0)?9\d{8}$/,
	  'en-US': /^(\+?1)?[2-9]\d{2}[2-9](?!11)\d{6}$/,
	  'cs-CZ': /^(\+?420)? ?[1-9][0-9]{2} ?[0-9]{3} ?[0-9]{3}$/,
	  'de-DE': /^(\+?49[ \.\-])?([\(]{1}[0-9]{1,6}[\)])?([0-9 \.\-\/]{3,20})((x|ext|extension)[ ]?[0-9]{1,4})?$/,
	  'el-GR': /^(\+?30)?(69\d{8})$/,
	  'en-AU': /^(\+?61|0)4\d{8}$/,
	  'en-GB': /^(\+?44|0)7\d{9}$/,
	  'en-HK': /^(\+?852\-?)?[569]\d{3}\-?\d{4}$/,
	  'en-IN': /^(\+?91|0)?[789]\d{9}$/,
	  'en-NZ': /^(\+?64|0)2\d{7,9}$/,
	  'en-ZA': /^(\+?27|0)\d{9}$/,
	  'en-ZM': /^(\+?26)?09[567]\d{7}$/,
	  'es-ES': /^(\+?34)?(6\d{1}|7[1234])\d{7}$/,
	  'fi-FI': /^(\+?358|0)\s?(4(0|1|2|4|5)?|50)\s?(\d\s?){4,8}\d$/,
	  'fr-FR': /^(\+?33|0)[67]\d{8}$/,
	  'ms-MY': /^(\+?6?01){1}(([145]{1}(\-|\s)?\d{7,8})|([236789]{1}(\s|\-)?\d{7}))$/,
	  'nb-NO': /^(\+?47)?[49]\d{7}$/,
	  'nn-NO': /^(\+?47)?[49]\d{7}$/,
	  'pt-BR': /^(\+?55|0)\-?[1-9]{2}\-?[2-9]{1}\d{3,4}\-?\d{4}$/,
	  'pt-PT': /^(\+?351)?9[1236]\d{7}$/,
	  'ru-RU': /^(\+?7|8)?9\d{9}$/,
	  'tr-TR': /^(\+?90|0)?5\d{9}$/,
	  'vi-VN': /^(\+?84|0)?((1(2([0-9])|6([2-9])|88|99))|(9((?!5)[0-9])))([0-9]{7})$/,
	  'zh-CN': /^(\+?0?86\-?)?((13\d|14[57]|15[^4,\D]|17[678]|18\d)\d{8}|170[059]\d{7})$/,
	  'zh-TW': /^(\+?886\-?|0)?9\d{8}$/
	};
	/* eslint-enable max-len */

	function isMobilePhone(str, locale) {
	  (0, _assertString2.default)(str);
	  if (locale in phones) {
	    return phones[locale].test(str);
	  }
	  return false;
	}
	module.exports = exports['default'];

/***/ },
/* 303 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isCurrency;

	var _merge = __webpack_require__(325);

	var _merge2 = _interopRequireDefault(_merge);

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function currencyRegex(options) {
	  var symbol = '(\\' + options.symbol.replace(/\./g, '\\.') + ')' + (options.require_symbol ? '' : '?'),
	      negative = '-?',
	      whole_dollar_amount_without_sep = '[1-9]\\d*',
	      whole_dollar_amount_with_sep = '[1-9]\\d{0,2}(\\' + options.thousands_separator + '\\d{3})*',
	      valid_whole_dollar_amounts = ['0', whole_dollar_amount_without_sep, whole_dollar_amount_with_sep],
	      whole_dollar_amount = '(' + valid_whole_dollar_amounts.join('|') + ')?',
	      decimal_amount = '(\\' + options.decimal_separator + '\\d{2})?';
	  var pattern = whole_dollar_amount + decimal_amount;

	  // default is negative sign before symbol, but there are two other options (besides parens)
	  if (options.allow_negatives && !options.parens_for_negatives) {
	    if (options.negative_sign_after_digits) {
	      pattern += negative;
	    } else if (options.negative_sign_before_digits) {
	      pattern = negative + pattern;
	    }
	  }

	  // South African Rand, for example, uses R 123 (space) and R-123 (no space)
	  if (options.allow_negative_sign_placeholder) {
	    pattern = '( (?!\\-))?' + pattern;
	  } else if (options.allow_space_after_symbol) {
	    pattern = ' ?' + pattern;
	  } else if (options.allow_space_after_digits) {
	    pattern += '( (?!$))?';
	  }

	  if (options.symbol_after_digits) {
	    pattern += symbol;
	  } else {
	    pattern = symbol + pattern;
	  }

	  if (options.allow_negatives) {
	    if (options.parens_for_negatives) {
	      pattern = '(\\(' + pattern + '\\)|' + pattern + ')';
	    } else if (!(options.negative_sign_before_digits || options.negative_sign_after_digits)) {
	      pattern = negative + pattern;
	    }
	  }

	  /* eslint-disable prefer-template */
	  return new RegExp('^' +
	  // ensure there's a dollar and/or decimal amount, and that
	  // it doesn't start with a space or a negative sign followed by a space
	  '(?!-? )(?=.*\\d)' + pattern + '$');
	  /* eslint-enable prefer-template */
	}

	var default_currency_options = {
	  symbol: '$',
	  require_symbol: false,
	  allow_space_after_symbol: false,
	  symbol_after_digits: false,
	  allow_negatives: true,
	  parens_for_negatives: false,
	  negative_sign_before_digits: false,
	  negative_sign_after_digits: false,
	  allow_negative_sign_placeholder: false,
	  thousands_separator: ',',
	  decimal_separator: '.',
	  allow_space_after_digits: false
	};

	function isCurrency(str, options) {
	  (0, _assertString2.default)(str);
	  options = (0, _merge2.default)(options, default_currency_options);
	  return currencyRegex(options).test(str);
	}
	module.exports = exports['default'];

/***/ },
/* 304 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.iso8601 = undefined;

	exports.default = function (str) {
	  (0, _assertString2.default)(str);
	  return iso8601.test(str);
	};

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	/* eslint-disable max-len */
	// from http://goo.gl/0ejHHW
	var iso8601 = exports.iso8601 = /^([\+-]?\d{4}(?!\d{2}\b))((-?)((0[1-9]|1[0-2])(\3([12]\d|0[1-9]|3[01]))?|W([0-4]\d|5[0-2])(-?[1-7])?|(00[1-9]|0[1-9]\d|[12]\d{2}|3([0-5]\d|6[1-6])))([T\s]((([01]\d|2[0-3])((:?)[0-5]\d)?|24\:?00)([\.,]\d+(?!:))?)?(\17[0-5]\d([\.,]\d+)?)?([zZ]|([\+-])([01]\d|2[0-3]):?([0-5]\d)?)?)?)?$/;
	/* eslint-enable max-len */

/***/ },
/* 305 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isBase64;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	var notBase64 = /[^A-Z0-9+\/=]/i;

	function isBase64(str) {
	  (0, _assertString2.default)(str);
	  var len = str.length;
	  if (!len || len % 4 !== 0 || notBase64.test(str)) {
	    return false;
	  }
	  var firstPaddingChar = str.indexOf('=');
	  return firstPaddingChar === -1 || firstPaddingChar === len - 1 || firstPaddingChar === len - 2 && str[len - 1] === '=';
	}
	module.exports = exports['default'];

/***/ },
/* 306 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isDataURI;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	var dataURI = /^\s*data:([a-z]+\/[a-z0-9\-\+]+(;[a-z\-]+\=[a-z0-9\-]+)?)?(;base64)?,[a-z0-9\!\$\&\'\,\(\)\*\+\,\;\=\-\.\_\~\:\@\/\?\%\s]*\s*$/i; // eslint-disable-line max-len

	function isDataURI(str) {
	  (0, _assertString2.default)(str);
	  return dataURI.test(str);
	}
	module.exports = exports['default'];

/***/ },
/* 307 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = ltrim;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function ltrim(str, chars) {
	  (0, _assertString2.default)(str);
	  var pattern = chars ? new RegExp('^[' + chars + ']+', 'g') : /^\s+/g;
	  return str.replace(pattern, '');
	}
	module.exports = exports['default'];

/***/ },
/* 308 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = rtrim;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function rtrim(str, chars) {
	  (0, _assertString2.default)(str);
	  var pattern = chars ? new RegExp('[' + chars + ']+$', 'g') : /\s+$/g;
	  return str.replace(pattern, '');
	}
	module.exports = exports['default'];

/***/ },
/* 309 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = trim;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function trim(str, chars) {
	  (0, _assertString2.default)(str);
	  var pattern = chars ? new RegExp('^[' + chars + ']+|[' + chars + ']+$', 'g') : /^\s+|\s+$/g;
	  return str.replace(pattern, '');
	}
	module.exports = exports['default'];

/***/ },
/* 310 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	      value: true
	});
	exports.default = escape;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function escape(str) {
	      (0, _assertString2.default)(str);
	      return str.replace(/&/g, '&amp;').replace(/"/g, '&quot;').replace(/'/g, '&#x27;').replace(/</g, '&lt;').replace(/>/g, '&gt;').replace(/\//g, '&#x2F;').replace(/\`/g, '&#96;');
	}
	module.exports = exports['default'];

/***/ },
/* 311 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	      value: true
	});
	exports.default = unescape;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function unescape(str) {
	      (0, _assertString2.default)(str);
	      return str.replace(/&amp;/g, '&').replace(/&quot;/g, '"').replace(/&#x27;/g, "'").replace(/&lt;/g, '<').replace(/&gt;/g, '>').replace(/&#x2F;/g, '\/').replace(/&#96;/g, '\`');
	}
	module.exports = exports['default'];

/***/ },
/* 312 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = stripLow;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	var _blacklist = __webpack_require__(314);

	var _blacklist2 = _interopRequireDefault(_blacklist);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function stripLow(str, keep_new_lines) {
	  (0, _assertString2.default)(str);
	  var chars = keep_new_lines ? '\\x00-\\x09\\x0B\\x0C\\x0E-\\x1F\\x7F' : '\\x00-\\x1F\\x7F';
	  return (0, _blacklist2.default)(str, chars);
	}
	module.exports = exports['default'];

/***/ },
/* 313 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = whitelist;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function whitelist(str, chars) {
	  (0, _assertString2.default)(str);
	  return str.replace(new RegExp('[^' + chars + ']+', 'g'), '');
	}
	module.exports = exports['default'];

/***/ },
/* 314 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = blacklist;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function blacklist(str, chars) {
	  (0, _assertString2.default)(str);
	  return str.replace(new RegExp('[' + chars + ']+', 'g'), '');
	}
	module.exports = exports['default'];

/***/ },
/* 315 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = isWhitelisted;

	var _assertString = __webpack_require__(324);

	var _assertString2 = _interopRequireDefault(_assertString);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	function isWhitelisted(str, chars) {
	  (0, _assertString2.default)(str);
	  for (var i = str.length - 1; i >= 0; i--) {
	    if (chars.indexOf(str[i]) === -1) {
	      return false;
	    }
	  }
	  return true;
	}
	module.exports = exports['default'];

/***/ },
/* 316 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = normalizeEmail;

	var _isEmail = __webpack_require__(266);

	var _isEmail2 = _interopRequireDefault(_isEmail);

	var _merge = __webpack_require__(325);

	var _merge2 = _interopRequireDefault(_merge);

	function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

	var default_normalize_email_options = {
	  lowercase: true,
	  remove_dots: true,
	  remove_extension: true
	};

	function normalizeEmail(email, options) {
	  options = (0, _merge2.default)(options, default_normalize_email_options);
	  if (!(0, _isEmail2.default)(email)) {
	    return false;
	  }
	  var parts = email.split('@', 2);
	  parts[1] = parts[1].toLowerCase();
	  if (parts[1] === 'gmail.com' || parts[1] === 'googlemail.com') {
	    if (options.remove_extension) {
	      parts[0] = parts[0].split('+')[0];
	    }
	    if (options.remove_dots) {
	      parts[0] = parts[0].replace(/\./g, '');
	    }
	    if (!parts[0].length) {
	      return false;
	    }
	    parts[0] = parts[0].toLowerCase();
	    parts[1] = 'gmail.com';
	  } else if (options.lowercase) {
	    parts[0] = parts[0].toLowerCase();
	  }
	  return parts.join('@');
	}
	module.exports = exports['default'];

/***/ },
/* 317 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});

	var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol ? "symbol" : typeof obj; };

	exports.default = toString;
	function toString(input) {
	  if ((typeof input === 'undefined' ? 'undefined' : _typeof(input)) === 'object' && input !== null) {
	    if (typeof input.toString === 'function') {
	      input = input.toString();
	    } else {
	      input = '[object Object]';
	    }
	  } else if (input === null || typeof input === 'undefined' || isNaN(input) && !input.length) {
	    input = '';
	  }
	  return String(input);
	}
	module.exports = exports['default'];

/***/ },
/* 318 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(module, global) {/**
	 * lodash 4.7.1 (Custom Build) <https://lodash.com/>
	 * Build: `lodash modularize exports="npm" -o ./`
	 * Copyright jQuery Foundation and other contributors <https://jquery.org/>
	 * Released under MIT license <https://lodash.com/license>
	 * Based on Underscore.js 1.8.3 <http://underscorejs.org/LICENSE>
	 * Copyright Jeremy Ashkenas, DocumentCloud and Investigative Reporters & Editors
	 */

	/** Used as the `TypeError` message for "Functions" methods. */
	var FUNC_ERROR_TEXT = 'Expected a function';

	/** Used to stand-in for `undefined` hash values. */
	var HASH_UNDEFINED = '__lodash_hash_undefined__';

	/** Used as references for various `Number` constants. */
	var INFINITY = 1 / 0;

	/** `Object#toString` result references. */
	var funcTag = '[object Function]',
	    genTag = '[object GeneratorFunction]',
	    symbolTag = '[object Symbol]';

	/** Used to match property names within property paths. */
	var rePropName = /[^.[\]]+|\[(?:(-?\d+(?:\.\d+)?)|(["'])((?:(?!\2)[^\\]|\\.)*?)\2)\]/g;

	/**
	 * Used to match `RegExp`
	 * [syntax characters](http://ecma-international.org/ecma-262/6.0/#sec-patterns).
	 */
	var reRegExpChar = /[\\^$.*+?()[\]{}|]/g;

	/** Used to match backslashes in property paths. */
	var reEscapeChar = /\\(\\)?/g;

	/** Used to detect host constructors (Safari). */
	var reIsHostCtor = /^\[object .+?Constructor\]$/;

	/** Used to determine if values are of the language type `Object`. */
	var objectTypes = {
	  'function': true,
	  'object': true
	};

	/** Detect free variable `exports`. */
	var freeExports = (objectTypes[typeof exports] && exports && !exports.nodeType)
	  ? exports
	  : undefined;

	/** Detect free variable `module`. */
	var freeModule = (objectTypes[typeof module] && module && !module.nodeType)
	  ? module
	  : undefined;

	/** Detect free variable `global` from Node.js. */
	var freeGlobal = checkGlobal(freeExports && freeModule && typeof global == 'object' && global);

	/** Detect free variable `self`. */
	var freeSelf = checkGlobal(objectTypes[typeof self] && self);

	/** Detect free variable `window`. */
	var freeWindow = checkGlobal(objectTypes[typeof window] && window);

	/** Detect `this` as the global object. */
	var thisGlobal = checkGlobal(objectTypes[typeof this] && this);

	/**
	 * Used as a reference to the global object.
	 *
	 * The `this` value is used if it's the global object to avoid Greasemonkey's
	 * restricted `window` object, otherwise the `window` object is used.
	 */
	var root = freeGlobal ||
	  ((freeWindow !== (thisGlobal && thisGlobal.window)) && freeWindow) ||
	    freeSelf || thisGlobal || Function('return this')();

	/**
	 * Checks if `value` is a global object.
	 *
	 * @private
	 * @param {*} value The value to check.
	 * @returns {null|Object} Returns `value` if it's a global object, else `null`.
	 */
	function checkGlobal(value) {
	  return (value && value.Object === Object) ? value : null;
	}

	/**
	 * Checks if `value` is a host object in IE < 9.
	 *
	 * @private
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is a host object, else `false`.
	 */
	function isHostObject(value) {
	  // Many host objects are `Object` objects that can coerce to strings
	  // despite having improperly defined `toString` methods.
	  var result = false;
	  if (value != null && typeof value.toString != 'function') {
	    try {
	      result = !!(value + '');
	    } catch (e) {}
	  }
	  return result;
	}

	/** Used for built-in method references. */
	var arrayProto = Array.prototype,
	    objectProto = Object.prototype;

	/** Used to resolve the decompiled source of functions. */
	var funcToString = Function.prototype.toString;

	/** Used to check objects for own properties. */
	var hasOwnProperty = objectProto.hasOwnProperty;

	/**
	 * Used to resolve the
	 * [`toStringTag`](http://ecma-international.org/ecma-262/6.0/#sec-object.prototype.tostring)
	 * of values.
	 */
	var objectToString = objectProto.toString;

	/** Used to detect if a method is native. */
	var reIsNative = RegExp('^' +
	  funcToString.call(hasOwnProperty).replace(reRegExpChar, '\\$&')
	  .replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g, '$1.*?') + '$'
	);

	/** Built-in value references. */
	var Symbol = root.Symbol,
	    splice = arrayProto.splice;

	/* Built-in method references that are verified to be native. */
	var Map = getNative(root, 'Map'),
	    nativeCreate = getNative(Object, 'create');

	/** Used to convert symbols to primitives and strings. */
	var symbolProto = Symbol ? Symbol.prototype : undefined,
	    symbolToString = symbolProto ? symbolProto.toString : undefined;

	/**
	 * Creates a hash object.
	 *
	 * @private
	 * @constructor
	 * @returns {Object} Returns the new hash object.
	 */
	function Hash() {}

	/**
	 * Removes `key` and its value from the hash.
	 *
	 * @private
	 * @param {Object} hash The hash to modify.
	 * @param {string} key The key of the value to remove.
	 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
	 */
	function hashDelete(hash, key) {
	  return hashHas(hash, key) && delete hash[key];
	}

	/**
	 * Gets the hash value for `key`.
	 *
	 * @private
	 * @param {Object} hash The hash to query.
	 * @param {string} key The key of the value to get.
	 * @returns {*} Returns the entry value.
	 */
	function hashGet(hash, key) {
	  if (nativeCreate) {
	    var result = hash[key];
	    return result === HASH_UNDEFINED ? undefined : result;
	  }
	  return hasOwnProperty.call(hash, key) ? hash[key] : undefined;
	}

	/**
	 * Checks if a hash value for `key` exists.
	 *
	 * @private
	 * @param {Object} hash The hash to query.
	 * @param {string} key The key of the entry to check.
	 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
	 */
	function hashHas(hash, key) {
	  return nativeCreate ? hash[key] !== undefined : hasOwnProperty.call(hash, key);
	}

	/**
	 * Sets the hash `key` to `value`.
	 *
	 * @private
	 * @param {Object} hash The hash to modify.
	 * @param {string} key The key of the value to set.
	 * @param {*} value The value to set.
	 */
	function hashSet(hash, key, value) {
	  hash[key] = (nativeCreate && value === undefined) ? HASH_UNDEFINED : value;
	}

	// Avoid inheriting from `Object.prototype` when possible.
	Hash.prototype = nativeCreate ? nativeCreate(null) : objectProto;

	/**
	 * Creates a map cache object to store key-value pairs.
	 *
	 * @private
	 * @constructor
	 * @param {Array} [values] The values to cache.
	 */
	function MapCache(values) {
	  var index = -1,
	      length = values ? values.length : 0;

	  this.clear();
	  while (++index < length) {
	    var entry = values[index];
	    this.set(entry[0], entry[1]);
	  }
	}

	/**
	 * Removes all key-value entries from the map.
	 *
	 * @private
	 * @name clear
	 * @memberOf MapCache
	 */
	function mapClear() {
	  this.__data__ = {
	    'hash': new Hash,
	    'map': Map ? new Map : [],
	    'string': new Hash
	  };
	}

	/**
	 * Removes `key` and its value from the map.
	 *
	 * @private
	 * @name delete
	 * @memberOf MapCache
	 * @param {string} key The key of the value to remove.
	 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
	 */
	function mapDelete(key) {
	  var data = this.__data__;
	  if (isKeyable(key)) {
	    return hashDelete(typeof key == 'string' ? data.string : data.hash, key);
	  }
	  return Map ? data.map['delete'](key) : assocDelete(data.map, key);
	}

	/**
	 * Gets the map value for `key`.
	 *
	 * @private
	 * @name get
	 * @memberOf MapCache
	 * @param {string} key The key of the value to get.
	 * @returns {*} Returns the entry value.
	 */
	function mapGet(key) {
	  var data = this.__data__;
	  if (isKeyable(key)) {
	    return hashGet(typeof key == 'string' ? data.string : data.hash, key);
	  }
	  return Map ? data.map.get(key) : assocGet(data.map, key);
	}

	/**
	 * Checks if a map value for `key` exists.
	 *
	 * @private
	 * @name has
	 * @memberOf MapCache
	 * @param {string} key The key of the entry to check.
	 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
	 */
	function mapHas(key) {
	  var data = this.__data__;
	  if (isKeyable(key)) {
	    return hashHas(typeof key == 'string' ? data.string : data.hash, key);
	  }
	  return Map ? data.map.has(key) : assocHas(data.map, key);
	}

	/**
	 * Sets the map `key` to `value`.
	 *
	 * @private
	 * @name set
	 * @memberOf MapCache
	 * @param {string} key The key of the value to set.
	 * @param {*} value The value to set.
	 * @returns {Object} Returns the map cache instance.
	 */
	function mapSet(key, value) {
	  var data = this.__data__;
	  if (isKeyable(key)) {
	    hashSet(typeof key == 'string' ? data.string : data.hash, key, value);
	  } else if (Map) {
	    data.map.set(key, value);
	  } else {
	    assocSet(data.map, key, value);
	  }
	  return this;
	}

	// Add methods to `MapCache`.
	MapCache.prototype.clear = mapClear;
	MapCache.prototype['delete'] = mapDelete;
	MapCache.prototype.get = mapGet;
	MapCache.prototype.has = mapHas;
	MapCache.prototype.set = mapSet;

	/**
	 * Removes `key` and its value from the associative array.
	 *
	 * @private
	 * @param {Array} array The array to modify.
	 * @param {string} key The key of the value to remove.
	 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
	 */
	function assocDelete(array, key) {
	  var index = assocIndexOf(array, key);
	  if (index < 0) {
	    return false;
	  }
	  var lastIndex = array.length - 1;
	  if (index == lastIndex) {
	    array.pop();
	  } else {
	    splice.call(array, index, 1);
	  }
	  return true;
	}

	/**
	 * Gets the associative array value for `key`.
	 *
	 * @private
	 * @param {Array} array The array to query.
	 * @param {string} key The key of the value to get.
	 * @returns {*} Returns the entry value.
	 */
	function assocGet(array, key) {
	  var index = assocIndexOf(array, key);
	  return index < 0 ? undefined : array[index][1];
	}

	/**
	 * Checks if an associative array value for `key` exists.
	 *
	 * @private
	 * @param {Array} array The array to query.
	 * @param {string} key The key of the entry to check.
	 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
	 */
	function assocHas(array, key) {
	  return assocIndexOf(array, key) > -1;
	}

	/**
	 * Gets the index at which the `key` is found in `array` of key-value pairs.
	 *
	 * @private
	 * @param {Array} array The array to search.
	 * @param {*} key The key to search for.
	 * @returns {number} Returns the index of the matched value, else `-1`.
	 */
	function assocIndexOf(array, key) {
	  var length = array.length;
	  while (length--) {
	    if (eq(array[length][0], key)) {
	      return length;
	    }
	  }
	  return -1;
	}

	/**
	 * Sets the associative array `key` to `value`.
	 *
	 * @private
	 * @param {Array} array The array to modify.
	 * @param {string} key The key of the value to set.
	 * @param {*} value The value to set.
	 */
	function assocSet(array, key, value) {
	  var index = assocIndexOf(array, key);
	  if (index < 0) {
	    array.push([key, value]);
	  } else {
	    array[index][1] = value;
	  }
	}

	/**
	 * Gets the native function at `key` of `object`.
	 *
	 * @private
	 * @param {Object} object The object to query.
	 * @param {string} key The key of the method to get.
	 * @returns {*} Returns the function if it's native, else `undefined`.
	 */
	function getNative(object, key) {
	  var value = object[key];
	  return isNative(value) ? value : undefined;
	}

	/**
	 * Checks if `value` is suitable for use as unique object key.
	 *
	 * @private
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is suitable, else `false`.
	 */
	function isKeyable(value) {
	  var type = typeof value;
	  return type == 'number' || type == 'boolean' ||
	    (type == 'string' && value != '__proto__') || value == null;
	}

	/**
	 * Converts `string` to a property path array.
	 *
	 * @private
	 * @param {string} string The string to convert.
	 * @returns {Array} Returns the property path array.
	 */
	var stringToPath = memoize(function(string) {
	  var result = [];
	  toString(string).replace(rePropName, function(match, number, quote, string) {
	    result.push(quote ? string.replace(reEscapeChar, '$1') : (number || match));
	  });
	  return result;
	});

	/**
	 * Converts `func` to its source code.
	 *
	 * @private
	 * @param {Function} func The function to process.
	 * @returns {string} Returns the source code.
	 */
	function toSource(func) {
	  if (func != null) {
	    try {
	      return funcToString.call(func);
	    } catch (e) {}
	    try {
	      return (func + '');
	    } catch (e) {}
	  }
	  return '';
	}

	/**
	 * Creates a function that memoizes the result of `func`. If `resolver` is
	 * provided, it determines the cache key for storing the result based on the
	 * arguments provided to the memoized function. By default, the first argument
	 * provided to the memoized function is used as the map cache key. The `func`
	 * is invoked with the `this` binding of the memoized function.
	 *
	 * **Note:** The cache is exposed as the `cache` property on the memoized
	 * function. Its creation may be customized by replacing the `_.memoize.Cache`
	 * constructor with one whose instances implement the
	 * [`Map`](http://ecma-international.org/ecma-262/6.0/#sec-properties-of-the-map-prototype-object)
	 * method interface of `delete`, `get`, `has`, and `set`.
	 *
	 * @static
	 * @memberOf _
	 * @since 0.1.0
	 * @category Function
	 * @param {Function} func The function to have its output memoized.
	 * @param {Function} [resolver] The function to resolve the cache key.
	 * @returns {Function} Returns the new memoizing function.
	 * @example
	 *
	 * var object = { 'a': 1, 'b': 2 };
	 * var other = { 'c': 3, 'd': 4 };
	 *
	 * var values = _.memoize(_.values);
	 * values(object);
	 * // => [1, 2]
	 *
	 * values(other);
	 * // => [3, 4]
	 *
	 * object.a = 2;
	 * values(object);
	 * // => [1, 2]
	 *
	 * // Modify the result cache.
	 * values.cache.set(object, ['a', 'b']);
	 * values(object);
	 * // => ['a', 'b']
	 *
	 * // Replace `_.memoize.Cache`.
	 * _.memoize.Cache = WeakMap;
	 */
	function memoize(func, resolver) {
	  if (typeof func != 'function' || (resolver && typeof resolver != 'function')) {
	    throw new TypeError(FUNC_ERROR_TEXT);
	  }
	  var memoized = function() {
	    var args = arguments,
	        key = resolver ? resolver.apply(this, args) : args[0],
	        cache = memoized.cache;

	    if (cache.has(key)) {
	      return cache.get(key);
	    }
	    var result = func.apply(this, args);
	    memoized.cache = cache.set(key, result);
	    return result;
	  };
	  memoized.cache = new (memoize.Cache || MapCache);
	  return memoized;
	}

	// Assign cache to `_.memoize`.
	memoize.Cache = MapCache;

	/**
	 * Performs a
	 * [`SameValueZero`](http://ecma-international.org/ecma-262/6.0/#sec-samevaluezero)
	 * comparison between two values to determine if they are equivalent.
	 *
	 * @static
	 * @memberOf _
	 * @since 4.0.0
	 * @category Lang
	 * @param {*} value The value to compare.
	 * @param {*} other The other value to compare.
	 * @returns {boolean} Returns `true` if the values are equivalent, else `false`.
	 * @example
	 *
	 * var object = { 'user': 'fred' };
	 * var other = { 'user': 'fred' };
	 *
	 * _.eq(object, object);
	 * // => true
	 *
	 * _.eq(object, other);
	 * // => false
	 *
	 * _.eq('a', 'a');
	 * // => true
	 *
	 * _.eq('a', Object('a'));
	 * // => false
	 *
	 * _.eq(NaN, NaN);
	 * // => true
	 */
	function eq(value, other) {
	  return value === other || (value !== value && other !== other);
	}

	/**
	 * Checks if `value` is classified as a `Function` object.
	 *
	 * @static
	 * @memberOf _
	 * @since 0.1.0
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is correctly classified,
	 *  else `false`.
	 * @example
	 *
	 * _.isFunction(_);
	 * // => true
	 *
	 * _.isFunction(/abc/);
	 * // => false
	 */
	function isFunction(value) {
	  // The use of `Object#toString` avoids issues with the `typeof` operator
	  // in Safari 8 which returns 'object' for typed array and weak map constructors,
	  // and PhantomJS 1.9 which returns 'function' for `NodeList` instances.
	  var tag = isObject(value) ? objectToString.call(value) : '';
	  return tag == funcTag || tag == genTag;
	}

	/**
	 * Checks if `value` is the
	 * [language type](http://www.ecma-international.org/ecma-262/6.0/#sec-ecmascript-language-types)
	 * of `Object`. (e.g. arrays, functions, objects, regexes, `new Number(0)`, and `new String('')`)
	 *
	 * @static
	 * @memberOf _
	 * @since 0.1.0
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is an object, else `false`.
	 * @example
	 *
	 * _.isObject({});
	 * // => true
	 *
	 * _.isObject([1, 2, 3]);
	 * // => true
	 *
	 * _.isObject(_.noop);
	 * // => true
	 *
	 * _.isObject(null);
	 * // => false
	 */
	function isObject(value) {
	  var type = typeof value;
	  return !!value && (type == 'object' || type == 'function');
	}

	/**
	 * Checks if `value` is object-like. A value is object-like if it's not `null`
	 * and has a `typeof` result of "object".
	 *
	 * @static
	 * @memberOf _
	 * @since 4.0.0
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is object-like, else `false`.
	 * @example
	 *
	 * _.isObjectLike({});
	 * // => true
	 *
	 * _.isObjectLike([1, 2, 3]);
	 * // => true
	 *
	 * _.isObjectLike(_.noop);
	 * // => false
	 *
	 * _.isObjectLike(null);
	 * // => false
	 */
	function isObjectLike(value) {
	  return !!value && typeof value == 'object';
	}

	/**
	 * Checks if `value` is a native function.
	 *
	 * @static
	 * @memberOf _
	 * @since 3.0.0
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is a native function,
	 *  else `false`.
	 * @example
	 *
	 * _.isNative(Array.prototype.push);
	 * // => true
	 *
	 * _.isNative(_);
	 * // => false
	 */
	function isNative(value) {
	  if (!isObject(value)) {
	    return false;
	  }
	  var pattern = (isFunction(value) || isHostObject(value)) ? reIsNative : reIsHostCtor;
	  return pattern.test(toSource(value));
	}

	/**
	 * Checks if `value` is classified as a `Symbol` primitive or object.
	 *
	 * @static
	 * @memberOf _
	 * @since 4.0.0
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is correctly classified,
	 *  else `false`.
	 * @example
	 *
	 * _.isSymbol(Symbol.iterator);
	 * // => true
	 *
	 * _.isSymbol('abc');
	 * // => false
	 */
	function isSymbol(value) {
	  return typeof value == 'symbol' ||
	    (isObjectLike(value) && objectToString.call(value) == symbolTag);
	}

	/**
	 * Converts `value` to a string if it's not one. An empty string is returned
	 * for `null` and `undefined` values. The sign of `-0` is preserved.
	 *
	 * @static
	 * @memberOf _
	 * @since 4.0.0
	 * @category Lang
	 * @param {*} value The value to process.
	 * @returns {string} Returns the string.
	 * @example
	 *
	 * _.toString(null);
	 * // => ''
	 *
	 * _.toString(-0);
	 * // => '-0'
	 *
	 * _.toString([1, 2, 3]);
	 * // => '1,2,3'
	 */
	function toString(value) {
	  // Exit early for strings to avoid a performance hit in some environments.
	  if (typeof value == 'string') {
	    return value;
	  }
	  if (value == null) {
	    return '';
	  }
	  if (isSymbol(value)) {
	    return symbolToString ? symbolToString.call(value) : '';
	  }
	  var result = (value + '');
	  return (result == '0' && (1 / value) == -INFINITY) ? '-0' : result;
	}

	module.exports = stringToPath;
	
	/* WEBPACK VAR INJECTION */}.call(exports, __webpack_require__(169)(module), (function() { return this; }())))

/***/ },
/* 319 */
/***/ function(module, exports, __webpack_require__) {

	// Generated by CoffeeScript 1.9.1
	(function() {
	  var XMLBuilder, XMLDeclaration, XMLDocType, XMLElement, XMLStringifier;

	  XMLStringifier = __webpack_require__(327);

	  XMLDeclaration = __webpack_require__(328);

	  XMLDocType = __webpack_require__(329);

	  XMLElement = __webpack_require__(330);

	  module.exports = XMLBuilder = (function() {
	    function XMLBuilder(name, options) {
	      var root, temp;
	      if (name == null) {
	        throw new Error("Root element needs a name");
	      }
	      if (options == null) {
	        options = {};
	      }
	      this.options = options;
	      this.stringify = new XMLStringifier(options);
	      temp = new XMLElement(this, 'doc');
	      root = temp.element(name);
	      root.isRoot = true;
	      root.documentObject = this;
	      this.rootObject = root;
	      if (!options.headless) {
	        root.declaration(options);
	        if ((options.pubID != null) || (options.sysID != null)) {
	          root.doctype(options);
	        }
	      }
	    }

	    XMLBuilder.prototype.root = function() {
	      return this.rootObject;
	    };

	    XMLBuilder.prototype.end = function(options) {
	      return this.toString(options);
	    };

	    XMLBuilder.prototype.toString = function(options) {
	      var indent, newline, offset, pretty, r, ref, ref1, ref2;
	      pretty = (options != null ? options.pretty : void 0) || false;
	      indent = (ref = options != null ? options.indent : void 0) != null ? ref : '  ';
	      offset = (ref1 = options != null ? options.offset : void 0) != null ? ref1 : 0;
	      newline = (ref2 = options != null ? options.newline : void 0) != null ? ref2 : '\n';
	      r = '';
	      if (this.xmldec != null) {
	        r += this.xmldec.toString(options);
	      }
	      if (this.doctype != null) {
	        r += this.doctype.toString(options);
	      }
	      r += this.rootObject.toString(options);
	      if (pretty && r.slice(-newline.length) === newline) {
	        r = r.slice(0, -newline.length);
	      }
	      return r;
	    };

	    return XMLBuilder;

	  })();

	}).call(this);


/***/ },
/* 320 */
/***/ function(module, exports, __webpack_require__) {

	module.exports = Array.isArray || function (arr) {
	  return Object.prototype.toString.call(arr) == '[object Array]';
	};


/***/ },
/* 321 */
/***/ function(module, exports, __webpack_require__) {

	if (typeof Object.create === 'function') {
	  // implementation from standard node.js 'util' module
	  module.exports = function inherits(ctor, superCtor) {
	    ctor.super_ = superCtor
	    ctor.prototype = Object.create(superCtor.prototype, {
	      constructor: {
	        value: ctor,
	        enumerable: false,
	        writable: true,
	        configurable: true
	      }
	    });
	  };
	} else {
	  // old school shim for old browsers
	  module.exports = function inherits(ctor, superCtor) {
	    ctor.super_ = superCtor
	    var TempCtor = function () {}
	    TempCtor.prototype = superCtor.prototype
	    ctor.prototype = new TempCtor()
	    ctor.prototype.constructor = ctor
	  }
	}


/***/ },
/* 322 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(Buffer) {// Copyright Joyent, Inc. and other Node contributors.
	//
	// Permission is hereby granted, free of charge, to any person obtaining a
	// copy of this software and associated documentation files (the
	// "Software"), to deal in the Software without restriction, including
	// without limitation the rights to use, copy, modify, merge, publish,
	// distribute, sublicense, and/or sell copies of the Software, and to permit
	// persons to whom the Software is furnished to do so, subject to the
	// following conditions:
	//
	// The above copyright notice and this permission notice shall be included
	// in all copies or substantial portions of the Software.
	//
	// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
	// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
	// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
	// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
	// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
	// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
	// USE OR OTHER DEALINGS IN THE SOFTWARE.

	// NOTE: These type checking functions intentionally don't use `instanceof`
	// because it is fragile and can be easily faked with `Object.create()`.

	function isArray(arg) {
	  if (Array.isArray) {
	    return Array.isArray(arg);
	  }
	  return objectToString(arg) === '[object Array]';
	}
	exports.isArray = isArray;

	function isBoolean(arg) {
	  return typeof arg === 'boolean';
	}
	exports.isBoolean = isBoolean;

	function isNull(arg) {
	  return arg === null;
	}
	exports.isNull = isNull;

	function isNullOrUndefined(arg) {
	  return arg == null;
	}
	exports.isNullOrUndefined = isNullOrUndefined;

	function isNumber(arg) {
	  return typeof arg === 'number';
	}
	exports.isNumber = isNumber;

	function isString(arg) {
	  return typeof arg === 'string';
	}
	exports.isString = isString;

	function isSymbol(arg) {
	  return typeof arg === 'symbol';
	}
	exports.isSymbol = isSymbol;

	function isUndefined(arg) {
	  return arg === void 0;
	}
	exports.isUndefined = isUndefined;

	function isRegExp(re) {
	  return objectToString(re) === '[object RegExp]';
	}
	exports.isRegExp = isRegExp;

	function isObject(arg) {
	  return typeof arg === 'object' && arg !== null;
	}
	exports.isObject = isObject;

	function isDate(d) {
	  return objectToString(d) === '[object Date]';
	}
	exports.isDate = isDate;

	function isError(e) {
	  return (objectToString(e) === '[object Error]' || e instanceof Error);
	}
	exports.isError = isError;

	function isFunction(arg) {
	  return typeof arg === 'function';
	}
	exports.isFunction = isFunction;

	function isPrimitive(arg) {
	  return arg === null ||
	         typeof arg === 'boolean' ||
	         typeof arg === 'number' ||
	         typeof arg === 'string' ||
	         typeof arg === 'symbol' ||  // ES6 symbol
	         typeof arg === 'undefined';
	}
	exports.isPrimitive = isPrimitive;

	exports.isBuffer = Buffer.isBuffer;

	function objectToString(o) {
	  return Object.prototype.toString.call(o);
	}
	
	/* WEBPACK VAR INJECTION */}.call(exports, __webpack_require__(87).Buffer))

/***/ },
/* 323 */
/***/ function(module, exports, __webpack_require__) {

	// shim for using process in browser

	var process = module.exports = {};
	var queue = [];
	var draining = false;
	var currentQueue;
	var queueIndex = -1;

	function cleanUpNextTick() {
	    if (!draining || !currentQueue) {
	        return;
	    }
	    draining = false;
	    if (currentQueue.length) {
	        queue = currentQueue.concat(queue);
	    } else {
	        queueIndex = -1;
	    }
	    if (queue.length) {
	        drainQueue();
	    }
	}

	function drainQueue() {
	    if (draining) {
	        return;
	    }
	    var timeout = setTimeout(cleanUpNextTick);
	    draining = true;

	    var len = queue.length;
	    while(len) {
	        currentQueue = queue;
	        queue = [];
	        while (++queueIndex < len) {
	            if (currentQueue) {
	                currentQueue[queueIndex].run();
	            }
	        }
	        queueIndex = -1;
	        len = queue.length;
	    }
	    currentQueue = null;
	    draining = false;
	    clearTimeout(timeout);
	}

	process.nextTick = function (fun) {
	    var args = new Array(arguments.length - 1);
	    if (arguments.length > 1) {
	        for (var i = 1; i < arguments.length; i++) {
	            args[i - 1] = arguments[i];
	        }
	    }
	    queue.push(new Item(fun, args));
	    if (queue.length === 1 && !draining) {
	        setTimeout(drainQueue, 0);
	    }
	};

	// v8 likes predictible objects
	function Item(fun, array) {
	    this.fun = fun;
	    this.array = array;
	}
	Item.prototype.run = function () {
	    this.fun.apply(null, this.array);
	};
	process.title = 'browser';
	process.browser = true;
	process.env = {};
	process.argv = [];
	process.version = ''; // empty string to avoid regexp issues
	process.versions = {};

	function noop() {}

	process.on = noop;
	process.addListener = noop;
	process.once = noop;
	process.off = noop;
	process.removeListener = noop;
	process.removeAllListeners = noop;
	process.emit = noop;

	process.binding = function (name) {
	    throw new Error('process.binding is not supported');
	};

	process.cwd = function () { return '/' };
	process.chdir = function (dir) {
	    throw new Error('process.chdir is not supported');
	};
	process.umask = function() { return 0; };


/***/ },
/* 324 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = assertString;
	function assertString(input) {
	  if (typeof input !== 'string') {
	    throw new TypeError('This library (validator.js) validates strings only');
	  }
	}
	module.exports = exports['default'];

/***/ },
/* 325 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	exports.default = merge;
	function merge() {
	  var obj = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];
	  var defaults = arguments[1];

	  for (var key in defaults) {
	    if (typeof obj[key] === 'undefined') {
	      obj[key] = defaults[key];
	    }
	  }
	  return obj;
	}
	module.exports = exports['default'];

/***/ },
/* 326 */
/***/ function(module, exports, __webpack_require__) {

	'use strict';

	Object.defineProperty(exports, "__esModule", {
	  value: true
	});
	var alpha = exports.alpha = {
	  'en-US': /^[A-Z]+$/i,
	  'cs-CZ': /^[A-ZÁČĎÉĚÍŇÓŘŠŤÚŮÝŽ]+$/i,
	  'de-DE': /^[A-ZÄÖÜß]+$/i,
	  'es-ES': /^[A-ZÁÉÍÑÓÚÜ]+$/i,
	  'fr-FR': /^[A-ZÀÂÆÇÉÈÊËÏÎÔŒÙÛÜŸ]+$/i,
	  'nl-NL': /^[A-ZÉËÏÓÖÜ]+$/i,
	  'pl-PL': /^[A-ZĄĆĘŚŁŃÓŻŹ]+$/i,
	  'pt-PT': /^[A-ZÃÁÀÂÇÉÊÍÕÓÔÚÜ]+$/i,
	  'ru-RU': /^[А-ЯЁа-яё]+$/i,
	  'tr-TR': /^[A-ZÇĞİıÖŞÜ]+$/i,
	  ar: /^[ءآأؤإئابةتثجحخدذرزسشصضطظعغفقكلمنهوىيًٌٍَُِّْٰ]+$/
	};

	var alphanumeric = exports.alphanumeric = {
	  'en-US': /^[0-9A-Z]+$/i,
	  'cs-CZ': /^[0-9A-ZÁČĎÉĚÍŇÓŘŠŤÚŮÝŽ]+$/i,
	  'de-DE': /^[0-9A-ZÄÖÜß]+$/i,
	  'es-ES': /^[0-9A-ZÁÉÍÑÓÚÜ]+$/i,
	  'fr-FR': /^[0-9A-ZÀÂÆÇÉÈÊËÏÎÔŒÙÛÜŸ]+$/i,
	  'nl-NL': /^[0-9A-ZÉËÏÓÖÜ]+$/i,
	  'pl-PL': /^[0-9A-ZĄĆĘŚŁŃÓŻŹ]+$/i,
	  'pt-PT': /^[0-9A-ZÃÁÀÂÇÉÊÍÕÓÔÚÜ]+$/i,
	  'ru-RU': /^[0-9А-ЯЁа-яё]+$/i,
	  'tr-TR': /^[0-9A-ZÇĞİıÖŞÜ]+$/i,
	  ar: /^[٠١٢٣٤٥٦٧٨٩0-9ءآأؤإئابةتثجحخدذرزسشصضطظعغفقكلمنهوىيًٌٍَُِّْٰ]+$/
	};

	var englishLocales = exports.englishLocales = ['AU', 'GB', 'HK', 'IN', 'NZ', 'ZA', 'ZM'];

	for (var locale, i = 0; i < englishLocales.length; i++) {
	  locale = 'en-' + englishLocales[i];
	  alpha[locale] = alpha['en-US'];
	  alphanumeric[locale] = alphanumeric['en-US'];
	}

	// Source: http://www.localeplanet.com/java/
	var arabicLocales = exports.arabicLocales = ['AE', 'BH', 'DZ', 'EG', 'IQ', 'JO', 'KW', 'LB', 'LY', 'MA', 'QM', 'QA', 'SA', 'SD', 'SY', 'TN', 'YE'];

	for (var _locale, _i = 0; _i < arabicLocales.length; _i++) {
	  _locale = 'ar-' + arabicLocales[_i];
	  alpha[_locale] = alpha.ar;
	  alphanumeric[_locale] = alphanumeric.ar;
	}

/***/ },
/* 327 */
/***/ function(module, exports, __webpack_require__) {

	// Generated by CoffeeScript 1.9.1
	(function() {
	  var XMLStringifier,
	    bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; },
	    hasProp = {}.hasOwnProperty;

	  module.exports = XMLStringifier = (function() {
	    function XMLStringifier(options) {
	      this.assertLegalChar = bind(this.assertLegalChar, this);
	      var key, ref, value;
	      this.allowSurrogateChars = options != null ? options.allowSurrogateChars : void 0;
	      this.noDoubleEncoding = options != null ? options.noDoubleEncoding : void 0;
	      ref = (options != null ? options.stringify : void 0) || {};
	      for (key in ref) {
	        if (!hasProp.call(ref, key)) continue;
	        value = ref[key];
	        this[key] = value;
	      }
	    }

	    XMLStringifier.prototype.eleName = function(val) {
	      val = '' + val || '';
	      return this.assertLegalChar(val);
	    };

	    XMLStringifier.prototype.eleText = function(val) {
	      val = '' + val || '';
	      return this.assertLegalChar(this.elEscape(val));
	    };

	    XMLStringifier.prototype.cdata = function(val) {
	      val = '' + val || '';
	      if (val.match(/]]>/)) {
	        throw new Error("Invalid CDATA text: " + val);
	      }
	      return this.assertLegalChar(val);
	    };

	    XMLStringifier.prototype.comment = function(val) {
	      val = '' + val || '';
	      if (val.match(/--/)) {
	        throw new Error("Comment text cannot contain double-hypen: " + val);
	      }
	      return this.assertLegalChar(val);
	    };

	    XMLStringifier.prototype.raw = function(val) {
	      return '' + val || '';
	    };

	    XMLStringifier.prototype.attName = function(val) {
	      return '' + val || '';
	    };

	    XMLStringifier.prototype.attValue = function(val) {
	      val = '' + val || '';
	      return this.attEscape(val);
	    };

	    XMLStringifier.prototype.insTarget = function(val) {
	      return '' + val || '';
	    };

	    XMLStringifier.prototype.insValue = function(val) {
	      val = '' + val || '';
	      if (val.match(/\?>/)) {
	        throw new Error("Invalid processing instruction value: " + val);
	      }
	      return val;
	    };

	    XMLStringifier.prototype.xmlVersion = function(val) {
	      val = '' + val || '';
	      if (!val.match(/1\.[0-9]+/)) {
	        throw new Error("Invalid version number: " + val);
	      }
	      return val;
	    };

	    XMLStringifier.prototype.xmlEncoding = function(val) {
	      val = '' + val || '';
	      if (!val.match(/^[A-Za-z](?:[A-Za-z0-9._-]|-)*$/)) {
	        throw new Error("Invalid encoding: " + val);
	      }
	      return val;
	    };

	    XMLStringifier.prototype.xmlStandalone = function(val) {
	      if (val) {
	        return "yes";
	      } else {
	        return "no";
	      }
	    };

	    XMLStringifier.prototype.dtdPubID = function(val) {
	      return '' + val || '';
	    };

	    XMLStringifier.prototype.dtdSysID = function(val) {
	      return '' + val || '';
	    };

	    XMLStringifier.prototype.dtdElementValue = function(val) {
	      return '' + val || '';
	    };

	    XMLStringifier.prototype.dtdAttType = function(val) {
	      return '' + val || '';
	    };

	    XMLStringifier.prototype.dtdAttDefault = function(val) {
	      if (val != null) {
	        return '' + val || '';
	      } else {
	        return val;
	      }
	    };

	    XMLStringifier.prototype.dtdEntityValue = function(val) {
	      return '' + val || '';
	    };

	    XMLStringifier.prototype.dtdNData = function(val) {
	      return '' + val || '';
	    };

	    XMLStringifier.prototype.convertAttKey = '@';

	    XMLStringifier.prototype.convertPIKey = '?';

	    XMLStringifier.prototype.convertTextKey = '#text';

	    XMLStringifier.prototype.convertCDataKey = '#cdata';

	    XMLStringifier.prototype.convertCommentKey = '#comment';

	    XMLStringifier.prototype.convertRawKey = '#raw';

	    XMLStringifier.prototype.assertLegalChar = function(str) {
	      var chars, chr;
	      if (this.allowSurrogateChars) {
	        chars = /[\u0000-\u0008\u000B-\u000C\u000E-\u001F\uFFFE-\uFFFF]/;
	      } else {
	        chars = /[\u0000-\u0008\u000B-\u000C\u000E-\u001F\uD800-\uDFFF\uFFFE-\uFFFF]/;
	      }
	      chr = str.match(chars);
	      if (chr) {
	        throw new Error("Invalid character (" + chr + ") in string: " + str + " at index " + chr.index);
	      }
	      return str;
	    };

	    XMLStringifier.prototype.elEscape = function(str) {
	      var ampregex;
	      ampregex = this.noDoubleEncoding ? /(?!&\S+;)&/g : /&/g;
	      return str.replace(ampregex, '&amp;').replace(/</g, '&lt;').replace(/>/g, '&gt;').replace(/\r/g, '&#xD;');
	    };

	    XMLStringifier.prototype.attEscape = function(str) {
	      var ampregex;
	      ampregex = this.noDoubleEncoding ? /(?!&\S+;)&/g : /&/g;
	      return str.replace(ampregex, '&amp;').replace(/</g, '&lt;').replace(/"/g, '&quot;');
	    };

	    return XMLStringifier;

	  })();

	}).call(this);


/***/ },
/* 328 */
/***/ function(module, exports, __webpack_require__) {

	// Generated by CoffeeScript 1.9.1
	(function() {
	  var XMLDeclaration, XMLNode, create, isObject,
	    extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
	    hasProp = {}.hasOwnProperty;

	  create = __webpack_require__(332);

	  isObject = __webpack_require__(333);

	  XMLNode = __webpack_require__(334);

	  module.exports = XMLDeclaration = (function(superClass) {
	    extend(XMLDeclaration, superClass);

	    function XMLDeclaration(parent, version, encoding, standalone) {
	      var ref;
	      XMLDeclaration.__super__.constructor.call(this, parent);
	      if (isObject(version)) {
	        ref = version, version = ref.version, encoding = ref.encoding, standalone = ref.standalone;
	      }
	      if (!version) {
	        version = '1.0';
	      }
	      this.version = this.stringify.xmlVersion(version);
	      if (encoding != null) {
	        this.encoding = this.stringify.xmlEncoding(encoding);
	      }
	      if (standalone != null) {
	        this.standalone = this.stringify.xmlStandalone(standalone);
	      }
	    }

	    XMLDeclaration.prototype.toString = function(options, level) {
	      var indent, newline, offset, pretty, r, ref, ref1, ref2, space;
	      pretty = (options != null ? options.pretty : void 0) || false;
	      indent = (ref = options != null ? options.indent : void 0) != null ? ref : '  ';
	      offset = (ref1 = options != null ? options.offset : void 0) != null ? ref1 : 0;
	      newline = (ref2 = options != null ? options.newline : void 0) != null ? ref2 : '\n';
	      level || (level = 0);
	      space = new Array(level + offset + 1).join(indent);
	      r = '';
	      if (pretty) {
	        r += space;
	      }
	      r += '<?xml';
	      r += ' version="' + this.version + '"';
	      if (this.encoding != null) {
	        r += ' encoding="' + this.encoding + '"';
	      }
	      if (this.standalone != null) {
	        r += ' standalone="' + this.standalone + '"';
	      }
	      r += '?>';
	      if (pretty) {
	        r += newline;
	      }
	      return r;
	    };

	    return XMLDeclaration;

	  })(XMLNode);

	}).call(this);


/***/ },
/* 329 */
/***/ function(module, exports, __webpack_require__) {

	// Generated by CoffeeScript 1.9.1
	(function() {
	  var XMLCData, XMLComment, XMLDTDAttList, XMLDTDElement, XMLDTDEntity, XMLDTDNotation, XMLDocType, XMLProcessingInstruction, create, isObject;

	  create = __webpack_require__(332);

	  isObject = __webpack_require__(333);

	  XMLCData = __webpack_require__(339);

	  XMLComment = __webpack_require__(340);

	  XMLDTDAttList = __webpack_require__(341);

	  XMLDTDEntity = __webpack_require__(342);

	  XMLDTDElement = __webpack_require__(343);

	  XMLDTDNotation = __webpack_require__(344);

	  XMLProcessingInstruction = __webpack_require__(338);

	  module.exports = XMLDocType = (function() {
	    function XMLDocType(parent, pubID, sysID) {
	      var ref, ref1;
	      this.documentObject = parent;
	      this.stringify = this.documentObject.stringify;
	      this.children = [];
	      if (isObject(pubID)) {
	        ref = pubID, pubID = ref.pubID, sysID = ref.sysID;
	      }
	      if (sysID == null) {
	        ref1 = [pubID, sysID], sysID = ref1[0], pubID = ref1[1];
	      }
	      if (pubID != null) {
	        this.pubID = this.stringify.dtdPubID(pubID);
	      }
	      if (sysID != null) {
	        this.sysID = this.stringify.dtdSysID(sysID);
	      }
	    }

	    XMLDocType.prototype.element = function(name, value) {
	      var child;
	      child = new XMLDTDElement(this, name, value);
	      this.children.push(child);
	      return this;
	    };

	    XMLDocType.prototype.attList = function(elementName, attributeName, attributeType, defaultValueType, defaultValue) {
	      var child;
	      child = new XMLDTDAttList(this, elementName, attributeName, attributeType, defaultValueType, defaultValue);
	      this.children.push(child);
	      return this;
	    };

	    XMLDocType.prototype.entity = function(name, value) {
	      var child;
	      child = new XMLDTDEntity(this, false, name, value);
	      this.children.push(child);
	      return this;
	    };

	    XMLDocType.prototype.pEntity = function(name, value) {
	      var child;
	      child = new XMLDTDEntity(this, true, name, value);
	      this.children.push(child);
	      return this;
	    };

	    XMLDocType.prototype.notation = function(name, value) {
	      var child;
	      child = new XMLDTDNotation(this, name, value);
	      this.children.push(child);
	      return this;
	    };

	    XMLDocType.prototype.cdata = function(value) {
	      var child;
	      child = new XMLCData(this, value);
	      this.children.push(child);
	      return this;
	    };

	    XMLDocType.prototype.comment = function(value) {
	      var child;
	      child = new XMLComment(this, value);
	      this.children.push(child);
	      return this;
	    };

	    XMLDocType.prototype.instruction = function(target, value) {
	      var child;
	      child = new XMLProcessingInstruction(this, target, value);
	      this.children.push(child);
	      return this;
	    };

	    XMLDocType.prototype.root = function() {
	      return this.documentObject.root();
	    };

	    XMLDocType.prototype.document = function() {
	      return this.documentObject;
	    };

	    XMLDocType.prototype.toString = function(options, level) {
	      var child, i, indent, len, newline, offset, pretty, r, ref, ref1, ref2, ref3, space;
	      pretty = (options != null ? options.pretty : void 0) || false;
	      indent = (ref = options != null ? options.indent : void 0) != null ? ref : '  ';
	      offset = (ref1 = options != null ? options.offset : void 0) != null ? ref1 : 0;
	      newline = (ref2 = options != null ? options.newline : void 0) != null ? ref2 : '\n';
	      level || (level = 0);
	      space = new Array(level + offset + 1).join(indent);
	      r = '';
	      if (pretty) {
	        r += space;
	      }
	      r += '<!DOCTYPE ' + this.root().name;
	      if (this.pubID && this.sysID) {
	        r += ' PUBLIC "' + this.pubID + '" "' + this.sysID + '"';
	      } else if (this.sysID) {
	        r += ' SYSTEM "' + this.sysID + '"';
	      }
	      if (this.children.length > 0) {
	        r += ' [';
	        if (pretty) {
	          r += newline;
	        }
	        ref3 = this.children;
	        for (i = 0, len = ref3.length; i < len; i++) {
	          child = ref3[i];
	          r += child.toString(options, level + 1);
	        }
	        r += ']';
	      }
	      r += '>';
	      if (pretty) {
	        r += newline;
	      }
	      return r;
	    };

	    XMLDocType.prototype.ele = function(name, value) {
	      return this.element(name, value);
	    };

	    XMLDocType.prototype.att = function(elementName, attributeName, attributeType, defaultValueType, defaultValue) {
	      return this.attList(elementName, attributeName, attributeType, defaultValueType, defaultValue);
	    };

	    XMLDocType.prototype.ent = function(name, value) {
	      return this.entity(name, value);
	    };

	    XMLDocType.prototype.pent = function(name, value) {
	      return this.pEntity(name, value);
	    };

	    XMLDocType.prototype.not = function(name, value) {
	      return this.notation(name, value);
	    };

	    XMLDocType.prototype.dat = function(value) {
	      return this.cdata(value);
	    };

	    XMLDocType.prototype.com = function(value) {
	      return this.comment(value);
	    };

	    XMLDocType.prototype.ins = function(target, value) {
	      return this.instruction(target, value);
	    };

	    XMLDocType.prototype.up = function() {
	      return this.root();
	    };

	    XMLDocType.prototype.doc = function() {
	      return this.document();
	    };

	    return XMLDocType;

	  })();

	}).call(this);


/***/ },
/* 330 */
/***/ function(module, exports, __webpack_require__) {

	// Generated by CoffeeScript 1.9.1
	(function() {
	  var XMLAttribute, XMLElement, XMLNode, XMLProcessingInstruction, create, every, isFunction, isObject,
	    extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
	    hasProp = {}.hasOwnProperty;

	  create = __webpack_require__(332);

	  isObject = __webpack_require__(333);

	  isFunction = __webpack_require__(335);

	  every = __webpack_require__(336);

	  XMLNode = __webpack_require__(334);

	  XMLAttribute = __webpack_require__(337);

	  XMLProcessingInstruction = __webpack_require__(338);

	  module.exports = XMLElement = (function(superClass) {
	    extend(XMLElement, superClass);

	    function XMLElement(parent, name, attributes) {
	      XMLElement.__super__.constructor.call(this, parent);
	      if (name == null) {
	        throw new Error("Missing element name");
	      }
	      this.name = this.stringify.eleName(name);
	      this.children = [];
	      this.instructions = [];
	      this.attributes = {};
	      if (attributes != null) {
	        this.attribute(attributes);
	      }
	    }

	    XMLElement.prototype.clone = function() {
	      var att, attName, clonedSelf, i, len, pi, ref, ref1;
	      clonedSelf = create(XMLElement.prototype, this);
	      if (clonedSelf.isRoot) {
	        clonedSelf.documentObject = null;
	      }
	      clonedSelf.attributes = {};
	      ref = this.attributes;
	      for (attName in ref) {
	        if (!hasProp.call(ref, attName)) continue;
	        att = ref[attName];
	        clonedSelf.attributes[attName] = att.clone();
	      }
	      clonedSelf.instructions = [];
	      ref1 = this.instructions;
	      for (i = 0, len = ref1.length; i < len; i++) {
	        pi = ref1[i];
	        clonedSelf.instructions.push(pi.clone());
	      }
	      clonedSelf.children = [];
	      this.children.forEach(function(child) {
	        var clonedChild;
	        clonedChild = child.clone();
	        clonedChild.parent = clonedSelf;
	        return clonedSelf.children.push(clonedChild);
	      });
	      return clonedSelf;
	    };

	    XMLElement.prototype.attribute = function(name, value) {
	      var attName, attValue;
	      if (name != null) {
	        name = name.valueOf();
	      }
	      if (isObject(name)) {
	        for (attName in name) {
	          if (!hasProp.call(name, attName)) continue;
	          attValue = name[attName];
	          this.attribute(attName, attValue);
	        }
	      } else {
	        if (isFunction(value)) {
	          value = value.apply();
	        }
	        if (!this.options.skipNullAttributes || (value != null)) {
	          this.attributes[name] = new XMLAttribute(this, name, value);
	        }
	      }
	      return this;
	    };

	    XMLElement.prototype.removeAttribute = function(name) {
	      var attName, i, len;
	      if (name == null) {
	        throw new Error("Missing attribute name");
	      }
	      name = name.valueOf();
	      if (Array.isArray(name)) {
	        for (i = 0, len = name.length; i < len; i++) {
	          attName = name[i];
	          delete this.attributes[attName];
	        }
	      } else {
	        delete this.attributes[name];
	      }
	      return this;
	    };

	    XMLElement.prototype.instruction = function(target, value) {
	      var i, insTarget, insValue, instruction, len;
	      if (target != null) {
	        target = target.valueOf();
	      }
	      if (value != null) {
	        value = value.valueOf();
	      }
	      if (Array.isArray(target)) {
	        for (i = 0, len = target.length; i < len; i++) {
	          insTarget = target[i];
	          this.instruction(insTarget);
	        }
	      } else if (isObject(target)) {
	        for (insTarget in target) {
	          if (!hasProp.call(target, insTarget)) continue;
	          insValue = target[insTarget];
	          this.instruction(insTarget, insValue);
	        }
	      } else {
	        if (isFunction(value)) {
	          value = value.apply();
	        }
	        instruction = new XMLProcessingInstruction(this, target, value);
	        this.instructions.push(instruction);
	      }
	      return this;
	    };

	    XMLElement.prototype.toString = function(options, level) {
	      var att, child, i, indent, instruction, j, len, len1, name, newline, offset, pretty, r, ref, ref1, ref2, ref3, ref4, ref5, space;
	      pretty = (options != null ? options.pretty : void 0) || false;
	      indent = (ref = options != null ? options.indent : void 0) != null ? ref : '  ';
	      offset = (ref1 = options != null ? options.offset : void 0) != null ? ref1 : 0;
	      newline = (ref2 = options != null ? options.newline : void 0) != null ? ref2 : '\n';
	      level || (level = 0);
	      space = new Array(level + offset + 1).join(indent);
	      r = '';
	      ref3 = this.instructions;
	      for (i = 0, len = ref3.length; i < len; i++) {
	        instruction = ref3[i];
	        r += instruction.toString(options, level);
	      }
	      if (pretty) {
	        r += space;
	      }
	      r += '<' + this.name;
	      ref4 = this.attributes;
	      for (name in ref4) {
	        if (!hasProp.call(ref4, name)) continue;
	        att = ref4[name];
	        r += att.toString(options);
	      }
	      if (this.children.length === 0 || every(this.children, function(e) {
	        return e.value === '';
	      })) {
	        r += '/>';
	        if (pretty) {
	          r += newline;
	        }
	      } else if (pretty && this.children.length === 1 && (this.children[0].value != null)) {
	        r += '>';
	        r += this.children[0].value;
	        r += '</' + this.name + '>';
	        r += newline;
	      } else {
	        r += '>';
	        if (pretty) {
	          r += newline;
	        }
	        ref5 = this.children;
	        for (j = 0, len1 = ref5.length; j < len1; j++) {
	          child = ref5[j];
	          r += child.toString(options, level + 1);
	        }
	        if (pretty) {
	          r += space;
	        }
	        r += '</' + this.name + '>';
	        if (pretty) {
	          r += newline;
	        }
	      }
	      return r;
	    };

	    XMLElement.prototype.att = function(name, value) {
	      return this.attribute(name, value);
	    };

	    XMLElement.prototype.ins = function(target, value) {
	      return this.instruction(target, value);
	    };

	    XMLElement.prototype.a = function(name, value) {
	      return this.attribute(name, value);
	    };

	    XMLElement.prototype.i = function(target, value) {
	      return this.instruction(target, value);
	    };

	    return XMLElement;

	  })(XMLNode);

	}).call(this);


/***/ },
/* 331 */
/***/ function(module, exports, __webpack_require__) {

	var assignValue = __webpack_require__(345),
	    copyObject = __webpack_require__(346),
	    createAssigner = __webpack_require__(347),
	    isArrayLike = __webpack_require__(348),
	    isPrototype = __webpack_require__(349),
	    keys = __webpack_require__(350);

	/** Used for built-in method references. */
	var objectProto = Object.prototype;

	/** Used to check objects for own properties. */
	var hasOwnProperty = objectProto.hasOwnProperty;

	/** Built-in value references. */
	var propertyIsEnumerable = objectProto.propertyIsEnumerable;

	/** Detect if properties shadowing those on `Object.prototype` are non-enumerable. */
	var nonEnumShadows = !propertyIsEnumerable.call({ 'valueOf': 1 }, 'valueOf');

	/**
	 * Assigns own enumerable string keyed properties of source objects to the
	 * destination object. Source objects are applied from left to right.
	 * Subsequent sources overwrite property assignments of previous sources.
	 *
	 * **Note:** This method mutates `object` and is loosely based on
	 * [`Object.assign`](https://mdn.io/Object/assign).
	 *
	 * @static
	 * @memberOf _
	 * @since 0.10.0
	 * @category Object
	 * @param {Object} object The destination object.
	 * @param {...Object} [sources] The source objects.
	 * @returns {Object} Returns `object`.
	 * @example
	 *
	 * function Foo() {
	 *   this.c = 3;
	 * }
	 *
	 * function Bar() {
	 *   this.e = 5;
	 * }
	 *
	 * Foo.prototype.d = 4;
	 * Bar.prototype.f = 6;
	 *
	 * _.assign({ 'a': 1 }, new Foo, new Bar);
	 * // => { 'a': 1, 'c': 3, 'e': 5 }
	 */
	var assign = createAssigner(function(object, source) {
	  if (nonEnumShadows || isPrototype(source) || isArrayLike(source)) {
	    copyObject(source, keys(source), object);
	    return;
	  }
	  for (var key in source) {
	    if (hasOwnProperty.call(source, key)) {
	      assignValue(object, key, source[key]);
	    }
	  }
	});

	module.exports = assign;


/***/ },
/* 332 */
/***/ function(module, exports, __webpack_require__) {

	var baseAssign = __webpack_require__(351),
	    baseCreate = __webpack_require__(352);

	/**
	 * Creates an object that inherits from the `prototype` object. If a
	 * `properties` object is given, its own enumerable string keyed properties
	 * are assigned to the created object.
	 *
	 * @static
	 * @memberOf _
	 * @since 2.3.0
	 * @category Object
	 * @param {Object} prototype The object to inherit from.
	 * @param {Object} [properties] The properties to assign to the object.
	 * @returns {Object} Returns the new object.
	 * @example
	 *
	 * function Shape() {
	 *   this.x = 0;
	 *   this.y = 0;
	 * }
	 *
	 * function Circle() {
	 *   Shape.call(this);
	 * }
	 *
	 * Circle.prototype = _.create(Shape.prototype, {
	 *   'constructor': Circle
	 * });
	 *
	 * var circle = new Circle;
	 * circle instanceof Circle;
	 * // => true
	 *
	 * circle instanceof Shape;
	 * // => true
	 */
	function create(prototype, properties) {
	  var result = baseCreate(prototype);
	  return properties ? baseAssign(result, properties) : result;
	}

	module.exports = create;


/***/ },
/* 333 */
/***/ function(module, exports, __webpack_require__) {

	/**
	 * Checks if `value` is the
	 * [language type](http://www.ecma-international.org/ecma-262/6.0/#sec-ecmascript-language-types)
	 * of `Object`. (e.g. arrays, functions, objects, regexes, `new Number(0)`, and `new String('')`)
	 *
	 * @static
	 * @memberOf _
	 * @since 0.1.0
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is an object, else `false`.
	 * @example
	 *
	 * _.isObject({});
	 * // => true
	 *
	 * _.isObject([1, 2, 3]);
	 * // => true
	 *
	 * _.isObject(_.noop);
	 * // => true
	 *
	 * _.isObject(null);
	 * // => false
	 */
	function isObject(value) {
	  var type = typeof value;
	  return !!value && (type == 'object' || type == 'function');
	}

	module.exports = isObject;


/***/ },
/* 334 */
/***/ function(module, exports, __webpack_require__) {

	// Generated by CoffeeScript 1.9.1
	(function() {
	  var XMLCData, XMLComment, XMLDeclaration, XMLDocType, XMLElement, XMLNode, XMLRaw, XMLText, isEmpty, isFunction, isObject,
	    hasProp = {}.hasOwnProperty;

	  isObject = __webpack_require__(333);

	  isFunction = __webpack_require__(335);

	  isEmpty = __webpack_require__(353);

	  XMLElement = null;

	  XMLCData = null;

	  XMLComment = null;

	  XMLDeclaration = null;

	  XMLDocType = null;

	  XMLRaw = null;

	  XMLText = null;

	  module.exports = XMLNode = (function() {
	    function XMLNode(parent) {
	      this.parent = parent;
	      this.options = this.parent.options;
	      this.stringify = this.parent.stringify;
	      if (XMLElement === null) {
	        XMLElement = __webpack_require__(330);
	        XMLCData = __webpack_require__(339);
	        XMLComment = __webpack_require__(340);
	        XMLDeclaration = __webpack_require__(328);
	        XMLDocType = __webpack_require__(329);
	        XMLRaw = __webpack_require__(354);
	        XMLText = __webpack_require__(355);
	      }
	    }

	    XMLNode.prototype.element = function(name, attributes, text) {
	      var childNode, item, j, k, key, lastChild, len, len1, ref, val;
	      lastChild = null;
	      if (attributes == null) {
	        attributes = {};
	      }
	      attributes = attributes.valueOf();
	      if (!isObject(attributes)) {
	        ref = [attributes, text], text = ref[0], attributes = ref[1];
	      }
	      if (name != null) {
	        name = name.valueOf();
	      }
	      if (Array.isArray(name)) {
	        for (j = 0, len = name.length; j < len; j++) {
	          item = name[j];
	          lastChild = this.element(item);
	        }
	      } else if (isFunction(name)) {
	        lastChild = this.element(name.apply());
	      } else if (isObject(name)) {
	        for (key in name) {
	          if (!hasProp.call(name, key)) continue;
	          val = name[key];
	          if (isFunction(val)) {
	            val = val.apply();
	          }
	          if ((isObject(val)) && (isEmpty(val))) {
	            val = null;
	          }
	          if (!this.options.ignoreDecorators && this.stringify.convertAttKey && key.indexOf(this.stringify.convertAttKey) === 0) {
	            lastChild = this.attribute(key.substr(this.stringify.convertAttKey.length), val);
	          } else if (!this.options.ignoreDecorators && this.stringify.convertPIKey && key.indexOf(this.stringify.convertPIKey) === 0) {
	            lastChild = this.instruction(key.substr(this.stringify.convertPIKey.length), val);
	          } else if (!this.options.separateArrayItems && Array.isArray(val)) {
	            for (k = 0, len1 = val.length; k < len1; k++) {
	              item = val[k];
	              childNode = {};
	              childNode[key] = item;
	              lastChild = this.element(childNode);
	            }
	          } else if (isObject(val)) {
	            lastChild = this.element(key);
	            lastChild.element(val);
	          } else {
	            lastChild = this.element(key, val);
	          }
	        }
	      } else {
	        if (!this.options.ignoreDecorators && this.stringify.convertTextKey && name.indexOf(this.stringify.convertTextKey) === 0) {
	          lastChild = this.text(text);
	        } else if (!this.options.ignoreDecorators && this.stringify.convertCDataKey && name.indexOf(this.stringify.convertCDataKey) === 0) {
	          lastChild = this.cdata(text);
	        } else if (!this.options.ignoreDecorators && this.stringify.convertCommentKey && name.indexOf(this.stringify.convertCommentKey) === 0) {
	          lastChild = this.comment(text);
	        } else if (!this.options.ignoreDecorators && this.stringify.convertRawKey && name.indexOf(this.stringify.convertRawKey) === 0) {
	          lastChild = this.raw(text);
	        } else {
	          lastChild = this.node(name, attributes, text);
	        }
	      }
	      if (lastChild == null) {
	        throw new Error("Could not create any elements with: " + name);
	      }
	      return lastChild;
	    };

	    XMLNode.prototype.insertBefore = function(name, attributes, text) {
	      var child, i, removed;
	      if (this.isRoot) {
	        throw new Error("Cannot insert elements at root level");
	      }
	      i = this.parent.children.indexOf(this);
	      removed = this.parent.children.splice(i);
	      child = this.parent.element(name, attributes, text);
	      Array.prototype.push.apply(this.parent.children, removed);
	      return child;
	    };

	    XMLNode.prototype.insertAfter = function(name, attributes, text) {
	      var child, i, removed;
	      if (this.isRoot) {
	        throw new Error("Cannot insert elements at root level");
	      }
	      i = this.parent.children.indexOf(this);
	      removed = this.parent.children.splice(i + 1);
	      child = this.parent.element(name, attributes, text);
	      Array.prototype.push.apply(this.parent.children, removed);
	      return child;
	    };

	    XMLNode.prototype.remove = function() {
	      var i, ref;
	      if (this.isRoot) {
	        throw new Error("Cannot remove the root element");
	      }
	      i = this.parent.children.indexOf(this);
	      [].splice.apply(this.parent.children, [i, i - i + 1].concat(ref = [])), ref;
	      return this.parent;
	    };

	    XMLNode.prototype.node = function(name, attributes, text) {
	      var child, ref;
	      if (name != null) {
	        name = name.valueOf();
	      }
	      if (attributes == null) {
	        attributes = {};
	      }
	      attributes = attributes.valueOf();
	      if (!isObject(attributes)) {
	        ref = [attributes, text], text = ref[0], attributes = ref[1];
	      }
	      child = new XMLElement(this, name, attributes);
	      if (text != null) {
	        child.text(text);
	      }
	      this.children.push(child);
	      return child;
	    };

	    XMLNode.prototype.text = function(value) {
	      var child;
	      child = new XMLText(this, value);
	      this.children.push(child);
	      return this;
	    };

	    XMLNode.prototype.cdata = function(value) {
	      var child;
	      child = new XMLCData(this, value);
	      this.children.push(child);
	      return this;
	    };

	    XMLNode.prototype.comment = function(value) {
	      var child;
	      child = new XMLComment(this, value);
	      this.children.push(child);
	      return this;
	    };

	    XMLNode.prototype.raw = function(value) {
	      var child;
	      child = new XMLRaw(this, value);
	      this.children.push(child);
	      return this;
	    };

	    XMLNode.prototype.declaration = function(version, encoding, standalone) {
	      var doc, xmldec;
	      doc = this.document();
	      xmldec = new XMLDeclaration(doc, version, encoding, standalone);
	      doc.xmldec = xmldec;
	      return doc.root();
	    };

	    XMLNode.prototype.doctype = function(pubID, sysID) {
	      var doc, doctype;
	      doc = this.document();
	      doctype = new XMLDocType(doc, pubID, sysID);
	      doc.doctype = doctype;
	      return doctype;
	    };

	    XMLNode.prototype.up = function() {
	      if (this.isRoot) {
	        throw new Error("The root node has no parent. Use doc() if you need to get the document object.");
	      }
	      return this.parent;
	    };

	    XMLNode.prototype.root = function() {
	      var child;
	      if (this.isRoot) {
	        return this;
	      }
	      child = this.parent;
	      while (!child.isRoot) {
	        child = child.parent;
	      }
	      return child;
	    };

	    XMLNode.prototype.document = function() {
	      return this.root().documentObject;
	    };

	    XMLNode.prototype.end = function(options) {
	      return this.document().toString(options);
	    };

	    XMLNode.prototype.prev = function() {
	      var i;
	      if (this.isRoot) {
	        throw new Error("Root node has no siblings");
	      }
	      i = this.parent.children.indexOf(this);
	      if (i < 1) {
	        throw new Error("Already at the first node");
	      }
	      return this.parent.children[i - 1];
	    };

	    XMLNode.prototype.next = function() {
	      var i;
	      if (this.isRoot) {
	        throw new Error("Root node has no siblings");
	      }
	      i = this.parent.children.indexOf(this);
	      if (i === -1 || i === this.parent.children.length - 1) {
	        throw new Error("Already at the last node");
	      }
	      return this.parent.children[i + 1];
	    };

	    XMLNode.prototype.importXMLBuilder = function(xmlbuilder) {
	      var clonedRoot;
	      clonedRoot = xmlbuilder.root().clone();
	      clonedRoot.parent = this;
	      clonedRoot.isRoot = false;
	      this.children.push(clonedRoot);
	      return this;
	    };

	    XMLNode.prototype.ele = function(name, attributes, text) {
	      return this.element(name, attributes, text);
	    };

	    XMLNode.prototype.nod = function(name, attributes, text) {
	      return this.node(name, attributes, text);
	    };

	    XMLNode.prototype.txt = function(value) {
	      return this.text(value);
	    };

	    XMLNode.prototype.dat = function(value) {
	      return this.cdata(value);
	    };

	    XMLNode.prototype.com = function(value) {
	      return this.comment(value);
	    };

	    XMLNode.prototype.doc = function() {
	      return this.document();
	    };

	    XMLNode.prototype.dec = function(version, encoding, standalone) {
	      return this.declaration(version, encoding, standalone);
	    };

	    XMLNode.prototype.dtd = function(pubID, sysID) {
	      return this.doctype(pubID, sysID);
	    };

	    XMLNode.prototype.e = function(name, attributes, text) {
	      return this.element(name, attributes, text);
	    };

	    XMLNode.prototype.n = function(name, attributes, text) {
	      return this.node(name, attributes, text);
	    };

	    XMLNode.prototype.t = function(value) {
	      return this.text(value);
	    };

	    XMLNode.prototype.d = function(value) {
	      return this.cdata(value);
	    };

	    XMLNode.prototype.c = function(value) {
	      return this.comment(value);
	    };

	    XMLNode.prototype.r = function(value) {
	      return this.raw(value);
	    };

	    XMLNode.prototype.u = function() {
	      return this.up();
	    };

	    return XMLNode;

	  })();

	}).call(this);


/***/ },
/* 335 */
/***/ function(module, exports, __webpack_require__) {

	var isObject = __webpack_require__(333);

	/** `Object#toString` result references. */
	var funcTag = '[object Function]',
	    genTag = '[object GeneratorFunction]';

	/** Used for built-in method references. */
	var objectProto = Object.prototype;

	/**
	 * Used to resolve the
	 * [`toStringTag`](http://ecma-international.org/ecma-262/6.0/#sec-object.prototype.tostring)
	 * of values.
	 */
	var objectToString = objectProto.toString;

	/**
	 * Checks if `value` is classified as a `Function` object.
	 *
	 * @static
	 * @memberOf _
	 * @since 0.1.0
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is correctly classified,
	 *  else `false`.
	 * @example
	 *
	 * _.isFunction(_);
	 * // => true
	 *
	 * _.isFunction(/abc/);
	 * // => false
	 */
	function isFunction(value) {
	  // The use of `Object#toString` avoids issues with the `typeof` operator
	  // in Safari 8 which returns 'object' for typed array and weak map constructors,
	  // and PhantomJS 1.9 which returns 'function' for `NodeList` instances.
	  var tag = isObject(value) ? objectToString.call(value) : '';
	  return tag == funcTag || tag == genTag;
	}

	module.exports = isFunction;


/***/ },
/* 336 */
/***/ function(module, exports, __webpack_require__) {

	var arrayEvery = __webpack_require__(356),
	    baseEvery = __webpack_require__(357),
	    baseIteratee = __webpack_require__(358),
	    isArray = __webpack_require__(359),
	    isIterateeCall = __webpack_require__(360);

	/**
	 * Checks if `predicate` returns truthy for **all** elements of `collection`.
	 * Iteration is stopped once `predicate` returns falsey. The predicate is
	 * invoked with three arguments: (value, index|key, collection).
	 *
	 * @static
	 * @memberOf _
	 * @since 0.1.0
	 * @category Collection
	 * @param {Array|Object} collection The collection to iterate over.
	 * @param {Array|Function|Object|string} [predicate=_.identity]
	 *  The function invoked per iteration.
	 * @param- {Object} [guard] Enables use as an iteratee for methods like `_.map`.
	 * @returns {boolean} Returns `true` if all elements pass the predicate check,
	 *  else `false`.
	 * @example
	 *
	 * _.every([true, 1, null, 'yes'], Boolean);
	 * // => false
	 *
	 * var users = [
	 *   { 'user': 'barney', 'age': 36, 'active': false },
	 *   { 'user': 'fred',   'age': 40, 'active': false }
	 * ];
	 *
	 * // The `_.matches` iteratee shorthand.
	 * _.every(users, { 'user': 'barney', 'active': false });
	 * // => false
	 *
	 * // The `_.matchesProperty` iteratee shorthand.
	 * _.every(users, ['active', false]);
	 * // => true
	 *
	 * // The `_.property` iteratee shorthand.
	 * _.every(users, 'active');
	 * // => false
	 */
	function every(collection, predicate, guard) {
	  var func = isArray(collection) ? arrayEvery : baseEvery;
	  if (guard && isIterateeCall(collection, predicate, guard)) {
	    predicate = undefined;
	  }
	  return func(collection, baseIteratee(predicate, 3));
	}

	module.exports = every;


/***/ },
/* 337 */
/***/ function(module, exports, __webpack_require__) {

	// Generated by CoffeeScript 1.9.1
	(function() {
	  var XMLAttribute, create;

	  create = __webpack_require__(332);

	  module.exports = XMLAttribute = (function() {
	    function XMLAttribute(parent, name, value) {
	      this.stringify = parent.stringify;
	      if (name == null) {
	        throw new Error("Missing attribute name of element " + parent.name);
	      }
	      if (value == null) {
	        throw new Error("Missing attribute value for attribute " + name + " of element " + parent.name);
	      }
	      this.name = this.stringify.attName(name);
	      this.value = this.stringify.attValue(value);
	    }

	    XMLAttribute.prototype.clone = function() {
	      return create(XMLAttribute.prototype, this);
	    };

	    XMLAttribute.prototype.toString = function(options, level) {
	      return ' ' + this.name + '="' + this.value + '"';
	    };

	    return XMLAttribute;

	  })();

	}).call(this);


/***/ },
/* 338 */
/***/ function(module, exports, __webpack_require__) {

	// Generated by CoffeeScript 1.9.1
	(function() {
	  var XMLProcessingInstruction, create;

	  create = __webpack_require__(332);

	  module.exports = XMLProcessingInstruction = (function() {
	    function XMLProcessingInstruction(parent, target, value) {
	      this.stringify = parent.stringify;
	      if (target == null) {
	        throw new Error("Missing instruction target");
	      }
	      this.target = this.stringify.insTarget(target);
	      if (value) {
	        this.value = this.stringify.insValue(value);
	      }
	    }

	    XMLProcessingInstruction.prototype.clone = function() {
	      return create(XMLProcessingInstruction.prototype, this);
	    };

	    XMLProcessingInstruction.prototype.toString = function(options, level) {
	      var indent, newline, offset, pretty, r, ref, ref1, ref2, space;
	      pretty = (options != null ? options.pretty : void 0) || false;
	      indent = (ref = options != null ? options.indent : void 0) != null ? ref : '  ';
	      offset = (ref1 = options != null ? options.offset : void 0) != null ? ref1 : 0;
	      newline = (ref2 = options != null ? options.newline : void 0) != null ? ref2 : '\n';
	      level || (level = 0);
	      space = new Array(level + offset + 1).join(indent);
	      r = '';
	      if (pretty) {
	        r += space;
	      }
	      r += '<?';
	      r += this.target;
	      if (this.value) {
	        r += ' ' + this.value;
	      }
	      r += '?>';
	      if (pretty) {
	        r += newline;
	      }
	      return r;
	    };

	    return XMLProcessingInstruction;

	  })();

	}).call(this);


/***/ },
/* 339 */
/***/ function(module, exports, __webpack_require__) {

	// Generated by CoffeeScript 1.9.1
	(function() {
	  var XMLCData, XMLNode, create,
	    extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
	    hasProp = {}.hasOwnProperty;

	  create = __webpack_require__(332);

	  XMLNode = __webpack_require__(334);

	  module.exports = XMLCData = (function(superClass) {
	    extend(XMLCData, superClass);

	    function XMLCData(parent, text) {
	      XMLCData.__super__.constructor.call(this, parent);
	      if (text == null) {
	        throw new Error("Missing CDATA text");
	      }
	      this.text = this.stringify.cdata(text);
	    }

	    XMLCData.prototype.clone = function() {
	      return create(XMLCData.prototype, this);
	    };

	    XMLCData.prototype.toString = function(options, level) {
	      var indent, newline, offset, pretty, r, ref, ref1, ref2, space;
	      pretty = (options != null ? options.pretty : void 0) || false;
	      indent = (ref = options != null ? options.indent : void 0) != null ? ref : '  ';
	      offset = (ref1 = options != null ? options.offset : void 0) != null ? ref1 : 0;
	      newline = (ref2 = options != null ? options.newline : void 0) != null ? ref2 : '\n';
	      level || (level = 0);
	      space = new Array(level + offset + 1).join(indent);
	      r = '';
	      if (pretty) {
	        r += space;
	      }
	      r += '<![CDATA[' + this.text + ']]>';
	      if (pretty) {
	        r += newline;
	      }
	      return r;
	    };

	    return XMLCData;

	  })(XMLNode);

	}).call(this);


/***/ },
/* 340 */
/***/ function(module, exports, __webpack_require__) {

	// Generated by CoffeeScript 1.9.1
	(function() {
	  var XMLComment, XMLNode, create,
	    extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
	    hasProp = {}.hasOwnProperty;

	  create = __webpack_require__(332);

	  XMLNode = __webpack_require__(334);

	  module.exports = XMLComment = (function(superClass) {
	    extend(XMLComment, superClass);

	    function XMLComment(parent, text) {
	      XMLComment.__super__.constructor.call(this, parent);
	      if (text == null) {
	        throw new Error("Missing comment text");
	      }
	      this.text = this.stringify.comment(text);
	    }

	    XMLComment.prototype.clone = function() {
	      return create(XMLComment.prototype, this);
	    };

	    XMLComment.prototype.toString = function(options, level) {
	      var indent, newline, offset, pretty, r, ref, ref1, ref2, space;
	      pretty = (options != null ? options.pretty : void 0) || false;
	      indent = (ref = options != null ? options.indent : void 0) != null ? ref : '  ';
	      offset = (ref1 = options != null ? options.offset : void 0) != null ? ref1 : 0;
	      newline = (ref2 = options != null ? options.newline : void 0) != null ? ref2 : '\n';
	      level || (level = 0);
	      space = new Array(level + offset + 1).join(indent);
	      r = '';
	      if (pretty) {
	        r += space;
	      }
	      r += '<!-- ' + this.text + ' -->';
	      if (pretty) {
	        r += newline;
	      }
	      return r;
	    };

	    return XMLComment;

	  })(XMLNode);

	}).call(this);


/***/ },
/* 341 */
/***/ function(module, exports, __webpack_require__) {

	// Generated by CoffeeScript 1.9.1
	(function() {
	  var XMLDTDAttList, create;

	  create = __webpack_require__(332);

	  module.exports = XMLDTDAttList = (function() {
	    function XMLDTDAttList(parent, elementName, attributeName, attributeType, defaultValueType, defaultValue) {
	      this.stringify = parent.stringify;
	      if (elementName == null) {
	        throw new Error("Missing DTD element name");
	      }
	      if (attributeName == null) {
	        throw new Error("Missing DTD attribute name");
	      }
	      if (!attributeType) {
	        throw new Error("Missing DTD attribute type");
	      }
	      if (!defaultValueType) {
	        throw new Error("Missing DTD attribute default");
	      }
	      if (defaultValueType.indexOf('#') !== 0) {
	        defaultValueType = '#' + defaultValueType;
	      }
	      if (!defaultValueType.match(/^(#REQUIRED|#IMPLIED|#FIXED|#DEFAULT)$/)) {
	        throw new Error("Invalid default value type; expected: #REQUIRED, #IMPLIED, #FIXED or #DEFAULT");
	      }
	      if (defaultValue && !defaultValueType.match(/^(#FIXED|#DEFAULT)$/)) {
	        throw new Error("Default value only applies to #FIXED or #DEFAULT");
	      }
	      this.elementName = this.stringify.eleName(elementName);
	      this.attributeName = this.stringify.attName(attributeName);
	      this.attributeType = this.stringify.dtdAttType(attributeType);
	      this.defaultValue = this.stringify.dtdAttDefault(defaultValue);
	      this.defaultValueType = defaultValueType;
	    }

	    XMLDTDAttList.prototype.toString = function(options, level) {
	      var indent, newline, offset, pretty, r, ref, ref1, ref2, space;
	      pretty = (options != null ? options.pretty : void 0) || false;
	      indent = (ref = options != null ? options.indent : void 0) != null ? ref : '  ';
	      offset = (ref1 = options != null ? options.offset : void 0) != null ? ref1 : 0;
	      newline = (ref2 = options != null ? options.newline : void 0) != null ? ref2 : '\n';
	      level || (level = 0);
	      space = new Array(level + offset + 1).join(indent);
	      r = '';
	      if (pretty) {
	        r += space;
	      }
	      r += '<!ATTLIST ' + this.elementName + ' ' + this.attributeName + ' ' + this.attributeType;
	      if (this.defaultValueType !== '#DEFAULT') {
	        r += ' ' + this.defaultValueType;
	      }
	      if (this.defaultValue) {
	        r += ' "' + this.defaultValue + '"';
	      }
	      r += '>';
	      if (pretty) {
	        r += newline;
	      }
	      return r;
	    };

	    return XMLDTDAttList;

	  })();

	}).call(this);


/***/ },
/* 342 */
/***/ function(module, exports, __webpack_require__) {

	// Generated by CoffeeScript 1.9.1
	(function() {
	  var XMLDTDEntity, create, isObject;

	  create = __webpack_require__(332);

	  isObject = __webpack_require__(333);

	  module.exports = XMLDTDEntity = (function() {
	    function XMLDTDEntity(parent, pe, name, value) {
	      this.stringify = parent.stringify;
	      if (name == null) {
	        throw new Error("Missing entity name");
	      }
	      if (value == null) {
	        throw new Error("Missing entity value");
	      }
	      this.pe = !!pe;
	      this.name = this.stringify.eleName(name);
	      if (!isObject(value)) {
	        this.value = this.stringify.dtdEntityValue(value);
	      } else {
	        if (!value.pubID && !value.sysID) {
	          throw new Error("Public and/or system identifiers are required for an external entity");
	        }
	        if (value.pubID && !value.sysID) {
	          throw new Error("System identifier is required for a public external entity");
	        }
	        if (value.pubID != null) {
	          this.pubID = this.stringify.dtdPubID(value.pubID);
	        }
	        if (value.sysID != null) {
	          this.sysID = this.stringify.dtdSysID(value.sysID);
	        }
	        if (value.nData != null) {
	          this.nData = this.stringify.dtdNData(value.nData);
	        }
	        if (this.pe && this.nData) {
	          throw new Error("Notation declaration is not allowed in a parameter entity");
	        }
	      }
	    }

	    XMLDTDEntity.prototype.toString = function(options, level) {
	      var indent, newline, offset, pretty, r, ref, ref1, ref2, space;
	      pretty = (options != null ? options.pretty : void 0) || false;
	      indent = (ref = options != null ? options.indent : void 0) != null ? ref : '  ';
	      offset = (ref1 = options != null ? options.offset : void 0) != null ? ref1 : 0;
	      newline = (ref2 = options != null ? options.newline : void 0) != null ? ref2 : '\n';
	      level || (level = 0);
	      space = new Array(level + offset + 1).join(indent);
	      r = '';
	      if (pretty) {
	        r += space;
	      }
	      r += '<!ENTITY';
	      if (this.pe) {
	        r += ' %';
	      }
	      r += ' ' + this.name;
	      if (this.value) {
	        r += ' "' + this.value + '"';
	      } else {
	        if (this.pubID && this.sysID) {
	          r += ' PUBLIC "' + this.pubID + '" "' + this.sysID + '"';
	        } else if (this.sysID) {
	          r += ' SYSTEM "' + this.sysID + '"';
	        }
	        if (this.nData) {
	          r += ' NDATA ' + this.nData;
	        }
	      }
	      r += '>';
	      if (pretty) {
	        r += newline;
	      }
	      return r;
	    };

	    return XMLDTDEntity;

	  })();

	}).call(this);


/***/ },
/* 343 */
/***/ function(module, exports, __webpack_require__) {

	// Generated by CoffeeScript 1.9.1
	(function() {
	  var XMLDTDElement, create;

	  create = __webpack_require__(332);

	  module.exports = XMLDTDElement = (function() {
	    function XMLDTDElement(parent, name, value) {
	      this.stringify = parent.stringify;
	      if (name == null) {
	        throw new Error("Missing DTD element name");
	      }
	      if (!value) {
	        value = '(#PCDATA)';
	      }
	      if (Array.isArray(value)) {
	        value = '(' + value.join(',') + ')';
	      }
	      this.name = this.stringify.eleName(name);
	      this.value = this.stringify.dtdElementValue(value);
	    }

	    XMLDTDElement.prototype.toString = function(options, level) {
	      var indent, newline, offset, pretty, r, ref, ref1, ref2, space;
	      pretty = (options != null ? options.pretty : void 0) || false;
	      indent = (ref = options != null ? options.indent : void 0) != null ? ref : '  ';
	      offset = (ref1 = options != null ? options.offset : void 0) != null ? ref1 : 0;
	      newline = (ref2 = options != null ? options.newline : void 0) != null ? ref2 : '\n';
	      level || (level = 0);
	      space = new Array(level + offset + 1).join(indent);
	      r = '';
	      if (pretty) {
	        r += space;
	      }
	      r += '<!ELEMENT ' + this.name + ' ' + this.value + '>';
	      if (pretty) {
	        r += newline;
	      }
	      return r;
	    };

	    return XMLDTDElement;

	  })();

	}).call(this);


/***/ },
/* 344 */
/***/ function(module, exports, __webpack_require__) {

	// Generated by CoffeeScript 1.9.1
	(function() {
	  var XMLDTDNotation, create;

	  create = __webpack_require__(332);

	  module.exports = XMLDTDNotation = (function() {
	    function XMLDTDNotation(parent, name, value) {
	      this.stringify = parent.stringify;
	      if (name == null) {
	        throw new Error("Missing notation name");
	      }
	      if (!value.pubID && !value.sysID) {
	        throw new Error("Public or system identifiers are required for an external entity");
	      }
	      this.name = this.stringify.eleName(name);
	      if (value.pubID != null) {
	        this.pubID = this.stringify.dtdPubID(value.pubID);
	      }
	      if (value.sysID != null) {
	        this.sysID = this.stringify.dtdSysID(value.sysID);
	      }
	    }

	    XMLDTDNotation.prototype.toString = function(options, level) {
	      var indent, newline, offset, pretty, r, ref, ref1, ref2, space;
	      pretty = (options != null ? options.pretty : void 0) || false;
	      indent = (ref = options != null ? options.indent : void 0) != null ? ref : '  ';
	      offset = (ref1 = options != null ? options.offset : void 0) != null ? ref1 : 0;
	      newline = (ref2 = options != null ? options.newline : void 0) != null ? ref2 : '\n';
	      level || (level = 0);
	      space = new Array(level + offset + 1).join(indent);
	      r = '';
	      if (pretty) {
	        r += space;
	      }
	      r += '<!NOTATION ' + this.name;
	      if (this.pubID && this.sysID) {
	        r += ' PUBLIC "' + this.pubID + '" "' + this.sysID + '"';
	      } else if (this.pubID) {
	        r += ' PUBLIC "' + this.pubID + '"';
	      } else if (this.sysID) {
	        r += ' SYSTEM "' + this.sysID + '"';
	      }
	      r += '>';
	      if (pretty) {
	        r += newline;
	      }
	      return r;
	    };

	    return XMLDTDNotation;

	  })();

	}).call(this);


/***/ },
/* 345 */
/***/ function(module, exports, __webpack_require__) {

	var eq = __webpack_require__(361);

	/** Used for built-in method references. */
	var objectProto = Object.prototype;

	/** Used to check objects for own properties. */
	var hasOwnProperty = objectProto.hasOwnProperty;

	/**
	 * Assigns `value` to `key` of `object` if the existing value is not equivalent
	 * using [`SameValueZero`](http://ecma-international.org/ecma-262/6.0/#sec-samevaluezero)
	 * for equality comparisons.
	 *
	 * @private
	 * @param {Object} object The object to modify.
	 * @param {string} key The key of the property to assign.
	 * @param {*} value The value to assign.
	 */
	function assignValue(object, key, value) {
	  var objValue = object[key];
	  if (!(hasOwnProperty.call(object, key) && eq(objValue, value)) ||
	      (value === undefined && !(key in object))) {
	    object[key] = value;
	  }
	}

	module.exports = assignValue;


/***/ },
/* 346 */
/***/ function(module, exports, __webpack_require__) {

	var assignValue = __webpack_require__(345);

	/**
	 * Copies properties of `source` to `object`.
	 *
	 * @private
	 * @param {Object} source The object to copy properties from.
	 * @param {Array} props The property identifiers to copy.
	 * @param {Object} [object={}] The object to copy properties to.
	 * @param {Function} [customizer] The function to customize copied values.
	 * @returns {Object} Returns `object`.
	 */
	function copyObject(source, props, object, customizer) {
	  object || (object = {});

	  var index = -1,
	      length = props.length;

	  while (++index < length) {
	    var key = props[index];

	    var newValue = customizer
	      ? customizer(object[key], source[key], key, object, source)
	      : source[key];

	    assignValue(object, key, newValue);
	  }
	  return object;
	}

	module.exports = copyObject;


/***/ },
/* 347 */
/***/ function(module, exports, __webpack_require__) {

	var isIterateeCall = __webpack_require__(360),
	    rest = __webpack_require__(362);

	/**
	 * Creates a function like `_.assign`.
	 *
	 * @private
	 * @param {Function} assigner The function to assign values.
	 * @returns {Function} Returns the new assigner function.
	 */
	function createAssigner(assigner) {
	  return rest(function(object, sources) {
	    var index = -1,
	        length = sources.length,
	        customizer = length > 1 ? sources[length - 1] : undefined,
	        guard = length > 2 ? sources[2] : undefined;

	    customizer = typeof customizer == 'function'
	      ? (length--, customizer)
	      : undefined;

	    if (guard && isIterateeCall(sources[0], sources[1], guard)) {
	      customizer = length < 3 ? undefined : customizer;
	      length = 1;
	    }
	    object = Object(object);
	    while (++index < length) {
	      var source = sources[index];
	      if (source) {
	        assigner(object, source, index, customizer);
	      }
	    }
	    return object;
	  });
	}

	module.exports = createAssigner;


/***/ },
/* 348 */
/***/ function(module, exports, __webpack_require__) {

	var getLength = __webpack_require__(363),
	    isFunction = __webpack_require__(335),
	    isLength = __webpack_require__(364);

	/**
	 * Checks if `value` is array-like. A value is considered array-like if it's
	 * not a function and has a `value.length` that's an integer greater than or
	 * equal to `0` and less than or equal to `Number.MAX_SAFE_INTEGER`.
	 *
	 * @static
	 * @memberOf _
	 * @since 4.0.0
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is array-like, else `false`.
	 * @example
	 *
	 * _.isArrayLike([1, 2, 3]);
	 * // => true
	 *
	 * _.isArrayLike(document.body.children);
	 * // => true
	 *
	 * _.isArrayLike('abc');
	 * // => true
	 *
	 * _.isArrayLike(_.noop);
	 * // => false
	 */
	function isArrayLike(value) {
	  return value != null && isLength(getLength(value)) && !isFunction(value);
	}

	module.exports = isArrayLike;


/***/ },
/* 349 */
/***/ function(module, exports, __webpack_require__) {

	/** Used for built-in method references. */
	var objectProto = Object.prototype;

	/**
	 * Checks if `value` is likely a prototype object.
	 *
	 * @private
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is a prototype, else `false`.
	 */
	function isPrototype(value) {
	  var Ctor = value && value.constructor,
	      proto = (typeof Ctor == 'function' && Ctor.prototype) || objectProto;

	  return value === proto;
	}

	module.exports = isPrototype;


/***/ },
/* 350 */
/***/ function(module, exports, __webpack_require__) {

	var baseHas = __webpack_require__(365),
	    baseKeys = __webpack_require__(366),
	    indexKeys = __webpack_require__(367),
	    isArrayLike = __webpack_require__(348),
	    isIndex = __webpack_require__(368),
	    isPrototype = __webpack_require__(349);

	/**
	 * Creates an array of the own enumerable property names of `object`.
	 *
	 * **Note:** Non-object values are coerced to objects. See the
	 * [ES spec](http://ecma-international.org/ecma-262/6.0/#sec-object.keys)
	 * for more details.
	 *
	 * @static
	 * @since 0.1.0
	 * @memberOf _
	 * @category Object
	 * @param {Object} object The object to query.
	 * @returns {Array} Returns the array of property names.
	 * @example
	 *
	 * function Foo() {
	 *   this.a = 1;
	 *   this.b = 2;
	 * }
	 *
	 * Foo.prototype.c = 3;
	 *
	 * _.keys(new Foo);
	 * // => ['a', 'b'] (iteration order is not guaranteed)
	 *
	 * _.keys('hi');
	 * // => ['0', '1']
	 */
	function keys(object) {
	  var isProto = isPrototype(object);
	  if (!(isProto || isArrayLike(object))) {
	    return baseKeys(object);
	  }
	  var indexes = indexKeys(object),
	      skipIndexes = !!indexes,
	      result = indexes || [],
	      length = result.length;

	  for (var key in object) {
	    if (baseHas(object, key) &&
	        !(skipIndexes && (key == 'length' || isIndex(key, length))) &&
	        !(isProto && key == 'constructor')) {
	      result.push(key);
	    }
	  }
	  return result;
	}

	module.exports = keys;


/***/ },
/* 351 */
/***/ function(module, exports, __webpack_require__) {

	var copyObject = __webpack_require__(346),
	    keys = __webpack_require__(350);

	/**
	 * The base implementation of `_.assign` without support for multiple sources
	 * or `customizer` functions.
	 *
	 * @private
	 * @param {Object} object The destination object.
	 * @param {Object} source The source object.
	 * @returns {Object} Returns `object`.
	 */
	function baseAssign(object, source) {
	  return object && copyObject(source, keys(source), object);
	}

	module.exports = baseAssign;


/***/ },
/* 352 */
/***/ function(module, exports, __webpack_require__) {

	var isObject = __webpack_require__(333);

	/** Built-in value references. */
	var objectCreate = Object.create;

	/**
	 * The base implementation of `_.create` without support for assigning
	 * properties to the created object.
	 *
	 * @private
	 * @param {Object} prototype The object to inherit from.
	 * @returns {Object} Returns the new object.
	 */
	function baseCreate(proto) {
	  return isObject(proto) ? objectCreate(proto) : {};
	}

	module.exports = baseCreate;


/***/ },
/* 353 */
/***/ function(module, exports, __webpack_require__) {

	var getTag = __webpack_require__(369),
	    isArguments = __webpack_require__(370),
	    isArray = __webpack_require__(359),
	    isArrayLike = __webpack_require__(348),
	    isBuffer = __webpack_require__(371),
	    isFunction = __webpack_require__(335),
	    isObjectLike = __webpack_require__(372),
	    isString = __webpack_require__(373),
	    keys = __webpack_require__(350);

	/** `Object#toString` result references. */
	var mapTag = '[object Map]',
	    setTag = '[object Set]';

	/** Used for built-in method references. */
	var objectProto = Object.prototype;

	/** Used to check objects for own properties. */
	var hasOwnProperty = objectProto.hasOwnProperty;

	/** Built-in value references. */
	var propertyIsEnumerable = objectProto.propertyIsEnumerable;

	/** Detect if properties shadowing those on `Object.prototype` are non-enumerable. */
	var nonEnumShadows = !propertyIsEnumerable.call({ 'valueOf': 1 }, 'valueOf');

	/**
	 * Checks if `value` is an empty object, collection, map, or set.
	 *
	 * Objects are considered empty if they have no own enumerable string keyed
	 * properties.
	 *
	 * Array-like values such as `arguments` objects, arrays, buffers, strings, or
	 * jQuery-like collections are considered empty if they have a `length` of `0`.
	 * Similarly, maps and sets are considered empty if they have a `size` of `0`.
	 *
	 * @static
	 * @memberOf _
	 * @since 0.1.0
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is empty, else `false`.
	 * @example
	 *
	 * _.isEmpty(null);
	 * // => true
	 *
	 * _.isEmpty(true);
	 * // => true
	 *
	 * _.isEmpty(1);
	 * // => true
	 *
	 * _.isEmpty([1, 2, 3]);
	 * // => false
	 *
	 * _.isEmpty({ 'a': 1 });
	 * // => false
	 */
	function isEmpty(value) {
	  if (isArrayLike(value) &&
	      (isArray(value) || isString(value) || isFunction(value.splice) ||
	        isArguments(value) || isBuffer(value))) {
	    return !value.length;
	  }
	  if (isObjectLike(value)) {
	    var tag = getTag(value);
	    if (tag == mapTag || tag == setTag) {
	      return !value.size;
	    }
	  }
	  for (var key in value) {
	    if (hasOwnProperty.call(value, key)) {
	      return false;
	    }
	  }
	  return !(nonEnumShadows && keys(value).length);
	}

	module.exports = isEmpty;


/***/ },
/* 354 */
/***/ function(module, exports, __webpack_require__) {

	// Generated by CoffeeScript 1.9.1
	(function() {
	  var XMLNode, XMLRaw, create,
	    extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
	    hasProp = {}.hasOwnProperty;

	  create = __webpack_require__(332);

	  XMLNode = __webpack_require__(334);

	  module.exports = XMLRaw = (function(superClass) {
	    extend(XMLRaw, superClass);

	    function XMLRaw(parent, text) {
	      XMLRaw.__super__.constructor.call(this, parent);
	      if (text == null) {
	        throw new Error("Missing raw text");
	      }
	      this.value = this.stringify.raw(text);
	    }

	    XMLRaw.prototype.clone = function() {
	      return create(XMLRaw.prototype, this);
	    };

	    XMLRaw.prototype.toString = function(options, level) {
	      var indent, newline, offset, pretty, r, ref, ref1, ref2, space;
	      pretty = (options != null ? options.pretty : void 0) || false;
	      indent = (ref = options != null ? options.indent : void 0) != null ? ref : '  ';
	      offset = (ref1 = options != null ? options.offset : void 0) != null ? ref1 : 0;
	      newline = (ref2 = options != null ? options.newline : void 0) != null ? ref2 : '\n';
	      level || (level = 0);
	      space = new Array(level + offset + 1).join(indent);
	      r = '';
	      if (pretty) {
	        r += space;
	      }
	      r += this.value;
	      if (pretty) {
	        r += newline;
	      }
	      return r;
	    };

	    return XMLRaw;

	  })(XMLNode);

	}).call(this);


/***/ },
/* 355 */
/***/ function(module, exports, __webpack_require__) {

	// Generated by CoffeeScript 1.9.1
	(function() {
	  var XMLNode, XMLText, create,
	    extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
	    hasProp = {}.hasOwnProperty;

	  create = __webpack_require__(332);

	  XMLNode = __webpack_require__(334);

	  module.exports = XMLText = (function(superClass) {
	    extend(XMLText, superClass);

	    function XMLText(parent, text) {
	      XMLText.__super__.constructor.call(this, parent);
	      if (text == null) {
	        throw new Error("Missing element text");
	      }
	      this.value = this.stringify.eleText(text);
	    }

	    XMLText.prototype.clone = function() {
	      return create(XMLText.prototype, this);
	    };

	    XMLText.prototype.toString = function(options, level) {
	      var indent, newline, offset, pretty, r, ref, ref1, ref2, space;
	      pretty = (options != null ? options.pretty : void 0) || false;
	      indent = (ref = options != null ? options.indent : void 0) != null ? ref : '  ';
	      offset = (ref1 = options != null ? options.offset : void 0) != null ? ref1 : 0;
	      newline = (ref2 = options != null ? options.newline : void 0) != null ? ref2 : '\n';
	      level || (level = 0);
	      space = new Array(level + offset + 1).join(indent);
	      r = '';
	      if (pretty) {
	        r += space;
	      }
	      r += this.value;
	      if (pretty) {
	        r += newline;
	      }
	      return r;
	    };

	    return XMLText;

	  })(XMLNode);

	}).call(this);


/***/ },
/* 356 */
/***/ function(module, exports, __webpack_require__) {

	/**
	 * A specialized version of `_.every` for arrays without support for
	 * iteratee shorthands.
	 *
	 * @private
	 * @param {Array} array The array to iterate over.
	 * @param {Function} predicate The function invoked per iteration.
	 * @returns {boolean} Returns `true` if all elements pass the predicate check,
	 *  else `false`.
	 */
	function arrayEvery(array, predicate) {
	  var index = -1,
	      length = array.length;

	  while (++index < length) {
	    if (!predicate(array[index], index, array)) {
	      return false;
	    }
	  }
	  return true;
	}

	module.exports = arrayEvery;


/***/ },
/* 357 */
/***/ function(module, exports, __webpack_require__) {

	var baseEach = __webpack_require__(374);

	/**
	 * The base implementation of `_.every` without support for iteratee shorthands.
	 *
	 * @private
	 * @param {Array|Object} collection The collection to iterate over.
	 * @param {Function} predicate The function invoked per iteration.
	 * @returns {boolean} Returns `true` if all elements pass the predicate check,
	 *  else `false`
	 */
	function baseEvery(collection, predicate) {
	  var result = true;
	  baseEach(collection, function(value, index, collection) {
	    result = !!predicate(value, index, collection);
	    return result;
	  });
	  return result;
	}

	module.exports = baseEvery;


/***/ },
/* 358 */
/***/ function(module, exports, __webpack_require__) {

	var baseMatches = __webpack_require__(375),
	    baseMatchesProperty = __webpack_require__(376),
	    identity = __webpack_require__(377),
	    isArray = __webpack_require__(359),
	    property = __webpack_require__(378);

	/**
	 * The base implementation of `_.iteratee`.
	 *
	 * @private
	 * @param {*} [value=_.identity] The value to convert to an iteratee.
	 * @returns {Function} Returns the iteratee.
	 */
	function baseIteratee(value) {
	  // Don't store the `typeof` result in a variable to avoid a JIT bug in Safari 9.
	  // See https://bugs.webkit.org/show_bug.cgi?id=156034 for more details.
	  if (typeof value == 'function') {
	    return value;
	  }
	  if (value == null) {
	    return identity;
	  }
	  if (typeof value == 'object') {
	    return isArray(value)
	      ? baseMatchesProperty(value[0], value[1])
	      : baseMatches(value);
	  }
	  return property(value);
	}

	module.exports = baseIteratee;


/***/ },
/* 359 */
/***/ function(module, exports, __webpack_require__) {

	/**
	 * Checks if `value` is classified as an `Array` object.
	 *
	 * @static
	 * @memberOf _
	 * @since 0.1.0
	 * @type {Function}
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is correctly classified,
	 *  else `false`.
	 * @example
	 *
	 * _.isArray([1, 2, 3]);
	 * // => true
	 *
	 * _.isArray(document.body.children);
	 * // => false
	 *
	 * _.isArray('abc');
	 * // => false
	 *
	 * _.isArray(_.noop);
	 * // => false
	 */
	var isArray = Array.isArray;

	module.exports = isArray;


/***/ },
/* 360 */
/***/ function(module, exports, __webpack_require__) {

	var eq = __webpack_require__(361),
	    isArrayLike = __webpack_require__(348),
	    isIndex = __webpack_require__(368),
	    isObject = __webpack_require__(333);

	/**
	 * Checks if the given arguments are from an iteratee call.
	 *
	 * @private
	 * @param {*} value The potential iteratee value argument.
	 * @param {*} index The potential iteratee index or key argument.
	 * @param {*} object The potential iteratee object argument.
	 * @returns {boolean} Returns `true` if the arguments are from an iteratee call,
	 *  else `false`.
	 */
	function isIterateeCall(value, index, object) {
	  if (!isObject(object)) {
	    return false;
	  }
	  var type = typeof index;
	  if (type == 'number'
	        ? (isArrayLike(object) && isIndex(index, object.length))
	        : (type == 'string' && index in object)
	      ) {
	    return eq(object[index], value);
	  }
	  return false;
	}

	module.exports = isIterateeCall;


/***/ },
/* 361 */
/***/ function(module, exports, __webpack_require__) {

	/**
	 * Performs a
	 * [`SameValueZero`](http://ecma-international.org/ecma-262/6.0/#sec-samevaluezero)
	 * comparison between two values to determine if they are equivalent.
	 *
	 * @static
	 * @memberOf _
	 * @since 4.0.0
	 * @category Lang
	 * @param {*} value The value to compare.
	 * @param {*} other The other value to compare.
	 * @returns {boolean} Returns `true` if the values are equivalent, else `false`.
	 * @example
	 *
	 * var object = { 'user': 'fred' };
	 * var other = { 'user': 'fred' };
	 *
	 * _.eq(object, object);
	 * // => true
	 *
	 * _.eq(object, other);
	 * // => false
	 *
	 * _.eq('a', 'a');
	 * // => true
	 *
	 * _.eq('a', Object('a'));
	 * // => false
	 *
	 * _.eq(NaN, NaN);
	 * // => true
	 */
	function eq(value, other) {
	  return value === other || (value !== value && other !== other);
	}

	module.exports = eq;


/***/ },
/* 362 */
/***/ function(module, exports, __webpack_require__) {

	var apply = __webpack_require__(379),
	    toInteger = __webpack_require__(380);

	/** Used as the `TypeError` message for "Functions" methods. */
	var FUNC_ERROR_TEXT = 'Expected a function';

	/* Built-in method references for those with the same name as other `lodash` methods. */
	var nativeMax = Math.max;

	/**
	 * Creates a function that invokes `func` with the `this` binding of the
	 * created function and arguments from `start` and beyond provided as
	 * an array.
	 *
	 * **Note:** This method is based on the
	 * [rest parameter](https://mdn.io/rest_parameters).
	 *
	 * @static
	 * @memberOf _
	 * @since 4.0.0
	 * @category Function
	 * @param {Function} func The function to apply a rest parameter to.
	 * @param {number} [start=func.length-1] The start position of the rest parameter.
	 * @returns {Function} Returns the new function.
	 * @example
	 *
	 * var say = _.rest(function(what, names) {
	 *   return what + ' ' + _.initial(names).join(', ') +
	 *     (_.size(names) > 1 ? ', & ' : '') + _.last(names);
	 * });
	 *
	 * say('hello', 'fred', 'barney', 'pebbles');
	 * // => 'hello fred, barney, & pebbles'
	 */
	function rest(func, start) {
	  if (typeof func != 'function') {
	    throw new TypeError(FUNC_ERROR_TEXT);
	  }
	  start = nativeMax(start === undefined ? (func.length - 1) : toInteger(start), 0);
	  return function() {
	    var args = arguments,
	        index = -1,
	        length = nativeMax(args.length - start, 0),
	        array = Array(length);

	    while (++index < length) {
	      array[index] = args[start + index];
	    }
	    switch (start) {
	      case 0: return func.call(this, array);
	      case 1: return func.call(this, args[0], array);
	      case 2: return func.call(this, args[0], args[1], array);
	    }
	    var otherArgs = Array(start + 1);
	    index = -1;
	    while (++index < start) {
	      otherArgs[index] = args[index];
	    }
	    otherArgs[start] = array;
	    return apply(func, this, otherArgs);
	  };
	}

	module.exports = rest;


/***/ },
/* 363 */
/***/ function(module, exports, __webpack_require__) {

	var baseProperty = __webpack_require__(381);

	/**
	 * Gets the "length" property value of `object`.
	 *
	 * **Note:** This function is used to avoid a
	 * [JIT bug](https://bugs.webkit.org/show_bug.cgi?id=142792) that affects
	 * Safari on at least iOS 8.1-8.3 ARM64.
	 *
	 * @private
	 * @param {Object} object The object to query.
	 * @returns {*} Returns the "length" value.
	 */
	var getLength = baseProperty('length');

	module.exports = getLength;


/***/ },
/* 364 */
/***/ function(module, exports, __webpack_require__) {

	/** Used as references for various `Number` constants. */
	var MAX_SAFE_INTEGER = 9007199254740991;

	/**
	 * Checks if `value` is a valid array-like length.
	 *
	 * **Note:** This function is loosely based on
	 * [`ToLength`](http://ecma-international.org/ecma-262/6.0/#sec-tolength).
	 *
	 * @static
	 * @memberOf _
	 * @since 4.0.0
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is a valid length,
	 *  else `false`.
	 * @example
	 *
	 * _.isLength(3);
	 * // => true
	 *
	 * _.isLength(Number.MIN_VALUE);
	 * // => false
	 *
	 * _.isLength(Infinity);
	 * // => false
	 *
	 * _.isLength('3');
	 * // => false
	 */
	function isLength(value) {
	  return typeof value == 'number' &&
	    value > -1 && value % 1 == 0 && value <= MAX_SAFE_INTEGER;
	}

	module.exports = isLength;


/***/ },
/* 365 */
/***/ function(module, exports, __webpack_require__) {

	var getPrototype = __webpack_require__(382);

	/** Used for built-in method references. */
	var objectProto = Object.prototype;

	/** Used to check objects for own properties. */
	var hasOwnProperty = objectProto.hasOwnProperty;

	/**
	 * The base implementation of `_.has` without support for deep paths.
	 *
	 * @private
	 * @param {Object} object The object to query.
	 * @param {Array|string} key The key to check.
	 * @returns {boolean} Returns `true` if `key` exists, else `false`.
	 */
	function baseHas(object, key) {
	  // Avoid a bug in IE 10-11 where objects with a [[Prototype]] of `null`,
	  // that are composed entirely of index properties, return `false` for
	  // `hasOwnProperty` checks of them.
	  return hasOwnProperty.call(object, key) ||
	    (typeof object == 'object' && key in object && getPrototype(object) === null);
	}

	module.exports = baseHas;


/***/ },
/* 366 */
/***/ function(module, exports, __webpack_require__) {

	/* Built-in method references for those with the same name as other `lodash` methods. */
	var nativeKeys = Object.keys;

	/**
	 * The base implementation of `_.keys` which doesn't skip the constructor
	 * property of prototypes or treat sparse arrays as dense.
	 *
	 * @private
	 * @param {Object} object The object to query.
	 * @returns {Array} Returns the array of property names.
	 */
	function baseKeys(object) {
	  return nativeKeys(Object(object));
	}

	module.exports = baseKeys;


/***/ },
/* 367 */
/***/ function(module, exports, __webpack_require__) {

	var baseTimes = __webpack_require__(383),
	    isArguments = __webpack_require__(370),
	    isArray = __webpack_require__(359),
	    isLength = __webpack_require__(364),
	    isString = __webpack_require__(373);

	/**
	 * Creates an array of index keys for `object` values of arrays,
	 * `arguments` objects, and strings, otherwise `null` is returned.
	 *
	 * @private
	 * @param {Object} object The object to query.
	 * @returns {Array|null} Returns index keys, else `null`.
	 */
	function indexKeys(object) {
	  var length = object ? object.length : undefined;
	  if (isLength(length) &&
	      (isArray(object) || isString(object) || isArguments(object))) {
	    return baseTimes(length, String);
	  }
	  return null;
	}

	module.exports = indexKeys;


/***/ },
/* 368 */
/***/ function(module, exports, __webpack_require__) {

	/** Used as references for various `Number` constants. */
	var MAX_SAFE_INTEGER = 9007199254740991;

	/** Used to detect unsigned integer values. */
	var reIsUint = /^(?:0|[1-9]\d*)$/;

	/**
	 * Checks if `value` is a valid array-like index.
	 *
	 * @private
	 * @param {*} value The value to check.
	 * @param {number} [length=MAX_SAFE_INTEGER] The upper bounds of a valid index.
	 * @returns {boolean} Returns `true` if `value` is a valid index, else `false`.
	 */
	function isIndex(value, length) {
	  value = (typeof value == 'number' || reIsUint.test(value)) ? +value : -1;
	  length = length == null ? MAX_SAFE_INTEGER : length;
	  return value > -1 && value % 1 == 0 && value < length;
	}

	module.exports = isIndex;


/***/ },
/* 369 */
/***/ function(module, exports, __webpack_require__) {

	var DataView = __webpack_require__(387),
	    Map = __webpack_require__(388),
	    Promise = __webpack_require__(389),
	    Set = __webpack_require__(390),
	    WeakMap = __webpack_require__(391),
	    toSource = __webpack_require__(392);

	/** `Object#toString` result references. */
	var mapTag = '[object Map]',
	    objectTag = '[object Object]',
	    promiseTag = '[object Promise]',
	    setTag = '[object Set]',
	    weakMapTag = '[object WeakMap]';

	var dataViewTag = '[object DataView]';

	/** Used for built-in method references. */
	var objectProto = Object.prototype;

	/**
	 * Used to resolve the
	 * [`toStringTag`](http://ecma-international.org/ecma-262/6.0/#sec-object.prototype.tostring)
	 * of values.
	 */
	var objectToString = objectProto.toString;

	/** Used to detect maps, sets, and weakmaps. */
	var dataViewCtorString = toSource(DataView),
	    mapCtorString = toSource(Map),
	    promiseCtorString = toSource(Promise),
	    setCtorString = toSource(Set),
	    weakMapCtorString = toSource(WeakMap);

	/**
	 * Gets the `toStringTag` of `value`.
	 *
	 * @private
	 * @param {*} value The value to query.
	 * @returns {string} Returns the `toStringTag`.
	 */
	function getTag(value) {
	  return objectToString.call(value);
	}

	// Fallback for data views, maps, sets, and weak maps in IE 11,
	// for data views in Edge, and promises in Node.js.
	if ((DataView && getTag(new DataView(new ArrayBuffer(1))) != dataViewTag) ||
	    (Map && getTag(new Map) != mapTag) ||
	    (Promise && getTag(Promise.resolve()) != promiseTag) ||
	    (Set && getTag(new Set) != setTag) ||
	    (WeakMap && getTag(new WeakMap) != weakMapTag)) {
	  getTag = function(value) {
	    var result = objectToString.call(value),
	        Ctor = result == objectTag ? value.constructor : undefined,
	        ctorString = Ctor ? toSource(Ctor) : undefined;

	    if (ctorString) {
	      switch (ctorString) {
	        case dataViewCtorString: return dataViewTag;
	        case mapCtorString: return mapTag;
	        case promiseCtorString: return promiseTag;
	        case setCtorString: return setTag;
	        case weakMapCtorString: return weakMapTag;
	      }
	    }
	    return result;
	  };
	}

	module.exports = getTag;


/***/ },
/* 370 */
/***/ function(module, exports, __webpack_require__) {

	var isArrayLikeObject = __webpack_require__(384);

	/** `Object#toString` result references. */
	var argsTag = '[object Arguments]';

	/** Used for built-in method references. */
	var objectProto = Object.prototype;

	/** Used to check objects for own properties. */
	var hasOwnProperty = objectProto.hasOwnProperty;

	/**
	 * Used to resolve the
	 * [`toStringTag`](http://ecma-international.org/ecma-262/6.0/#sec-object.prototype.tostring)
	 * of values.
	 */
	var objectToString = objectProto.toString;

	/** Built-in value references. */
	var propertyIsEnumerable = objectProto.propertyIsEnumerable;

	/**
	 * Checks if `value` is likely an `arguments` object.
	 *
	 * @static
	 * @memberOf _
	 * @since 0.1.0
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is correctly classified,
	 *  else `false`.
	 * @example
	 *
	 * _.isArguments(function() { return arguments; }());
	 * // => true
	 *
	 * _.isArguments([1, 2, 3]);
	 * // => false
	 */
	function isArguments(value) {
	  // Safari 8.1 incorrectly makes `arguments.callee` enumerable in strict mode.
	  return isArrayLikeObject(value) && hasOwnProperty.call(value, 'callee') &&
	    (!propertyIsEnumerable.call(value, 'callee') || objectToString.call(value) == argsTag);
	}

	module.exports = isArguments;


/***/ },
/* 371 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(module) {var constant = __webpack_require__(385),
	    root = __webpack_require__(386);

	/** Used to determine if values are of the language type `Object`. */
	var objectTypes = {
	  'function': true,
	  'object': true
	};

	/** Detect free variable `exports`. */
	var freeExports = (objectTypes[typeof exports] && exports && !exports.nodeType)
	  ? exports
	  : undefined;

	/** Detect free variable `module`. */
	var freeModule = (objectTypes[typeof module] && module && !module.nodeType)
	  ? module
	  : undefined;

	/** Detect the popular CommonJS extension `module.exports`. */
	var moduleExports = (freeModule && freeModule.exports === freeExports)
	  ? freeExports
	  : undefined;

	/** Built-in value references. */
	var Buffer = moduleExports ? root.Buffer : undefined;

	/**
	 * Checks if `value` is a buffer.
	 *
	 * @static
	 * @memberOf _
	 * @since 4.3.0
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is a buffer, else `false`.
	 * @example
	 *
	 * _.isBuffer(new Buffer(2));
	 * // => true
	 *
	 * _.isBuffer(new Uint8Array(2));
	 * // => false
	 */
	var isBuffer = !Buffer ? constant(false) : function(value) {
	  return value instanceof Buffer;
	};

	module.exports = isBuffer;
	
	/* WEBPACK VAR INJECTION */}.call(exports, __webpack_require__(169)(module)))

/***/ },
/* 372 */
/***/ function(module, exports, __webpack_require__) {

	/**
	 * Checks if `value` is object-like. A value is object-like if it's not `null`
	 * and has a `typeof` result of "object".
	 *
	 * @static
	 * @memberOf _
	 * @since 4.0.0
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is object-like, else `false`.
	 * @example
	 *
	 * _.isObjectLike({});
	 * // => true
	 *
	 * _.isObjectLike([1, 2, 3]);
	 * // => true
	 *
	 * _.isObjectLike(_.noop);
	 * // => false
	 *
	 * _.isObjectLike(null);
	 * // => false
	 */
	function isObjectLike(value) {
	  return !!value && typeof value == 'object';
	}

	module.exports = isObjectLike;


/***/ },
/* 373 */
/***/ function(module, exports, __webpack_require__) {

	var isArray = __webpack_require__(359),
	    isObjectLike = __webpack_require__(372);

	/** `Object#toString` result references. */
	var stringTag = '[object String]';

	/** Used for built-in method references. */
	var objectProto = Object.prototype;

	/**
	 * Used to resolve the
	 * [`toStringTag`](http://ecma-international.org/ecma-262/6.0/#sec-object.prototype.tostring)
	 * of values.
	 */
	var objectToString = objectProto.toString;

	/**
	 * Checks if `value` is classified as a `String` primitive or object.
	 *
	 * @static
	 * @since 0.1.0
	 * @memberOf _
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is correctly classified,
	 *  else `false`.
	 * @example
	 *
	 * _.isString('abc');
	 * // => true
	 *
	 * _.isString(1);
	 * // => false
	 */
	function isString(value) {
	  return typeof value == 'string' ||
	    (!isArray(value) && isObjectLike(value) && objectToString.call(value) == stringTag);
	}

	module.exports = isString;


/***/ },
/* 374 */
/***/ function(module, exports, __webpack_require__) {

	var baseForOwn = __webpack_require__(393),
	    createBaseEach = __webpack_require__(394);

	/**
	 * The base implementation of `_.forEach` without support for iteratee shorthands.
	 *
	 * @private
	 * @param {Array|Object} collection The collection to iterate over.
	 * @param {Function} iteratee The function invoked per iteration.
	 * @returns {Array|Object} Returns `collection`.
	 */
	var baseEach = createBaseEach(baseForOwn);

	module.exports = baseEach;


/***/ },
/* 375 */
/***/ function(module, exports, __webpack_require__) {

	var baseIsMatch = __webpack_require__(395),
	    getMatchData = __webpack_require__(396),
	    matchesStrictComparable = __webpack_require__(397);

	/**
	 * The base implementation of `_.matches` which doesn't clone `source`.
	 *
	 * @private
	 * @param {Object} source The object of property values to match.
	 * @returns {Function} Returns the new function.
	 */
	function baseMatches(source) {
	  var matchData = getMatchData(source);
	  if (matchData.length == 1 && matchData[0][2]) {
	    return matchesStrictComparable(matchData[0][0], matchData[0][1]);
	  }
	  return function(object) {
	    return object === source || baseIsMatch(object, source, matchData);
	  };
	}

	module.exports = baseMatches;


/***/ },
/* 376 */
/***/ function(module, exports, __webpack_require__) {

	var baseIsEqual = __webpack_require__(398),
	    get = __webpack_require__(399),
	    hasIn = __webpack_require__(400),
	    isKey = __webpack_require__(401),
	    isStrictComparable = __webpack_require__(402),
	    matchesStrictComparable = __webpack_require__(397);

	/** Used to compose bitmasks for comparison styles. */
	var UNORDERED_COMPARE_FLAG = 1,
	    PARTIAL_COMPARE_FLAG = 2;

	/**
	 * The base implementation of `_.matchesProperty` which doesn't clone `srcValue`.
	 *
	 * @private
	 * @param {string} path The path of the property to get.
	 * @param {*} srcValue The value to match.
	 * @returns {Function} Returns the new function.
	 */
	function baseMatchesProperty(path, srcValue) {
	  if (isKey(path) && isStrictComparable(srcValue)) {
	    return matchesStrictComparable(path, srcValue);
	  }
	  return function(object) {
	    var objValue = get(object, path);
	    return (objValue === undefined && objValue === srcValue)
	      ? hasIn(object, path)
	      : baseIsEqual(srcValue, objValue, undefined, UNORDERED_COMPARE_FLAG | PARTIAL_COMPARE_FLAG);
	  };
	}

	module.exports = baseMatchesProperty;


/***/ },
/* 377 */
/***/ function(module, exports, __webpack_require__) {

	/**
	 * This method returns the first argument given to it.
	 *
	 * @static
	 * @since 0.1.0
	 * @memberOf _
	 * @category Util
	 * @param {*} value Any value.
	 * @returns {*} Returns `value`.
	 * @example
	 *
	 * var object = { 'user': 'fred' };
	 *
	 * _.identity(object) === object;
	 * // => true
	 */
	function identity(value) {
	  return value;
	}

	module.exports = identity;


/***/ },
/* 378 */
/***/ function(module, exports, __webpack_require__) {

	var baseProperty = __webpack_require__(381),
	    basePropertyDeep = __webpack_require__(403),
	    isKey = __webpack_require__(401);

	/**
	 * Creates a function that returns the value at `path` of a given object.
	 *
	 * @static
	 * @memberOf _
	 * @since 2.4.0
	 * @category Util
	 * @param {Array|string} path The path of the property to get.
	 * @returns {Function} Returns the new function.
	 * @example
	 *
	 * var objects = [
	 *   { 'a': { 'b': 2 } },
	 *   { 'a': { 'b': 1 } }
	 * ];
	 *
	 * _.map(objects, _.property('a.b'));
	 * // => [2, 1]
	 *
	 * _.map(_.sortBy(objects, _.property(['a', 'b'])), 'a.b');
	 * // => [1, 2]
	 */
	function property(path) {
	  return isKey(path) ? baseProperty(path) : basePropertyDeep(path);
	}

	module.exports = property;


/***/ },
/* 379 */
/***/ function(module, exports, __webpack_require__) {

	/**
	 * A faster alternative to `Function#apply`, this function invokes `func`
	 * with the `this` binding of `thisArg` and the arguments of `args`.
	 *
	 * @private
	 * @param {Function} func The function to invoke.
	 * @param {*} thisArg The `this` binding of `func`.
	 * @param {Array} args The arguments to invoke `func` with.
	 * @returns {*} Returns the result of `func`.
	 */
	function apply(func, thisArg, args) {
	  var length = args.length;
	  switch (length) {
	    case 0: return func.call(thisArg);
	    case 1: return func.call(thisArg, args[0]);
	    case 2: return func.call(thisArg, args[0], args[1]);
	    case 3: return func.call(thisArg, args[0], args[1], args[2]);
	  }
	  return func.apply(thisArg, args);
	}

	module.exports = apply;


/***/ },
/* 380 */
/***/ function(module, exports, __webpack_require__) {

	var toNumber = __webpack_require__(404);

	/** Used as references for various `Number` constants. */
	var INFINITY = 1 / 0,
	    MAX_INTEGER = 1.7976931348623157e+308;

	/**
	 * Converts `value` to an integer.
	 *
	 * **Note:** This function is loosely based on
	 * [`ToInteger`](http://www.ecma-international.org/ecma-262/6.0/#sec-tointeger).
	 *
	 * @static
	 * @memberOf _
	 * @since 4.0.0
	 * @category Lang
	 * @param {*} value The value to convert.
	 * @returns {number} Returns the converted integer.
	 * @example
	 *
	 * _.toInteger(3);
	 * // => 3
	 *
	 * _.toInteger(Number.MIN_VALUE);
	 * // => 0
	 *
	 * _.toInteger(Infinity);
	 * // => 1.7976931348623157e+308
	 *
	 * _.toInteger('3');
	 * // => 3
	 */
	function toInteger(value) {
	  if (!value) {
	    return value === 0 ? value : 0;
	  }
	  value = toNumber(value);
	  if (value === INFINITY || value === -INFINITY) {
	    var sign = (value < 0 ? -1 : 1);
	    return sign * MAX_INTEGER;
	  }
	  var remainder = value % 1;
	  return value === value ? (remainder ? value - remainder : value) : 0;
	}

	module.exports = toInteger;


/***/ },
/* 381 */
/***/ function(module, exports, __webpack_require__) {

	/**
	 * The base implementation of `_.property` without support for deep paths.
	 *
	 * @private
	 * @param {string} key The key of the property to get.
	 * @returns {Function} Returns the new function.
	 */
	function baseProperty(key) {
	  return function(object) {
	    return object == null ? undefined : object[key];
	  };
	}

	module.exports = baseProperty;


/***/ },
/* 382 */
/***/ function(module, exports, __webpack_require__) {

	/* Built-in method references for those with the same name as other `lodash` methods. */
	var nativeGetPrototype = Object.getPrototypeOf;

	/**
	 * Gets the `[[Prototype]]` of `value`.
	 *
	 * @private
	 * @param {*} value The value to query.
	 * @returns {null|Object} Returns the `[[Prototype]]`.
	 */
	function getPrototype(value) {
	  return nativeGetPrototype(Object(value));
	}

	module.exports = getPrototype;


/***/ },
/* 383 */
/***/ function(module, exports, __webpack_require__) {

	/**
	 * The base implementation of `_.times` without support for iteratee shorthands
	 * or max array length checks.
	 *
	 * @private
	 * @param {number} n The number of times to invoke `iteratee`.
	 * @param {Function} iteratee The function invoked per iteration.
	 * @returns {Array} Returns the array of results.
	 */
	function baseTimes(n, iteratee) {
	  var index = -1,
	      result = Array(n);

	  while (++index < n) {
	    result[index] = iteratee(index);
	  }
	  return result;
	}

	module.exports = baseTimes;


/***/ },
/* 384 */
/***/ function(module, exports, __webpack_require__) {

	var isArrayLike = __webpack_require__(348),
	    isObjectLike = __webpack_require__(372);

	/**
	 * This method is like `_.isArrayLike` except that it also checks if `value`
	 * is an object.
	 *
	 * @static
	 * @memberOf _
	 * @since 4.0.0
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is an array-like object,
	 *  else `false`.
	 * @example
	 *
	 * _.isArrayLikeObject([1, 2, 3]);
	 * // => true
	 *
	 * _.isArrayLikeObject(document.body.children);
	 * // => true
	 *
	 * _.isArrayLikeObject('abc');
	 * // => false
	 *
	 * _.isArrayLikeObject(_.noop);
	 * // => false
	 */
	function isArrayLikeObject(value) {
	  return isObjectLike(value) && isArrayLike(value);
	}

	module.exports = isArrayLikeObject;


/***/ },
/* 385 */
/***/ function(module, exports, __webpack_require__) {

	/**
	 * Creates a function that returns `value`.
	 *
	 * @static
	 * @memberOf _
	 * @since 2.4.0
	 * @category Util
	 * @param {*} value The value to return from the new function.
	 * @returns {Function} Returns the new function.
	 * @example
	 *
	 * var object = { 'user': 'fred' };
	 * var getter = _.constant(object);
	 *
	 * getter() === object;
	 * // => true
	 */
	function constant(value) {
	  return function() {
	    return value;
	  };
	}

	module.exports = constant;


/***/ },
/* 386 */
/***/ function(module, exports, __webpack_require__) {

	/* WEBPACK VAR INJECTION */(function(module, global) {var checkGlobal = __webpack_require__(406);

	/** Used to determine if values are of the language type `Object`. */
	var objectTypes = {
	  'function': true,
	  'object': true
	};

	/** Detect free variable `exports`. */
	var freeExports = (objectTypes[typeof exports] && exports && !exports.nodeType)
	  ? exports
	  : undefined;

	/** Detect free variable `module`. */
	var freeModule = (objectTypes[typeof module] && module && !module.nodeType)
	  ? module
	  : undefined;

	/** Detect free variable `global` from Node.js. */
	var freeGlobal = checkGlobal(freeExports && freeModule && typeof global == 'object' && global);

	/** Detect free variable `self`. */
	var freeSelf = checkGlobal(objectTypes[typeof self] && self);

	/** Detect free variable `window`. */
	var freeWindow = checkGlobal(objectTypes[typeof window] && window);

	/** Detect `this` as the global object. */
	var thisGlobal = checkGlobal(objectTypes[typeof this] && this);

	/**
	 * Used as a reference to the global object.
	 *
	 * The `this` value is used if it's the global object to avoid Greasemonkey's
	 * restricted `window` object, otherwise the `window` object is used.
	 */
	var root = freeGlobal ||
	  ((freeWindow !== (thisGlobal && thisGlobal.window)) && freeWindow) ||
	    freeSelf || thisGlobal || Function('return this')();

	module.exports = root;
	
	/* WEBPACK VAR INJECTION */}.call(exports, __webpack_require__(169)(module), (function() { return this; }())))

/***/ },
/* 387 */
/***/ function(module, exports, __webpack_require__) {

	var getNative = __webpack_require__(405),
	    root = __webpack_require__(386);

	/* Built-in method references that are verified to be native. */
	var DataView = getNative(root, 'DataView');

	module.exports = DataView;


/***/ },
/* 388 */
/***/ function(module, exports, __webpack_require__) {

	var getNative = __webpack_require__(405),
	    root = __webpack_require__(386);

	/* Built-in method references that are verified to be native. */
	var Map = getNative(root, 'Map');

	module.exports = Map;


/***/ },
/* 389 */
/***/ function(module, exports, __webpack_require__) {

	var getNative = __webpack_require__(405),
	    root = __webpack_require__(386);

	/* Built-in method references that are verified to be native. */
	var Promise = getNative(root, 'Promise');

	module.exports = Promise;


/***/ },
/* 390 */
/***/ function(module, exports, __webpack_require__) {

	var getNative = __webpack_require__(405),
	    root = __webpack_require__(386);

	/* Built-in method references that are verified to be native. */
	var Set = getNative(root, 'Set');

	module.exports = Set;


/***/ },
/* 391 */
/***/ function(module, exports, __webpack_require__) {

	var getNative = __webpack_require__(405),
	    root = __webpack_require__(386);

	/* Built-in method references that are verified to be native. */
	var WeakMap = getNative(root, 'WeakMap');

	module.exports = WeakMap;


/***/ },
/* 392 */
/***/ function(module, exports, __webpack_require__) {

	/** Used to resolve the decompiled source of functions. */
	var funcToString = Function.prototype.toString;

	/**
	 * Converts `func` to its source code.
	 *
	 * @private
	 * @param {Function} func The function to process.
	 * @returns {string} Returns the source code.
	 */
	function toSource(func) {
	  if (func != null) {
	    try {
	      return funcToString.call(func);
	    } catch (e) {}
	    try {
	      return (func + '');
	    } catch (e) {}
	  }
	  return '';
	}

	module.exports = toSource;


/***/ },
/* 393 */
/***/ function(module, exports, __webpack_require__) {

	var baseFor = __webpack_require__(407),
	    keys = __webpack_require__(350);

	/**
	 * The base implementation of `_.forOwn` without support for iteratee shorthands.
	 *
	 * @private
	 * @param {Object} object The object to iterate over.
	 * @param {Function} iteratee The function invoked per iteration.
	 * @returns {Object} Returns `object`.
	 */
	function baseForOwn(object, iteratee) {
	  return object && baseFor(object, iteratee, keys);
	}

	module.exports = baseForOwn;


/***/ },
/* 394 */
/***/ function(module, exports, __webpack_require__) {

	var isArrayLike = __webpack_require__(348);

	/**
	 * Creates a `baseEach` or `baseEachRight` function.
	 *
	 * @private
	 * @param {Function} eachFunc The function to iterate over a collection.
	 * @param {boolean} [fromRight] Specify iterating from right to left.
	 * @returns {Function} Returns the new base function.
	 */
	function createBaseEach(eachFunc, fromRight) {
	  return function(collection, iteratee) {
	    if (collection == null) {
	      return collection;
	    }
	    if (!isArrayLike(collection)) {
	      return eachFunc(collection, iteratee);
	    }
	    var length = collection.length,
	        index = fromRight ? length : -1,
	        iterable = Object(collection);

	    while ((fromRight ? index-- : ++index < length)) {
	      if (iteratee(iterable[index], index, iterable) === false) {
	        break;
	      }
	    }
	    return collection;
	  };
	}

	module.exports = createBaseEach;


/***/ },
/* 395 */
/***/ function(module, exports, __webpack_require__) {

	var Stack = __webpack_require__(408),
	    baseIsEqual = __webpack_require__(398);

	/** Used to compose bitmasks for comparison styles. */
	var UNORDERED_COMPARE_FLAG = 1,
	    PARTIAL_COMPARE_FLAG = 2;

	/**
	 * The base implementation of `_.isMatch` without support for iteratee shorthands.
	 *
	 * @private
	 * @param {Object} object The object to inspect.
	 * @param {Object} source The object of property values to match.
	 * @param {Array} matchData The property names, values, and compare flags to match.
	 * @param {Function} [customizer] The function to customize comparisons.
	 * @returns {boolean} Returns `true` if `object` is a match, else `false`.
	 */
	function baseIsMatch(object, source, matchData, customizer) {
	  var index = matchData.length,
	      length = index,
	      noCustomizer = !customizer;

	  if (object == null) {
	    return !length;
	  }
	  object = Object(object);
	  while (index--) {
	    var data = matchData[index];
	    if ((noCustomizer && data[2])
	          ? data[1] !== object[data[0]]
	          : !(data[0] in object)
	        ) {
	      return false;
	    }
	  }
	  while (++index < length) {
	    data = matchData[index];
	    var key = data[0],
	        objValue = object[key],
	        srcValue = data[1];

	    if (noCustomizer && data[2]) {
	      if (objValue === undefined && !(key in object)) {
	        return false;
	      }
	    } else {
	      var stack = new Stack;
	      if (customizer) {
	        var result = customizer(objValue, srcValue, key, object, source, stack);
	      }
	      if (!(result === undefined
	            ? baseIsEqual(srcValue, objValue, customizer, UNORDERED_COMPARE_FLAG | PARTIAL_COMPARE_FLAG, stack)
	            : result
	          )) {
	        return false;
	      }
	    }
	  }
	  return true;
	}

	module.exports = baseIsMatch;


/***/ },
/* 396 */
/***/ function(module, exports, __webpack_require__) {

	var isStrictComparable = __webpack_require__(402),
	    toPairs = __webpack_require__(409);

	/**
	 * Gets the property names, values, and compare flags of `object`.
	 *
	 * @private
	 * @param {Object} object The object to query.
	 * @returns {Array} Returns the match data of `object`.
	 */
	function getMatchData(object) {
	  var result = toPairs(object),
	      length = result.length;

	  while (length--) {
	    result[length][2] = isStrictComparable(result[length][1]);
	  }
	  return result;
	}

	module.exports = getMatchData;


/***/ },
/* 397 */
/***/ function(module, exports, __webpack_require__) {

	/**
	 * A specialized version of `matchesProperty` for source values suitable
	 * for strict equality comparisons, i.e. `===`.
	 *
	 * @private
	 * @param {string} key The key of the property to get.
	 * @param {*} srcValue The value to match.
	 * @returns {Function} Returns the new function.
	 */
	function matchesStrictComparable(key, srcValue) {
	  return function(object) {
	    if (object == null) {
	      return false;
	    }
	    return object[key] === srcValue &&
	      (srcValue !== undefined || (key in Object(object)));
	  };
	}

	module.exports = matchesStrictComparable;


/***/ },
/* 398 */
/***/ function(module, exports, __webpack_require__) {

	var baseIsEqualDeep = __webpack_require__(410),
	    isObject = __webpack_require__(333),
	    isObjectLike = __webpack_require__(372);

	/**
	 * The base implementation of `_.isEqual` which supports partial comparisons
	 * and tracks traversed objects.
	 *
	 * @private
	 * @param {*} value The value to compare.
	 * @param {*} other The other value to compare.
	 * @param {Function} [customizer] The function to customize comparisons.
	 * @param {boolean} [bitmask] The bitmask of comparison flags.
	 *  The bitmask may be composed of the following flags:
	 *     1 - Unordered comparison
	 *     2 - Partial comparison
	 * @param {Object} [stack] Tracks traversed `value` and `other` objects.
	 * @returns {boolean} Returns `true` if the values are equivalent, else `false`.
	 */
	function baseIsEqual(value, other, customizer, bitmask, stack) {
	  if (value === other) {
	    return true;
	  }
	  if (value == null || other == null || (!isObject(value) && !isObjectLike(other))) {
	    return value !== value && other !== other;
	  }
	  return baseIsEqualDeep(value, other, baseIsEqual, customizer, bitmask, stack);
	}

	module.exports = baseIsEqual;


/***/ },
/* 399 */
/***/ function(module, exports, __webpack_require__) {

	var baseGet = __webpack_require__(411);

	/**
	 * Gets the value at `path` of `object`. If the resolved value is
	 * `undefined`, the `defaultValue` is used in its place.
	 *
	 * @static
	 * @memberOf _
	 * @since 3.7.0
	 * @category Object
	 * @param {Object} object The object to query.
	 * @param {Array|string} path The path of the property to get.
	 * @param {*} [defaultValue] The value returned for `undefined` resolved values.
	 * @returns {*} Returns the resolved value.
	 * @example
	 *
	 * var object = { 'a': [{ 'b': { 'c': 3 } }] };
	 *
	 * _.get(object, 'a[0].b.c');
	 * // => 3
	 *
	 * _.get(object, ['a', '0', 'b', 'c']);
	 * // => 3
	 *
	 * _.get(object, 'a.b.c', 'default');
	 * // => 'default'
	 */
	function get(object, path, defaultValue) {
	  var result = object == null ? undefined : baseGet(object, path);
	  return result === undefined ? defaultValue : result;
	}

	module.exports = get;


/***/ },
/* 400 */
/***/ function(module, exports, __webpack_require__) {

	var baseHasIn = __webpack_require__(412),
	    hasPath = __webpack_require__(413);

	/**
	 * Checks if `path` is a direct or inherited property of `object`.
	 *
	 * @static
	 * @memberOf _
	 * @since 4.0.0
	 * @category Object
	 * @param {Object} object The object to query.
	 * @param {Array|string} path The path to check.
	 * @returns {boolean} Returns `true` if `path` exists, else `false`.
	 * @example
	 *
	 * var object = _.create({ 'a': _.create({ 'b': 2 }) });
	 *
	 * _.hasIn(object, 'a');
	 * // => true
	 *
	 * _.hasIn(object, 'a.b');
	 * // => true
	 *
	 * _.hasIn(object, ['a', 'b']);
	 * // => true
	 *
	 * _.hasIn(object, 'b');
	 * // => false
	 */
	function hasIn(object, path) {
	  return object != null && hasPath(object, path, baseHasIn);
	}

	module.exports = hasIn;


/***/ },
/* 401 */
/***/ function(module, exports, __webpack_require__) {

	var isArray = __webpack_require__(359),
	    isSymbol = __webpack_require__(414);

	/** Used to match property names within property paths. */
	var reIsDeepProp = /\.|\[(?:[^[\]]*|(["'])(?:(?!\1)[^\\]|\\.)*?\1)\]/,
	    reIsPlainProp = /^\w*$/;

	/**
	 * Checks if `value` is a property name and not a property path.
	 *
	 * @private
	 * @param {*} value The value to check.
	 * @param {Object} [object] The object to query keys on.
	 * @returns {boolean} Returns `true` if `value` is a property name, else `false`.
	 */
	function isKey(value, object) {
	  var type = typeof value;
	  if (type == 'number' || type == 'symbol') {
	    return true;
	  }
	  return !isArray(value) &&
	    (isSymbol(value) || reIsPlainProp.test(value) || !reIsDeepProp.test(value) ||
	      (object != null && value in Object(object)));
	}

	module.exports = isKey;


/***/ },
/* 402 */
/***/ function(module, exports, __webpack_require__) {

	var isObject = __webpack_require__(333);

	/**
	 * Checks if `value` is suitable for strict equality comparisons, i.e. `===`.
	 *
	 * @private
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` if suitable for strict
	 *  equality comparisons, else `false`.
	 */
	function isStrictComparable(value) {
	  return value === value && !isObject(value);
	}

	module.exports = isStrictComparable;


/***/ },
/* 403 */
/***/ function(module, exports, __webpack_require__) {

	var baseGet = __webpack_require__(411);

	/**
	 * A specialized version of `baseProperty` which supports deep paths.
	 *
	 * @private
	 * @param {Array|string} path The path of the property to get.
	 * @returns {Function} Returns the new function.
	 */
	function basePropertyDeep(path) {
	  return function(object) {
	    return baseGet(object, path);
	  };
	}

	module.exports = basePropertyDeep;


/***/ },
/* 404 */
/***/ function(module, exports, __webpack_require__) {

	var isFunction = __webpack_require__(335),
	    isObject = __webpack_require__(333),
	    isSymbol = __webpack_require__(414);

	/** Used as references for various `Number` constants. */
	var NAN = 0 / 0;

	/** Used to match leading and trailing whitespace. */
	var reTrim = /^\s+|\s+$/g;

	/** Used to detect bad signed hexadecimal string values. */
	var reIsBadHex = /^[-+]0x[0-9a-f]+$/i;

	/** Used to detect binary string values. */
	var reIsBinary = /^0b[01]+$/i;

	/** Used to detect octal string values. */
	var reIsOctal = /^0o[0-7]+$/i;

	/** Built-in method references without a dependency on `root`. */
	var freeParseInt = parseInt;

	/**
	 * Converts `value` to a number.
	 *
	 * @static
	 * @memberOf _
	 * @since 4.0.0
	 * @category Lang
	 * @param {*} value The value to process.
	 * @returns {number} Returns the number.
	 * @example
	 *
	 * _.toNumber(3);
	 * // => 3
	 *
	 * _.toNumber(Number.MIN_VALUE);
	 * // => 5e-324
	 *
	 * _.toNumber(Infinity);
	 * // => Infinity
	 *
	 * _.toNumber('3');
	 * // => 3
	 */
	function toNumber(value) {
	  if (typeof value == 'number') {
	    return value;
	  }
	  if (isSymbol(value)) {
	    return NAN;
	  }
	  if (isObject(value)) {
	    var other = isFunction(value.valueOf) ? value.valueOf() : value;
	    value = isObject(other) ? (other + '') : other;
	  }
	  if (typeof value != 'string') {
	    return value === 0 ? value : +value;
	  }
	  value = value.replace(reTrim, '');
	  var isBinary = reIsBinary.test(value);
	  return (isBinary || reIsOctal.test(value))
	    ? freeParseInt(value.slice(2), isBinary ? 2 : 8)
	    : (reIsBadHex.test(value) ? NAN : +value);
	}

	module.exports = toNumber;


/***/ },
/* 405 */
/***/ function(module, exports, __webpack_require__) {

	var isNative = __webpack_require__(415);

	/**
	 * Gets the native function at `key` of `object`.
	 *
	 * @private
	 * @param {Object} object The object to query.
	 * @param {string} key The key of the method to get.
	 * @returns {*} Returns the function if it's native, else `undefined`.
	 */
	function getNative(object, key) {
	  var value = object[key];
	  return isNative(value) ? value : undefined;
	}

	module.exports = getNative;


/***/ },
/* 406 */
/***/ function(module, exports, __webpack_require__) {

	/**
	 * Checks if `value` is a global object.
	 *
	 * @private
	 * @param {*} value The value to check.
	 * @returns {null|Object} Returns `value` if it's a global object, else `null`.
	 */
	function checkGlobal(value) {
	  return (value && value.Object === Object) ? value : null;
	}

	module.exports = checkGlobal;


/***/ },
/* 407 */
/***/ function(module, exports, __webpack_require__) {

	var createBaseFor = __webpack_require__(416);

	/**
	 * The base implementation of `baseForOwn` which iterates over `object`
	 * properties returned by `keysFunc` and invokes `iteratee` for each property.
	 * Iteratee functions may exit iteration early by explicitly returning `false`.
	 *
	 * @private
	 * @param {Object} object The object to iterate over.
	 * @param {Function} iteratee The function invoked per iteration.
	 * @param {Function} keysFunc The function to get the keys of `object`.
	 * @returns {Object} Returns `object`.
	 */
	var baseFor = createBaseFor();

	module.exports = baseFor;


/***/ },
/* 408 */
/***/ function(module, exports, __webpack_require__) {

	var stackClear = __webpack_require__(417),
	    stackDelete = __webpack_require__(418),
	    stackGet = __webpack_require__(419),
	    stackHas = __webpack_require__(420),
	    stackSet = __webpack_require__(421);

	/**
	 * Creates a stack cache object to store key-value pairs.
	 *
	 * @private
	 * @constructor
	 * @param {Array} [values] The values to cache.
	 */
	function Stack(values) {
	  var index = -1,
	      length = values ? values.length : 0;

	  this.clear();
	  while (++index < length) {
	    var entry = values[index];
	    this.set(entry[0], entry[1]);
	  }
	}

	// Add methods to `Stack`.
	Stack.prototype.clear = stackClear;
	Stack.prototype['delete'] = stackDelete;
	Stack.prototype.get = stackGet;
	Stack.prototype.has = stackHas;
	Stack.prototype.set = stackSet;

	module.exports = Stack;


/***/ },
/* 409 */
/***/ function(module, exports, __webpack_require__) {

	var baseToPairs = __webpack_require__(422),
	    keys = __webpack_require__(350);

	/**
	 * Creates an array of own enumerable string keyed-value pairs for `object`
	 * which can be consumed by `_.fromPairs`.
	 *
	 * @static
	 * @memberOf _
	 * @since 4.0.0
	 * @alias entries
	 * @category Object
	 * @param {Object} object The object to query.
	 * @returns {Array} Returns the new array of key-value pairs.
	 * @example
	 *
	 * function Foo() {
	 *   this.a = 1;
	 *   this.b = 2;
	 * }
	 *
	 * Foo.prototype.c = 3;
	 *
	 * _.toPairs(new Foo);
	 * // => [['a', 1], ['b', 2]] (iteration order is not guaranteed)
	 */
	function toPairs(object) {
	  return baseToPairs(object, keys(object));
	}

	module.exports = toPairs;


/***/ },
/* 410 */
/***/ function(module, exports, __webpack_require__) {

	var Stack = __webpack_require__(408),
	    equalArrays = __webpack_require__(424),
	    equalByTag = __webpack_require__(425),
	    equalObjects = __webpack_require__(426),
	    getTag = __webpack_require__(369),
	    isArray = __webpack_require__(359),
	    isHostObject = __webpack_require__(427),
	    isTypedArray = __webpack_require__(428);

	/** Used to compose bitmasks for comparison styles. */
	var PARTIAL_COMPARE_FLAG = 2;

	/** `Object#toString` result references. */
	var argsTag = '[object Arguments]',
	    arrayTag = '[object Array]',
	    objectTag = '[object Object]';

	/** Used for built-in method references. */
	var objectProto = Object.prototype;

	/** Used to check objects for own properties. */
	var hasOwnProperty = objectProto.hasOwnProperty;

	/**
	 * A specialized version of `baseIsEqual` for arrays and objects which performs
	 * deep comparisons and tracks traversed objects enabling objects with circular
	 * references to be compared.
	 *
	 * @private
	 * @param {Object} object The object to compare.
	 * @param {Object} other The other object to compare.
	 * @param {Function} equalFunc The function to determine equivalents of values.
	 * @param {Function} [customizer] The function to customize comparisons.
	 * @param {number} [bitmask] The bitmask of comparison flags. See `baseIsEqual`
	 *  for more details.
	 * @param {Object} [stack] Tracks traversed `object` and `other` objects.
	 * @returns {boolean} Returns `true` if the objects are equivalent, else `false`.
	 */
	function baseIsEqualDeep(object, other, equalFunc, customizer, bitmask, stack) {
	  var objIsArr = isArray(object),
	      othIsArr = isArray(other),
	      objTag = arrayTag,
	      othTag = arrayTag;

	  if (!objIsArr) {
	    objTag = getTag(object);
	    objTag = objTag == argsTag ? objectTag : objTag;
	  }
	  if (!othIsArr) {
	    othTag = getTag(other);
	    othTag = othTag == argsTag ? objectTag : othTag;
	  }
	  var objIsObj = objTag == objectTag && !isHostObject(object),
	      othIsObj = othTag == objectTag && !isHostObject(other),
	      isSameTag = objTag == othTag;

	  if (isSameTag && !objIsObj) {
	    stack || (stack = new Stack);
	    return (objIsArr || isTypedArray(object))
	      ? equalArrays(object, other, equalFunc, customizer, bitmask, stack)
	      : equalByTag(object, other, objTag, equalFunc, customizer, bitmask, stack);
	  }
	  if (!(bitmask & PARTIAL_COMPARE_FLAG)) {
	    var objIsWrapped = objIsObj && hasOwnProperty.call(object, '__wrapped__'),
	        othIsWrapped = othIsObj && hasOwnProperty.call(other, '__wrapped__');

	    if (objIsWrapped || othIsWrapped) {
	      var objUnwrapped = objIsWrapped ? object.value() : object,
	          othUnwrapped = othIsWrapped ? other.value() : other;

	      stack || (stack = new Stack);
	      return equalFunc(objUnwrapped, othUnwrapped, customizer, bitmask, stack);
	    }
	  }
	  if (!isSameTag) {
	    return false;
	  }
	  stack || (stack = new Stack);
	  return equalObjects(object, other, equalFunc, customizer, bitmask, stack);
	}

	module.exports = baseIsEqualDeep;


/***/ },
/* 411 */
/***/ function(module, exports, __webpack_require__) {

	var castPath = __webpack_require__(423),
	    isKey = __webpack_require__(401);

	/**
	 * The base implementation of `_.get` without support for default values.
	 *
	 * @private
	 * @param {Object} object The object to query.
	 * @param {Array|string} path The path of the property to get.
	 * @returns {*} Returns the resolved value.
	 */
	function baseGet(object, path) {
	  path = isKey(path, object) ? [path] : castPath(path);

	  var index = 0,
	      length = path.length;

	  while (object != null && index < length) {
	    object = object[path[index++]];
	  }
	  return (index && index == length) ? object : undefined;
	}

	module.exports = baseGet;


/***/ },
/* 412 */
/***/ function(module, exports, __webpack_require__) {

	/**
	 * The base implementation of `_.hasIn` without support for deep paths.
	 *
	 * @private
	 * @param {Object} object The object to query.
	 * @param {Array|string} key The key to check.
	 * @returns {boolean} Returns `true` if `key` exists, else `false`.
	 */
	function baseHasIn(object, key) {
	  return key in Object(object);
	}

	module.exports = baseHasIn;


/***/ },
/* 413 */
/***/ function(module, exports, __webpack_require__) {

	var castPath = __webpack_require__(423),
	    isArguments = __webpack_require__(370),
	    isArray = __webpack_require__(359),
	    isIndex = __webpack_require__(368),
	    isKey = __webpack_require__(401),
	    isLength = __webpack_require__(364),
	    isString = __webpack_require__(373);

	/**
	 * Checks if `path` exists on `object`.
	 *
	 * @private
	 * @param {Object} object The object to query.
	 * @param {Array|string} path The path to check.
	 * @param {Function} hasFunc The function to check properties.
	 * @returns {boolean} Returns `true` if `path` exists, else `false`.
	 */
	function hasPath(object, path, hasFunc) {
	  path = isKey(path, object) ? [path] : castPath(path);

	  var result,
	      index = -1,
	      length = path.length;

	  while (++index < length) {
	    var key = path[index];
	    if (!(result = object != null && hasFunc(object, key))) {
	      break;
	    }
	    object = object[key];
	  }
	  if (result) {
	    return result;
	  }
	  var length = object ? object.length : 0;
	  return !!length && isLength(length) && isIndex(key, length) &&
	    (isArray(object) || isString(object) || isArguments(object));
	}

	module.exports = hasPath;


/***/ },
/* 414 */
/***/ function(module, exports, __webpack_require__) {

	var isObjectLike = __webpack_require__(372);

	/** `Object#toString` result references. */
	var symbolTag = '[object Symbol]';

	/** Used for built-in method references. */
	var objectProto = Object.prototype;

	/**
	 * Used to resolve the
	 * [`toStringTag`](http://ecma-international.org/ecma-262/6.0/#sec-object.prototype.tostring)
	 * of values.
	 */
	var objectToString = objectProto.toString;

	/**
	 * Checks if `value` is classified as a `Symbol` primitive or object.
	 *
	 * @static
	 * @memberOf _
	 * @since 4.0.0
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is correctly classified,
	 *  else `false`.
	 * @example
	 *
	 * _.isSymbol(Symbol.iterator);
	 * // => true
	 *
	 * _.isSymbol('abc');
	 * // => false
	 */
	function isSymbol(value) {
	  return typeof value == 'symbol' ||
	    (isObjectLike(value) && objectToString.call(value) == symbolTag);
	}

	module.exports = isSymbol;


/***/ },
/* 415 */
/***/ function(module, exports, __webpack_require__) {

	var isFunction = __webpack_require__(335),
	    isHostObject = __webpack_require__(427),
	    isObject = __webpack_require__(333),
	    toSource = __webpack_require__(392);

	/**
	 * Used to match `RegExp`
	 * [syntax characters](http://ecma-international.org/ecma-262/6.0/#sec-patterns).
	 */
	var reRegExpChar = /[\\^$.*+?()[\]{}|]/g;

	/** Used to detect host constructors (Safari). */
	var reIsHostCtor = /^\[object .+?Constructor\]$/;

	/** Used for built-in method references. */
	var objectProto = Object.prototype;

	/** Used to resolve the decompiled source of functions. */
	var funcToString = Function.prototype.toString;

	/** Used to check objects for own properties. */
	var hasOwnProperty = objectProto.hasOwnProperty;

	/** Used to detect if a method is native. */
	var reIsNative = RegExp('^' +
	  funcToString.call(hasOwnProperty).replace(reRegExpChar, '\\$&')
	  .replace(/hasOwnProperty|(function).*?(?=\\\()| for .+?(?=\\\])/g, '$1.*?') + '$'
	);

	/**
	 * Checks if `value` is a native function.
	 *
	 * @static
	 * @memberOf _
	 * @since 3.0.0
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is a native function,
	 *  else `false`.
	 * @example
	 *
	 * _.isNative(Array.prototype.push);
	 * // => true
	 *
	 * _.isNative(_);
	 * // => false
	 */
	function isNative(value) {
	  if (!isObject(value)) {
	    return false;
	  }
	  var pattern = (isFunction(value) || isHostObject(value)) ? reIsNative : reIsHostCtor;
	  return pattern.test(toSource(value));
	}

	module.exports = isNative;


/***/ },
/* 416 */
/***/ function(module, exports, __webpack_require__) {

	/**
	 * Creates a base function for methods like `_.forIn` and `_.forOwn`.
	 *
	 * @private
	 * @param {boolean} [fromRight] Specify iterating from right to left.
	 * @returns {Function} Returns the new base function.
	 */
	function createBaseFor(fromRight) {
	  return function(object, iteratee, keysFunc) {
	    var index = -1,
	        iterable = Object(object),
	        props = keysFunc(object),
	        length = props.length;

	    while (length--) {
	      var key = props[fromRight ? length : ++index];
	      if (iteratee(iterable[key], key, iterable) === false) {
	        break;
	      }
	    }
	    return object;
	  };
	}

	module.exports = createBaseFor;


/***/ },
/* 417 */
/***/ function(module, exports, __webpack_require__) {

	/**
	 * Removes all key-value entries from the stack.
	 *
	 * @private
	 * @name clear
	 * @memberOf Stack
	 */
	function stackClear() {
	  this.__data__ = { 'array': [], 'map': null };
	}

	module.exports = stackClear;


/***/ },
/* 418 */
/***/ function(module, exports, __webpack_require__) {

	var assocDelete = __webpack_require__(429);

	/**
	 * Removes `key` and its value from the stack.
	 *
	 * @private
	 * @name delete
	 * @memberOf Stack
	 * @param {string} key The key of the value to remove.
	 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
	 */
	function stackDelete(key) {
	  var data = this.__data__,
	      array = data.array;

	  return array ? assocDelete(array, key) : data.map['delete'](key);
	}

	module.exports = stackDelete;


/***/ },
/* 419 */
/***/ function(module, exports, __webpack_require__) {

	var assocGet = __webpack_require__(431);

	/**
	 * Gets the stack value for `key`.
	 *
	 * @private
	 * @name get
	 * @memberOf Stack
	 * @param {string} key The key of the value to get.
	 * @returns {*} Returns the entry value.
	 */
	function stackGet(key) {
	  var data = this.__data__,
	      array = data.array;

	  return array ? assocGet(array, key) : data.map.get(key);
	}

	module.exports = stackGet;


/***/ },
/* 420 */
/***/ function(module, exports, __webpack_require__) {

	var assocHas = __webpack_require__(430);

	/**
	 * Checks if a stack value for `key` exists.
	 *
	 * @private
	 * @name has
	 * @memberOf Stack
	 * @param {string} key The key of the entry to check.
	 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
	 */
	function stackHas(key) {
	  var data = this.__data__,
	      array = data.array;

	  return array ? assocHas(array, key) : data.map.has(key);
	}

	module.exports = stackHas;


/***/ },
/* 421 */
/***/ function(module, exports, __webpack_require__) {

	var MapCache = __webpack_require__(435),
	    assocSet = __webpack_require__(436);

	/** Used as the size to enable large array optimizations. */
	var LARGE_ARRAY_SIZE = 200;

	/**
	 * Sets the stack `key` to `value`.
	 *
	 * @private
	 * @name set
	 * @memberOf Stack
	 * @param {string} key The key of the value to set.
	 * @param {*} value The value to set.
	 * @returns {Object} Returns the stack cache instance.
	 */
	function stackSet(key, value) {
	  var data = this.__data__,
	      array = data.array;

	  if (array) {
	    if (array.length < (LARGE_ARRAY_SIZE - 1)) {
	      assocSet(array, key, value);
	    } else {
	      data.array = null;
	      data.map = new MapCache(array);
	    }
	  }
	  var map = data.map;
	  if (map) {
	    map.set(key, value);
	  }
	  return this;
	}

	module.exports = stackSet;


/***/ },
/* 422 */
/***/ function(module, exports, __webpack_require__) {

	var arrayMap = __webpack_require__(433);

	/**
	 * The base implementation of `_.toPairs` and `_.toPairsIn` which creates an array
	 * of key-value pairs for `object` corresponding to the property names of `props`.
	 *
	 * @private
	 * @param {Object} object The object to query.
	 * @param {Array} props The property names to get values for.
	 * @returns {Object} Returns the new array of key-value pairs.
	 */
	function baseToPairs(object, props) {
	  return arrayMap(props, function(key) {
	    return [key, object[key]];
	  });
	}

	module.exports = baseToPairs;


/***/ },
/* 423 */
/***/ function(module, exports, __webpack_require__) {

	var isArray = __webpack_require__(359),
	    stringToPath = __webpack_require__(434);

	/**
	 * Casts `value` to a path array if it's not one.
	 *
	 * @private
	 * @param {*} value The value to inspect.
	 * @returns {Array} Returns the cast property path array.
	 */
	function castPath(value) {
	  return isArray(value) ? value : stringToPath(value);
	}

	module.exports = castPath;


/***/ },
/* 424 */
/***/ function(module, exports, __webpack_require__) {

	var arraySome = __webpack_require__(432);

	/** Used to compose bitmasks for comparison styles. */
	var UNORDERED_COMPARE_FLAG = 1,
	    PARTIAL_COMPARE_FLAG = 2;

	/**
	 * A specialized version of `baseIsEqualDeep` for arrays with support for
	 * partial deep comparisons.
	 *
	 * @private
	 * @param {Array} array The array to compare.
	 * @param {Array} other The other array to compare.
	 * @param {Function} equalFunc The function to determine equivalents of values.
	 * @param {Function} customizer The function to customize comparisons.
	 * @param {number} bitmask The bitmask of comparison flags. See `baseIsEqual`
	 *  for more details.
	 * @param {Object} stack Tracks traversed `array` and `other` objects.
	 * @returns {boolean} Returns `true` if the arrays are equivalent, else `false`.
	 */
	function equalArrays(array, other, equalFunc, customizer, bitmask, stack) {
	  var index = -1,
	      isPartial = bitmask & PARTIAL_COMPARE_FLAG,
	      isUnordered = bitmask & UNORDERED_COMPARE_FLAG,
	      arrLength = array.length,
	      othLength = other.length;

	  if (arrLength != othLength && !(isPartial && othLength > arrLength)) {
	    return false;
	  }
	  // Assume cyclic values are equal.
	  var stacked = stack.get(array);
	  if (stacked) {
	    return stacked == other;
	  }
	  var result = true;
	  stack.set(array, other);

	  // Ignore non-index properties.
	  while (++index < arrLength) {
	    var arrValue = array[index],
	        othValue = other[index];

	    if (customizer) {
	      var compared = isPartial
	        ? customizer(othValue, arrValue, index, other, array, stack)
	        : customizer(arrValue, othValue, index, array, other, stack);
	    }
	    if (compared !== undefined) {
	      if (compared) {
	        continue;
	      }
	      result = false;
	      break;
	    }
	    // Recursively compare arrays (susceptible to call stack limits).
	    if (isUnordered) {
	      if (!arraySome(other, function(othValue) {
	            return arrValue === othValue ||
	              equalFunc(arrValue, othValue, customizer, bitmask, stack);
	          })) {
	        result = false;
	        break;
	      }
	    } else if (!(
	          arrValue === othValue ||
	            equalFunc(arrValue, othValue, customizer, bitmask, stack)
	        )) {
	      result = false;
	      break;
	    }
	  }
	  stack['delete'](array);
	  return result;
	}

	module.exports = equalArrays;


/***/ },
/* 425 */
/***/ function(module, exports, __webpack_require__) {

	var Symbol = __webpack_require__(437),
	    Uint8Array = __webpack_require__(438),
	    equalArrays = __webpack_require__(424),
	    mapToArray = __webpack_require__(439),
	    setToArray = __webpack_require__(440);

	/** Used to compose bitmasks for comparison styles. */
	var UNORDERED_COMPARE_FLAG = 1,
	    PARTIAL_COMPARE_FLAG = 2;

	/** `Object#toString` result references. */
	var boolTag = '[object Boolean]',
	    dateTag = '[object Date]',
	    errorTag = '[object Error]',
	    mapTag = '[object Map]',
	    numberTag = '[object Number]',
	    regexpTag = '[object RegExp]',
	    setTag = '[object Set]',
	    stringTag = '[object String]',
	    symbolTag = '[object Symbol]';

	var arrayBufferTag = '[object ArrayBuffer]',
	    dataViewTag = '[object DataView]';

	/** Used to convert symbols to primitives and strings. */
	var symbolProto = Symbol ? Symbol.prototype : undefined,
	    symbolValueOf = symbolProto ? symbolProto.valueOf : undefined;

	/**
	 * A specialized version of `baseIsEqualDeep` for comparing objects of
	 * the same `toStringTag`.
	 *
	 * **Note:** This function only supports comparing values with tags of
	 * `Boolean`, `Date`, `Error`, `Number`, `RegExp`, or `String`.
	 *
	 * @private
	 * @param {Object} object The object to compare.
	 * @param {Object} other The other object to compare.
	 * @param {string} tag The `toStringTag` of the objects to compare.
	 * @param {Function} equalFunc The function to determine equivalents of values.
	 * @param {Function} customizer The function to customize comparisons.
	 * @param {number} bitmask The bitmask of comparison flags. See `baseIsEqual`
	 *  for more details.
	 * @param {Object} stack Tracks traversed `object` and `other` objects.
	 * @returns {boolean} Returns `true` if the objects are equivalent, else `false`.
	 */
	function equalByTag(object, other, tag, equalFunc, customizer, bitmask, stack) {
	  switch (tag) {
	    case dataViewTag:
	      if ((object.byteLength != other.byteLength) ||
	          (object.byteOffset != other.byteOffset)) {
	        return false;
	      }
	      object = object.buffer;
	      other = other.buffer;

	    case arrayBufferTag:
	      if ((object.byteLength != other.byteLength) ||
	          !equalFunc(new Uint8Array(object), new Uint8Array(other))) {
	        return false;
	      }
	      return true;

	    case boolTag:
	    case dateTag:
	      // Coerce dates and booleans to numbers, dates to milliseconds and
	      // booleans to `1` or `0` treating invalid dates coerced to `NaN` as
	      // not equal.
	      return +object == +other;

	    case errorTag:
	      return object.name == other.name && object.message == other.message;

	    case numberTag:
	      // Treat `NaN` vs. `NaN` as equal.
	      return (object != +object) ? other != +other : object == +other;

	    case regexpTag:
	    case stringTag:
	      // Coerce regexes to strings and treat strings, primitives and objects,
	      // as equal. See http://www.ecma-international.org/ecma-262/6.0/#sec-regexp.prototype.tostring
	      // for more details.
	      return object == (other + '');

	    case mapTag:
	      var convert = mapToArray;

	    case setTag:
	      var isPartial = bitmask & PARTIAL_COMPARE_FLAG;
	      convert || (convert = setToArray);

	      if (object.size != other.size && !isPartial) {
	        return false;
	      }
	      // Assume cyclic values are equal.
	      var stacked = stack.get(object);
	      if (stacked) {
	        return stacked == other;
	      }
	      bitmask |= UNORDERED_COMPARE_FLAG;
	      stack.set(object, other);

	      // Recursively compare objects (susceptible to call stack limits).
	      return equalArrays(convert(object), convert(other), equalFunc, customizer, bitmask, stack);

	    case symbolTag:
	      if (symbolValueOf) {
	        return symbolValueOf.call(object) == symbolValueOf.call(other);
	      }
	  }
	  return false;
	}

	module.exports = equalByTag;


/***/ },
/* 426 */
/***/ function(module, exports, __webpack_require__) {

	var baseHas = __webpack_require__(365),
	    keys = __webpack_require__(350);

	/** Used to compose bitmasks for comparison styles. */
	var PARTIAL_COMPARE_FLAG = 2;

	/**
	 * A specialized version of `baseIsEqualDeep` for objects with support for
	 * partial deep comparisons.
	 *
	 * @private
	 * @param {Object} object The object to compare.
	 * @param {Object} other The other object to compare.
	 * @param {Function} equalFunc The function to determine equivalents of values.
	 * @param {Function} customizer The function to customize comparisons.
	 * @param {number} bitmask The bitmask of comparison flags. See `baseIsEqual`
	 *  for more details.
	 * @param {Object} stack Tracks traversed `object` and `other` objects.
	 * @returns {boolean} Returns `true` if the objects are equivalent, else `false`.
	 */
	function equalObjects(object, other, equalFunc, customizer, bitmask, stack) {
	  var isPartial = bitmask & PARTIAL_COMPARE_FLAG,
	      objProps = keys(object),
	      objLength = objProps.length,
	      othProps = keys(other),
	      othLength = othProps.length;

	  if (objLength != othLength && !isPartial) {
	    return false;
	  }
	  var index = objLength;
	  while (index--) {
	    var key = objProps[index];
	    if (!(isPartial ? key in other : baseHas(other, key))) {
	      return false;
	    }
	  }
	  // Assume cyclic values are equal.
	  var stacked = stack.get(object);
	  if (stacked) {
	    return stacked == other;
	  }
	  var result = true;
	  stack.set(object, other);

	  var skipCtor = isPartial;
	  while (++index < objLength) {
	    key = objProps[index];
	    var objValue = object[key],
	        othValue = other[key];

	    if (customizer) {
	      var compared = isPartial
	        ? customizer(othValue, objValue, key, other, object, stack)
	        : customizer(objValue, othValue, key, object, other, stack);
	    }
	    // Recursively compare objects (susceptible to call stack limits).
	    if (!(compared === undefined
	          ? (objValue === othValue || equalFunc(objValue, othValue, customizer, bitmask, stack))
	          : compared
	        )) {
	      result = false;
	      break;
	    }
	    skipCtor || (skipCtor = key == 'constructor');
	  }
	  if (result && !skipCtor) {
	    var objCtor = object.constructor,
	        othCtor = other.constructor;

	    // Non `Object` object instances with different constructors are not equal.
	    if (objCtor != othCtor &&
	        ('constructor' in object && 'constructor' in other) &&
	        !(typeof objCtor == 'function' && objCtor instanceof objCtor &&
	          typeof othCtor == 'function' && othCtor instanceof othCtor)) {
	      result = false;
	    }
	  }
	  stack['delete'](object);
	  return result;
	}

	module.exports = equalObjects;


/***/ },
/* 427 */
/***/ function(module, exports, __webpack_require__) {

	/**
	 * Checks if `value` is a host object in IE < 9.
	 *
	 * @private
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is a host object, else `false`.
	 */
	function isHostObject(value) {
	  // Many host objects are `Object` objects that can coerce to strings
	  // despite having improperly defined `toString` methods.
	  var result = false;
	  if (value != null && typeof value.toString != 'function') {
	    try {
	      result = !!(value + '');
	    } catch (e) {}
	  }
	  return result;
	}

	module.exports = isHostObject;


/***/ },
/* 428 */
/***/ function(module, exports, __webpack_require__) {

	var isLength = __webpack_require__(364),
	    isObjectLike = __webpack_require__(372);

	/** `Object#toString` result references. */
	var argsTag = '[object Arguments]',
	    arrayTag = '[object Array]',
	    boolTag = '[object Boolean]',
	    dateTag = '[object Date]',
	    errorTag = '[object Error]',
	    funcTag = '[object Function]',
	    mapTag = '[object Map]',
	    numberTag = '[object Number]',
	    objectTag = '[object Object]',
	    regexpTag = '[object RegExp]',
	    setTag = '[object Set]',
	    stringTag = '[object String]',
	    weakMapTag = '[object WeakMap]';

	var arrayBufferTag = '[object ArrayBuffer]',
	    dataViewTag = '[object DataView]',
	    float32Tag = '[object Float32Array]',
	    float64Tag = '[object Float64Array]',
	    int8Tag = '[object Int8Array]',
	    int16Tag = '[object Int16Array]',
	    int32Tag = '[object Int32Array]',
	    uint8Tag = '[object Uint8Array]',
	    uint8ClampedTag = '[object Uint8ClampedArray]',
	    uint16Tag = '[object Uint16Array]',
	    uint32Tag = '[object Uint32Array]';

	/** Used to identify `toStringTag` values of typed arrays. */
	var typedArrayTags = {};
	typedArrayTags[float32Tag] = typedArrayTags[float64Tag] =
	typedArrayTags[int8Tag] = typedArrayTags[int16Tag] =
	typedArrayTags[int32Tag] = typedArrayTags[uint8Tag] =
	typedArrayTags[uint8ClampedTag] = typedArrayTags[uint16Tag] =
	typedArrayTags[uint32Tag] = true;
	typedArrayTags[argsTag] = typedArrayTags[arrayTag] =
	typedArrayTags[arrayBufferTag] = typedArrayTags[boolTag] =
	typedArrayTags[dataViewTag] = typedArrayTags[dateTag] =
	typedArrayTags[errorTag] = typedArrayTags[funcTag] =
	typedArrayTags[mapTag] = typedArrayTags[numberTag] =
	typedArrayTags[objectTag] = typedArrayTags[regexpTag] =
	typedArrayTags[setTag] = typedArrayTags[stringTag] =
	typedArrayTags[weakMapTag] = false;

	/** Used for built-in method references. */
	var objectProto = Object.prototype;

	/**
	 * Used to resolve the
	 * [`toStringTag`](http://ecma-international.org/ecma-262/6.0/#sec-object.prototype.tostring)
	 * of values.
	 */
	var objectToString = objectProto.toString;

	/**
	 * Checks if `value` is classified as a typed array.
	 *
	 * @static
	 * @memberOf _
	 * @since 3.0.0
	 * @category Lang
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is correctly classified,
	 *  else `false`.
	 * @example
	 *
	 * _.isTypedArray(new Uint8Array);
	 * // => true
	 *
	 * _.isTypedArray([]);
	 * // => false
	 */
	function isTypedArray(value) {
	  return isObjectLike(value) &&
	    isLength(value.length) && !!typedArrayTags[objectToString.call(value)];
	}

	module.exports = isTypedArray;


/***/ },
/* 429 */
/***/ function(module, exports, __webpack_require__) {

	var assocIndexOf = __webpack_require__(441);

	/** Used for built-in method references. */
	var arrayProto = Array.prototype;

	/** Built-in value references. */
	var splice = arrayProto.splice;

	/**
	 * Removes `key` and its value from the associative array.
	 *
	 * @private
	 * @param {Array} array The array to modify.
	 * @param {string} key The key of the value to remove.
	 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
	 */
	function assocDelete(array, key) {
	  var index = assocIndexOf(array, key);
	  if (index < 0) {
	    return false;
	  }
	  var lastIndex = array.length - 1;
	  if (index == lastIndex) {
	    array.pop();
	  } else {
	    splice.call(array, index, 1);
	  }
	  return true;
	}

	module.exports = assocDelete;


/***/ },
/* 430 */
/***/ function(module, exports, __webpack_require__) {

	var assocIndexOf = __webpack_require__(441);

	/**
	 * Checks if an associative array value for `key` exists.
	 *
	 * @private
	 * @param {Array} array The array to query.
	 * @param {string} key The key of the entry to check.
	 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
	 */
	function assocHas(array, key) {
	  return assocIndexOf(array, key) > -1;
	}

	module.exports = assocHas;


/***/ },
/* 431 */
/***/ function(module, exports, __webpack_require__) {

	var assocIndexOf = __webpack_require__(441);

	/**
	 * Gets the associative array value for `key`.
	 *
	 * @private
	 * @param {Array} array The array to query.
	 * @param {string} key The key of the value to get.
	 * @returns {*} Returns the entry value.
	 */
	function assocGet(array, key) {
	  var index = assocIndexOf(array, key);
	  return index < 0 ? undefined : array[index][1];
	}

	module.exports = assocGet;


/***/ },
/* 432 */
/***/ function(module, exports, __webpack_require__) {

	/**
	 * A specialized version of `_.some` for arrays without support for iteratee
	 * shorthands.
	 *
	 * @private
	 * @param {Array} array The array to iterate over.
	 * @param {Function} predicate The function invoked per iteration.
	 * @returns {boolean} Returns `true` if any element passes the predicate check,
	 *  else `false`.
	 */
	function arraySome(array, predicate) {
	  var index = -1,
	      length = array.length;

	  while (++index < length) {
	    if (predicate(array[index], index, array)) {
	      return true;
	    }
	  }
	  return false;
	}

	module.exports = arraySome;


/***/ },
/* 433 */
/***/ function(module, exports, __webpack_require__) {

	/**
	 * A specialized version of `_.map` for arrays without support for iteratee
	 * shorthands.
	 *
	 * @private
	 * @param {Array} array The array to iterate over.
	 * @param {Function} iteratee The function invoked per iteration.
	 * @returns {Array} Returns the new mapped array.
	 */
	function arrayMap(array, iteratee) {
	  var index = -1,
	      length = array.length,
	      result = Array(length);

	  while (++index < length) {
	    result[index] = iteratee(array[index], index, array);
	  }
	  return result;
	}

	module.exports = arrayMap;


/***/ },
/* 434 */
/***/ function(module, exports, __webpack_require__) {

	var memoize = __webpack_require__(442),
	    toString = __webpack_require__(443);

	/** Used to match property names within property paths. */
	var rePropName = /[^.[\]]+|\[(?:(-?\d+(?:\.\d+)?)|(["'])((?:(?!\2)[^\\]|\\.)*?)\2)\]/g;

	/** Used to match backslashes in property paths. */
	var reEscapeChar = /\\(\\)?/g;

	/**
	 * Converts `string` to a property path array.
	 *
	 * @private
	 * @param {string} string The string to convert.
	 * @returns {Array} Returns the property path array.
	 */
	var stringToPath = memoize(function(string) {
	  var result = [];
	  toString(string).replace(rePropName, function(match, number, quote, string) {
	    result.push(quote ? string.replace(reEscapeChar, '$1') : (number || match));
	  });
	  return result;
	});

	module.exports = stringToPath;


/***/ },
/* 435 */
/***/ function(module, exports, __webpack_require__) {

	var mapClear = __webpack_require__(444),
	    mapDelete = __webpack_require__(445),
	    mapGet = __webpack_require__(446),
	    mapHas = __webpack_require__(447),
	    mapSet = __webpack_require__(448);

	/**
	 * Creates a map cache object to store key-value pairs.
	 *
	 * @private
	 * @constructor
	 * @param {Array} [values] The values to cache.
	 */
	function MapCache(values) {
	  var index = -1,
	      length = values ? values.length : 0;

	  this.clear();
	  while (++index < length) {
	    var entry = values[index];
	    this.set(entry[0], entry[1]);
	  }
	}

	// Add methods to `MapCache`.
	MapCache.prototype.clear = mapClear;
	MapCache.prototype['delete'] = mapDelete;
	MapCache.prototype.get = mapGet;
	MapCache.prototype.has = mapHas;
	MapCache.prototype.set = mapSet;

	module.exports = MapCache;


/***/ },
/* 436 */
/***/ function(module, exports, __webpack_require__) {

	var assocIndexOf = __webpack_require__(441);

	/**
	 * Sets the associative array `key` to `value`.
	 *
	 * @private
	 * @param {Array} array The array to modify.
	 * @param {string} key The key of the value to set.
	 * @param {*} value The value to set.
	 */
	function assocSet(array, key, value) {
	  var index = assocIndexOf(array, key);
	  if (index < 0) {
	    array.push([key, value]);
	  } else {
	    array[index][1] = value;
	  }
	}

	module.exports = assocSet;


/***/ },
/* 437 */
/***/ function(module, exports, __webpack_require__) {

	var root = __webpack_require__(386);

	/** Built-in value references. */
	var Symbol = root.Symbol;

	module.exports = Symbol;


/***/ },
/* 438 */
/***/ function(module, exports, __webpack_require__) {

	var root = __webpack_require__(386);

	/** Built-in value references. */
	var Uint8Array = root.Uint8Array;

	module.exports = Uint8Array;


/***/ },
/* 439 */
/***/ function(module, exports, __webpack_require__) {

	/**
	 * Converts `map` to an array.
	 *
	 * @private
	 * @param {Object} map The map to convert.
	 * @returns {Array} Returns the converted array.
	 */
	function mapToArray(map) {
	  var index = -1,
	      result = Array(map.size);

	  map.forEach(function(value, key) {
	    result[++index] = [key, value];
	  });
	  return result;
	}

	module.exports = mapToArray;


/***/ },
/* 440 */
/***/ function(module, exports, __webpack_require__) {

	/**
	 * Converts `set` to an array.
	 *
	 * @private
	 * @param {Object} set The set to convert.
	 * @returns {Array} Returns the converted array.
	 */
	function setToArray(set) {
	  var index = -1,
	      result = Array(set.size);

	  set.forEach(function(value) {
	    result[++index] = value;
	  });
	  return result;
	}

	module.exports = setToArray;


/***/ },
/* 441 */
/***/ function(module, exports, __webpack_require__) {

	var eq = __webpack_require__(361);

	/**
	 * Gets the index at which the `key` is found in `array` of key-value pairs.
	 *
	 * @private
	 * @param {Array} array The array to search.
	 * @param {*} key The key to search for.
	 * @returns {number} Returns the index of the matched value, else `-1`.
	 */
	function assocIndexOf(array, key) {
	  var length = array.length;
	  while (length--) {
	    if (eq(array[length][0], key)) {
	      return length;
	    }
	  }
	  return -1;
	}

	module.exports = assocIndexOf;


/***/ },
/* 442 */
/***/ function(module, exports, __webpack_require__) {

	var MapCache = __webpack_require__(435);

	/** Used as the `TypeError` message for "Functions" methods. */
	var FUNC_ERROR_TEXT = 'Expected a function';

	/**
	 * Creates a function that memoizes the result of `func`. If `resolver` is
	 * provided, it determines the cache key for storing the result based on the
	 * arguments provided to the memoized function. By default, the first argument
	 * provided to the memoized function is used as the map cache key. The `func`
	 * is invoked with the `this` binding of the memoized function.
	 *
	 * **Note:** The cache is exposed as the `cache` property on the memoized
	 * function. Its creation may be customized by replacing the `_.memoize.Cache`
	 * constructor with one whose instances implement the
	 * [`Map`](http://ecma-international.org/ecma-262/6.0/#sec-properties-of-the-map-prototype-object)
	 * method interface of `delete`, `get`, `has`, and `set`.
	 *
	 * @static
	 * @memberOf _
	 * @since 0.1.0
	 * @category Function
	 * @param {Function} func The function to have its output memoized.
	 * @param {Function} [resolver] The function to resolve the cache key.
	 * @returns {Function} Returns the new memoizing function.
	 * @example
	 *
	 * var object = { 'a': 1, 'b': 2 };
	 * var other = { 'c': 3, 'd': 4 };
	 *
	 * var values = _.memoize(_.values);
	 * values(object);
	 * // => [1, 2]
	 *
	 * values(other);
	 * // => [3, 4]
	 *
	 * object.a = 2;
	 * values(object);
	 * // => [1, 2]
	 *
	 * // Modify the result cache.
	 * values.cache.set(object, ['a', 'b']);
	 * values(object);
	 * // => ['a', 'b']
	 *
	 * // Replace `_.memoize.Cache`.
	 * _.memoize.Cache = WeakMap;
	 */
	function memoize(func, resolver) {
	  if (typeof func != 'function' || (resolver && typeof resolver != 'function')) {
	    throw new TypeError(FUNC_ERROR_TEXT);
	  }
	  var memoized = function() {
	    var args = arguments,
	        key = resolver ? resolver.apply(this, args) : args[0],
	        cache = memoized.cache;

	    if (cache.has(key)) {
	      return cache.get(key);
	    }
	    var result = func.apply(this, args);
	    memoized.cache = cache.set(key, result);
	    return result;
	  };
	  memoized.cache = new (memoize.Cache || MapCache);
	  return memoized;
	}

	// Assign cache to `_.memoize`.
	memoize.Cache = MapCache;

	module.exports = memoize;


/***/ },
/* 443 */
/***/ function(module, exports, __webpack_require__) {

	var Symbol = __webpack_require__(437),
	    isSymbol = __webpack_require__(414);

	/** Used as references for various `Number` constants. */
	var INFINITY = 1 / 0;

	/** Used to convert symbols to primitives and strings. */
	var symbolProto = Symbol ? Symbol.prototype : undefined,
	    symbolToString = symbolProto ? symbolProto.toString : undefined;

	/**
	 * Converts `value` to a string. An empty string is returned for `null`
	 * and `undefined` values. The sign of `-0` is preserved.
	 *
	 * @static
	 * @memberOf _
	 * @since 4.0.0
	 * @category Lang
	 * @param {*} value The value to process.
	 * @returns {string} Returns the string.
	 * @example
	 *
	 * _.toString(null);
	 * // => ''
	 *
	 * _.toString(-0);
	 * // => '-0'
	 *
	 * _.toString([1, 2, 3]);
	 * // => '1,2,3'
	 */
	function toString(value) {
	  // Exit early for strings to avoid a performance hit in some environments.
	  if (typeof value == 'string') {
	    return value;
	  }
	  if (value == null) {
	    return '';
	  }
	  if (isSymbol(value)) {
	    return symbolToString ? symbolToString.call(value) : '';
	  }
	  var result = (value + '');
	  return (result == '0' && (1 / value) == -INFINITY) ? '-0' : result;
	}

	module.exports = toString;


/***/ },
/* 444 */
/***/ function(module, exports, __webpack_require__) {

	var Hash = __webpack_require__(449),
	    Map = __webpack_require__(388);

	/**
	 * Removes all key-value entries from the map.
	 *
	 * @private
	 * @name clear
	 * @memberOf MapCache
	 */
	function mapClear() {
	  this.__data__ = {
	    'hash': new Hash,
	    'map': Map ? new Map : [],
	    'string': new Hash
	  };
	}

	module.exports = mapClear;


/***/ },
/* 445 */
/***/ function(module, exports, __webpack_require__) {

	var Map = __webpack_require__(388),
	    assocDelete = __webpack_require__(429),
	    hashDelete = __webpack_require__(450),
	    isKeyable = __webpack_require__(451);

	/**
	 * Removes `key` and its value from the map.
	 *
	 * @private
	 * @name delete
	 * @memberOf MapCache
	 * @param {string} key The key of the value to remove.
	 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
	 */
	function mapDelete(key) {
	  var data = this.__data__;
	  if (isKeyable(key)) {
	    return hashDelete(typeof key == 'string' ? data.string : data.hash, key);
	  }
	  return Map ? data.map['delete'](key) : assocDelete(data.map, key);
	}

	module.exports = mapDelete;


/***/ },
/* 446 */
/***/ function(module, exports, __webpack_require__) {

	var Map = __webpack_require__(388),
	    assocGet = __webpack_require__(431),
	    hashGet = __webpack_require__(452),
	    isKeyable = __webpack_require__(451);

	/**
	 * Gets the map value for `key`.
	 *
	 * @private
	 * @name get
	 * @memberOf MapCache
	 * @param {string} key The key of the value to get.
	 * @returns {*} Returns the entry value.
	 */
	function mapGet(key) {
	  var data = this.__data__;
	  if (isKeyable(key)) {
	    return hashGet(typeof key == 'string' ? data.string : data.hash, key);
	  }
	  return Map ? data.map.get(key) : assocGet(data.map, key);
	}

	module.exports = mapGet;


/***/ },
/* 447 */
/***/ function(module, exports, __webpack_require__) {

	var Map = __webpack_require__(388),
	    assocHas = __webpack_require__(430),
	    hashHas = __webpack_require__(453),
	    isKeyable = __webpack_require__(451);

	/**
	 * Checks if a map value for `key` exists.
	 *
	 * @private
	 * @name has
	 * @memberOf MapCache
	 * @param {string} key The key of the entry to check.
	 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
	 */
	function mapHas(key) {
	  var data = this.__data__;
	  if (isKeyable(key)) {
	    return hashHas(typeof key == 'string' ? data.string : data.hash, key);
	  }
	  return Map ? data.map.has(key) : assocHas(data.map, key);
	}

	module.exports = mapHas;


/***/ },
/* 448 */
/***/ function(module, exports, __webpack_require__) {

	var Map = __webpack_require__(388),
	    assocSet = __webpack_require__(436),
	    hashSet = __webpack_require__(454),
	    isKeyable = __webpack_require__(451);

	/**
	 * Sets the map `key` to `value`.
	 *
	 * @private
	 * @name set
	 * @memberOf MapCache
	 * @param {string} key The key of the value to set.
	 * @param {*} value The value to set.
	 * @returns {Object} Returns the map cache instance.
	 */
	function mapSet(key, value) {
	  var data = this.__data__;
	  if (isKeyable(key)) {
	    hashSet(typeof key == 'string' ? data.string : data.hash, key, value);
	  } else if (Map) {
	    data.map.set(key, value);
	  } else {
	    assocSet(data.map, key, value);
	  }
	  return this;
	}

	module.exports = mapSet;


/***/ },
/* 449 */
/***/ function(module, exports, __webpack_require__) {

	var nativeCreate = __webpack_require__(455);

	/** Used for built-in method references. */
	var objectProto = Object.prototype;

	/**
	 * Creates a hash object.
	 *
	 * @private
	 * @constructor
	 * @returns {Object} Returns the new hash object.
	 */
	function Hash() {}

	// Avoid inheriting from `Object.prototype` when possible.
	Hash.prototype = nativeCreate ? nativeCreate(null) : objectProto;

	module.exports = Hash;


/***/ },
/* 450 */
/***/ function(module, exports, __webpack_require__) {

	var hashHas = __webpack_require__(453);

	/**
	 * Removes `key` and its value from the hash.
	 *
	 * @private
	 * @param {Object} hash The hash to modify.
	 * @param {string} key The key of the value to remove.
	 * @returns {boolean} Returns `true` if the entry was removed, else `false`.
	 */
	function hashDelete(hash, key) {
	  return hashHas(hash, key) && delete hash[key];
	}

	module.exports = hashDelete;


/***/ },
/* 451 */
/***/ function(module, exports, __webpack_require__) {

	/**
	 * Checks if `value` is suitable for use as unique object key.
	 *
	 * @private
	 * @param {*} value The value to check.
	 * @returns {boolean} Returns `true` if `value` is suitable, else `false`.
	 */
	function isKeyable(value) {
	  var type = typeof value;
	  return type == 'number' || type == 'boolean' ||
	    (type == 'string' && value != '__proto__') || value == null;
	}

	module.exports = isKeyable;


/***/ },
/* 452 */
/***/ function(module, exports, __webpack_require__) {

	var nativeCreate = __webpack_require__(455);

	/** Used to stand-in for `undefined` hash values. */
	var HASH_UNDEFINED = '__lodash_hash_undefined__';

	/** Used for built-in method references. */
	var objectProto = Object.prototype;

	/** Used to check objects for own properties. */
	var hasOwnProperty = objectProto.hasOwnProperty;

	/**
	 * Gets the hash value for `key`.
	 *
	 * @private
	 * @param {Object} hash The hash to query.
	 * @param {string} key The key of the value to get.
	 * @returns {*} Returns the entry value.
	 */
	function hashGet(hash, key) {
	  if (nativeCreate) {
	    var result = hash[key];
	    return result === HASH_UNDEFINED ? undefined : result;
	  }
	  return hasOwnProperty.call(hash, key) ? hash[key] : undefined;
	}

	module.exports = hashGet;


/***/ },
/* 453 */
/***/ function(module, exports, __webpack_require__) {

	var nativeCreate = __webpack_require__(455);

	/** Used for built-in method references. */
	var objectProto = Object.prototype;

	/** Used to check objects for own properties. */
	var hasOwnProperty = objectProto.hasOwnProperty;

	/**
	 * Checks if a hash value for `key` exists.
	 *
	 * @private
	 * @param {Object} hash The hash to query.
	 * @param {string} key The key of the entry to check.
	 * @returns {boolean} Returns `true` if an entry for `key` exists, else `false`.
	 */
	function hashHas(hash, key) {
	  return nativeCreate ? hash[key] !== undefined : hasOwnProperty.call(hash, key);
	}

	module.exports = hashHas;


/***/ },
/* 454 */
/***/ function(module, exports, __webpack_require__) {

	var nativeCreate = __webpack_require__(455);

	/** Used to stand-in for `undefined` hash values. */
	var HASH_UNDEFINED = '__lodash_hash_undefined__';

	/**
	 * Sets the hash `key` to `value`.
	 *
	 * @private
	 * @param {Object} hash The hash to modify.
	 * @param {string} key The key of the value to set.
	 * @param {*} value The value to set.
	 */
	function hashSet(hash, key, value) {
	  hash[key] = (nativeCreate && value === undefined) ? HASH_UNDEFINED : value;
	}

	module.exports = hashSet;


/***/ },
/* 455 */
/***/ function(module, exports, __webpack_require__) {

	var getNative = __webpack_require__(405);

	/* Built-in method references that are verified to be native. */
	var nativeCreate = getNative(Object, 'create');

	module.exports = nativeCreate;


/***/ }
/******/ ])
});

// Copyright 2014 Simon Lydell
// X11 (“MIT”) Licensed. (See LICENSE.)

void (function(root, factory) {
  if (typeof define === "function" && define.amd) {
    define(factory)
  } else if (typeof exports === "object") {
    module.exports = factory()
  } else {
    root.resolveUrl = factory()
  }
}(this, function() {

  function resolveUrl(/* ...urls */) {
    var numUrls = arguments.length

    if (numUrls === 0) {
      throw new Error("resolveUrl requires at least one argument; got none.")
    }

    var base = document.createElement("base")
    base.href = arguments[0]

    if (numUrls === 1) {
      return base.href
    }

    var head = document.getElementsByTagName("head")[0]
    head.insertBefore(base, head.firstChild)

    var a = document.createElement("a")
    var resolved

    for (var index = 1; index < numUrls; index++) {
      a.href = arguments[index]
      resolved = a.href
      base.href = resolved
    }

    head.removeChild(base)

    return resolved
  }

  return resolveUrl

}));

(function(f){if(typeof exports==="object"&&typeof module!=="undefined"){module.exports=f()}else if(typeof define==="function"&&define.amd){define([],f)}else{var g;if(typeof window!=="undefined"){g=window}else if(typeof global!=="undefined"){g=global}else if(typeof self!=="undefined"){g=self}else{g=this}(g.RAML || (g.RAML = {})).Grammar = f()}})(function(){var define,module,exports;return (function e(t,n,r){function s(o,u){if(!n[o]){if(!t[o]){var a=typeof require=="function"&&require;if(!u&&a)return a(o,!0);if(i)return i(o,!0);var f=new Error("Cannot find module '"+o+"'");throw f.code="MODULE_NOT_FOUND",f}var l=n[o]={exports:{}};t[o][0].call(l.exports,function(e){var n=t[o][1][e];return s(n?n:e)},l,l.exports,e,t,n,r)}return n[o].exports}var i=typeof require=="function"&&require;for(var o=0;o<r.length;o++)s(r[o]);return s})({1:[function(require,module,exports){
var noopSuggestor, suggestor08, suggestor10;

noopSuggestor = require('./suggestorXX').noopSuggestor;

suggestor08 = require('./suggestor08');

suggestor10 = require('./suggestor10');

module.exports.suggestRAML = function(path, version, fragment) {
  var suggestor;
  if (path == null) {
    path = [];
  }
  if (version == null) {
    version = '0.8';
  }
  if (fragment == null) {
    fragment = 'ApiDefinition';
  }
  suggestor = {
    '0.8': suggestor08,
    '1.0': suggestor10
  }[version];
  if (!suggestor) {
    throw new Error('unsupported version: ' + version);
  }
  suggestor = suggestor[fragment];
  if (!suggestor) {
    throw new Error('unsupported fragment: ' + fragment);
  }
  while (suggestor && path.length) {
    suggestor = suggestor.suggestorFor(path.shift());
  }
  if (!suggestor) {
    suggestor = noopSuggestor;
  }
  return {
    suggestions: suggestor.suggestions(),
    metadata: suggestor.metadata
  };
};


},{"./suggestor08":2,"./suggestor10":3,"./suggestorXX":4}],2:[function(require,module,exports){
var EmptySuggestor, SuggestionItem, Suggestor, UnionSuggestor, describedBySuggestor, dynamicResource, makeMethodGroupSuggestor, makeMethodSuggestor, methodBodySuggestor, namedParameterGroupSuggestor, namedParameterSuggestor, noopSuggestor, protocolsSuggestor, requestBodySuggestor, resourceBasicSuggestor, resourceFallback, resourceSuggestor, resourceTypeGroupSuggestor, resourceTypeSuggestor, responseBodyGroupSuggestor, responseBodyMimetypeSuggestor, responseGroupSuggestor, responseSuggestor, rootDocumentationSuggestor, securitySchemeTypeSuggestor, securitySchemesGroupSuggestor, securitySchemesSettingSuggestor, securitySchemesSuggestor, traitAdditions, traitGroupSuggestor, traitSuggestor;

EmptySuggestor = require('./suggestorXX').EmptySuggestor;

SuggestionItem = require('./suggestorXX').SuggestionItem;

Suggestor = require('./suggestorXX').Suggestor;

UnionSuggestor = require('./suggestorXX').UnionSuggestor;

noopSuggestor = require('./suggestorXX').noopSuggestor;

namedParameterSuggestor = new Suggestor([
  new SuggestionItem('description', noopSuggestor, {
    category: 'docs'
  }), new SuggestionItem('displayName', noopSuggestor, {
    category: 'docs'
  }), new SuggestionItem('example', noopSuggestor, {
    category: 'docs'
  }), new SuggestionItem('default', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('enum', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('maximum', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('maxLength', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('minimum', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('minLength', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('pattern', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('required', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('type', noopSuggestor, {
    category: 'parameters'
  })
]);

namedParameterGroupSuggestor = new EmptySuggestor(function(key) {
  return namedParameterSuggestor;
});

responseBodyMimetypeSuggestor = new Suggestor([
  new SuggestionItem('schema', noopSuggestor, {
    category: 'schemas'
  }), new SuggestionItem('example', noopSuggestor, {
    category: 'docs'
  })
]);

responseBodyGroupSuggestor = new Suggestor([
  new SuggestionItem('application/json', responseBodyMimetypeSuggestor, {
    category: 'body'
  }), new SuggestionItem('application/x-www-form-urlencoded', responseBodyMimetypeSuggestor, {
    category: 'body'
  }), new SuggestionItem('application/xml', responseBodyMimetypeSuggestor, {
    category: 'body'
  }), new SuggestionItem('multipart/form-data', responseBodyMimetypeSuggestor, {
    category: 'body'
  })
]);

responseSuggestor = new Suggestor([
  new SuggestionItem('body', responseBodyGroupSuggestor, {
    category: 'responses'
  }), new SuggestionItem('description', noopSuggestor, {
    category: 'docs'
  })
]);

responseGroupSuggestor = new EmptySuggestor(function(key) {
  if (/\d{3}/.test(key)) {
    return responseSuggestor;
  }
});

requestBodySuggestor = new EmptySuggestor(function() {
  return namedParameterGroupSuggestor;
});

methodBodySuggestor = new Suggestor([
  new SuggestionItem('application/json', noopSuggestor, {
    category: 'body'
  }), new SuggestionItem('application/x-www-form-urlencoded', requestBodySuggestor, {
    category: 'body'
  }), new SuggestionItem('application/xml', noopSuggestor, {
    category: 'body'
  }), new SuggestionItem('multipart/form-data', requestBodySuggestor, {
    category: 'body'
  })
]);

protocolsSuggestor = new Suggestor([
  new SuggestionItem('HTTP', noopSuggestor, {
    isText: true
  }), new SuggestionItem('HTTPS', noopSuggestor, {
    isText: true
  })
], null, {
  isList: true
});

makeMethodSuggestor = function() {
  return new Suggestor([
    new SuggestionItem('description', noopSuggestor, {
      category: 'docs'
    }), new SuggestionItem('body', methodBodySuggestor, {
      category: 'body'
    }), new SuggestionItem('protocols', protocolsSuggestor, {
      category: 'root'
    }), new SuggestionItem('baseUriParameters', namedParameterGroupSuggestor, {
      category: 'parameters'
    }), new SuggestionItem('headers', namedParameterGroupSuggestor, {
      category: 'parameters'
    }), new SuggestionItem('queryParameters', namedParameterGroupSuggestor, {
      category: 'parameters'
    }), new SuggestionItem('responses', responseGroupSuggestor, {
      category: 'responses'
    }), new SuggestionItem('securedBy', noopSuggestor, {
      category: 'security'
    })
  ]);
};

makeMethodGroupSuggestor = function(optional) {
  var method, methodSuggestor;
  if (optional == null) {
    optional = false;
  }
  methodSuggestor = new UnionSuggestor([
    makeMethodSuggestor(), new Suggestor([
      new SuggestionItem('is', noopSuggestor, {
        category: 'traits and types'
      })
    ])
  ]);
  return new Suggestor((function() {
    var i, len, ref, results;
    ref = ['options', 'get', 'head', 'post', 'put', 'delete', 'trace', 'connect', 'patch'];
    results = [];
    for (i = 0, len = ref.length; i < len; i++) {
      method = ref[i];
      results.push(new SuggestionItem(method, methodSuggestor, {
        category: 'methods',
        canBeOptional: optional
      }));
    }
    return results;
  })());
};

resourceBasicSuggestor = new Suggestor([
  new SuggestionItem('description', noopSuggestor, {
    category: 'docs'
  }), new SuggestionItem('displayName', noopSuggestor, {
    category: 'docs'
  }), new SuggestionItem('securedBy', noopSuggestor, {
    category: 'security'
  }), new SuggestionItem('type', noopSuggestor, {
    category: 'traits and types'
  }), new SuggestionItem('is', noopSuggestor, {
    category: 'traits and types'
  })
]);

resourceFallback = function(key) {
  if (/^\//.test(key)) {
    return resourceSuggestor;
  }
};

dynamicResource = new SuggestionItem('<resource>', resourceSuggestor, {
  category: 'resources',
  dynamic: true
});

resourceSuggestor = new UnionSuggestor([
  resourceBasicSuggestor, makeMethodGroupSuggestor(), new Suggestor([
    new SuggestionItem('baseUriParameters', namedParameterGroupSuggestor, {
      category: 'parameters'
    }), new SuggestionItem('uriParameters', namedParameterGroupSuggestor, {
      category: 'parameters'
    }), dynamicResource
  ])
], resourceFallback);

traitAdditions = new Suggestor([
  new SuggestionItem('displayName', noopSuggestor, {
    category: 'docs'
  }), new SuggestionItem('usage', noopSuggestor, {
    category: 'docs'
  })
]);

traitSuggestor = new UnionSuggestor([traitAdditions, makeMethodSuggestor()]);

resourceTypeSuggestor = new UnionSuggestor([
  resourceBasicSuggestor, makeMethodGroupSuggestor(true), new Suggestor([
    new SuggestionItem('baseUriParameters', namedParameterGroupSuggestor, {
      category: 'parameters',
      canBeOptional: true
    }), new SuggestionItem('uriParameters', namedParameterGroupSuggestor, {
      category: 'parameters',
      canBeOptional: true
    }), new SuggestionItem('usage', noopSuggestor, {
      category: 'docs'
    })
  ])
]);

securitySchemesSettingSuggestor = new Suggestor([
  new SuggestionItem('accessTokenUri', noopSuggestor, {
    category: 'security'
  }), new SuggestionItem('authorizationGrants', noopSuggestor, {
    category: 'security'
  }), new SuggestionItem('authorizationUri', noopSuggestor, {
    category: 'security'
  }), new SuggestionItem('requestTokenUri', noopSuggestor, {
    category: 'security'
  }), new SuggestionItem('scopes', noopSuggestor, {
    category: 'security'
  }), new SuggestionItem('tokenCredentialsUri', noopSuggestor, {
    category: 'security'
  })
]);

securitySchemeTypeSuggestor = new Suggestor([
  new SuggestionItem('OAuth 1.0', noopSuggestor, {
    category: 'security'
  }), new SuggestionItem('OAuth 2.0', noopSuggestor, {
    category: 'security'
  }), new SuggestionItem('Basic Authentication', noopSuggestor, {
    category: 'security'
  }), new SuggestionItem('Digest Authentication', noopSuggestor, {
    category: 'security'
  })
]);

describedBySuggestor = new Suggestor([
  new SuggestionItem('headers', namedParameterGroupSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('queryParameters', namedParameterGroupSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('responses', responseGroupSuggestor, {
    category: 'responses'
  })
]);

securitySchemesSuggestor = new Suggestor([
  new SuggestionItem('description', noopSuggestor, {
    category: 'docs'
  }), new SuggestionItem('describedBy', describedBySuggestor, {
    category: 'security'
  }), new SuggestionItem('type', securitySchemeTypeSuggestor, {
    category: 'security'
  }), new SuggestionItem('settings', securitySchemesSettingSuggestor, {
    category: 'security'
  })
]);

traitGroupSuggestor = new EmptySuggestor(function() {
  return traitSuggestor;
});

resourceTypeGroupSuggestor = new EmptySuggestor(function() {
  return resourceTypeSuggestor;
});

securitySchemesGroupSuggestor = new EmptySuggestor(function() {
  return securitySchemesSuggestor;
});

rootDocumentationSuggestor = new Suggestor([
  new SuggestionItem('content', noopSuggestor, {
    category: 'docs'
  }), new SuggestionItem('title', noopSuggestor, {
    category: 'docs'
  })
], null, {
  isList: true
});

module.exports = {
  ApiDefinition: new Suggestor([
    new SuggestionItem('baseUriParameters', namedParameterGroupSuggestor, {
      category: 'parameters'
    }), new SuggestionItem('baseUri', noopSuggestor, {
      category: 'root'
    }), new SuggestionItem('mediaType', noopSuggestor, {
      category: 'root'
    }), new SuggestionItem('protocols', protocolsSuggestor, {
      category: 'root'
    }), new SuggestionItem('title', noopSuggestor, {
      category: 'root'
    }), new SuggestionItem('version', noopSuggestor, {
      category: 'root'
    }), new SuggestionItem('documentation', rootDocumentationSuggestor, {
      category: 'docs'
    }), new SuggestionItem('schemas', noopSuggestor, {
      category: 'schemas'
    }), new SuggestionItem('securedBy', noopSuggestor, {
      category: 'security'
    }), new SuggestionItem('securitySchemes', securitySchemesGroupSuggestor, {
      category: 'security'
    }), new SuggestionItem('resourceTypes', resourceTypeGroupSuggestor, {
      category: 'traits and types'
    }), new SuggestionItem('traits', traitGroupSuggestor, {
      category: 'traits and types'
    }), dynamicResource
  ], resourceFallback)
};


},{"./suggestorXX":4}],3:[function(require,module,exports){
var EmptySuggestor, SuggestionItem, Suggestor, UnionSuggestor, apiDefinitionSuggestor, describedBySuggestor, documentationItemSuggestor, dynamicResource, extensionSuggestor, librarySuggestor, makeMethodGroupSuggestor, makeMethodSuggestor, methodBodySuggestor, namedParameterGroupSuggestor, namedParameterSuggestor, noopSuggestor, overlaySuggestor, protocolsSuggestor, requestBodySuggestor, resourceBasicSuggestor, resourceFallback, resourceSuggestor, resourceTypeGroupSuggestor, resourceTypeSuggestor, responseBodyGroupSuggestor, responseBodyMimetypeSuggestor, responseGroupSuggestor, responseSuggestor, rootDocumentationSuggestor, securitySchemeTypeSuggestor, securitySchemesGroupSuggestor, securitySchemesSettingSuggestor, securitySchemesSuggestor, traitAdditions, traitGroupSuggestor, traitSuggestor, xmlSuggestor;

EmptySuggestor = require('./suggestorXX').EmptySuggestor;

SuggestionItem = require('./suggestorXX').SuggestionItem;

Suggestor = require('./suggestorXX').Suggestor;

UnionSuggestor = require('./suggestorXX').UnionSuggestor;

noopSuggestor = require('./suggestorXX').noopSuggestor;

xmlSuggestor = new Suggestor([
  new SuggestionItem('attribute', noopSuggestor, {
    category: 'docs'
  }), new SuggestionItem('name', noopSuggestor, {
    category: 'docs'
  }), new SuggestionItem('namespace', noopSuggestor, {
    category: 'docs'
  }), new SuggestionItem('prefix', noopSuggestor, {
    category: 'docs'
  }), new SuggestionItem('wrapped', noopSuggestor, {
    category: 'docs'
  })
]);

namedParameterSuggestor = new Suggestor([
  new SuggestionItem('description', noopSuggestor, {
    category: 'docs'
  }), new SuggestionItem('displayName', noopSuggestor, {
    category: 'docs'
  }), new SuggestionItem('example', noopSuggestor, {
    category: 'docs'
  }), new SuggestionItem('examples', noopSuggestor, {
    category: 'docs'
  }), new SuggestionItem('additionalProperties', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('default', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('discriminator', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('discriminatorValue', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('enum', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('facets', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('fileTypes', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('format', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('items', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('maximum', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('maxItems', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('maxLength', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('maxProperties', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('minimum', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('minItems', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('minLength', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('minProperties', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('multipleOf', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('pattern', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('properties', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('required', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('schema', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('type', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('uniqueItems', noopSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('xml', xmlSuggestor, {
    category: 'parameters'
  })
]);

namedParameterGroupSuggestor = new EmptySuggestor(function(key) {
  return namedParameterSuggestor;
});

responseBodyMimetypeSuggestor = new Suggestor([
  new SuggestionItem('schema', noopSuggestor, {
    category: 'schemas'
  }), new SuggestionItem('example', noopSuggestor, {
    category: 'docs'
  })
]);

responseBodyGroupSuggestor = new Suggestor([
  new SuggestionItem('application/json', responseBodyMimetypeSuggestor, {
    category: 'body'
  }), new SuggestionItem('application/x-www-form-urlencoded', responseBodyMimetypeSuggestor, {
    category: 'body'
  }), new SuggestionItem('application/xml', responseBodyMimetypeSuggestor, {
    category: 'body'
  }), new SuggestionItem('multipart/form-data', responseBodyMimetypeSuggestor, {
    category: 'body'
  })
]);

responseSuggestor = new Suggestor([
  new SuggestionItem('body', responseBodyGroupSuggestor, {
    category: 'responses'
  }), new SuggestionItem('description', noopSuggestor, {
    category: 'docs'
  })
]);

responseGroupSuggestor = new EmptySuggestor(function(key) {
  if (/\d{3}/.test(key)) {
    return responseSuggestor;
  }
});

requestBodySuggestor = new EmptySuggestor(function() {
  return namedParameterGroupSuggestor;
});

methodBodySuggestor = new Suggestor([
  new SuggestionItem('application/json', noopSuggestor, {
    category: 'body'
  }), new SuggestionItem('application/x-www-form-urlencoded', requestBodySuggestor, {
    category: 'body'
  }), new SuggestionItem('application/xml', noopSuggestor, {
    category: 'body'
  }), new SuggestionItem('multipart/form-data', requestBodySuggestor, {
    category: 'body'
  })
]);

protocolsSuggestor = new Suggestor([
  new SuggestionItem('HTTP', noopSuggestor, {
    isText: true
  }), new SuggestionItem('HTTPS', noopSuggestor, {
    isText: true
  })
], null, {
  isList: true
});

makeMethodSuggestor = function() {
  return new Suggestor([
    new SuggestionItem('description', noopSuggestor, {
      category: 'docs'
    }), new SuggestionItem('body', methodBodySuggestor, {
      category: 'body'
    }), new SuggestionItem('protocols', protocolsSuggestor, {
      category: 'root'
    }), new SuggestionItem('baseUriParameters', namedParameterGroupSuggestor, {
      category: 'parameters'
    }), new SuggestionItem('headers', namedParameterGroupSuggestor, {
      category: 'parameters'
    }), new SuggestionItem('queryParameters', namedParameterGroupSuggestor, {
      category: 'parameters'
    }), new SuggestionItem('responses', responseGroupSuggestor, {
      category: 'responses'
    }), new SuggestionItem('securedBy', noopSuggestor, {
      category: 'security'
    })
  ]);
};

makeMethodGroupSuggestor = function(optional) {
  var method, methodSuggestor;
  if (optional == null) {
    optional = false;
  }
  methodSuggestor = new UnionSuggestor([
    makeMethodSuggestor(), new Suggestor([
      new SuggestionItem('is', noopSuggestor, {
        category: 'traits and types'
      })
    ])
  ]);
  return new Suggestor((function() {
    var i, len, ref, results;
    ref = ['options', 'get', 'head', 'post', 'put', 'delete', 'trace', 'connect', 'patch'];
    results = [];
    for (i = 0, len = ref.length; i < len; i++) {
      method = ref[i];
      results.push(new SuggestionItem(method, methodSuggestor, {
        category: 'methods',
        canBeOptional: optional
      }));
    }
    return results;
  })());
};

resourceBasicSuggestor = new Suggestor([
  new SuggestionItem('description', noopSuggestor, {
    category: 'docs'
  }), new SuggestionItem('displayName', noopSuggestor, {
    category: 'docs'
  }), new SuggestionItem('securedBy', noopSuggestor, {
    category: 'security'
  }), new SuggestionItem('type', noopSuggestor, {
    category: 'traits and types'
  }), new SuggestionItem('is', noopSuggestor, {
    category: 'traits and types'
  })
]);

resourceFallback = function(key) {
  if (/^\//.test(key)) {
    return resourceSuggestor;
  }
};

dynamicResource = new SuggestionItem('<resource>', resourceSuggestor, {
  category: 'resources',
  dynamic: true
});

resourceSuggestor = new UnionSuggestor([
  resourceBasicSuggestor, makeMethodGroupSuggestor(), new Suggestor([
    new SuggestionItem('baseUriParameters', namedParameterGroupSuggestor, {
      category: 'parameters'
    }), new SuggestionItem('uriParameters', namedParameterGroupSuggestor, {
      category: 'parameters'
    }), dynamicResource
  ])
], resourceFallback);

traitAdditions = new Suggestor([
  new SuggestionItem('displayName', noopSuggestor, {
    category: 'docs'
  }), new SuggestionItem('usage', noopSuggestor, {
    category: 'docs'
  })
]);

traitSuggestor = new UnionSuggestor([traitAdditions, makeMethodSuggestor()]);

resourceTypeSuggestor = new UnionSuggestor([
  resourceBasicSuggestor, makeMethodGroupSuggestor(true), new Suggestor([
    new SuggestionItem('baseUriParameters', namedParameterGroupSuggestor, {
      category: 'parameters',
      canBeOptional: true
    }), new SuggestionItem('uriParameters', namedParameterGroupSuggestor, {
      category: 'parameters',
      canBeOptional: true
    }), new SuggestionItem('usage', noopSuggestor, {
      category: 'docs'
    })
  ])
]);

securitySchemesSettingSuggestor = new Suggestor([
  new SuggestionItem('accessTokenUri', noopSuggestor, {
    category: 'security'
  }), new SuggestionItem('authorizationGrants', noopSuggestor, {
    category: 'security'
  }), new SuggestionItem('authorizationUri', noopSuggestor, {
    category: 'security'
  }), new SuggestionItem('requestTokenUri', noopSuggestor, {
    category: 'security'
  }), new SuggestionItem('scopes', noopSuggestor, {
    category: 'security'
  }), new SuggestionItem('tokenCredentialsUri', noopSuggestor, {
    category: 'security'
  })
]);

securitySchemeTypeSuggestor = new Suggestor([
  new SuggestionItem('OAuth 1.0', noopSuggestor, {
    category: 'security'
  }), new SuggestionItem('OAuth 2.0', noopSuggestor, {
    category: 'security'
  }), new SuggestionItem('Basic Authentication', noopSuggestor, {
    category: 'security'
  }), new SuggestionItem('Digest Authentication', noopSuggestor, {
    category: 'security'
  })
]);

describedBySuggestor = new Suggestor([
  new SuggestionItem('headers', namedParameterGroupSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('queryParameters', namedParameterGroupSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('responses', responseGroupSuggestor, {
    category: 'responses'
  })
]);

securitySchemesSuggestor = new Suggestor([
  new SuggestionItem('description', noopSuggestor, {
    category: 'docs'
  }), new SuggestionItem('describedBy', describedBySuggestor, {
    category: 'security'
  }), new SuggestionItem('type', securitySchemeTypeSuggestor, {
    category: 'security'
  }), new SuggestionItem('settings', securitySchemesSettingSuggestor, {
    category: 'security'
  })
]);

traitGroupSuggestor = new EmptySuggestor(function() {
  return traitSuggestor;
});

resourceTypeGroupSuggestor = new EmptySuggestor(function() {
  return resourceTypeSuggestor;
});

securitySchemesGroupSuggestor = new EmptySuggestor(function() {
  return securitySchemesSuggestor;
});

documentationItemSuggestor = new Suggestor([
  new SuggestionItem('content', noopSuggestor, {
    category: 'docs'
  }), new SuggestionItem('title', noopSuggestor, {
    category: 'docs'
  })
]);

rootDocumentationSuggestor = new Suggestor([
  new SuggestionItem('content', noopSuggestor, {
    category: 'docs'
  }), new SuggestionItem('title', noopSuggestor, {
    category: 'docs'
  })
], null, {
  isList: true
});

apiDefinitionSuggestor = new Suggestor([
  new SuggestionItem('baseUri', noopSuggestor, {
    category: 'root'
  }), new SuggestionItem('baseUriParameters', namedParameterGroupSuggestor, {
    category: 'parameters'
  }), new SuggestionItem('documentation', rootDocumentationSuggestor, {
    category: 'docs'
  }), new SuggestionItem('mediaType', noopSuggestor, {
    category: 'root'
  }), new SuggestionItem('protocols', protocolsSuggestor, {
    category: 'root'
  }), new SuggestionItem('resourceTypes', resourceTypeGroupSuggestor, {
    category: 'traits and types'
  }), new SuggestionItem('schemas', noopSuggestor, {
    category: 'schemas'
  }), new SuggestionItem('securedBy', noopSuggestor, {
    category: 'security'
  }), new SuggestionItem('securitySchemes', securitySchemesGroupSuggestor, {
    category: 'security'
  }), new SuggestionItem('title', noopSuggestor, {
    category: 'root'
  }), new SuggestionItem('traits', traitGroupSuggestor, {
    category: 'traits and types'
  }), new SuggestionItem('types', namedParameterGroupSuggestor, {
    category: 'traits and types'
  }), new SuggestionItem('uses', noopSuggestor, {
    category: 'docs'
  }), new SuggestionItem('version', noopSuggestor, {
    category: 'root'
  }), dynamicResource
], resourceFallback);

librarySuggestor = new Suggestor([
  new SuggestionItem('resourceTypes', resourceTypeGroupSuggestor, {
    category: 'traits and types'
  }), new SuggestionItem('schemas', noopSuggestor, {
    category: 'schemas'
  }), new SuggestionItem('securitySchemes', securitySchemesGroupSuggestor, {
    category: 'security'
  }), new SuggestionItem('traits', traitGroupSuggestor, {
    category: 'traits and types'
  }), new SuggestionItem('types', namedParameterGroupSuggestor, {
    category: 'traits and types'
  }), new SuggestionItem('usage', noopSuggestor, {
    category: 'docs'
  }), new SuggestionItem('uses', noopSuggestor, {
    category: 'docs'
  })
]);

overlaySuggestor = new UnionSuggestor([
  apiDefinitionSuggestor, new Suggestor([
    new SuggestionItem('extends', noopSuggestor, {
      category: 'docs'
    })
  ])
]);

extensionSuggestor = new UnionSuggestor([
  apiDefinitionSuggestor, new Suggestor([
    new SuggestionItem('extends', noopSuggestor, {
      category: 'docs'
    })
  ])
]);

module.exports = {
  ApiDefinition: apiDefinitionSuggestor,
  DataType: namedParameterSuggestor,
  DocumentationItem: documentationItemSuggestor,
  Extension: extensionSuggestor,
  Library: librarySuggestor,
  Overlay: overlaySuggestor,
  ResourceType: resourceTypeSuggestor,
  SecurityScheme: securitySchemesSuggestor,
  Trait: traitSuggestor
};


},{"./suggestorXX":4}],4:[function(require,module,exports){
var EmptySuggestor, SuggestionItem, Suggestor, UnionSuggestor,
  extend = function(child, parent) { for (var key in parent) { if (hasProp.call(parent, key)) child[key] = parent[key]; } function ctor() { this.constructor = child; } ctor.prototype = parent.prototype; child.prototype = new ctor(); child.__super__ = parent.prototype; return child; },
  hasProp = {}.hasOwnProperty;

SuggestionItem = (function() {
  function SuggestionItem(key1, suggestor1, metadata) {
    this.key = key1;
    this.suggestor = suggestor1;
    this.metadata = metadata != null ? metadata : {};
  }

  SuggestionItem.prototype.matches = function(key) {
    return this.key === key || this.metadata.canBeOptional && this.key + '?' === key;
  };

  return SuggestionItem;

})();

Suggestor = (function() {
  function Suggestor(items, fallback1, metadata) {
    this.items = items;
    this.fallback = fallback1;
    this.metadata = metadata != null ? metadata : {};
    if (this.fallback == null) {
      this.fallback = function() {};
    }
  }

  Suggestor.prototype.suggestorFor = function(key) {
    var matchingItems;
    matchingItems = this.items.filter(function(item) {
      return item.matches(key);
    });
    if (matchingItems.length > 0) {
      return matchingItems[0].suggestor;
    } else {
      return this.fallback(key);
    }
  };

  Suggestor.prototype.suggestions = function() {
    var i, item, len, ref, suggestions;
    suggestions = {};
    ref = this.items;
    for (i = 0, len = ref.length; i < len; i++) {
      item = ref[i];
      suggestions[item.key] = {
        metadata: item.metadata
      };
    }
    return suggestions;
  };

  return Suggestor;

})();

EmptySuggestor = (function(superClass) {
  extend(EmptySuggestor, superClass);

  function EmptySuggestor(fallback) {
    EmptySuggestor.__super__.constructor.call(this, [], fallback);
  }

  return EmptySuggestor;

})(Suggestor);

UnionSuggestor = (function() {
  function UnionSuggestor(suggestors, fallback1) {
    this.suggestors = suggestors;
    this.fallback = fallback1;
    if (this.fallback == null) {
      this.fallback = function() {};
    }
  }

  UnionSuggestor.prototype.suggestorFor = function(key) {
    var i, len, ref, suggestor;
    ref = this.suggestors;
    for (i = 0, len = ref.length; i < len; i++) {
      suggestor = ref[i];
      if (suggestor = suggestor.suggestorFor(key)) {
        return suggestor;
      }
    }
    return this.fallback(key);
  };

  UnionSuggestor.prototype.suggestions = function() {
    var i, key, len, ref, suggestions, suggestor, suggestorSuggestions, value;
    suggestions = {};
    ref = this.suggestors;
    for (i = 0, len = ref.length; i < len; i++) {
      suggestor = ref[i];
      suggestorSuggestions = suggestor.suggestions();
      for (key in suggestorSuggestions) {
        value = suggestorSuggestions[key];
        suggestions[key] = value;
      }
    }
    return suggestions;
  };

  return UnionSuggestor;

})();

module.exports.SuggestionItem = SuggestionItem;

module.exports.Suggestor = Suggestor;

module.exports.EmptySuggestor = EmptySuggestor;

module.exports.UnionSuggestor = UnionSuggestor;

module.exports.noopSuggestor = new EmptySuggestor();


},{}]},{},[1])(1)
});
!function(e){if("object"==typeof exports&&"undefined"!=typeof module)module.exports=e();else if("function"==typeof define&&define.amd)define([],e);else{var f;"undefined"!=typeof window?f=window:"undefined"!=typeof global?f=global:"undefined"!=typeof self&&(f=self),f.ramlObjectToRaml=e()}}(function(){var define,module,exports;return (function e(t,n,r){function s(o,u){if(!n[o]){if(!t[o]){var a=typeof require=="function"&&require;if(!u&&a)return a(o,!0);if(i)return i(o,!0);var f=new Error("Cannot find module '"+o+"'");throw f.code="MODULE_NOT_FOUND",f}var l=n[o]={exports:{}};t[o][0].call(l.exports,function(e){var n=t[o][1][e];return s(n?n:e)},l,l.exports,e,t,n,r)}return n[o].exports}var i=typeof require=="function"&&require;for(var o=0;o<r.length;o++)s(r[o]);return s})({1:[function(require,module,exports){
var is = require('../utils/is');

/**
 * Sanitize documentation for RAML.
 *
 * @param  {Array} documentation
 * @return {Array}
 */
module.exports = function (documentation) {
  return documentation.filter(function (document) {
    return is.string(document.title) && is.string(document.content);
  }).map(function (document) {
    return {
      title:   document.title,
      content: document.content
    };
  });
};

},{"../utils/is":12}],2:[function(require,module,exports){
var extend                  = require('xtend/mutable');
var is                      = require('../utils/is');
var sanitizeSchemas         = require('./schemas');
var sanitizeParameters      = require('./parameters');
var sanitizeDocumentation   = require('./documentation');
var sanitizeSecuritySchemes = require('./security-schemes');
var sanitizeResources       = require('./resources');
var sanitizeResourceTypes   = require('./resource-types');
var sanitizeTraits          = require('./traits');

/**
 * Transform a RAML object into a YAML compatible structure.
 *
 * @param  {Object} input
 * @return {Object}
 */
module.exports = function (input) {
  var output = {};

  if (is.string(input.title)) {
    output.title = input.title;
  }

  if (is.string(input.version) || is.number(input.version)) {
    output.version = input.version;
  }

  if (is.string(input.mediaType)) {
    output.mediaType = input.mediaType;
  }

  if (is.string(input.baseUri)) {
    output.baseUri = input.baseUri;
  }

  if (is.object(input.baseUriParameters)) {
    output.baseUriParameters = sanitizeParameters(input.baseUriParameters);
  }

  if (is.array(input.documentation)) {
    output.documentation = sanitizeDocumentation(input.documentation);
  }

  if (is.array(input.securitySchemes)) {
    output.securitySchemes = sanitizeSecuritySchemes(input.securitySchemes);
  }

  if (is.array(input.schemas)) {
    output.schemas = sanitizeSchemas(input.schemas);
  }

  if (is.array(input.resourceTypes)) {
    output.resourceTypes = sanitizeResourceTypes(input.resourceTypes);
  }

  if (is.array(input.traits)) {
    output.traits = sanitizeTraits(input.traits);
  }

  if (is.array(input.resources)) {
    extend(output, sanitizeResources(input.resources));
  }

  return output;
};

},{"../utils/is":12,"./documentation":1,"./parameters":3,"./resource-types":4,"./resources":5,"./schemas":7,"./security-schemes":8,"./traits":10,"xtend/mutable":18}],3:[function(require,module,exports){
var extend = require('xtend/mutable');
var is     = require('../utils/is');

/**
 * Map of valid types.
 *
 * @type {Object}
 */
var TYPES = {
  string:  true,
  number:  true,
  integer: true,
  date:    true,
  boolean: true,
  file:    true
};

/**
 * Sanitize a single parameter representation.
 *
 * @param  {Object} param
 * @param  {String} key
 * @return {Object}
 */
var sanitizeParameter = function (param, key) {
  var obj = {};

  // Avoid unneccessary display names.
  if (is.string(param.displayName) && key !== param.displayName) {
    obj.displayName = param.displayName;
  }

  if (is.string(param.type) && TYPES.hasOwnProperty(param.type)) {
    obj.type = param.type;
  }

  if (is.string(param.description)) {
    obj.description = param.description;
  }

  if (is.array(param.enum)) {
    obj.enum = param.enum;
  }

  if (is.string(param.pattern)) {
    obj.pattern = param.pattern;
  }

  if (is.number(param.minLength)) {
    obj.minLength = param.minLength;
  }

  if (is.number(param.maxLength)) {
    obj.maxLength = param.maxLength;
  }

  if (is.number(param.minimum)) {
    obj.minimum = param.minimum;
  }

  if (is.number(param.maximum)) {
    obj.maximum = param.maximum;
  }

  if (param.example != null && is.primitive(param.example)) {
    obj.example = param.example;
  }

  if (param.default != null && is.primitive(param.default)) {
    obj.default = param.default;
  }

  if (is.boolean(param.repeat)) {
    obj.repeat = param.repeat;
  }

  if (is.boolean(param.required)) {
    obj.required = param.required;
  }

  return obj;
};

/**
 * Sanitize parameters and ensure the object structure is correct.
 *
 * @param  {Object} params
 * @return {Object}
 */
module.exports = function (params) {
  var obj = {};

  Object.keys(params).forEach(function (key) {
    var param = params[key];

    if (is.array(param)) {
      return obj[key] = param.map(sanitizeParameter);
    }

    obj[key] = sanitizeParameter(param, key);
  });

  return obj;
};

},{"../utils/is":12,"xtend/mutable":18}],4:[function(require,module,exports){
var is            = require('../utils/is');
var sanitizeTrait = require('./trait');

/**
 * Escape characters used inside a method name for the regexp.
 *
 * @param  {String} str
 * @return {String}
 */
var escape = function (str) {
  return str.replace(/([\-])/g, '\\$1');
};

/**
 * Check if the key is potentially a method name.
 *
 * @type {RegExp}
 */
var METHOD_KEY_REGEXP = /^(?:GET|HEAD|POST|PUT|PATCH|DELETE|OPTIONS)\??$/i;

/**
 * Sanitize resource types suitable for RAML.
 *
 * @param  {Array} resourceTypes
 * @return {Array}
 */
module.exports = function (resourceTypes) {
  var array = [];

  resourceTypes.forEach(function (resourceTypeMap) {
    Object.keys(resourceTypeMap).forEach(function (type) {
      var obj          = {};
      var child        = obj[type] = {};
      var resourceType = resourceTypeMap[type];

      Object.keys(resourceType).forEach(function (key) {
        var value = resourceType[key];
        var keys  = ['type', 'usage', 'description'];

        if (METHOD_KEY_REGEXP.test(key)) {
          child[key] = value == null ? value : sanitizeTrait(value);
        }

        // Allow usage and description strings alongside methods.
        if (~keys.indexOf(key) && is.string(value)) {
          child[key] = value;
        }
      });

      array.push(obj);
    });
  });

  return array;
};

},{"../utils/is":12,"./trait":9}],5:[function(require,module,exports){
var extend             = require('xtend/mutable');
var is                 = require('../utils/is');
var sanitizeTrait      = require('./trait');
var sanitizeParameters = require('./parameters');

/**
 * Sanitize a method into RAML structure for stringification.
 *
 * @param  {Object} method
 * @return {Object}
 */
var sanitizeMethods = function (methods) {
  var obj = {};

  methods.forEach(function (method) {
    var child = obj[method.method.toLowerCase()] = {};

    if (is.array(method.is)) {
      child.is = method.is;
    }

    extend(child, sanitizeTrait(method));
  });

  return obj;
};

/**
 * Sanitize the resources array to the correct RAML structure.
 *
 * @param  {Array}  resources
 * @return {Object}
 */
module.exports = function sanitizeResources (resources) {
  var obj = {};

  resources.forEach(function (resource) {
    var child = obj;

    if (resource.relativeUri) {
      child = obj[resource.relativeUri] = obj[resource.relativeUri] || {};
    }

    if (resource.uriParameters) {
      child.uriParameters = sanitizeParameters(resource.uriParameters);
    }

    if (is.string(resource.type) || is.object(resource.type)) {
      child.type = resource.type;
    }

    if (is.array(resource.methods)) {
      extend(child, sanitizeMethods(resource.methods));
    }

    if (is.array(resource.resources)) {
      extend(child, sanitizeResources(resource.resources));
    }
  });

  return obj;
};

},{"../utils/is":12,"./parameters":3,"./trait":9,"xtend/mutable":18}],6:[function(require,module,exports){
/**
 * Sanitize the responses object.
 *
 * @param  {Object} responses
 * @return {Object}
 */
module.exports = function (responses) {
  var obj = {};

  Object.keys(responses).forEach(function (code) {
    if (!/^\d{3}$/.test(code)) {
      return;
    }

    obj[code] = responses[code];
  });

  return obj;
};

},{}],7:[function(require,module,exports){
var is = require('../utils/is');

/**
 * Map the schemas array of objects into a standard array.
 *
 * @param  {Array} schemas
 * @return {Array}
 */
module.exports = function (schemas) {
  var array = [];

  // Iterate over the schema array and object and make it one schema per index.
  schemas.forEach(function (schemaMap) {
    Object.keys(schemaMap).forEach(function (key) {
      if (!is.string(schemaMap[key])) {
        return;
      }

      var obj = {};

      obj[key] = schemaMap[key];

      array.push(obj);
    });
  });

  return array;
};

},{"../utils/is":12}],8:[function(require,module,exports){
var is            = require('../utils/is');
var sanitizeTrait = require('./trait');

/**
 * Map of valid authentication types.
 *
 * @type {Object}
 */
var AUTH_TYPES = {
  'Basic Authentication':  true,
  'Digest Authentication': true,
  'OAuth 1.0':             true,
  'OAuth 2.0':             true
};

/**
 * Sanitize security schemes.
 *
 * @param  {Array} securitySchemes
 * @return {Array}
 */
module.exports = function (securitySchemes) {
  var array = [];

  securitySchemes.forEach(function (schemeMap) {
    Object.keys(schemeMap).forEach(function (key) {
      var scheme = schemeMap[key];

      if (!AUTH_TYPES[scheme.type] && !/^x-/i.test(scheme.type)) {
        return;
      }

      var obj  = {};
      var data = obj[key] = { type: scheme.type };

      if (is.string(scheme.description)) {
        data.description = scheme.description;
      }

      if (is.object(scheme.describedBy)) {
        data.describedBy = sanitizeTrait(scheme.describedBy);
      }

      if (is.object(scheme.settings)) {
        data.settings = scheme.settings;
      }

      array.push(obj);
    });
  });

  return array;
};

},{"../utils/is":12,"./trait":9}],9:[function(require,module,exports){
var is                 = require('../utils/is');
var sanitizeResponses  = require('./responses');
var sanitizeParameters = require('./parameters');

/**
 * Sanitize a trait-like object.
 *
 * @param  {Object} trait
 * @return {Object}
 */
module.exports = function (trait) {
  var obj = {};

  if (is.string(trait.usage)) {
    obj.usage = trait.usage;
  }

  if (is.string(trait.description)) {
    obj.description = trait.description;
  }

  if (is.object(trait.headers)) {
    obj.headers = sanitizeParameters(trait.headers);
  }

  if (is.object(trait.queryParameters)) {
    obj.queryParameters = sanitizeParameters(trait.queryParameters);
  }

  if (is.object(trait.body)) {
    obj.body = trait.body;
  }

  if (is.object(trait.responses)) {
    obj.responses = sanitizeResponses(trait.responses);
  }

  return obj;
};

},{"../utils/is":12,"./parameters":3,"./responses":6}],10:[function(require,module,exports){
var sanitizeTrait = require('./trait');

/**
 * Sanitize traits into an array of keyed maps.
 *
 * @param  {Array} traits
 * @return {Array}
 */
module.exports = function (traits) {
  var array = [];

  traits.forEach(function (traitMap) {
    Object.keys(traitMap).forEach(function (key) {
      var obj = {};

      obj[key] = sanitizeTrait(traitMap[key]);

      array.push(obj);
    });
  });

  return array;
};

},{"./trait":9}],11:[function(require,module,exports){
var extend   = require('xtend/mutable');
var indent   = require('indent-string');
var repeat   = require('repeat-string');
var length   = require('string-length');
var is       = require('./utils/is');
var toString = Function.prototype.call.bind(Object.prototype.toString);

/**
 * Map of characters to escape character sequences.
 *
 * Reference: https://github.com/nodeca/js-yaml/blob/7bbbb863c9c696311d149693a34f4dec20616cc2/lib/js-yaml/dumper.js#L39-L55
 *
 * @type {Object}
 */
var ESCAPE_SEQUENCES = {};

ESCAPE_SEQUENCES[0x00]   = '\\0';
ESCAPE_SEQUENCES[0x07]   = '\\a';
ESCAPE_SEQUENCES[0x08]   = '\\b';
ESCAPE_SEQUENCES[0x09]   = '\\t';
ESCAPE_SEQUENCES[0x0A]   = '\\n';
ESCAPE_SEQUENCES[0x0B]   = '\\v';
ESCAPE_SEQUENCES[0x0C]   = '\\f';
ESCAPE_SEQUENCES[0x0D]   = '\\r';
ESCAPE_SEQUENCES[0x1B]   = '\\e';
ESCAPE_SEQUENCES[0x22]   = '\\"';
ESCAPE_SEQUENCES[0x5C]   = '\\\\';
ESCAPE_SEQUENCES[0x85]   = '\\N';
ESCAPE_SEQUENCES[0xA0]   = '\\_';
ESCAPE_SEQUENCES[0x2028] = '\\L';
ESCAPE_SEQUENCES[0x2029] = '\\P';

/**
 * Quickly check wheter a character code needs to be quoted within a string.
 *
 * Reference: https://github.com/nodeca/js-yaml/blob/7bbbb863c9c696311d149693a34f4dec20616cc2/lib/js-yaml/dumper.js#L14-L36
 *
 * @type {Object}
 */
var QUOTED_CHARACTERS = {};

QUOTED_CHARACTERS[0x09] = true; /* Tab */
QUOTED_CHARACTERS[0x0A] = true; /* LF */
QUOTED_CHARACTERS[0x0D] = true; /* CR */
QUOTED_CHARACTERS[0x21] = true; /* ! */
QUOTED_CHARACTERS[0x22] = true; /* " */
QUOTED_CHARACTERS[0x23] = true; /* # */
QUOTED_CHARACTERS[0x25] = true; /* % */
QUOTED_CHARACTERS[0x26] = true; /* & */
QUOTED_CHARACTERS[0x27] = true; /* ' */
QUOTED_CHARACTERS[0x2A] = true; /* * */
// QUOTED_CHARACTERS[0x2C] = true; /* , */
// QUOTED_CHARACTERS[0x3A] = true; /* : */
QUOTED_CHARACTERS[0x3E] = true; /* > */
QUOTED_CHARACTERS[0x40] = true; /* @ */
QUOTED_CHARACTERS[0x5B] = true; /* [ */
QUOTED_CHARACTERS[0x5D] = true; /* ] */
QUOTED_CHARACTERS[0x60] = true; /* ` */
QUOTED_CHARACTERS[0x7B] = true; /* { */
QUOTED_CHARACTERS[0x7C] = true; /* | */
QUOTED_CHARACTERS[0x7D] = true; /* } */

/**
 * Check if numbers match the YAML number pattern.
 *
 * Reference: https://github.com/nodeca/js-yaml/blob/6030fa6c389aaf14545222f7fa27e86359ca3a3b/lib/js-yaml/type/float.js#L6-L11
 *
 * @type {RegExp}
 */
var NUMBER_REGEXP = new RegExp(
  '^(?:[-+]?(?:[0-9][0-9_]*)' +
  '|[-+]?(?:[0-9][0-9_]*)\\.[0-9_]*(?:[eE][-+][0-9]+)?' +
  '|\\.[0-9_]+(?:[eE][-+][0-9]+)?' +
  '|[-+]?[0-9][0-9_]*(?::[0-5]?[0-9])+\\.[0-9_]*' +
  '|[-+]?\\.(?:inf|Inf|INF)' +
  '|\\.(?:nan|NaN|NAN))$'
);

/**
 * Encode a character code in hex form.
 *
 * Reference: https://github.com/nodeca/js-yaml/blob/7bbbb863c9c696311d149693a34f4dec20616cc2/lib/js-yaml/dumper.js#L95-L114
 *
 * @param  {Number} charCode
 * @return {String}
 */
var encodeHex = function (charCode) {
  var string = charCode.toString(16).toUpperCase();
  var handle;
  var length;

  if (charCode <= 0xFF) {
    handle = 'x';
    length = 2;
  } else if (charCode <= 0xFFFF) {
    handle = 'u';
    length = 4;
  } else if (charCode <= 0xFFFFFFFF) {
    handle = 'U';
    length = 8;
  } else {
    throw new Error(
      'Character code within a string may not be greater than 0xFFFFFFFF'
    );
  }

  return '\\' + handle + repeat('0', length - string.length) + string;
};

/**
 * Return whether a character code needs to be escaped.
 *
 * @param  {Number}  charCode
 * @return {Boolean}
 */
var requiresEscape = function (charCode) {
  return ESCAPE_SEQUENCES[charCode] ||
    !((0x00020 <= charCode && charCode <= 0x00007E) ||
      (0x00085 === charCode)                        ||
      (0x000A0 <= charCode && charCode <= 0x00D7FF) ||
      (0x0E000 <= charCode && charCode <= 0x00FFFD) ||
      (0x10000 <= charCode && charCode <= 0x10FFFF));
};

/**
 * Check whether a string requires quotes in RAML.
 *
 * @param  {String}  str
 * @return {Boolean}
 */
var requiresQuotes = function (str) {
  // Empty strings require quotes.
  if (length(str) === 0) {
    return true;
  }

  // Check whether it's surrounded by spaces or starts with `-` or `?`.
  if (/^[ \-?]| $/.test(str) || NUMBER_REGEXP.test(str)) {
    return true;
  }

  for (var i = 0; i < str.length; i++) {
    var charCode = str.charCodeAt(i);

    if (requiresEscape(charCode)) {
      return true;
    }

    if (QUOTED_CHARACTERS[charCode]) {
      return true;
    }
  }

  return false;
};

/**
 * Escape a string to be wrapped in quotes.
 *
 * @param  {String} str
 * @return {String}
 */
var escapeString = function (str) {
  return str.split('').map(function (character) {
    var charCode = character.charCodeAt(0);

    if (requiresEscape(charCode)) {
      return ESCAPE_SEQUENCES[charCode] || escapeHex(charCode);
    }

    return character;
  }).join('');
};

/**
 * Wrap a string in quotes and escape.
 *
 * @param  {String} str
 * @return {String}
 */
var wrapString = function (str) {
  return '"' + escapeString(str) + '"';
};

/**
 * Stringify a string into RAML.
 *
 * @param  {String} str
 * @return {String}
 */
var stringifyString = function (str) {
  if (requiresQuotes(str)) {
    return wrapString(str);
  }

  return str;
};

/**
 * Check whether an inline RAML array can be rendered with the max length.
 *
 * @param  {Array}   array
 * @param  {Number}  length
 * @param  {Object}  opts
 * @return {Boolean}
 */
var arrayWithinLength = function (array, maxLength, opts) {
  // Empty arrays must always be true.
  if (!array.length) {
    return true;
  }

  // Surrounding brackets and every comma separator - "[ ... ]".
  var total = 4 + (array.length - 1) * 2;

  return array.every(function (value) {
    if (!is.primitive(value)) {
      return false;
    }

    total += length(stringify(value, 0, opts));

    return total < maxLength;
  });
};

/**
 * Stringify an array using the inline RAML format.
 *
 * @param  {Array}  array
 * @param  {Number} level
 * @param  {Object} opts
 * @return {String}
 */
var stringifyArrayInline = function (array, level, opts) {
  if (!array.length) {
    return '[]';
  }

  return '[ ' + array.map(function (value) {
    if (is.string(value) && value.indexOf(':') > -1) {
      return wrapString(value);
    }

    return stringify(value, level, opts);
  }).join(', ') + ' ]';
};

/**
 * Check whether a string fits within the designated width.
 *
 * @param  {String}  str
 * @param  {Number}  maxLength
 * @param  {Object}  opts
 * @return {Boolean}
 */
var stringWithinLength = function (str, maxLength, opts) {
  if (/\r?\n/.test(str)) {
    return false;
  }

  return length(stringifyString(str)) < maxLength;
};

/**
 * Stringify a string into RAML with support for multiple lines.
 *
 * @param  {String} str
 * @param  {Number} level
 * @param  {Object} opts
 * @return {String}
 */
var stringifyStringMultiLine = function (str, level, opts) {
  return indent(str, opts.indent, level);
};

/**
 * Generalized property stringification.
 *
 * @param  {String} prefix
 * @param  {*}      value
 * @param  {Number} level
 * @param  {Object} opts
 * @return {String}
 */
var stringifyProperty = function (prefix, value, level, opts) {
  var maxLength = opts.maxLength - length(prefix) - 1;

  // Empty values can stay empty in RAML.
  if (value == null) {
    return prefix;
  }

  // Check whether the array can fit using inline representation.
  if (is.array(value) && arrayWithinLength(value, maxLength, opts)) {
    return prefix + ' ' + stringifyArrayInline(value, level + 1, opts);
  }

  // Check whether strings should be on a single line.
  if (is.string(value) && !stringWithinLength(value, maxLength, opts)) {
    return prefix + ' |\n' + stringifyStringMultiLine(value, level + 1, opts);
  }

  // Inline object representation when empty.
  if (is.object(value) && !Object.keys(value).length) {
    return prefix + ' {}';
  }

  // All other primitives will fit inline.
  if (is.primitive(value)) {
    return prefix + ' ' + stringify(value, level + 1, opts);
  }

  return prefix + '\n' + stringify(value, level + 1, opts);
};

/**
 * Stringify an object property for RAML.
 *
 * @param  {String} key
 * @param  {*}      value
 * @param  {Number} level
 * @param  {Object} opts
 * @return {String}
 */
var stringifyObjectProperty = function (key, value, level, opts) {
  var prefix = repeat(opts.indent, level) + key + ':';

  return stringifyProperty(prefix, value, level, opts);
};

/**
 * Stringify an object for RAML.
 *
 * @param  {Object} obj
 * @param  {Number} level
 * @param  {Object} opts
 * @return {String}
 */
var stringifyObject = function (obj, level, opts) {
  var keys = Object.keys(obj);

  return keys.map(function (key) {
    return stringifyObjectProperty(key, obj[key], level, opts);
  }).join('\n');
};

/**
 * Stringify an array property for RAML.
 *
 * @param  {*}      value
 * @param  {Number} level
 * @param  {Object} opts
 * @return {String}
 */
var stringifyArrayProperty = function (value, level, opts) {
  var prefix = repeat(opts.indent, level) + '-';

  // Represent objects inline with the array token. E.g. "- schema: test".
  if (is.object(value)) {
    return prefix + ' ' + stringify(value, level + 1, opts).replace(/^ +/, '');
  }

  if (is.string(value) && value.indexOf(':') > -1) {
    return prefix + ' ' + wrapString(value);
  }

  return stringifyProperty(prefix, value, level, opts);
};

/**
 * Stringify an array for RAML.
 *
 * @param  {Array}  array
 * @param  {Number} level
 * @param  {Object} opts
 * @return {String}
 */
var stringifyArray = function (array, level, opts) {
  return array.map(function (value) {
    return stringifyArrayProperty(value, level, opts);
  }).join('\n');
};

/**
 * Map of types to stringify.
 *
 * @type {Object}
 */
var TYPES = {
  '[object String]':  stringifyString,
  '[object Object]':  stringifyObject,
  '[object Array]':   stringifyArray,
  '[object Number]':  String,
  '[object Boolean]': String
};

/**
 * Stringify any JavaScript type.
 *
 * @param  {*}      input
 * @param  {Number} level
 * @param  {Object} opts
 * @return {String}
 */
var stringify = function (input, level, opts) {
  var type = toString(input);

  if (!TYPES[type]) {
    return '';
  }

  return TYPES[type](input, level, opts);
};

/**
 * Stringify JavaScript to a YAML (RAML) string.
 *
 * @param  {*}      input
 * @param  {Number} level
 * @param  {Object} opts
 * @return {String}
 */
module.exports = function (input, opts) {
  return stringify(input, 0, extend({
    indent:    '  ',
    maxLength: 80
  }, opts));
};

},{"./utils/is":12,"indent-string":13,"repeat-string":14,"string-length":15,"xtend/mutable":18}],12:[function(require,module,exports){
var is        = exports;
var _toString = Object.prototype.toString;

[
  'String',
  'Number',
  'Boolean',
  'RegExp',
  'Object',
  'Array',
  'Function',
  'Null',
  'Undefined'
].forEach(function (instance) {
  var name = instance.charAt(0).toLowerCase() + instance.substr(1);
  var type = '[object ' + instance + ']';

  is[name] = function (value) {
    return _toString.call(value) === type;
  };
});

/**
 * Map of primitive types.
 *
 * @type {Object}
 */
var PRIMITIVES = {
  '[object Number]':    true,
  '[object String]':    true,
  '[object Boolean]':   true,
  '[object Null]':      true,
  '[object Undefined]': true
};

/**
 * Check whether a value is a primitive JavaScript type.
 *
 * @param  {*}       value
 * @return {Boolean}
 */
is.primitive = function (value) {
  return !!PRIMITIVES[_toString.call(value)];
}

},{}],13:[function(require,module,exports){
'use strict';
var repeatString = require('repeat-string');

module.exports = function (str, indent, count) {
	if (typeof str !== 'string' || typeof indent !== 'string') {
		throw new TypeError('`string` and `indent` should be strings');
	}

	if (count != null && typeof count !== 'number') {
		throw new TypeError('`count` should be a number');
	}

	indent = count > 1 ? repeatString(indent, count) : indent;

	return str.replace(/^(?!\s*$)/mg, indent);
};

},{"repeat-string":14}],14:[function(require,module,exports){
module.exports = function(str, count) {
  if (count < 1) {
    return '';
  }

  var result = '';
  while (count > 0) {
    if (count & 1) {
      result += str;
    }
    count >>= 1;
    str += str;
  }
  return result;
}

},{}],15:[function(require,module,exports){
'use strict';
var stripAnsi = require('strip-ansi');
var reAstral = /[\uD800-\uDBFF][\uDC00-\uDFFF]/g;

module.exports = function (str) {
	return stripAnsi(str).replace(reAstral, ' ').length;
};

},{"strip-ansi":16}],16:[function(require,module,exports){
'use strict';
var ansiRegex = require('ansi-regex')();

module.exports = function (str) {
	return typeof str === 'string' ? str.replace(ansiRegex, '') : str;
};

},{"ansi-regex":17}],17:[function(require,module,exports){
'use strict';
module.exports = function () {
	return /(?:(?:\u001b\[)|\u009b)(?:(?:[0-9]{1,3})?(?:(?:;[0-9]{0,3})*)?[A-M|f-m])|\u001b[A-M]/g;
};

},{}],18:[function(require,module,exports){
module.exports = extend

function extend(target) {
    for (var i = 1; i < arguments.length; i++) {
        var source = arguments[i]

        for (var key in source) {
            if (source.hasOwnProperty(key)) {
                target[key] = source[key]
            }
        }
    }

    return target
}

},{}],19:[function(require,module,exports){
var sanitize  = require('./lib/sanitize');
var stringify = require('./lib/stringify');

/**
 * Transform a RAML object into a RAML string.
 *
 * @param  {Object} obj
 * @return {String}
 */
module.exports = function (obj) {
  return '#%RAML 0.8\n' + stringify(sanitize(obj));
};

},{"./lib/sanitize":2,"./lib/stringify":11}]},{},[19])(19)
});
!function(e){if("object"==typeof exports&&"undefined"!=typeof module)module.exports=e();else if("function"==typeof define&&define.amd)define([],e);else{var f;"undefined"!=typeof window?f=window:"undefined"!=typeof global?f=global:"undefined"!=typeof self&&(f=self),f.swaggerToRamlObject=e()}}(function(){var define,module,exports;return (function e(t,n,r){function s(o,u){if(!n[o]){if(!t[o]){var a=typeof require=="function"&&require;if(!u&&a)return a(o,!0);if(i)return i(o,!0);var f=new Error("Cannot find module '"+o+"'");throw f.code="MODULE_NOT_FOUND",f}var l=n[o]={exports:{}};t[o][0].call(l.exports,function(e){var n=t[o][1][e];return s(n?n:e)},l,l.exports,e,t,n,r)}return n[o].exports}var i=typeof require=="function"&&require;for(var o=0;o<r.length;o++)s(r[o]);return s})({1:[function(require,module,exports){
var extend         = require('extend');
var camelCase      = require('camel-case');
var getVersion     = require('./utils/version');
var compareVersion = require('./utils/version-equal');

/**
 * Map of valid param types to raml types.
 *
 * @type {Object}
 */
var PARAM_TYPE_MAP = {
  string:  { type: 'string' },
  number:  { type: 'number' },
  integer: { type: 'integer' },
  boolean: { type: 'boolean' },
  File:    { type: 'file' },
  array:   { repeat: true }
};

/**
 * Map of valid param types to json schema types.
 *
 * @type {Object}
 */
var JSON_TYPE_MAP = {
  string:  { type: 'string' },
  number:  { type: 'number' },
  integer: { type: 'integer' },
  boolean: { type: 'boolean' },
  array:   { type: 'array' },
  object:  { type: 'object' }
};

/**
 * Map of valid formats to their properties.
 *
 * @type {Object}
 */
var PARAM_FORMAT_MAP = {
  int32: {
    type: 'integer',
    minimum: -2147483648,
    maximum: 2147483647
  },
  int64: {
    type: 'integer',
    minimum: -9223372036854775808,
    maximum: 9223372036854775807
  },
  date: {
    type: 'date'
  },
  'date-time': {
    type: 'date'
  }
};

/**
 * Url-encoded form content type.
 *
 * @type {String}
 */
var URL_ENCODED_MIME = 'application/x-www-form-urlencoded';

/**
 * Content type for multipart form uploads.
 *
 * @type {String}
 */
var MULTI_PART_MIME = 'multipart/form-data';

/**
 * Location of the spec on api declarations.
 *
 * @type {String}
 */
var API_SPEC_URI = 'https://github.com/wordnik/swagger-spec' +
  '/blob/master/versions/1.2.md#52-api-declaration';

/**
 * Expose the converter function.
 */
module.exports = convertApiDeclaration;

/**
 * Convert an api declaration into RAML.
 *
 * @param  {Object} declaration
 * @param  {Object} ramlObject
 * @return {Object}
 */
function convertApiDeclaration (declaration, ramlObject) {
  var version = getVersion(declaration);

  if (version >= 2) {
    throw new Error('Swagger ' + version.toFixed(1) + ' is not supported');
  }

  // Verify the api declaration is valid.
  if (!declaration.basePath || !declaration.apis) {
    throw new Error('Must be a valid api declaration: ' + API_SPEC_URI);
  }

  ramlObject = ramlObject || {};

  // Check if the api version is still the same.
  if (!compareVersion(declaration.apiVersion, ramlObject.version)) {
    throw new Error(
      'The api version has changed: ' +
      ramlObject.version + ' -> ' + declaration.apiVersion
    );
  } else if (!ramlObject.version) {
    ramlObject.version = declaration.apiVersion;
  }

  addBasePath(declaration.basePath, ramlObject);
  convertApis(declaration, ramlObject);

  return ramlObject;
}

/**
 * Set the base path from the api declaration on the raml object.
 *
 * @param  {String} basePath
 * @param  {Object} ramlObject
 * @return {Object}
 */
function addBasePath (basePath, ramlObject) {
  // If a base uri has not been set yet, set it here.
  if (!ramlObject.baseUri) {
    ramlObject.baseUri = basePath;

    return ramlObject;
  }

  // If the base path changes for some reason, throw an error. In the future,
  // we may want to refactor the resource tree with new prefixes.
  if (ramlObject.baseUri !== basePath) {
    throw new Error(
      'The base uri has changed: ' + ramlObject.baseUri + ' -> ' + basePath
    );
  }

  return ramlObject;
}

/**
 * Convert an array of apis into a raml resource.
 *
 * @param  {Object} declaration
 * @param  {Object} ramlObject
 * @return {Object}
 */
function convertApis (declaration, ramlObject) {
  var relativeUri   = declaration.resourcePath;
  var ramlResources = ramlObject.resources = ramlObject.resources || [];
  var ramlResource  = findResource(ramlResources, relativeUri);

  declaration.apis.forEach(function (api) {
    var path     = api.path;
    var resource = ramlResource;

    // I assume this will always occur based on the Swagger specs I've seen.
    if (path.substr(0, relativeUri.length) === relativeUri) {
      path = path.substr(relativeUri.length);

      // If no raml resource exists, create it.
      if (!ramlResource) {
        resource = ramlResource = { relativeUri: relativeUri };

        ramlResources.push(resource);
      }

      // Only create a new subresource when the path has changed.
      if (path !== '') {
        resource = { relativeUri: path };

        ramlResource.resources = ramlResource.resources || [];
        ramlResource.resources.push(resource);
      }
    } else {
      ramlResources.push(resource = {
        relativeUri: path
      });
    }

    // Alias the api description onto the new raml resource.
    if (api.description) {
      resource.description = api.description;
    }

    return convertOperations(api.operations, declaration, resource);
  });

  return ramlResource;
}

/**
 * Find a resource by uri in an array of resources.
 *
 * @param  {Array}  resources
 * @param  {String} uri
 * @return {Object}
 */
function findResource (resources, uri) {
  var matchingResource;

  resources.some(function (resource) {
    if (resource.relativeUri === uri) {
      matchingResource = resource;

      return true;
    }
  });

  return matchingResource;
}

/**
 * Convert an array of swagger operations for a raml resource.
 *
 * @param  {Object} operations
 * @param  {Object} declaration
 * @param  {Object} ramlResource
 * @return {Object}
 */
function convertOperations (operations, declaration, ramlResource) {
  ramlResource.methods = ramlResource.methods || [];

  operations.forEach(function (operation) {
    if (!operation.method) {
      throw new Error('Expected the operation to have a method defined');
    }

    // Initialise the method object. This assumes the same method name has not
    // already been used.
    var method = {
      method: operation.method
    };

    if (operation.nickname) {
      method.displayName = operation.nickname;
    }

    if (operation.notes || operation.summary) {
      method.description = operation.notes || operation.summary;
    }

    if (operation.deprecated === 'true' || operation.deprecated === true) {
      if (!method.description) {
        method.description = '';
      } else {
        method.description += '\n\n';
      }

      method.description += 'This method has been deprecated.';
    }

    convertParameters(operation, declaration, method, ramlResource);
    convertResponseMessages(operation, declaration, method);

    ramlResource.methods.push(method);
  });

  return ramlResource;
}

/**
 * Convert response messages into the raml object.
 *
 * @param  {Object} operation
 * @param  {Object} declaration
 * @param  {Object} method
 * @return {Object}
 */
function convertResponseMessages (operation, declaration, method) {
  if (!operation.responseMessages || !operation.responseMessages.length) {
    return method;
  }

  // Initialise the responses object.
  var responses = method.responses = method.responses || {};
  var produces  = operation.produces || declaration.produces || [];

  // Alias all response messages.
  operation.responseMessages.forEach(function (response) {
    responses[response.code] = { description: response.message };

    // Adds the produces mime types to the reponses object.
    if (produces.length) {
      responses[response.code].body = {};

      produces.forEach(function (mime) {
        if (response.responseModel && CONVERT_MODEL_TO_SCHEMA[mime]) {
          responses[response.code].body[mime] = {
            schema: CONVERT_MODEL_TO_SCHEMA[mime](
              response.responseModel, declaration
            )
          };

          return;
        }

        responses[response.code].body[mime] = null;
      });
    }
  });

  return method;
}

/**
 * Checks whether a uri parameter is valid.
 *
 * @param  {String}  name
 * @return {Boolean}
 */
function isValidUriParameterName (name) {
  return /^(?:[\w\.]|%\d{2})*$/.test(name);
}

/**
 * Correct resource uri parameters to be valid.
 *
 * @param  {Object} ramlResource
 * @return {Object}
 */
function sanitizeUriParameterNames (ramlResource) {
  /**
   * Replace uri parameters with valid names.
   *
   * @param  {String} match
   * @param  {String} name
   * @return {String}
   */
  function replaceParameters (match, name) {
    if (isValidUriParameterName(name)) {
      return match;
    }

    // Camelize invalid parameter names. Purely stylistic over the
    // alternative of using percent-encoding.
    var updatedName = camelCase(name);
    var uriParameters = ramlResource.uriParameters;

    // Move the uri parameter definition.
    if (uriParameters[name]) {
      uriParameters[updatedName] = uriParameters[name];
      delete uriParameters[name];
    }

    return '{' + updatedName + '}';
  }

  ramlResource.relativeUri = ramlResource.relativeUri
    .replace(/\{([^\}]+)\}/g, replaceParameters);

  return ramlResource;
}

/**
 * Convert swagger operation parameters for a raml method.
 *
 * @param  {Array}  operation
 * @param  {Object} declaration
 * @param  {Object} ramlMethod
 * @param  {Object} ramlResource
 * @return {Object}
 */
function convertParameters (operation, declaration, ramlMethod, ramlResource) {
  var consumes   = operation.consumes || declaration.consumes || [];
  var parameters = groupParameters(operation.parameters);

  // Path parameters are more applicable to the resource than the method.
  if (parameters.path) {
    ramlResource.uriParameters = convertParametersToRaml(
      parameters.path, declaration
    );

    sanitizeUriParameterNames(ramlResource);
  }

  // Add query parameters to the current method.
  if (parameters.query) {
    ramlMethod.queryParameters = convertParametersToRaml(
      parameters.query, declaration
    );
  }

  // Add headers to the current method.
  if (parameters.header) {
    ramlMethod.headers = convertParametersToRaml(
      parameters.header, declaration
    );
  }

  // Convert the body parameters before attempting the form.
  if (parameters.body) {
    convertBodyParameters(parameters.body, consumes, declaration, ramlMethod);
  }

  // Convert the form parameter into something that works better
  if (parameters.form) {
    convertFormParameters(parameters.form, consumes, declaration, ramlMethod);
  }

  return ramlMethod;
}

/**
 * Map of parameter mime types to conversion functions.
 *
 * @type {Object}
 */
var CONVERT_PARAMS_TO_SCHEMA = {
  'application/xml':  null, // convertParameterToXmlSchema
  'application/json': convertParameterToJsonSchema
};

/**
 * Map of model mime types to conversion functions.
 *
 * @type {Object}
 */
var CONVERT_MODEL_TO_SCHEMA = {
  'application/xml':  null, // convertParameterToXmlSchema
  'application/json': convertModelToJsonSchema
};

/**
 * Convert body parameters inline into raml schemas.
 *
 * @param  {Array}  params
 * @param  {Array}  consumes
 * @param  {Object} declaration
 * @param  {Object} ramlMethod
 * @return {Object}
 */
function convertBodyParameters (params, consumes, declaration, ramlMethod) {
  ramlMethod.body = ramlMethod.body || {};

  if (params.length > 1) {
    throw new Error('Found ' + param.length + ' parameters for body type');
  }

  // Iterate over the consumes object and convert known types.
  params.forEach(function (param) {
    consumes.forEach(function (mime) {
      if (CONVERT_PARAMS_TO_SCHEMA[mime]) {
        return ramlMethod.body[mime] = {
          schema: CONVERT_PARAMS_TO_SCHEMA[mime](param, declaration)
        };
      }

      ramlMethod.body[mime] = null;
    });
  });

  return ramlMethod;
}

/**
 * Convert form parameters inline and mutate the raml method.
 *
 * @param  {Array}  params
 * @param  {Array}  consumes
 * @param  {Object} declaration
 * @param  {Object} ramlMethod
 * @return {Object}
 */
function convertFormParameters (params, consumes, declaration, ramlMethod) {
  var multiPart  = consumes.indexOf(MULTI_PART_MIME) > -1;
  var urlEncoded = consumes.indexOf(URL_ENCODED_MIME) > -1;
  var ramlParams = convertParametersToRaml(params, declaration);

  // Enforce multipart if the parameters contain a file type.
  if (!multiPart) {
    multiPart = params.some(function (param) {
      return param.type === 'File';
    });
  }

  // Initialise the body to an object, if it hasn't already been.
  ramlMethod.body = ramlMethod.body || {};

  // Alias the object based on the consumes type.
  if (multiPart && urlEncoded) {
    ramlMethod.body[MULTI_PART_MIME] = { formParameters: ramlParams };
    ramlMethod.body[URL_ENCODED_MIME] = { formParameters: ramlParams };
  } else if (multiPart) {
    ramlMethod.body[MULTI_PART_MIME] = { formParameters: ramlParams };
  } else {
    ramlMethod.body[URL_ENCODED_MIME] = { formParameters: ramlParams };
  }

  return ramlMethod;
}

/**
 * Group parameters by types.
 *
 * @param  {Array}  parameters
 * @return {Object}
 */
function groupParameters (parameters) {
  var groups = {};

  Object.keys(parameters).forEach(function (key) {
    var parameter = parameters[key];
    var type      = parameter.paramType;
    var group     = groups[type] = groups[type] || [];

    group.push(parameter);
  });

  return groups;
}

/**
 * Convert an array of swagger parameters to the resource path.
 *
 * @param  {Array}  params
 * @param  {Object} declaration
 * @return {Object}
 */
function convertParametersToRaml (params, declaration) {
  var ramlParams = {};

  params.forEach(function (param) {
    ramlParams[param.name] = convertParameter(param, declaration);
  });

  return ramlParams;
}

/**
 * Convert a single parameter to raml style.
 *
 * @param  {Object} param
 * @param  {Object} declaration
 * @return {Object}
 */
function convertParameter (param, declaration) {
  var ramlParameter = {};

  // Extend the parameter information based on the type.
  if (param.type && PARAM_TYPE_MAP[param.type]) {
    extend(ramlParameter, PARAM_TYPE_MAP[param.type]);
  } else {
    // TODO: Handle params with `.type` or `.$ref` models.
  }

  // Extend the parameter with defaults set by the format.
  if (PARAM_FORMAT_MAP[param.format]) {
    extend(ramlParameter, PARAM_FORMAT_MAP[param.format]);
  }

  if (typeof param.description === 'string') {
    ramlParameter.description = param.description;
  }

  if (typeof param.required === 'boolean') {
    ramlParameter.required = param.required;
  }

  if (param.defaultValue) {
    ramlParameter.default = param.defaultValue;
  }

  if (Array.isArray(param.enum)) {
    ramlParameter.enum = param.enum;
  }

  if (typeof param.minimum === 'number') {
    ramlParameter.minimum = param.minimum;
  }

  if (typeof param.maximum === 'number') {
    ramlParameter.maximum = param.maximum;
  }

  return ramlParameter;
}

/**
 * Convert a model to a JSON schema object.
 *
 * @param  {String} name
 * @param  {Object} declaration
 * @return {Object}
 */
function convertModelToJson (name, declaration) {
  var schema = {};
  var model  = declaration.models[name];

  // Unfortunately, it is possible that the model has not been documented.
  if (!model) {
    return;
  }

  // Find potential parent models.
  Object.keys(declaration.models).some(function (key) {
    var model = declaration.models[key];

    if (!model || !model.subTypes || !model.subTypes.indexOf(name)) {
      return false;
    }

    // Find and compile the parent schema.
    var parentSchema = convertParameterToJson(key, declaration);

    extend(schema, parentSchema);
    schema.properties = extend({}, parentSchema.properties);

    return true;
  });

  // Compile child properties into expected objects.
  Object.keys(model.properties || {}).forEach(function (key) {
    var property   = model.properties[key];
    var properties = schema.properties = schema.properties || {};

    properties[key] = convertParameterToJson(property, declaration);
  });

  return schema;
}

/**
 * Convert a parameter into JSON schema object.
 *
 * @param  {Object} param
 * @param  {Object} declaration
 * @return {Object}
 */
function convertParameterToJson (param, declaration) {
  var schema = {};

  if (param.type && JSON_TYPE_MAP[param.type]) {
    extend(schema, JSON_TYPE_MAP[param.type]);
  } else if (param.$ref || param.type) {
    // Extend the current schema with model meta data.
    extend(schema, convertModelToJson(param.$ref || param.type, declaration));
  }

  // Iterate over the allowed JSON schema properties in Swagger and set.
  [
    'description',
    'defaultValue',
    'enum',
    'minimum',
    'maximum',
    'items',
    'required',
    'uniqueItems'
  ].forEach(function (key) {
    if (param[key] == null) {
      return;
    }

    // Handle sub-items different and convert the types.
    if (key === 'items') {
      return schema[key] = convertParameterToJson(param[key], declaration);
    }

    schema[key] = param[key];
  });

  return schema;
}

/**
 * Convert a parameter to JSON.
 *
 * @param  {Object} param
 * @param  {Object} declaration
 * @return {String}
 */
function convertParameterToJsonSchema (param, declaration) {
  var schema = extend({
    $schema: 'http://json-schema.org/draft-04/schema#'
  }, convertParameterToJson(param, declaration));

  return JSON.stringify(schema, null, 2);
}

/**
 * Convert a model to JSON.
 *
 * @param  {String} name
 * @param  {Object} declaration
 * @return {String}
 */
function convertModelToJsonSchema (name, declaration) {
  var schema = extend({
    $schema: 'http://json-schema.org/draft-04/schema#'
  }, convertModelToJson(name, declaration));

  return JSON.stringify(schema, null, 2);
}

},{"./utils/version":7,"./utils/version-equal":6,"camel-case":8,"extend":13}],2:[function(require,module,exports){
/**
 * Expose the parse module.
 */
module.exports = parse;

/**
 * Parse the content based on the file name.
 *
 * @param  {String} content
 * @return {Object}
 */
function parse (content) {
  var result = JSON.parse(content);

  if (!result.swaggerVersion) {
    throw new Error('Swagger version is required');
  }

  return result;
}

},{}],3:[function(require,module,exports){
var getVersion = require('./utils/version');

/**
 * Map swagger documentation keys into title-cased strings.
 *
 * @type {Object}
 */
var DOCUMENTATION_NAME_MAP = {
  description:       'Description',
  termsOfServiceUrl: 'Terms of Service URL',
  contact:           'Contact',
  license:           'License',
  licenseUrl:        'License URL'
};

/**
 * Map of Swagger OAuth 2.0 grant types to the RAML equivalents.
 *
 * @type {Object}
 */
var GRANT_TYPE_MAP = {
  implicit:           'token',
  authorization_code: 'code'
};

/**
 * Map of ways to pass API keys in Swagger to RAML properties.
 * @type {Object}
 */
var API_KEY_PASS_AS_MAP = {
  header: 'headers',
  query:  'queryParameters'
};

/**
 * Location of the swagger spec on resource listings.
 *
 * @type {String}
 */
var RESOURCE_SPEC_URI = 'https://github.com/wordnik/swagger-spec' +
  '/blob/master/versions/1.2.md#51-resource-listing';

/**
 * Expose the converter.
 */
module.exports = convertResourceListing;

/**
 * Convert a resource listing into a base raml object.
 *
 * @param  {Object} resource
 * @param  {Object} ramlObject
 * @return {Object}
 */
function convertResourceListing (resource, ramlObject) {
  var version = getVersion(resource);

  if (version >= 2) {
    throw new Error('Swagger ' + version.toFixed(1) + ' is not supported');
  }

  if (!resource.apis) {
    throw new Error('Must be a valid resource listing: ' + RESOURCE_SPEC_URI);
  }

  ramlObject = ramlObject || {};

  if (resource.apiVersion) {
    ramlObject.version = resource.apiVersion;
  }

  convertInfo(resource.info, ramlObject);
  convertAuthorizations(resource.authorizations, ramlObject);

  return ramlObject;
}

/**
 * Attach information from the swagger spec to the raml object.
 *
 * @param  {Object} info
 * @param  {Object} ramlObject
 * @return {Object}
 */
function convertInfo (info, ramlObject) {
  if (!info) {
    return ramlObject;
  }

  var documentation = Object.keys(DOCUMENTATION_NAME_MAP)
    .filter(function (key) {
      return info[key];
    })
    .map(function (key) {
      return {
        title:   DOCUMENTATION_NAME_MAP[key],
        content: info[key]
      };
    });

  if (info.title) {
    ramlObject.title = info.title;
  }

  if (documentation.length) {
    ramlObject.documentation = documentation;
  }

  return ramlObject;
}

/**
 * Convert swagger authorizations into raml object format.
 *
 * @param  {Object} authorizations
 * @param  {Object} ramlObject
 * @return {Object}
 */
function convertAuthorizations (authorizations, ramlObject) {
  if (!authorizations) {
    return ramlObject;
  }

  ramlObject.securitySchemes = Object.keys(authorizations)
    .map(function (key) {
      var data = {};

      data[key] = convertAuthorization(authorizations[key]);

      return data;
    });

  return ramlObject;
}

/**
 * Convert a single swagger authorization object into something compatible
 * with raml.
 *
 * @param  {Object} authorization
 * @return {Object}
 */
function convertAuthorization (authorization) {
  if (authorization.type === 'oauth2') {
    return convertOAuth2(authorization);
  }

  if (authorization.type === 'apiKey') {
    return convertApiKey(authorization);
  }

  if (authorization.type === 'basicAuth') {
    return convertBasicAuth(authorization);
  }
}

/**
 * Convert the OAuth 2.0 authorization from swagger into raml object.
 *
 * @param  {Object} authorization
 * @return {Object}
 */
function convertOAuth2 (authorization) {
  var ramlAuth = {
    type: 'OAuth 2.0',
    settings: {
      authorizationGrants: []
    }
  };

  var implicit     = authorization.grantTypes.implicit;
  var authCode     = authorization.grantTypes.authorization_code;
  var description  = [];
  var authSettings = ramlAuth.settings;

  // Map scopes to the RAML object.
  if (authorization.scopes && authorization.scopes.length) {
    var scopeDescriptions = [];

    authSettings.scopes = authorization.scopes.map(function (scope) {
      var name = scope.scope;

      if (scope.description) {
        scopeDescriptions.push('* ' + name + ' - ' + scope.description);
      }

      return name;
    });

    // Push the scope descriptions onto the primary description.
    if (scopeDescriptions.length) {
      description.push('Available scopes: ');
      description.push(scopeDescriptions.join('\n'));
    }
  }

  // Map grant types into the raml object.
  Object.keys(authorization.grantTypes).forEach(function (grantType) {
    authSettings.authorizationGrants.push(GRANT_TYPE_MAP[grantType]);
  });

  if (implicit) {
    if (implicit.loginEndpoint && implicit.loginEndpoint.url) {
      authSettings.authorizationUri = implicit.loginEndpoint.url;
    }

    // Add a manual description if the token name is non-standard.
    if (implicit.tokenName && implicit.tokenName !== 'access_token') {
      description.push(
        'The token grant uses "' + implicit.tokenName + '" as the token name.'
      );
    }
  }

  if (authCode) {
    var tokenEndpoint        = authCode.tokenEndpoint;
    var tokenRequestEndpoint = authCode.tokenRequestEndpoint;
    var clientIdName         = tokenRequestEndpoint.clientIdName;
    var clientSecretName     = tokenRequestEndpoint.clientSecretName;
    var tokenName            = tokenEndpoint.tokenName;

    authSettings.accessTokenUri   = tokenEndpoint.url;
    authSettings.authorizationUri = tokenRequestEndpoint.url;

    if (clientIdName && clientIdName !== 'client_id') {
      description.push(
        'The code grant uses "' + clientIdName + '" as the parameter for ' +
        'passing the client id.'
      );
    }

    if (clientSecretName && clientSecretName !== 'client_secret') {
      description.push(
        'The code grant uses "' + clientSecretName + '" as the parameter ' +
        'for passing the client secret.'
      );
    }

    if (tokenName && tokenName !== 'access_code') {
      description.push(
        'The code grant uses "' + tokenName + '" as the parameter for ' +
        'passing the authorization token.'
      );
    }
  }

  // Add the description to the object if options are available.
  if (description.length) {
    ramlAuth.description = description.join('\n\n');
  }

  return ramlAuth;
}

/**
 * Convert the API key definition in Swagger to a RAML object.
 *
 * @param  {Object} authorization
 * @return {Object}
 */
function convertApiKey (authorization) {
  var ramlAuth = {
    type: 'x-api-key',
    describedBy: {}
  };

  var describedBy = API_KEY_PASS_AS_MAP[authorization.passAs];

  // If the described by property is valid,
  if (describedBy) {
    var description = ramlAuth.describedBy[describedBy] = {};

    // Set the correct parameter on the `describedBy` object.
    description[authorization.keyname] = {
      type:        'string',
      description: 'Used to send a valid API key for authentication.'
    };
  }

  return ramlAuth;
}

/**
 * Convert the basic auth definition in Swagger to a RAML object.
 *
 * @param  {Object} authorization
 * @return {Object}
 */
function convertBasicAuth (authorization) {
  return {
    type: 'Basic Authentication'
  };
}

},{"./utils/version":7}],4:[function(require,module,exports){
/**
 * Export the resource listing check.
 */
module.exports = isResourceListing;

/**
 * Check whether an object is a resource listing.
 *
 * @param  {Object}  resource
 * @return {Boolean}
 */
function isResourceListing (resource) {
  return !resource.basePath;
}

},{}],5:[function(require,module,exports){
/**
 * Export the resolve function.
 */
module.exports = resolve;

/**
 * Resolve a series of path segments.
 *
 * @return {String}
 */
function resolve () {
  var parts = Array.prototype.reduce.call(arguments, function (path, segment) {
    var parts = splitSegment(segment);

    if (hasProtocol(segment)) {
      return parts;
    }

    return path.concat(parts);
  }, []);

  var index = 0;

  while (index < parts.length) {
    var part = parts[index];

    if (part === '' || part === '.') {
      parts.splice(index, 1);
    } else if (part === '..') {
      parts.splice(index - 1, 2);
      index--;
    } else {
      index++;
    }
  }

  return parts.join('/');
}

/**
 * Split a path into parts.
 *
 * @param  {String} segment
 * @return {Array}
 */
function splitSegment (segment) {
  if (!hasProtocol(segment)) {
    return segment.replace(/^\/+/, '').split(/\/+/g);
  }

  var proto = segment.match(/^\w+:\/\//)[0];
  var index = segment.substr(proto.length).indexOf('/');

  // No URL path.
  if (index === -1) {
    return [segment];
  }

  var pathIndex = proto.length + index;
  var parts     = splitSegment(segment.substr(pathIndex));
  var origin    = segment.substr(0, pathIndex);

  return [origin].concat(parts);
}

/**
 * Check if the path begins with a protocol.
 *
 * @param  {String}  path
 * @return {Boolean}
 */
function hasProtocol (path) {
  return /^\w+:\/\//.test(path);
}

/**
 * Check if a path is absolute.
 *
 * @param  {String}  path
 * @return {Boolean}
 */
function isAbsolute (path) {
  return /^\//.test(path);
}

},{}],6:[function(require,module,exports){
/**
 * Export the function.
 */
module.exports = versionEqual;

/**
 * Check whether the new version is the same as the previous version.
 *
 * @param  {String}  currentVersion
 * @param  {String}  newVersion
 * @return {Boolean}
 */
function versionEqual (currentVersion, newVersion) {
  // Allow the new version to be empty.
  if (newVersion == null) {
    return true;
  }

  var newVersionNumber     = Number(newVersion);
  var currentVersionNumber = Number(currentVersion);

  // If both are valid numbers, compare as numbers.
  if (newVersionNumber && currentVersionNumber) {
    return newVersionNumber === currentVersionNumber;
  }

  // Compare directly as strings.
  return currentVersion === newVersion;
}

},{}],7:[function(require,module,exports){
/**
 * Export version function.
 */
module.exports = version;

/**
 * Retrieve the Swagger version from a specification.
 *
 * @param  {Object} declaration
 * @return {Number}
 */
function version (declaration) {
  return parseFloat(declaration.swaggerVersion || declaration.swagger);
}

},{}],8:[function(require,module,exports){
var sentence = require('sentence-case');

/**
 * Camel case a string.
 *
 * @param  {String} string
 * @return {String}
 */
module.exports = function (string) {
  return sentence(string)
    // Replace periods between numeric entities with an underscore.
    .replace(/(\d) (?=\d)/g, '$1_')
    // Replace spaces between words with a string upper cased character.
    .replace(/ (\w)/g, function (_, $1) {
      return $1.toUpperCase();
    });
};

},{"sentence-case":9}],9:[function(require,module,exports){
var NON_WORD_REGEXP       = require('./vendor/non-word-regexp.js');
var CAMEL_CASE_REGEXP     = require('./vendor/camel-case-regexp.js');
var TRAILING_DIGIT_REGEXP = require('./vendor/trailing-digit-regexp.js');

/**
 * Sentence case a string.
 *
 * @param  {String} str
 * @return {String}
 */
module.exports = function (str) {
  if (str == null) {
    return '';
  }

  return String(str)
    // Enables camel case support.
    .replace(CAMEL_CASE_REGEXP, '$1 $2')
    // Add a space after any digits.
    .replace(TRAILING_DIGIT_REGEXP, '$1 $2')
    // Remove all non-word characters and replace with a single space.
    .replace(NON_WORD_REGEXP, ' ')
    // Trim whitespace around the string.
    .replace(/^ | $/g, '')
    // Finally lower case the entire string.
    .toLowerCase();
};

},{"./vendor/camel-case-regexp.js":10,"./vendor/non-word-regexp.js":11,"./vendor/trailing-digit-regexp.js":12}],10:[function(require,module,exports){
module.exports = /([\u0061-\u007A\u00B5\u00DF-\u00F6\u00F8-\u00FF\u0101\u0103\u0105\u0107\u0109\u010B\u010D\u010F\u0111\u0113\u0115\u0117\u0119\u011B\u011D\u011F\u0121\u0123\u0125\u0127\u0129\u012B\u012D\u012F\u0131\u0133\u0135\u0137\u0138\u013A\u013C\u013E\u0140\u0142\u0144\u0146\u0148\u0149\u014B\u014D\u014F\u0151\u0153\u0155\u0157\u0159\u015B\u015D\u015F\u0161\u0163\u0165\u0167\u0169\u016B\u016D\u016F\u0171\u0173\u0175\u0177\u017A\u017C\u017E-\u0180\u0183\u0185\u0188\u018C\u018D\u0192\u0195\u0199-\u019B\u019E\u01A1\u01A3\u01A5\u01A8\u01AA\u01AB\u01AD\u01B0\u01B4\u01B6\u01B9\u01BA\u01BD-\u01BF\u01C6\u01C9\u01CC\u01CE\u01D0\u01D2\u01D4\u01D6\u01D8\u01DA\u01DC\u01DD\u01DF\u01E1\u01E3\u01E5\u01E7\u01E9\u01EB\u01ED\u01EF\u01F0\u01F3\u01F5\u01F9\u01FB\u01FD\u01FF\u0201\u0203\u0205\u0207\u0209\u020B\u020D\u020F\u0211\u0213\u0215\u0217\u0219\u021B\u021D\u021F\u0221\u0223\u0225\u0227\u0229\u022B\u022D\u022F\u0231\u0233-\u0239\u023C\u023F\u0240\u0242\u0247\u0249\u024B\u024D\u024F-\u0293\u0295-\u02AF\u0371\u0373\u0377\u037B-\u037D\u0390\u03AC-\u03CE\u03D0\u03D1\u03D5-\u03D7\u03D9\u03DB\u03DD\u03DF\u03E1\u03E3\u03E5\u03E7\u03E9\u03EB\u03ED\u03EF-\u03F3\u03F5\u03F8\u03FB\u03FC\u0430-\u045F\u0461\u0463\u0465\u0467\u0469\u046B\u046D\u046F\u0471\u0473\u0475\u0477\u0479\u047B\u047D\u047F\u0481\u048B\u048D\u048F\u0491\u0493\u0495\u0497\u0499\u049B\u049D\u049F\u04A1\u04A3\u04A5\u04A7\u04A9\u04AB\u04AD\u04AF\u04B1\u04B3\u04B5\u04B7\u04B9\u04BB\u04BD\u04BF\u04C2\u04C4\u04C6\u04C8\u04CA\u04CC\u04CE\u04CF\u04D1\u04D3\u04D5\u04D7\u04D9\u04DB\u04DD\u04DF\u04E1\u04E3\u04E5\u04E7\u04E9\u04EB\u04ED\u04EF\u04F1\u04F3\u04F5\u04F7\u04F9\u04FB\u04FD\u04FF\u0501\u0503\u0505\u0507\u0509\u050B\u050D\u050F\u0511\u0513\u0515\u0517\u0519\u051B\u051D\u051F\u0521\u0523\u0525\u0527\u0561-\u0587\u1D00-\u1D2B\u1D6B-\u1D77\u1D79-\u1D9A\u1E01\u1E03\u1E05\u1E07\u1E09\u1E0B\u1E0D\u1E0F\u1E11\u1E13\u1E15\u1E17\u1E19\u1E1B\u1E1D\u1E1F\u1E21\u1E23\u1E25\u1E27\u1E29\u1E2B\u1E2D\u1E2F\u1E31\u1E33\u1E35\u1E37\u1E39\u1E3B\u1E3D\u1E3F\u1E41\u1E43\u1E45\u1E47\u1E49\u1E4B\u1E4D\u1E4F\u1E51\u1E53\u1E55\u1E57\u1E59\u1E5B\u1E5D\u1E5F\u1E61\u1E63\u1E65\u1E67\u1E69\u1E6B\u1E6D\u1E6F\u1E71\u1E73\u1E75\u1E77\u1E79\u1E7B\u1E7D\u1E7F\u1E81\u1E83\u1E85\u1E87\u1E89\u1E8B\u1E8D\u1E8F\u1E91\u1E93\u1E95-\u1E9D\u1E9F\u1EA1\u1EA3\u1EA5\u1EA7\u1EA9\u1EAB\u1EAD\u1EAF\u1EB1\u1EB3\u1EB5\u1EB7\u1EB9\u1EBB\u1EBD\u1EBF\u1EC1\u1EC3\u1EC5\u1EC7\u1EC9\u1ECB\u1ECD\u1ECF\u1ED1\u1ED3\u1ED5\u1ED7\u1ED9\u1EDB\u1EDD\u1EDF\u1EE1\u1EE3\u1EE5\u1EE7\u1EE9\u1EEB\u1EED\u1EEF\u1EF1\u1EF3\u1EF5\u1EF7\u1EF9\u1EFB\u1EFD\u1EFF-\u1F07\u1F10-\u1F15\u1F20-\u1F27\u1F30-\u1F37\u1F40-\u1F45\u1F50-\u1F57\u1F60-\u1F67\u1F70-\u1F7D\u1F80-\u1F87\u1F90-\u1F97\u1FA0-\u1FA7\u1FB0-\u1FB4\u1FB6\u1FB7\u1FBE\u1FC2-\u1FC4\u1FC6\u1FC7\u1FD0-\u1FD3\u1FD6\u1FD7\u1FE0-\u1FE7\u1FF2-\u1FF4\u1FF6\u1FF7\u210A\u210E\u210F\u2113\u212F\u2134\u2139\u213C\u213D\u2146-\u2149\u214E\u2184\u2C30-\u2C5E\u2C61\u2C65\u2C66\u2C68\u2C6A\u2C6C\u2C71\u2C73\u2C74\u2C76-\u2C7B\u2C81\u2C83\u2C85\u2C87\u2C89\u2C8B\u2C8D\u2C8F\u2C91\u2C93\u2C95\u2C97\u2C99\u2C9B\u2C9D\u2C9F\u2CA1\u2CA3\u2CA5\u2CA7\u2CA9\u2CAB\u2CAD\u2CAF\u2CB1\u2CB3\u2CB5\u2CB7\u2CB9\u2CBB\u2CBD\u2CBF\u2CC1\u2CC3\u2CC5\u2CC7\u2CC9\u2CCB\u2CCD\u2CCF\u2CD1\u2CD3\u2CD5\u2CD7\u2CD9\u2CDB\u2CDD\u2CDF\u2CE1\u2CE3\u2CE4\u2CEC\u2CEE\u2CF3\u2D00-\u2D25\u2D27\u2D2D\uA641\uA643\uA645\uA647\uA649\uA64B\uA64D\uA64F\uA651\uA653\uA655\uA657\uA659\uA65B\uA65D\uA65F\uA661\uA663\uA665\uA667\uA669\uA66B\uA66D\uA681\uA683\uA685\uA687\uA689\uA68B\uA68D\uA68F\uA691\uA693\uA695\uA697\uA723\uA725\uA727\uA729\uA72B\uA72D\uA72F-\uA731\uA733\uA735\uA737\uA739\uA73B\uA73D\uA73F\uA741\uA743\uA745\uA747\uA749\uA74B\uA74D\uA74F\uA751\uA753\uA755\uA757\uA759\uA75B\uA75D\uA75F\uA761\uA763\uA765\uA767\uA769\uA76B\uA76D\uA76F\uA771-\uA778\uA77A\uA77C\uA77F\uA781\uA783\uA785\uA787\uA78C\uA78E\uA791\uA793\uA7A1\uA7A3\uA7A5\uA7A7\uA7A9\uA7FA\uFB00-\uFB06\uFB13-\uFB17\uFF41-\uFF5A])([\u0041-\u005A\u00C0-\u00D6\u00D8-\u00DE\u0100\u0102\u0104\u0106\u0108\u010A\u010C\u010E\u0110\u0112\u0114\u0116\u0118\u011A\u011C\u011E\u0120\u0122\u0124\u0126\u0128\u012A\u012C\u012E\u0130\u0132\u0134\u0136\u0139\u013B\u013D\u013F\u0141\u0143\u0145\u0147\u014A\u014C\u014E\u0150\u0152\u0154\u0156\u0158\u015A\u015C\u015E\u0160\u0162\u0164\u0166\u0168\u016A\u016C\u016E\u0170\u0172\u0174\u0176\u0178\u0179\u017B\u017D\u0181\u0182\u0184\u0186\u0187\u0189-\u018B\u018E-\u0191\u0193\u0194\u0196-\u0198\u019C\u019D\u019F\u01A0\u01A2\u01A4\u01A6\u01A7\u01A9\u01AC\u01AE\u01AF\u01B1-\u01B3\u01B5\u01B7\u01B8\u01BC\u01C4\u01C7\u01CA\u01CD\u01CF\u01D1\u01D3\u01D5\u01D7\u01D9\u01DB\u01DE\u01E0\u01E2\u01E4\u01E6\u01E8\u01EA\u01EC\u01EE\u01F1\u01F4\u01F6-\u01F8\u01FA\u01FC\u01FE\u0200\u0202\u0204\u0206\u0208\u020A\u020C\u020E\u0210\u0212\u0214\u0216\u0218\u021A\u021C\u021E\u0220\u0222\u0224\u0226\u0228\u022A\u022C\u022E\u0230\u0232\u023A\u023B\u023D\u023E\u0241\u0243-\u0246\u0248\u024A\u024C\u024E\u0370\u0372\u0376\u0386\u0388-\u038A\u038C\u038E\u038F\u0391-\u03A1\u03A3-\u03AB\u03CF\u03D2-\u03D4\u03D8\u03DA\u03DC\u03DE\u03E0\u03E2\u03E4\u03E6\u03E8\u03EA\u03EC\u03EE\u03F4\u03F7\u03F9\u03FA\u03FD-\u042F\u0460\u0462\u0464\u0466\u0468\u046A\u046C\u046E\u0470\u0472\u0474\u0476\u0478\u047A\u047C\u047E\u0480\u048A\u048C\u048E\u0490\u0492\u0494\u0496\u0498\u049A\u049C\u049E\u04A0\u04A2\u04A4\u04A6\u04A8\u04AA\u04AC\u04AE\u04B0\u04B2\u04B4\u04B6\u04B8\u04BA\u04BC\u04BE\u04C0\u04C1\u04C3\u04C5\u04C7\u04C9\u04CB\u04CD\u04D0\u04D2\u04D4\u04D6\u04D8\u04DA\u04DC\u04DE\u04E0\u04E2\u04E4\u04E6\u04E8\u04EA\u04EC\u04EE\u04F0\u04F2\u04F4\u04F6\u04F8\u04FA\u04FC\u04FE\u0500\u0502\u0504\u0506\u0508\u050A\u050C\u050E\u0510\u0512\u0514\u0516\u0518\u051A\u051C\u051E\u0520\u0522\u0524\u0526\u0531-\u0556\u10A0-\u10C5\u10C7\u10CD\u1E00\u1E02\u1E04\u1E06\u1E08\u1E0A\u1E0C\u1E0E\u1E10\u1E12\u1E14\u1E16\u1E18\u1E1A\u1E1C\u1E1E\u1E20\u1E22\u1E24\u1E26\u1E28\u1E2A\u1E2C\u1E2E\u1E30\u1E32\u1E34\u1E36\u1E38\u1E3A\u1E3C\u1E3E\u1E40\u1E42\u1E44\u1E46\u1E48\u1E4A\u1E4C\u1E4E\u1E50\u1E52\u1E54\u1E56\u1E58\u1E5A\u1E5C\u1E5E\u1E60\u1E62\u1E64\u1E66\u1E68\u1E6A\u1E6C\u1E6E\u1E70\u1E72\u1E74\u1E76\u1E78\u1E7A\u1E7C\u1E7E\u1E80\u1E82\u1E84\u1E86\u1E88\u1E8A\u1E8C\u1E8E\u1E90\u1E92\u1E94\u1E9E\u1EA0\u1EA2\u1EA4\u1EA6\u1EA8\u1EAA\u1EAC\u1EAE\u1EB0\u1EB2\u1EB4\u1EB6\u1EB8\u1EBA\u1EBC\u1EBE\u1EC0\u1EC2\u1EC4\u1EC6\u1EC8\u1ECA\u1ECC\u1ECE\u1ED0\u1ED2\u1ED4\u1ED6\u1ED8\u1EDA\u1EDC\u1EDE\u1EE0\u1EE2\u1EE4\u1EE6\u1EE8\u1EEA\u1EEC\u1EEE\u1EF0\u1EF2\u1EF4\u1EF6\u1EF8\u1EFA\u1EFC\u1EFE\u1F08-\u1F0F\u1F18-\u1F1D\u1F28-\u1F2F\u1F38-\u1F3F\u1F48-\u1F4D\u1F59\u1F5B\u1F5D\u1F5F\u1F68-\u1F6F\u1FB8-\u1FBB\u1FC8-\u1FCB\u1FD8-\u1FDB\u1FE8-\u1FEC\u1FF8-\u1FFB\u2102\u2107\u210B-\u210D\u2110-\u2112\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u2130-\u2133\u213E\u213F\u2145\u2183\u2C00-\u2C2E\u2C60\u2C62-\u2C64\u2C67\u2C69\u2C6B\u2C6D-\u2C70\u2C72\u2C75\u2C7E-\u2C80\u2C82\u2C84\u2C86\u2C88\u2C8A\u2C8C\u2C8E\u2C90\u2C92\u2C94\u2C96\u2C98\u2C9A\u2C9C\u2C9E\u2CA0\u2CA2\u2CA4\u2CA6\u2CA8\u2CAA\u2CAC\u2CAE\u2CB0\u2CB2\u2CB4\u2CB6\u2CB8\u2CBA\u2CBC\u2CBE\u2CC0\u2CC2\u2CC4\u2CC6\u2CC8\u2CCA\u2CCC\u2CCE\u2CD0\u2CD2\u2CD4\u2CD6\u2CD8\u2CDA\u2CDC\u2CDE\u2CE0\u2CE2\u2CEB\u2CED\u2CF2\uA640\uA642\uA644\uA646\uA648\uA64A\uA64C\uA64E\uA650\uA652\uA654\uA656\uA658\uA65A\uA65C\uA65E\uA660\uA662\uA664\uA666\uA668\uA66A\uA66C\uA680\uA682\uA684\uA686\uA688\uA68A\uA68C\uA68E\uA690\uA692\uA694\uA696\uA722\uA724\uA726\uA728\uA72A\uA72C\uA72E\uA732\uA734\uA736\uA738\uA73A\uA73C\uA73E\uA740\uA742\uA744\uA746\uA748\uA74A\uA74C\uA74E\uA750\uA752\uA754\uA756\uA758\uA75A\uA75C\uA75E\uA760\uA762\uA764\uA766\uA768\uA76A\uA76C\uA76E\uA779\uA77B\uA77D\uA77E\uA780\uA782\uA784\uA786\uA78B\uA78D\uA790\uA792\uA7A0\uA7A2\uA7A4\uA7A6\uA7A8\uA7AA\uFF21-\uFF3A\u0030-\u0039\u00B2\u00B3\u00B9\u00BC-\u00BE\u0660-\u0669\u06F0-\u06F9\u07C0-\u07C9\u0966-\u096F\u09E6-\u09EF\u09F4-\u09F9\u0A66-\u0A6F\u0AE6-\u0AEF\u0B66-\u0B6F\u0B72-\u0B77\u0BE6-\u0BF2\u0C66-\u0C6F\u0C78-\u0C7E\u0CE6-\u0CEF\u0D66-\u0D75\u0E50-\u0E59\u0ED0-\u0ED9\u0F20-\u0F33\u1040-\u1049\u1090-\u1099\u1369-\u137C\u16EE-\u16F0\u17E0-\u17E9\u17F0-\u17F9\u1810-\u1819\u1946-\u194F\u19D0-\u19DA\u1A80-\u1A89\u1A90-\u1A99\u1B50-\u1B59\u1BB0-\u1BB9\u1C40-\u1C49\u1C50-\u1C59\u2070\u2074-\u2079\u2080-\u2089\u2150-\u2182\u2185-\u2189\u2460-\u249B\u24EA-\u24FF\u2776-\u2793\u2CFD\u3007\u3021-\u3029\u3038-\u303A\u3192-\u3195\u3220-\u3229\u3248-\u324F\u3251-\u325F\u3280-\u3289\u32B1-\u32BF\uA620-\uA629\uA6E6-\uA6EF\uA830-\uA835\uA8D0-\uA8D9\uA900-\uA909\uA9D0-\uA9D9\uAA50-\uAA59\uABF0-\uABF9\uFF10-\uFF19])/g;
},{}],11:[function(require,module,exports){
module.exports = /[^\u0041-\u005A\u0061-\u007A\u00AA\u00B5\u00BA\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u0527\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u08A0\u08A2-\u08AC\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0977\u0979-\u097F\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C33\u0C35-\u0C39\u0C3D\u0C58\u0C59\u0C60\u0C61\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D60\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F4\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191C\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19C1-\u19C7\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2183\u2184\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2E2F\u3005\u3006\u3031-\u3035\u303B\u303C\u3041-\u3096\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FCC\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA697\uA6A0-\uA6E5\uA717-\uA71F\uA722-\uA788\uA78B-\uA78E\uA790-\uA793\uA7A0-\uA7AA\uA7F8-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA80-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uABC0-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC\u0030-\u0039\u00B2\u00B3\u00B9\u00BC-\u00BE\u0660-\u0669\u06F0-\u06F9\u07C0-\u07C9\u0966-\u096F\u09E6-\u09EF\u09F4-\u09F9\u0A66-\u0A6F\u0AE6-\u0AEF\u0B66-\u0B6F\u0B72-\u0B77\u0BE6-\u0BF2\u0C66-\u0C6F\u0C78-\u0C7E\u0CE6-\u0CEF\u0D66-\u0D75\u0E50-\u0E59\u0ED0-\u0ED9\u0F20-\u0F33\u1040-\u1049\u1090-\u1099\u1369-\u137C\u16EE-\u16F0\u17E0-\u17E9\u17F0-\u17F9\u1810-\u1819\u1946-\u194F\u19D0-\u19DA\u1A80-\u1A89\u1A90-\u1A99\u1B50-\u1B59\u1BB0-\u1BB9\u1C40-\u1C49\u1C50-\u1C59\u2070\u2074-\u2079\u2080-\u2089\u2150-\u2182\u2185-\u2189\u2460-\u249B\u24EA-\u24FF\u2776-\u2793\u2CFD\u3007\u3021-\u3029\u3038-\u303A\u3192-\u3195\u3220-\u3229\u3248-\u324F\u3251-\u325F\u3280-\u3289\u32B1-\u32BF\uA620-\uA629\uA6E6-\uA6EF\uA830-\uA835\uA8D0-\uA8D9\uA900-\uA909\uA9D0-\uA9D9\uAA50-\uAA59\uABF0-\uABF9\uFF10-\uFF19]+/g;
},{}],12:[function(require,module,exports){
module.exports = /([\u0030-\u0039\u00B2\u00B3\u00B9\u00BC-\u00BE\u0660-\u0669\u06F0-\u06F9\u07C0-\u07C9\u0966-\u096F\u09E6-\u09EF\u09F4-\u09F9\u0A66-\u0A6F\u0AE6-\u0AEF\u0B66-\u0B6F\u0B72-\u0B77\u0BE6-\u0BF2\u0C66-\u0C6F\u0C78-\u0C7E\u0CE6-\u0CEF\u0D66-\u0D75\u0E50-\u0E59\u0ED0-\u0ED9\u0F20-\u0F33\u1040-\u1049\u1090-\u1099\u1369-\u137C\u16EE-\u16F0\u17E0-\u17E9\u17F0-\u17F9\u1810-\u1819\u1946-\u194F\u19D0-\u19DA\u1A80-\u1A89\u1A90-\u1A99\u1B50-\u1B59\u1BB0-\u1BB9\u1C40-\u1C49\u1C50-\u1C59\u2070\u2074-\u2079\u2080-\u2089\u2150-\u2182\u2185-\u2189\u2460-\u249B\u24EA-\u24FF\u2776-\u2793\u2CFD\u3007\u3021-\u3029\u3038-\u303A\u3192-\u3195\u3220-\u3229\u3248-\u324F\u3251-\u325F\u3280-\u3289\u32B1-\u32BF\uA620-\uA629\uA6E6-\uA6EF\uA830-\uA835\uA8D0-\uA8D9\uA900-\uA909\uA9D0-\uA9D9\uAA50-\uAA59\uABF0-\uABF9\uFF10-\uFF19])([^\u0030-\u0039\u00B2\u00B3\u00B9\u00BC-\u00BE\u0660-\u0669\u06F0-\u06F9\u07C0-\u07C9\u0966-\u096F\u09E6-\u09EF\u09F4-\u09F9\u0A66-\u0A6F\u0AE6-\u0AEF\u0B66-\u0B6F\u0B72-\u0B77\u0BE6-\u0BF2\u0C66-\u0C6F\u0C78-\u0C7E\u0CE6-\u0CEF\u0D66-\u0D75\u0E50-\u0E59\u0ED0-\u0ED9\u0F20-\u0F33\u1040-\u1049\u1090-\u1099\u1369-\u137C\u16EE-\u16F0\u17E0-\u17E9\u17F0-\u17F9\u1810-\u1819\u1946-\u194F\u19D0-\u19DA\u1A80-\u1A89\u1A90-\u1A99\u1B50-\u1B59\u1BB0-\u1BB9\u1C40-\u1C49\u1C50-\u1C59\u2070\u2074-\u2079\u2080-\u2089\u2150-\u2182\u2185-\u2189\u2460-\u249B\u24EA-\u24FF\u2776-\u2793\u2CFD\u3007\u3021-\u3029\u3038-\u303A\u3192-\u3195\u3220-\u3229\u3248-\u324F\u3251-\u325F\u3280-\u3289\u32B1-\u32BF\uA620-\uA629\uA6E6-\uA6EF\uA830-\uA835\uA8D0-\uA8D9\uA900-\uA909\uA9D0-\uA9D9\uAA50-\uAA59\uABF0-\uABF9\uFF10-\uFF19])/g;
},{}],13:[function(require,module,exports){
var hasOwn = Object.prototype.hasOwnProperty;
var toString = Object.prototype.toString;
var undefined;

var isPlainObject = function isPlainObject(obj) {
	"use strict";
	if (!obj || toString.call(obj) !== '[object Object]' || obj.nodeType || obj.setInterval) {
		return false;
	}

	var has_own_constructor = hasOwn.call(obj, 'constructor');
	var has_is_property_of_method = obj.constructor && obj.constructor.prototype && hasOwn.call(obj.constructor.prototype, 'isPrototypeOf');
	// Not own constructor property must be Object
	if (obj.constructor && !has_own_constructor && !has_is_property_of_method) {
		return false;
	}

	// Own properties are enumerated firstly, so to speed up,
	// if last one is own, then all properties are own.
	var key;
	for (key in obj) {}

	return key === undefined || hasOwn.call(obj, key);
};

module.exports = function extend() {
	"use strict";
	var options, name, src, copy, copyIsArray, clone,
		target = arguments[0],
		i = 1,
		length = arguments.length,
		deep = false;

	// Handle a deep copy situation
	if (typeof target === "boolean") {
		deep = target;
		target = arguments[1] || {};
		// skip the boolean and the target
		i = 2;
	} else if (typeof target !== "object" && typeof target !== "function" || target == undefined) {
			target = {};
	}

	for (; i < length; ++i) {
		// Only deal with non-null/undefined values
		if ((options = arguments[i]) != null) {
			// Extend the base object
			for (name in options) {
				src = target[name];
				copy = options[name];

				// Prevent never-ending loop
				if (target === copy) {
					continue;
				}

				// Recurse if we're merging plain objects or arrays
				if (deep && copy && (isPlainObject(copy) || (copyIsArray = Array.isArray(copy)))) {
					if (copyIsArray) {
						copyIsArray = false;
						clone = src && Array.isArray(src) ? src : [];
					} else {
						clone = src && isPlainObject(src) ? src : {};
					}

					// Never move original objects, clone them
					target[name] = extend(deep, clone, copy);

				// Don't bring in undefined values
				} else if (copy !== undefined) {
					target[name] = copy;
				}
			}
		}
	}

	// Return the modified object
	return target;
};


},{}],14:[function(require,module,exports){
var parse                  = require('./lib/parse');
var resolve                = require('./lib/utils/resolve');
var isResourceListing      = require('./lib/utils/is-resource-listing');
var convertApiDeclaration  = require('./lib/api-declaration');
var convertResourceListing = require('./lib/resource-listing');

/**
 * Expose the swagger to raml object converter module.
 */
module.exports = swaggerToRamlObject;
module.exports.files = swaggerFilesToRamlObject;

/**
 * Convert swagger to a raml object by loading the file.
 *
 * @param {String}   filename
 * @param {Function} filereader
 * @param {Function} done
 */
function swaggerToRamlObject (filename, filereader, done) {
  var read = wrapFileReader(filereader);

  return read(filename, wrapContents(function (result) {
    if (!isResourceListing(result)) {
      return done(null, convertApiDeclaration(result));
    }

    // Parse the initial resource listing to start reading more resources.
    var resources  = extractResources(result, filename);
    var ramlObject = convertResourceListing(result);

    function success (results) {
      results.forEach(function (contents) {
        convertApiDeclaration(contents, ramlObject);
      });

      return done(null, ramlObject);
    }

    return async(resources, read, wrapContents(success, done));
  }, done));
}

/**
 * Generate RAML from an array of Swagger files.
 *
 * @param {Array}    files
 * @param {Function} filereader
 * @param {Function} done
 */
function swaggerFilesToRamlObject (files, filereader, done) {
  return async(files, filereader, wrapContents(function (results) {
    var fileMap = {};

    // Parse all the files and ignore non-parsable files (non-Swagger, etc.)
    results.forEach(function (contents, index) {
      var filename = files[index];
      var result;

      try {
        result = parse(contents);
      } catch (e) {
        return;
      }

      fileMap[filename] = result;
    });

    var keys = Object.keys(fileMap);
    var rootFileName = keys[0];

    if (keys.length > 1) {
      rootFileName = findResourceListing(fileMap);

      if (!rootFileName) {
        throw new TypeError('Unable to determine entry file (Swagger resource listing)');
      }
    }

    var resourceListing = fileMap[rootFileName];

    if (!isResourceListing(resourceListing)) {
      return done(null, convertApiDeclaration(resourceListing));
    }

    var read       = wrapFileReader(filereader);
    var resources  = extractResources(resourceListing, rootFileName);
    var ramlObject = convertResourceListing(resourceListing);

    function readfile (filename, done) {
      if (fileMap.hasOwnProperty(filename)) {
        return done(null, fileMap[filename]);
      }

      return read(filename, done);
    }

    function success (results) {
      results.forEach(function (contents) {
        convertApiDeclaration(contents, ramlObject);
      });

      return done(null, ramlObject);
    }

    return async(resources, readfile, wrapContents(success, done));
  }, done));
}

/**
 * Extract API resources from a resource listing.
 *
 * @param  {Object} resourceListing
 * @param  {String} filename
 * @return {Array}
 */
function extractResources (resourceListing, filename) {
  return resourceListing.apis.map(function (api) {
    return resolve(filename, api.path);
  });
}

/**
 * Find a valid resource listing file out of an object.
 *
 * @param  {Object} files
 * @return {String}
 */
function findResourceListing (files) {
  var resourceListings = Object.keys(files).filter(function (key) {
    return isResourceListing(files[key]);
  });

  if (resourceListings.length > 1) {
    throw new Error('Multiple resource listings found');
  }

  return resourceListings[0];
}

/**
 * Run a function on an array of items asynchonrously.
 *
 * @param {Array}    items
 * @param {Function} fn
 * @param {Function} done
 */
function async (items, fn, done) {
  var count   = 0;
  var length  = items.length;
  var results = [];
  var errored = false;

  items.forEach(function (item, index) {
    // Call the async function with the item and callback.
    fn(item, function (err, result) {
      if (errored) {
        return;
      }

      if (err) {
        errored = true;

        return done(err);
      }

      count++;
      results[index] = result;

      if (count === length) {
        return done(null, results);
      }
    });
  });
}

/**
 * Wrap the file reader functionality with parsing.
 *
 * @param  {Function} fn
 * @return {Function}
 */
function wrapFileReader (fn) {
  return function (filename, done) {
    return fn(filename, function (err, result) {
      if (err) {
        return done(err);
      }

      try {
        return done(null, parse(result));
      } catch (e) {
        return done(e);
      }
    });
  }
}

/**
 * Wrap the response from a file reader with parse ability.
 *
 * @param  {Function} resolve
 * @param  {Function} reject
 * @return {Function}
 */
function wrapContents (resolve, reject) {
  return function (err, result) {
    if (err) {
      return reject(err);
    }

    try {
      return resolve(result);
    } catch (e) {
      return reject(e);
    }
  };
}

},{"./lib/api-declaration":1,"./lib/parse":2,"./lib/resource-listing":3,"./lib/utils/is-resource-listing":4,"./lib/utils/resolve":5}]},{},[14])(14)
});
/**

JSZip - A Javascript class for generating and reading zip files
<http://stuartk.com/jszip>

(c) 2009-2012 Stuart Knightley <stuart [at] stuartk.com>
Dual licenced under the MIT license or GPLv3. See LICENSE.markdown.

Usage:
   zip = new JSZip();
   zip.file("hello.txt", "Hello, World!").file("tempfile", "nothing");
   zip.folder("images").file("smile.gif", base64Data, {base64: true});
   zip.file("Xmas.txt", "Ho ho ho !", {date : new Date("December 25, 2007 00:00:01")});
   zip.remove("tempfile");

   base64zip = zip.generate();

**/
// We use strict, but it should not be placed outside of a function because
// the environment is shared inside the browser.
// "use strict";

/**
 * Representation a of zip file in js
 * @constructor
 * @param {String=|ArrayBuffer=|Uint8Array=|Buffer=} data the data to load, if any (optional).
 * @param {Object=} options the options for creating this objects (optional).
 */
var JSZip = function(data, options) {
   // object containing the files :
   // {
   //   "folder/" : {...},
   //   "folder/data.txt" : {...}
   // }
   this.files = {};

   // Where we are in the hierarchy
   this.root = "";

   if (data) {
      this.load(data, options);
   }
};

JSZip.signature = {
   LOCAL_FILE_HEADER : "\x50\x4b\x03\x04",
   CENTRAL_FILE_HEADER : "\x50\x4b\x01\x02",
   CENTRAL_DIRECTORY_END : "\x50\x4b\x05\x06",
   ZIP64_CENTRAL_DIRECTORY_LOCATOR : "\x50\x4b\x06\x07",
   ZIP64_CENTRAL_DIRECTORY_END : "\x50\x4b\x06\x06",
   DATA_DESCRIPTOR : "\x50\x4b\x07\x08"
};

// Default properties for a new file
JSZip.defaults = {
   base64: false,
   binary: false,
   dir: false,
   date: null,
   compression: null
};

/*
 * List features that require a modern browser, and if the current browser support them.
 */
JSZip.support = {
   // contains true if JSZip can read/generate ArrayBuffer, false otherwise.
   arraybuffer : (function(){
      return typeof ArrayBuffer !== "undefined" && typeof Uint8Array !== "undefined";
   })(),
   // contains true if JSZip can read/generate nodejs Buffer, false otherwise.
   nodebuffer : (function(){
      return typeof Buffer !== "undefined";
   })(),
   // contains true if JSZip can read/generate Uint8Array, false otherwise.
   uint8array : (function(){
      return typeof Uint8Array !== "undefined";
   })(),
   // contains true if JSZip can read/generate Blob, false otherwise.
   blob : (function(){
      // the spec started with BlobBuilder then replaced it with a construtor for Blob.
      // Result : we have browsers that :
      // * know the BlobBuilder (but with prefix)
      // * know the Blob constructor
      // * know about Blob but not about how to build them
      // About the "=== 0" test : if given the wrong type, it may be converted to a string.
      // Instead of an empty content, we will get "[object Uint8Array]" for example.
      if (typeof ArrayBuffer === "undefined") {
         return false;
      }
      var buffer = new ArrayBuffer(0);
      try {
         return new Blob([buffer], { type: "application/zip" }).size === 0;
      }
      catch(e) {}

      try {
         var BlobBuilder = window.BlobBuilder || window.WebKitBlobBuilder || window.MozBlobBuilder || window.MSBlobBuilder;
         var builder = new BlobBuilder();
         builder.append(buffer);
         return builder.getBlob('application/zip').size === 0;
      }
      catch(e) {}

      return false;
   })()
};

JSZip.prototype = (function () {
   var textEncoder, textDecoder;
   if (
      JSZip.support.uint8array &&
      typeof TextEncoder === "function" &&
      typeof TextDecoder === "function"
   ) {
      textEncoder = new TextEncoder("utf-8");
      textDecoder = new TextDecoder("utf-8");
   }

   /**
    * Returns the raw data of a ZipObject, decompress the content if necessary.
    * @param {ZipObject} file the file to use.
    * @return {String|ArrayBuffer|Uint8Array|Buffer} the data.
    */
   var getRawData = function (file) {
      if (file._data instanceof JSZip.CompressedObject) {
         file._data = file._data.getContent();
         file.options.binary = true;
         file.options.base64 = false;

         if (JSZip.utils.getTypeOf(file._data) === "uint8array") {
            var copy = file._data;
            // when reading an arraybuffer, the CompressedObject mechanism will keep it and subarray() a Uint8Array.
            // if we request a file in the same format, we might get the same Uint8Array or its ArrayBuffer (the original zip file).
            file._data = new Uint8Array(copy.length);
            // with an empty Uint8Array, Opera fails with a "Offset larger than array size"
            if (copy.length !== 0) {
               file._data.set(copy, 0);
            }
         }
      }
      return file._data;
   };

   /**
    * Returns the data of a ZipObject in a binary form. If the content is an unicode string, encode it.
    * @param {ZipObject} file the file to use.
    * @return {String|ArrayBuffer|Uint8Array|Buffer} the data.
    */
   var getBinaryData = function (file) {
      var result = getRawData(file), type = JSZip.utils.getTypeOf(result);
      if (type === "string") {
         if (!file.options.binary) {
            // unicode text !
            // unicode string => binary string is a painful process, check if we can avoid it.
            if (textEncoder) {
               return textEncoder.encode(result);
            }
            if (JSZip.support.nodebuffer) {
               return new Buffer(result, "utf-8");
            }
         }
         return file.asBinary();
      }
      return result;
   };

   /**
    * Transform this._data into a string.
    * @param {function} filter a function String -> String, applied if not null on the result.
    * @return {String} the string representing this._data.
    */
   var dataToString = function (asUTF8) {
      var result = getRawData(this);
      if (result === null || typeof result === "undefined") {
         return "";
      }
      // if the data is a base64 string, we decode it before checking the encoding !
      if (this.options.base64) {
         result = JSZip.base64.decode(result);
      }
      if (asUTF8 && this.options.binary) {
         // JSZip.prototype.utf8decode supports arrays as input
         // skip to array => string step, utf8decode will do it.
         result = JSZip.prototype.utf8decode(result);
      } else {
         // no utf8 transformation, do the array => string step.
         result = JSZip.utils.transformTo("string", result);
      }

      if (!asUTF8 && !this.options.binary) {
         result = JSZip.prototype.utf8encode(result);
      }
      return result;
   };
   /**
    * A simple object representing a file in the zip file.
    * @constructor
    * @param {string} name the name of the file
    * @param {String|ArrayBuffer|Uint8Array|Buffer} data the data
    * @param {Object} options the options of the file
    */
   var ZipObject = function (name, data, options) {
      this.name = name;
      this._data = data;
      this.options = options;
   };

   ZipObject.prototype = {
      /**
       * Return the content as UTF8 string.
       * @return {string} the UTF8 string.
       */
      asText : function () {
         return dataToString.call(this, true);
      },
      /**
       * Returns the binary content.
       * @return {string} the content as binary.
       */
      asBinary : function () {
         return dataToString.call(this, false);
      },
      /**
       * Returns the content as a nodejs Buffer.
       * @return {Buffer} the content as a Buffer.
       */
      asNodeBuffer : function () {
         var result = getBinaryData(this);
         return JSZip.utils.transformTo("nodebuffer", result);
      },
      /**
       * Returns the content as an Uint8Array.
       * @return {Uint8Array} the content as an Uint8Array.
       */
      asUint8Array : function () {
         var result = getBinaryData(this);
         return JSZip.utils.transformTo("uint8array", result);
      },
      /**
       * Returns the content as an ArrayBuffer.
       * @return {ArrayBuffer} the content as an ArrayBufer.
       */
      asArrayBuffer : function () {
         return this.asUint8Array().buffer;
      }
   };

   /**
    * Transform an integer into a string in hexadecimal.
    * @private
    * @param {number} dec the number to convert.
    * @param {number} bytes the number of bytes to generate.
    * @returns {string} the result.
    */
   var decToHex = function(dec, bytes) {
      var hex = "", i;
      for(i = 0; i < bytes; i++) {
         hex += String.fromCharCode(dec&0xff);
         dec=dec>>>8;
      }
      return hex;
   };

   /**
    * Merge the objects passed as parameters into a new one.
    * @private
    * @param {...Object} var_args All objects to merge.
    * @return {Object} a new object with the data of the others.
    */
   var extend = function () {
      var result = {}, i, attr;
      for (i = 0; i < arguments.length; i++) { // arguments is not enumerable in some browsers
         for (attr in arguments[i]) {
            if (arguments[i].hasOwnProperty(attr) && typeof result[attr] === "undefined") {
               result[attr] = arguments[i][attr];
            }
         }
      }
      return result;
   };

   /**
    * Transforms the (incomplete) options from the user into the complete
    * set of options to create a file.
    * @private
    * @param {Object} o the options from the user.
    * @return {Object} the complete set of options.
    */
   var prepareFileAttrs = function (o) {
      o = o || {};
      /*jshint -W041 */
      if (o.base64 === true && o.binary == null) {
         o.binary = true;
      }
      /*jshint +W041 */
      o = extend(o, JSZip.defaults);
      o.date = o.date || new Date();
      if (o.compression !== null) o.compression = o.compression.toUpperCase();

      return o;
   };

   /**
    * Add a file in the current folder.
    * @private
    * @param {string} name the name of the file
    * @param {String|ArrayBuffer|Uint8Array|Buffer} data the data of the file
    * @param {Object} o the options of the file
    * @return {Object} the new file.
    */
   var fileAdd = function (name, data, o) {
      // be sure sub folders exist
      var parent = parentFolder(name), dataType = JSZip.utils.getTypeOf(data);
      if (parent) {
         folderAdd.call(this, parent);
      }

      o = prepareFileAttrs(o);

      if (o.dir || data === null || typeof data === "undefined") {
         o.base64 = false;
         o.binary = false;
         data = null;
      } else if (dataType === "string") {
         if (o.binary && !o.base64) {
            // optimizedBinaryString == true means that the file has already been filtered with a 0xFF mask
            if (o.optimizedBinaryString !== true) {
               // this is a string, not in a base64 format.
               // Be sure that this is a correct "binary string"
               data = JSZip.utils.string2binary(data);
            }
         }
      } else { // arraybuffer, uint8array, ...
         o.base64 = false;
         o.binary = true;

         if (!dataType && !(data instanceof JSZip.CompressedObject)) {
            throw new Error("The data of '" + name + "' is in an unsupported format !");
         }

         // special case : it's way easier to work with Uint8Array than with ArrayBuffer
         if (dataType === "arraybuffer") {
            data = JSZip.utils.transformTo("uint8array", data);
         }
      }

      var object = new ZipObject(name, data, o);
      this.files[name] = object;
      return object;
   };


   /**
    * Find the parent folder of the path.
    * @private
    * @param {string} path the path to use
    * @return {string} the parent folder, or ""
    */
   var parentFolder = function (path) {
      if (path.slice(-1) == '/') {
         path = path.substring(0, path.length - 1);
      }
      var lastSlash = path.lastIndexOf('/');
      return (lastSlash > 0) ? path.substring(0, lastSlash) : "";
   };

   /**
    * Add a (sub) folder in the current folder.
    * @private
    * @param {string} name the folder's name
    * @return {Object} the new folder.
    */
   var folderAdd = function (name) {
      // Check the name ends with a /
      if (name.slice(-1) != "/") {
         name += "/"; // IE doesn't like substr(-1)
      }

      // Does this folder already exist?
      if (!this.files[name]) {
         fileAdd.call(this, name, null, {dir:true});
      }
      return this.files[name];
   };

   /**
    * Generate a JSZip.CompressedObject for a given zipOject.
    * @param {ZipObject} file the object to read.
    * @param {JSZip.compression} compression the compression to use.
    * @return {JSZip.CompressedObject} the compressed result.
    */
   var generateCompressedObjectFrom = function (file, compression) {
      var result = new JSZip.CompressedObject(), content;

      // the data has not been decompressed, we might reuse things !
      if (file._data instanceof JSZip.CompressedObject) {
         result.uncompressedSize = file._data.uncompressedSize;
         result.crc32 = file._data.crc32;

         if (result.uncompressedSize === 0 || file.options.dir) {
            compression = JSZip.compressions['STORE'];
            result.compressedContent = "";
            result.crc32 = 0;
         } else if (file._data.compressionMethod === compression.magic) {
            result.compressedContent = file._data.getCompressedContent();
         } else {
            content = file._data.getContent();
            // need to decompress / recompress
            result.compressedContent = compression.compress(JSZip.utils.transformTo(compression.compressInputType, content));
         }
      } else {
         // have uncompressed data
         content = getBinaryData(file);
         if (!content || content.length === 0 || file.options.dir) {
            compression = JSZip.compressions['STORE'];
            content = "";
         }
         result.uncompressedSize = content.length;
         result.crc32 = this.crc32(content);
         result.compressedContent = compression.compress(JSZip.utils.transformTo(compression.compressInputType, content));
      }

      result.compressedSize = result.compressedContent.length;
      result.compressionMethod = compression.magic;

      return result;
   };

   /**
    * Generate the various parts used in the construction of the final zip file.
    * @param {string} name the file name.
    * @param {ZipObject} file the file content.
    * @param {JSZip.CompressedObject} compressedObject the compressed object.
    * @param {number} offset the current offset from the start of the zip file.
    * @return {object} the zip parts.
    */
   var generateZipParts = function(name, file, compressedObject, offset) {
      var data = compressedObject.compressedContent,
          utfEncodedFileName = this.utf8encode(file.name),
          useUTF8 = utfEncodedFileName !== file.name,
          o       = file.options,
          dosTime,
          dosDate;

      // date
      // @see http://www.delorie.com/djgpp/doc/rbinter/it/52/13.html
      // @see http://www.delorie.com/djgpp/doc/rbinter/it/65/16.html
      // @see http://www.delorie.com/djgpp/doc/rbinter/it/66/16.html

      dosTime = o.date.getHours();
      dosTime = dosTime << 6;
      dosTime = dosTime | o.date.getMinutes();
      dosTime = dosTime << 5;
      dosTime = dosTime | o.date.getSeconds() / 2;

      dosDate = o.date.getFullYear() - 1980;
      dosDate = dosDate << 4;
      dosDate = dosDate | (o.date.getMonth() + 1);
      dosDate = dosDate << 5;
      dosDate = dosDate | o.date.getDate();


      var header = "";

      // version needed to extract
      header += "\x0A\x00";
      // general purpose bit flag
      // set bit 11 if utf8
      header += useUTF8 ? "\x00\x08" : "\x00\x00";
      // compression method
      header += compressedObject.compressionMethod;
      // last mod file time
      header += decToHex(dosTime, 2);
      // last mod file date
      header += decToHex(dosDate, 2);
      // crc-32
      header += decToHex(compressedObject.crc32, 4);
      // compressed size
      header += decToHex(compressedObject.compressedSize, 4);
      // uncompressed size
      header += decToHex(compressedObject.uncompressedSize, 4);
      // file name length
      header += decToHex(utfEncodedFileName.length, 2);
      // extra field length
      header += "\x00\x00";


      var fileRecord = JSZip.signature.LOCAL_FILE_HEADER + header + utfEncodedFileName;

      var dirRecord = JSZip.signature.CENTRAL_FILE_HEADER +
      // version made by (00: DOS)
      "\x14\x00" +
      // file header (common to file and central directory)
      header +
      // file comment length
      "\x00\x00" +
      // disk number start
      "\x00\x00" +
      // internal file attributes TODO
      "\x00\x00" +
      // external file attributes
      (file.options.dir===true?"\x10\x00\x00\x00":"\x00\x00\x00\x00")+
      // relative offset of local header
      decToHex(offset, 4) +
      // file name
      utfEncodedFileName;


      return {
         fileRecord : fileRecord,
         dirRecord : dirRecord,
         compressedObject : compressedObject
      };
   };

   /**
    * An object to write any content to a string.
    * @constructor
    */
   var StringWriter = function () {
      this.data = [];
   };
   StringWriter.prototype = {
      /**
       * Append any content to the current string.
       * @param {Object} input the content to add.
       */
      append : function (input) {
         input = JSZip.utils.transformTo("string", input);
         this.data.push(input);
      },
      /**
       * Finalize the construction an return the result.
       * @return {string} the generated string.
       */
      finalize : function () {
         return this.data.join("");
      }
   };
   /**
    * An object to write any content to an Uint8Array.
    * @constructor
    * @param {number} length The length of the array.
    */
   var Uint8ArrayWriter = function (length) {
      this.data = new Uint8Array(length);
      this.index = 0;
   };
   Uint8ArrayWriter.prototype = {
      /**
       * Append any content to the current array.
       * @param {Object} input the content to add.
       */
      append : function (input) {
         if (input.length !== 0) {
            // with an empty Uint8Array, Opera fails with a "Offset larger than array size"
            input = JSZip.utils.transformTo("uint8array", input);
            this.data.set(input, this.index);
            this.index += input.length;
         }
      },
      /**
       * Finalize the construction an return the result.
       * @return {Uint8Array} the generated array.
       */
      finalize : function () {
         return this.data;
      }
   };

   // return the actual prototype of JSZip
   return {
      /**
       * Read an existing zip and merge the data in the current JSZip object.
       * The implementation is in jszip-load.js, don't forget to include it.
       * @param {String|ArrayBuffer|Uint8Array|Buffer} stream  The stream to load
       * @param {Object} options Options for loading the stream.
       *  options.base64 : is the stream in base64 ? default : false
       * @return {JSZip} the current JSZip object
       */
      load : function (stream, options) {
         throw new Error("Load method is not defined. Is the file jszip-load.js included ?");
      },

      /**
       * Filter nested files/folders with the specified function.
       * @param {Function} search the predicate to use :
       * function (relativePath, file) {...}
       * It takes 2 arguments : the relative path and the file.
       * @return {Array} An array of matching elements.
       */
      filter : function (search) {
         var result = [], filename, relativePath, file, fileClone;
         for (filename in this.files) {
            if ( !this.files.hasOwnProperty(filename) ) { continue; }
            file = this.files[filename];
            // return a new object, don't let the user mess with our internal objects :)
            fileClone = new ZipObject(file.name, file._data, extend(file.options));
            relativePath = filename.slice(this.root.length, filename.length);
            if (filename.slice(0, this.root.length) === this.root && // the file is in the current root
                search(relativePath, fileClone)) { // and the file matches the function
               result.push(fileClone);
            }
         }
         return result;
      },

      /**
       * Add a file to the zip file, or search a file.
       * @param   {string|RegExp} name The name of the file to add (if data is defined),
       * the name of the file to find (if no data) or a regex to match files.
       * @param   {String|ArrayBuffer|Uint8Array|Buffer} data  The file data, either raw or base64 encoded
       * @param   {Object} o     File options
       * @return  {JSZip|Object|Array} this JSZip object (when adding a file),
       * a file (when searching by string) or an array of files (when searching by regex).
       */
      file : function(name, data, o) {
         if (arguments.length === 1) {
            if (JSZip.utils.isRegExp(name)) {
               var regexp = name;
               return this.filter(function(relativePath, file) {
                  return !file.options.dir && regexp.test(relativePath);
               });
            } else { // text
               return this.filter(function (relativePath, file) {
                  return !file.options.dir && relativePath === name;
               })[0]||null;
            }
         } else { // more than one argument : we have data !
            name = this.root+name;
            fileAdd.call(this, name, data, o);
         }
         return this;
      },

      /**
       * Add a directory to the zip file, or search.
       * @param   {String|RegExp} arg The name of the directory to add, or a regex to search folders.
       * @return  {JSZip} an object with the new directory as the root, or an array containing matching folders.
       */
      folder : function(arg) {
         if (!arg) {
            return this;
         }

         if (JSZip.utils.isRegExp(arg)) {
            return this.filter(function(relativePath, file) {
               return file.options.dir && arg.test(relativePath);
            });
         }

         // else, name is a new folder
         var name = this.root + arg;
         var newFolder = folderAdd.call(this, name);

         // Allow chaining by returning a new object with this folder as the root
         var ret = this.clone();
         ret.root = newFolder.name;
         return ret;
      },

      /**
       * Delete a file, or a directory and all sub-files, from the zip
       * @param {string} name the name of the file to delete
       * @return {JSZip} this JSZip object
       */
      remove : function(name) {
         name = this.root + name;
         var file = this.files[name];
         if (!file) {
            // Look for any folders
            if (name.slice(-1) != "/") {
               name += "/";
            }
            file = this.files[name];
         }

         if (file) {
            if (!file.options.dir) {
               // file
               delete this.files[name];
            } else {
               // folder
               var kids = this.filter(function (relativePath, file) {
                  return file.name.slice(0, name.length) === name;
               });
               for (var i = 0; i < kids.length; i++) {
                  delete this.files[kids[i].name];
               }
            }
         }

         return this;
      },

      /**
       * Generate the complete zip file
       * @param {Object} options the options to generate the zip file :
       * - base64, (deprecated, use type instead) true to generate base64.
       * - compression, "STORE" by default.
       * - type, "base64" by default. Values are : string, base64, uint8array, arraybuffer, blob.
       * @return {String|Uint8Array|ArrayBuffer|Buffer|Blob} the zip file
       */
      generate : function(options) {
         options = extend(options || {}, {
            base64 : true,
            compression : "STORE",
            type : "base64"
         });

         JSZip.utils.checkSupport(options.type);

         var zipData = [], localDirLength = 0, centralDirLength = 0, writer, i;


         // first, generate all the zip parts.
         for (var name in this.files) {
            if ( !this.files.hasOwnProperty(name) ) { continue; }
            var file = this.files[name];

            var compressionName = file.options.compression || options.compression.toUpperCase();
            var compression = JSZip.compressions[compressionName];
            if (!compression) {
               throw new Error(compressionName + " is not a valid compression method !");
            }

            var compressedObject = generateCompressedObjectFrom.call(this, file, compression);

            var zipPart = generateZipParts.call(this, name, file, compressedObject, localDirLength);
            localDirLength += zipPart.fileRecord.length + compressedObject.compressedSize;
            centralDirLength += zipPart.dirRecord.length;
            zipData.push(zipPart);
         }

         var dirEnd = "";

         // end of central dir signature
         dirEnd = JSZip.signature.CENTRAL_DIRECTORY_END +
         // number of this disk
         "\x00\x00" +
         // number of the disk with the start of the central directory
         "\x00\x00" +
         // total number of entries in the central directory on this disk
         decToHex(zipData.length, 2) +
         // total number of entries in the central directory
         decToHex(zipData.length, 2) +
         // size of the central directory   4 bytes
         decToHex(centralDirLength, 4) +
         // offset of start of central directory with respect to the starting disk number
         decToHex(localDirLength, 4) +
         // .ZIP file comment length
         "\x00\x00";


         // we have all the parts (and the total length)
         // time to create a writer !
         switch(options.type.toLowerCase()) {
            case "uint8array" :
            case "arraybuffer" :
            case "blob" :
            case "nodebuffer" :
               writer = new Uint8ArrayWriter(localDirLength + centralDirLength + dirEnd.length);
               break;
            // case "base64" :
            // case "string" :
            default :
               writer = new StringWriter(localDirLength + centralDirLength + dirEnd.length);
               break;
         }

         for (i = 0; i < zipData.length; i++) {
            writer.append(zipData[i].fileRecord);
            writer.append(zipData[i].compressedObject.compressedContent);
         }
         for (i = 0; i < zipData.length; i++) {
            writer.append(zipData[i].dirRecord);
         }

         writer.append(dirEnd);

         var zip = writer.finalize();



         switch(options.type.toLowerCase()) {
            // case "zip is an Uint8Array"
            case "uint8array" :
            case "arraybuffer" :
            case "nodebuffer" :
               return JSZip.utils.transformTo(options.type.toLowerCase(), zip);
            case "blob" :
               return JSZip.utils.arrayBuffer2Blob(JSZip.utils.transformTo("arraybuffer", zip));

            // case "zip is a string"
            case "base64" :
               return (options.base64) ? JSZip.base64.encode(zip) : zip;
            default : // case "string" :
               return zip;
         }
      },

      /**
       *
       *  Javascript crc32
       *  http://www.webtoolkit.info/
       *
       */
      crc32 : function crc32(input, crc) {
         if (typeof input === "undefined" || !input.length) {
            return 0;
         }

         var isArray = JSZip.utils.getTypeOf(input) !== "string";

         var table = [
            0x00000000, 0x77073096, 0xEE0E612C, 0x990951BA,
            0x076DC419, 0x706AF48F, 0xE963A535, 0x9E6495A3,
            0x0EDB8832, 0x79DCB8A4, 0xE0D5E91E, 0x97D2D988,
            0x09B64C2B, 0x7EB17CBD, 0xE7B82D07, 0x90BF1D91,
            0x1DB71064, 0x6AB020F2, 0xF3B97148, 0x84BE41DE,
            0x1ADAD47D, 0x6DDDE4EB, 0xF4D4B551, 0x83D385C7,
            0x136C9856, 0x646BA8C0, 0xFD62F97A, 0x8A65C9EC,
            0x14015C4F, 0x63066CD9, 0xFA0F3D63, 0x8D080DF5,
            0x3B6E20C8, 0x4C69105E, 0xD56041E4, 0xA2677172,
            0x3C03E4D1, 0x4B04D447, 0xD20D85FD, 0xA50AB56B,
            0x35B5A8FA, 0x42B2986C, 0xDBBBC9D6, 0xACBCF940,
            0x32D86CE3, 0x45DF5C75, 0xDCD60DCF, 0xABD13D59,
            0x26D930AC, 0x51DE003A, 0xC8D75180, 0xBFD06116,
            0x21B4F4B5, 0x56B3C423, 0xCFBA9599, 0xB8BDA50F,
            0x2802B89E, 0x5F058808, 0xC60CD9B2, 0xB10BE924,
            0x2F6F7C87, 0x58684C11, 0xC1611DAB, 0xB6662D3D,
            0x76DC4190, 0x01DB7106, 0x98D220BC, 0xEFD5102A,
            0x71B18589, 0x06B6B51F, 0x9FBFE4A5, 0xE8B8D433,
            0x7807C9A2, 0x0F00F934, 0x9609A88E, 0xE10E9818,
            0x7F6A0DBB, 0x086D3D2D, 0x91646C97, 0xE6635C01,
            0x6B6B51F4, 0x1C6C6162, 0x856530D8, 0xF262004E,
            0x6C0695ED, 0x1B01A57B, 0x8208F4C1, 0xF50FC457,
            0x65B0D9C6, 0x12B7E950, 0x8BBEB8EA, 0xFCB9887C,
            0x62DD1DDF, 0x15DA2D49, 0x8CD37CF3, 0xFBD44C65,
            0x4DB26158, 0x3AB551CE, 0xA3BC0074, 0xD4BB30E2,
            0x4ADFA541, 0x3DD895D7, 0xA4D1C46D, 0xD3D6F4FB,
            0x4369E96A, 0x346ED9FC, 0xAD678846, 0xDA60B8D0,
            0x44042D73, 0x33031DE5, 0xAA0A4C5F, 0xDD0D7CC9,
            0x5005713C, 0x270241AA, 0xBE0B1010, 0xC90C2086,
            0x5768B525, 0x206F85B3, 0xB966D409, 0xCE61E49F,
            0x5EDEF90E, 0x29D9C998, 0xB0D09822, 0xC7D7A8B4,
            0x59B33D17, 0x2EB40D81, 0xB7BD5C3B, 0xC0BA6CAD,
            0xEDB88320, 0x9ABFB3B6, 0x03B6E20C, 0x74B1D29A,
            0xEAD54739, 0x9DD277AF, 0x04DB2615, 0x73DC1683,
            0xE3630B12, 0x94643B84, 0x0D6D6A3E, 0x7A6A5AA8,
            0xE40ECF0B, 0x9309FF9D, 0x0A00AE27, 0x7D079EB1,
            0xF00F9344, 0x8708A3D2, 0x1E01F268, 0x6906C2FE,
            0xF762575D, 0x806567CB, 0x196C3671, 0x6E6B06E7,
            0xFED41B76, 0x89D32BE0, 0x10DA7A5A, 0x67DD4ACC,
            0xF9B9DF6F, 0x8EBEEFF9, 0x17B7BE43, 0x60B08ED5,
            0xD6D6A3E8, 0xA1D1937E, 0x38D8C2C4, 0x4FDFF252,
            0xD1BB67F1, 0xA6BC5767, 0x3FB506DD, 0x48B2364B,
            0xD80D2BDA, 0xAF0A1B4C, 0x36034AF6, 0x41047A60,
            0xDF60EFC3, 0xA867DF55, 0x316E8EEF, 0x4669BE79,
            0xCB61B38C, 0xBC66831A, 0x256FD2A0, 0x5268E236,
            0xCC0C7795, 0xBB0B4703, 0x220216B9, 0x5505262F,
            0xC5BA3BBE, 0xB2BD0B28, 0x2BB45A92, 0x5CB36A04,
            0xC2D7FFA7, 0xB5D0CF31, 0x2CD99E8B, 0x5BDEAE1D,
            0x9B64C2B0, 0xEC63F226, 0x756AA39C, 0x026D930A,
            0x9C0906A9, 0xEB0E363F, 0x72076785, 0x05005713,
            0x95BF4A82, 0xE2B87A14, 0x7BB12BAE, 0x0CB61B38,
            0x92D28E9B, 0xE5D5BE0D, 0x7CDCEFB7, 0x0BDBDF21,
            0x86D3D2D4, 0xF1D4E242, 0x68DDB3F8, 0x1FDA836E,
            0x81BE16CD, 0xF6B9265B, 0x6FB077E1, 0x18B74777,
            0x88085AE6, 0xFF0F6A70, 0x66063BCA, 0x11010B5C,
            0x8F659EFF, 0xF862AE69, 0x616BFFD3, 0x166CCF45,
            0xA00AE278, 0xD70DD2EE, 0x4E048354, 0x3903B3C2,
            0xA7672661, 0xD06016F7, 0x4969474D, 0x3E6E77DB,
            0xAED16A4A, 0xD9D65ADC, 0x40DF0B66, 0x37D83BF0,
            0xA9BCAE53, 0xDEBB9EC5, 0x47B2CF7F, 0x30B5FFE9,
            0xBDBDF21C, 0xCABAC28A, 0x53B39330, 0x24B4A3A6,
            0xBAD03605, 0xCDD70693, 0x54DE5729, 0x23D967BF,
            0xB3667A2E, 0xC4614AB8, 0x5D681B02, 0x2A6F2B94,
            0xB40BBE37, 0xC30C8EA1, 0x5A05DF1B, 0x2D02EF8D
         ];

         if (typeof(crc) == "undefined") { crc = 0; }
         var x = 0;
         var y = 0;
         var byte = 0;

         crc = crc ^ (-1);
         for( var i = 0, iTop = input.length; i < iTop; i++ ) {
            byte = isArray ? input[i] : input.charCodeAt(i);
            y = ( crc ^ byte ) & 0xFF;
            x = table[y];
            crc = ( crc >>> 8 ) ^ x;
         }

         return crc ^ (-1);
      },

      // Inspired by http://my.opera.com/GreyWyvern/blog/show.dml/1725165
      clone : function() {
         var newObj = new JSZip();
         for (var i in this) {
            if (typeof this[i] !== "function") {
               newObj[i] = this[i];
            }
         }
         return newObj;
      },


      /**
       * http://www.webtoolkit.info/javascript-utf8.html
       */
      utf8encode : function (string) {
         // TextEncoder + Uint8Array to binary string is faster than checking every bytes on long strings.
         // http://jsperf.com/utf8encode-vs-textencoder
         // On short strings (file names for example), the TextEncoder API is (currently) slower.
         if (textEncoder) {
            var u8 = textEncoder.encode(string);
            return JSZip.utils.transformTo("string", u8);
         }
         if (JSZip.support.nodebuffer) {
            return JSZip.utils.transformTo("string", new Buffer(string, "utf-8"));
         }

         // array.join may be slower than string concatenation but generates less objects (less time spent garbage collecting).
         // See also http://jsperf.com/array-direct-assignment-vs-push/31
         var result = [], resIndex = 0;

         for (var n = 0; n < string.length; n++) {

            var c = string.charCodeAt(n);

            if (c < 128) {
               result[resIndex++] = String.fromCharCode(c);
            } else if ((c > 127) && (c < 2048)) {
               result[resIndex++] = String.fromCharCode((c >> 6) | 192);
               result[resIndex++] = String.fromCharCode((c & 63) | 128);
            } else {
               result[resIndex++] = String.fromCharCode((c >> 12) | 224);
               result[resIndex++] = String.fromCharCode(((c >> 6) & 63) | 128);
               result[resIndex++] = String.fromCharCode((c & 63) | 128);
            }

         }

         return result.join("");
      },

      /**
       * http://www.webtoolkit.info/javascript-utf8.html
       */
      utf8decode : function (input) {
         var result = [], resIndex = 0;
         var type = JSZip.utils.getTypeOf(input);
         var isArray = type !== "string";
         var i = 0;
         var c = 0, c1 = 0, c2 = 0, c3 = 0;

         // check if we can use the TextDecoder API
         // see http://encoding.spec.whatwg.org/#api
         if (textDecoder) {
            return textDecoder.decode(
               JSZip.utils.transformTo("uint8array", input)
            );
         }
         if (JSZip.support.nodebuffer) {
            return JSZip.utils.transformTo("nodebuffer", input).toString("utf-8");
         }

         while ( i < input.length ) {

            c = isArray ? input[i] : input.charCodeAt(i);

            if (c < 128) {
               result[resIndex++] = String.fromCharCode(c);
               i++;
            } else if ((c > 191) && (c < 224)) {
               c2 = isArray ? input[i+1] : input.charCodeAt(i+1);
               result[resIndex++] = String.fromCharCode(((c & 31) << 6) | (c2 & 63));
               i += 2;
            } else {
               c2 = isArray ? input[i+1] : input.charCodeAt(i+1);
               c3 = isArray ? input[i+2] : input.charCodeAt(i+2);
               result[resIndex++] = String.fromCharCode(((c & 15) << 12) | ((c2 & 63) << 6) | (c3 & 63));
               i += 3;
            }

         }

         return result.join("");
      }
   };
}());

/*
 * Compression methods
 * This object is filled in as follow :
 * name : {
 *    magic // the 2 bytes indentifying the compression method
 *    compress // function, take the uncompressed content and return it compressed.
 *    uncompress // function, take the compressed content and return it uncompressed.
 *    compressInputType // string, the type accepted by the compress method. null to accept everything.
 *    uncompressInputType // string, the type accepted by the uncompress method. null to accept everything.
 * }
 *
 * STORE is the default compression method, so it's included in this file.
 * Other methods should go to separated files : the user wants modularity.
 */
JSZip.compressions = {
   "STORE" : {
      magic : "\x00\x00",
      compress : function (content) {
         return content; // no compression
      },
      uncompress : function (content) {
         return content; // no compression
      },
      compressInputType : null,
      uncompressInputType : null
   }
};

(function () {
   JSZip.utils = {
      /**
       * Convert a string to a "binary string" : a string containing only char codes between 0 and 255.
       * @param {string} str the string to transform.
       * @return {String} the binary string.
       */
      string2binary : function (str) {
         var result = "";
         for (var i = 0; i < str.length; i++) {
            result += String.fromCharCode(str.charCodeAt(i) & 0xff);
         }
         return result;
      },
      /**
       * Create a Uint8Array from the string.
       * @param {string} str the string to transform.
       * @return {Uint8Array} the typed array.
       * @throws {Error} an Error if the browser doesn't support the requested feature.
       * @deprecated : use JSZip.utils.transformTo instead.
       */
      string2Uint8Array : function (str) {
         return JSZip.utils.transformTo("uint8array", str);
      },

      /**
       * Create a string from the Uint8Array.
       * @param {Uint8Array} array the array to transform.
       * @return {string} the string.
       * @throws {Error} an Error if the browser doesn't support the requested feature.
       * @deprecated : use JSZip.utils.transformTo instead.
       */
      uint8Array2String : function (array) {
         return JSZip.utils.transformTo("string", array);
      },
      /**
       * Create a blob from the given ArrayBuffer.
       * @param {ArrayBuffer} buffer the buffer to transform.
       * @return {Blob} the result.
       * @throws {Error} an Error if the browser doesn't support the requested feature.
       */
      arrayBuffer2Blob : function (buffer) {
         JSZip.utils.checkSupport("blob");

         try {
            // Blob constructor
            return new Blob([buffer], { type: "application/zip" });
         }
         catch(e) {}

         try {
            // deprecated, browser only, old way
            var BlobBuilder = window.BlobBuilder || window.WebKitBlobBuilder || window.MozBlobBuilder || window.MSBlobBuilder;
            var builder = new BlobBuilder();
            builder.append(buffer);
            return builder.getBlob('application/zip');
         }
         catch(e) {}

         // well, fuck ?!
         throw new Error("Bug : can't construct the Blob.");
      },
      /**
       * Create a blob from the given string.
       * @param {string} str the string to transform.
       * @return {Blob} the result.
       * @throws {Error} an Error if the browser doesn't support the requested feature.
       */
      string2Blob : function (str) {
         var buffer = JSZip.utils.transformTo("arraybuffer", str);
         return JSZip.utils.arrayBuffer2Blob(buffer);
      }
   };

   /**
    * The identity function.
    * @param {Object} input the input.
    * @return {Object} the same input.
    */
   function identity(input) {
      return input;
   }

   /**
    * Fill in an array with a string.
    * @param {String} str the string to use.
    * @param {Array|ArrayBuffer|Uint8Array|Buffer} array the array to fill in (will be mutated).
    * @return {Array|ArrayBuffer|Uint8Array|Buffer} the updated array.
    */
   function stringToArrayLike(str, array) {
      for (var i = 0; i < str.length; ++i) {
         array[i] = str.charCodeAt(i) & 0xFF;
      }
      return array;
   }

   /**
    * Transform an array-like object to a string.
    * @param {Array|ArrayBuffer|Uint8Array|Buffer} array the array to transform.
    * @return {String} the result.
    */
   function arrayLikeToString(array) {
      // Performances notes :
      // --------------------
      // String.fromCharCode.apply(null, array) is the fastest, see
      // see http://jsperf.com/converting-a-uint8array-to-a-string/2
      // but the stack is limited (and we can get huge arrays !).
      //
      // result += String.fromCharCode(array[i]); generate too many strings !
      //
      // This code is inspired by http://jsperf.com/arraybuffer-to-string-apply-performance/2
      var chunk = 65536;
      var result = [], len = array.length, type = JSZip.utils.getTypeOf(array), k = 0;

      var canUseApply = true;
      try {
         switch(type) {
            case "uint8array":
               String.fromCharCode.apply(null, new Uint8Array(0));
               break;
            case "nodebuffer":
               String.fromCharCode.apply(null, new Buffer(0));
               break;
         }
      } catch(e) {
         canUseApply = false;
      }

      // no apply : slow and painful algorithm
      // default browser on android 4.*
      if (!canUseApply) {
         var resultStr = "";
         for(var i = 0; i < array.length;i++) {
            resultStr += String.fromCharCode(array[i]);
         }
         return resultStr;
      }

      while (k < len && chunk > 1) {
         try {
            if (type === "array" || type === "nodebuffer") {
               result.push(String.fromCharCode.apply(null, array.slice(k, Math.min(k + chunk, len))));
            } else {
               result.push(String.fromCharCode.apply(null, array.subarray(k, Math.min(k + chunk, len))));
            }
            k += chunk;
         } catch (e) {
            chunk = Math.floor(chunk / 2);
         }
      }
      return result.join("");
   }

   /**
    * Copy the data from an array-like to an other array-like.
    * @param {Array|ArrayBuffer|Uint8Array|Buffer} arrayFrom the origin array.
    * @param {Array|ArrayBuffer|Uint8Array|Buffer} arrayTo the destination array which will be mutated.
    * @return {Array|ArrayBuffer|Uint8Array|Buffer} the updated destination array.
    */
   function arrayLikeToArrayLike(arrayFrom, arrayTo) {
      for(var i = 0; i < arrayFrom.length; i++) {
         arrayTo[i] = arrayFrom[i];
      }
      return arrayTo;
   }

   // a matrix containing functions to transform everything into everything.
   var transform = {};

   // string to ?
   transform["string"] = {
      "string" : identity,
      "array" : function (input) {
         return stringToArrayLike(input, new Array(input.length));
      },
      "arraybuffer" : function (input) {
         return transform["string"]["uint8array"](input).buffer;
      },
      "uint8array" : function (input) {
         return stringToArrayLike(input, new Uint8Array(input.length));
      },
      "nodebuffer" : function (input) {
         return stringToArrayLike(input, new Buffer(input.length));
      }
   };

   // array to ?
   transform["array"] = {
      "string" : arrayLikeToString,
      "array" : identity,
      "arraybuffer" : function (input) {
         return (new Uint8Array(input)).buffer;
      },
      "uint8array" : function (input) {
         return new Uint8Array(input);
      },
      "nodebuffer" : function (input) {
         return new Buffer(input);
      }
   };

   // arraybuffer to ?
   transform["arraybuffer"] = {
      "string" : function (input) {
         return arrayLikeToString(new Uint8Array(input));
      },
      "array" : function (input) {
         return arrayLikeToArrayLike(new Uint8Array(input), new Array(input.byteLength));
      },
      "arraybuffer" : identity,
      "uint8array" : function (input) {
         return new Uint8Array(input);
      },
      "nodebuffer" : function (input) {
         return new Buffer(new Uint8Array(input));
      }
   };

   // uint8array to ?
   transform["uint8array"] = {
      "string" : arrayLikeToString,
      "array" : function (input) {
         return arrayLikeToArrayLike(input, new Array(input.length));
      },
      "arraybuffer" : function (input) {
         return input.buffer;
      },
      "uint8array" : identity,
      "nodebuffer" : function(input) {
         return new Buffer(input);
      }
   };

   // nodebuffer to ?
   transform["nodebuffer"] = {
      "string" : arrayLikeToString,
      "array" : function (input) {
         return arrayLikeToArrayLike(input, new Array(input.length));
      },
      "arraybuffer" : function (input) {
         return transform["nodebuffer"]["uint8array"](input).buffer;
      },
      "uint8array" : function (input) {
         return arrayLikeToArrayLike(input, new Uint8Array(input.length));
      },
      "nodebuffer" : identity
   };

   /**
    * Transform an input into any type.
    * The supported output type are : string, array, uint8array, arraybuffer, nodebuffer.
    * If no output type is specified, the unmodified input will be returned.
    * @param {String} outputType the output type.
    * @param {String|Array|ArrayBuffer|Uint8Array|Buffer} input the input to convert.
    * @throws {Error} an Error if the browser doesn't support the requested output type.
    */
   JSZip.utils.transformTo = function (outputType, input) {
      if (!input) {
         // undefined, null, etc
         // an empty string won't harm.
         input = "";
      }
      if (!outputType) {
         return input;
      }
      JSZip.utils.checkSupport(outputType);
      var inputType = JSZip.utils.getTypeOf(input);
      var result = transform[inputType][outputType](input);
      return result;
   };

   /**
    * Return the type of the input.
    * The type will be in a format valid for JSZip.utils.transformTo : string, array, uint8array, arraybuffer.
    * @param {Object} input the input to identify.
    * @return {String} the (lowercase) type of the input.
    */
   JSZip.utils.getTypeOf = function (input) {
      if (typeof input === "string") {
         return "string";
      }
      if (Object.prototype.toString.call(input) === "[object Array]") {
         return "array";
      }
      if (JSZip.support.nodebuffer && Buffer.isBuffer(input)) {
         return "nodebuffer";
      }
      if (JSZip.support.uint8array && input instanceof Uint8Array) {
         return "uint8array";
      }
      if (JSZip.support.arraybuffer && input instanceof ArrayBuffer) {
         return "arraybuffer";
      }
   };

   /**
    * Cross-window, cross-Node-context regular expression detection
    * @param  {Object}  object Anything
    * @return {Boolean}        true if the object is a regular expression,
    * false otherwise
    */
   JSZip.utils.isRegExp = function (object) {
      return Object.prototype.toString.call(object) === "[object RegExp]";
   };

   /**
    * Throw an exception if the type is not supported.
    * @param {String} type the type to check.
    * @throws {Error} an Error if the browser doesn't support the requested type.
    */
   JSZip.utils.checkSupport = function (type) {
      var supported = true;
      switch (type.toLowerCase()) {
         case "uint8array":
            supported = JSZip.support.uint8array;
         break;
         case "arraybuffer":
            supported = JSZip.support.arraybuffer;
         break;
         case "nodebuffer":
            supported = JSZip.support.nodebuffer;
         break;
         case "blob":
            supported = JSZip.support.blob;
         break;
      }
      if (!supported) {
         throw new Error(type + " is not supported by this browser");
      }
   };


})();

(function (){
   /**
    * Represents an entry in the zip.
    * The content may or may not be compressed.
    * @constructor
    */
   JSZip.CompressedObject = function () {
         this.compressedSize = 0;
         this.uncompressedSize = 0;
         this.crc32 = 0;
         this.compressionMethod = null;
         this.compressedContent = null;
   };

   JSZip.CompressedObject.prototype = {
      /**
       * Return the decompressed content in an unspecified format.
       * The format will depend on the decompressor.
       * @return {Object} the decompressed content.
       */
      getContent : function () {
         return null; // see implementation
      },
      /**
       * Return the compressed content in an unspecified format.
       * The format will depend on the compressed conten source.
       * @return {Object} the compressed content.
       */
      getCompressedContent : function () {
         return null; // see implementation
      }
   };
})();

/**
 *
 *  Base64 encode / decode
 *  http://www.webtoolkit.info/
 *
 *  Hacked so that it doesn't utf8 en/decode everything
 **/
JSZip.base64 = (function() {
   // private property
   var _keyStr = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=";

   return {
      // public method for encoding
      encode : function(input, utf8) {
         var output = "";
         var chr1, chr2, chr3, enc1, enc2, enc3, enc4;
         var i = 0;

         while (i < input.length) {

            chr1 = input.charCodeAt(i++);
            chr2 = input.charCodeAt(i++);
            chr3 = input.charCodeAt(i++);

            enc1 = chr1 >> 2;
            enc2 = ((chr1 & 3) << 4) | (chr2 >> 4);
            enc3 = ((chr2 & 15) << 2) | (chr3 >> 6);
            enc4 = chr3 & 63;

            if (isNaN(chr2)) {
               enc3 = enc4 = 64;
            } else if (isNaN(chr3)) {
               enc4 = 64;
            }

            output = output +
               _keyStr.charAt(enc1) + _keyStr.charAt(enc2) +
               _keyStr.charAt(enc3) + _keyStr.charAt(enc4);

         }

         return output;
      },

      // public method for decoding
      decode : function(input, utf8) {
         var output = "";
         var chr1, chr2, chr3;
         var enc1, enc2, enc3, enc4;
         var i = 0;

         input = input.replace(/[^A-Za-z0-9\+\/\=]/g, "");

         while (i < input.length) {

            enc1 = _keyStr.indexOf(input.charAt(i++));
            enc2 = _keyStr.indexOf(input.charAt(i++));
            enc3 = _keyStr.indexOf(input.charAt(i++));
            enc4 = _keyStr.indexOf(input.charAt(i++));

            chr1 = (enc1 << 2) | (enc2 >> 4);
            chr2 = ((enc2 & 15) << 4) | (enc3 >> 2);
            chr3 = ((enc3 & 3) << 6) | enc4;

            output = output + String.fromCharCode(chr1);

            if (enc3 != 64) {
               output = output + String.fromCharCode(chr2);
            }
            if (enc4 != 64) {
               output = output + String.fromCharCode(chr3);
            }

         }

         return output;

      }
   };
}());

// enforcing Stuk's coding style
// vim: set shiftwidth=3 softtabstop=3:

/**

JSZip - A Javascript class for generating and reading zip files
<http://stuartk.com/jszip>

(c) 2011 David Duponchel <d.duponchel@gmail.com>
Dual licenced under the MIT license or GPLv3. See LICENSE.markdown.

**/
/*global JSZip */
(function (root) {
  "use strict";

   var JSZip = root.JSZip;

   var MAX_VALUE_16BITS = 65535;
   var MAX_VALUE_32BITS = -1; // well, "\xFF\xFF\xFF\xFF\xFF\xFF\xFF\xFF" is parsed as -1

   /**
    * Prettify a string read as binary.
    * @param {string} str the string to prettify.
    * @return {string} a pretty string.
    */
   var pretty = function (str) {
      var res = '', code, i;
      for (i = 0; i < (str||"").length; i++) {
         code = str.charCodeAt(i);
         res += '\\x' + (code < 16 ? "0" : "") + code.toString(16).toUpperCase();
      }
      return res;
   };

   /**
    * Find a compression registered in JSZip.
    * @param {string} compressionMethod the method magic to find.
    * @return {Object|null} the JSZip compression object, null if none found.
    */
   var findCompression = function (compressionMethod) {
      for (var method in JSZip.compressions) {
         if( !JSZip.compressions.hasOwnProperty(method) ) { continue; }
         if (JSZip.compressions[method].magic === compressionMethod) {
            return JSZip.compressions[method];
         }
      }
      return null;
   };

   // class DataReader {{{
   /**
    * Read bytes from a source.
    * Developer tip : when debugging, a watch on pretty(this.reader.data.slice(this.reader.index))
    * is very useful :)
    * @constructor
    * @param {String|ArrayBuffer|Uint8Array|Buffer} data the data to read.
    */
   function DataReader(data) {
      this.data = null; // type : see implementation
      this.length = 0;
      this.index = 0;
   }
   DataReader.prototype = {
      /**
       * Check that the offset will not go too far.
       * @param {string} offset the additional offset to check.
       * @throws {Error} an Error if the offset is out of bounds.
       */
      checkOffset : function (offset) {
         this.checkIndex(this.index + offset);
      },
      /**
       * Check that the specifed index will not be too far.
       * @param {string} newIndex the index to check.
       * @throws {Error} an Error if the index is out of bounds.
       */
      checkIndex : function (newIndex) {
         if (this.length < newIndex || newIndex < 0) {
            throw new Error("End of data reached (data length = " +
                            this.length + ", asked index = " +
                            (newIndex) + "). Corrupted zip ?");
         }
      },
      /**
       * Change the index.
       * @param {number} newIndex The new index.
       * @throws {Error} if the new index is out of the data.
       */
      setIndex : function (newIndex) {
         this.checkIndex(newIndex);
         this.index = newIndex;
      },
      /**
       * Skip the next n bytes.
       * @param {number} n the number of bytes to skip.
       * @throws {Error} if the new index is out of the data.
       */
      skip : function (n) {
         this.setIndex(this.index + n);
      },
      /**
       * Get the byte at the specified index.
       * @param {number} i the index to use.
       * @return {number} a byte.
       */
      byteAt : function(i) {
         // see implementations
      },
      /**
       * Get the next number with a given byte size.
       * @param {number} size the number of bytes to read.
       * @return {number} the corresponding number.
       */
      readInt : function (size) {
         var result = 0, i;
         this.checkOffset(size);
         for(i = this.index + size - 1; i >= this.index; i--) {
            result = (result << 8) + this.byteAt(i);
         }
         this.index += size;
         return result;
      },
      /**
       * Get the next string with a given byte size.
       * @param {number} size the number of bytes to read.
       * @return {string} the corresponding string.
       */
      readString : function (size) {
         return JSZip.utils.transformTo("string", this.readData(size));
      },
      /**
       * Get raw data without conversion, <size> bytes.
       * @param {number} size the number of bytes to read.
       * @return {Object} the raw data, implementation specific.
       */
      readData : function (size) {
         // see implementations
      },
      /**
       * Find the last occurence of a zip signature (4 bytes).
       * @param {string} sig the signature to find.
       * @return {number} the index of the last occurence, -1 if not found.
       */
      lastIndexOfSignature : function (sig) {
         // see implementations
      },
      /**
       * Get the next date.
       * @return {Date} the date.
       */
      readDate : function () {
         var dostime = this.readInt(4);
         return new Date(
            ((dostime >> 25) & 0x7f) + 1980, // year
            ((dostime >> 21) & 0x0f) - 1, // month
            (dostime >> 16) & 0x1f, // day
            (dostime >> 11) & 0x1f, // hour
            (dostime >> 5) & 0x3f, // minute
            (dostime & 0x1f) << 1); // second
      }
   };


   /**
    * Read bytes from a string.
    * @constructor
    * @param {String} data the data to read.
    */
   function StringReader(data, optimizedBinaryString) {
      this.data = data;
      if (!optimizedBinaryString) {
         this.data = JSZip.utils.string2binary(this.data);
      }
      this.length = this.data.length;
      this.index = 0;
   }
   StringReader.prototype = new DataReader();
   /**
    * @see DataReader.byteAt
    */
   StringReader.prototype.byteAt = function(i) {
      return this.data.charCodeAt(i);
   };
   /**
    * @see DataReader.lastIndexOfSignature
    */
   StringReader.prototype.lastIndexOfSignature = function (sig) {
      return this.data.lastIndexOf(sig);
   };
   /**
    * @see DataReader.readData
    */
   StringReader.prototype.readData = function (size) {
      this.checkOffset(size);
      // this will work because the constructor applied the "& 0xff" mask.
      var result = this.data.slice(this.index, this.index + size);
      this.index += size;
      return result;
   };


   /**
    * Read bytes from an Uin8Array.
    * @constructor
    * @param {Uint8Array} data the data to read.
    */
   function Uint8ArrayReader(data) {
      if (data) {
         this.data = data;
         this.length = this.data.length;
         this.index = 0;
      }
   }
   Uint8ArrayReader.prototype = new DataReader();
   /**
    * @see DataReader.byteAt
    */
   Uint8ArrayReader.prototype.byteAt = function(i) {
      return this.data[i];
   };
   /**
    * @see DataReader.lastIndexOfSignature
    */
   Uint8ArrayReader.prototype.lastIndexOfSignature = function (sig) {
      var sig0 = sig.charCodeAt(0),
      sig1 = sig.charCodeAt(1),
      sig2 = sig.charCodeAt(2),
      sig3 = sig.charCodeAt(3);
      for(var i = this.length - 4;i >= 0;--i) {
         if (this.data[i] === sig0 && this.data[i+1] === sig1 && this.data[i+2] === sig2 && this.data[i+3] === sig3) {
            return i;
         }
      }

      return -1;
   };
   /**
    * @see DataReader.readData
    */
   Uint8ArrayReader.prototype.readData = function (size) {
      this.checkOffset(size);
      var result = this.data.subarray(this.index, this.index + size);
      this.index += size;
      return result;
   };

   /**
    * Read bytes from a Buffer.
    * @constructor
    * @param {Buffer} data the data to read.
    */
   function NodeBufferReader(data) {
      this.data = data;
      this.length = this.data.length;
      this.index = 0;
   }
   NodeBufferReader.prototype = new Uint8ArrayReader();

   /**
    * @see DataReader.readData
    */
   NodeBufferReader.prototype.readData = function (size) {
      this.checkOffset(size);
      var result = this.data.slice(this.index, this.index + size);
      this.index += size;
      return result;
   };
   // }}} end of DataReader

   // class ZipEntry {{{
   /**
    * An entry in the zip file.
    * @constructor
    * @param {Object} options Options of the current file.
    * @param {Object} loadOptions Options for loading the data.
    */
   function ZipEntry(options, loadOptions) {
      this.options = options;
      this.loadOptions = loadOptions;
   }
   ZipEntry.prototype = {
      /**
       * say if the file is encrypted.
       * @return {boolean} true if the file is encrypted, false otherwise.
       */
      isEncrypted : function () {
         // bit 1 is set
         return (this.bitFlag & 0x0001) === 0x0001;
      },
      /**
       * say if the file has utf-8 filename/comment.
       * @return {boolean} true if the filename/comment is in utf-8, false otherwise.
       */
      useUTF8 : function () {
         // bit 11 is set
         return (this.bitFlag & 0x0800) === 0x0800;
      },
      /**
       * Prepare the function used to generate the compressed content from this ZipFile.
       * @param {DataReader} reader the reader to use.
       * @param {number} from the offset from where we should read the data.
       * @param {number} length the length of the data to read.
       * @return {Function} the callback to get the compressed content (the type depends of the DataReader class).
       */
      prepareCompressedContent : function (reader, from, length) {
         return function () {
            var previousIndex = reader.index;
            reader.setIndex(from);
            var compressedFileData = reader.readData(length);
            reader.setIndex(previousIndex);

            return compressedFileData;
         };
      },
      /**
       * Prepare the function used to generate the uncompressed content from this ZipFile.
       * @param {DataReader} reader the reader to use.
       * @param {number} from the offset from where we should read the data.
       * @param {number} length the length of the data to read.
       * @param {JSZip.compression} compression the compression used on this file.
       * @param {number} uncompressedSize the uncompressed size to expect.
       * @return {Function} the callback to get the uncompressed content (the type depends of the DataReader class).
       */
      prepareContent : function (reader, from, length, compression, uncompressedSize) {
         return function () {

            var compressedFileData = JSZip.utils.transformTo(compression.uncompressInputType, this.getCompressedContent());
            var uncompressedFileData = compression.uncompress(compressedFileData);

            if (uncompressedFileData.length !== uncompressedSize) {
               throw new Error("Bug : uncompressed data size mismatch");
            }

            return uncompressedFileData;
         };
      },
      /**
       * Read the local part of a zip file and add the info in this object.
       * @param {DataReader} reader the reader to use.
       */
      readLocalPart : function(reader) {
         var compression, localExtraFieldsLength;

         // we already know everything from the central dir !
         // If the central dir data are false, we are doomed.
         // On the bright side, the local part is scary  : zip64, data descriptors, both, etc.
         // The less data we get here, the more reliable this should be.
         // Let's skip the whole header and dash to the data !
         reader.skip(22);
         // in some zip created on windows, the filename stored in the central dir contains \ instead of /.
         // Strangely, the filename here is OK.
         // I would love to treat these zip files as corrupted (see http://www.info-zip.org/FAQ.html#backslashes
         // or APPNOTE#4.4.17.1, "All slashes MUST be forward slashes '/'") but there are a lot of bad zip generators...
         // Search "unzip mismatching "local" filename continuing with "central" filename version" on
         // the internet.
         //
         // I think I see the logic here : the central directory is used to display
         // content and the local directory is used to extract the files. Mixing / and \
         // may be used to display \ to windows users and use / when extracting the files.
         // Unfortunately, this lead also to some issues : http://seclists.org/fulldisclosure/2009/Sep/394
         this.fileNameLength = reader.readInt(2);
         localExtraFieldsLength = reader.readInt(2); // can't be sure this will be the same as the central dir
         this.fileName = reader.readString(this.fileNameLength);
         reader.skip(localExtraFieldsLength);

         if (this.compressedSize == -1 || this.uncompressedSize == -1) {
            throw new Error("Bug or corrupted zip : didn't get enough informations from the central directory " +
                            "(compressedSize == -1 || uncompressedSize == -1)");
         }

         compression = findCompression(this.compressionMethod);
         if (compression === null) { // no compression found
            throw new Error("Corrupted zip : compression " + pretty(this.compressionMethod) +
                            " unknown (inner file : " + this.fileName + ")");
         }
         this.decompressed = new JSZip.CompressedObject();
         this.decompressed.compressedSize = this.compressedSize;
         this.decompressed.uncompressedSize = this.uncompressedSize;
         this.decompressed.crc32 = this.crc32;
         this.decompressed.compressionMethod = this.compressionMethod;
         this.decompressed.getCompressedContent = this.prepareCompressedContent(reader, reader.index, this.compressedSize, compression);
         this.decompressed.getContent = this.prepareContent(reader, reader.index, this.compressedSize, compression, this.uncompressedSize);

         // we need to compute the crc32...
         if (this.loadOptions.checkCRC32) {
            this.decompressed = JSZip.utils.transformTo("string", this.decompressed.getContent());
            if (JSZip.prototype.crc32(this.decompressed) !== this.crc32) {
               throw new Error("Corrupted zip : CRC32 mismatch");
            }
         }
      },

      /**
       * Read the central part of a zip file and add the info in this object.
       * @param {DataReader} reader the reader to use.
       */
      readCentralPart : function(reader) {
         this.versionMadeBy          = reader.readString(2);
         this.versionNeeded          = reader.readInt(2);
         this.bitFlag                = reader.readInt(2);
         this.compressionMethod      = reader.readString(2);
         this.date                   = reader.readDate();
         this.crc32                  = reader.readInt(4);
         this.compressedSize         = reader.readInt(4);
         this.uncompressedSize       = reader.readInt(4);
         this.fileNameLength         = reader.readInt(2);
         this.extraFieldsLength      = reader.readInt(2);
         this.fileCommentLength      = reader.readInt(2);
         this.diskNumberStart        = reader.readInt(2);
         this.internalFileAttributes = reader.readInt(2);
         this.externalFileAttributes = reader.readInt(4);
         this.localHeaderOffset      = reader.readInt(4);

         if (this.isEncrypted()) {
            throw new Error("Encrypted zip are not supported");
         }

         this.fileName = reader.readString(this.fileNameLength);
         this.readExtraFields(reader);
         this.parseZIP64ExtraField(reader);
         this.fileComment = reader.readString(this.fileCommentLength);

         // warning, this is true only for zip with madeBy == DOS (plateform dependent feature)
         this.dir = this.externalFileAttributes & 0x00000010 ? true : false;
      },
      /**
       * Parse the ZIP64 extra field and merge the info in the current ZipEntry.
       * @param {DataReader} reader the reader to use.
       */
      parseZIP64ExtraField : function(reader) {

         if(!this.extraFields[0x0001]) {
            return;
         }

         // should be something, preparing the extra reader
         var extraReader = new StringReader(this.extraFields[0x0001].value);

         // I really hope that these 64bits integer can fit in 32 bits integer, because js
         // won't let us have more.
         if(this.uncompressedSize === MAX_VALUE_32BITS) {
            this.uncompressedSize = extraReader.readInt(8);
         }
         if(this.compressedSize === MAX_VALUE_32BITS) {
            this.compressedSize = extraReader.readInt(8);
         }
         if(this.localHeaderOffset === MAX_VALUE_32BITS) {
            this.localHeaderOffset = extraReader.readInt(8);
         }
         if(this.diskNumberStart === MAX_VALUE_32BITS) {
            this.diskNumberStart = extraReader.readInt(4);
         }
      },
      /**
       * Read the central part of a zip file and add the info in this object.
       * @param {DataReader} reader the reader to use.
       */
      readExtraFields : function(reader) {
         var start = reader.index,
             extraFieldId,
             extraFieldLength,
             extraFieldValue;

         this.extraFields = this.extraFields || {};

         while (reader.index < start + this.extraFieldsLength) {
            extraFieldId     = reader.readInt(2);
            extraFieldLength = reader.readInt(2);
            extraFieldValue  = reader.readString(extraFieldLength);

            this.extraFields[extraFieldId] = {
               id:     extraFieldId,
               length: extraFieldLength,
               value:  extraFieldValue
            };
         }
      },
      /**
       * Apply an UTF8 transformation if needed.
       */
      handleUTF8 : function() {
         if (this.useUTF8()) {
            this.fileName    = JSZip.prototype.utf8decode(this.fileName);
            this.fileComment = JSZip.prototype.utf8decode(this.fileComment);
         }
      }
   };
   // }}} end of ZipEntry

   //  class ZipEntries {{{
   /**
    * All the entries in the zip file.
    * @constructor
    * @param {String|ArrayBuffer|Uint8Array|Buffer} data the binary data to load.
    * @param {Object} loadOptions Options for loading the data.
    */
   function ZipEntries(data, loadOptions) {
      this.files = [];
      this.loadOptions = loadOptions;
      if (data) {
         this.load(data);
      }
   }
   ZipEntries.prototype = {
      /**
       * Check that the reader is on the speficied signature.
       * @param {string} expectedSignature the expected signature.
       * @throws {Error} if it is an other signature.
       */
      checkSignature : function(expectedSignature) {
         var signature = this.reader.readString(4);
         if (signature !== expectedSignature) {
            throw new Error("Corrupted zip or bug : unexpected signature " +
                            "(" + pretty(signature) + ", expected " + pretty(expectedSignature) + ")");
         }
      },
      /**
       * Read the end of the central directory.
       */
      readBlockEndOfCentral : function () {
         this.diskNumber                  = this.reader.readInt(2);
         this.diskWithCentralDirStart     = this.reader.readInt(2);
         this.centralDirRecordsOnThisDisk = this.reader.readInt(2);
         this.centralDirRecords           = this.reader.readInt(2);
         this.centralDirSize              = this.reader.readInt(4);
         this.centralDirOffset            = this.reader.readInt(4);

         this.zipCommentLength            = this.reader.readInt(2);
         this.zipComment                  = this.reader.readString(this.zipCommentLength);
      },
      /**
       * Read the end of the Zip 64 central directory.
       * Not merged with the method readEndOfCentral :
       * The end of central can coexist with its Zip64 brother,
       * I don't want to read the wrong number of bytes !
       */
      readBlockZip64EndOfCentral : function () {
         this.zip64EndOfCentralSize       = this.reader.readInt(8);
         this.versionMadeBy               = this.reader.readString(2);
         this.versionNeeded               = this.reader.readInt(2);
         this.diskNumber                  = this.reader.readInt(4);
         this.diskWithCentralDirStart     = this.reader.readInt(4);
         this.centralDirRecordsOnThisDisk = this.reader.readInt(8);
         this.centralDirRecords           = this.reader.readInt(8);
         this.centralDirSize              = this.reader.readInt(8);
         this.centralDirOffset            = this.reader.readInt(8);

         this.zip64ExtensibleData = {};
         var extraDataSize = this.zip64EndOfCentralSize - 44,
         index = 0,
         extraFieldId,
         extraFieldLength,
         extraFieldValue;
         while(index < extraDataSize) {
            extraFieldId     = this.reader.readInt(2);
            extraFieldLength = this.reader.readInt(4);
            extraFieldValue  = this.reader.readString(extraFieldLength);
            this.zip64ExtensibleData[extraFieldId] = {
               id:     extraFieldId,
               length: extraFieldLength,
               value:  extraFieldValue
            };
         }
      },
      /**
       * Read the end of the Zip 64 central directory locator.
       */
      readBlockZip64EndOfCentralLocator : function () {
         this.diskWithZip64CentralDirStart       = this.reader.readInt(4);
         this.relativeOffsetEndOfZip64CentralDir = this.reader.readInt(8);
         this.disksCount                         = this.reader.readInt(4);
         if (this.disksCount > 1) {
            throw new Error("Multi-volumes zip are not supported");
         }
      },
      /**
       * Read the local files, based on the offset read in the central part.
       */
      readLocalFiles : function() {
         var i, file;
         for(i = 0; i < this.files.length; i++) {
            file = this.files[i];
            this.reader.setIndex(file.localHeaderOffset);
            this.checkSignature(JSZip.signature.LOCAL_FILE_HEADER);
            file.readLocalPart(this.reader);
            file.handleUTF8();
         }
      },
      /**
       * Read the central directory.
       */
      readCentralDir : function() {
         var file;

         this.reader.setIndex(this.centralDirOffset);
         while(this.reader.readString(4) === JSZip.signature.CENTRAL_FILE_HEADER) {
            file = new ZipEntry({
               zip64: this.zip64
            }, this.loadOptions);
            file.readCentralPart(this.reader);
            this.files.push(file);
         }
      },
      /**
       * Read the end of central directory.
       */
      readEndOfCentral : function() {
         var offset = this.reader.lastIndexOfSignature(JSZip.signature.CENTRAL_DIRECTORY_END);
         if (offset === -1) {
            throw new Error("Corrupted zip : can't find end of central directory");
         }
         this.reader.setIndex(offset);
         this.checkSignature(JSZip.signature.CENTRAL_DIRECTORY_END);
         this.readBlockEndOfCentral();


         /* extract from the zip spec :
            4)  If one of the fields in the end of central directory
                record is too small to hold required data, the field
                should be set to -1 (0xFFFF or 0xFFFFFFFF) and the
                ZIP64 format record should be created.
            5)  The end of central directory record and the
                Zip64 end of central directory locator record must
                reside on the same disk when splitting or spanning
                an archive.
         */
         if (this.diskNumber                 === MAX_VALUE_16BITS ||
            this.diskWithCentralDirStart     === MAX_VALUE_16BITS ||
            this.centralDirRecordsOnThisDisk === MAX_VALUE_16BITS ||
            this.centralDirRecords           === MAX_VALUE_16BITS ||
            this.centralDirSize              === MAX_VALUE_32BITS ||
            this.centralDirOffset            === MAX_VALUE_32BITS
         ) {
            this.zip64 = true;

            /*
            Warning : the zip64 extension is supported, but ONLY if the 64bits integer read from
            the zip file can fit into a 32bits integer. This cannot be solved : Javascript represents
            all numbers as 64-bit double precision IEEE 754 floating point numbers.
            So, we have 53bits for integers and bitwise operations treat everything as 32bits.
            see https://developer.mozilla.org/en-US/docs/JavaScript/Reference/Operators/Bitwise_Operators
            and http://www.ecma-international.org/publications/files/ECMA-ST/ECMA-262.pdf section 8.5
            */

            // should look for a zip64 EOCD locator
            offset = this.reader.lastIndexOfSignature(JSZip.signature.ZIP64_CENTRAL_DIRECTORY_LOCATOR);
            if (offset === -1) {
               throw new Error("Corrupted zip : can't find the ZIP64 end of central directory locator");
            }
            this.reader.setIndex(offset);
            this.checkSignature(JSZip.signature.ZIP64_CENTRAL_DIRECTORY_LOCATOR);
            this.readBlockZip64EndOfCentralLocator();

            // now the zip64 EOCD record
            this.reader.setIndex(this.relativeOffsetEndOfZip64CentralDir);
            this.checkSignature(JSZip.signature.ZIP64_CENTRAL_DIRECTORY_END);
            this.readBlockZip64EndOfCentral();
         }
      },
      prepareReader : function (data) {
         var type = JSZip.utils.getTypeOf(data);
         if (type === "string" && !JSZip.support.uint8array) {
            this.reader = new StringReader(data, this.loadOptions.optimizedBinaryString);
         } else if (type === "nodebuffer") {
            this.reader = new NodeBufferReader(data);
         } else {
            this.reader = new Uint8ArrayReader(JSZip.utils.transformTo("uint8array", data));
         }
      },
      /**
       * Read a zip file and create ZipEntries.
       * @param {String|ArrayBuffer|Uint8Array|Buffer} data the binary string representing a zip file.
       */
      load : function(data) {
         this.prepareReader(data);
         this.readEndOfCentral();
         this.readCentralDir();
         this.readLocalFiles();
      }
   };
   // }}} end of ZipEntries

   /**
    * Implementation of the load method of JSZip.
    * It uses the above classes to decode a zip file, and load every files.
    * @param {String|ArrayBuffer|Uint8Array|Buffer} data the data to load.
    * @param {Object} options Options for loading the data.
    *  options.base64 : is the data in base64 ? default : false
    */
   JSZip.prototype.load = function(data, options) {
      var files, zipEntries, i, input;
      options = options || {};
      if(options.base64) {
         data = JSZip.base64.decode(data);
      }

      zipEntries = new ZipEntries(data, options);
      files = zipEntries.files;
      for (i = 0; i < files.length; i++) {
         input = files[i];
         this.file(input.fileName, input.decompressed, {
            binary:true,
            optimizedBinaryString:true,
            date:input.date,
            dir:input.dir
         });
      }

      return this;
   };

}(this));
// enforcing Stuk's coding style
// vim: set shiftwidth=3 softtabstop=3 foldmethod=marker:

(function () {
   "use strict";

   if(!JSZip) {
      throw "JSZip not defined";
   }

   /*jshint -W004, -W018, -W030, -W032, -W033, -W034, -W037,-W040, -W055, -W056, -W061, -W064, -W093, -W117 */
   var context = {};
   (function () {

      // https://github.com/imaya/zlib.js
      // tag 0.1.6
      // file bin/deflate.min.js

/** @license zlib.js 2012 - imaya [ https://github.com/imaya/zlib.js ] The MIT License */(function() {'use strict';var n=void 0,u=!0,aa=this;function ba(e,d){var c=e.split("."),f=aa;!(c[0]in f)&&f.execScript&&f.execScript("var "+c[0]);for(var a;c.length&&(a=c.shift());)!c.length&&d!==n?f[a]=d:f=f[a]?f[a]:f[a]={}};var C="undefined"!==typeof Uint8Array&&"undefined"!==typeof Uint16Array&&"undefined"!==typeof Uint32Array;function K(e,d){this.index="number"===typeof d?d:0;this.d=0;this.buffer=e instanceof(C?Uint8Array:Array)?e:new (C?Uint8Array:Array)(32768);if(2*this.buffer.length<=this.index)throw Error("invalid index");this.buffer.length<=this.index&&ca(this)}function ca(e){var d=e.buffer,c,f=d.length,a=new (C?Uint8Array:Array)(f<<1);if(C)a.set(d);else for(c=0;c<f;++c)a[c]=d[c];return e.buffer=a}
K.prototype.a=function(e,d,c){var f=this.buffer,a=this.index,b=this.d,k=f[a],m;c&&1<d&&(e=8<d?(L[e&255]<<24|L[e>>>8&255]<<16|L[e>>>16&255]<<8|L[e>>>24&255])>>32-d:L[e]>>8-d);if(8>d+b)k=k<<d|e,b+=d;else for(m=0;m<d;++m)k=k<<1|e>>d-m-1&1,8===++b&&(b=0,f[a++]=L[k],k=0,a===f.length&&(f=ca(this)));f[a]=k;this.buffer=f;this.d=b;this.index=a};K.prototype.finish=function(){var e=this.buffer,d=this.index,c;0<this.d&&(e[d]<<=8-this.d,e[d]=L[e[d]],d++);C?c=e.subarray(0,d):(e.length=d,c=e);return c};
var ga=new (C?Uint8Array:Array)(256),M;for(M=0;256>M;++M){for(var R=M,S=R,ha=7,R=R>>>1;R;R>>>=1)S<<=1,S|=R&1,--ha;ga[M]=(S<<ha&255)>>>0}var L=ga;function ja(e){this.buffer=new (C?Uint16Array:Array)(2*e);this.length=0}ja.prototype.getParent=function(e){return 2*((e-2)/4|0)};ja.prototype.push=function(e,d){var c,f,a=this.buffer,b;c=this.length;a[this.length++]=d;for(a[this.length++]=e;0<c;)if(f=this.getParent(c),a[c]>a[f])b=a[c],a[c]=a[f],a[f]=b,b=a[c+1],a[c+1]=a[f+1],a[f+1]=b,c=f;else break;return this.length};
ja.prototype.pop=function(){var e,d,c=this.buffer,f,a,b;d=c[0];e=c[1];this.length-=2;c[0]=c[this.length];c[1]=c[this.length+1];for(b=0;;){a=2*b+2;if(a>=this.length)break;a+2<this.length&&c[a+2]>c[a]&&(a+=2);if(c[a]>c[b])f=c[b],c[b]=c[a],c[a]=f,f=c[b+1],c[b+1]=c[a+1],c[a+1]=f;else break;b=a}return{index:e,value:d,length:this.length}};function ka(e,d){this.e=ma;this.f=0;this.input=C&&e instanceof Array?new Uint8Array(e):e;this.c=0;d&&(d.lazy&&(this.f=d.lazy),"number"===typeof d.compressionType&&(this.e=d.compressionType),d.outputBuffer&&(this.b=C&&d.outputBuffer instanceof Array?new Uint8Array(d.outputBuffer):d.outputBuffer),"number"===typeof d.outputIndex&&(this.c=d.outputIndex));this.b||(this.b=new (C?Uint8Array:Array)(32768))}var ma=2,T=[],U;
for(U=0;288>U;U++)switch(u){case 143>=U:T.push([U+48,8]);break;case 255>=U:T.push([U-144+400,9]);break;case 279>=U:T.push([U-256+0,7]);break;case 287>=U:T.push([U-280+192,8]);break;default:throw"invalid literal: "+U;}
ka.prototype.h=function(){var e,d,c,f,a=this.input;switch(this.e){case 0:c=0;for(f=a.length;c<f;){d=C?a.subarray(c,c+65535):a.slice(c,c+65535);c+=d.length;var b=d,k=c===f,m=n,g=n,p=n,v=n,x=n,l=this.b,h=this.c;if(C){for(l=new Uint8Array(this.b.buffer);l.length<=h+b.length+5;)l=new Uint8Array(l.length<<1);l.set(this.b)}m=k?1:0;l[h++]=m|0;g=b.length;p=~g+65536&65535;l[h++]=g&255;l[h++]=g>>>8&255;l[h++]=p&255;l[h++]=p>>>8&255;if(C)l.set(b,h),h+=b.length,l=l.subarray(0,h);else{v=0;for(x=b.length;v<x;++v)l[h++]=
b[v];l.length=h}this.c=h;this.b=l}break;case 1:var q=new K(C?new Uint8Array(this.b.buffer):this.b,this.c);q.a(1,1,u);q.a(1,2,u);var t=na(this,a),w,da,z;w=0;for(da=t.length;w<da;w++)if(z=t[w],K.prototype.a.apply(q,T[z]),256<z)q.a(t[++w],t[++w],u),q.a(t[++w],5),q.a(t[++w],t[++w],u);else if(256===z)break;this.b=q.finish();this.c=this.b.length;break;case ma:var B=new K(C?new Uint8Array(this.b.buffer):this.b,this.c),ra,J,N,O,P,Ia=[16,17,18,0,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15],W,sa,X,ta,ea,ia=Array(19),
ua,Q,fa,y,va;ra=ma;B.a(1,1,u);B.a(ra,2,u);J=na(this,a);W=oa(this.j,15);sa=pa(W);X=oa(this.i,7);ta=pa(X);for(N=286;257<N&&0===W[N-1];N--);for(O=30;1<O&&0===X[O-1];O--);var wa=N,xa=O,F=new (C?Uint32Array:Array)(wa+xa),r,G,s,Y,E=new (C?Uint32Array:Array)(316),D,A,H=new (C?Uint8Array:Array)(19);for(r=G=0;r<wa;r++)F[G++]=W[r];for(r=0;r<xa;r++)F[G++]=X[r];if(!C){r=0;for(Y=H.length;r<Y;++r)H[r]=0}r=D=0;for(Y=F.length;r<Y;r+=G){for(G=1;r+G<Y&&F[r+G]===F[r];++G);s=G;if(0===F[r])if(3>s)for(;0<s--;)E[D++]=0,
H[0]++;else for(;0<s;)A=138>s?s:138,A>s-3&&A<s&&(A=s-3),10>=A?(E[D++]=17,E[D++]=A-3,H[17]++):(E[D++]=18,E[D++]=A-11,H[18]++),s-=A;else if(E[D++]=F[r],H[F[r]]++,s--,3>s)for(;0<s--;)E[D++]=F[r],H[F[r]]++;else for(;0<s;)A=6>s?s:6,A>s-3&&A<s&&(A=s-3),E[D++]=16,E[D++]=A-3,H[16]++,s-=A}e=C?E.subarray(0,D):E.slice(0,D);ea=oa(H,7);for(y=0;19>y;y++)ia[y]=ea[Ia[y]];for(P=19;4<P&&0===ia[P-1];P--);ua=pa(ea);B.a(N-257,5,u);B.a(O-1,5,u);B.a(P-4,4,u);for(y=0;y<P;y++)B.a(ia[y],3,u);y=0;for(va=e.length;y<va;y++)if(Q=
e[y],B.a(ua[Q],ea[Q],u),16<=Q){y++;switch(Q){case 16:fa=2;break;case 17:fa=3;break;case 18:fa=7;break;default:throw"invalid code: "+Q;}B.a(e[y],fa,u)}var ya=[sa,W],za=[ta,X],I,Aa,Z,la,Ba,Ca,Da,Ea;Ba=ya[0];Ca=ya[1];Da=za[0];Ea=za[1];I=0;for(Aa=J.length;I<Aa;++I)if(Z=J[I],B.a(Ba[Z],Ca[Z],u),256<Z)B.a(J[++I],J[++I],u),la=J[++I],B.a(Da[la],Ea[la],u),B.a(J[++I],J[++I],u);else if(256===Z)break;this.b=B.finish();this.c=this.b.length;break;default:throw"invalid compression type";}return this.b};
function qa(e,d){this.length=e;this.g=d}
var Fa=function(){function e(a){switch(u){case 3===a:return[257,a-3,0];case 4===a:return[258,a-4,0];case 5===a:return[259,a-5,0];case 6===a:return[260,a-6,0];case 7===a:return[261,a-7,0];case 8===a:return[262,a-8,0];case 9===a:return[263,a-9,0];case 10===a:return[264,a-10,0];case 12>=a:return[265,a-11,1];case 14>=a:return[266,a-13,1];case 16>=a:return[267,a-15,1];case 18>=a:return[268,a-17,1];case 22>=a:return[269,a-19,2];case 26>=a:return[270,a-23,2];case 30>=a:return[271,a-27,2];case 34>=a:return[272,
a-31,2];case 42>=a:return[273,a-35,3];case 50>=a:return[274,a-43,3];case 58>=a:return[275,a-51,3];case 66>=a:return[276,a-59,3];case 82>=a:return[277,a-67,4];case 98>=a:return[278,a-83,4];case 114>=a:return[279,a-99,4];case 130>=a:return[280,a-115,4];case 162>=a:return[281,a-131,5];case 194>=a:return[282,a-163,5];case 226>=a:return[283,a-195,5];case 257>=a:return[284,a-227,5];case 258===a:return[285,a-258,0];default:throw"invalid length: "+a;}}var d=[],c,f;for(c=3;258>=c;c++)f=e(c),d[c]=f[2]<<24|
f[1]<<16|f[0];return d}(),Ga=C?new Uint32Array(Fa):Fa;
function na(e,d){function c(a,c){var b=a.g,d=[],f=0,e;e=Ga[a.length];d[f++]=e&65535;d[f++]=e>>16&255;d[f++]=e>>24;var g;switch(u){case 1===b:g=[0,b-1,0];break;case 2===b:g=[1,b-2,0];break;case 3===b:g=[2,b-3,0];break;case 4===b:g=[3,b-4,0];break;case 6>=b:g=[4,b-5,1];break;case 8>=b:g=[5,b-7,1];break;case 12>=b:g=[6,b-9,2];break;case 16>=b:g=[7,b-13,2];break;case 24>=b:g=[8,b-17,3];break;case 32>=b:g=[9,b-25,3];break;case 48>=b:g=[10,b-33,4];break;case 64>=b:g=[11,b-49,4];break;case 96>=b:g=[12,b-
65,5];break;case 128>=b:g=[13,b-97,5];break;case 192>=b:g=[14,b-129,6];break;case 256>=b:g=[15,b-193,6];break;case 384>=b:g=[16,b-257,7];break;case 512>=b:g=[17,b-385,7];break;case 768>=b:g=[18,b-513,8];break;case 1024>=b:g=[19,b-769,8];break;case 1536>=b:g=[20,b-1025,9];break;case 2048>=b:g=[21,b-1537,9];break;case 3072>=b:g=[22,b-2049,10];break;case 4096>=b:g=[23,b-3073,10];break;case 6144>=b:g=[24,b-4097,11];break;case 8192>=b:g=[25,b-6145,11];break;case 12288>=b:g=[26,b-8193,12];break;case 16384>=
b:g=[27,b-12289,12];break;case 24576>=b:g=[28,b-16385,13];break;case 32768>=b:g=[29,b-24577,13];break;default:throw"invalid distance";}e=g;d[f++]=e[0];d[f++]=e[1];d[f++]=e[2];var k,m;k=0;for(m=d.length;k<m;++k)l[h++]=d[k];t[d[0]]++;w[d[3]]++;q=a.length+c-1;x=null}var f,a,b,k,m,g={},p,v,x,l=C?new Uint16Array(2*d.length):[],h=0,q=0,t=new (C?Uint32Array:Array)(286),w=new (C?Uint32Array:Array)(30),da=e.f,z;if(!C){for(b=0;285>=b;)t[b++]=0;for(b=0;29>=b;)w[b++]=0}t[256]=1;f=0;for(a=d.length;f<a;++f){b=
m=0;for(k=3;b<k&&f+b!==a;++b)m=m<<8|d[f+b];g[m]===n&&(g[m]=[]);p=g[m];if(!(0<q--)){for(;0<p.length&&32768<f-p[0];)p.shift();if(f+3>=a){x&&c(x,-1);b=0;for(k=a-f;b<k;++b)z=d[f+b],l[h++]=z,++t[z];break}0<p.length?(v=Ha(d,f,p),x?x.length<v.length?(z=d[f-1],l[h++]=z,++t[z],c(v,0)):c(x,-1):v.length<da?x=v:c(v,0)):x?c(x,-1):(z=d[f],l[h++]=z,++t[z])}p.push(f)}l[h++]=256;t[256]++;e.j=t;e.i=w;return C?l.subarray(0,h):l}
function Ha(e,d,c){var f,a,b=0,k,m,g,p,v=e.length;m=0;p=c.length;a:for(;m<p;m++){f=c[p-m-1];k=3;if(3<b){for(g=b;3<g;g--)if(e[f+g-1]!==e[d+g-1])continue a;k=b}for(;258>k&&d+k<v&&e[f+k]===e[d+k];)++k;k>b&&(a=f,b=k);if(258===k)break}return new qa(b,d-a)}
function oa(e,d){var c=e.length,f=new ja(572),a=new (C?Uint8Array:Array)(c),b,k,m,g,p;if(!C)for(g=0;g<c;g++)a[g]=0;for(g=0;g<c;++g)0<e[g]&&f.push(g,e[g]);b=Array(f.length/2);k=new (C?Uint32Array:Array)(f.length/2);if(1===b.length)return a[f.pop().index]=1,a;g=0;for(p=f.length/2;g<p;++g)b[g]=f.pop(),k[g]=b[g].value;m=Ja(k,k.length,d);g=0;for(p=b.length;g<p;++g)a[b[g].index]=m[g];return a}
function Ja(e,d,c){function f(a){var b=g[a][p[a]];b===d?(f(a+1),f(a+1)):--k[b];++p[a]}var a=new (C?Uint16Array:Array)(c),b=new (C?Uint8Array:Array)(c),k=new (C?Uint8Array:Array)(d),m=Array(c),g=Array(c),p=Array(c),v=(1<<c)-d,x=1<<c-1,l,h,q,t,w;a[c-1]=d;for(h=0;h<c;++h)v<x?b[h]=0:(b[h]=1,v-=x),v<<=1,a[c-2-h]=(a[c-1-h]/2|0)+d;a[0]=b[0];m[0]=Array(a[0]);g[0]=Array(a[0]);for(h=1;h<c;++h)a[h]>2*a[h-1]+b[h]&&(a[h]=2*a[h-1]+b[h]),m[h]=Array(a[h]),g[h]=Array(a[h]);for(l=0;l<d;++l)k[l]=c;for(q=0;q<a[c-1];++q)m[c-
1][q]=e[q],g[c-1][q]=q;for(l=0;l<c;++l)p[l]=0;1===b[c-1]&&(--k[0],++p[c-1]);for(h=c-2;0<=h;--h){t=l=0;w=p[h+1];for(q=0;q<a[h];q++)t=m[h+1][w]+m[h+1][w+1],t>e[l]?(m[h][q]=t,g[h][q]=d,w+=2):(m[h][q]=e[l],g[h][q]=l,++l);p[h]=0;1===b[h]&&f(h)}return k}
function pa(e){var d=new (C?Uint16Array:Array)(e.length),c=[],f=[],a=0,b,k,m,g;b=0;for(k=e.length;b<k;b++)c[e[b]]=(c[e[b]]|0)+1;b=1;for(k=16;b<=k;b++)f[b]=a,a+=c[b]|0,a<<=1;b=0;for(k=e.length;b<k;b++){a=f[e[b]];f[e[b]]+=1;m=d[b]=0;for(g=e[b];m<g;m++)d[b]=d[b]<<1|a&1,a>>>=1}return d};ba("Zlib.RawDeflate",ka);ba("Zlib.RawDeflate.prototype.compress",ka.prototype.h);var Ka={NONE:0,FIXED:1,DYNAMIC:ma},V,La,$,Ma;if(Object.keys)V=Object.keys(Ka);else for(La in V=[],$=0,Ka)V[$++]=La;$=0;for(Ma=V.length;$<Ma;++$)La=V[$],ba("Zlib.RawDeflate.CompressionType."+La,Ka[La]);}).call(this); //@ sourceMappingURL=rawdeflate.min.js.map


   }).call(context);
   /*jshint +W004, +W018, +W030, +W032, +W033, +W034, +W037,+W040, +W055, +W056, +W061, +W064, +W093, +W117 */

   var compress = function (input) {
      var deflate = new context.Zlib.RawDeflate(input);
      return deflate.compress();
   };

   var USE_TYPEDARRAY =
      (typeof Uint8Array !== 'undefined') &&
      (typeof Uint16Array !== 'undefined') &&
      (typeof Uint32Array !== 'undefined');


   // we add the compression method for JSZip
   if(!JSZip.compressions["DEFLATE"]) {
      JSZip.compressions["DEFLATE"] = {
         magic : "\x08\x00",
         compress : compress,
         compressInputType : USE_TYPEDARRAY ? "uint8array" : "array"
      };
   } else {
      JSZip.compressions["DEFLATE"].compress = compress;
      JSZip.compressions["DEFLATE"].compressInputType = USE_TYPEDARRAY ? "uint8array" : "array";
   }
})();

// enforcing Stuk's coding style
// vim: set shiftwidth=3 softtabstop=3:

(function () {
   "use strict";

   if(!JSZip) {
      throw "JSZip not defined";
   }

   /*jshint -W004, -W030, -W032, -W033, -W034, -W040, -W056, -W061, -W064, -W093 */
   var context = {};
   (function () {

      // https://github.com/imaya/zlib.js
      // tag 0.1.6
      // file bin/deflate.min.js

/** @license zlib.js 2012 - imaya [ https://github.com/imaya/zlib.js ] The MIT License */(function() {'use strict';var l=void 0,p=this;function q(c,d){var a=c.split("."),b=p;!(a[0]in b)&&b.execScript&&b.execScript("var "+a[0]);for(var e;a.length&&(e=a.shift());)!a.length&&d!==l?b[e]=d:b=b[e]?b[e]:b[e]={}};var r="undefined"!==typeof Uint8Array&&"undefined"!==typeof Uint16Array&&"undefined"!==typeof Uint32Array;function u(c){var d=c.length,a=0,b=Number.POSITIVE_INFINITY,e,f,g,h,k,m,s,n,t;for(n=0;n<d;++n)c[n]>a&&(a=c[n]),c[n]<b&&(b=c[n]);e=1<<a;f=new (r?Uint32Array:Array)(e);g=1;h=0;for(k=2;g<=a;){for(n=0;n<d;++n)if(c[n]===g){m=0;s=h;for(t=0;t<g;++t)m=m<<1|s&1,s>>=1;for(t=m;t<e;t+=k)f[t]=g<<16|n;++h}++g;h<<=1;k<<=1}return[f,a,b]};function v(c,d){this.g=[];this.h=32768;this.c=this.f=this.d=this.k=0;this.input=r?new Uint8Array(c):c;this.l=!1;this.i=w;this.p=!1;if(d||!(d={}))d.index&&(this.d=d.index),d.bufferSize&&(this.h=d.bufferSize),d.bufferType&&(this.i=d.bufferType),d.resize&&(this.p=d.resize);switch(this.i){case x:this.a=32768;this.b=new (r?Uint8Array:Array)(32768+this.h+258);break;case w:this.a=0;this.b=new (r?Uint8Array:Array)(this.h);this.e=this.u;this.m=this.r;this.j=this.s;break;default:throw Error("invalid inflate mode");
}}var x=0,w=1;
v.prototype.t=function(){for(;!this.l;){var c=y(this,3);c&1&&(this.l=!0);c>>>=1;switch(c){case 0:var d=this.input,a=this.d,b=this.b,e=this.a,f=l,g=l,h=l,k=b.length,m=l;this.c=this.f=0;f=d[a++];if(f===l)throw Error("invalid uncompressed block header: LEN (first byte)");g=f;f=d[a++];if(f===l)throw Error("invalid uncompressed block header: LEN (second byte)");g|=f<<8;f=d[a++];if(f===l)throw Error("invalid uncompressed block header: NLEN (first byte)");h=f;f=d[a++];if(f===l)throw Error("invalid uncompressed block header: NLEN (second byte)");h|=
f<<8;if(g===~h)throw Error("invalid uncompressed block header: length verify");if(a+g>d.length)throw Error("input buffer is broken");switch(this.i){case x:for(;e+g>b.length;){m=k-e;g-=m;if(r)b.set(d.subarray(a,a+m),e),e+=m,a+=m;else for(;m--;)b[e++]=d[a++];this.a=e;b=this.e();e=this.a}break;case w:for(;e+g>b.length;)b=this.e({o:2});break;default:throw Error("invalid inflate mode");}if(r)b.set(d.subarray(a,a+g),e),e+=g,a+=g;else for(;g--;)b[e++]=d[a++];this.d=a;this.a=e;this.b=b;break;case 1:this.j(z,
A);break;case 2:B(this);break;default:throw Error("unknown BTYPE: "+c);}}return this.m()};
var C=[16,17,18,0,8,7,9,6,10,5,11,4,12,3,13,2,14,1,15],D=r?new Uint16Array(C):C,E=[3,4,5,6,7,8,9,10,11,13,15,17,19,23,27,31,35,43,51,59,67,83,99,115,131,163,195,227,258,258,258],F=r?new Uint16Array(E):E,G=[0,0,0,0,0,0,0,0,1,1,1,1,2,2,2,2,3,3,3,3,4,4,4,4,5,5,5,5,0,0,0],H=r?new Uint8Array(G):G,I=[1,2,3,4,5,7,9,13,17,25,33,49,65,97,129,193,257,385,513,769,1025,1537,2049,3073,4097,6145,8193,12289,16385,24577],J=r?new Uint16Array(I):I,K=[0,0,0,0,1,1,2,2,3,3,4,4,5,5,6,6,7,7,8,8,9,9,10,10,11,11,12,12,13,
13],L=r?new Uint8Array(K):K,M=new (r?Uint8Array:Array)(288),N,O;N=0;for(O=M.length;N<O;++N)M[N]=143>=N?8:255>=N?9:279>=N?7:8;var z=u(M),P=new (r?Uint8Array:Array)(30),Q,R;Q=0;for(R=P.length;Q<R;++Q)P[Q]=5;var A=u(P);function y(c,d){for(var a=c.f,b=c.c,e=c.input,f=c.d,g;b<d;){g=e[f++];if(g===l)throw Error("input buffer is broken");a|=g<<b;b+=8}g=a&(1<<d)-1;c.f=a>>>d;c.c=b-d;c.d=f;return g}
function S(c,d){for(var a=c.f,b=c.c,e=c.input,f=c.d,g=d[0],h=d[1],k,m,s;b<h;){k=e[f++];if(k===l)break;a|=k<<b;b+=8}m=g[a&(1<<h)-1];s=m>>>16;c.f=a>>s;c.c=b-s;c.d=f;return m&65535}
function B(c){function d(a,c,b){var d,f,e,g;for(g=0;g<a;)switch(d=S(this,c),d){case 16:for(e=3+y(this,2);e--;)b[g++]=f;break;case 17:for(e=3+y(this,3);e--;)b[g++]=0;f=0;break;case 18:for(e=11+y(this,7);e--;)b[g++]=0;f=0;break;default:f=b[g++]=d}return b}var a=y(c,5)+257,b=y(c,5)+1,e=y(c,4)+4,f=new (r?Uint8Array:Array)(D.length),g,h,k,m;for(m=0;m<e;++m)f[D[m]]=y(c,3);g=u(f);h=new (r?Uint8Array:Array)(a);k=new (r?Uint8Array:Array)(b);c.j(u(d.call(c,a,g,h)),u(d.call(c,b,g,k)))}
v.prototype.j=function(c,d){var a=this.b,b=this.a;this.n=c;for(var e=a.length-258,f,g,h,k;256!==(f=S(this,c));)if(256>f)b>=e&&(this.a=b,a=this.e(),b=this.a),a[b++]=f;else{g=f-257;k=F[g];0<H[g]&&(k+=y(this,H[g]));f=S(this,d);h=J[f];0<L[f]&&(h+=y(this,L[f]));b>=e&&(this.a=b,a=this.e(),b=this.a);for(;k--;)a[b]=a[b++-h]}for(;8<=this.c;)this.c-=8,this.d--;this.a=b};
v.prototype.s=function(c,d){var a=this.b,b=this.a;this.n=c;for(var e=a.length,f,g,h,k;256!==(f=S(this,c));)if(256>f)b>=e&&(a=this.e(),e=a.length),a[b++]=f;else{g=f-257;k=F[g];0<H[g]&&(k+=y(this,H[g]));f=S(this,d);h=J[f];0<L[f]&&(h+=y(this,L[f]));b+k>e&&(a=this.e(),e=a.length);for(;k--;)a[b]=a[b++-h]}for(;8<=this.c;)this.c-=8,this.d--;this.a=b};
v.prototype.e=function(){var c=new (r?Uint8Array:Array)(this.a-32768),d=this.a-32768,a,b,e=this.b;if(r)c.set(e.subarray(32768,c.length));else{a=0;for(b=c.length;a<b;++a)c[a]=e[a+32768]}this.g.push(c);this.k+=c.length;if(r)e.set(e.subarray(d,d+32768));else for(a=0;32768>a;++a)e[a]=e[d+a];this.a=32768;return e};
v.prototype.u=function(c){var d,a=this.input.length/this.d+1|0,b,e,f,g=this.input,h=this.b;c&&("number"===typeof c.o&&(a=c.o),"number"===typeof c.q&&(a+=c.q));2>a?(b=(g.length-this.d)/this.n[2],f=258*(b/2)|0,e=f<h.length?h.length+f:h.length<<1):e=h.length*a;r?(d=new Uint8Array(e),d.set(h)):d=h;return this.b=d};
v.prototype.m=function(){var c=0,d=this.b,a=this.g,b,e=new (r?Uint8Array:Array)(this.k+(this.a-32768)),f,g,h,k;if(0===a.length)return r?this.b.subarray(32768,this.a):this.b.slice(32768,this.a);f=0;for(g=a.length;f<g;++f){b=a[f];h=0;for(k=b.length;h<k;++h)e[c++]=b[h]}f=32768;for(g=this.a;f<g;++f)e[c++]=d[f];this.g=[];return this.buffer=e};
v.prototype.r=function(){var c,d=this.a;r?this.p?(c=new Uint8Array(d),c.set(this.b.subarray(0,d))):c=this.b.subarray(0,d):(this.b.length>d&&(this.b.length=d),c=this.b);return this.buffer=c};q("Zlib.RawInflate",v);q("Zlib.RawInflate.prototype.decompress",v.prototype.t);var T={ADAPTIVE:w,BLOCK:x},U,V,W,X;if(Object.keys)U=Object.keys(T);else for(V in U=[],W=0,T)U[W++]=V;W=0;for(X=U.length;W<X;++W)V=U[W],q("Zlib.RawInflate.BufferType."+V,T[V]);}).call(this); //@ sourceMappingURL=rawinflate.min.js.map


   }).call(context);
   /*jshint +W004, +W030, +W032, +W033, +W034, +W040, +W056, +W061, +W064, +W093 */

   var uncompress = function (input) {
      var inflate = new context.Zlib.RawInflate(input);
      return inflate.decompress();
   };

   var USE_TYPEDARRAY =
      (typeof Uint8Array !== 'undefined') &&
      (typeof Uint16Array !== 'undefined') &&
      (typeof Uint32Array !== 'undefined');


   // we add the compression method for JSZip
   if(!JSZip.compressions["DEFLATE"]) {
      JSZip.compressions["DEFLATE"] = {
         magic : "\x08\x00",
         uncompress : uncompress,
         uncompressInputType : USE_TYPEDARRAY ? "uint8array" : "array"
      };
   } else {
      JSZip.compressions["DEFLATE"].uncompress = uncompress;
      JSZip.compressions["DEFLATE"].uncompressInputType = USE_TYPEDARRAY ? "uint8array" : "array";
   }
})();

// enforcing Stuk's coding style
// vim: set shiftwidth=3 softtabstop=3:

/**
 * marked - a markdown parser
 * Copyright (c) 2011-2014, Christopher Jeffrey. (MIT Licensed)
 * https://github.com/chjj/marked
 */

;(function() {

/**
 * Block-Level Grammar
 */

var block = {
  newline: /^\n+/,
  code: /^( {4}[^\n]+\n*)+/,
  fences: noop,
  hr: /^( *[-*_]){3,} *(?:\n+|$)/,
  heading: /^ *(#{1,6}) *([^\n]+?) *#* *(?:\n+|$)/,
  nptable: noop,
  lheading: /^([^\n]+)\n *(=|-){2,} *(?:\n+|$)/,
  blockquote: /^( *>[^\n]+(\n(?!def)[^\n]+)*\n*)+/,
  list: /^( *)(bull) [\s\S]+?(?:hr|def|\n{2,}(?! )(?!\1bull )\n*|\s*$)/,
  html: /^ *(?:comment *(?:\n|\s*$)|closed *(?:\n{2,}|\s*$)|closing *(?:\n{2,}|\s*$))/,
  def: /^ *\[([^\]]+)\]: *<?([^\s>]+)>?(?: +["(]([^\n]+)[")])? *(?:\n+|$)/,
  table: noop,
  paragraph: /^((?:[^\n]+\n?(?!hr|heading|lheading|blockquote|tag|def))+)\n*/,
  text: /^[^\n]+/
};

block.bullet = /(?:[*+-]|\d+\.)/;
block.item = /^( *)(bull) [^\n]*(?:\n(?!\1bull )[^\n]*)*/;
block.item = replace(block.item, 'gm')
  (/bull/g, block.bullet)
  ();

block.list = replace(block.list)
  (/bull/g, block.bullet)
  ('hr', '\\n+(?=\\1?(?:[-*_] *){3,}(?:\\n+|$))')
  ('def', '\\n+(?=' + block.def.source + ')')
  ();

block.blockquote = replace(block.blockquote)
  ('def', block.def)
  ();

block._tag = '(?!(?:'
  + 'a|em|strong|small|s|cite|q|dfn|abbr|data|time|code'
  + '|var|samp|kbd|sub|sup|i|b|u|mark|ruby|rt|rp|bdi|bdo'
  + '|span|br|wbr|ins|del|img)\\b)\\w+(?!:/|[^\\w\\s@]*@)\\b';

block.html = replace(block.html)
  ('comment', /<!--[\s\S]*?-->/)
  ('closed', /<(tag)[\s\S]+?<\/\1>/)
  ('closing', /<tag(?:"[^"]*"|'[^']*'|[^'">])*?>/)
  (/tag/g, block._tag)
  ();

block.paragraph = replace(block.paragraph)
  ('hr', block.hr)
  ('heading', block.heading)
  ('lheading', block.lheading)
  ('blockquote', block.blockquote)
  ('tag', '<' + block._tag)
  ('def', block.def)
  ();

/**
 * Normal Block Grammar
 */

block.normal = merge({}, block);

/**
 * GFM Block Grammar
 */

block.gfm = merge({}, block.normal, {
  fences: /^ *(`{3,}|~{3,})[ \.]*(\S+)? *\n([\s\S]*?)\s*\1 *(?:\n+|$)/,
  paragraph: /^/,
  heading: /^ *(#{1,6}) +([^\n]+?) *#* *(?:\n+|$)/
});

block.gfm.paragraph = replace(block.paragraph)
  ('(?!', '(?!'
    + block.gfm.fences.source.replace('\\1', '\\2') + '|'
    + block.list.source.replace('\\1', '\\3') + '|')
  ();

/**
 * GFM + Tables Block Grammar
 */

block.tables = merge({}, block.gfm, {
  nptable: /^ *(\S.*\|.*)\n *([-:]+ *\|[-| :]*)\n((?:.*\|.*(?:\n|$))*)\n*/,
  table: /^ *\|(.+)\n *\|( *[-:]+[-| :]*)\n((?: *\|.*(?:\n|$))*)\n*/
});

/**
 * Block Lexer
 */

function Lexer(options) {
  this.tokens = [];
  this.tokens.links = {};
  this.options = options || marked.defaults;
  this.rules = block.normal;

  if (this.options.gfm) {
    if (this.options.tables) {
      this.rules = block.tables;
    } else {
      this.rules = block.gfm;
    }
  }
}

/**
 * Expose Block Rules
 */

Lexer.rules = block;

/**
 * Static Lex Method
 */

Lexer.lex = function(src, options) {
  var lexer = new Lexer(options);
  return lexer.lex(src);
};

/**
 * Preprocessing
 */

Lexer.prototype.lex = function(src) {
  src = src
    .replace(/\r\n|\r/g, '\n')
    .replace(/\t/g, '    ')
    .replace(/\u00a0/g, ' ')
    .replace(/\u2424/g, '\n');

  return this.token(src, true);
};

/**
 * Lexing
 */

Lexer.prototype.token = function(src, top, bq) {
  var src = src.replace(/^ +$/gm, '')
    , next
    , loose
    , cap
    , bull
    , b
    , item
    , space
    , i
    , l;

  while (src) {
    // newline
    if (cap = this.rules.newline.exec(src)) {
      src = src.substring(cap[0].length);
      if (cap[0].length > 1) {
        this.tokens.push({
          type: 'space'
        });
      }
    }

    // code
    if (cap = this.rules.code.exec(src)) {
      src = src.substring(cap[0].length);
      cap = cap[0].replace(/^ {4}/gm, '');
      this.tokens.push({
        type: 'code',
        text: !this.options.pedantic
          ? cap.replace(/\n+$/, '')
          : cap
      });
      continue;
    }

    // fences (gfm)
    if (cap = this.rules.fences.exec(src)) {
      src = src.substring(cap[0].length);
      this.tokens.push({
        type: 'code',
        lang: cap[2],
        text: cap[3] || ''
      });
      continue;
    }

    // heading
    if (cap = this.rules.heading.exec(src)) {
      src = src.substring(cap[0].length);
      this.tokens.push({
        type: 'heading',
        depth: cap[1].length,
        text: cap[2]
      });
      continue;
    }

    // table no leading pipe (gfm)
    if (top && (cap = this.rules.nptable.exec(src))) {
      src = src.substring(cap[0].length);

      item = {
        type: 'table',
        header: cap[1].replace(/^ *| *\| *$/g, '').split(/ *\| */),
        align: cap[2].replace(/^ *|\| *$/g, '').split(/ *\| */),
        cells: cap[3].replace(/\n$/, '').split('\n')
      };

      for (i = 0; i < item.align.length; i++) {
        if (/^ *-+: *$/.test(item.align[i])) {
          item.align[i] = 'right';
        } else if (/^ *:-+: *$/.test(item.align[i])) {
          item.align[i] = 'center';
        } else if (/^ *:-+ *$/.test(item.align[i])) {
          item.align[i] = 'left';
        } else {
          item.align[i] = null;
        }
      }

      for (i = 0; i < item.cells.length; i++) {
        item.cells[i] = item.cells[i].split(/ *\| */);
      }

      this.tokens.push(item);

      continue;
    }

    // lheading
    if (cap = this.rules.lheading.exec(src)) {
      src = src.substring(cap[0].length);
      this.tokens.push({
        type: 'heading',
        depth: cap[2] === '=' ? 1 : 2,
        text: cap[1]
      });
      continue;
    }

    // hr
    if (cap = this.rules.hr.exec(src)) {
      src = src.substring(cap[0].length);
      this.tokens.push({
        type: 'hr'
      });
      continue;
    }

    // blockquote
    if (cap = this.rules.blockquote.exec(src)) {
      src = src.substring(cap[0].length);

      this.tokens.push({
        type: 'blockquote_start'
      });

      cap = cap[0].replace(/^ *> ?/gm, '');

      // Pass `top` to keep the current
      // "toplevel" state. This is exactly
      // how markdown.pl works.
      this.token(cap, top, true);

      this.tokens.push({
        type: 'blockquote_end'
      });

      continue;
    }

    // list
    if (cap = this.rules.list.exec(src)) {
      src = src.substring(cap[0].length);
      bull = cap[2];

      this.tokens.push({
        type: 'list_start',
        ordered: bull.length > 1
      });

      // Get each top-level item.
      cap = cap[0].match(this.rules.item);

      next = false;
      l = cap.length;
      i = 0;

      for (; i < l; i++) {
        item = cap[i];

        // Remove the list item's bullet
        // so it is seen as the next token.
        space = item.length;
        item = item.replace(/^ *([*+-]|\d+\.) +/, '');

        // Outdent whatever the
        // list item contains. Hacky.
        if (~item.indexOf('\n ')) {
          space -= item.length;
          item = !this.options.pedantic
            ? item.replace(new RegExp('^ {1,' + space + '}', 'gm'), '')
            : item.replace(/^ {1,4}/gm, '');
        }

        // Determine whether the next list item belongs here.
        // Backpedal if it does not belong in this list.
        if (this.options.smartLists && i !== l - 1) {
          b = block.bullet.exec(cap[i + 1])[0];
          if (bull !== b && !(bull.length > 1 && b.length > 1)) {
            src = cap.slice(i + 1).join('\n') + src;
            i = l - 1;
          }
        }

        // Determine whether item is loose or not.
        // Use: /(^|\n)(?! )[^\n]+\n\n(?!\s*$)/
        // for discount behavior.
        loose = next || /\n\n(?!\s*$)/.test(item);
        if (i !== l - 1) {
          next = item.charAt(item.length - 1) === '\n';
          if (!loose) loose = next;
        }

        this.tokens.push({
          type: loose
            ? 'loose_item_start'
            : 'list_item_start'
        });

        // Recurse.
        this.token(item, false, bq);

        this.tokens.push({
          type: 'list_item_end'
        });
      }

      this.tokens.push({
        type: 'list_end'
      });

      continue;
    }

    // html
    if (cap = this.rules.html.exec(src)) {
      src = src.substring(cap[0].length);
      this.tokens.push({
        type: this.options.sanitize
          ? 'paragraph'
          : 'html',
        pre: !this.options.sanitizer
          && (cap[1] === 'pre' || cap[1] === 'script' || cap[1] === 'style'),
        text: cap[0]
      });
      continue;
    }

    // def
    if ((!bq && top) && (cap = this.rules.def.exec(src))) {
      src = src.substring(cap[0].length);
      this.tokens.links[cap[1].toLowerCase()] = {
        href: cap[2],
        title: cap[3]
      };
      continue;
    }

    // table (gfm)
    if (top && (cap = this.rules.table.exec(src))) {
      src = src.substring(cap[0].length);

      item = {
        type: 'table',
        header: cap[1].replace(/^ *| *\| *$/g, '').split(/ *\| */),
        align: cap[2].replace(/^ *|\| *$/g, '').split(/ *\| */),
        cells: cap[3].replace(/(?: *\| *)?\n$/, '').split('\n')
      };

      for (i = 0; i < item.align.length; i++) {
        if (/^ *-+: *$/.test(item.align[i])) {
          item.align[i] = 'right';
        } else if (/^ *:-+: *$/.test(item.align[i])) {
          item.align[i] = 'center';
        } else if (/^ *:-+ *$/.test(item.align[i])) {
          item.align[i] = 'left';
        } else {
          item.align[i] = null;
        }
      }

      for (i = 0; i < item.cells.length; i++) {
        item.cells[i] = item.cells[i]
          .replace(/^ *\| *| *\| *$/g, '')
          .split(/ *\| */);
      }

      this.tokens.push(item);

      continue;
    }

    // top-level paragraph
    if (top && (cap = this.rules.paragraph.exec(src))) {
      src = src.substring(cap[0].length);
      this.tokens.push({
        type: 'paragraph',
        text: cap[1].charAt(cap[1].length - 1) === '\n'
          ? cap[1].slice(0, -1)
          : cap[1]
      });
      continue;
    }

    // text
    if (cap = this.rules.text.exec(src)) {
      // Top-level should never reach here.
      src = src.substring(cap[0].length);
      this.tokens.push({
        type: 'text',
        text: cap[0]
      });
      continue;
    }

    if (src) {
      throw new
        Error('Infinite loop on byte: ' + src.charCodeAt(0));
    }
  }

  return this.tokens;
};

/**
 * Inline-Level Grammar
 */

var inline = {
  escape: /^\\([\\`*{}\[\]()#+\-.!_>])/,
  autolink: /^<([^ >]+(@|:\/)[^ >]+)>/,
  url: noop,
  tag: /^<!--[\s\S]*?-->|^<\/?\w+(?:"[^"]*"|'[^']*'|[^'">])*?>/,
  link: /^!?\[(inside)\]\(href\)/,
  reflink: /^!?\[(inside)\]\s*\[([^\]]*)\]/,
  nolink: /^!?\[((?:\[[^\]]*\]|[^\[\]])*)\]/,
  strong: /^__([\s\S]+?)__(?!_)|^\*\*([\s\S]+?)\*\*(?!\*)/,
  em: /^\b_((?:[^_]|__)+?)_\b|^\*((?:\*\*|[\s\S])+?)\*(?!\*)/,
  code: /^(`+)\s*([\s\S]*?[^`])\s*\1(?!`)/,
  br: /^ {2,}\n(?!\s*$)/,
  del: noop,
  text: /^[\s\S]+?(?=[\\<!\[_*`]| {2,}\n|$)/
};

inline._inside = /(?:\[[^\]]*\]|[^\[\]]|\](?=[^\[]*\]))*/;
inline._href = /\s*<?([\s\S]*?)>?(?:\s+['"]([\s\S]*?)['"])?\s*/;

inline.link = replace(inline.link)
  ('inside', inline._inside)
  ('href', inline._href)
  ();

inline.reflink = replace(inline.reflink)
  ('inside', inline._inside)
  ();

/**
 * Normal Inline Grammar
 */

inline.normal = merge({}, inline);

/**
 * Pedantic Inline Grammar
 */

inline.pedantic = merge({}, inline.normal, {
  strong: /^__(?=\S)([\s\S]*?\S)__(?!_)|^\*\*(?=\S)([\s\S]*?\S)\*\*(?!\*)/,
  em: /^_(?=\S)([\s\S]*?\S)_(?!_)|^\*(?=\S)([\s\S]*?\S)\*(?!\*)/
});

/**
 * GFM Inline Grammar
 */

inline.gfm = merge({}, inline.normal, {
  escape: replace(inline.escape)('])', '~|])')(),
  url: /^(https?:\/\/[^\s<]+[^<.,:;"')\]\s])/,
  del: /^~~(?=\S)([\s\S]*?\S)~~/,
  text: replace(inline.text)
    (']|', '~]|')
    ('|', '|https?://|')
    ()
});

/**
 * GFM + Line Breaks Inline Grammar
 */

inline.breaks = merge({}, inline.gfm, {
  br: replace(inline.br)('{2,}', '*')(),
  text: replace(inline.gfm.text)('{2,}', '*')()
});

/**
 * Inline Lexer & Compiler
 */

function InlineLexer(links, options) {
  this.options = options || marked.defaults;
  this.links = links;
  this.rules = inline.normal;
  this.renderer = this.options.renderer || new Renderer;
  this.renderer.options = this.options;

  if (!this.links) {
    throw new
      Error('Tokens array requires a `links` property.');
  }

  if (this.options.gfm) {
    if (this.options.breaks) {
      this.rules = inline.breaks;
    } else {
      this.rules = inline.gfm;
    }
  } else if (this.options.pedantic) {
    this.rules = inline.pedantic;
  }
}

/**
 * Expose Inline Rules
 */

InlineLexer.rules = inline;

/**
 * Static Lexing/Compiling Method
 */

InlineLexer.output = function(src, links, options) {
  var inline = new InlineLexer(links, options);
  return inline.output(src);
};

/**
 * Lexing/Compiling
 */

InlineLexer.prototype.output = function(src) {
  var out = ''
    , link
    , text
    , href
    , cap;

  while (src) {
    // escape
    if (cap = this.rules.escape.exec(src)) {
      src = src.substring(cap[0].length);
      out += cap[1];
      continue;
    }

    // autolink
    if (cap = this.rules.autolink.exec(src)) {
      src = src.substring(cap[0].length);
      if (cap[2] === '@') {
        text = cap[1].charAt(6) === ':'
          ? this.mangle(cap[1].substring(7))
          : this.mangle(cap[1]);
        href = this.mangle('mailto:') + text;
      } else {
        text = escape(cap[1]);
        href = text;
      }
      out += this.renderer.link(href, null, text);
      continue;
    }

    // url (gfm)
    if (!this.inLink && (cap = this.rules.url.exec(src))) {
      src = src.substring(cap[0].length);
      text = escape(cap[1]);
      href = text;
      out += this.renderer.link(href, null, text);
      continue;
    }

    // tag
    if (cap = this.rules.tag.exec(src)) {
      if (!this.inLink && /^<a /i.test(cap[0])) {
        this.inLink = true;
      } else if (this.inLink && /^<\/a>/i.test(cap[0])) {
        this.inLink = false;
      }
      src = src.substring(cap[0].length);
      out += this.options.sanitize
        ? this.options.sanitizer
          ? this.options.sanitizer(cap[0])
          : escape(cap[0])
        : cap[0]
      continue;
    }

    // link
    if (cap = this.rules.link.exec(src)) {
      src = src.substring(cap[0].length);
      this.inLink = true;
      out += this.outputLink(cap, {
        href: cap[2],
        title: cap[3]
      });
      this.inLink = false;
      continue;
    }

    // reflink, nolink
    if ((cap = this.rules.reflink.exec(src))
        || (cap = this.rules.nolink.exec(src))) {
      src = src.substring(cap[0].length);
      link = (cap[2] || cap[1]).replace(/\s+/g, ' ');
      link = this.links[link.toLowerCase()];
      if (!link || !link.href) {
        out += cap[0].charAt(0);
        src = cap[0].substring(1) + src;
        continue;
      }
      this.inLink = true;
      out += this.outputLink(cap, link);
      this.inLink = false;
      continue;
    }

    // strong
    if (cap = this.rules.strong.exec(src)) {
      src = src.substring(cap[0].length);
      out += this.renderer.strong(this.output(cap[2] || cap[1]));
      continue;
    }

    // em
    if (cap = this.rules.em.exec(src)) {
      src = src.substring(cap[0].length);
      out += this.renderer.em(this.output(cap[2] || cap[1]));
      continue;
    }

    // code
    if (cap = this.rules.code.exec(src)) {
      src = src.substring(cap[0].length);
      out += this.renderer.codespan(escape(cap[2], true));
      continue;
    }

    // br
    if (cap = this.rules.br.exec(src)) {
      src = src.substring(cap[0].length);
      out += this.renderer.br();
      continue;
    }

    // del (gfm)
    if (cap = this.rules.del.exec(src)) {
      src = src.substring(cap[0].length);
      out += this.renderer.del(this.output(cap[1]));
      continue;
    }

    // text
    if (cap = this.rules.text.exec(src)) {
      src = src.substring(cap[0].length);
      out += this.renderer.text(escape(this.smartypants(cap[0])));
      continue;
    }

    if (src) {
      throw new
        Error('Infinite loop on byte: ' + src.charCodeAt(0));
    }
  }

  return out;
};

/**
 * Compile Link
 */

InlineLexer.prototype.outputLink = function(cap, link) {
  var href = escape(link.href)
    , title = link.title ? escape(link.title) : null;

  return cap[0].charAt(0) !== '!'
    ? this.renderer.link(href, title, this.output(cap[1]))
    : this.renderer.image(href, title, escape(cap[1]));
};

/**
 * Smartypants Transformations
 */

InlineLexer.prototype.smartypants = function(text) {
  if (!this.options.smartypants) return text;
  return text
    // em-dashes
    .replace(/---/g, '\u2014')
    // en-dashes
    .replace(/--/g, '\u2013')
    // opening singles
    .replace(/(^|[-\u2014/(\[{"\s])'/g, '$1\u2018')
    // closing singles & apostrophes
    .replace(/'/g, '\u2019')
    // opening doubles
    .replace(/(^|[-\u2014/(\[{\u2018\s])"/g, '$1\u201c')
    // closing doubles
    .replace(/"/g, '\u201d')
    // ellipses
    .replace(/\.{3}/g, '\u2026');
};

/**
 * Mangle Links
 */

InlineLexer.prototype.mangle = function(text) {
  if (!this.options.mangle) return text;
  var out = ''
    , l = text.length
    , i = 0
    , ch;

  for (; i < l; i++) {
    ch = text.charCodeAt(i);
    if (Math.random() > 0.5) {
      ch = 'x' + ch.toString(16);
    }
    out += '&#' + ch + ';';
  }

  return out;
};

/**
 * Renderer
 */

function Renderer(options) {
  this.options = options || {};
}

Renderer.prototype.code = function(code, lang, escaped) {
  if (this.options.highlight) {
    var out = this.options.highlight(code, lang);
    if (out != null && out !== code) {
      escaped = true;
      code = out;
    }
  }

  if (!lang) {
    return '<pre><code>'
      + (escaped ? code : escape(code, true))
      + '\n</code></pre>';
  }

  return '<pre><code class="'
    + this.options.langPrefix
    + escape(lang, true)
    + '">'
    + (escaped ? code : escape(code, true))
    + '\n</code></pre>\n';
};

Renderer.prototype.blockquote = function(quote) {
  return '<blockquote>\n' + quote + '</blockquote>\n';
};

Renderer.prototype.html = function(html) {
  return html;
};

Renderer.prototype.heading = function(text, level, raw) {
  return '<h'
    + level
    + ' id="'
    + this.options.headerPrefix
    + raw.toLowerCase().replace(/[^\w]+/g, '-')
    + '">'
    + text
    + '</h'
    + level
    + '>\n';
};

Renderer.prototype.hr = function() {
  return this.options.xhtml ? '<hr/>\n' : '<hr>\n';
};

Renderer.prototype.list = function(body, ordered) {
  var type = ordered ? 'ol' : 'ul';
  return '<' + type + '>\n' + body + '</' + type + '>\n';
};

Renderer.prototype.listitem = function(text) {
  return '<li>' + text + '</li>\n';
};

Renderer.prototype.paragraph = function(text) {
  return '<p>' + text + '</p>\n';
};

Renderer.prototype.table = function(header, body) {
  return '<table>\n'
    + '<thead>\n'
    + header
    + '</thead>\n'
    + '<tbody>\n'
    + body
    + '</tbody>\n'
    + '</table>\n';
};

Renderer.prototype.tablerow = function(content) {
  return '<tr>\n' + content + '</tr>\n';
};

Renderer.prototype.tablecell = function(content, flags) {
  var type = flags.header ? 'th' : 'td';
  var tag = flags.align
    ? '<' + type + ' style="text-align:' + flags.align + '">'
    : '<' + type + '>';
  return tag + content + '</' + type + '>\n';
};

// span level renderer
Renderer.prototype.strong = function(text) {
  return '<strong>' + text + '</strong>';
};

Renderer.prototype.em = function(text) {
  return '<em>' + text + '</em>';
};

Renderer.prototype.codespan = function(text) {
  return '<code>' + text + '</code>';
};

Renderer.prototype.br = function() {
  return this.options.xhtml ? '<br/>' : '<br>';
};

Renderer.prototype.del = function(text) {
  return '<del>' + text + '</del>';
};

Renderer.prototype.link = function(href, title, text) {
  if (this.options.sanitize) {
    try {
      var prot = decodeURIComponent(unescape(href))
        .replace(/[^\w:]/g, '')
        .toLowerCase();
    } catch (e) {
      return '';
    }
    if (prot.indexOf('javascript:') === 0 || prot.indexOf('vbscript:') === 0) {
      return '';
    }
  }
  var out = '<a href="' + href + '"';
  if (title) {
    out += ' title="' + title + '"';
  }
  out += '>' + text + '</a>';
  return out;
};

Renderer.prototype.image = function(href, title, text) {
  var out = '<img src="' + href + '" alt="' + text + '"';
  if (title) {
    out += ' title="' + title + '"';
  }
  out += this.options.xhtml ? '/>' : '>';
  return out;
};

Renderer.prototype.text = function(text) {
  return text;
};

/**
 * Parsing & Compiling
 */

function Parser(options) {
  this.tokens = [];
  this.token = null;
  this.options = options || marked.defaults;
  this.options.renderer = this.options.renderer || new Renderer;
  this.renderer = this.options.renderer;
  this.renderer.options = this.options;
}

/**
 * Static Parse Method
 */

Parser.parse = function(src, options, renderer) {
  var parser = new Parser(options, renderer);
  return parser.parse(src);
};

/**
 * Parse Loop
 */

Parser.prototype.parse = function(src) {
  this.inline = new InlineLexer(src.links, this.options, this.renderer);
  this.tokens = src.reverse();

  var out = '';
  while (this.next()) {
    out += this.tok();
  }

  return out;
};

/**
 * Next Token
 */

Parser.prototype.next = function() {
  return this.token = this.tokens.pop();
};

/**
 * Preview Next Token
 */

Parser.prototype.peek = function() {
  return this.tokens[this.tokens.length - 1] || 0;
};

/**
 * Parse Text Tokens
 */

Parser.prototype.parseText = function() {
  var body = this.token.text;

  while (this.peek().type === 'text') {
    body += '\n' + this.next().text;
  }

  return this.inline.output(body);
};

/**
 * Parse Current Token
 */

Parser.prototype.tok = function() {
  switch (this.token.type) {
    case 'space': {
      return '';
    }
    case 'hr': {
      return this.renderer.hr();
    }
    case 'heading': {
      return this.renderer.heading(
        this.inline.output(this.token.text),
        this.token.depth,
        this.token.text);
    }
    case 'code': {
      return this.renderer.code(this.token.text,
        this.token.lang,
        this.token.escaped);
    }
    case 'table': {
      var header = ''
        , body = ''
        , i
        , row
        , cell
        , flags
        , j;

      // header
      cell = '';
      for (i = 0; i < this.token.header.length; i++) {
        flags = { header: true, align: this.token.align[i] };
        cell += this.renderer.tablecell(
          this.inline.output(this.token.header[i]),
          { header: true, align: this.token.align[i] }
        );
      }
      header += this.renderer.tablerow(cell);

      for (i = 0; i < this.token.cells.length; i++) {
        row = this.token.cells[i];

        cell = '';
        for (j = 0; j < row.length; j++) {
          cell += this.renderer.tablecell(
            this.inline.output(row[j]),
            { header: false, align: this.token.align[j] }
          );
        }

        body += this.renderer.tablerow(cell);
      }
      return this.renderer.table(header, body);
    }
    case 'blockquote_start': {
      var body = '';

      while (this.next().type !== 'blockquote_end') {
        body += this.tok();
      }

      return this.renderer.blockquote(body);
    }
    case 'list_start': {
      var body = ''
        , ordered = this.token.ordered;

      while (this.next().type !== 'list_end') {
        body += this.tok();
      }

      return this.renderer.list(body, ordered);
    }
    case 'list_item_start': {
      var body = '';

      while (this.next().type !== 'list_item_end') {
        body += this.token.type === 'text'
          ? this.parseText()
          : this.tok();
      }

      return this.renderer.listitem(body);
    }
    case 'loose_item_start': {
      var body = '';

      while (this.next().type !== 'list_item_end') {
        body += this.tok();
      }

      return this.renderer.listitem(body);
    }
    case 'html': {
      var html = !this.token.pre && !this.options.pedantic
        ? this.inline.output(this.token.text)
        : this.token.text;
      return this.renderer.html(html);
    }
    case 'paragraph': {
      return this.renderer.paragraph(this.inline.output(this.token.text));
    }
    case 'text': {
      return this.renderer.paragraph(this.parseText());
    }
  }
};

/**
 * Helpers
 */

function escape(html, encode) {
  return html
    .replace(!encode ? /&(?!#?\w+;)/g : /&/g, '&amp;')
    .replace(/</g, '&lt;')
    .replace(/>/g, '&gt;')
    .replace(/"/g, '&quot;')
    .replace(/'/g, '&#39;');
}

function unescape(html) {
  return html.replace(/&([#\w]+);/g, function(_, n) {
    n = n.toLowerCase();
    if (n === 'colon') return ':';
    if (n.charAt(0) === '#') {
      return n.charAt(1) === 'x'
        ? String.fromCharCode(parseInt(n.substring(2), 16))
        : String.fromCharCode(+n.substring(1));
    }
    return '';
  });
}

function replace(regex, opt) {
  regex = regex.source;
  opt = opt || '';
  return function self(name, val) {
    if (!name) return new RegExp(regex, opt);
    val = val.source || val;
    val = val.replace(/(^|[^\[])\^/g, '$1');
    regex = regex.replace(name, val);
    return self;
  };
}

function noop() {}
noop.exec = noop;

function merge(obj) {
  var i = 1
    , target
    , key;

  for (; i < arguments.length; i++) {
    target = arguments[i];
    for (key in target) {
      if (Object.prototype.hasOwnProperty.call(target, key)) {
        obj[key] = target[key];
      }
    }
  }

  return obj;
}


/**
 * Marked
 */

function marked(src, opt, callback) {
  if (callback || typeof opt === 'function') {
    if (!callback) {
      callback = opt;
      opt = null;
    }

    opt = merge({}, marked.defaults, opt || {});

    var highlight = opt.highlight
      , tokens
      , pending
      , i = 0;

    try {
      tokens = Lexer.lex(src, opt)
    } catch (e) {
      return callback(e);
    }

    pending = tokens.length;

    var done = function(err) {
      if (err) {
        opt.highlight = highlight;
        return callback(err);
      }

      var out;

      try {
        out = Parser.parse(tokens, opt);
      } catch (e) {
        err = e;
      }

      opt.highlight = highlight;

      return err
        ? callback(err)
        : callback(null, out);
    };

    if (!highlight || highlight.length < 3) {
      return done();
    }

    delete opt.highlight;

    if (!pending) return done();

    for (; i < tokens.length; i++) {
      (function(token) {
        if (token.type !== 'code') {
          return --pending || done();
        }
        return highlight(token.text, token.lang, function(err, code) {
          if (err) return done(err);
          if (code == null || code === token.text) {
            return --pending || done();
          }
          token.text = code;
          token.escaped = true;
          --pending || done();
        });
      })(tokens[i]);
    }

    return;
  }
  try {
    if (opt) opt = merge({}, marked.defaults, opt);
    return Parser.parse(Lexer.lex(src, opt), opt);
  } catch (e) {
    e.message += '\nPlease report this to https://github.com/chjj/marked.';
    if ((opt || marked.defaults).silent) {
      return '<p>An error occured:</p><pre>'
        + escape(e.message + '', true)
        + '</pre>';
    }
    throw e;
  }
}

/**
 * Options
 */

marked.options =
marked.setOptions = function(opt) {
  merge(marked.defaults, opt);
  return marked;
};

marked.defaults = {
  gfm: true,
  tables: true,
  breaks: false,
  pedantic: false,
  sanitize: false,
  sanitizer: null,
  mangle: true,
  smartLists: false,
  silent: false,
  highlight: null,
  langPrefix: 'lang-',
  smartypants: false,
  headerPrefix: '',
  renderer: new Renderer,
  xhtml: false
};

/**
 * Expose
 */

marked.Parser = Parser;
marked.parser = Parser.parse;

marked.Renderer = Renderer;

marked.Lexer = Lexer;
marked.lexer = Lexer.lex;

marked.InlineLexer = InlineLexer;
marked.inlineLexer = InlineLexer.output;

marked.parse = marked;

if (typeof module !== 'undefined' && typeof exports === 'object') {
  module.exports = marked;
} else if (typeof define === 'function' && define.amd) {
  define(function() { return marked; });
} else {
  this.marked = marked;
}

}).call(function() {
  return this || (typeof window !== 'undefined' ? window : global);
}());

(function(factory) {

  // Setup highlight.js for different environments. First is Node.js or
  // CommonJS.
  if(typeof exports !== 'undefined') {
    factory(exports);
  } else {
    // Export hljs globally even when using AMD for cases when this script
    // is loaded with others that may still expect a global hljs.
    window.hljs = factory({});

    // Finally register the global hljs with AMD.
    if(typeof define === 'function' && define.amd) {
      define('hljs', [], function() {
        return window.hljs;
      });
    }
  }

}(function(hljs) {

  /* Utility functions */

  function escape(value) {
    return value.replace(/&/gm, '&amp;').replace(/</gm, '&lt;').replace(/>/gm, '&gt;');
  }

  function tag(node) {
    return node.nodeName.toLowerCase();
  }

  function testRe(re, lexeme) {
    var match = re && re.exec(lexeme);
    return match && match.index == 0;
  }

  function isNotHighlighted(language) {
    return (/^(no-?highlight|plain|text)$/i).test(language);
  }

  function blockLanguage(block) {
    var i, match, length,
        classes = block.className + ' ';

    classes += block.parentNode ? block.parentNode.className : '';

    // language-* takes precedence over non-prefixed class names
    match = (/\blang(?:uage)?-([\w-]+)\b/i).exec(classes);
    if (match) {
      return getLanguage(match[1]) ? match[1] : 'no-highlight';
    }

    classes = classes.split(/\s+/);
    for (i = 0, length = classes.length; i < length; i++) {
      if (getLanguage(classes[i]) || isNotHighlighted(classes[i])) {
        return classes[i];
      }
    }
  }

  function inherit(parent, obj) {
    var result = {}, key;
    for (key in parent)
      result[key] = parent[key];
    if (obj)
      for (key in obj)
        result[key] = obj[key];
    return result;
  }

  /* Stream merging */

  function nodeStream(node) {
    var result = [];
    (function _nodeStream(node, offset) {
      for (var child = node.firstChild; child; child = child.nextSibling) {
        if (child.nodeType == 3)
          offset += child.nodeValue.length;
        else if (child.nodeType == 1) {
          result.push({
            event: 'start',
            offset: offset,
            node: child
          });
          offset = _nodeStream(child, offset);
          // Prevent void elements from having an end tag that would actually
          // double them in the output. There are more void elements in HTML
          // but we list only those realistically expected in code display.
          if (!tag(child).match(/br|hr|img|input/)) {
            result.push({
              event: 'stop',
              offset: offset,
              node: child
            });
          }
        }
      }
      return offset;
    })(node, 0);
    return result;
  }

  function mergeStreams(original, highlighted, value) {
    var processed = 0;
    var result = '';
    var nodeStack = [];

    function selectStream() {
      if (!original.length || !highlighted.length) {
        return original.length ? original : highlighted;
      }
      if (original[0].offset != highlighted[0].offset) {
        return (original[0].offset < highlighted[0].offset) ? original : highlighted;
      }

      /*
      To avoid starting the stream just before it should stop the order is
      ensured that original always starts first and closes last:

      if (event1 == 'start' && event2 == 'start')
        return original;
      if (event1 == 'start' && event2 == 'stop')
        return highlighted;
      if (event1 == 'stop' && event2 == 'start')
        return original;
      if (event1 == 'stop' && event2 == 'stop')
        return highlighted;

      ... which is collapsed to:
      */
      return highlighted[0].event == 'start' ? original : highlighted;
    }

    function open(node) {
      function attr_str(a) {return ' ' + a.nodeName + '="' + escape(a.value) + '"';}
      result += '<' + tag(node) + Array.prototype.map.call(node.attributes, attr_str).join('') + '>';
    }

    function close(node) {
      result += '</' + tag(node) + '>';
    }

    function render(event) {
      (event.event == 'start' ? open : close)(event.node);
    }

    while (original.length || highlighted.length) {
      var stream = selectStream();
      result += escape(value.substr(processed, stream[0].offset - processed));
      processed = stream[0].offset;
      if (stream == original) {
        /*
        On any opening or closing tag of the original markup we first close
        the entire highlighted node stack, then render the original tag along
        with all the following original tags at the same offset and then
        reopen all the tags on the highlighted stack.
        */
        nodeStack.reverse().forEach(close);
        do {
          render(stream.splice(0, 1)[0]);
          stream = selectStream();
        } while (stream == original && stream.length && stream[0].offset == processed);
        nodeStack.reverse().forEach(open);
      } else {
        if (stream[0].event == 'start') {
          nodeStack.push(stream[0].node);
        } else {
          nodeStack.pop();
        }
        render(stream.splice(0, 1)[0]);
      }
    }
    return result + escape(value.substr(processed));
  }

  /* Initialization */

  function compileLanguage(language) {

    function reStr(re) {
        return (re && re.source) || re;
    }

    function langRe(value, global) {
      return new RegExp(
        reStr(value),
        'm' + (language.case_insensitive ? 'i' : '') + (global ? 'g' : '')
      );
    }

    function compileMode(mode, parent) {
      if (mode.compiled)
        return;
      mode.compiled = true;

      mode.keywords = mode.keywords || mode.beginKeywords;
      if (mode.keywords) {
        var compiled_keywords = {};

        var flatten = function(className, str) {
          if (language.case_insensitive) {
            str = str.toLowerCase();
          }
          str.split(' ').forEach(function(kw) {
            var pair = kw.split('|');
            compiled_keywords[pair[0]] = [className, pair[1] ? Number(pair[1]) : 1];
          });
        };

        if (typeof mode.keywords == 'string') { // string
          flatten('keyword', mode.keywords);
        } else {
          Object.keys(mode.keywords).forEach(function (className) {
            flatten(className, mode.keywords[className]);
          });
        }
        mode.keywords = compiled_keywords;
      }
      mode.lexemesRe = langRe(mode.lexemes || /\b\w+\b/, true);

      if (parent) {
        if (mode.beginKeywords) {
          mode.begin = '\\b(' + mode.beginKeywords.split(' ').join('|') + ')\\b';
        }
        if (!mode.begin)
          mode.begin = /\B|\b/;
        mode.beginRe = langRe(mode.begin);
        if (!mode.end && !mode.endsWithParent)
          mode.end = /\B|\b/;
        if (mode.end)
          mode.endRe = langRe(mode.end);
        mode.terminator_end = reStr(mode.end) || '';
        if (mode.endsWithParent && parent.terminator_end)
          mode.terminator_end += (mode.end ? '|' : '') + parent.terminator_end;
      }
      if (mode.illegal)
        mode.illegalRe = langRe(mode.illegal);
      if (mode.relevance === undefined)
        mode.relevance = 1;
      if (!mode.contains) {
        mode.contains = [];
      }
      var expanded_contains = [];
      mode.contains.forEach(function(c) {
        if (c.variants) {
          c.variants.forEach(function(v) {expanded_contains.push(inherit(c, v));});
        } else {
          expanded_contains.push(c == 'self' ? mode : c);
        }
      });
      mode.contains = expanded_contains;
      mode.contains.forEach(function(c) {compileMode(c, mode);});

      if (mode.starts) {
        compileMode(mode.starts, parent);
      }

      var terminators =
        mode.contains.map(function(c) {
          return c.beginKeywords ? '\\.?(' + c.begin + ')\\.?' : c.begin;
        })
        .concat([mode.terminator_end, mode.illegal])
        .map(reStr)
        .filter(Boolean);
      mode.terminators = terminators.length ? langRe(terminators.join('|'), true) : {exec: function(/*s*/) {return null;}};
    }

    compileMode(language);
  }

  /*
  Core highlighting function. Accepts a language name, or an alias, and a
  string with the code to highlight. Returns an object with the following
  properties:

  - relevance (int)
  - value (an HTML string with highlighting markup)

  */
  function highlight(name, value, ignore_illegals, continuation) {

    function subMode(lexeme, mode) {
      for (var i = 0; i < mode.contains.length; i++) {
        if (testRe(mode.contains[i].beginRe, lexeme)) {
          return mode.contains[i];
        }
      }
    }

    function endOfMode(mode, lexeme) {
      if (testRe(mode.endRe, lexeme)) {
        while (mode.endsParent && mode.parent) {
          mode = mode.parent;
        }
        return mode;
      }
      if (mode.endsWithParent) {
        return endOfMode(mode.parent, lexeme);
      }
    }

    function isIllegal(lexeme, mode) {
      return !ignore_illegals && testRe(mode.illegalRe, lexeme);
    }

    function keywordMatch(mode, match) {
      var match_str = language.case_insensitive ? match[0].toLowerCase() : match[0];
      return mode.keywords.hasOwnProperty(match_str) && mode.keywords[match_str];
    }

    function buildSpan(classname, insideSpan, leaveOpen, noPrefix) {
      var classPrefix = noPrefix ? '' : options.classPrefix,
          openSpan    = '<span class="' + classPrefix,
          closeSpan   = leaveOpen ? '' : '</span>';

      openSpan += classname + '">';

      return openSpan + insideSpan + closeSpan;
    }

    function processKeywords() {
      if (!top.keywords)
        return escape(mode_buffer);
      var result = '';
      var last_index = 0;
      top.lexemesRe.lastIndex = 0;
      var match = top.lexemesRe.exec(mode_buffer);
      while (match) {
        result += escape(mode_buffer.substr(last_index, match.index - last_index));
        var keyword_match = keywordMatch(top, match);
        if (keyword_match) {
          relevance += keyword_match[1];
          result += buildSpan(keyword_match[0], escape(match[0]));
        } else {
          result += escape(match[0]);
        }
        last_index = top.lexemesRe.lastIndex;
        match = top.lexemesRe.exec(mode_buffer);
      }
      return result + escape(mode_buffer.substr(last_index));
    }

    function processSubLanguage() {
      var explicit = typeof top.subLanguage == 'string';
      if (explicit && !languages[top.subLanguage]) {
        return escape(mode_buffer);
      }

      var result = explicit ?
                   highlight(top.subLanguage, mode_buffer, true, continuations[top.subLanguage]) :
                   highlightAuto(mode_buffer, top.subLanguage.length ? top.subLanguage : undefined);

      // Counting embedded language score towards the host language may be disabled
      // with zeroing the containing mode relevance. Usecase in point is Markdown that
      // allows XML everywhere and makes every XML snippet to have a much larger Markdown
      // score.
      if (top.relevance > 0) {
        relevance += result.relevance;
      }
      if (explicit) {
        continuations[top.subLanguage] = result.top;
      }
      return buildSpan(result.language, result.value, false, true);
    }

    function processBuffer() {
      return top.subLanguage !== undefined ? processSubLanguage() : processKeywords();
    }

    function startNewMode(mode, lexeme) {
      var markup = mode.className? buildSpan(mode.className, '', true): '';
      if (mode.returnBegin) {
        result += markup;
        mode_buffer = '';
      } else if (mode.excludeBegin) {
        result += escape(lexeme) + markup;
        mode_buffer = '';
      } else {
        result += markup;
        mode_buffer = lexeme;
      }
      top = Object.create(mode, {parent: {value: top}});
    }

    function processLexeme(buffer, lexeme) {

      mode_buffer += buffer;
      if (lexeme === undefined) {
        result += processBuffer();
        return 0;
      }

      var new_mode = subMode(lexeme, top);
      if (new_mode) {
        result += processBuffer();
        startNewMode(new_mode, lexeme);
        return new_mode.returnBegin ? 0 : lexeme.length;
      }

      var end_mode = endOfMode(top, lexeme);
      if (end_mode) {
        var origin = top;
        if (!(origin.returnEnd || origin.excludeEnd)) {
          mode_buffer += lexeme;
        }
        result += processBuffer();
        do {
          if (top.className) {
            result += '</span>';
          }
          relevance += top.relevance;
          top = top.parent;
        } while (top != end_mode.parent);
        if (origin.excludeEnd) {
          result += escape(lexeme);
        }
        mode_buffer = '';
        if (end_mode.starts) {
          startNewMode(end_mode.starts, '');
        }
        return origin.returnEnd ? 0 : lexeme.length;
      }

      if (isIllegal(lexeme, top))
        throw new Error('Illegal lexeme "' + lexeme + '" for mode "' + (top.className || '<unnamed>') + '"');

      /*
      Parser should not reach this point as all types of lexemes should be caught
      earlier, but if it does due to some bug make sure it advances at least one
      character forward to prevent infinite looping.
      */
      mode_buffer += lexeme;
      return lexeme.length || 1;
    }

    var language = getLanguage(name);
    if (!language) {
      throw new Error('Unknown language: "' + name + '"');
    }

    compileLanguage(language);
    var top = continuation || language;
    var continuations = {}; // keep continuations for sub-languages
    var result = '', current;
    for(current = top; current != language; current = current.parent) {
      if (current.className) {
        result = buildSpan(current.className, '', true) + result;
      }
    }
    var mode_buffer = '';
    var relevance = 0;
    try {
      var match, count, index = 0;
      while (true) {
        top.terminators.lastIndex = index;
        match = top.terminators.exec(value);
        if (!match)
          break;
        count = processLexeme(value.substr(index, match.index - index), match[0]);
        index = match.index + count;
      }
      processLexeme(value.substr(index));
      for(current = top; current.parent; current = current.parent) { // close dangling modes
        if (current.className) {
          result += '</span>';
        }
      }
      return {
        relevance: relevance,
        value: result,
        language: name,
        top: top
      };
    } catch (e) {
      if (e.message.indexOf('Illegal') != -1) {
        return {
          relevance: 0,
          value: escape(value)
        };
      } else {
        throw e;
      }
    }
  }

  /*
  Highlighting with language detection. Accepts a string with the code to
  highlight. Returns an object with the following properties:

  - language (detected language)
  - relevance (int)
  - value (an HTML string with highlighting markup)
  - second_best (object with the same structure for second-best heuristically
    detected language, may be absent)

  */
  function highlightAuto(text, languageSubset) {
    languageSubset = languageSubset || options.languages || Object.keys(languages);
    var result = {
      relevance: 0,
      value: escape(text)
    };
    var second_best = result;
    languageSubset.forEach(function(name) {
      if (!getLanguage(name)) {
        return;
      }
      var current = highlight(name, text, false);
      current.language = name;
      if (current.relevance > second_best.relevance) {
        second_best = current;
      }
      if (current.relevance > result.relevance) {
        second_best = result;
        result = current;
      }
    });
    if (second_best.language) {
      result.second_best = second_best;
    }
    return result;
  }

  /*
  Post-processing of the highlighted markup:

  - replace TABs with something more useful
  - replace real line-breaks with '<br>' for non-pre containers

  */
  function fixMarkup(value) {
    if (options.tabReplace) {
      value = value.replace(/^((<[^>]+>|\t)+)/gm, function(match, p1 /*..., offset, s*/) {
        return p1.replace(/\t/g, options.tabReplace);
      });
    }
    if (options.useBR) {
      value = value.replace(/\n/g, '<br>');
    }
    return value;
  }

  function buildClassName(prevClassName, currentLang, resultLang) {
    var language = currentLang ? aliases[currentLang] : resultLang,
        result   = [prevClassName.trim()];

    if (!prevClassName.match(/\bhljs\b/)) {
      result.push('hljs');
    }

    if (prevClassName.indexOf(language) === -1) {
      result.push(language);
    }

    return result.join(' ').trim();
  }

  /*
  Applies highlighting to a DOM node containing code. Accepts a DOM node and
  two optional parameters for fixMarkup.
  */
  function highlightBlock(block) {
    var language = blockLanguage(block);
    if (isNotHighlighted(language))
        return;

    var node;
    if (options.useBR) {
      node = document.createElementNS('http://www.w3.org/1999/xhtml', 'div');
      node.innerHTML = block.innerHTML.replace(/\n/g, '').replace(/<br[ \/]*>/g, '\n');
    } else {
      node = block;
    }
    var text = node.textContent;
    var result = language ? highlight(language, text, true) : highlightAuto(text);

    var originalStream = nodeStream(node);
    if (originalStream.length) {
      var resultNode = document.createElementNS('http://www.w3.org/1999/xhtml', 'div');
      resultNode.innerHTML = result.value;
      result.value = mergeStreams(originalStream, nodeStream(resultNode), text);
    }
    result.value = fixMarkup(result.value);

    block.innerHTML = result.value;
    block.className = buildClassName(block.className, language, result.language);
    block.result = {
      language: result.language,
      re: result.relevance
    };
    if (result.second_best) {
      block.second_best = {
        language: result.second_best.language,
        re: result.second_best.relevance
      };
    }
  }

  var options = {
    classPrefix: 'hljs-',
    tabReplace: null,
    useBR: false,
    languages: undefined
  };

  /*
  Updates highlight.js global options with values passed in the form of an object
  */
  function configure(user_options) {
    options = inherit(options, user_options);
  }

  /*
  Applies highlighting to all <pre><code>..</code></pre> blocks on a page.
  */
  function initHighlighting() {
    if (initHighlighting.called)
      return;
    initHighlighting.called = true;

    var blocks = document.querySelectorAll('pre code');
    Array.prototype.forEach.call(blocks, highlightBlock);
  }

  /*
  Attaches highlighting to the page load event.
  */
  function initHighlightingOnLoad() {
    addEventListener('DOMContentLoaded', initHighlighting, false);
    addEventListener('load', initHighlighting, false);
  }

  var languages = {};
  var aliases = {};

  function registerLanguage(name, language) {
    var lang = languages[name] = language(hljs);
    if (lang.aliases) {
      lang.aliases.forEach(function(alias) {aliases[alias] = name;});
    }
  }

  function listLanguages() {
    return Object.keys(languages);
  }

  function getLanguage(name) {
    name = (name || '').toLowerCase();
    return languages[name] || languages[aliases[name]];
  }

  /* Interface definition */

  hljs.highlight = highlight;
  hljs.highlightAuto = highlightAuto;
  hljs.fixMarkup = fixMarkup;
  hljs.highlightBlock = highlightBlock;
  hljs.configure = configure;
  hljs.initHighlighting = initHighlighting;
  hljs.initHighlightingOnLoad = initHighlightingOnLoad;
  hljs.registerLanguage = registerLanguage;
  hljs.listLanguages = listLanguages;
  hljs.getLanguage = getLanguage;
  hljs.inherit = inherit;

  // Common regexps
  hljs.IDENT_RE = '[a-zA-Z]\\w*';
  hljs.UNDERSCORE_IDENT_RE = '[a-zA-Z_]\\w*';
  hljs.NUMBER_RE = '\\b\\d+(\\.\\d+)?';
  hljs.C_NUMBER_RE = '(\\b0[xX][a-fA-F0-9]+|(\\b\\d+(\\.\\d*)?|\\.\\d+)([eE][-+]?\\d+)?)'; // 0x..., 0..., decimal, float
  hljs.BINARY_NUMBER_RE = '\\b(0b[01]+)'; // 0b...
  hljs.RE_STARTERS_RE = '!|!=|!==|%|%=|&|&&|&=|\\*|\\*=|\\+|\\+=|,|-|-=|/=|/|:|;|<<|<<=|<=|<|===|==|=|>>>=|>>=|>=|>>>|>>|>|\\?|\\[|\\{|\\(|\\^|\\^=|\\||\\|=|\\|\\||~';

  // Common modes
  hljs.BACKSLASH_ESCAPE = {
    begin: '\\\\[\\s\\S]', relevance: 0
  };
  hljs.APOS_STRING_MODE = {
    className: 'string',
    begin: '\'', end: '\'',
    illegal: '\\n',
    contains: [hljs.BACKSLASH_ESCAPE]
  };
  hljs.QUOTE_STRING_MODE = {
    className: 'string',
    begin: '"', end: '"',
    illegal: '\\n',
    contains: [hljs.BACKSLASH_ESCAPE]
  };
  hljs.PHRASAL_WORDS_MODE = {
    begin: /\b(a|an|the|are|I|I'm|isn't|don't|doesn't|won't|but|just|should|pretty|simply|enough|gonna|going|wtf|so|such|will|you|your|like)\b/
  };
  hljs.COMMENT = function (begin, end, inherits) {
    var mode = hljs.inherit(
      {
        className: 'comment',
        begin: begin, end: end,
        contains: []
      },
      inherits || {}
    );
    mode.contains.push(hljs.PHRASAL_WORDS_MODE);
    mode.contains.push({
      className: 'doctag',
      begin: "(?:TODO|FIXME|NOTE|BUG|XXX):",
      relevance: 0
    });
    return mode;
  };
  hljs.C_LINE_COMMENT_MODE = hljs.COMMENT('//', '$');
  hljs.C_BLOCK_COMMENT_MODE = hljs.COMMENT('/\\*', '\\*/');
  hljs.HASH_COMMENT_MODE = hljs.COMMENT('#', '$');
  hljs.NUMBER_MODE = {
    className: 'number',
    begin: hljs.NUMBER_RE,
    relevance: 0
  };
  hljs.C_NUMBER_MODE = {
    className: 'number',
    begin: hljs.C_NUMBER_RE,
    relevance: 0
  };
  hljs.BINARY_NUMBER_MODE = {
    className: 'number',
    begin: hljs.BINARY_NUMBER_RE,
    relevance: 0
  };
  hljs.CSS_NUMBER_MODE = {
    className: 'number',
    begin: hljs.NUMBER_RE + '(' +
      '%|em|ex|ch|rem'  +
      '|vw|vh|vmin|vmax' +
      '|cm|mm|in|pt|pc|px' +
      '|deg|grad|rad|turn' +
      '|s|ms' +
      '|Hz|kHz' +
      '|dpi|dpcm|dppx' +
      ')?',
    relevance: 0
  };
  hljs.REGEXP_MODE = {
    className: 'regexp',
    begin: /\//, end: /\/[gimuy]*/,
    illegal: /\n/,
    contains: [
      hljs.BACKSLASH_ESCAPE,
      {
        begin: /\[/, end: /\]/,
        relevance: 0,
        contains: [hljs.BACKSLASH_ESCAPE]
      }
    ]
  };
  hljs.TITLE_MODE = {
    className: 'title',
    begin: hljs.IDENT_RE,
    relevance: 0
  };
  hljs.UNDERSCORE_TITLE_MODE = {
    className: 'title',
    begin: hljs.UNDERSCORE_IDENT_RE,
    relevance: 0
  };

hljs.registerLanguage('1c', function(hljs){
  var IDENT_RE_RU = '[a-zA-Zа-яА-Я][a-zA-Z0-9_а-яА-Я]*';
  var OneS_KEYWORDS = 'возврат дата для если и или иначе иначеесли исключение конецесли ' +
    'конецпопытки конецпроцедуры конецфункции конеццикла константа не перейти перем ' +
    'перечисление по пока попытка прервать продолжить процедура строка тогда фс функция цикл ' +
    'число экспорт';
  var OneS_BUILT_IN = 'ansitooem oemtoansi ввестивидсубконто ввестидату ввестизначение ' +
    'ввестиперечисление ввестипериод ввестиплансчетов ввестистроку ввестичисло вопрос ' +
    'восстановитьзначение врег выбранныйплансчетов вызватьисключение датагод датамесяц ' +
    'датачисло добавитьмесяц завершитьработусистемы заголовоксистемы записьжурналарегистрации ' +
    'запуститьприложение зафиксироватьтранзакцию значениевстроку значениевстрокувнутр ' +
    'значениевфайл значениеизстроки значениеизстрокивнутр значениеизфайла имякомпьютера ' +
    'имяпользователя каталогвременныхфайлов каталогиб каталогпользователя каталогпрограммы ' +
    'кодсимв командасистемы конгода конецпериодаби конецрассчитанногопериодаби ' +
    'конецстандартногоинтервала конквартала конмесяца коннедели лев лог лог10 макс ' +
    'максимальноеколичествосубконто мин монопольныйрежим названиеинтерфейса названиенабораправ ' +
    'назначитьвид назначитьсчет найти найтипомеченныенаудаление найтиссылки началопериодаби ' +
    'началостандартногоинтервала начатьтранзакцию начгода начквартала начмесяца начнедели ' +
    'номерднягода номерднянедели номернеделигода нрег обработкаожидания окр описаниеошибки ' +
    'основнойжурналрасчетов основнойплансчетов основнойязык открытьформу открытьформумодально ' +
    'отменитьтранзакцию очиститьокносообщений периодстр полноеимяпользователя получитьвремята ' +
    'получитьдатута получитьдокументта получитьзначенияотбора получитьпозициюта ' +
    'получитьпустоезначение получитьта прав праводоступа предупреждение префиксавтонумерации ' +
    'пустаястрока пустоезначение рабочаядаттьпустоезначение рабочаядата разделительстраниц ' +
    'разделительстрок разм разобратьпозициюдокумента рассчитатьрегистрына ' +
    'рассчитатьрегистрыпо сигнал симв символтабуляции создатьобъект сокрл сокрлп сокрп ' +
    'сообщить состояние сохранитьзначение сред статусвозврата стрдлина стрзаменить ' +
    'стрколичествострок стрполучитьстроку  стрчисловхождений сформироватьпозициюдокумента ' +
    'счетпокоду текущаядата текущеевремя типзначения типзначениястр удалитьобъекты ' +
    'установитьтана установитьтапо фиксшаблон формат цел шаблон';
  var DQUOTE =  {className: 'dquote',  begin: '""'};
  var STR_START = {
      className: 'string',
      begin: '"', end: '"|$',
      contains: [DQUOTE]
    };
  var STR_CONT = {
    className: 'string',
    begin: '\\|', end: '"|$',
    contains: [DQUOTE]
  };

  return {
    case_insensitive: true,
    lexemes: IDENT_RE_RU,
    keywords: {keyword: OneS_KEYWORDS, built_in: OneS_BUILT_IN},
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.NUMBER_MODE,
      STR_START, STR_CONT,
      {
        className: 'function',
        begin: '(процедура|функция)', end: '$',
        lexemes: IDENT_RE_RU,
        keywords: 'процедура функция',
        contains: [
          hljs.inherit(hljs.TITLE_MODE, {begin: IDENT_RE_RU}),
          {
            className: 'tail',
            endsWithParent: true,
            contains: [
              {
                className: 'params',
                begin: '\\(', end: '\\)',
                lexemes: IDENT_RE_RU,
                keywords: 'знач',
                contains: [STR_START, STR_CONT]
              },
              {
                className: 'export',
                begin: 'экспорт', endsWithParent: true,
                lexemes: IDENT_RE_RU,
                keywords: 'экспорт',
                contains: [hljs.C_LINE_COMMENT_MODE]
              }
            ]
          },
          hljs.C_LINE_COMMENT_MODE
        ]
      },
      {className: 'preprocessor', begin: '#', end: '$'},
      {className: 'date', begin: '\'\\d{2}\\.\\d{2}\\.(\\d{2}|\\d{4})\''}
    ]
  };
});

hljs.registerLanguage('accesslog', function(hljs) {
  return {
    contains: [
      // IP
      {
        className: 'number',
        begin: '\\b\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}(:\\d{1,5})?\\b'
      },
      // Other numbers
      {
        className: 'number',
        begin: '\\b\\d+\\b',
        relevance: 0
      },
      // Requests
      {
        className: 'string',
        begin: '"(GET|POST|HEAD|PUT|DELETE|CONNECT|OPTIONS|PATCH|TRACE)', end: '"',
        keywords: 'GET POST HEAD PUT DELETE CONNECT OPTIONS PATCH TRACE',
        illegal: '\\n',
        relevance: 10
      },
      // Dates
      {
        className: 'string',
        begin: /\[/, end: /\]/,
        illegal: '\\n'
      },
      // Strings
      {
        className: 'string',
        begin: '"', end: '"',
        illegal: '\\n'
      }
    ]
  };
});

hljs.registerLanguage('actionscript', function(hljs) {
  var IDENT_RE = '[a-zA-Z_$][a-zA-Z0-9_$]*';
  var IDENT_FUNC_RETURN_TYPE_RE = '([*]|[a-zA-Z_$][a-zA-Z0-9_$]*)';

  var AS3_REST_ARG_MODE = {
    className: 'rest_arg',
    begin: '[.]{3}', end: IDENT_RE,
    relevance: 10
  };

  return {
    aliases: ['as'],
    keywords: {
      keyword: 'as break case catch class const continue default delete do dynamic each ' +
        'else extends final finally for function get if implements import in include ' +
        'instanceof interface internal is namespace native new override package private ' +
        'protected public return set static super switch this throw try typeof use var void ' +
        'while with',
      literal: 'true false null undefined'
    },
    contains: [
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.C_NUMBER_MODE,
      {
        className: 'package',
        beginKeywords: 'package', end: '{',
        contains: [hljs.TITLE_MODE]
      },
      {
        className: 'class',
        beginKeywords: 'class interface', end: '{', excludeEnd: true,
        contains: [
          {
            beginKeywords: 'extends implements'
          },
          hljs.TITLE_MODE
        ]
      },
      {
        className: 'preprocessor',
        beginKeywords: 'import include', end: ';'
      },
      {
        className: 'function',
        beginKeywords: 'function', end: '[{;]', excludeEnd: true,
        illegal: '\\S',
        contains: [
          hljs.TITLE_MODE,
          {
            className: 'params',
            begin: '\\(', end: '\\)',
            contains: [
              hljs.APOS_STRING_MODE,
              hljs.QUOTE_STRING_MODE,
              hljs.C_LINE_COMMENT_MODE,
              hljs.C_BLOCK_COMMENT_MODE,
              AS3_REST_ARG_MODE
            ]
          },
          {
            className: 'type',
            begin: ':',
            end: IDENT_FUNC_RETURN_TYPE_RE,
            relevance: 10
          }
        ]
      }
    ],
    illegal: /#/
  };
});

hljs.registerLanguage('apache', function(hljs) {
  var NUMBER = {className: 'number', begin: '[\\$%]\\d+'};
  return {
    aliases: ['apacheconf'],
    case_insensitive: true,
    contains: [
      hljs.HASH_COMMENT_MODE,
      {className: 'tag', begin: '</?', end: '>'},
      {
        className: 'keyword',
        begin: /\w+/,
        relevance: 0,
        // keywords aren’t needed for highlighting per se, they only boost relevance
        // for a very generally defined mode (starts with a word, ends with line-end
        keywords: {
          common:
            'order deny allow setenv rewriterule rewriteengine rewritecond documentroot ' +
            'sethandler errordocument loadmodule options header listen serverroot ' +
            'servername'
        },
        starts: {
          end: /$/,
          relevance: 0,
          keywords: {
            literal: 'on off all'
          },
          contains: [
            {
              className: 'sqbracket',
              begin: '\\s\\[', end: '\\]$'
            },
            {
              className: 'cbracket',
              begin: '[\\$%]\\{', end: '\\}',
              contains: ['self', NUMBER]
            },
            NUMBER,
            hljs.QUOTE_STRING_MODE
          ]
        }
      }
    ],
    illegal: /\S/
  };
});

hljs.registerLanguage('applescript', function(hljs) {
  var STRING = hljs.inherit(hljs.QUOTE_STRING_MODE, {illegal: ''});
  var PARAMS = {
    className: 'params',
    begin: '\\(', end: '\\)',
    contains: ['self', hljs.C_NUMBER_MODE, STRING]
  };
  var COMMENT_MODE_1 = hljs.COMMENT('--', '$');
  var COMMENT_MODE_2 = hljs.COMMENT(
    '\\(\\*',
    '\\*\\)',
    {
      contains: ['self', COMMENT_MODE_1] //allow nesting
    }
  );
  var COMMENTS = [
    COMMENT_MODE_1,
    COMMENT_MODE_2,
    hljs.HASH_COMMENT_MODE
  ];

  return {
    aliases: ['osascript'],
    keywords: {
      keyword:
        'about above after against and around as at back before beginning ' +
        'behind below beneath beside between but by considering ' +
        'contain contains continue copy div does eighth else end equal ' +
        'equals error every exit fifth first for fourth from front ' +
        'get given global if ignoring in into is it its last local me ' +
        'middle mod my ninth not of on onto or over prop property put ref ' +
        'reference repeat returning script second set seventh since ' +
        'sixth some tell tenth that the|0 then third through thru ' +
        'timeout times to transaction try until where while whose with ' +
        'without',
      constant:
        'AppleScript false linefeed return pi quote result space tab true',
      type:
        'alias application boolean class constant date file integer list ' +
        'number real record string text',
      command:
        'activate beep count delay launch log offset read round ' +
        'run say summarize write',
      property:
        'character characters contents day frontmost id item length ' +
        'month name paragraph paragraphs rest reverse running time version ' +
        'weekday word words year'
    },
    contains: [
      STRING,
      hljs.C_NUMBER_MODE,
      {
        className: 'type',
        begin: '\\bPOSIX file\\b'
      },
      {
        className: 'command',
        begin:
          '\\b(clipboard info|the clipboard|info for|list (disks|folder)|' +
          'mount volume|path to|(close|open for) access|(get|set) eof|' +
          'current date|do shell script|get volume settings|random number|' +
          'set volume|system attribute|system info|time to GMT|' +
          '(load|run|store) script|scripting components|' +
          'ASCII (character|number)|localized string|' +
          'choose (application|color|file|file name|' +
          'folder|from list|remote application|URL)|' +
          'display (alert|dialog))\\b|^\\s*return\\b'
      },
      {
        className: 'constant',
        begin:
          '\\b(text item delimiters|current application|missing value)\\b'
      },
      {
        className: 'keyword',
        begin:
          '\\b(apart from|aside from|instead of|out of|greater than|' +
          "isn't|(doesn't|does not) (equal|come before|come after|contain)|" +
          '(greater|less) than( or equal)?|(starts?|ends|begins?) with|' +
          'contained by|comes (before|after)|a (ref|reference))\\b'
      },
      {
        className: 'property',
        begin:
          '\\b(POSIX path|(date|time) string|quoted form)\\b'
      },
      {
        className: 'function_start',
        beginKeywords: 'on',
        illegal: '[${=;\\n]',
        contains: [hljs.UNDERSCORE_TITLE_MODE, PARAMS]
      }
    ].concat(COMMENTS),
    illegal: '//|->|=>|\\[\\['
  };
});

hljs.registerLanguage('armasm', function(hljs) {
    //local labels: %?[FB]?[AT]?\d{1,2}\w+
  return {
    case_insensitive: true,
    aliases: ['arm'],
    lexemes: '\\.?' + hljs.IDENT_RE,
    keywords: {
      literal:
        'r0 r1 r2 r3 r4 r5 r6 r7 r8 r9 r10 r11 r12 r13 r14 r15 '+ //standard registers
        'pc lr sp ip sl sb fp '+ //typical regs plus backward compatibility
        'a1 a2 a3 a4 v1 v2 v3 v4 v5 v6 v7 v8 f0 f1 f2 f3 f4 f5 f6 f7 '+ //more regs and fp
        'p0 p1 p2 p3 p4 p5 p6 p7 p8 p9 p10 p11 p12 p13 p14 p15 '+ //coprocessor regs
        'c0 c1 c2 c3 c4 c5 c6 c7 c8 c9 c10 c11 c12 c13 c14 c15 '+ //more coproc
        'q0 q1 q2 q3 q4 q5 q6 q7 q8 q9 q10 q11 q12 q13 q14 q15 '+ //advanced SIMD NEON regs

        //program status registers
        'cpsr_c cpsr_x cpsr_s cpsr_f cpsr_cx cpsr_cxs cpsr_xs cpsr_xsf cpsr_sf cpsr_cxsf '+
        'spsr_c spsr_x spsr_s spsr_f spsr_cx spsr_cxs spsr_xs spsr_xsf spsr_sf spsr_cxsf '+

        //NEON and VFP registers
        's0 s1 s2 s3 s4 s5 s6 s7 s8 s9 s10 s11 s12 s13 s14 s15 '+
        's16 s17 s18 s19 s20 s21 s22 s23 s24 s25 s26 s27 s28 s29 s30 s31 '+
        'd0 d1 d2 d3 d4 d5 d6 d7 d8 d9 d10 d11 d12 d13 d14 d15 '+
        'd16 d17 d18 d19 d20 d21 d22 d23 d24 d25 d26 d27 d28 d29 d30 d31 ',
    preprocessor:
        //GNU preprocs
        '.2byte .4byte .align .ascii .asciz .balign .byte .code .data .else .end .endif .endm .endr .equ .err .exitm .extern .global .hword .if .ifdef .ifndef .include .irp .long .macro .rept .req .section .set .skip .space .text .word .arm .thumb .code16 .code32 .force_thumb .thumb_func .ltorg '+
        //ARM directives
        'ALIAS ALIGN ARM AREA ASSERT ATTR CN CODE CODE16 CODE32 COMMON CP DATA DCB DCD DCDU DCDO DCFD DCFDU DCI DCQ DCQU DCW DCWU DN ELIF ELSE END ENDFUNC ENDIF ENDP ENTRY EQU EXPORT EXPORTAS EXTERN FIELD FILL FUNCTION GBLA GBLL GBLS GET GLOBAL IF IMPORT INCBIN INCLUDE INFO KEEP LCLA LCLL LCLS LTORG MACRO MAP MEND MEXIT NOFP OPT PRESERVE8 PROC QN READONLY RELOC REQUIRE REQUIRE8 RLIST FN ROUT SETA SETL SETS SN SPACE SUBT THUMB THUMBX TTL WHILE WEND ',
    built_in:
        '{PC} {VAR} {TRUE} {FALSE} {OPT} {CONFIG} {ENDIAN} {CODESIZE} {CPU} {FPU} {ARCHITECTURE} {PCSTOREOFFSET} {ARMASM_VERSION} {INTER} {ROPI} {RWPI} {SWST} {NOSWST} . @ '
    },
    contains: [
      {
        className: 'keyword',
        begin: '\\b('+     //mnemonics
            'adc|'+
            '(qd?|sh?|u[qh]?)?add(8|16)?|usada?8|(q|sh?|u[qh]?)?(as|sa)x|'+
            'and|adrl?|sbc|rs[bc]|asr|b[lx]?|blx|bxj|cbn?z|tb[bh]|bic|'+
            'bfc|bfi|[su]bfx|bkpt|cdp2?|clz|clrex|cmp|cmn|cpsi[ed]|cps|'+
            'setend|dbg|dmb|dsb|eor|isb|it[te]{0,3}|lsl|lsr|ror|rrx|'+
            'ldm(([id][ab])|f[ds])?|ldr((s|ex)?[bhd])?|movt?|mvn|mra|mar|'+
            'mul|[us]mull|smul[bwt][bt]|smu[as]d|smmul|smmla|'+
            'mla|umlaal|smlal?([wbt][bt]|d)|mls|smlsl?[ds]|smc|svc|sev|'+
            'mia([bt]{2}|ph)?|mrr?c2?|mcrr2?|mrs|msr|orr|orn|pkh(tb|bt)|rbit|'+
            'rev(16|sh)?|sel|[su]sat(16)?|nop|pop|push|rfe([id][ab])?|'+
            'stm([id][ab])?|str(ex)?[bhd]?|(qd?)?sub|(sh?|q|u[qh]?)?sub(8|16)|'+
            '[su]xt(a?h|a?b(16)?)|srs([id][ab])?|swpb?|swi|smi|tst|teq|'+
            'wfe|wfi|yield'+
        ')'+
        '(eq|ne|cs|cc|mi|pl|vs|vc|hi|ls|ge|lt|gt|le|al|hs|lo)?'+ //condition codes
        '[sptrx]?' ,                                             //legal postfixes
        end: '\\s'
      },
      hljs.COMMENT('[;@]', '$', {relevance: 0}),
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.QUOTE_STRING_MODE,
      {
        className: 'string',
        begin: '\'',
        end: '[^\\\\]\'',
        relevance: 0
      },
      {
        className: 'title',
        begin: '\\|', end: '\\|',
        illegal: '\\n',
        relevance: 0
      },
      {
        className: 'number',
        variants: [
            {begin: '[#$=]?0x[0-9a-f]+'}, //hex
            {begin: '[#$=]?0b[01]+'},     //bin
            {begin: '[#$=]\\d+'},        //literal
            {begin: '\\b\\d+'}           //bare number
        ],
        relevance: 0
      },
      {
        className: 'label',
        variants: [
            {begin: '^[a-z_\\.\\$][a-z0-9_\\.\\$]+'}, //ARM syntax
            {begin: '^\\s*[a-z_\\.\\$][a-z0-9_\\.\\$]+:'}, //GNU ARM syntax
            {begin: '[=#]\\w+' }  //label reference
        ],
        relevance: 0
      }
    ]
  };
});

hljs.registerLanguage('xml', function(hljs) {
  var XML_IDENT_RE = '[A-Za-z0-9\\._:-]+';
  var PHP = {
    begin: /<\?(php)?(?!\w)/, end: /\?>/,
    subLanguage: 'php'
  };
  var TAG_INTERNALS = {
    endsWithParent: true,
    illegal: /</,
    relevance: 0,
    contains: [
      PHP,
      {
        className: 'attribute',
        begin: XML_IDENT_RE,
        relevance: 0
      },
      {
        begin: '=',
        relevance: 0,
        contains: [
          {
            className: 'value',
            contains: [PHP],
            variants: [
              {begin: /"/, end: /"/},
              {begin: /'/, end: /'/},
              {begin: /[^\s\/>]+/}
            ]
          }
        ]
      }
    ]
  };
  return {
    aliases: ['html', 'xhtml', 'rss', 'atom', 'xsl', 'plist'],
    case_insensitive: true,
    contains: [
      {
        className: 'doctype',
        begin: '<!DOCTYPE', end: '>',
        relevance: 10,
        contains: [{begin: '\\[', end: '\\]'}]
      },
      hljs.COMMENT(
        '<!--',
        '-->',
        {
          relevance: 10
        }
      ),
      {
        className: 'cdata',
        begin: '<\\!\\[CDATA\\[', end: '\\]\\]>',
        relevance: 10
      },
      {
        className: 'tag',
        /*
        The lookahead pattern (?=...) ensures that 'begin' only matches
        '<style' as a single word, followed by a whitespace or an
        ending braket. The '$' is needed for the lexeme to be recognized
        by hljs.subMode() that tests lexemes outside the stream.
        */
        begin: '<style(?=\\s|>|$)', end: '>',
        keywords: {title: 'style'},
        contains: [TAG_INTERNALS],
        starts: {
          end: '</style>', returnEnd: true,
          subLanguage: 'css'
        }
      },
      {
        className: 'tag',
        // See the comment in the <style tag about the lookahead pattern
        begin: '<script(?=\\s|>|$)', end: '>',
        keywords: {title: 'script'},
        contains: [TAG_INTERNALS],
        starts: {
          end: '\<\/script\>', returnEnd: true,
          subLanguage: ['actionscript', 'javascript', 'handlebars']
        }
      },
      PHP,
      {
        className: 'pi',
        begin: /<\?\w+/, end: /\?>/,
        relevance: 10
      },
      {
        className: 'tag',
        begin: '</?', end: '/?>',
        contains: [
          {
            className: 'title', begin: /[^ \/><\n\t]+/, relevance: 0
          },
          TAG_INTERNALS
        ]
      }
    ]
  };
});

hljs.registerLanguage('asciidoc', function(hljs) {
  return {
    aliases: ['adoc'],
    contains: [
      // block comment
      hljs.COMMENT(
        '^/{4,}\\n',
        '\\n/{4,}$',
        // can also be done as...
        //'^/{4,}$',
        //'^/{4,}$',
        {
          relevance: 10
        }
      ),
      // line comment
      hljs.COMMENT(
        '^//',
        '$',
        {
          relevance: 0
        }
      ),
      // title
      {
        className: 'title',
        begin: '^\\.\\w.*$'
      },
      // example, admonition & sidebar blocks
      {
        begin: '^[=\\*]{4,}\\n',
        end: '\\n^[=\\*]{4,}$',
        relevance: 10
      },
      // headings
      {
        className: 'header',
        begin: '^(={1,5}) .+?( \\1)?$',
        relevance: 10
      },
      {
        className: 'header',
        begin: '^[^\\[\\]\\n]+?\\n[=\\-~\\^\\+]{2,}$',
        relevance: 10
      },
      // document attributes
      {
        className: 'attribute',
        begin: '^:.+?:',
        end: '\\s',
        excludeEnd: true,
        relevance: 10
      },
      // block attributes
      {
        className: 'attribute',
        begin: '^\\[.+?\\]$',
        relevance: 0
      },
      // quoteblocks
      {
        className: 'blockquote',
        begin: '^_{4,}\\n',
        end: '\\n_{4,}$',
        relevance: 10
      },
      // listing and literal blocks
      {
        className: 'code',
        begin: '^[\\-\\.]{4,}\\n',
        end: '\\n[\\-\\.]{4,}$',
        relevance: 10
      },
      // passthrough blocks
      {
        begin: '^\\+{4,}\\n',
        end: '\\n\\+{4,}$',
        contains: [
          {
            begin: '<', end: '>',
            subLanguage: 'xml',
            relevance: 0
          }
        ],
        relevance: 10
      },
      // lists (can only capture indicators)
      {
        className: 'bullet',
        begin: '^(\\*+|\\-+|\\.+|[^\\n]+?::)\\s+'
      },
      // admonition
      {
        className: 'label',
        begin: '^(NOTE|TIP|IMPORTANT|WARNING|CAUTION):\\s+',
        relevance: 10
      },
      // inline strong
      {
        className: 'strong',
        // must not follow a word character or be followed by an asterisk or space
        begin: '\\B\\*(?![\\*\\s])',
        end: '(\\n{2}|\\*)',
        // allow escaped asterisk followed by word char
        contains: [
          {
            begin: '\\\\*\\w',
            relevance: 0
          }
        ]
      },
      // inline emphasis
      {
        className: 'emphasis',
        // must not follow a word character or be followed by a single quote or space
        begin: '\\B\'(?![\'\\s])',
        end: '(\\n{2}|\')',
        // allow escaped single quote followed by word char
        contains: [
          {
            begin: '\\\\\'\\w',
            relevance: 0
          }
        ],
        relevance: 0
      },
      // inline emphasis (alt)
      {
        className: 'emphasis',
        // must not follow a word character or be followed by an underline or space
        begin: '_(?![_\\s])',
        end: '(\\n{2}|_)',
        relevance: 0
      },
      // inline smart quotes
      {
        className: 'smartquote',
        variants: [
          {begin: "``.+?''"},
          {begin: "`.+?'"}
        ]
      },
      // inline code snippets (TODO should get same treatment as strong and emphasis)
      {
        className: 'code',
        begin: '(`.+?`|\\+.+?\\+)',
        relevance: 0
      },
      // indented literal block
      {
        className: 'code',
        begin: '^[ \\t]',
        end: '$',
        relevance: 0
      },
      // horizontal rules
      {
        className: 'horizontal_rule',
        begin: '^\'{3,}[ \\t]*$',
        relevance: 10
      },
      // images and links
      {
        begin: '(link:)?(http|https|ftp|file|irc|image:?):\\S+\\[.*?\\]',
        returnBegin: true,
        contains: [
          {
            //className: 'macro',
            begin: '(link|image:?):',
            relevance: 0
          },
          {
            className: 'link_url',
            begin: '\\w',
            end: '[^\\[]+',
            relevance: 0
          },
          {
            className: 'link_label',
            begin: '\\[',
            end: '\\]',
            excludeBegin: true,
            excludeEnd: true,
            relevance: 0
          }
        ],
        relevance: 10
      }
    ]
  };
});

hljs.registerLanguage('aspectj', function (hljs) {
  var KEYWORDS =
    'false synchronized int abstract float private char boolean static null if const ' +
    'for true while long throw strictfp finally protected import native final return void ' +
    'enum else extends implements break transient new catch instanceof byte super volatile case ' +
    'assert short package default double public try this switch continue throws privileged ' +
    'aspectOf adviceexecution proceed cflowbelow cflow initialization preinitialization ' +
    'staticinitialization withincode target within execution getWithinTypeName handler ' +
    'thisJoinPoint thisJoinPointStaticPart thisEnclosingJoinPointStaticPart declare parents '+
    'warning error soft precedence thisAspectInstance';
  var SHORTKEYS = 'get set args call';
  return {
    keywords : KEYWORDS,
    illegal : /<\/|#/,
    contains : [
      hljs.COMMENT(
        '/\\*\\*',
        '\\*/',
        {
          relevance : 0,
          contains : [{
            className : 'doctag',
            begin : '@[A-Za-z]+'
          }]
        }
      ),
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      {
        className : 'aspect',
        beginKeywords : 'aspect',
        end : /[{;=]/,
        excludeEnd : true,
        illegal : /[:;"\[\]]/,
        contains : [
          {
            beginKeywords : 'extends implements pertypewithin perthis pertarget percflowbelow percflow issingleton'
          },
          hljs.UNDERSCORE_TITLE_MODE,
          {
            begin : /\([^\)]*/,
            end : /[)]+/,
            keywords : KEYWORDS + ' ' + SHORTKEYS,
            excludeEnd : false
          }
        ]
      },
      {
        className : 'class',
        beginKeywords : 'class interface',
        end : /[{;=]/,
        excludeEnd : true,
        relevance: 0,
        keywords : 'class interface',
        illegal : /[:"\[\]]/,
        contains : [
          {beginKeywords : 'extends implements'},
          hljs.UNDERSCORE_TITLE_MODE
        ]
      },
      {
        // AspectJ Constructs
        beginKeywords : 'pointcut after before around throwing returning',
        end : /[)]/,
        excludeEnd : false,
        illegal : /["\[\]]/,
        contains : [
          {
            begin : hljs.UNDERSCORE_IDENT_RE + '\\s*\\(',
            returnBegin : true,
            contains : [hljs.UNDERSCORE_TITLE_MODE]
          }
        ]
      },
      {
        begin : /[:]/,
        returnBegin : true,
        end : /[{;]/,
        relevance: 0,
        excludeEnd : false,
        keywords : KEYWORDS,
        illegal : /["\[\]]/,
        contains : [
          {
            begin : hljs.UNDERSCORE_IDENT_RE + '\\s*\\(',
            keywords : KEYWORDS + ' ' + SHORTKEYS
          },
          hljs.QUOTE_STRING_MODE
        ]
      },
      {
        // this prevents 'new Name(...), or throw ...' from being recognized as a function definition
        beginKeywords : 'new throw',
        relevance : 0
      },
      {
        // the function class is a bit different for AspectJ compared to the Java language
        className : 'function',
        begin : /\w+ +\w+(\.)?\w+\s*\([^\)]*\)\s*((throws)[\w\s,]+)?[\{;]/,
        returnBegin : true,
        end : /[{;=]/,
        keywords : KEYWORDS,
        excludeEnd : true,
        contains : [
          {
            begin : hljs.UNDERSCORE_IDENT_RE + '\\s*\\(',
            returnBegin : true,
            relevance: 0,
            contains : [hljs.UNDERSCORE_TITLE_MODE]
          },
          {
            className : 'params',
            begin : /\(/, end : /\)/,
            relevance: 0,
            keywords : KEYWORDS,
            contains : [
              hljs.APOS_STRING_MODE,
              hljs.QUOTE_STRING_MODE,
              hljs.C_NUMBER_MODE,
              hljs.C_BLOCK_COMMENT_MODE
            ]
          },
          hljs.C_LINE_COMMENT_MODE,
          hljs.C_BLOCK_COMMENT_MODE
        ]
      },
      hljs.C_NUMBER_MODE,
      {
        // annotation is also used in this language
        className : 'annotation',
        begin : '@[A-Za-z]+'
      }
    ]
  };
});

hljs.registerLanguage('autohotkey', function(hljs) {
  var BACKTICK_ESCAPE = {
    className: 'escape',
    begin: '`[\\s\\S]'
  };
  var COMMENTS = hljs.COMMENT(
    ';',
    '$',
    {
      relevance: 0
    }
  );
  var BUILT_IN = [
    {
      className: 'built_in',
      begin: 'A_[a-zA-Z0-9]+'
    },
    {
      className: 'built_in',
      beginKeywords: 'ComSpec Clipboard ClipboardAll ErrorLevel'
    }
  ];

  return {
    case_insensitive: true,
    keywords: {
      keyword: 'Break Continue Else Gosub If Loop Return While',
      literal: 'A true false NOT AND OR'
    },
    contains: BUILT_IN.concat([
      BACKTICK_ESCAPE,
      hljs.inherit(hljs.QUOTE_STRING_MODE, {contains: [BACKTICK_ESCAPE]}),
      COMMENTS,
      {
        className: 'number',
        begin: hljs.NUMBER_RE,
        relevance: 0
      },
      {
        className: 'var_expand', // FIXME
        begin: '%', end: '%',
        illegal: '\\n',
        contains: [BACKTICK_ESCAPE]
      },
      {
        className: 'label',
        contains: [BACKTICK_ESCAPE],
        variants: [
          {begin: '^[^\\n";]+::(?!=)'},
          {begin: '^[^\\n";]+:(?!=)', relevance: 0} // zero relevance as it catches a lot of things
                                                    // followed by a single ':' in many languages
        ]
      },
      {
        // consecutive commas, not for highlighting but just for relevance
        begin: ',\\s*,',
        relevance: 10
      }
    ])
  }
});

hljs.registerLanguage('autoit', function(hljs) {
    var KEYWORDS = 'ByRef Case Const ContinueCase ContinueLoop ' +
        'Default Dim Do Else ElseIf EndFunc EndIf EndSelect ' +
        'EndSwitch EndWith Enum Exit ExitLoop For Func ' +
        'Global If In Local Next ReDim Return Select Static ' +
        'Step Switch Then To Until Volatile WEnd While With',

        LITERAL = 'True False And Null Not Or',

        BUILT_IN = 'Abs ACos AdlibRegister AdlibUnRegister Asc AscW ASin ' +
        'Assign ATan AutoItSetOption AutoItWinGetTitle ' +
        'AutoItWinSetTitle Beep Binary BinaryLen BinaryMid ' +
        'BinaryToString BitAND BitNOT BitOR BitRotate BitShift ' +
        'BitXOR BlockInput Break Call CDTray Ceiling Chr ' +
        'ChrW ClipGet ClipPut ConsoleRead ConsoleWrite ' +
        'ConsoleWriteError ControlClick ControlCommand ' +
        'ControlDisable ControlEnable ControlFocus ControlGetFocus ' +
        'ControlGetHandle ControlGetPos ControlGetText ControlHide ' +
        'ControlListView ControlMove ControlSend ControlSetText ' +
        'ControlShow ControlTreeView Cos Dec DirCopy DirCreate ' +
        'DirGetSize DirMove DirRemove DllCall DllCallAddress ' +
        'DllCallbackFree DllCallbackGetPtr DllCallbackRegister ' +
        'DllClose DllOpen DllStructCreate DllStructGetData ' +
        'DllStructGetPtr DllStructGetSize DllStructSetData ' +
        'DriveGetDrive DriveGetFileSystem DriveGetLabel ' +
        'DriveGetSerial DriveGetType DriveMapAdd DriveMapDel ' +
        'DriveMapGet DriveSetLabel DriveSpaceFree DriveSpaceTotal ' +
        'DriveStatus EnvGet EnvSet EnvUpdate Eval Execute Exp ' +
        'FileChangeDir FileClose FileCopy FileCreateNTFSLink ' +
        'FileCreateShortcut FileDelete FileExists FileFindFirstFile ' +
        'FileFindNextFile FileFlush FileGetAttrib FileGetEncoding ' +
        'FileGetLongName FileGetPos FileGetShortcut FileGetShortName ' +
        'FileGetSize FileGetTime FileGetVersion FileInstall ' +
        'FileMove FileOpen FileOpenDialog FileRead FileReadLine ' +
        'FileReadToArray FileRecycle FileRecycleEmpty FileSaveDialog ' +
        'FileSelectFolder FileSetAttrib FileSetEnd FileSetPos ' +
        'FileSetTime FileWrite FileWriteLine Floor FtpSetProxy ' +
        'FuncName GUICreate GUICtrlCreateAvi GUICtrlCreateButton ' +
        'GUICtrlCreateCheckbox GUICtrlCreateCombo ' +
        'GUICtrlCreateContextMenu GUICtrlCreateDate GUICtrlCreateDummy ' +
        'GUICtrlCreateEdit GUICtrlCreateGraphic GUICtrlCreateGroup ' +
        'GUICtrlCreateIcon GUICtrlCreateInput GUICtrlCreateLabel ' +
        'GUICtrlCreateList GUICtrlCreateListView ' +
        'GUICtrlCreateListViewItem GUICtrlCreateMenu ' +
        'GUICtrlCreateMenuItem GUICtrlCreateMonthCal GUICtrlCreateObj ' +
        'GUICtrlCreatePic GUICtrlCreateProgress GUICtrlCreateRadio ' +
        'GUICtrlCreateSlider GUICtrlCreateTab GUICtrlCreateTabItem ' +
        'GUICtrlCreateTreeView GUICtrlCreateTreeViewItem ' +
        'GUICtrlCreateUpdown GUICtrlDelete GUICtrlGetHandle ' +
        'GUICtrlGetState GUICtrlRead GUICtrlRecvMsg ' +
        'GUICtrlRegisterListViewSort GUICtrlSendMsg GUICtrlSendToDummy ' +
        'GUICtrlSetBkColor GUICtrlSetColor GUICtrlSetCursor ' +
        'GUICtrlSetData GUICtrlSetDefBkColor GUICtrlSetDefColor ' +
        'GUICtrlSetFont GUICtrlSetGraphic GUICtrlSetImage ' +
        'GUICtrlSetLimit GUICtrlSetOnEvent GUICtrlSetPos ' +
        'GUICtrlSetResizing GUICtrlSetState GUICtrlSetStyle ' +
        'GUICtrlSetTip GUIDelete GUIGetCursorInfo GUIGetMsg ' +
        'GUIGetStyle GUIRegisterMsg GUISetAccelerators GUISetBkColor ' +
        'GUISetCoord GUISetCursor GUISetFont GUISetHelp GUISetIcon ' +
        'GUISetOnEvent GUISetState GUISetStyle GUIStartGroup ' +
        'GUISwitch Hex HotKeySet HttpSetProxy HttpSetUserAgent ' +
        'HWnd InetClose InetGet InetGetInfo InetGetSize InetRead ' +
        'IniDelete IniRead IniReadSection IniReadSectionNames ' +
        'IniRenameSection IniWrite IniWriteSection InputBox Int ' +
        'IsAdmin IsArray IsBinary IsBool IsDeclared IsDllStruct ' +
        'IsFloat IsFunc IsHWnd IsInt IsKeyword IsNumber IsObj ' +
        'IsPtr IsString Log MemGetStats Mod MouseClick ' +
        'MouseClickDrag MouseDown MouseGetCursor MouseGetPos ' +
        'MouseMove MouseUp MouseWheel MsgBox Number ObjCreate ' +
        'ObjCreateInterface ObjEvent ObjGet ObjName ' +
        'OnAutoItExitRegister OnAutoItExitUnRegister Opt Ping ' +
        'PixelChecksum PixelGetColor PixelSearch ProcessClose ' +
        'ProcessExists ProcessGetStats ProcessList ' +
        'ProcessSetPriority ProcessWait ProcessWaitClose ProgressOff ' +
        'ProgressOn ProgressSet Ptr Random RegDelete RegEnumKey ' +
        'RegEnumVal RegRead RegWrite Round Run RunAs RunAsWait ' +
        'RunWait Send SendKeepActive SetError SetExtended ' +
        'ShellExecute ShellExecuteWait Shutdown Sin Sleep ' +
        'SoundPlay SoundSetWaveVolume SplashImageOn SplashOff ' +
        'SplashTextOn Sqrt SRandom StatusbarGetText StderrRead ' +
        'StdinWrite StdioClose StdoutRead String StringAddCR ' +
        'StringCompare StringFormat StringFromASCIIArray StringInStr ' +
        'StringIsAlNum StringIsAlpha StringIsASCII StringIsDigit ' +
        'StringIsFloat StringIsInt StringIsLower StringIsSpace ' +
        'StringIsUpper StringIsXDigit StringLeft StringLen ' +
        'StringLower StringMid StringRegExp StringRegExpReplace ' +
        'StringReplace StringReverse StringRight StringSplit ' +
        'StringStripCR StringStripWS StringToASCIIArray ' +
        'StringToBinary StringTrimLeft StringTrimRight StringUpper ' +
        'Tan TCPAccept TCPCloseSocket TCPConnect TCPListen ' +
        'TCPNameToIP TCPRecv TCPSend TCPShutdown TCPStartup ' +
        'TimerDiff TimerInit ToolTip TrayCreateItem TrayCreateMenu ' +
        'TrayGetMsg TrayItemDelete TrayItemGetHandle ' +
        'TrayItemGetState TrayItemGetText TrayItemSetOnEvent ' +
        'TrayItemSetState TrayItemSetText TraySetClick TraySetIcon ' +
        'TraySetOnEvent TraySetPauseIcon TraySetState TraySetToolTip ' +
        'TrayTip UBound UDPBind UDPCloseSocket UDPOpen UDPRecv ' +
        'UDPSend UDPShutdown UDPStartup VarGetType WinActivate ' +
        'WinActive WinClose WinExists WinFlash WinGetCaretPos ' +
        'WinGetClassList WinGetClientSize WinGetHandle WinGetPos ' +
        'WinGetProcess WinGetState WinGetText WinGetTitle WinKill ' +
        'WinList WinMenuSelectItem WinMinimizeAll WinMinimizeAllUndo ' +
        'WinMove WinSetOnTop WinSetState WinSetTitle WinSetTrans ' +
        'WinWait WinWaitActive WinWaitClose WinWaitNotActive ' +
        'Array1DToHistogram ArrayAdd ArrayBinarySearch ' +
        'ArrayColDelete ArrayColInsert ArrayCombinations ' +
        'ArrayConcatenate ArrayDelete ArrayDisplay ArrayExtract ' +
        'ArrayFindAll ArrayInsert ArrayMax ArrayMaxIndex ArrayMin ' +
        'ArrayMinIndex ArrayPermute ArrayPop ArrayPush ' +
        'ArrayReverse ArraySearch ArrayShuffle ArraySort ArraySwap ' +
        'ArrayToClip ArrayToString ArrayTranspose ArrayTrim ' +
        'ArrayUnique Assert ChooseColor ChooseFont ' +
        'ClipBoard_ChangeChain ClipBoard_Close ClipBoard_CountFormats ' +
        'ClipBoard_Empty ClipBoard_EnumFormats ClipBoard_FormatStr ' +
        'ClipBoard_GetData ClipBoard_GetDataEx ClipBoard_GetFormatName ' +
        'ClipBoard_GetOpenWindow ClipBoard_GetOwner ' +
        'ClipBoard_GetPriorityFormat ClipBoard_GetSequenceNumber ' +
        'ClipBoard_GetViewer ClipBoard_IsFormatAvailable ' +
        'ClipBoard_Open ClipBoard_RegisterFormat ClipBoard_SetData ' +
        'ClipBoard_SetDataEx ClipBoard_SetViewer ClipPutFile ' +
        'ColorConvertHSLtoRGB ColorConvertRGBtoHSL ColorGetBlue ' +
        'ColorGetCOLORREF ColorGetGreen ColorGetRed ColorGetRGB ' +
        'ColorSetCOLORREF ColorSetRGB Crypt_DecryptData ' +
        'Crypt_DecryptFile Crypt_DeriveKey Crypt_DestroyKey ' +
        'Crypt_EncryptData Crypt_EncryptFile Crypt_GenRandom ' +
        'Crypt_HashData Crypt_HashFile Crypt_Shutdown Crypt_Startup ' +
        'DateAdd DateDayOfWeek DateDaysInMonth DateDiff ' +
        'DateIsLeapYear DateIsValid DateTimeFormat DateTimeSplit ' +
        'DateToDayOfWeek DateToDayOfWeekISO DateToDayValue ' +
        'DateToMonth Date_Time_CompareFileTime ' +
        'Date_Time_DOSDateTimeToArray Date_Time_DOSDateTimeToFileTime ' +
        'Date_Time_DOSDateTimeToStr Date_Time_DOSDateToArray ' +
        'Date_Time_DOSDateToStr Date_Time_DOSTimeToArray ' +
        'Date_Time_DOSTimeToStr Date_Time_EncodeFileTime ' +
        'Date_Time_EncodeSystemTime Date_Time_FileTimeToArray ' +
        'Date_Time_FileTimeToDOSDateTime ' +
        'Date_Time_FileTimeToLocalFileTime Date_Time_FileTimeToStr ' +
        'Date_Time_FileTimeToSystemTime Date_Time_GetFileTime ' +
        'Date_Time_GetLocalTime Date_Time_GetSystemTime ' +
        'Date_Time_GetSystemTimeAdjustment ' +
        'Date_Time_GetSystemTimeAsFileTime Date_Time_GetSystemTimes ' +
        'Date_Time_GetTickCount Date_Time_GetTimeZoneInformation ' +
        'Date_Time_LocalFileTimeToFileTime Date_Time_SetFileTime ' +
        'Date_Time_SetLocalTime Date_Time_SetSystemTime ' +
        'Date_Time_SetSystemTimeAdjustment ' +
        'Date_Time_SetTimeZoneInformation Date_Time_SystemTimeToArray ' +
        'Date_Time_SystemTimeToDateStr Date_Time_SystemTimeToDateTimeStr ' +
        'Date_Time_SystemTimeToFileTime Date_Time_SystemTimeToTimeStr ' +
        'Date_Time_SystemTimeToTzSpecificLocalTime ' +
        'Date_Time_TzSpecificLocalTimeToSystemTime DayValueToDate ' +
        'DebugBugReportEnv DebugCOMError DebugOut DebugReport ' +
        'DebugReportEx DebugReportVar DebugSetup Degree ' +
        'EventLog__Backup EventLog__Clear EventLog__Close ' +
        'EventLog__Count EventLog__DeregisterSource EventLog__Full ' +
        'EventLog__Notify EventLog__Oldest EventLog__Open ' +
        'EventLog__OpenBackup EventLog__Read EventLog__RegisterSource ' +
        'EventLog__Report Excel_BookAttach Excel_BookClose ' +
        'Excel_BookList Excel_BookNew Excel_BookOpen ' +
        'Excel_BookOpenText Excel_BookSave Excel_BookSaveAs ' +
        'Excel_Close Excel_ColumnToLetter Excel_ColumnToNumber ' +
        'Excel_ConvertFormula Excel_Export Excel_FilterGet ' +
        'Excel_FilterSet Excel_Open Excel_PictureAdd Excel_Print ' +
        'Excel_RangeCopyPaste Excel_RangeDelete Excel_RangeFind ' +
        'Excel_RangeInsert Excel_RangeLinkAddRemove Excel_RangeRead ' +
        'Excel_RangeReplace Excel_RangeSort Excel_RangeValidate ' +
        'Excel_RangeWrite Excel_SheetAdd Excel_SheetCopyMove ' +
        'Excel_SheetDelete Excel_SheetList FileCountLines FileCreate ' +
        'FileListToArray FileListToArrayRec FilePrint ' +
        'FileReadToArray FileWriteFromArray FileWriteLog ' +
        'FileWriteToLine FTP_Close FTP_Command FTP_Connect ' +
        'FTP_DecodeInternetStatus FTP_DirCreate FTP_DirDelete ' +
        'FTP_DirGetCurrent FTP_DirPutContents FTP_DirSetCurrent ' +
        'FTP_FileClose FTP_FileDelete FTP_FileGet FTP_FileGetSize ' +
        'FTP_FileOpen FTP_FilePut FTP_FileRead FTP_FileRename ' +
        'FTP_FileTimeLoHiToStr FTP_FindFileClose FTP_FindFileFirst ' +
        'FTP_FindFileNext FTP_GetLastResponseInfo FTP_ListToArray ' +
        'FTP_ListToArray2D FTP_ListToArrayEx FTP_Open ' +
        'FTP_ProgressDownload FTP_ProgressUpload FTP_SetStatusCallback ' +
        'GDIPlus_ArrowCapCreate GDIPlus_ArrowCapDispose ' +
        'GDIPlus_ArrowCapGetFillState GDIPlus_ArrowCapGetHeight ' +
        'GDIPlus_ArrowCapGetMiddleInset GDIPlus_ArrowCapGetWidth ' +
        'GDIPlus_ArrowCapSetFillState GDIPlus_ArrowCapSetHeight ' +
        'GDIPlus_ArrowCapSetMiddleInset GDIPlus_ArrowCapSetWidth ' +
        'GDIPlus_BitmapApplyEffect GDIPlus_BitmapApplyEffectEx ' +
        'GDIPlus_BitmapCloneArea GDIPlus_BitmapConvertFormat ' +
        'GDIPlus_BitmapCreateApplyEffect ' +
        'GDIPlus_BitmapCreateApplyEffectEx ' +
        'GDIPlus_BitmapCreateDIBFromBitmap GDIPlus_BitmapCreateFromFile ' +
        'GDIPlus_BitmapCreateFromGraphics ' +
        'GDIPlus_BitmapCreateFromHBITMAP GDIPlus_BitmapCreateFromHICON ' +
        'GDIPlus_BitmapCreateFromHICON32 GDIPlus_BitmapCreateFromMemory ' +
        'GDIPlus_BitmapCreateFromResource GDIPlus_BitmapCreateFromScan0 ' +
        'GDIPlus_BitmapCreateFromStream ' +
        'GDIPlus_BitmapCreateHBITMAPFromBitmap GDIPlus_BitmapDispose ' +
        'GDIPlus_BitmapGetHistogram GDIPlus_BitmapGetHistogramEx ' +
        'GDIPlus_BitmapGetHistogramSize GDIPlus_BitmapGetPixel ' +
        'GDIPlus_BitmapLockBits GDIPlus_BitmapSetPixel ' +
        'GDIPlus_BitmapUnlockBits GDIPlus_BrushClone ' +
        'GDIPlus_BrushCreateSolid GDIPlus_BrushDispose ' +
        'GDIPlus_BrushGetSolidColor GDIPlus_BrushGetType ' +
        'GDIPlus_BrushSetSolidColor GDIPlus_ColorMatrixCreate ' +
        'GDIPlus_ColorMatrixCreateGrayScale ' +
        'GDIPlus_ColorMatrixCreateNegative ' +
        'GDIPlus_ColorMatrixCreateSaturation ' +
        'GDIPlus_ColorMatrixCreateScale ' +
        'GDIPlus_ColorMatrixCreateTranslate GDIPlus_CustomLineCapClone ' +
        'GDIPlus_CustomLineCapCreate GDIPlus_CustomLineCapDispose ' +
        'GDIPlus_CustomLineCapGetStrokeCaps ' +
        'GDIPlus_CustomLineCapSetStrokeCaps GDIPlus_Decoders ' +
        'GDIPlus_DecodersGetCount GDIPlus_DecodersGetSize ' +
        'GDIPlus_DrawImageFX GDIPlus_DrawImageFXEx ' +
        'GDIPlus_DrawImagePoints GDIPlus_EffectCreate ' +
        'GDIPlus_EffectCreateBlur GDIPlus_EffectCreateBrightnessContrast ' +
        'GDIPlus_EffectCreateColorBalance GDIPlus_EffectCreateColorCurve ' +
        'GDIPlus_EffectCreateColorLUT GDIPlus_EffectCreateColorMatrix ' +
        'GDIPlus_EffectCreateHueSaturationLightness ' +
        'GDIPlus_EffectCreateLevels GDIPlus_EffectCreateRedEyeCorrection ' +
        'GDIPlus_EffectCreateSharpen GDIPlus_EffectCreateTint ' +
        'GDIPlus_EffectDispose GDIPlus_EffectGetParameters ' +
        'GDIPlus_EffectSetParameters GDIPlus_Encoders ' +
        'GDIPlus_EncodersGetCLSID GDIPlus_EncodersGetCount ' +
        'GDIPlus_EncodersGetParamList GDIPlus_EncodersGetParamListSize ' +
        'GDIPlus_EncodersGetSize GDIPlus_FontCreate ' +
        'GDIPlus_FontDispose GDIPlus_FontFamilyCreate ' +
        'GDIPlus_FontFamilyCreateFromCollection ' +
        'GDIPlus_FontFamilyDispose GDIPlus_FontFamilyGetCellAscent ' +
        'GDIPlus_FontFamilyGetCellDescent GDIPlus_FontFamilyGetEmHeight ' +
        'GDIPlus_FontFamilyGetLineSpacing GDIPlus_FontGetHeight ' +
        'GDIPlus_FontPrivateAddFont GDIPlus_FontPrivateAddMemoryFont ' +
        'GDIPlus_FontPrivateCollectionDispose ' +
        'GDIPlus_FontPrivateCreateCollection GDIPlus_GraphicsClear ' +
        'GDIPlus_GraphicsCreateFromHDC GDIPlus_GraphicsCreateFromHWND ' +
        'GDIPlus_GraphicsDispose GDIPlus_GraphicsDrawArc ' +
        'GDIPlus_GraphicsDrawBezier GDIPlus_GraphicsDrawClosedCurve ' +
        'GDIPlus_GraphicsDrawClosedCurve2 GDIPlus_GraphicsDrawCurve ' +
        'GDIPlus_GraphicsDrawCurve2 GDIPlus_GraphicsDrawEllipse ' +
        'GDIPlus_GraphicsDrawImage GDIPlus_GraphicsDrawImagePointsRect ' +
        'GDIPlus_GraphicsDrawImageRect GDIPlus_GraphicsDrawImageRectRect ' +
        'GDIPlus_GraphicsDrawLine GDIPlus_GraphicsDrawPath ' +
        'GDIPlus_GraphicsDrawPie GDIPlus_GraphicsDrawPolygon ' +
        'GDIPlus_GraphicsDrawRect GDIPlus_GraphicsDrawString ' +
        'GDIPlus_GraphicsDrawStringEx GDIPlus_GraphicsFillClosedCurve ' +
        'GDIPlus_GraphicsFillClosedCurve2 GDIPlus_GraphicsFillEllipse ' +
        'GDIPlus_GraphicsFillPath GDIPlus_GraphicsFillPie ' +
        'GDIPlus_GraphicsFillPolygon GDIPlus_GraphicsFillRect ' +
        'GDIPlus_GraphicsFillRegion GDIPlus_GraphicsGetCompositingMode ' +
        'GDIPlus_GraphicsGetCompositingQuality GDIPlus_GraphicsGetDC ' +
        'GDIPlus_GraphicsGetInterpolationMode ' +
        'GDIPlus_GraphicsGetSmoothingMode GDIPlus_GraphicsGetTransform ' +
        'GDIPlus_GraphicsMeasureCharacterRanges ' +
        'GDIPlus_GraphicsMeasureString GDIPlus_GraphicsReleaseDC ' +
        'GDIPlus_GraphicsResetClip GDIPlus_GraphicsResetTransform ' +
        'GDIPlus_GraphicsRestore GDIPlus_GraphicsRotateTransform ' +
        'GDIPlus_GraphicsSave GDIPlus_GraphicsScaleTransform ' +
        'GDIPlus_GraphicsSetClipPath GDIPlus_GraphicsSetClipRect ' +
        'GDIPlus_GraphicsSetClipRegion ' +
        'GDIPlus_GraphicsSetCompositingMode ' +
        'GDIPlus_GraphicsSetCompositingQuality ' +
        'GDIPlus_GraphicsSetInterpolationMode ' +
        'GDIPlus_GraphicsSetPixelOffsetMode ' +
        'GDIPlus_GraphicsSetSmoothingMode ' +
        'GDIPlus_GraphicsSetTextRenderingHint ' +
        'GDIPlus_GraphicsSetTransform GDIPlus_GraphicsTransformPoints ' +
        'GDIPlus_GraphicsTranslateTransform GDIPlus_HatchBrushCreate ' +
        'GDIPlus_HICONCreateFromBitmap GDIPlus_ImageAttributesCreate ' +
        'GDIPlus_ImageAttributesDispose ' +
        'GDIPlus_ImageAttributesSetColorKeys ' +
        'GDIPlus_ImageAttributesSetColorMatrix GDIPlus_ImageDispose ' +
        'GDIPlus_ImageGetDimension GDIPlus_ImageGetFlags ' +
        'GDIPlus_ImageGetGraphicsContext GDIPlus_ImageGetHeight ' +
        'GDIPlus_ImageGetHorizontalResolution ' +
        'GDIPlus_ImageGetPixelFormat GDIPlus_ImageGetRawFormat ' +
        'GDIPlus_ImageGetThumbnail GDIPlus_ImageGetType ' +
        'GDIPlus_ImageGetVerticalResolution GDIPlus_ImageGetWidth ' +
        'GDIPlus_ImageLoadFromFile GDIPlus_ImageLoadFromStream ' +
        'GDIPlus_ImageResize GDIPlus_ImageRotateFlip ' +
        'GDIPlus_ImageSaveToFile GDIPlus_ImageSaveToFileEx ' +
        'GDIPlus_ImageSaveToStream GDIPlus_ImageScale ' +
        'GDIPlus_LineBrushCreate GDIPlus_LineBrushCreateFromRect ' +
        'GDIPlus_LineBrushCreateFromRectWithAngle ' +
        'GDIPlus_LineBrushGetColors GDIPlus_LineBrushGetRect ' +
        'GDIPlus_LineBrushMultiplyTransform ' +
        'GDIPlus_LineBrushResetTransform GDIPlus_LineBrushSetBlend ' +
        'GDIPlus_LineBrushSetColors GDIPlus_LineBrushSetGammaCorrection ' +
        'GDIPlus_LineBrushSetLinearBlend GDIPlus_LineBrushSetPresetBlend ' +
        'GDIPlus_LineBrushSetSigmaBlend GDIPlus_LineBrushSetTransform ' +
        'GDIPlus_MatrixClone GDIPlus_MatrixCreate ' +
        'GDIPlus_MatrixDispose GDIPlus_MatrixGetElements ' +
        'GDIPlus_MatrixInvert GDIPlus_MatrixMultiply ' +
        'GDIPlus_MatrixRotate GDIPlus_MatrixScale ' +
        'GDIPlus_MatrixSetElements GDIPlus_MatrixShear ' +
        'GDIPlus_MatrixTransformPoints GDIPlus_MatrixTranslate ' +
        'GDIPlus_PaletteInitialize GDIPlus_ParamAdd GDIPlus_ParamInit ' +
        'GDIPlus_ParamSize GDIPlus_PathAddArc GDIPlus_PathAddBezier ' +
        'GDIPlus_PathAddClosedCurve GDIPlus_PathAddClosedCurve2 ' +
        'GDIPlus_PathAddCurve GDIPlus_PathAddCurve2 ' +
        'GDIPlus_PathAddCurve3 GDIPlus_PathAddEllipse ' +
        'GDIPlus_PathAddLine GDIPlus_PathAddLine2 GDIPlus_PathAddPath ' +
        'GDIPlus_PathAddPie GDIPlus_PathAddPolygon ' +
        'GDIPlus_PathAddRectangle GDIPlus_PathAddString ' +
        'GDIPlus_PathBrushCreate GDIPlus_PathBrushCreateFromPath ' +
        'GDIPlus_PathBrushGetCenterPoint GDIPlus_PathBrushGetFocusScales ' +
        'GDIPlus_PathBrushGetPointCount GDIPlus_PathBrushGetRect ' +
        'GDIPlus_PathBrushGetWrapMode GDIPlus_PathBrushMultiplyTransform ' +
        'GDIPlus_PathBrushResetTransform GDIPlus_PathBrushSetBlend ' +
        'GDIPlus_PathBrushSetCenterColor GDIPlus_PathBrushSetCenterPoint ' +
        'GDIPlus_PathBrushSetFocusScales ' +
        'GDIPlus_PathBrushSetGammaCorrection ' +
        'GDIPlus_PathBrushSetLinearBlend GDIPlus_PathBrushSetPresetBlend ' +
        'GDIPlus_PathBrushSetSigmaBlend ' +
        'GDIPlus_PathBrushSetSurroundColor ' +
        'GDIPlus_PathBrushSetSurroundColorsWithCount ' +
        'GDIPlus_PathBrushSetTransform GDIPlus_PathBrushSetWrapMode ' +
        'GDIPlus_PathClone GDIPlus_PathCloseFigure GDIPlus_PathCreate ' +
        'GDIPlus_PathCreate2 GDIPlus_PathDispose GDIPlus_PathFlatten ' +
        'GDIPlus_PathGetData GDIPlus_PathGetFillMode ' +
        'GDIPlus_PathGetLastPoint GDIPlus_PathGetPointCount ' +
        'GDIPlus_PathGetPoints GDIPlus_PathGetWorldBounds ' +
        'GDIPlus_PathIsOutlineVisiblePoint GDIPlus_PathIsVisiblePoint ' +
        'GDIPlus_PathIterCreate GDIPlus_PathIterDispose ' +
        'GDIPlus_PathIterGetSubpathCount GDIPlus_PathIterNextMarkerPath ' +
        'GDIPlus_PathIterNextSubpathPath GDIPlus_PathIterRewind ' +
        'GDIPlus_PathReset GDIPlus_PathReverse GDIPlus_PathSetFillMode ' +
        'GDIPlus_PathSetMarker GDIPlus_PathStartFigure ' +
        'GDIPlus_PathTransform GDIPlus_PathWarp GDIPlus_PathWiden ' +
        'GDIPlus_PathWindingModeOutline GDIPlus_PenCreate ' +
        'GDIPlus_PenCreate2 GDIPlus_PenDispose GDIPlus_PenGetAlignment ' +
        'GDIPlus_PenGetColor GDIPlus_PenGetCustomEndCap ' +
        'GDIPlus_PenGetDashCap GDIPlus_PenGetDashStyle ' +
        'GDIPlus_PenGetEndCap GDIPlus_PenGetMiterLimit ' +
        'GDIPlus_PenGetWidth GDIPlus_PenSetAlignment ' +
        'GDIPlus_PenSetColor GDIPlus_PenSetCustomEndCap ' +
        'GDIPlus_PenSetDashCap GDIPlus_PenSetDashStyle ' +
        'GDIPlus_PenSetEndCap GDIPlus_PenSetLineCap ' +
        'GDIPlus_PenSetLineJoin GDIPlus_PenSetMiterLimit ' +
        'GDIPlus_PenSetStartCap GDIPlus_PenSetWidth ' +
        'GDIPlus_RectFCreate GDIPlus_RegionClone ' +
        'GDIPlus_RegionCombinePath GDIPlus_RegionCombineRect ' +
        'GDIPlus_RegionCombineRegion GDIPlus_RegionCreate ' +
        'GDIPlus_RegionCreateFromPath GDIPlus_RegionCreateFromRect ' +
        'GDIPlus_RegionDispose GDIPlus_RegionGetBounds ' +
        'GDIPlus_RegionGetHRgn GDIPlus_RegionTransform ' +
        'GDIPlus_RegionTranslate GDIPlus_Shutdown GDIPlus_Startup ' +
        'GDIPlus_StringFormatCreate GDIPlus_StringFormatDispose ' +
        'GDIPlus_StringFormatGetMeasurableCharacterRangeCount ' +
        'GDIPlus_StringFormatSetAlign GDIPlus_StringFormatSetLineAlign ' +
        'GDIPlus_StringFormatSetMeasurableCharacterRanges ' +
        'GDIPlus_TextureCreate GDIPlus_TextureCreate2 ' +
        'GDIPlus_TextureCreateIA GetIP GUICtrlAVI_Close ' +
        'GUICtrlAVI_Create GUICtrlAVI_Destroy GUICtrlAVI_IsPlaying ' +
        'GUICtrlAVI_Open GUICtrlAVI_OpenEx GUICtrlAVI_Play ' +
        'GUICtrlAVI_Seek GUICtrlAVI_Show GUICtrlAVI_Stop ' +
        'GUICtrlButton_Click GUICtrlButton_Create ' +
        'GUICtrlButton_Destroy GUICtrlButton_Enable ' +
        'GUICtrlButton_GetCheck GUICtrlButton_GetFocus ' +
        'GUICtrlButton_GetIdealSize GUICtrlButton_GetImage ' +
        'GUICtrlButton_GetImageList GUICtrlButton_GetNote ' +
        'GUICtrlButton_GetNoteLength GUICtrlButton_GetSplitInfo ' +
        'GUICtrlButton_GetState GUICtrlButton_GetText ' +
        'GUICtrlButton_GetTextMargin GUICtrlButton_SetCheck ' +
        'GUICtrlButton_SetDontClick GUICtrlButton_SetFocus ' +
        'GUICtrlButton_SetImage GUICtrlButton_SetImageList ' +
        'GUICtrlButton_SetNote GUICtrlButton_SetShield ' +
        'GUICtrlButton_SetSize GUICtrlButton_SetSplitInfo ' +
        'GUICtrlButton_SetState GUICtrlButton_SetStyle ' +
        'GUICtrlButton_SetText GUICtrlButton_SetTextMargin ' +
        'GUICtrlButton_Show GUICtrlComboBoxEx_AddDir ' +
        'GUICtrlComboBoxEx_AddString GUICtrlComboBoxEx_BeginUpdate ' +
        'GUICtrlComboBoxEx_Create GUICtrlComboBoxEx_CreateSolidBitMap ' +
        'GUICtrlComboBoxEx_DeleteString GUICtrlComboBoxEx_Destroy ' +
        'GUICtrlComboBoxEx_EndUpdate GUICtrlComboBoxEx_FindStringExact ' +
        'GUICtrlComboBoxEx_GetComboBoxInfo ' +
        'GUICtrlComboBoxEx_GetComboControl GUICtrlComboBoxEx_GetCount ' +
        'GUICtrlComboBoxEx_GetCurSel ' +
        'GUICtrlComboBoxEx_GetDroppedControlRect ' +
        'GUICtrlComboBoxEx_GetDroppedControlRectEx ' +
        'GUICtrlComboBoxEx_GetDroppedState ' +
        'GUICtrlComboBoxEx_GetDroppedWidth ' +
        'GUICtrlComboBoxEx_GetEditControl GUICtrlComboBoxEx_GetEditSel ' +
        'GUICtrlComboBoxEx_GetEditText ' +
        'GUICtrlComboBoxEx_GetExtendedStyle ' +
        'GUICtrlComboBoxEx_GetExtendedUI GUICtrlComboBoxEx_GetImageList ' +
        'GUICtrlComboBoxEx_GetItem GUICtrlComboBoxEx_GetItemEx ' +
        'GUICtrlComboBoxEx_GetItemHeight GUICtrlComboBoxEx_GetItemImage ' +
        'GUICtrlComboBoxEx_GetItemIndent ' +
        'GUICtrlComboBoxEx_GetItemOverlayImage ' +
        'GUICtrlComboBoxEx_GetItemParam ' +
        'GUICtrlComboBoxEx_GetItemSelectedImage ' +
        'GUICtrlComboBoxEx_GetItemText GUICtrlComboBoxEx_GetItemTextLen ' +
        'GUICtrlComboBoxEx_GetList GUICtrlComboBoxEx_GetListArray ' +
        'GUICtrlComboBoxEx_GetLocale GUICtrlComboBoxEx_GetLocaleCountry ' +
        'GUICtrlComboBoxEx_GetLocaleLang ' +
        'GUICtrlComboBoxEx_GetLocalePrimLang ' +
        'GUICtrlComboBoxEx_GetLocaleSubLang ' +
        'GUICtrlComboBoxEx_GetMinVisible GUICtrlComboBoxEx_GetTopIndex ' +
        'GUICtrlComboBoxEx_GetUnicode GUICtrlComboBoxEx_InitStorage ' +
        'GUICtrlComboBoxEx_InsertString GUICtrlComboBoxEx_LimitText ' +
        'GUICtrlComboBoxEx_ReplaceEditSel GUICtrlComboBoxEx_ResetContent ' +
        'GUICtrlComboBoxEx_SetCurSel GUICtrlComboBoxEx_SetDroppedWidth ' +
        'GUICtrlComboBoxEx_SetEditSel GUICtrlComboBoxEx_SetEditText ' +
        'GUICtrlComboBoxEx_SetExtendedStyle ' +
        'GUICtrlComboBoxEx_SetExtendedUI GUICtrlComboBoxEx_SetImageList ' +
        'GUICtrlComboBoxEx_SetItem GUICtrlComboBoxEx_SetItemEx ' +
        'GUICtrlComboBoxEx_SetItemHeight GUICtrlComboBoxEx_SetItemImage ' +
        'GUICtrlComboBoxEx_SetItemIndent ' +
        'GUICtrlComboBoxEx_SetItemOverlayImage ' +
        'GUICtrlComboBoxEx_SetItemParam ' +
        'GUICtrlComboBoxEx_SetItemSelectedImage ' +
        'GUICtrlComboBoxEx_SetMinVisible GUICtrlComboBoxEx_SetTopIndex ' +
        'GUICtrlComboBoxEx_SetUnicode GUICtrlComboBoxEx_ShowDropDown ' +
        'GUICtrlComboBox_AddDir GUICtrlComboBox_AddString ' +
        'GUICtrlComboBox_AutoComplete GUICtrlComboBox_BeginUpdate ' +
        'GUICtrlComboBox_Create GUICtrlComboBox_DeleteString ' +
        'GUICtrlComboBox_Destroy GUICtrlComboBox_EndUpdate ' +
        'GUICtrlComboBox_FindString GUICtrlComboBox_FindStringExact ' +
        'GUICtrlComboBox_GetComboBoxInfo GUICtrlComboBox_GetCount ' +
        'GUICtrlComboBox_GetCueBanner GUICtrlComboBox_GetCurSel ' +
        'GUICtrlComboBox_GetDroppedControlRect ' +
        'GUICtrlComboBox_GetDroppedControlRectEx ' +
        'GUICtrlComboBox_GetDroppedState GUICtrlComboBox_GetDroppedWidth ' +
        'GUICtrlComboBox_GetEditSel GUICtrlComboBox_GetEditText ' +
        'GUICtrlComboBox_GetExtendedUI ' +
        'GUICtrlComboBox_GetHorizontalExtent ' +
        'GUICtrlComboBox_GetItemHeight GUICtrlComboBox_GetLBText ' +
        'GUICtrlComboBox_GetLBTextLen GUICtrlComboBox_GetList ' +
        'GUICtrlComboBox_GetListArray GUICtrlComboBox_GetLocale ' +
        'GUICtrlComboBox_GetLocaleCountry GUICtrlComboBox_GetLocaleLang ' +
        'GUICtrlComboBox_GetLocalePrimLang ' +
        'GUICtrlComboBox_GetLocaleSubLang GUICtrlComboBox_GetMinVisible ' +
        'GUICtrlComboBox_GetTopIndex GUICtrlComboBox_InitStorage ' +
        'GUICtrlComboBox_InsertString GUICtrlComboBox_LimitText ' +
        'GUICtrlComboBox_ReplaceEditSel GUICtrlComboBox_ResetContent ' +
        'GUICtrlComboBox_SelectString GUICtrlComboBox_SetCueBanner ' +
        'GUICtrlComboBox_SetCurSel GUICtrlComboBox_SetDroppedWidth ' +
        'GUICtrlComboBox_SetEditSel GUICtrlComboBox_SetEditText ' +
        'GUICtrlComboBox_SetExtendedUI ' +
        'GUICtrlComboBox_SetHorizontalExtent ' +
        'GUICtrlComboBox_SetItemHeight GUICtrlComboBox_SetMinVisible ' +
        'GUICtrlComboBox_SetTopIndex GUICtrlComboBox_ShowDropDown ' +
        'GUICtrlDTP_Create GUICtrlDTP_Destroy GUICtrlDTP_GetMCColor ' +
        'GUICtrlDTP_GetMCFont GUICtrlDTP_GetMonthCal ' +
        'GUICtrlDTP_GetRange GUICtrlDTP_GetRangeEx ' +
        'GUICtrlDTP_GetSystemTime GUICtrlDTP_GetSystemTimeEx ' +
        'GUICtrlDTP_SetFormat GUICtrlDTP_SetMCColor ' +
        'GUICtrlDTP_SetMCFont GUICtrlDTP_SetRange ' +
        'GUICtrlDTP_SetRangeEx GUICtrlDTP_SetSystemTime ' +
        'GUICtrlDTP_SetSystemTimeEx GUICtrlEdit_AppendText ' +
        'GUICtrlEdit_BeginUpdate GUICtrlEdit_CanUndo ' +
        'GUICtrlEdit_CharFromPos GUICtrlEdit_Create ' +
        'GUICtrlEdit_Destroy GUICtrlEdit_EmptyUndoBuffer ' +
        'GUICtrlEdit_EndUpdate GUICtrlEdit_Find GUICtrlEdit_FmtLines ' +
        'GUICtrlEdit_GetCueBanner GUICtrlEdit_GetFirstVisibleLine ' +
        'GUICtrlEdit_GetLimitText GUICtrlEdit_GetLine ' +
        'GUICtrlEdit_GetLineCount GUICtrlEdit_GetMargins ' +
        'GUICtrlEdit_GetModify GUICtrlEdit_GetPasswordChar ' +
        'GUICtrlEdit_GetRECT GUICtrlEdit_GetRECTEx GUICtrlEdit_GetSel ' +
        'GUICtrlEdit_GetText GUICtrlEdit_GetTextLen ' +
        'GUICtrlEdit_HideBalloonTip GUICtrlEdit_InsertText ' +
        'GUICtrlEdit_LineFromChar GUICtrlEdit_LineIndex ' +
        'GUICtrlEdit_LineLength GUICtrlEdit_LineScroll ' +
        'GUICtrlEdit_PosFromChar GUICtrlEdit_ReplaceSel ' +
        'GUICtrlEdit_Scroll GUICtrlEdit_SetCueBanner ' +
        'GUICtrlEdit_SetLimitText GUICtrlEdit_SetMargins ' +
        'GUICtrlEdit_SetModify GUICtrlEdit_SetPasswordChar ' +
        'GUICtrlEdit_SetReadOnly GUICtrlEdit_SetRECT ' +
        'GUICtrlEdit_SetRECTEx GUICtrlEdit_SetRECTNP ' +
        'GUICtrlEdit_SetRectNPEx GUICtrlEdit_SetSel ' +
        'GUICtrlEdit_SetTabStops GUICtrlEdit_SetText ' +
        'GUICtrlEdit_ShowBalloonTip GUICtrlEdit_Undo ' +
        'GUICtrlHeader_AddItem GUICtrlHeader_ClearFilter ' +
        'GUICtrlHeader_ClearFilterAll GUICtrlHeader_Create ' +
        'GUICtrlHeader_CreateDragImage GUICtrlHeader_DeleteItem ' +
        'GUICtrlHeader_Destroy GUICtrlHeader_EditFilter ' +
        'GUICtrlHeader_GetBitmapMargin GUICtrlHeader_GetImageList ' +
        'GUICtrlHeader_GetItem GUICtrlHeader_GetItemAlign ' +
        'GUICtrlHeader_GetItemBitmap GUICtrlHeader_GetItemCount ' +
        'GUICtrlHeader_GetItemDisplay GUICtrlHeader_GetItemFlags ' +
        'GUICtrlHeader_GetItemFormat GUICtrlHeader_GetItemImage ' +
        'GUICtrlHeader_GetItemOrder GUICtrlHeader_GetItemParam ' +
        'GUICtrlHeader_GetItemRect GUICtrlHeader_GetItemRectEx ' +
        'GUICtrlHeader_GetItemText GUICtrlHeader_GetItemWidth ' +
        'GUICtrlHeader_GetOrderArray GUICtrlHeader_GetUnicodeFormat ' +
        'GUICtrlHeader_HitTest GUICtrlHeader_InsertItem ' +
        'GUICtrlHeader_Layout GUICtrlHeader_OrderToIndex ' +
        'GUICtrlHeader_SetBitmapMargin ' +
        'GUICtrlHeader_SetFilterChangeTimeout ' +
        'GUICtrlHeader_SetHotDivider GUICtrlHeader_SetImageList ' +
        'GUICtrlHeader_SetItem GUICtrlHeader_SetItemAlign ' +
        'GUICtrlHeader_SetItemBitmap GUICtrlHeader_SetItemDisplay ' +
        'GUICtrlHeader_SetItemFlags GUICtrlHeader_SetItemFormat ' +
        'GUICtrlHeader_SetItemImage GUICtrlHeader_SetItemOrder ' +
        'GUICtrlHeader_SetItemParam GUICtrlHeader_SetItemText ' +
        'GUICtrlHeader_SetItemWidth GUICtrlHeader_SetOrderArray ' +
        'GUICtrlHeader_SetUnicodeFormat GUICtrlIpAddress_ClearAddress ' +
        'GUICtrlIpAddress_Create GUICtrlIpAddress_Destroy ' +
        'GUICtrlIpAddress_Get GUICtrlIpAddress_GetArray ' +
        'GUICtrlIpAddress_GetEx GUICtrlIpAddress_IsBlank ' +
        'GUICtrlIpAddress_Set GUICtrlIpAddress_SetArray ' +
        'GUICtrlIpAddress_SetEx GUICtrlIpAddress_SetFocus ' +
        'GUICtrlIpAddress_SetFont GUICtrlIpAddress_SetRange ' +
        'GUICtrlIpAddress_ShowHide GUICtrlListBox_AddFile ' +
        'GUICtrlListBox_AddString GUICtrlListBox_BeginUpdate ' +
        'GUICtrlListBox_ClickItem GUICtrlListBox_Create ' +
        'GUICtrlListBox_DeleteString GUICtrlListBox_Destroy ' +
        'GUICtrlListBox_Dir GUICtrlListBox_EndUpdate ' +
        'GUICtrlListBox_FindInText GUICtrlListBox_FindString ' +
        'GUICtrlListBox_GetAnchorIndex GUICtrlListBox_GetCaretIndex ' +
        'GUICtrlListBox_GetCount GUICtrlListBox_GetCurSel ' +
        'GUICtrlListBox_GetHorizontalExtent GUICtrlListBox_GetItemData ' +
        'GUICtrlListBox_GetItemHeight GUICtrlListBox_GetItemRect ' +
        'GUICtrlListBox_GetItemRectEx GUICtrlListBox_GetListBoxInfo ' +
        'GUICtrlListBox_GetLocale GUICtrlListBox_GetLocaleCountry ' +
        'GUICtrlListBox_GetLocaleLang GUICtrlListBox_GetLocalePrimLang ' +
        'GUICtrlListBox_GetLocaleSubLang GUICtrlListBox_GetSel ' +
        'GUICtrlListBox_GetSelCount GUICtrlListBox_GetSelItems ' +
        'GUICtrlListBox_GetSelItemsText GUICtrlListBox_GetText ' +
        'GUICtrlListBox_GetTextLen GUICtrlListBox_GetTopIndex ' +
        'GUICtrlListBox_InitStorage GUICtrlListBox_InsertString ' +
        'GUICtrlListBox_ItemFromPoint GUICtrlListBox_ReplaceString ' +
        'GUICtrlListBox_ResetContent GUICtrlListBox_SelectString ' +
        'GUICtrlListBox_SelItemRange GUICtrlListBox_SelItemRangeEx ' +
        'GUICtrlListBox_SetAnchorIndex GUICtrlListBox_SetCaretIndex ' +
        'GUICtrlListBox_SetColumnWidth GUICtrlListBox_SetCurSel ' +
        'GUICtrlListBox_SetHorizontalExtent GUICtrlListBox_SetItemData ' +
        'GUICtrlListBox_SetItemHeight GUICtrlListBox_SetLocale ' +
        'GUICtrlListBox_SetSel GUICtrlListBox_SetTabStops ' +
        'GUICtrlListBox_SetTopIndex GUICtrlListBox_Sort ' +
        'GUICtrlListBox_SwapString GUICtrlListBox_UpdateHScroll ' +
        'GUICtrlListView_AddArray GUICtrlListView_AddColumn ' +
        'GUICtrlListView_AddItem GUICtrlListView_AddSubItem ' +
        'GUICtrlListView_ApproximateViewHeight ' +
        'GUICtrlListView_ApproximateViewRect ' +
        'GUICtrlListView_ApproximateViewWidth GUICtrlListView_Arrange ' +
        'GUICtrlListView_BeginUpdate GUICtrlListView_CancelEditLabel ' +
        'GUICtrlListView_ClickItem GUICtrlListView_CopyItems ' +
        'GUICtrlListView_Create GUICtrlListView_CreateDragImage ' +
        'GUICtrlListView_CreateSolidBitMap ' +
        'GUICtrlListView_DeleteAllItems GUICtrlListView_DeleteColumn ' +
        'GUICtrlListView_DeleteItem GUICtrlListView_DeleteItemsSelected ' +
        'GUICtrlListView_Destroy GUICtrlListView_DrawDragImage ' +
        'GUICtrlListView_EditLabel GUICtrlListView_EnableGroupView ' +
        'GUICtrlListView_EndUpdate GUICtrlListView_EnsureVisible ' +
        'GUICtrlListView_FindInText GUICtrlListView_FindItem ' +
        'GUICtrlListView_FindNearest GUICtrlListView_FindParam ' +
        'GUICtrlListView_FindText GUICtrlListView_GetBkColor ' +
        'GUICtrlListView_GetBkImage GUICtrlListView_GetCallbackMask ' +
        'GUICtrlListView_GetColumn GUICtrlListView_GetColumnCount ' +
        'GUICtrlListView_GetColumnOrder ' +
        'GUICtrlListView_GetColumnOrderArray ' +
        'GUICtrlListView_GetColumnWidth GUICtrlListView_GetCounterPage ' +
        'GUICtrlListView_GetEditControl ' +
        'GUICtrlListView_GetExtendedListViewStyle ' +
        'GUICtrlListView_GetFocusedGroup GUICtrlListView_GetGroupCount ' +
        'GUICtrlListView_GetGroupInfo ' +
        'GUICtrlListView_GetGroupInfoByIndex ' +
        'GUICtrlListView_GetGroupRect ' +
        'GUICtrlListView_GetGroupViewEnabled GUICtrlListView_GetHeader ' +
        'GUICtrlListView_GetHotCursor GUICtrlListView_GetHotItem ' +
        'GUICtrlListView_GetHoverTime GUICtrlListView_GetImageList ' +
        'GUICtrlListView_GetISearchString GUICtrlListView_GetItem ' +
        'GUICtrlListView_GetItemChecked GUICtrlListView_GetItemCount ' +
        'GUICtrlListView_GetItemCut GUICtrlListView_GetItemDropHilited ' +
        'GUICtrlListView_GetItemEx GUICtrlListView_GetItemFocused ' +
        'GUICtrlListView_GetItemGroupID GUICtrlListView_GetItemImage ' +
        'GUICtrlListView_GetItemIndent GUICtrlListView_GetItemParam ' +
        'GUICtrlListView_GetItemPosition ' +
        'GUICtrlListView_GetItemPositionX ' +
        'GUICtrlListView_GetItemPositionY GUICtrlListView_GetItemRect ' +
        'GUICtrlListView_GetItemRectEx GUICtrlListView_GetItemSelected ' +
        'GUICtrlListView_GetItemSpacing GUICtrlListView_GetItemSpacingX ' +
        'GUICtrlListView_GetItemSpacingY GUICtrlListView_GetItemState ' +
        'GUICtrlListView_GetItemStateImage GUICtrlListView_GetItemText ' +
        'GUICtrlListView_GetItemTextArray ' +
        'GUICtrlListView_GetItemTextString GUICtrlListView_GetNextItem ' +
        'GUICtrlListView_GetNumberOfWorkAreas GUICtrlListView_GetOrigin ' +
        'GUICtrlListView_GetOriginX GUICtrlListView_GetOriginY ' +
        'GUICtrlListView_GetOutlineColor ' +
        'GUICtrlListView_GetSelectedColumn ' +
        'GUICtrlListView_GetSelectedCount ' +
        'GUICtrlListView_GetSelectedIndices ' +
        'GUICtrlListView_GetSelectionMark GUICtrlListView_GetStringWidth ' +
        'GUICtrlListView_GetSubItemRect GUICtrlListView_GetTextBkColor ' +
        'GUICtrlListView_GetTextColor GUICtrlListView_GetToolTips ' +
        'GUICtrlListView_GetTopIndex GUICtrlListView_GetUnicodeFormat ' +
        'GUICtrlListView_GetView GUICtrlListView_GetViewDetails ' +
        'GUICtrlListView_GetViewLarge GUICtrlListView_GetViewList ' +
        'GUICtrlListView_GetViewRect GUICtrlListView_GetViewSmall ' +
        'GUICtrlListView_GetViewTile GUICtrlListView_HideColumn ' +
        'GUICtrlListView_HitTest GUICtrlListView_InsertColumn ' +
        'GUICtrlListView_InsertGroup GUICtrlListView_InsertItem ' +
        'GUICtrlListView_JustifyColumn GUICtrlListView_MapIDToIndex ' +
        'GUICtrlListView_MapIndexToID GUICtrlListView_RedrawItems ' +
        'GUICtrlListView_RegisterSortCallBack ' +
        'GUICtrlListView_RemoveAllGroups GUICtrlListView_RemoveGroup ' +
        'GUICtrlListView_Scroll GUICtrlListView_SetBkColor ' +
        'GUICtrlListView_SetBkImage GUICtrlListView_SetCallBackMask ' +
        'GUICtrlListView_SetColumn GUICtrlListView_SetColumnOrder ' +
        'GUICtrlListView_SetColumnOrderArray ' +
        'GUICtrlListView_SetColumnWidth ' +
        'GUICtrlListView_SetExtendedListViewStyle ' +
        'GUICtrlListView_SetGroupInfo GUICtrlListView_SetHotItem ' +
        'GUICtrlListView_SetHoverTime GUICtrlListView_SetIconSpacing ' +
        'GUICtrlListView_SetImageList GUICtrlListView_SetItem ' +
        'GUICtrlListView_SetItemChecked GUICtrlListView_SetItemCount ' +
        'GUICtrlListView_SetItemCut GUICtrlListView_SetItemDropHilited ' +
        'GUICtrlListView_SetItemEx GUICtrlListView_SetItemFocused ' +
        'GUICtrlListView_SetItemGroupID GUICtrlListView_SetItemImage ' +
        'GUICtrlListView_SetItemIndent GUICtrlListView_SetItemParam ' +
        'GUICtrlListView_SetItemPosition ' +
        'GUICtrlListView_SetItemPosition32 ' +
        'GUICtrlListView_SetItemSelected GUICtrlListView_SetItemState ' +
        'GUICtrlListView_SetItemStateImage GUICtrlListView_SetItemText ' +
        'GUICtrlListView_SetOutlineColor ' +
        'GUICtrlListView_SetSelectedColumn ' +
        'GUICtrlListView_SetSelectionMark GUICtrlListView_SetTextBkColor ' +
        'GUICtrlListView_SetTextColor GUICtrlListView_SetToolTips ' +
        'GUICtrlListView_SetUnicodeFormat GUICtrlListView_SetView ' +
        'GUICtrlListView_SetWorkAreas GUICtrlListView_SimpleSort ' +
        'GUICtrlListView_SortItems GUICtrlListView_SubItemHitTest ' +
        'GUICtrlListView_UnRegisterSortCallBack GUICtrlMenu_AddMenuItem ' +
        'GUICtrlMenu_AppendMenu GUICtrlMenu_CalculatePopupWindowPosition ' +
        'GUICtrlMenu_CheckMenuItem GUICtrlMenu_CheckRadioItem ' +
        'GUICtrlMenu_CreateMenu GUICtrlMenu_CreatePopup ' +
        'GUICtrlMenu_DeleteMenu GUICtrlMenu_DestroyMenu ' +
        'GUICtrlMenu_DrawMenuBar GUICtrlMenu_EnableMenuItem ' +
        'GUICtrlMenu_FindItem GUICtrlMenu_FindParent ' +
        'GUICtrlMenu_GetItemBmp GUICtrlMenu_GetItemBmpChecked ' +
        'GUICtrlMenu_GetItemBmpUnchecked GUICtrlMenu_GetItemChecked ' +
        'GUICtrlMenu_GetItemCount GUICtrlMenu_GetItemData ' +
        'GUICtrlMenu_GetItemDefault GUICtrlMenu_GetItemDisabled ' +
        'GUICtrlMenu_GetItemEnabled GUICtrlMenu_GetItemGrayed ' +
        'GUICtrlMenu_GetItemHighlighted GUICtrlMenu_GetItemID ' +
        'GUICtrlMenu_GetItemInfo GUICtrlMenu_GetItemRect ' +
        'GUICtrlMenu_GetItemRectEx GUICtrlMenu_GetItemState ' +
        'GUICtrlMenu_GetItemStateEx GUICtrlMenu_GetItemSubMenu ' +
        'GUICtrlMenu_GetItemText GUICtrlMenu_GetItemType ' +
        'GUICtrlMenu_GetMenu GUICtrlMenu_GetMenuBackground ' +
        'GUICtrlMenu_GetMenuBarInfo GUICtrlMenu_GetMenuContextHelpID ' +
        'GUICtrlMenu_GetMenuData GUICtrlMenu_GetMenuDefaultItem ' +
        'GUICtrlMenu_GetMenuHeight GUICtrlMenu_GetMenuInfo ' +
        'GUICtrlMenu_GetMenuStyle GUICtrlMenu_GetSystemMenu ' +
        'GUICtrlMenu_InsertMenuItem GUICtrlMenu_InsertMenuItemEx ' +
        'GUICtrlMenu_IsMenu GUICtrlMenu_LoadMenu ' +
        'GUICtrlMenu_MapAccelerator GUICtrlMenu_MenuItemFromPoint ' +
        'GUICtrlMenu_RemoveMenu GUICtrlMenu_SetItemBitmaps ' +
        'GUICtrlMenu_SetItemBmp GUICtrlMenu_SetItemBmpChecked ' +
        'GUICtrlMenu_SetItemBmpUnchecked GUICtrlMenu_SetItemChecked ' +
        'GUICtrlMenu_SetItemData GUICtrlMenu_SetItemDefault ' +
        'GUICtrlMenu_SetItemDisabled GUICtrlMenu_SetItemEnabled ' +
        'GUICtrlMenu_SetItemGrayed GUICtrlMenu_SetItemHighlighted ' +
        'GUICtrlMenu_SetItemID GUICtrlMenu_SetItemInfo ' +
        'GUICtrlMenu_SetItemState GUICtrlMenu_SetItemSubMenu ' +
        'GUICtrlMenu_SetItemText GUICtrlMenu_SetItemType ' +
        'GUICtrlMenu_SetMenu GUICtrlMenu_SetMenuBackground ' +
        'GUICtrlMenu_SetMenuContextHelpID GUICtrlMenu_SetMenuData ' +
        'GUICtrlMenu_SetMenuDefaultItem GUICtrlMenu_SetMenuHeight ' +
        'GUICtrlMenu_SetMenuInfo GUICtrlMenu_SetMenuStyle ' +
        'GUICtrlMenu_TrackPopupMenu GUICtrlMonthCal_Create ' +
        'GUICtrlMonthCal_Destroy GUICtrlMonthCal_GetCalendarBorder ' +
        'GUICtrlMonthCal_GetCalendarCount GUICtrlMonthCal_GetColor ' +
        'GUICtrlMonthCal_GetColorArray GUICtrlMonthCal_GetCurSel ' +
        'GUICtrlMonthCal_GetCurSelStr GUICtrlMonthCal_GetFirstDOW ' +
        'GUICtrlMonthCal_GetFirstDOWStr GUICtrlMonthCal_GetMaxSelCount ' +
        'GUICtrlMonthCal_GetMaxTodayWidth ' +
        'GUICtrlMonthCal_GetMinReqHeight GUICtrlMonthCal_GetMinReqRect ' +
        'GUICtrlMonthCal_GetMinReqRectArray ' +
        'GUICtrlMonthCal_GetMinReqWidth GUICtrlMonthCal_GetMonthDelta ' +
        'GUICtrlMonthCal_GetMonthRange GUICtrlMonthCal_GetMonthRangeMax ' +
        'GUICtrlMonthCal_GetMonthRangeMaxStr ' +
        'GUICtrlMonthCal_GetMonthRangeMin ' +
        'GUICtrlMonthCal_GetMonthRangeMinStr ' +
        'GUICtrlMonthCal_GetMonthRangeSpan GUICtrlMonthCal_GetRange ' +
        'GUICtrlMonthCal_GetRangeMax GUICtrlMonthCal_GetRangeMaxStr ' +
        'GUICtrlMonthCal_GetRangeMin GUICtrlMonthCal_GetRangeMinStr ' +
        'GUICtrlMonthCal_GetSelRange GUICtrlMonthCal_GetSelRangeMax ' +
        'GUICtrlMonthCal_GetSelRangeMaxStr ' +
        'GUICtrlMonthCal_GetSelRangeMin ' +
        'GUICtrlMonthCal_GetSelRangeMinStr GUICtrlMonthCal_GetToday ' +
        'GUICtrlMonthCal_GetTodayStr GUICtrlMonthCal_GetUnicodeFormat ' +
        'GUICtrlMonthCal_HitTest GUICtrlMonthCal_SetCalendarBorder ' +
        'GUICtrlMonthCal_SetColor GUICtrlMonthCal_SetCurSel ' +
        'GUICtrlMonthCal_SetDayState GUICtrlMonthCal_SetFirstDOW ' +
        'GUICtrlMonthCal_SetMaxSelCount GUICtrlMonthCal_SetMonthDelta ' +
        'GUICtrlMonthCal_SetRange GUICtrlMonthCal_SetSelRange ' +
        'GUICtrlMonthCal_SetToday GUICtrlMonthCal_SetUnicodeFormat ' +
        'GUICtrlRebar_AddBand GUICtrlRebar_AddToolBarBand ' +
        'GUICtrlRebar_BeginDrag GUICtrlRebar_Create ' +
        'GUICtrlRebar_DeleteBand GUICtrlRebar_Destroy ' +
        'GUICtrlRebar_DragMove GUICtrlRebar_EndDrag ' +
        'GUICtrlRebar_GetBandBackColor GUICtrlRebar_GetBandBorders ' +
        'GUICtrlRebar_GetBandBordersEx GUICtrlRebar_GetBandChildHandle ' +
        'GUICtrlRebar_GetBandChildSize GUICtrlRebar_GetBandCount ' +
        'GUICtrlRebar_GetBandForeColor GUICtrlRebar_GetBandHeaderSize ' +
        'GUICtrlRebar_GetBandID GUICtrlRebar_GetBandIdealSize ' +
        'GUICtrlRebar_GetBandLength GUICtrlRebar_GetBandLParam ' +
        'GUICtrlRebar_GetBandMargins GUICtrlRebar_GetBandMarginsEx ' +
        'GUICtrlRebar_GetBandRect GUICtrlRebar_GetBandRectEx ' +
        'GUICtrlRebar_GetBandStyle GUICtrlRebar_GetBandStyleBreak ' +
        'GUICtrlRebar_GetBandStyleChildEdge ' +
        'GUICtrlRebar_GetBandStyleFixedBMP ' +
        'GUICtrlRebar_GetBandStyleFixedSize ' +
        'GUICtrlRebar_GetBandStyleGripperAlways ' +
        'GUICtrlRebar_GetBandStyleHidden ' +
        'GUICtrlRebar_GetBandStyleHideTitle ' +
        'GUICtrlRebar_GetBandStyleNoGripper ' +
        'GUICtrlRebar_GetBandStyleTopAlign ' +
        'GUICtrlRebar_GetBandStyleUseChevron ' +
        'GUICtrlRebar_GetBandStyleVariableHeight ' +
        'GUICtrlRebar_GetBandText GUICtrlRebar_GetBarHeight ' +
        'GUICtrlRebar_GetBarInfo GUICtrlRebar_GetBKColor ' +
        'GUICtrlRebar_GetColorScheme GUICtrlRebar_GetRowCount ' +
        'GUICtrlRebar_GetRowHeight GUICtrlRebar_GetTextColor ' +
        'GUICtrlRebar_GetToolTips GUICtrlRebar_GetUnicodeFormat ' +
        'GUICtrlRebar_HitTest GUICtrlRebar_IDToIndex ' +
        'GUICtrlRebar_MaximizeBand GUICtrlRebar_MinimizeBand ' +
        'GUICtrlRebar_MoveBand GUICtrlRebar_SetBandBackColor ' +
        'GUICtrlRebar_SetBandForeColor GUICtrlRebar_SetBandHeaderSize ' +
        'GUICtrlRebar_SetBandID GUICtrlRebar_SetBandIdealSize ' +
        'GUICtrlRebar_SetBandLength GUICtrlRebar_SetBandLParam ' +
        'GUICtrlRebar_SetBandStyle GUICtrlRebar_SetBandStyleBreak ' +
        'GUICtrlRebar_SetBandStyleChildEdge ' +
        'GUICtrlRebar_SetBandStyleFixedBMP ' +
        'GUICtrlRebar_SetBandStyleFixedSize ' +
        'GUICtrlRebar_SetBandStyleGripperAlways ' +
        'GUICtrlRebar_SetBandStyleHidden ' +
        'GUICtrlRebar_SetBandStyleHideTitle ' +
        'GUICtrlRebar_SetBandStyleNoGripper ' +
        'GUICtrlRebar_SetBandStyleTopAlign ' +
        'GUICtrlRebar_SetBandStyleUseChevron ' +
        'GUICtrlRebar_SetBandStyleVariableHeight ' +
        'GUICtrlRebar_SetBandText GUICtrlRebar_SetBarInfo ' +
        'GUICtrlRebar_SetBKColor GUICtrlRebar_SetColorScheme ' +
        'GUICtrlRebar_SetTextColor GUICtrlRebar_SetToolTips ' +
        'GUICtrlRebar_SetUnicodeFormat GUICtrlRebar_ShowBand ' +
        'GUICtrlRichEdit_AppendText GUICtrlRichEdit_AutoDetectURL ' +
        'GUICtrlRichEdit_CanPaste GUICtrlRichEdit_CanPasteSpecial ' +
        'GUICtrlRichEdit_CanRedo GUICtrlRichEdit_CanUndo ' +
        'GUICtrlRichEdit_ChangeFontSize GUICtrlRichEdit_Copy ' +
        'GUICtrlRichEdit_Create GUICtrlRichEdit_Cut ' +
        'GUICtrlRichEdit_Deselect GUICtrlRichEdit_Destroy ' +
        'GUICtrlRichEdit_EmptyUndoBuffer GUICtrlRichEdit_FindText ' +
        'GUICtrlRichEdit_FindTextInRange GUICtrlRichEdit_GetBkColor ' +
        'GUICtrlRichEdit_GetCharAttributes ' +
        'GUICtrlRichEdit_GetCharBkColor GUICtrlRichEdit_GetCharColor ' +
        'GUICtrlRichEdit_GetCharPosFromXY ' +
        'GUICtrlRichEdit_GetCharPosOfNextWord ' +
        'GUICtrlRichEdit_GetCharPosOfPreviousWord ' +
        'GUICtrlRichEdit_GetCharWordBreakInfo ' +
        'GUICtrlRichEdit_GetFirstCharPosOnLine GUICtrlRichEdit_GetFont ' +
        'GUICtrlRichEdit_GetLineCount GUICtrlRichEdit_GetLineLength ' +
        'GUICtrlRichEdit_GetLineNumberFromCharPos ' +
        'GUICtrlRichEdit_GetNextRedo GUICtrlRichEdit_GetNextUndo ' +
        'GUICtrlRichEdit_GetNumberOfFirstVisibleLine ' +
        'GUICtrlRichEdit_GetParaAlignment ' +
        'GUICtrlRichEdit_GetParaAttributes GUICtrlRichEdit_GetParaBorder ' +
        'GUICtrlRichEdit_GetParaIndents GUICtrlRichEdit_GetParaNumbering ' +
        'GUICtrlRichEdit_GetParaShading GUICtrlRichEdit_GetParaSpacing ' +
        'GUICtrlRichEdit_GetParaTabStops GUICtrlRichEdit_GetPasswordChar ' +
        'GUICtrlRichEdit_GetRECT GUICtrlRichEdit_GetScrollPos ' +
        'GUICtrlRichEdit_GetSel GUICtrlRichEdit_GetSelAA ' +
        'GUICtrlRichEdit_GetSelText GUICtrlRichEdit_GetSpaceUnit ' +
        'GUICtrlRichEdit_GetText GUICtrlRichEdit_GetTextInLine ' +
        'GUICtrlRichEdit_GetTextInRange GUICtrlRichEdit_GetTextLength ' +
        'GUICtrlRichEdit_GetVersion GUICtrlRichEdit_GetXYFromCharPos ' +
        'GUICtrlRichEdit_GetZoom GUICtrlRichEdit_GotoCharPos ' +
        'GUICtrlRichEdit_HideSelection GUICtrlRichEdit_InsertText ' +
        'GUICtrlRichEdit_IsModified GUICtrlRichEdit_IsTextSelected ' +
        'GUICtrlRichEdit_Paste GUICtrlRichEdit_PasteSpecial ' +
        'GUICtrlRichEdit_PauseRedraw GUICtrlRichEdit_Redo ' +
        'GUICtrlRichEdit_ReplaceText GUICtrlRichEdit_ResumeRedraw ' +
        'GUICtrlRichEdit_ScrollLineOrPage GUICtrlRichEdit_ScrollLines ' +
        'GUICtrlRichEdit_ScrollToCaret GUICtrlRichEdit_SetBkColor ' +
        'GUICtrlRichEdit_SetCharAttributes ' +
        'GUICtrlRichEdit_SetCharBkColor GUICtrlRichEdit_SetCharColor ' +
        'GUICtrlRichEdit_SetEventMask GUICtrlRichEdit_SetFont ' +
        'GUICtrlRichEdit_SetLimitOnText GUICtrlRichEdit_SetModified ' +
        'GUICtrlRichEdit_SetParaAlignment ' +
        'GUICtrlRichEdit_SetParaAttributes GUICtrlRichEdit_SetParaBorder ' +
        'GUICtrlRichEdit_SetParaIndents GUICtrlRichEdit_SetParaNumbering ' +
        'GUICtrlRichEdit_SetParaShading GUICtrlRichEdit_SetParaSpacing ' +
        'GUICtrlRichEdit_SetParaTabStops GUICtrlRichEdit_SetPasswordChar ' +
        'GUICtrlRichEdit_SetReadOnly GUICtrlRichEdit_SetRECT ' +
        'GUICtrlRichEdit_SetScrollPos GUICtrlRichEdit_SetSel ' +
        'GUICtrlRichEdit_SetSpaceUnit GUICtrlRichEdit_SetTabStops ' +
        'GUICtrlRichEdit_SetText GUICtrlRichEdit_SetUndoLimit ' +
        'GUICtrlRichEdit_SetZoom GUICtrlRichEdit_StreamFromFile ' +
        'GUICtrlRichEdit_StreamFromVar GUICtrlRichEdit_StreamToFile ' +
        'GUICtrlRichEdit_StreamToVar GUICtrlRichEdit_Undo ' +
        'GUICtrlSlider_ClearSel GUICtrlSlider_ClearTics ' +
        'GUICtrlSlider_Create GUICtrlSlider_Destroy ' +
        'GUICtrlSlider_GetBuddy GUICtrlSlider_GetChannelRect ' +
        'GUICtrlSlider_GetChannelRectEx GUICtrlSlider_GetLineSize ' +
        'GUICtrlSlider_GetLogicalTics GUICtrlSlider_GetNumTics ' +
        'GUICtrlSlider_GetPageSize GUICtrlSlider_GetPos ' +
        'GUICtrlSlider_GetRange GUICtrlSlider_GetRangeMax ' +
        'GUICtrlSlider_GetRangeMin GUICtrlSlider_GetSel ' +
        'GUICtrlSlider_GetSelEnd GUICtrlSlider_GetSelStart ' +
        'GUICtrlSlider_GetThumbLength GUICtrlSlider_GetThumbRect ' +
        'GUICtrlSlider_GetThumbRectEx GUICtrlSlider_GetTic ' +
        'GUICtrlSlider_GetTicPos GUICtrlSlider_GetToolTips ' +
        'GUICtrlSlider_GetUnicodeFormat GUICtrlSlider_SetBuddy ' +
        'GUICtrlSlider_SetLineSize GUICtrlSlider_SetPageSize ' +
        'GUICtrlSlider_SetPos GUICtrlSlider_SetRange ' +
        'GUICtrlSlider_SetRangeMax GUICtrlSlider_SetRangeMin ' +
        'GUICtrlSlider_SetSel GUICtrlSlider_SetSelEnd ' +
        'GUICtrlSlider_SetSelStart GUICtrlSlider_SetThumbLength ' +
        'GUICtrlSlider_SetTic GUICtrlSlider_SetTicFreq ' +
        'GUICtrlSlider_SetTipSide GUICtrlSlider_SetToolTips ' +
        'GUICtrlSlider_SetUnicodeFormat GUICtrlStatusBar_Create ' +
        'GUICtrlStatusBar_Destroy GUICtrlStatusBar_EmbedControl ' +
        'GUICtrlStatusBar_GetBorders GUICtrlStatusBar_GetBordersHorz ' +
        'GUICtrlStatusBar_GetBordersRect GUICtrlStatusBar_GetBordersVert ' +
        'GUICtrlStatusBar_GetCount GUICtrlStatusBar_GetHeight ' +
        'GUICtrlStatusBar_GetIcon GUICtrlStatusBar_GetParts ' +
        'GUICtrlStatusBar_GetRect GUICtrlStatusBar_GetRectEx ' +
        'GUICtrlStatusBar_GetText GUICtrlStatusBar_GetTextFlags ' +
        'GUICtrlStatusBar_GetTextLength GUICtrlStatusBar_GetTextLengthEx ' +
        'GUICtrlStatusBar_GetTipText GUICtrlStatusBar_GetUnicodeFormat ' +
        'GUICtrlStatusBar_GetWidth GUICtrlStatusBar_IsSimple ' +
        'GUICtrlStatusBar_Resize GUICtrlStatusBar_SetBkColor ' +
        'GUICtrlStatusBar_SetIcon GUICtrlStatusBar_SetMinHeight ' +
        'GUICtrlStatusBar_SetParts GUICtrlStatusBar_SetSimple ' +
        'GUICtrlStatusBar_SetText GUICtrlStatusBar_SetTipText ' +
        'GUICtrlStatusBar_SetUnicodeFormat GUICtrlStatusBar_ShowHide ' +
        'GUICtrlTab_ActivateTab GUICtrlTab_ClickTab GUICtrlTab_Create ' +
        'GUICtrlTab_DeleteAllItems GUICtrlTab_DeleteItem ' +
        'GUICtrlTab_DeselectAll GUICtrlTab_Destroy GUICtrlTab_FindTab ' +
        'GUICtrlTab_GetCurFocus GUICtrlTab_GetCurSel ' +
        'GUICtrlTab_GetDisplayRect GUICtrlTab_GetDisplayRectEx ' +
        'GUICtrlTab_GetExtendedStyle GUICtrlTab_GetImageList ' +
        'GUICtrlTab_GetItem GUICtrlTab_GetItemCount ' +
        'GUICtrlTab_GetItemImage GUICtrlTab_GetItemParam ' +
        'GUICtrlTab_GetItemRect GUICtrlTab_GetItemRectEx ' +
        'GUICtrlTab_GetItemState GUICtrlTab_GetItemText ' +
        'GUICtrlTab_GetRowCount GUICtrlTab_GetToolTips ' +
        'GUICtrlTab_GetUnicodeFormat GUICtrlTab_HighlightItem ' +
        'GUICtrlTab_HitTest GUICtrlTab_InsertItem ' +
        'GUICtrlTab_RemoveImage GUICtrlTab_SetCurFocus ' +
        'GUICtrlTab_SetCurSel GUICtrlTab_SetExtendedStyle ' +
        'GUICtrlTab_SetImageList GUICtrlTab_SetItem ' +
        'GUICtrlTab_SetItemImage GUICtrlTab_SetItemParam ' +
        'GUICtrlTab_SetItemSize GUICtrlTab_SetItemState ' +
        'GUICtrlTab_SetItemText GUICtrlTab_SetMinTabWidth ' +
        'GUICtrlTab_SetPadding GUICtrlTab_SetToolTips ' +
        'GUICtrlTab_SetUnicodeFormat GUICtrlToolbar_AddBitmap ' +
        'GUICtrlToolbar_AddButton GUICtrlToolbar_AddButtonSep ' +
        'GUICtrlToolbar_AddString GUICtrlToolbar_ButtonCount ' +
        'GUICtrlToolbar_CheckButton GUICtrlToolbar_ClickAccel ' +
        'GUICtrlToolbar_ClickButton GUICtrlToolbar_ClickIndex ' +
        'GUICtrlToolbar_CommandToIndex GUICtrlToolbar_Create ' +
        'GUICtrlToolbar_Customize GUICtrlToolbar_DeleteButton ' +
        'GUICtrlToolbar_Destroy GUICtrlToolbar_EnableButton ' +
        'GUICtrlToolbar_FindToolbar GUICtrlToolbar_GetAnchorHighlight ' +
        'GUICtrlToolbar_GetBitmapFlags GUICtrlToolbar_GetButtonBitmap ' +
        'GUICtrlToolbar_GetButtonInfo GUICtrlToolbar_GetButtonInfoEx ' +
        'GUICtrlToolbar_GetButtonParam GUICtrlToolbar_GetButtonRect ' +
        'GUICtrlToolbar_GetButtonRectEx GUICtrlToolbar_GetButtonSize ' +
        'GUICtrlToolbar_GetButtonState GUICtrlToolbar_GetButtonStyle ' +
        'GUICtrlToolbar_GetButtonText GUICtrlToolbar_GetColorScheme ' +
        'GUICtrlToolbar_GetDisabledImageList ' +
        'GUICtrlToolbar_GetExtendedStyle GUICtrlToolbar_GetHotImageList ' +
        'GUICtrlToolbar_GetHotItem GUICtrlToolbar_GetImageList ' +
        'GUICtrlToolbar_GetInsertMark GUICtrlToolbar_GetInsertMarkColor ' +
        'GUICtrlToolbar_GetMaxSize GUICtrlToolbar_GetMetrics ' +
        'GUICtrlToolbar_GetPadding GUICtrlToolbar_GetRows ' +
        'GUICtrlToolbar_GetString GUICtrlToolbar_GetStyle ' +
        'GUICtrlToolbar_GetStyleAltDrag ' +
        'GUICtrlToolbar_GetStyleCustomErase GUICtrlToolbar_GetStyleFlat ' +
        'GUICtrlToolbar_GetStyleList GUICtrlToolbar_GetStyleRegisterDrop ' +
        'GUICtrlToolbar_GetStyleToolTips ' +
        'GUICtrlToolbar_GetStyleTransparent ' +
        'GUICtrlToolbar_GetStyleWrapable GUICtrlToolbar_GetTextRows ' +
        'GUICtrlToolbar_GetToolTips GUICtrlToolbar_GetUnicodeFormat ' +
        'GUICtrlToolbar_HideButton GUICtrlToolbar_HighlightButton ' +
        'GUICtrlToolbar_HitTest GUICtrlToolbar_IndexToCommand ' +
        'GUICtrlToolbar_InsertButton GUICtrlToolbar_InsertMarkHitTest ' +
        'GUICtrlToolbar_IsButtonChecked GUICtrlToolbar_IsButtonEnabled ' +
        'GUICtrlToolbar_IsButtonHidden ' +
        'GUICtrlToolbar_IsButtonHighlighted ' +
        'GUICtrlToolbar_IsButtonIndeterminate ' +
        'GUICtrlToolbar_IsButtonPressed GUICtrlToolbar_LoadBitmap ' +
        'GUICtrlToolbar_LoadImages GUICtrlToolbar_MapAccelerator ' +
        'GUICtrlToolbar_MoveButton GUICtrlToolbar_PressButton ' +
        'GUICtrlToolbar_SetAnchorHighlight GUICtrlToolbar_SetBitmapSize ' +
        'GUICtrlToolbar_SetButtonBitMap GUICtrlToolbar_SetButtonInfo ' +
        'GUICtrlToolbar_SetButtonInfoEx GUICtrlToolbar_SetButtonParam ' +
        'GUICtrlToolbar_SetButtonSize GUICtrlToolbar_SetButtonState ' +
        'GUICtrlToolbar_SetButtonStyle GUICtrlToolbar_SetButtonText ' +
        'GUICtrlToolbar_SetButtonWidth GUICtrlToolbar_SetCmdID ' +
        'GUICtrlToolbar_SetColorScheme ' +
        'GUICtrlToolbar_SetDisabledImageList ' +
        'GUICtrlToolbar_SetDrawTextFlags GUICtrlToolbar_SetExtendedStyle ' +
        'GUICtrlToolbar_SetHotImageList GUICtrlToolbar_SetHotItem ' +
        'GUICtrlToolbar_SetImageList GUICtrlToolbar_SetIndent ' +
        'GUICtrlToolbar_SetIndeterminate GUICtrlToolbar_SetInsertMark ' +
        'GUICtrlToolbar_SetInsertMarkColor GUICtrlToolbar_SetMaxTextRows ' +
        'GUICtrlToolbar_SetMetrics GUICtrlToolbar_SetPadding ' +
        'GUICtrlToolbar_SetParent GUICtrlToolbar_SetRows ' +
        'GUICtrlToolbar_SetStyle GUICtrlToolbar_SetStyleAltDrag ' +
        'GUICtrlToolbar_SetStyleCustomErase GUICtrlToolbar_SetStyleFlat ' +
        'GUICtrlToolbar_SetStyleList GUICtrlToolbar_SetStyleRegisterDrop ' +
        'GUICtrlToolbar_SetStyleToolTips ' +
        'GUICtrlToolbar_SetStyleTransparent ' +
        'GUICtrlToolbar_SetStyleWrapable GUICtrlToolbar_SetToolTips ' +
        'GUICtrlToolbar_SetUnicodeFormat GUICtrlToolbar_SetWindowTheme ' +
        'GUICtrlTreeView_Add GUICtrlTreeView_AddChild ' +
        'GUICtrlTreeView_AddChildFirst GUICtrlTreeView_AddFirst ' +
        'GUICtrlTreeView_BeginUpdate GUICtrlTreeView_ClickItem ' +
        'GUICtrlTreeView_Create GUICtrlTreeView_CreateDragImage ' +
        'GUICtrlTreeView_CreateSolidBitMap GUICtrlTreeView_Delete ' +
        'GUICtrlTreeView_DeleteAll GUICtrlTreeView_DeleteChildren ' +
        'GUICtrlTreeView_Destroy GUICtrlTreeView_DisplayRect ' +
        'GUICtrlTreeView_DisplayRectEx GUICtrlTreeView_EditText ' +
        'GUICtrlTreeView_EndEdit GUICtrlTreeView_EndUpdate ' +
        'GUICtrlTreeView_EnsureVisible GUICtrlTreeView_Expand ' +
        'GUICtrlTreeView_ExpandedOnce GUICtrlTreeView_FindItem ' +
        'GUICtrlTreeView_FindItemEx GUICtrlTreeView_GetBkColor ' +
        'GUICtrlTreeView_GetBold GUICtrlTreeView_GetChecked ' +
        'GUICtrlTreeView_GetChildCount GUICtrlTreeView_GetChildren ' +
        'GUICtrlTreeView_GetCount GUICtrlTreeView_GetCut ' +
        'GUICtrlTreeView_GetDropTarget GUICtrlTreeView_GetEditControl ' +
        'GUICtrlTreeView_GetExpanded GUICtrlTreeView_GetFirstChild ' +
        'GUICtrlTreeView_GetFirstItem GUICtrlTreeView_GetFirstVisible ' +
        'GUICtrlTreeView_GetFocused GUICtrlTreeView_GetHeight ' +
        'GUICtrlTreeView_GetImageIndex ' +
        'GUICtrlTreeView_GetImageListIconHandle ' +
        'GUICtrlTreeView_GetIndent GUICtrlTreeView_GetInsertMarkColor ' +
        'GUICtrlTreeView_GetISearchString GUICtrlTreeView_GetItemByIndex ' +
        'GUICtrlTreeView_GetItemHandle GUICtrlTreeView_GetItemParam ' +
        'GUICtrlTreeView_GetLastChild GUICtrlTreeView_GetLineColor ' +
        'GUICtrlTreeView_GetNext GUICtrlTreeView_GetNextChild ' +
        'GUICtrlTreeView_GetNextSibling GUICtrlTreeView_GetNextVisible ' +
        'GUICtrlTreeView_GetNormalImageList ' +
        'GUICtrlTreeView_GetParentHandle GUICtrlTreeView_GetParentParam ' +
        'GUICtrlTreeView_GetPrev GUICtrlTreeView_GetPrevChild ' +
        'GUICtrlTreeView_GetPrevSibling GUICtrlTreeView_GetPrevVisible ' +
        'GUICtrlTreeView_GetScrollTime GUICtrlTreeView_GetSelected ' +
        'GUICtrlTreeView_GetSelectedImageIndex ' +
        'GUICtrlTreeView_GetSelection GUICtrlTreeView_GetSiblingCount ' +
        'GUICtrlTreeView_GetState GUICtrlTreeView_GetStateImageIndex ' +
        'GUICtrlTreeView_GetStateImageList GUICtrlTreeView_GetText ' +
        'GUICtrlTreeView_GetTextColor GUICtrlTreeView_GetToolTips ' +
        'GUICtrlTreeView_GetTree GUICtrlTreeView_GetUnicodeFormat ' +
        'GUICtrlTreeView_GetVisible GUICtrlTreeView_GetVisibleCount ' +
        'GUICtrlTreeView_HitTest GUICtrlTreeView_HitTestEx ' +
        'GUICtrlTreeView_HitTestItem GUICtrlTreeView_Index ' +
        'GUICtrlTreeView_InsertItem GUICtrlTreeView_IsFirstItem ' +
        'GUICtrlTreeView_IsParent GUICtrlTreeView_Level ' +
        'GUICtrlTreeView_SelectItem GUICtrlTreeView_SelectItemByIndex ' +
        'GUICtrlTreeView_SetBkColor GUICtrlTreeView_SetBold ' +
        'GUICtrlTreeView_SetChecked GUICtrlTreeView_SetCheckedByIndex ' +
        'GUICtrlTreeView_SetChildren GUICtrlTreeView_SetCut ' +
        'GUICtrlTreeView_SetDropTarget GUICtrlTreeView_SetFocused ' +
        'GUICtrlTreeView_SetHeight GUICtrlTreeView_SetIcon ' +
        'GUICtrlTreeView_SetImageIndex GUICtrlTreeView_SetIndent ' +
        'GUICtrlTreeView_SetInsertMark ' +
        'GUICtrlTreeView_SetInsertMarkColor ' +
        'GUICtrlTreeView_SetItemHeight GUICtrlTreeView_SetItemParam ' +
        'GUICtrlTreeView_SetLineColor GUICtrlTreeView_SetNormalImageList ' +
        'GUICtrlTreeView_SetScrollTime GUICtrlTreeView_SetSelected ' +
        'GUICtrlTreeView_SetSelectedImageIndex GUICtrlTreeView_SetState ' +
        'GUICtrlTreeView_SetStateImageIndex ' +
        'GUICtrlTreeView_SetStateImageList GUICtrlTreeView_SetText ' +
        'GUICtrlTreeView_SetTextColor GUICtrlTreeView_SetToolTips ' +
        'GUICtrlTreeView_SetUnicodeFormat GUICtrlTreeView_Sort ' +
        'GUIImageList_Add GUIImageList_AddBitmap GUIImageList_AddIcon ' +
        'GUIImageList_AddMasked GUIImageList_BeginDrag ' +
        'GUIImageList_Copy GUIImageList_Create GUIImageList_Destroy ' +
        'GUIImageList_DestroyIcon GUIImageList_DragEnter ' +
        'GUIImageList_DragLeave GUIImageList_DragMove ' +
        'GUIImageList_Draw GUIImageList_DrawEx GUIImageList_Duplicate ' +
        'GUIImageList_EndDrag GUIImageList_GetBkColor ' +
        'GUIImageList_GetIcon GUIImageList_GetIconHeight ' +
        'GUIImageList_GetIconSize GUIImageList_GetIconSizeEx ' +
        'GUIImageList_GetIconWidth GUIImageList_GetImageCount ' +
        'GUIImageList_GetImageInfoEx GUIImageList_Remove ' +
        'GUIImageList_ReplaceIcon GUIImageList_SetBkColor ' +
        'GUIImageList_SetIconSize GUIImageList_SetImageCount ' +
        'GUIImageList_Swap GUIScrollBars_EnableScrollBar ' +
        'GUIScrollBars_GetScrollBarInfoEx GUIScrollBars_GetScrollBarRect ' +
        'GUIScrollBars_GetScrollBarRGState ' +
        'GUIScrollBars_GetScrollBarXYLineButton ' +
        'GUIScrollBars_GetScrollBarXYThumbBottom ' +
        'GUIScrollBars_GetScrollBarXYThumbTop ' +
        'GUIScrollBars_GetScrollInfo GUIScrollBars_GetScrollInfoEx ' +
        'GUIScrollBars_GetScrollInfoMax GUIScrollBars_GetScrollInfoMin ' +
        'GUIScrollBars_GetScrollInfoPage GUIScrollBars_GetScrollInfoPos ' +
        'GUIScrollBars_GetScrollInfoTrackPos GUIScrollBars_GetScrollPos ' +
        'GUIScrollBars_GetScrollRange GUIScrollBars_Init ' +
        'GUIScrollBars_ScrollWindow GUIScrollBars_SetScrollInfo ' +
        'GUIScrollBars_SetScrollInfoMax GUIScrollBars_SetScrollInfoMin ' +
        'GUIScrollBars_SetScrollInfoPage GUIScrollBars_SetScrollInfoPos ' +
        'GUIScrollBars_SetScrollRange GUIScrollBars_ShowScrollBar ' +
        'GUIToolTip_Activate GUIToolTip_AddTool GUIToolTip_AdjustRect ' +
        'GUIToolTip_BitsToTTF GUIToolTip_Create GUIToolTip_Deactivate ' +
        'GUIToolTip_DelTool GUIToolTip_Destroy GUIToolTip_EnumTools ' +
        'GUIToolTip_GetBubbleHeight GUIToolTip_GetBubbleSize ' +
        'GUIToolTip_GetBubbleWidth GUIToolTip_GetCurrentTool ' +
        'GUIToolTip_GetDelayTime GUIToolTip_GetMargin ' +
        'GUIToolTip_GetMarginEx GUIToolTip_GetMaxTipWidth ' +
        'GUIToolTip_GetText GUIToolTip_GetTipBkColor ' +
        'GUIToolTip_GetTipTextColor GUIToolTip_GetTitleBitMap ' +
        'GUIToolTip_GetTitleText GUIToolTip_GetToolCount ' +
        'GUIToolTip_GetToolInfo GUIToolTip_HitTest ' +
        'GUIToolTip_NewToolRect GUIToolTip_Pop GUIToolTip_PopUp ' +
        'GUIToolTip_SetDelayTime GUIToolTip_SetMargin ' +
        'GUIToolTip_SetMaxTipWidth GUIToolTip_SetTipBkColor ' +
        'GUIToolTip_SetTipTextColor GUIToolTip_SetTitle ' +
        'GUIToolTip_SetToolInfo GUIToolTip_SetWindowTheme ' +
        'GUIToolTip_ToolExists GUIToolTip_ToolToArray ' +
        'GUIToolTip_TrackActivate GUIToolTip_TrackPosition ' +
        'GUIToolTip_Update GUIToolTip_UpdateTipText HexToString ' +
        'IEAction IEAttach IEBodyReadHTML IEBodyReadText ' +
        'IEBodyWriteHTML IECreate IECreateEmbedded IEDocGetObj ' +
        'IEDocInsertHTML IEDocInsertText IEDocReadHTML ' +
        'IEDocWriteHTML IEErrorNotify IEFormElementCheckBoxSelect ' +
        'IEFormElementGetCollection IEFormElementGetObjByName ' +
        'IEFormElementGetValue IEFormElementOptionSelect ' +
        'IEFormElementRadioSelect IEFormElementSetValue ' +
        'IEFormGetCollection IEFormGetObjByName IEFormImageClick ' +
        'IEFormReset IEFormSubmit IEFrameGetCollection ' +
        'IEFrameGetObjByName IEGetObjById IEGetObjByName ' +
        'IEHeadInsertEventScript IEImgClick IEImgGetCollection ' +
        'IEIsFrameSet IELinkClickByIndex IELinkClickByText ' +
        'IELinkGetCollection IELoadWait IELoadWaitTimeout IENavigate ' +
        'IEPropertyGet IEPropertySet IEQuit IETableGetCollection ' +
        'IETableWriteToArray IETagNameAllGetCollection ' +
        'IETagNameGetCollection IE_Example IE_Introduction ' +
        'IE_VersionInfo INetExplorerCapable INetGetSource INetMail ' +
        'INetSmtpMail IsPressed MathCheckDiv Max MemGlobalAlloc ' +
        'MemGlobalFree MemGlobalLock MemGlobalSize MemGlobalUnlock ' +
        'MemMoveMemory MemVirtualAlloc MemVirtualAllocEx ' +
        'MemVirtualFree MemVirtualFreeEx Min MouseTrap ' +
        'NamedPipes_CallNamedPipe NamedPipes_ConnectNamedPipe ' +
        'NamedPipes_CreateNamedPipe NamedPipes_CreatePipe ' +
        'NamedPipes_DisconnectNamedPipe ' +
        'NamedPipes_GetNamedPipeHandleState NamedPipes_GetNamedPipeInfo ' +
        'NamedPipes_PeekNamedPipe NamedPipes_SetNamedPipeHandleState ' +
        'NamedPipes_TransactNamedPipe NamedPipes_WaitNamedPipe ' +
        'Net_Share_ConnectionEnum Net_Share_FileClose ' +
        'Net_Share_FileEnum Net_Share_FileGetInfo Net_Share_PermStr ' +
        'Net_Share_ResourceStr Net_Share_SessionDel ' +
        'Net_Share_SessionEnum Net_Share_SessionGetInfo ' +
        'Net_Share_ShareAdd Net_Share_ShareCheck Net_Share_ShareDel ' +
        'Net_Share_ShareEnum Net_Share_ShareGetInfo ' +
        'Net_Share_ShareSetInfo Net_Share_StatisticsGetSvr ' +
        'Net_Share_StatisticsGetWrk Now NowCalc NowCalcDate ' +
        'NowDate NowTime PathFull PathGetRelative PathMake ' +
        'PathSplit ProcessGetName ProcessGetPriority Radian ' +
        'ReplaceStringInFile RunDos ScreenCapture_Capture ' +
        'ScreenCapture_CaptureWnd ScreenCapture_SaveImage ' +
        'ScreenCapture_SetBMPFormat ScreenCapture_SetJPGQuality ' +
        'ScreenCapture_SetTIFColorDepth ScreenCapture_SetTIFCompression ' +
        'Security__AdjustTokenPrivileges ' +
        'Security__CreateProcessWithToken Security__DuplicateTokenEx ' +
        'Security__GetAccountSid Security__GetLengthSid ' +
        'Security__GetTokenInformation Security__ImpersonateSelf ' +
        'Security__IsValidSid Security__LookupAccountName ' +
        'Security__LookupAccountSid Security__LookupPrivilegeValue ' +
        'Security__OpenProcessToken Security__OpenThreadToken ' +
        'Security__OpenThreadTokenEx Security__SetPrivilege ' +
        'Security__SetTokenInformation Security__SidToStringSid ' +
        'Security__SidTypeStr Security__StringSidToSid SendMessage ' +
        'SendMessageA SetDate SetTime Singleton SoundClose ' +
        'SoundLength SoundOpen SoundPause SoundPlay SoundPos ' +
        'SoundResume SoundSeek SoundStatus SoundStop ' +
        'SQLite_Changes SQLite_Close SQLite_Display2DResult ' +
        'SQLite_Encode SQLite_ErrCode SQLite_ErrMsg SQLite_Escape ' +
        'SQLite_Exec SQLite_FastEncode SQLite_FastEscape ' +
        'SQLite_FetchData SQLite_FetchNames SQLite_GetTable ' +
        'SQLite_GetTable2d SQLite_LastInsertRowID SQLite_LibVersion ' +
        'SQLite_Open SQLite_Query SQLite_QueryFinalize ' +
        'SQLite_QueryReset SQLite_QuerySingleRow SQLite_SafeMode ' +
        'SQLite_SetTimeout SQLite_Shutdown SQLite_SQLiteExe ' +
        'SQLite_Startup SQLite_TotalChanges StringBetween ' +
        'StringExplode StringInsert StringProper StringRepeat ' +
        'StringTitleCase StringToHex TCPIpToName TempFile ' +
        'TicksToTime Timer_Diff Timer_GetIdleTime Timer_GetTimerID ' +
        'Timer_Init Timer_KillAllTimers Timer_KillTimer ' +
        'Timer_SetTimer TimeToTicks VersionCompare viClose ' +
        'viExecCommand viFindGpib viGpibBusReset viGTL ' +
        'viInteractiveControl viOpen viSetAttribute viSetTimeout ' +
        'WeekNumberISO WinAPI_AbortPath WinAPI_ActivateKeyboardLayout ' +
        'WinAPI_AddClipboardFormatListener WinAPI_AddFontMemResourceEx ' +
        'WinAPI_AddFontResourceEx WinAPI_AddIconOverlay ' +
        'WinAPI_AddIconTransparency WinAPI_AddMRUString ' +
        'WinAPI_AdjustBitmap WinAPI_AdjustTokenPrivileges ' +
        'WinAPI_AdjustWindowRectEx WinAPI_AlphaBlend WinAPI_AngleArc ' +
        'WinAPI_AnimateWindow WinAPI_Arc WinAPI_ArcTo ' +
        'WinAPI_ArrayToStruct WinAPI_AssignProcessToJobObject ' +
        'WinAPI_AssocGetPerceivedType WinAPI_AssocQueryString ' +
        'WinAPI_AttachConsole WinAPI_AttachThreadInput ' +
        'WinAPI_BackupRead WinAPI_BackupReadAbort WinAPI_BackupSeek ' +
        'WinAPI_BackupWrite WinAPI_BackupWriteAbort WinAPI_Beep ' +
        'WinAPI_BeginBufferedPaint WinAPI_BeginDeferWindowPos ' +
        'WinAPI_BeginPaint WinAPI_BeginPath WinAPI_BeginUpdateResource ' +
        'WinAPI_BitBlt WinAPI_BringWindowToTop ' +
        'WinAPI_BroadcastSystemMessage WinAPI_BrowseForFolderDlg ' +
        'WinAPI_BufferedPaintClear WinAPI_BufferedPaintInit ' +
        'WinAPI_BufferedPaintSetAlpha WinAPI_BufferedPaintUnInit ' +
        'WinAPI_CallNextHookEx WinAPI_CallWindowProc ' +
        'WinAPI_CallWindowProcW WinAPI_CascadeWindows ' +
        'WinAPI_ChangeWindowMessageFilterEx WinAPI_CharToOem ' +
        'WinAPI_ChildWindowFromPointEx WinAPI_ClientToScreen ' +
        'WinAPI_ClipCursor WinAPI_CloseDesktop WinAPI_CloseEnhMetaFile ' +
        'WinAPI_CloseFigure WinAPI_CloseHandle WinAPI_CloseThemeData ' +
        'WinAPI_CloseWindow WinAPI_CloseWindowStation ' +
        'WinAPI_CLSIDFromProgID WinAPI_CoInitialize ' +
        'WinAPI_ColorAdjustLuma WinAPI_ColorHLSToRGB ' +
        'WinAPI_ColorRGBToHLS WinAPI_CombineRgn ' +
        'WinAPI_CombineTransform WinAPI_CommandLineToArgv ' +
        'WinAPI_CommDlgExtendedError WinAPI_CommDlgExtendedErrorEx ' +
        'WinAPI_CompareString WinAPI_CompressBitmapBits ' +
        'WinAPI_CompressBuffer WinAPI_ComputeCrc32 ' +
        'WinAPI_ConfirmCredentials WinAPI_CopyBitmap WinAPI_CopyCursor ' +
        'WinAPI_CopyEnhMetaFile WinAPI_CopyFileEx WinAPI_CopyIcon ' +
        'WinAPI_CopyImage WinAPI_CopyRect WinAPI_CopyStruct ' +
        'WinAPI_CoTaskMemAlloc WinAPI_CoTaskMemFree ' +
        'WinAPI_CoTaskMemRealloc WinAPI_CoUninitialize ' +
        'WinAPI_Create32BitHBITMAP WinAPI_Create32BitHICON ' +
        'WinAPI_CreateANDBitmap WinAPI_CreateBitmap ' +
        'WinAPI_CreateBitmapIndirect WinAPI_CreateBrushIndirect ' +
        'WinAPI_CreateBuffer WinAPI_CreateBufferFromStruct ' +
        'WinAPI_CreateCaret WinAPI_CreateColorAdjustment ' +
        'WinAPI_CreateCompatibleBitmap WinAPI_CreateCompatibleBitmapEx ' +
        'WinAPI_CreateCompatibleDC WinAPI_CreateDesktop ' +
        'WinAPI_CreateDIB WinAPI_CreateDIBColorTable ' +
        'WinAPI_CreateDIBitmap WinAPI_CreateDIBSection ' +
        'WinAPI_CreateDirectory WinAPI_CreateDirectoryEx ' +
        'WinAPI_CreateEllipticRgn WinAPI_CreateEmptyIcon ' +
        'WinAPI_CreateEnhMetaFile WinAPI_CreateEvent WinAPI_CreateFile ' +
        'WinAPI_CreateFileEx WinAPI_CreateFileMapping ' +
        'WinAPI_CreateFont WinAPI_CreateFontEx ' +
        'WinAPI_CreateFontIndirect WinAPI_CreateGUID ' +
        'WinAPI_CreateHardLink WinAPI_CreateIcon ' +
        'WinAPI_CreateIconFromResourceEx WinAPI_CreateIconIndirect ' +
        'WinAPI_CreateJobObject WinAPI_CreateMargins ' +
        'WinAPI_CreateMRUList WinAPI_CreateMutex WinAPI_CreateNullRgn ' +
        'WinAPI_CreateNumberFormatInfo WinAPI_CreateObjectID ' +
        'WinAPI_CreatePen WinAPI_CreatePoint WinAPI_CreatePolygonRgn ' +
        'WinAPI_CreateProcess WinAPI_CreateProcessWithToken ' +
        'WinAPI_CreateRect WinAPI_CreateRectEx WinAPI_CreateRectRgn ' +
        'WinAPI_CreateRectRgnIndirect WinAPI_CreateRoundRectRgn ' +
        'WinAPI_CreateSemaphore WinAPI_CreateSize ' +
        'WinAPI_CreateSolidBitmap WinAPI_CreateSolidBrush ' +
        'WinAPI_CreateStreamOnHGlobal WinAPI_CreateString ' +
        'WinAPI_CreateSymbolicLink WinAPI_CreateTransform ' +
        'WinAPI_CreateWindowEx WinAPI_CreateWindowStation ' +
        'WinAPI_DecompressBuffer WinAPI_DecryptFile ' +
        'WinAPI_DeferWindowPos WinAPI_DefineDosDevice ' +
        'WinAPI_DefRawInputProc WinAPI_DefSubclassProc ' +
        'WinAPI_DefWindowProc WinAPI_DefWindowProcW WinAPI_DeleteDC ' +
        'WinAPI_DeleteEnhMetaFile WinAPI_DeleteFile ' +
        'WinAPI_DeleteObject WinAPI_DeleteObjectID ' +
        'WinAPI_DeleteVolumeMountPoint WinAPI_DeregisterShellHookWindow ' +
        'WinAPI_DestroyCaret WinAPI_DestroyCursor WinAPI_DestroyIcon ' +
        'WinAPI_DestroyWindow WinAPI_DeviceIoControl ' +
        'WinAPI_DisplayStruct WinAPI_DllGetVersion WinAPI_DllInstall ' +
        'WinAPI_DllUninstall WinAPI_DPtoLP WinAPI_DragAcceptFiles ' +
        'WinAPI_DragFinish WinAPI_DragQueryFileEx ' +
        'WinAPI_DragQueryPoint WinAPI_DrawAnimatedRects ' +
        'WinAPI_DrawBitmap WinAPI_DrawEdge WinAPI_DrawFocusRect ' +
        'WinAPI_DrawFrameControl WinAPI_DrawIcon WinAPI_DrawIconEx ' +
        'WinAPI_DrawLine WinAPI_DrawShadowText WinAPI_DrawText ' +
        'WinAPI_DrawThemeBackground WinAPI_DrawThemeEdge ' +
        'WinAPI_DrawThemeIcon WinAPI_DrawThemeParentBackground ' +
        'WinAPI_DrawThemeText WinAPI_DrawThemeTextEx ' +
        'WinAPI_DuplicateEncryptionInfoFile WinAPI_DuplicateHandle ' +
        'WinAPI_DuplicateTokenEx WinAPI_DwmDefWindowProc ' +
        'WinAPI_DwmEnableBlurBehindWindow WinAPI_DwmEnableComposition ' +
        'WinAPI_DwmExtendFrameIntoClientArea ' +
        'WinAPI_DwmGetColorizationColor ' +
        'WinAPI_DwmGetColorizationParameters ' +
        'WinAPI_DwmGetWindowAttribute WinAPI_DwmInvalidateIconicBitmaps ' +
        'WinAPI_DwmIsCompositionEnabled ' +
        'WinAPI_DwmQueryThumbnailSourceSize WinAPI_DwmRegisterThumbnail ' +
        'WinAPI_DwmSetColorizationParameters ' +
        'WinAPI_DwmSetIconicLivePreviewBitmap ' +
        'WinAPI_DwmSetIconicThumbnail WinAPI_DwmSetWindowAttribute ' +
        'WinAPI_DwmUnregisterThumbnail ' +
        'WinAPI_DwmUpdateThumbnailProperties WinAPI_DWordToFloat ' +
        'WinAPI_DWordToInt WinAPI_EjectMedia WinAPI_Ellipse ' +
        'WinAPI_EmptyWorkingSet WinAPI_EnableWindow WinAPI_EncryptFile ' +
        'WinAPI_EncryptionDisable WinAPI_EndBufferedPaint ' +
        'WinAPI_EndDeferWindowPos WinAPI_EndPaint WinAPI_EndPath ' +
        'WinAPI_EndUpdateResource WinAPI_EnumChildProcess ' +
        'WinAPI_EnumChildWindows WinAPI_EnumDesktops ' +
        'WinAPI_EnumDesktopWindows WinAPI_EnumDeviceDrivers ' +
        'WinAPI_EnumDisplayDevices WinAPI_EnumDisplayMonitors ' +
        'WinAPI_EnumDisplaySettings WinAPI_EnumDllProc ' +
        'WinAPI_EnumFiles WinAPI_EnumFileStreams ' +
        'WinAPI_EnumFontFamilies WinAPI_EnumHardLinks ' +
        'WinAPI_EnumMRUList WinAPI_EnumPageFiles ' +
        'WinAPI_EnumProcessHandles WinAPI_EnumProcessModules ' +
        'WinAPI_EnumProcessThreads WinAPI_EnumProcessWindows ' +
        'WinAPI_EnumRawInputDevices WinAPI_EnumResourceLanguages ' +
        'WinAPI_EnumResourceNames WinAPI_EnumResourceTypes ' +
        'WinAPI_EnumSystemGeoID WinAPI_EnumSystemLocales ' +
        'WinAPI_EnumUILanguages WinAPI_EnumWindows ' +
        'WinAPI_EnumWindowsPopup WinAPI_EnumWindowStations ' +
        'WinAPI_EnumWindowsTop WinAPI_EqualMemory WinAPI_EqualRect ' +
        'WinAPI_EqualRgn WinAPI_ExcludeClipRect ' +
        'WinAPI_ExpandEnvironmentStrings WinAPI_ExtCreatePen ' +
        'WinAPI_ExtCreateRegion WinAPI_ExtFloodFill WinAPI_ExtractIcon ' +
        'WinAPI_ExtractIconEx WinAPI_ExtSelectClipRgn ' +
        'WinAPI_FatalAppExit WinAPI_FatalExit ' +
        'WinAPI_FileEncryptionStatus WinAPI_FileExists ' +
        'WinAPI_FileIconInit WinAPI_FileInUse WinAPI_FillMemory ' +
        'WinAPI_FillPath WinAPI_FillRect WinAPI_FillRgn ' +
        'WinAPI_FindClose WinAPI_FindCloseChangeNotification ' +
        'WinAPI_FindExecutable WinAPI_FindFirstChangeNotification ' +
        'WinAPI_FindFirstFile WinAPI_FindFirstFileName ' +
        'WinAPI_FindFirstStream WinAPI_FindNextChangeNotification ' +
        'WinAPI_FindNextFile WinAPI_FindNextFileName ' +
        'WinAPI_FindNextStream WinAPI_FindResource ' +
        'WinAPI_FindResourceEx WinAPI_FindTextDlg WinAPI_FindWindow ' +
        'WinAPI_FlashWindow WinAPI_FlashWindowEx WinAPI_FlattenPath ' +
        'WinAPI_FloatToDWord WinAPI_FloatToInt WinAPI_FlushFileBuffers ' +
        'WinAPI_FlushFRBuffer WinAPI_FlushViewOfFile ' +
        'WinAPI_FormatDriveDlg WinAPI_FormatMessage WinAPI_FrameRect ' +
        'WinAPI_FrameRgn WinAPI_FreeLibrary WinAPI_FreeMemory ' +
        'WinAPI_FreeMRUList WinAPI_FreeResource WinAPI_GdiComment ' +
        'WinAPI_GetActiveWindow WinAPI_GetAllUsersProfileDirectory ' +
        'WinAPI_GetAncestor WinAPI_GetApplicationRestartSettings ' +
        'WinAPI_GetArcDirection WinAPI_GetAsyncKeyState ' +
        'WinAPI_GetBinaryType WinAPI_GetBitmapBits ' +
        'WinAPI_GetBitmapDimension WinAPI_GetBitmapDimensionEx ' +
        'WinAPI_GetBkColor WinAPI_GetBkMode WinAPI_GetBoundsRect ' +
        'WinAPI_GetBrushOrg WinAPI_GetBufferedPaintBits ' +
        'WinAPI_GetBufferedPaintDC WinAPI_GetBufferedPaintTargetDC ' +
        'WinAPI_GetBufferedPaintTargetRect WinAPI_GetBValue ' +
        'WinAPI_GetCaretBlinkTime WinAPI_GetCaretPos WinAPI_GetCDType ' +
        'WinAPI_GetClassInfoEx WinAPI_GetClassLongEx ' +
        'WinAPI_GetClassName WinAPI_GetClientHeight ' +
        'WinAPI_GetClientRect WinAPI_GetClientWidth ' +
        'WinAPI_GetClipboardSequenceNumber WinAPI_GetClipBox ' +
        'WinAPI_GetClipCursor WinAPI_GetClipRgn ' +
        'WinAPI_GetColorAdjustment WinAPI_GetCompressedFileSize ' +
        'WinAPI_GetCompression WinAPI_GetConnectedDlg ' +
        'WinAPI_GetCurrentDirectory WinAPI_GetCurrentHwProfile ' +
        'WinAPI_GetCurrentObject WinAPI_GetCurrentPosition ' +
        'WinAPI_GetCurrentProcess ' +
        'WinAPI_GetCurrentProcessExplicitAppUserModelID ' +
        'WinAPI_GetCurrentProcessID WinAPI_GetCurrentThemeName ' +
        'WinAPI_GetCurrentThread WinAPI_GetCurrentThreadId ' +
        'WinAPI_GetCursor WinAPI_GetCursorInfo WinAPI_GetDateFormat ' +
        'WinAPI_GetDC WinAPI_GetDCEx WinAPI_GetDefaultPrinter ' +
        'WinAPI_GetDefaultUserProfileDirectory WinAPI_GetDesktopWindow ' +
        'WinAPI_GetDeviceCaps WinAPI_GetDeviceDriverBaseName ' +
        'WinAPI_GetDeviceDriverFileName WinAPI_GetDeviceGammaRamp ' +
        'WinAPI_GetDIBColorTable WinAPI_GetDIBits ' +
        'WinAPI_GetDiskFreeSpaceEx WinAPI_GetDlgCtrlID ' +
        'WinAPI_GetDlgItem WinAPI_GetDllDirectory ' +
        'WinAPI_GetDriveBusType WinAPI_GetDriveGeometryEx ' +
        'WinAPI_GetDriveNumber WinAPI_GetDriveType ' +
        'WinAPI_GetDurationFormat WinAPI_GetEffectiveClientRect ' +
        'WinAPI_GetEnhMetaFile WinAPI_GetEnhMetaFileBits ' +
        'WinAPI_GetEnhMetaFileDescription WinAPI_GetEnhMetaFileDimension ' +
        'WinAPI_GetEnhMetaFileHeader WinAPI_GetErrorMessage ' +
        'WinAPI_GetErrorMode WinAPI_GetExitCodeProcess ' +
        'WinAPI_GetExtended WinAPI_GetFileAttributes WinAPI_GetFileID ' +
        'WinAPI_GetFileInformationByHandle ' +
        'WinAPI_GetFileInformationByHandleEx WinAPI_GetFilePointerEx ' +
        'WinAPI_GetFileSizeEx WinAPI_GetFileSizeOnDisk ' +
        'WinAPI_GetFileTitle WinAPI_GetFileType ' +
        'WinAPI_GetFileVersionInfo WinAPI_GetFinalPathNameByHandle ' +
        'WinAPI_GetFinalPathNameByHandleEx WinAPI_GetFocus ' +
        'WinAPI_GetFontMemoryResourceInfo WinAPI_GetFontName ' +
        'WinAPI_GetFontResourceInfo WinAPI_GetForegroundWindow ' +
        'WinAPI_GetFRBuffer WinAPI_GetFullPathName WinAPI_GetGeoInfo ' +
        'WinAPI_GetGlyphOutline WinAPI_GetGraphicsMode ' +
        'WinAPI_GetGuiResources WinAPI_GetGUIThreadInfo ' +
        'WinAPI_GetGValue WinAPI_GetHandleInformation ' +
        'WinAPI_GetHGlobalFromStream WinAPI_GetIconDimension ' +
        'WinAPI_GetIconInfo WinAPI_GetIconInfoEx WinAPI_GetIdleTime ' +
        'WinAPI_GetKeyboardLayout WinAPI_GetKeyboardLayoutList ' +
        'WinAPI_GetKeyboardState WinAPI_GetKeyboardType ' +
        'WinAPI_GetKeyNameText WinAPI_GetKeyState ' +
        'WinAPI_GetLastActivePopup WinAPI_GetLastError ' +
        'WinAPI_GetLastErrorMessage WinAPI_GetLayeredWindowAttributes ' +
        'WinAPI_GetLocaleInfo WinAPI_GetLogicalDrives ' +
        'WinAPI_GetMapMode WinAPI_GetMemorySize ' +
        'WinAPI_GetMessageExtraInfo WinAPI_GetModuleFileNameEx ' +
        'WinAPI_GetModuleHandle WinAPI_GetModuleHandleEx ' +
        'WinAPI_GetModuleInformation WinAPI_GetMonitorInfo ' +
        'WinAPI_GetMousePos WinAPI_GetMousePosX WinAPI_GetMousePosY ' +
        'WinAPI_GetMUILanguage WinAPI_GetNumberFormat WinAPI_GetObject ' +
        'WinAPI_GetObjectID WinAPI_GetObjectInfoByHandle ' +
        'WinAPI_GetObjectNameByHandle WinAPI_GetObjectType ' +
        'WinAPI_GetOpenFileName WinAPI_GetOutlineTextMetrics ' +
        'WinAPI_GetOverlappedResult WinAPI_GetParent ' +
        'WinAPI_GetParentProcess WinAPI_GetPerformanceInfo ' +
        'WinAPI_GetPEType WinAPI_GetPhysicallyInstalledSystemMemory ' +
        'WinAPI_GetPixel WinAPI_GetPolyFillMode WinAPI_GetPosFromRect ' +
        'WinAPI_GetPriorityClass WinAPI_GetProcAddress ' +
        'WinAPI_GetProcessAffinityMask WinAPI_GetProcessCommandLine ' +
        'WinAPI_GetProcessFileName WinAPI_GetProcessHandleCount ' +
        'WinAPI_GetProcessID WinAPI_GetProcessIoCounters ' +
        'WinAPI_GetProcessMemoryInfo WinAPI_GetProcessName ' +
        'WinAPI_GetProcessShutdownParameters WinAPI_GetProcessTimes ' +
        'WinAPI_GetProcessUser WinAPI_GetProcessWindowStation ' +
        'WinAPI_GetProcessWorkingDirectory WinAPI_GetProfilesDirectory ' +
        'WinAPI_GetPwrCapabilities WinAPI_GetRawInputBuffer ' +
        'WinAPI_GetRawInputBufferLength WinAPI_GetRawInputData ' +
        'WinAPI_GetRawInputDeviceInfo WinAPI_GetRegionData ' +
        'WinAPI_GetRegisteredRawInputDevices ' +
        'WinAPI_GetRegKeyNameByHandle WinAPI_GetRgnBox WinAPI_GetROP2 ' +
        'WinAPI_GetRValue WinAPI_GetSaveFileName WinAPI_GetShellWindow ' +
        'WinAPI_GetStartupInfo WinAPI_GetStdHandle ' +
        'WinAPI_GetStockObject WinAPI_GetStretchBltMode ' +
        'WinAPI_GetString WinAPI_GetSysColor WinAPI_GetSysColorBrush ' +
        'WinAPI_GetSystemDefaultLangID WinAPI_GetSystemDefaultLCID ' +
        'WinAPI_GetSystemDefaultUILanguage WinAPI_GetSystemDEPPolicy ' +
        'WinAPI_GetSystemInfo WinAPI_GetSystemMetrics ' +
        'WinAPI_GetSystemPowerStatus WinAPI_GetSystemTimes ' +
        'WinAPI_GetSystemWow64Directory WinAPI_GetTabbedTextExtent ' +
        'WinAPI_GetTempFileName WinAPI_GetTextAlign ' +
        'WinAPI_GetTextCharacterExtra WinAPI_GetTextColor ' +
        'WinAPI_GetTextExtentPoint32 WinAPI_GetTextFace ' +
        'WinAPI_GetTextMetrics WinAPI_GetThemeAppProperties ' +
        'WinAPI_GetThemeBackgroundContentRect ' +
        'WinAPI_GetThemeBackgroundExtent WinAPI_GetThemeBackgroundRegion ' +
        'WinAPI_GetThemeBitmap WinAPI_GetThemeBool ' +
        'WinAPI_GetThemeColor WinAPI_GetThemeDocumentationProperty ' +
        'WinAPI_GetThemeEnumValue WinAPI_GetThemeFilename ' +
        'WinAPI_GetThemeFont WinAPI_GetThemeInt WinAPI_GetThemeMargins ' +
        'WinAPI_GetThemeMetric WinAPI_GetThemePartSize ' +
        'WinAPI_GetThemePosition WinAPI_GetThemePropertyOrigin ' +
        'WinAPI_GetThemeRect WinAPI_GetThemeString ' +
        'WinAPI_GetThemeSysBool WinAPI_GetThemeSysColor ' +
        'WinAPI_GetThemeSysColorBrush WinAPI_GetThemeSysFont ' +
        'WinAPI_GetThemeSysInt WinAPI_GetThemeSysSize ' +
        'WinAPI_GetThemeSysString WinAPI_GetThemeTextExtent ' +
        'WinAPI_GetThemeTextMetrics WinAPI_GetThemeTransitionDuration ' +
        'WinAPI_GetThreadDesktop WinAPI_GetThreadErrorMode ' +
        'WinAPI_GetThreadLocale WinAPI_GetThreadUILanguage ' +
        'WinAPI_GetTickCount WinAPI_GetTickCount64 ' +
        'WinAPI_GetTimeFormat WinAPI_GetTopWindow ' +
        'WinAPI_GetUDFColorMode WinAPI_GetUpdateRect ' +
        'WinAPI_GetUpdateRgn WinAPI_GetUserDefaultLangID ' +
        'WinAPI_GetUserDefaultLCID WinAPI_GetUserDefaultUILanguage ' +
        'WinAPI_GetUserGeoID WinAPI_GetUserObjectInformation ' +
        'WinAPI_GetVersion WinAPI_GetVersionEx ' +
        'WinAPI_GetVolumeInformation WinAPI_GetVolumeInformationByHandle ' +
        'WinAPI_GetVolumeNameForVolumeMountPoint WinAPI_GetWindow ' +
        'WinAPI_GetWindowDC WinAPI_GetWindowDisplayAffinity ' +
        'WinAPI_GetWindowExt WinAPI_GetWindowFileName ' +
        'WinAPI_GetWindowHeight WinAPI_GetWindowInfo ' +
        'WinAPI_GetWindowLong WinAPI_GetWindowOrg ' +
        'WinAPI_GetWindowPlacement WinAPI_GetWindowRect ' +
        'WinAPI_GetWindowRgn WinAPI_GetWindowRgnBox ' +
        'WinAPI_GetWindowSubclass WinAPI_GetWindowText ' +
        'WinAPI_GetWindowTheme WinAPI_GetWindowThreadProcessId ' +
        'WinAPI_GetWindowWidth WinAPI_GetWorkArea ' +
        'WinAPI_GetWorldTransform WinAPI_GetXYFromPoint ' +
        'WinAPI_GlobalMemoryStatus WinAPI_GradientFill ' +
        'WinAPI_GUIDFromString WinAPI_GUIDFromStringEx WinAPI_HashData ' +
        'WinAPI_HashString WinAPI_HiByte WinAPI_HideCaret ' +
        'WinAPI_HiDWord WinAPI_HiWord WinAPI_InflateRect ' +
        'WinAPI_InitMUILanguage WinAPI_InProcess ' +
        'WinAPI_IntersectClipRect WinAPI_IntersectRect ' +
        'WinAPI_IntToDWord WinAPI_IntToFloat WinAPI_InvalidateRect ' +
        'WinAPI_InvalidateRgn WinAPI_InvertANDBitmap ' +
        'WinAPI_InvertColor WinAPI_InvertRect WinAPI_InvertRgn ' +
        'WinAPI_IOCTL WinAPI_IsAlphaBitmap WinAPI_IsBadCodePtr ' +
        'WinAPI_IsBadReadPtr WinAPI_IsBadStringPtr ' +
        'WinAPI_IsBadWritePtr WinAPI_IsChild WinAPI_IsClassName ' +
        'WinAPI_IsDoorOpen WinAPI_IsElevated WinAPI_IsHungAppWindow ' +
        'WinAPI_IsIconic WinAPI_IsInternetConnected ' +
        'WinAPI_IsLoadKBLayout WinAPI_IsMemory ' +
        'WinAPI_IsNameInExpression WinAPI_IsNetworkAlive ' +
        'WinAPI_IsPathShared WinAPI_IsProcessInJob ' +
        'WinAPI_IsProcessorFeaturePresent WinAPI_IsRectEmpty ' +
        'WinAPI_IsThemeActive ' +
        'WinAPI_IsThemeBackgroundPartiallyTransparent ' +
        'WinAPI_IsThemePartDefined WinAPI_IsValidLocale ' +
        'WinAPI_IsWindow WinAPI_IsWindowEnabled WinAPI_IsWindowUnicode ' +
        'WinAPI_IsWindowVisible WinAPI_IsWow64Process ' +
        'WinAPI_IsWritable WinAPI_IsZoomed WinAPI_Keybd_Event ' +
        'WinAPI_KillTimer WinAPI_LineDDA WinAPI_LineTo ' +
        'WinAPI_LoadBitmap WinAPI_LoadCursor WinAPI_LoadCursorFromFile ' +
        'WinAPI_LoadIcon WinAPI_LoadIconMetric ' +
        'WinAPI_LoadIconWithScaleDown WinAPI_LoadImage ' +
        'WinAPI_LoadIndirectString WinAPI_LoadKeyboardLayout ' +
        'WinAPI_LoadLibrary WinAPI_LoadLibraryEx WinAPI_LoadMedia ' +
        'WinAPI_LoadResource WinAPI_LoadShell32Icon WinAPI_LoadString ' +
        'WinAPI_LoadStringEx WinAPI_LoByte WinAPI_LocalFree ' +
        'WinAPI_LockDevice WinAPI_LockFile WinAPI_LockResource ' +
        'WinAPI_LockWindowUpdate WinAPI_LockWorkStation WinAPI_LoDWord ' +
        'WinAPI_LongMid WinAPI_LookupIconIdFromDirectoryEx ' +
        'WinAPI_LoWord WinAPI_LPtoDP WinAPI_MAKELANGID ' +
        'WinAPI_MAKELCID WinAPI_MakeLong WinAPI_MakeQWord ' +
        'WinAPI_MakeWord WinAPI_MapViewOfFile WinAPI_MapVirtualKey ' +
        'WinAPI_MaskBlt WinAPI_MessageBeep WinAPI_MessageBoxCheck ' +
        'WinAPI_MessageBoxIndirect WinAPI_MirrorIcon ' +
        'WinAPI_ModifyWorldTransform WinAPI_MonitorFromPoint ' +
        'WinAPI_MonitorFromRect WinAPI_MonitorFromWindow ' +
        'WinAPI_Mouse_Event WinAPI_MoveFileEx WinAPI_MoveMemory ' +
        'WinAPI_MoveTo WinAPI_MoveToEx WinAPI_MoveWindow ' +
        'WinAPI_MsgBox WinAPI_MulDiv WinAPI_MultiByteToWideChar ' +
        'WinAPI_MultiByteToWideCharEx WinAPI_NtStatusToDosError ' +
        'WinAPI_OemToChar WinAPI_OffsetClipRgn WinAPI_OffsetPoints ' +
        'WinAPI_OffsetRect WinAPI_OffsetRgn WinAPI_OffsetWindowOrg ' +
        'WinAPI_OpenDesktop WinAPI_OpenFileById WinAPI_OpenFileDlg ' +
        'WinAPI_OpenFileMapping WinAPI_OpenIcon ' +
        'WinAPI_OpenInputDesktop WinAPI_OpenJobObject WinAPI_OpenMutex ' +
        'WinAPI_OpenProcess WinAPI_OpenProcessToken ' +
        'WinAPI_OpenSemaphore WinAPI_OpenThemeData ' +
        'WinAPI_OpenWindowStation WinAPI_PageSetupDlg ' +
        'WinAPI_PaintDesktop WinAPI_PaintRgn WinAPI_ParseURL ' +
        'WinAPI_ParseUserName WinAPI_PatBlt WinAPI_PathAddBackslash ' +
        'WinAPI_PathAddExtension WinAPI_PathAppend ' +
        'WinAPI_PathBuildRoot WinAPI_PathCanonicalize ' +
        'WinAPI_PathCommonPrefix WinAPI_PathCompactPath ' +
        'WinAPI_PathCompactPathEx WinAPI_PathCreateFromUrl ' +
        'WinAPI_PathFindExtension WinAPI_PathFindFileName ' +
        'WinAPI_PathFindNextComponent WinAPI_PathFindOnPath ' +
        'WinAPI_PathGetArgs WinAPI_PathGetCharType ' +
        'WinAPI_PathGetDriveNumber WinAPI_PathIsContentType ' +
        'WinAPI_PathIsDirectory WinAPI_PathIsDirectoryEmpty ' +
        'WinAPI_PathIsExe WinAPI_PathIsFileSpec ' +
        'WinAPI_PathIsLFNFileSpec WinAPI_PathIsRelative ' +
        'WinAPI_PathIsRoot WinAPI_PathIsSameRoot ' +
        'WinAPI_PathIsSystemFolder WinAPI_PathIsUNC ' +
        'WinAPI_PathIsUNCServer WinAPI_PathIsUNCServerShare ' +
        'WinAPI_PathMakeSystemFolder WinAPI_PathMatchSpec ' +
        'WinAPI_PathParseIconLocation WinAPI_PathRelativePathTo ' +
        'WinAPI_PathRemoveArgs WinAPI_PathRemoveBackslash ' +
        'WinAPI_PathRemoveExtension WinAPI_PathRemoveFileSpec ' +
        'WinAPI_PathRenameExtension WinAPI_PathSearchAndQualify ' +
        'WinAPI_PathSkipRoot WinAPI_PathStripPath ' +
        'WinAPI_PathStripToRoot WinAPI_PathToRegion ' +
        'WinAPI_PathUndecorate WinAPI_PathUnExpandEnvStrings ' +
        'WinAPI_PathUnmakeSystemFolder WinAPI_PathUnquoteSpaces ' +
        'WinAPI_PathYetAnotherMakeUniqueName WinAPI_PickIconDlg ' +
        'WinAPI_PlayEnhMetaFile WinAPI_PlaySound WinAPI_PlgBlt ' +
        'WinAPI_PointFromRect WinAPI_PolyBezier WinAPI_PolyBezierTo ' +
        'WinAPI_PolyDraw WinAPI_Polygon WinAPI_PostMessage ' +
        'WinAPI_PrimaryLangId WinAPI_PrintDlg WinAPI_PrintDlgEx ' +
        'WinAPI_PrintWindow WinAPI_ProgIDFromCLSID WinAPI_PtInRect ' +
        'WinAPI_PtInRectEx WinAPI_PtInRegion WinAPI_PtVisible ' +
        'WinAPI_QueryDosDevice WinAPI_QueryInformationJobObject ' +
        'WinAPI_QueryPerformanceCounter WinAPI_QueryPerformanceFrequency ' +
        'WinAPI_RadialGradientFill WinAPI_ReadDirectoryChanges ' +
        'WinAPI_ReadFile WinAPI_ReadProcessMemory WinAPI_Rectangle ' +
        'WinAPI_RectInRegion WinAPI_RectIsEmpty WinAPI_RectVisible ' +
        'WinAPI_RedrawWindow WinAPI_RegCloseKey ' +
        'WinAPI_RegConnectRegistry WinAPI_RegCopyTree ' +
        'WinAPI_RegCopyTreeEx WinAPI_RegCreateKey ' +
        'WinAPI_RegDeleteEmptyKey WinAPI_RegDeleteKey ' +
        'WinAPI_RegDeleteKeyValue WinAPI_RegDeleteTree ' +
        'WinAPI_RegDeleteTreeEx WinAPI_RegDeleteValue ' +
        'WinAPI_RegDisableReflectionKey WinAPI_RegDuplicateHKey ' +
        'WinAPI_RegEnableReflectionKey WinAPI_RegEnumKey ' +
        'WinAPI_RegEnumValue WinAPI_RegFlushKey ' +
        'WinAPI_RegisterApplicationRestart WinAPI_RegisterClass ' +
        'WinAPI_RegisterClassEx WinAPI_RegisterHotKey ' +
        'WinAPI_RegisterPowerSettingNotification ' +
        'WinAPI_RegisterRawInputDevices WinAPI_RegisterShellHookWindow ' +
        'WinAPI_RegisterWindowMessage WinAPI_RegLoadMUIString ' +
        'WinAPI_RegNotifyChangeKeyValue WinAPI_RegOpenKey ' +
        'WinAPI_RegQueryInfoKey WinAPI_RegQueryLastWriteTime ' +
        'WinAPI_RegQueryMultipleValues WinAPI_RegQueryReflectionKey ' +
        'WinAPI_RegQueryValue WinAPI_RegRestoreKey WinAPI_RegSaveKey ' +
        'WinAPI_RegSetValue WinAPI_ReleaseCapture WinAPI_ReleaseDC ' +
        'WinAPI_ReleaseMutex WinAPI_ReleaseSemaphore ' +
        'WinAPI_ReleaseStream WinAPI_RemoveClipboardFormatListener ' +
        'WinAPI_RemoveDirectory WinAPI_RemoveFontMemResourceEx ' +
        'WinAPI_RemoveFontResourceEx WinAPI_RemoveWindowSubclass ' +
        'WinAPI_ReOpenFile WinAPI_ReplaceFile WinAPI_ReplaceTextDlg ' +
        'WinAPI_ResetEvent WinAPI_RestartDlg WinAPI_RestoreDC ' +
        'WinAPI_RGB WinAPI_RotatePoints WinAPI_RoundRect ' +
        'WinAPI_SaveDC WinAPI_SaveFileDlg WinAPI_SaveHBITMAPToFile ' +
        'WinAPI_SaveHICONToFile WinAPI_ScaleWindowExt ' +
        'WinAPI_ScreenToClient WinAPI_SearchPath WinAPI_SelectClipPath ' +
        'WinAPI_SelectClipRgn WinAPI_SelectObject ' +
        'WinAPI_SendMessageTimeout WinAPI_SetActiveWindow ' +
        'WinAPI_SetArcDirection WinAPI_SetBitmapBits ' +
        'WinAPI_SetBitmapDimensionEx WinAPI_SetBkColor ' +
        'WinAPI_SetBkMode WinAPI_SetBoundsRect WinAPI_SetBrushOrg ' +
        'WinAPI_SetCapture WinAPI_SetCaretBlinkTime WinAPI_SetCaretPos ' +
        'WinAPI_SetClassLongEx WinAPI_SetColorAdjustment ' +
        'WinAPI_SetCompression WinAPI_SetCurrentDirectory ' +
        'WinAPI_SetCurrentProcessExplicitAppUserModelID WinAPI_SetCursor ' +
        'WinAPI_SetDCBrushColor WinAPI_SetDCPenColor ' +
        'WinAPI_SetDefaultPrinter WinAPI_SetDeviceGammaRamp ' +
        'WinAPI_SetDIBColorTable WinAPI_SetDIBits ' +
        'WinAPI_SetDIBitsToDevice WinAPI_SetDllDirectory ' +
        'WinAPI_SetEndOfFile WinAPI_SetEnhMetaFileBits ' +
        'WinAPI_SetErrorMode WinAPI_SetEvent WinAPI_SetFileAttributes ' +
        'WinAPI_SetFileInformationByHandleEx WinAPI_SetFilePointer ' +
        'WinAPI_SetFilePointerEx WinAPI_SetFileShortName ' +
        'WinAPI_SetFileValidData WinAPI_SetFocus WinAPI_SetFont ' +
        'WinAPI_SetForegroundWindow WinAPI_SetFRBuffer ' +
        'WinAPI_SetGraphicsMode WinAPI_SetHandleInformation ' +
        'WinAPI_SetInformationJobObject WinAPI_SetKeyboardLayout ' +
        'WinAPI_SetKeyboardState WinAPI_SetLastError ' +
        'WinAPI_SetLayeredWindowAttributes WinAPI_SetLocaleInfo ' +
        'WinAPI_SetMapMode WinAPI_SetMessageExtraInfo WinAPI_SetParent ' +
        'WinAPI_SetPixel WinAPI_SetPolyFillMode ' +
        'WinAPI_SetPriorityClass WinAPI_SetProcessAffinityMask ' +
        'WinAPI_SetProcessShutdownParameters ' +
        'WinAPI_SetProcessWindowStation WinAPI_SetRectRgn ' +
        'WinAPI_SetROP2 WinAPI_SetSearchPathMode ' +
        'WinAPI_SetStretchBltMode WinAPI_SetSysColors ' +
        'WinAPI_SetSystemCursor WinAPI_SetTextAlign ' +
        'WinAPI_SetTextCharacterExtra WinAPI_SetTextColor ' +
        'WinAPI_SetTextJustification WinAPI_SetThemeAppProperties ' +
        'WinAPI_SetThreadDesktop WinAPI_SetThreadErrorMode ' +
        'WinAPI_SetThreadExecutionState WinAPI_SetThreadLocale ' +
        'WinAPI_SetThreadUILanguage WinAPI_SetTimer ' +
        'WinAPI_SetUDFColorMode WinAPI_SetUserGeoID ' +
        'WinAPI_SetUserObjectInformation WinAPI_SetVolumeMountPoint ' +
        'WinAPI_SetWindowDisplayAffinity WinAPI_SetWindowExt ' +
        'WinAPI_SetWindowLong WinAPI_SetWindowOrg ' +
        'WinAPI_SetWindowPlacement WinAPI_SetWindowPos ' +
        'WinAPI_SetWindowRgn WinAPI_SetWindowsHookEx ' +
        'WinAPI_SetWindowSubclass WinAPI_SetWindowText ' +
        'WinAPI_SetWindowTheme WinAPI_SetWinEventHook ' +
        'WinAPI_SetWorldTransform WinAPI_SfcIsFileProtected ' +
        'WinAPI_SfcIsKeyProtected WinAPI_ShellAboutDlg ' +
        'WinAPI_ShellAddToRecentDocs WinAPI_ShellChangeNotify ' +
        'WinAPI_ShellChangeNotifyDeregister ' +
        'WinAPI_ShellChangeNotifyRegister WinAPI_ShellCreateDirectory ' +
        'WinAPI_ShellEmptyRecycleBin WinAPI_ShellExecute ' +
        'WinAPI_ShellExecuteEx WinAPI_ShellExtractAssociatedIcon ' +
        'WinAPI_ShellExtractIcon WinAPI_ShellFileOperation ' +
        'WinAPI_ShellFlushSFCache WinAPI_ShellGetFileInfo ' +
        'WinAPI_ShellGetIconOverlayIndex WinAPI_ShellGetImageList ' +
        'WinAPI_ShellGetKnownFolderIDList WinAPI_ShellGetKnownFolderPath ' +
        'WinAPI_ShellGetLocalizedName WinAPI_ShellGetPathFromIDList ' +
        'WinAPI_ShellGetSetFolderCustomSettings WinAPI_ShellGetSettings ' +
        'WinAPI_ShellGetSpecialFolderLocation ' +
        'WinAPI_ShellGetSpecialFolderPath WinAPI_ShellGetStockIconInfo ' +
        'WinAPI_ShellILCreateFromPath WinAPI_ShellNotifyIcon ' +
        'WinAPI_ShellNotifyIconGetRect WinAPI_ShellObjectProperties ' +
        'WinAPI_ShellOpenFolderAndSelectItems WinAPI_ShellOpenWithDlg ' +
        'WinAPI_ShellQueryRecycleBin ' +
        'WinAPI_ShellQueryUserNotificationState ' +
        'WinAPI_ShellRemoveLocalizedName WinAPI_ShellRestricted ' +
        'WinAPI_ShellSetKnownFolderPath WinAPI_ShellSetLocalizedName ' +
        'WinAPI_ShellSetSettings WinAPI_ShellStartNetConnectionDlg ' +
        'WinAPI_ShellUpdateImage WinAPI_ShellUserAuthenticationDlg ' +
        'WinAPI_ShellUserAuthenticationDlgEx WinAPI_ShortToWord ' +
        'WinAPI_ShowCaret WinAPI_ShowCursor WinAPI_ShowError ' +
        'WinAPI_ShowLastError WinAPI_ShowMsg WinAPI_ShowOwnedPopups ' +
        'WinAPI_ShowWindow WinAPI_ShutdownBlockReasonCreate ' +
        'WinAPI_ShutdownBlockReasonDestroy ' +
        'WinAPI_ShutdownBlockReasonQuery WinAPI_SizeOfResource ' +
        'WinAPI_StretchBlt WinAPI_StretchDIBits ' +
        'WinAPI_StrFormatByteSize WinAPI_StrFormatByteSizeEx ' +
        'WinAPI_StrFormatKBSize WinAPI_StrFromTimeInterval ' +
        'WinAPI_StringFromGUID WinAPI_StringLenA WinAPI_StringLenW ' +
        'WinAPI_StrLen WinAPI_StrokeAndFillPath WinAPI_StrokePath ' +
        'WinAPI_StructToArray WinAPI_SubLangId WinAPI_SubtractRect ' +
        'WinAPI_SwapDWord WinAPI_SwapQWord WinAPI_SwapWord ' +
        'WinAPI_SwitchColor WinAPI_SwitchDesktop ' +
        'WinAPI_SwitchToThisWindow WinAPI_SystemParametersInfo ' +
        'WinAPI_TabbedTextOut WinAPI_TerminateJobObject ' +
        'WinAPI_TerminateProcess WinAPI_TextOut WinAPI_TileWindows ' +
        'WinAPI_TrackMouseEvent WinAPI_TransparentBlt ' +
        'WinAPI_TwipsPerPixelX WinAPI_TwipsPerPixelY ' +
        'WinAPI_UnhookWindowsHookEx WinAPI_UnhookWinEvent ' +
        'WinAPI_UnionRect WinAPI_UnionStruct WinAPI_UniqueHardwareID ' +
        'WinAPI_UnloadKeyboardLayout WinAPI_UnlockFile ' +
        'WinAPI_UnmapViewOfFile WinAPI_UnregisterApplicationRestart ' +
        'WinAPI_UnregisterClass WinAPI_UnregisterHotKey ' +
        'WinAPI_UnregisterPowerSettingNotification ' +
        'WinAPI_UpdateLayeredWindow WinAPI_UpdateLayeredWindowEx ' +
        'WinAPI_UpdateLayeredWindowIndirect WinAPI_UpdateResource ' +
        'WinAPI_UpdateWindow WinAPI_UrlApplyScheme ' +
        'WinAPI_UrlCanonicalize WinAPI_UrlCombine WinAPI_UrlCompare ' +
        'WinAPI_UrlCreateFromPath WinAPI_UrlFixup WinAPI_UrlGetPart ' +
        'WinAPI_UrlHash WinAPI_UrlIs WinAPI_UserHandleGrantAccess ' +
        'WinAPI_ValidateRect WinAPI_ValidateRgn WinAPI_VerQueryRoot ' +
        'WinAPI_VerQueryValue WinAPI_VerQueryValueEx ' +
        'WinAPI_WaitForInputIdle WinAPI_WaitForMultipleObjects ' +
        'WinAPI_WaitForSingleObject WinAPI_WideCharToMultiByte ' +
        'WinAPI_WidenPath WinAPI_WindowFromDC WinAPI_WindowFromPoint ' +
        'WinAPI_WordToShort WinAPI_Wow64EnableWow64FsRedirection ' +
        'WinAPI_WriteConsole WinAPI_WriteFile ' +
        'WinAPI_WriteProcessMemory WinAPI_ZeroMemory ' +
        'WinNet_AddConnection WinNet_AddConnection2 ' +
        'WinNet_AddConnection3 WinNet_CancelConnection ' +
        'WinNet_CancelConnection2 WinNet_CloseEnum ' +
        'WinNet_ConnectionDialog WinNet_ConnectionDialog1 ' +
        'WinNet_DisconnectDialog WinNet_DisconnectDialog1 ' +
        'WinNet_EnumResource WinNet_GetConnection ' +
        'WinNet_GetConnectionPerformance WinNet_GetLastError ' +
        'WinNet_GetNetworkInformation WinNet_GetProviderName ' +
        'WinNet_GetResourceInformation WinNet_GetResourceParent ' +
        'WinNet_GetUniversalName WinNet_GetUser WinNet_OpenEnum ' +
        'WinNet_RestoreConnection WinNet_UseConnection Word_Create ' +
        'Word_DocAdd Word_DocAttach Word_DocClose Word_DocExport ' +
        'Word_DocFind Word_DocFindReplace Word_DocGet ' +
        'Word_DocLinkAdd Word_DocLinkGet Word_DocOpen ' +
        'Word_DocPictureAdd Word_DocPrint Word_DocRangeSet ' +
        'Word_DocSave Word_DocSaveAs Word_DocTableRead ' +
        'Word_DocTableWrite Word_Quit',

        COMMENT = {
            variants: [
              hljs.COMMENT(';', '$', {relevance: 0}),
              hljs.COMMENT('#cs', '#ce'),
              hljs.COMMENT('#comments-start', '#comments-end')
            ]
        },

        VARIABLE = {
            className: 'variable',
            begin: '\\$[A-z0-9_]+'
        },

        STRING = {
            className: 'string',
            variants: [{
                begin: /"/,
                end: /"/,
                contains: [{
                    begin: /""/,
                    relevance: 0
                }]
            }, {
                begin: /'/,
                end: /'/,
                contains: [{
                    begin: /''/,
                    relevance: 0
                }]
            }]
        },

        NUMBER = {
            variants: [hljs.BINARY_NUMBER_MODE, hljs.C_NUMBER_MODE]
        },

        PREPROCESSOR = {
            className: 'preprocessor',
            begin: '#',
            end: '$',
            keywords: 'include include-once NoTrayIcon OnAutoItStartRegister RequireAdmin pragma ' +
                'Au3Stripper_Ignore_Funcs Au3Stripper_Ignore_Variables ' +
                'Au3Stripper_Off Au3Stripper_On Au3Stripper_Parameters ' +
                'AutoIt3Wrapper_Add_Constants AutoIt3Wrapper_Au3Check_Parameters ' +
                'AutoIt3Wrapper_Au3Check_Stop_OnWarning AutoIt3Wrapper_Aut2Exe ' +
                'AutoIt3Wrapper_AutoIt3 AutoIt3Wrapper_AutoIt3Dir ' +
                'AutoIt3Wrapper_Change2CUI AutoIt3Wrapper_Compile_Both ' +
                'AutoIt3Wrapper_Compression AutoIt3Wrapper_EndIf ' +
                'AutoIt3Wrapper_Icon AutoIt3Wrapper_If_Compile ' +
                'AutoIt3Wrapper_If_Run AutoIt3Wrapper_Jump_To_First_Error ' +
                'AutoIt3Wrapper_OutFile AutoIt3Wrapper_OutFile_Type ' +
                'AutoIt3Wrapper_OutFile_X64 AutoIt3Wrapper_PlugIn_Funcs ' +
                'AutoIt3Wrapper_Res_Comment Autoit3Wrapper_Res_Compatibility ' +
                'AutoIt3Wrapper_Res_Description AutoIt3Wrapper_Res_Field ' +
                'AutoIt3Wrapper_Res_File_Add AutoIt3Wrapper_Res_FileVersion ' +
                'AutoIt3Wrapper_Res_FileVersion_AutoIncrement ' +
                'AutoIt3Wrapper_Res_Icon_Add AutoIt3Wrapper_Res_Language ' +
                'AutoIt3Wrapper_Res_LegalCopyright ' +
                'AutoIt3Wrapper_Res_ProductVersion ' +
                'AutoIt3Wrapper_Res_requestedExecutionLevel ' +
                'AutoIt3Wrapper_Res_SaveSource AutoIt3Wrapper_Run_After ' +
                'AutoIt3Wrapper_Run_Au3Check AutoIt3Wrapper_Run_Au3Stripper ' +
                'AutoIt3Wrapper_Run_Before AutoIt3Wrapper_Run_Debug_Mode ' +
                'AutoIt3Wrapper_Run_SciTE_Minimized ' +
                'AutoIt3Wrapper_Run_SciTE_OutputPane_Minimized ' +
                'AutoIt3Wrapper_Run_Tidy AutoIt3Wrapper_ShowProgress ' +
                'AutoIt3Wrapper_Testing AutoIt3Wrapper_Tidy_Stop_OnError ' +
                'AutoIt3Wrapper_UPX_Parameters AutoIt3Wrapper_UseUPX ' +
                'AutoIt3Wrapper_UseX64 AutoIt3Wrapper_Version ' +
                'AutoIt3Wrapper_Versioning AutoIt3Wrapper_Versioning_Parameters ' +
                'Tidy_Off Tidy_On Tidy_Parameters EndRegion Region',
            contains: [{
                    begin: /\\\n/,
                    relevance: 0
                }, {
                    beginKeywords: 'include',
                    end: '$',
                    contains: [
                        STRING, {
                            className: 'string',
                            variants: [{
                                begin: '<',
                                end: '>'
                            }, {
                                begin: /"/,
                                end: /"/,
                                contains: [{
                                    begin: /""/,
                                    relevance: 0
                                }]
                            }, {
                                begin: /'/,
                                end: /'/,
                                contains: [{
                                    begin: /''/,
                                    relevance: 0
                                }]
                            }]
                        }
                    ]
                },
                STRING,
                COMMENT
            ]
        },

        CONSTANT = {
            className: 'constant',
            // begin: '@',
            // end: '$',
            // keywords: 'AppDataCommonDir AppDataDir AutoItExe AutoItPID AutoItVersion AutoItX64 COM_EventObj CommonFilesDir Compiled ComputerName ComSpec CPUArch CR CRLF DesktopCommonDir DesktopDepth DesktopDir DesktopHeight DesktopRefresh DesktopWidth DocumentsCommonDir error exitCode exitMethod extended FavoritesCommonDir FavoritesDir GUI_CtrlHandle GUI_CtrlId GUI_DragFile GUI_DragId GUI_DropId GUI_WinHandle HomeDrive HomePath HomeShare HotKeyPressed HOUR IPAddress1 IPAddress2 IPAddress3 IPAddress4 KBLayout LF LocalAppDataDir LogonDNSDomain LogonDomain LogonServer MDAY MIN MON MSEC MUILang MyDocumentsDir NumParams OSArch OSBuild OSLang OSServicePack OSType OSVersion ProgramFilesDir ProgramsCommonDir ProgramsDir ScriptDir ScriptFullPath ScriptLineNumber ScriptName SEC StartMenuCommonDir StartMenuDir StartupCommonDir StartupDir SW_DISABLE SW_ENABLE SW_HIDE SW_LOCK SW_MAXIMIZE SW_MINIMIZE SW_RESTORE SW_SHOW SW_SHOWDEFAULT SW_SHOWMAXIMIZED SW_SHOWMINIMIZED SW_SHOWMINNOACTIVE SW_SHOWNA SW_SHOWNOACTIVATE SW_SHOWNORMAL SW_UNLOCK SystemDir TAB TempDir TRAY_ID TrayIconFlashing TrayIconVisible UserName UserProfileDir WDAY WindowsDir WorkingDir YDAY YEAR',
            // relevance: 5
            begin: '@[A-z0-9_]+'
        },

        FUNCTION = {
            className: 'function',
            beginKeywords: 'Func',
            end: '$',
            excludeEnd: true,
            illegal: '\\$|\\[|%',
            contains: [
                hljs.UNDERSCORE_TITLE_MODE, {
                    className: 'params',
                    begin: '\\(',
                    end: '\\)',
                    contains: [
                        VARIABLE,
                        STRING,
                        NUMBER
                    ]
                }
            ]
        };

    return {
        case_insensitive: true,
        illegal: /\/\*/,
        keywords: {
            keyword: KEYWORDS,
            built_in: BUILT_IN,
            literal: LITERAL
        },
        contains: [
            COMMENT,
            VARIABLE,
            STRING,
            NUMBER,
            PREPROCESSOR,
            CONSTANT,
            FUNCTION
        ]
    }
});

hljs.registerLanguage('avrasm', function(hljs) {
  return {
    case_insensitive: true,
    lexemes: '\\.?' + hljs.IDENT_RE,
    keywords: {
      keyword:
        /* mnemonic */
        'adc add adiw and andi asr bclr bld brbc brbs brcc brcs break breq brge brhc brhs ' +
        'brid brie brlo brlt brmi brne brpl brsh brtc brts brvc brvs bset bst call cbi cbr ' +
        'clc clh cli cln clr cls clt clv clz com cp cpc cpi cpse dec eicall eijmp elpm eor ' +
        'fmul fmuls fmulsu icall ijmp in inc jmp ld ldd ldi lds lpm lsl lsr mov movw mul ' +
        'muls mulsu neg nop or ori out pop push rcall ret reti rjmp rol ror sbc sbr sbrc sbrs ' +
        'sec seh sbi sbci sbic sbis sbiw sei sen ser ses set sev sez sleep spm st std sts sub ' +
        'subi swap tst wdr',
      built_in:
        /* general purpose registers */
        'r0 r1 r2 r3 r4 r5 r6 r7 r8 r9 r10 r11 r12 r13 r14 r15 r16 r17 r18 r19 r20 r21 r22 ' +
        'r23 r24 r25 r26 r27 r28 r29 r30 r31 x|0 xh xl y|0 yh yl z|0 zh zl ' +
        /* IO Registers (ATMega128) */
        'ucsr1c udr1 ucsr1a ucsr1b ubrr1l ubrr1h ucsr0c ubrr0h tccr3c tccr3a tccr3b tcnt3h ' +
        'tcnt3l ocr3ah ocr3al ocr3bh ocr3bl ocr3ch ocr3cl icr3h icr3l etimsk etifr tccr1c ' +
        'ocr1ch ocr1cl twcr twdr twar twsr twbr osccal xmcra xmcrb eicra spmcsr spmcr portg ' +
        'ddrg ping portf ddrf sreg sph spl xdiv rampz eicrb eimsk gimsk gicr eifr gifr timsk ' +
        'tifr mcucr mcucsr tccr0 tcnt0 ocr0 assr tccr1a tccr1b tcnt1h tcnt1l ocr1ah ocr1al ' +
        'ocr1bh ocr1bl icr1h icr1l tccr2 tcnt2 ocr2 ocdr wdtcr sfior eearh eearl eedr eecr ' +
        'porta ddra pina portb ddrb pinb portc ddrc pinc portd ddrd pind spdr spsr spcr udr0 ' +
        'ucsr0a ucsr0b ubrr0l acsr admux adcsr adch adcl porte ddre pine pinf',
      preprocessor:
        '.byte .cseg .db .def .device .dseg .dw .endmacro .equ .eseg .exit .include .list ' +
        '.listmac .macro .nolist .org .set'
    },
    contains: [
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.COMMENT(
        ';',
        '$',
        {
          relevance: 0
        }
      ),
      hljs.C_NUMBER_MODE, // 0x..., decimal, float
      hljs.BINARY_NUMBER_MODE, // 0b...
      {
        className: 'number',
        begin: '\\b(\\$[a-zA-Z0-9]+|0o[0-7]+)' // $..., 0o...
      },
      hljs.QUOTE_STRING_MODE,
      {
        className: 'string',
        begin: '\'', end: '[^\\\\]\'',
        illegal: '[^\\\\][^\']'
      },
      {className: 'label',  begin: '^[A-Za-z0-9_.$]+:'},
      {className: 'preprocessor', begin: '#', end: '$'},
      {  // подстановка в «.macro»
        className: 'localvars',
        begin: '@[0-9]+'
      }
    ]
  };
});

hljs.registerLanguage('axapta', function(hljs) {
  return {
    keywords: 'false int abstract private char boolean static null if for true ' +
      'while long throw finally protected final return void enum else ' +
      'break new catch byte super case short default double public try this switch ' +
      'continue reverse firstfast firstonly forupdate nofetch sum avg minof maxof count ' +
      'order group by asc desc index hint like dispaly edit client server ttsbegin ' +
      'ttscommit str real date container anytype common div mod',
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      hljs.C_NUMBER_MODE,
      {
        className: 'preprocessor',
        begin: '#', end: '$'
      },
      {
        className: 'class',
        beginKeywords: 'class interface', end: '{', excludeEnd: true,
        illegal: ':',
        contains: [
          {beginKeywords: 'extends implements'},
          hljs.UNDERSCORE_TITLE_MODE
        ]
      }
    ]
  };
});

hljs.registerLanguage('bash', function(hljs) {
  var VAR = {
    className: 'variable',
    variants: [
      {begin: /\$[\w\d#@][\w\d_]*/},
      {begin: /\$\{(.*?)}/}
    ]
  };
  var QUOTE_STRING = {
    className: 'string',
    begin: /"/, end: /"/,
    contains: [
      hljs.BACKSLASH_ESCAPE,
      VAR,
      {
        className: 'variable',
        begin: /\$\(/, end: /\)/,
        contains: [hljs.BACKSLASH_ESCAPE]
      }
    ]
  };
  var APOS_STRING = {
    className: 'string',
    begin: /'/, end: /'/
  };

  return {
    aliases: ['sh', 'zsh'],
    lexemes: /-?[a-z\.]+/,
    keywords: {
      keyword:
        'if then else elif fi for while in do done case esac function',
      literal:
        'true false',
      built_in:
        // Shell built-ins
        // http://www.gnu.org/software/bash/manual/html_node/Shell-Builtin-Commands.html
        'break cd continue eval exec exit export getopts hash pwd readonly return shift test times ' +
        'trap umask unset ' +
        // Bash built-ins
        'alias bind builtin caller command declare echo enable help let local logout mapfile printf ' +
        'read readarray source type typeset ulimit unalias ' +
        // Shell modifiers
        'set shopt ' +
        // Zsh built-ins
        'autoload bg bindkey bye cap chdir clone comparguments compcall compctl compdescribe compfiles ' +
        'compgroups compquote comptags comptry compvalues dirs disable disown echotc echoti emulate ' +
        'fc fg float functions getcap getln history integer jobs kill limit log noglob popd print ' +
        'pushd pushln rehash sched setcap setopt stat suspend ttyctl unfunction unhash unlimit ' +
        'unsetopt vared wait whence where which zcompile zformat zftp zle zmodload zparseopts zprof ' +
        'zpty zregexparse zsocket zstyle ztcp',
      operator:
        '-ne -eq -lt -gt -f -d -e -s -l -a' // relevance booster
    },
    contains: [
      {
        className: 'shebang',
        begin: /^#![^\n]+sh\s*$/,
        relevance: 10
      },
      {
        className: 'function',
        begin: /\w[\w\d_]*\s*\(\s*\)\s*\{/,
        returnBegin: true,
        contains: [hljs.inherit(hljs.TITLE_MODE, {begin: /\w[\w\d_]*/})],
        relevance: 0
      },
      hljs.HASH_COMMENT_MODE,
      hljs.NUMBER_MODE,
      QUOTE_STRING,
      APOS_STRING,
      VAR
    ]
  };
});

hljs.registerLanguage('brainfuck', function(hljs){
  var LITERAL = {
    className: 'literal',
    begin: '[\\+\\-]',
    relevance: 0
  };
  return {
    aliases: ['bf'],
    contains: [
      hljs.COMMENT(
        '[^\\[\\]\\.,\\+\\-<> \r\n]',
        '[\\[\\]\\.,\\+\\-<> \r\n]',
        {
          returnEnd: true,
          relevance: 0
        }
      ),
      {
        className: 'title',
        begin: '[\\[\\]]',
        relevance: 0
      },
      {
        className: 'string',
        begin: '[\\.,]',
        relevance: 0
      },
      {
        // this mode works as the only relevance counter
        begin: /\+\+|\-\-/, returnBegin: true,
        contains: [LITERAL]
      },
      LITERAL
    ]
  };
});

hljs.registerLanguage('cal', function(hljs) {
  var KEYWORDS =
    'div mod in and or not xor asserterror begin case do downto else end exit for if of repeat then to ' +
    'until while with var';
  var LITERALS = 'false true';
  var COMMENT_MODES = [
    hljs.C_LINE_COMMENT_MODE,
    hljs.COMMENT(
      /\{/,
      /\}/,
      {
        relevance: 0
      }
    ),
    hljs.COMMENT(
      /\(\*/,
      /\*\)/,
      {
        relevance: 10
      }
    )
  ];
  var STRING = {
    className: 'string',
    begin: /'/, end: /'/,
    contains: [{begin: /''/}]
  };
  var CHAR_STRING = {
    className: 'string', begin: /(#\d+)+/
  };
  var DATE = {
      className: 'date',
      begin: '\\b\\d+(\\.\\d+)?(DT|D|T)',
      relevance: 0
  };
  var DBL_QUOTED_VARIABLE = {
      className: 'variable',
      begin: '"',
      end: '"'
  };

  var PROCEDURE = {
    className: 'function',
    beginKeywords: 'procedure', end: /[:;]/,
    keywords: 'procedure|10',
    contains: [
      hljs.TITLE_MODE,
      {
        className: 'params',
        begin: /\(/, end: /\)/,
        keywords: KEYWORDS,
        contains: [STRING, CHAR_STRING]
      }
    ].concat(COMMENT_MODES)
  };

  var OBJECT = {
    className: 'class',
    begin: 'OBJECT (Table|Form|Report|Dataport|Codeunit|XMLport|MenuSuite|Page|Query) (\\d+) ([^\\r\\n]+)',
    returnBegin: true,
    contains: [
      hljs.TITLE_MODE,
        PROCEDURE
    ]
  };

  return {
    case_insensitive: true,
    keywords: { keyword: KEYWORDS, literal: LITERALS },
    illegal: /\/\*/,
    contains: [
      STRING, CHAR_STRING,
      DATE, DBL_QUOTED_VARIABLE,
      hljs.NUMBER_MODE,
      OBJECT,
      PROCEDURE
    ]
  };
});

hljs.registerLanguage('capnproto', function(hljs) {
  return {
    aliases: ['capnp'],
    keywords: {
      keyword:
        'struct enum interface union group import using const annotation extends in of on as with from fixed',
      built_in:
        'Void Bool Int8 Int16 Int32 Int64 UInt8 UInt16 UInt32 UInt64 Float32 Float64 ' +
        'Text Data AnyPointer AnyStruct Capability List',
      literal:
        'true false'
    },
    contains: [
      hljs.QUOTE_STRING_MODE,
      hljs.NUMBER_MODE,
      hljs.HASH_COMMENT_MODE,
      {
        className: 'shebang',
        begin: /@0x[\w\d]{16};/,
        illegal: /\n/
      },
      {
        className: 'number',
        begin: /@\d+\b/
      },
      {
        className: 'class',
        beginKeywords: 'struct enum', end: /\{/,
        illegal: /\n/,
        contains: [
          hljs.inherit(hljs.TITLE_MODE, {
            starts: {endsWithParent: true, excludeEnd: true} // hack: eating everything after the first title
          })
        ]
      },
      {
        className: 'class',
        beginKeywords: 'interface', end: /\{/,
        illegal: /\n/,
        contains: [
          hljs.inherit(hljs.TITLE_MODE, {
            starts: {endsWithParent: true, excludeEnd: true} // hack: eating everything after the first title
          })
        ]
      }
    ]
  };
});

hljs.registerLanguage('ceylon', function(hljs) {
  // 2.3. Identifiers and keywords
  var KEYWORDS =
    'assembly module package import alias class interface object given value ' +
    'assign void function new of extends satisfies abstracts in out return ' +
    'break continue throw assert dynamic if else switch case for while try ' +
    'catch finally then let this outer super is exists nonempty';
  // 7.4.1 Declaration Modifiers
  var DECLARATION_MODIFIERS =
    'shared abstract formal default actual variable late native deprecated' +
    'final sealed annotation suppressWarnings small';
  // 7.4.2 Documentation
  var DOCUMENTATION =
    'doc by license see throws tagged';
  var LANGUAGE_ANNOTATIONS = DECLARATION_MODIFIERS + ' ' + DOCUMENTATION;
  var SUBST = {
    className: 'subst', excludeBegin: true, excludeEnd: true,
    begin: /``/, end: /``/,
    keywords: KEYWORDS,
    relevance: 10
  };
  var EXPRESSIONS = [
    {
      // verbatim string
      className: 'string',
      begin: '"""',
      end: '"""',
      relevance: 10
    },
    {
      // string literal or template
      className: 'string',
      begin: '"', end: '"',
      contains: [SUBST]
    },
    {
      // character literal
      className: 'string',
      begin: "'",
      end: "'"
    },
    {
      // numeric literal
      className: 'number',
      begin: '#[0-9a-fA-F_]+|\\$[01_]+|[0-9_]+(?:\\.[0-9_](?:[eE][+-]?\\d+)?)?[kMGTPmunpf]?',
      relevance: 0
    }
  ];
  SUBST.contains = EXPRESSIONS;

  return {
    keywords: {
      keyword: KEYWORDS,
      annotation: LANGUAGE_ANNOTATIONS
    },
    illegal: '\\$[^01]|#[^0-9a-fA-F]',
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.COMMENT('/\\*', '\\*/', {contains: ['self']}),
      {
        // compiler annotation
        className: 'annotation',
        begin: '@[a-z]\\w*(?:\\:\"[^\"]*\")?'
      }
    ].concat(EXPRESSIONS)
  };
});

hljs.registerLanguage('clojure', function(hljs) {
  var keywords = {
    built_in:
      // Clojure keywords
      'def defonce cond apply if-not if-let if not not= = < > <= >= == + / * - rem '+
      'quot neg? pos? delay? symbol? keyword? true? false? integer? empty? coll? list? '+
      'set? ifn? fn? associative? sequential? sorted? counted? reversible? number? decimal? '+
      'class? distinct? isa? float? rational? reduced? ratio? odd? even? char? seq? vector? '+
      'string? map? nil? contains? zero? instance? not-every? not-any? libspec? -> ->> .. . '+
      'inc compare do dotimes mapcat take remove take-while drop letfn drop-last take-last '+
      'drop-while while intern condp case reduced cycle split-at split-with repeat replicate '+
      'iterate range merge zipmap declare line-seq sort comparator sort-by dorun doall nthnext '+
      'nthrest partition eval doseq await await-for let agent atom send send-off release-pending-sends '+
      'add-watch mapv filterv remove-watch agent-error restart-agent set-error-handler error-handler '+
      'set-error-mode! error-mode shutdown-agents quote var fn loop recur throw try monitor-enter '+
      'monitor-exit defmacro defn defn- macroexpand macroexpand-1 for dosync and or '+
      'when when-not when-let comp juxt partial sequence memoize constantly complement identity assert '+
      'peek pop doto proxy defstruct first rest cons defprotocol cast coll deftype defrecord last butlast '+
      'sigs reify second ffirst fnext nfirst nnext defmulti defmethod meta with-meta ns in-ns create-ns import '+
      'refer keys select-keys vals key val rseq name namespace promise into transient persistent! conj! '+
      'assoc! dissoc! pop! disj! use class type num float double short byte boolean bigint biginteger '+
      'bigdec print-method print-dup throw-if printf format load compile get-in update-in pr pr-on newline '+
      'flush read slurp read-line subvec with-open memfn time re-find re-groups rand-int rand mod locking '+
      'assert-valid-fdecl alias resolve ref deref refset swap! reset! set-validator! compare-and-set! alter-meta! '+
      'reset-meta! commute get-validator alter ref-set ref-history-count ref-min-history ref-max-history ensure sync io! '+
      'new next conj set! to-array future future-call into-array aset gen-class reduce map filter find empty '+
      'hash-map hash-set sorted-map sorted-map-by sorted-set sorted-set-by vec vector seq flatten reverse assoc dissoc list '+
      'disj get union difference intersection extend extend-type extend-protocol int nth delay count concat chunk chunk-buffer '+
      'chunk-append chunk-first chunk-rest max min dec unchecked-inc-int unchecked-inc unchecked-dec-inc unchecked-dec unchecked-negate '+
      'unchecked-add-int unchecked-add unchecked-subtract-int unchecked-subtract chunk-next chunk-cons chunked-seq? prn vary-meta '+
      'lazy-seq spread list* str find-keyword keyword symbol gensym force rationalize'
   };

  var SYMBOLSTART = 'a-zA-Z_\\-!.?+*=<>&#\'';
  var SYMBOL_RE = '[' + SYMBOLSTART + '][' + SYMBOLSTART + '0-9/;:]*';
  var SIMPLE_NUMBER_RE = '[-+]?\\d+(\\.\\d+)?';

  var SYMBOL = {
    begin: SYMBOL_RE,
    relevance: 0
  };
  var NUMBER = {
    className: 'number', begin: SIMPLE_NUMBER_RE,
    relevance: 0
  };
  var STRING = hljs.inherit(hljs.QUOTE_STRING_MODE, {illegal: null});
  var COMMENT = hljs.COMMENT(
    ';',
    '$',
    {
      relevance: 0
    }
  );
  var LITERAL = {
    className: 'literal',
    begin: /\b(true|false|nil)\b/
  };
  var COLLECTION = {
    className: 'collection',
    begin: '[\\[\\{]', end: '[\\]\\}]'
  };
  var HINT = {
    className: 'comment',
    begin: '\\^' + SYMBOL_RE
  };
  var HINT_COL = hljs.COMMENT('\\^\\{', '\\}');
  var KEY = {
    className: 'attribute',
    begin: '[:]' + SYMBOL_RE
  };
  var LIST = {
    className: 'list',
    begin: '\\(', end: '\\)'
  };
  var BODY = {
    endsWithParent: true,
    relevance: 0
  };
  var NAME = {
    keywords: keywords,
    lexemes: SYMBOL_RE,
    className: 'keyword', begin: SYMBOL_RE,
    starts: BODY
  };
  var DEFAULT_CONTAINS = [LIST, STRING, HINT, HINT_COL, COMMENT, KEY, COLLECTION, NUMBER, LITERAL, SYMBOL];

  LIST.contains = [hljs.COMMENT('comment', ''), NAME, BODY];
  BODY.contains = DEFAULT_CONTAINS;
  COLLECTION.contains = DEFAULT_CONTAINS;

  return {
    aliases: ['clj'],
    illegal: /\S/,
    contains: [LIST, STRING, HINT, HINT_COL, COMMENT, KEY, COLLECTION, NUMBER, LITERAL]
  }
});

hljs.registerLanguage('clojure-repl', function(hljs) {
  return {
    contains: [
      {
        className: 'prompt',
        begin: /^([\w.-]+|\s*#_)=>/,
        starts: {
          end: /$/,
          subLanguage: 'clojure'
        }
      }
    ]
  }
});

hljs.registerLanguage('cmake', function(hljs) {
  return {
    aliases: ['cmake.in'],
    case_insensitive: true,
    keywords: {
      keyword:
        'add_custom_command add_custom_target add_definitions add_dependencies ' +
        'add_executable add_library add_subdirectory add_test aux_source_directory ' +
        'break build_command cmake_minimum_required cmake_policy configure_file ' +
        'create_test_sourcelist define_property else elseif enable_language enable_testing ' +
        'endforeach endfunction endif endmacro endwhile execute_process export find_file ' +
        'find_library find_package find_path find_program fltk_wrap_ui foreach function ' +
        'get_cmake_property get_directory_property get_filename_component get_property ' +
        'get_source_file_property get_target_property get_test_property if include ' +
        'include_directories include_external_msproject include_regular_expression install ' +
        'link_directories load_cache load_command macro mark_as_advanced message option ' +
        'output_required_files project qt_wrap_cpp qt_wrap_ui remove_definitions return ' +
        'separate_arguments set set_directory_properties set_property ' +
        'set_source_files_properties set_target_properties set_tests_properties site_name ' +
        'source_group string target_link_libraries try_compile try_run unset variable_watch ' +
        'while build_name exec_program export_library_dependencies install_files ' +
        'install_programs install_targets link_libraries make_directory remove subdir_depends ' +
        'subdirs use_mangled_mesa utility_source variable_requires write_file ' +
        'qt5_use_modules qt5_use_package qt5_wrap_cpp on off true false and or',
      operator:
        'equal less greater strless strgreater strequal matches'
    },
    contains: [
      {
        className: 'envvar',
        begin: '\\${', end: '}'
      },
      hljs.HASH_COMMENT_MODE,
      hljs.QUOTE_STRING_MODE,
      hljs.NUMBER_MODE
    ]
  };
});

hljs.registerLanguage('coffeescript', function(hljs) {
  var KEYWORDS = {
    keyword:
      // JS keywords
      'in if for while finally new do return else break catch instanceof throw try this ' +
      'switch continue typeof delete debugger super ' +
      // Coffee keywords
      'then unless until loop of by when and or is isnt not',
    literal:
      // JS literals
      'true false null undefined ' +
      // Coffee literals
      'yes no on off',
    built_in:
      'npm require console print module global window document'
  };
  var JS_IDENT_RE = '[A-Za-z$_][0-9A-Za-z$_]*';
  var SUBST = {
    className: 'subst',
    begin: /#\{/, end: /}/,
    keywords: KEYWORDS
  };
  var EXPRESSIONS = [
    hljs.BINARY_NUMBER_MODE,
    hljs.inherit(hljs.C_NUMBER_MODE, {starts: {end: '(\\s*/)?', relevance: 0}}), // a number tries to eat the following slash to prevent treating it as a regexp
    {
      className: 'string',
      variants: [
        {
          begin: /'''/, end: /'''/,
          contains: [hljs.BACKSLASH_ESCAPE]
        },
        {
          begin: /'/, end: /'/,
          contains: [hljs.BACKSLASH_ESCAPE]
        },
        {
          begin: /"""/, end: /"""/,
          contains: [hljs.BACKSLASH_ESCAPE, SUBST]
        },
        {
          begin: /"/, end: /"/,
          contains: [hljs.BACKSLASH_ESCAPE, SUBST]
        }
      ]
    },
    {
      className: 'regexp',
      variants: [
        {
          begin: '///', end: '///',
          contains: [SUBST, hljs.HASH_COMMENT_MODE]
        },
        {
          begin: '//[gim]*',
          relevance: 0
        },
        {
          // regex can't start with space to parse x / 2 / 3 as two divisions
          // regex can't start with *, and it supports an "illegal" in the main mode
          begin: /\/(?![ *])(\\\/|.)*?\/[gim]*(?=\W|$)/
        }
      ]
    },
    {
      className: 'property',
      begin: '@' + JS_IDENT_RE
    },
    {
      begin: '`', end: '`',
      excludeBegin: true, excludeEnd: true,
      subLanguage: 'javascript'
    }
  ];
  SUBST.contains = EXPRESSIONS;

  var TITLE = hljs.inherit(hljs.TITLE_MODE, {begin: JS_IDENT_RE});
  var PARAMS_RE = '(\\(.*\\))?\\s*\\B[-=]>';
  var PARAMS = {
    className: 'params',
    begin: '\\([^\\(]', returnBegin: true,
    /* We need another contained nameless mode to not have every nested
    pair of parens to be called "params" */
    contains: [{
      begin: /\(/, end: /\)/,
      keywords: KEYWORDS,
      contains: ['self'].concat(EXPRESSIONS)
    }]
  };

  return {
    aliases: ['coffee', 'cson', 'iced'],
    keywords: KEYWORDS,
    illegal: /\/\*/,
    contains: EXPRESSIONS.concat([
      hljs.COMMENT('###', '###'),
      hljs.HASH_COMMENT_MODE,
      {
        className: 'function',
        begin: '^\\s*' + JS_IDENT_RE + '\\s*=\\s*' + PARAMS_RE, end: '[-=]>',
        returnBegin: true,
        contains: [TITLE, PARAMS]
      },
      {
        // anonymous function start
        begin: /[:\(,=]\s*/,
        relevance: 0,
        contains: [
          {
            className: 'function',
            begin: PARAMS_RE, end: '[-=]>',
            returnBegin: true,
            contains: [PARAMS]
          }
        ]
      },
      {
        className: 'class',
        beginKeywords: 'class',
        end: '$',
        illegal: /[:="\[\]]/,
        contains: [
          {
            beginKeywords: 'extends',
            endsWithParent: true,
            illegal: /[:="\[\]]/,
            contains: [TITLE]
          },
          TITLE
        ]
      },
      {
        className: 'attribute',
        begin: JS_IDENT_RE + ':', end: ':',
        returnBegin: true, returnEnd: true,
        relevance: 0
      }
    ])
  };
});

hljs.registerLanguage('cpp', function(hljs) {
  var CPP_PRIMATIVE_TYPES = {
    className: 'keyword',
    begin: '\\b[a-z\\d_]*_t\\b'
  };

  var STRINGS = {
    className: 'string',
    variants: [
      hljs.inherit(hljs.QUOTE_STRING_MODE, { begin: '((u8?|U)|L)?"' }),
      {
        begin: '(u8?|U)?R"', end: '"',
        contains: [hljs.BACKSLASH_ESCAPE]
      },
      {
        begin: '\'\\\\?.', end: '\'',
        illegal: '.'
      }
    ]
  };

  var NUMBERS = {
    className: 'number',
    variants: [
      { begin: '\\b(\\d+(\\.\\d*)?|\\.\\d+)(u|U|l|L|ul|UL|f|F)' },
      { begin: hljs.C_NUMBER_RE }
    ]
  };

  var PREPROCESSOR =       {
    className: 'preprocessor',
    begin: '#', end: '$',
    keywords: 'if else elif endif define undef warning error line ' +
              'pragma ifdef ifndef',
    contains: [
      {
        begin: /\\\n/, relevance: 0
      },
      {
        beginKeywords: 'include', end: '$',
        contains: [
          STRINGS,
          {
            className: 'string',
            begin: '<', end: '>',
            illegal: '\\n',
          }
        ]
      },
      STRINGS,
      NUMBERS,
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE
    ]
  };

  var FUNCTION_TITLE = hljs.IDENT_RE + '\\s*\\(';

  var CPP_KEYWORDS = {
    keyword: 'int float while private char catch export virtual operator sizeof ' +
      'dynamic_cast|10 typedef const_cast|10 const struct for static_cast|10 union namespace ' +
      'unsigned long volatile static protected bool template mutable if public friend ' +
      'do goto auto void enum else break extern using class asm case typeid ' +
      'short reinterpret_cast|10 default double register explicit signed typename try this ' +
      'switch continue inline delete alignof constexpr decltype ' +
      'noexcept static_assert thread_local restrict _Bool complex _Complex _Imaginary ' +
      'atomic_bool atomic_char atomic_schar ' +
      'atomic_uchar atomic_short atomic_ushort atomic_int atomic_uint atomic_long atomic_ulong atomic_llong ' +
      'atomic_ullong',
    built_in: 'std string cin cout cerr clog stdin stdout stderr stringstream istringstream ostringstream ' +
      'auto_ptr deque list queue stack vector map set bitset multiset multimap unordered_set ' +
      'unordered_map unordered_multiset unordered_multimap array shared_ptr abort abs acos ' +
      'asin atan2 atan calloc ceil cosh cos exit exp fabs floor fmod fprintf fputs free frexp ' +
      'fscanf isalnum isalpha iscntrl isdigit isgraph islower isprint ispunct isspace isupper ' +
      'isxdigit tolower toupper labs ldexp log10 log malloc realloc memchr memcmp memcpy memset modf pow ' +
      'printf putchar puts scanf sinh sin snprintf sprintf sqrt sscanf strcat strchr strcmp ' +
      'strcpy strcspn strlen strncat strncmp strncpy strpbrk strrchr strspn strstr tanh tan ' +
      'vfprintf vprintf vsprintf',
    literal: 'true false nullptr NULL'
  };

  return {
    aliases: ['c', 'cc', 'h', 'c++', 'h++', 'hpp'],
    keywords: CPP_KEYWORDS,
    illegal: '</',
    contains: [
      CPP_PRIMATIVE_TYPES,
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      NUMBERS,
      STRINGS,
      PREPROCESSOR,
      {
        begin: '\\b(deque|list|queue|stack|vector|map|set|bitset|multiset|multimap|unordered_map|unordered_set|unordered_multiset|unordered_multimap|array)\\s*<', end: '>',
        keywords: CPP_KEYWORDS,
        contains: ['self', CPP_PRIMATIVE_TYPES]
      },
      {
        begin: hljs.IDENT_RE + '::',
        keywords: CPP_KEYWORDS
      },
      {
        // Expression keywords prevent 'keyword Name(...) or else if(...)' from
        // being recognized as a function definition
        beginKeywords: 'new throw return else',
        relevance: 0
      },
      {
        className: 'function',
        begin: '(' + hljs.IDENT_RE + '[\\*&\\s]+)+' + FUNCTION_TITLE,
        returnBegin: true, end: /[{;=]/,
        excludeEnd: true,
        keywords: CPP_KEYWORDS,
        illegal: /[^\w\s\*&]/,
        contains: [
          {
            begin: FUNCTION_TITLE, returnBegin: true,
            contains: [hljs.TITLE_MODE],
            relevance: 0
          },
          {
            className: 'params',
            begin: /\(/, end: /\)/,
            keywords: CPP_KEYWORDS,
            relevance: 0,
            contains: [
              hljs.C_LINE_COMMENT_MODE,
              hljs.C_BLOCK_COMMENT_MODE,
              STRINGS,
              NUMBERS
            ]
          },
          hljs.C_LINE_COMMENT_MODE,
          hljs.C_BLOCK_COMMENT_MODE,
          PREPROCESSOR
        ]
      }
    ]
  };
});

hljs.registerLanguage('crmsh', function(hljs) {
  var RESOURCES = 'primitive rsc_template';

  var COMMANDS = 'group clone ms master location colocation order fencing_topology ' +
      'rsc_ticket acl_target acl_group user role ' +
      'tag xml';

  var PROPERTY_SETS = 'property rsc_defaults op_defaults';

  var KEYWORDS = 'params meta operations op rule attributes utilization';

  var OPERATORS = 'read write deny defined not_defined in_range date spec in ' +
      'ref reference attribute type xpath version and or lt gt tag ' +
      'lte gte eq ne \\';

  var TYPES = 'number string';

  var LITERALS = 'Master Started Slave Stopped start promote demote stop monitor true false';

  return {
    aliases: ['crm', 'pcmk'],
    case_insensitive: true,
    keywords: {
      keyword: KEYWORDS,
      operator: OPERATORS,
      type: TYPES,
      literal: LITERALS
    },
    contains: [
      hljs.HASH_COMMENT_MODE,
      {
        beginKeywords: 'node',
        starts: {
          className: 'identifier',
          end: '\\s*([\\w_-]+:)?',
          starts: {
            className: 'title',
            end: '\\s*[\\$\\w_][\\w_-]*'
          }
        }
      },
      {
        beginKeywords: RESOURCES,
        starts: {
          className: 'title',
          end: '\\s*[\\$\\w_][\\w_-]*',
          starts: {
            className: 'pragma',
            end: '\\s*@?[\\w_][\\w_\\.:-]*',
          }
        }
      },
      {
        begin: '\\b(' + COMMANDS.split(' ').join('|') + ')\\s+',
        keywords: COMMANDS,
        starts: {
          className: 'title',
          end: '[\\$\\w_][\\w_-]*',
        }
      },
      {
        beginKeywords: PROPERTY_SETS,
        starts: {
          className: 'title',
          end: '\\s*([\\w_-]+:)?'
        }
      },
      hljs.QUOTE_STRING_MODE,
      {
        className: 'pragma',
        begin: '(ocf|systemd|service|lsb):[\\w_:-]+',
        relevance: 0
      },
      {
        className: 'number',
        begin: '\\b\\d+(\\.\\d+)?(ms|s|h|m)?',
        relevance: 0
      },
      {
        className: 'number',
        begin: '[-]?(infinity|inf)',
        relevance: 0
      },
      {
        className: 'variable',
        begin: /([A-Za-z\$_\#][\w_-]+)=/,
        relevance: 0
      },
      {
        className: 'tag',
        begin: '</?',
        end: '/?>',
        relevance: 0
      }
    ]
  };
});

hljs.registerLanguage('crystal', function(hljs) {
  var NUM_SUFFIX = '(_[uif](8|16|32|64))?';
  var CRYSTAL_IDENT_RE = '[a-zA-Z_]\\w*[!?=]?';
  var RE_STARTER = '!=|!==|%|%=|&|&&|&=|\\*|\\*=|\\+|\\+=|,|-|-=|/=|/|:|;|<<|<<=|<=|<|===|==|=|>>>=|>>=|>=|>>>|' +
    '>>|>|\\[|\\{|\\(|\\^|\\^=|\\||\\|=|\\|\\||~';
  var CRYSTAL_METHOD_RE = '[a-zA-Z_]\\w*[!?=]?|[-+~]\\@|<<|>>|=~|===?|<=>|[<>]=?|\\*\\*|[-/+%^&*~`|]|\\[\\][=?]?';
  var CRYSTAL_KEYWORDS = {
    keyword:
      'abstract alias as asm begin break case class def do else elsif end ensure enum extend for fun if ifdef ' +
      'include instance_sizeof is_a? lib macro module next of out pointerof private protected rescue responds_to? ' +
      'return require self sizeof struct super then type typeof union unless until when while with yield ' +
      '__DIR__ __FILE__ __LINE__',
    literal: 'false nil true'
  };
  var SUBST = {
    className: 'subst',
    begin: '#{', end: '}',
    keywords: CRYSTAL_KEYWORDS
  };
  var EXPANSION = {
    className: 'expansion',
    variants: [
      {begin: '\\{\\{', end: '\\}\\}'},
      {begin: '\\{%', end: '%\\}'}
    ],
    keywords: CRYSTAL_KEYWORDS,
    relevance: 10
  };

  function recursiveParen(begin, end) {
    var
    contains = [{begin: begin, end: end}];
    contains[0].contains = contains;
    return contains;
  }
  var STRING = {
    className: 'string',
    contains: [hljs.BACKSLASH_ESCAPE, SUBST],
    variants: [
      {begin: /'/, end: /'/},
      {begin: /"/, end: /"/},
      {begin: /`/, end: /`/},
      {begin: '%w?\\(', end: '\\)', contains: recursiveParen('\\(', '\\)')},
      {begin: '%w?\\[', end: '\\]', contains: recursiveParen('\\[', '\\]')},
      {begin: '%w?{', end: '}', contains: recursiveParen('{', '}')},
      {begin: '%w?<', end: '>', contains: recursiveParen('<', '>')},
      {begin: '%w?/', end: '/'},
      {begin: '%w?%', end: '%'},
      {begin: '%w?-', end: '-'},
      {begin: '%w?\\|', end: '\\|'},
    ],
    relevance: 0,
  };
  var REGEXP = {
    begin: '(' + RE_STARTER + ')\\s*',
    contains: [
      {
        className: 'regexp',
        contains: [hljs.BACKSLASH_ESCAPE, SUBST],
        variants: [
          {begin: '/', end: '/[a-z]*'},
          {begin: '%r\\(', end: '\\)', contains: recursiveParen('\\(', '\\)')},
          {begin: '%r\\[', end: '\\]', contains: recursiveParen('\\[', '\\]')},
          {begin: '%r{', end: '}', contains: recursiveParen('{', '}')},
          {begin: '%r<', end: '>', contains: recursiveParen('<', '>')},
          {begin: '%r/', end: '/'},
          {begin: '%r%', end: '%'},
          {begin: '%r-', end: '-'},
          {begin: '%r\\|', end: '\\|'},
        ]
      }
    ],
    relevance: 0
  };
  var REGEXP2 = {
    className: 'regexp',
    contains: [hljs.BACKSLASH_ESCAPE, SUBST],
    variants: [
      {begin: '%r\\(', end: '\\)', contains: recursiveParen('\\(', '\\)')},
      {begin: '%r\\[', end: '\\]', contains: recursiveParen('\\[', '\\]')},
      {begin: '%r{', end: '}', contains: recursiveParen('{', '}')},
      {begin: '%r<', end: '>', contains: recursiveParen('<', '>')},
      {begin: '%r/', end: '/'},
      {begin: '%r%', end: '%'},
      {begin: '%r-', end: '-'},
      {begin: '%r\\|', end: '\\|'},
    ],
    relevance: 0
  };
  var ATTRIBUTE = {
    className: 'annotation',
    begin: '@\\[', end: '\\]',
    relevance: 5
  };
  var CRYSTAL_DEFAULT_CONTAINS = [
    EXPANSION,
    STRING,
    REGEXP,
    REGEXP2,
    ATTRIBUTE,
    hljs.HASH_COMMENT_MODE,
    {
      className: 'class',
      beginKeywords: 'class module struct', end: '$|;',
      illegal: /=/,
      contains: [
        hljs.HASH_COMMENT_MODE,
        hljs.inherit(hljs.TITLE_MODE, {begin: '[A-Za-z_]\\w*(::\\w+)*(\\?|\\!)?'}),
        {
          className: 'inheritance',
          begin: '<\\s*',
          contains: [{
            className: 'parent',
            begin: '(' + hljs.IDENT_RE + '::)?' + hljs.IDENT_RE
          }]
        }
      ]
    },
    {
      className: 'class',
      beginKeywords: 'lib enum union', end: '$|;',
      illegal: /=/,
      contains: [
        hljs.HASH_COMMENT_MODE,
        hljs.inherit(hljs.TITLE_MODE, {begin: '[A-Za-z_]\\w*(::\\w+)*(\\?|\\!)?'}),
      ],
      relevance: 10
    },
    {
      className: 'function',
      beginKeywords: 'def', end: /\B\b/,
      contains: [
        hljs.inherit(hljs.TITLE_MODE, {
          begin: CRYSTAL_METHOD_RE,
          endsParent: true
        })
      ]
    },
    {
      className: 'function',
      beginKeywords: 'fun macro', end: /\B\b/,
      contains: [
        hljs.inherit(hljs.TITLE_MODE, {
          begin: CRYSTAL_METHOD_RE,
          endsParent: true
        })
      ],
      relevance: 5
    },
    {
      className: 'constant',
      begin: '(::)?(\\b[A-Z]\\w*(::)?)+',
      relevance: 0
    },
    {
      className: 'symbol',
      begin: hljs.UNDERSCORE_IDENT_RE + '(\\!|\\?)?:',
      relevance: 0
    },
    {
      className: 'symbol',
      begin: ':',
      contains: [STRING, {begin: CRYSTAL_METHOD_RE}],
      relevance: 0
    },
    {
      className: 'number',
      variants: [
        { begin: '\\b0b([01_]*[01])' + NUM_SUFFIX },
        { begin: '\\b0o([0-7_]*[0-7])' + NUM_SUFFIX },
        { begin: '\\b0x([A-Fa-f0-9_]*[A-Fa-f0-9])' + NUM_SUFFIX },
        { begin: '\\b(([0-9][0-9_]*[0-9]|[0-9])(\\.[0-9_]*[0-9])?([eE][+-]?[0-9_]*[0-9])?)' + NUM_SUFFIX}
      ],
      relevance: 0
    },
    {
      className: 'variable',
      begin: '(\\$\\W)|((\\$|\\@\\@?|%)(\\w+))'
    }
  ];
  SUBST.contains = CRYSTAL_DEFAULT_CONTAINS;
  ATTRIBUTE.contains = CRYSTAL_DEFAULT_CONTAINS;
  EXPANSION.contains = CRYSTAL_DEFAULT_CONTAINS.slice(1); // without EXPANSION

  return {
    aliases: ['cr'],
    lexemes: CRYSTAL_IDENT_RE,
    keywords: CRYSTAL_KEYWORDS,
    contains: CRYSTAL_DEFAULT_CONTAINS
  };
});

hljs.registerLanguage('cs', function(hljs) {
  var KEYWORDS =
    // Normal keywords.
    'abstract as base bool break byte case catch char checked const continue decimal dynamic ' +
    'default delegate do double else enum event explicit extern false finally fixed float ' +
    'for foreach goto if implicit in int interface internal is lock long null when ' +
    'object operator out override params private protected public readonly ref sbyte ' +
    'sealed short sizeof stackalloc static string struct switch this true try typeof ' +
    'uint ulong unchecked unsafe ushort using virtual volatile void while async ' +
    'protected public private internal ' +
    // Contextual keywords.
    'ascending descending from get group into join let orderby partial select set value var ' +
    'where yield';
  var GENERIC_IDENT_RE = hljs.IDENT_RE + '(<' + hljs.IDENT_RE + '>)?';
  return {
    aliases: ['csharp'],
    keywords: KEYWORDS,
    illegal: /::/,
    contains: [
      hljs.COMMENT(
        '///',
        '$',
        {
          returnBegin: true,
          contains: [
            {
              className: 'xmlDocTag',
              variants: [
                {
                  begin: '///', relevance: 0
                },
                {
                  begin: '<!--|-->'
                },
                {
                  begin: '</?', end: '>'
                }
              ]
            }
          ]
        }
      ),
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      {
        className: 'preprocessor',
        begin: '#', end: '$',
        keywords: 'if else elif endif define undef warning error line region endregion pragma checksum'
      },
      {
        className: 'string',
        begin: '@"', end: '"',
        contains: [{begin: '""'}]
      },
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      hljs.C_NUMBER_MODE,
      {
        beginKeywords: 'class interface', end: /[{;=]/,
        illegal: /[^\s:]/,
        contains: [
          hljs.TITLE_MODE,
          hljs.C_LINE_COMMENT_MODE,
          hljs.C_BLOCK_COMMENT_MODE
        ]
      },
      {
        beginKeywords: 'namespace', end: /[{;=]/,
        illegal: /[^\s:]/,
        contains: [
          {
            // Customization of hljs.TITLE_MODE that allows '.'
            className: 'title',
            begin: '[a-zA-Z](\\.?\\w)*',
            relevance: 0
          },
          hljs.C_LINE_COMMENT_MODE,
          hljs.C_BLOCK_COMMENT_MODE
        ]
      },
      {
        // Expression keywords prevent 'keyword Name(...)' from being
        // recognized as a function definition
        beginKeywords: 'new return throw await',
        relevance: 0
      },
      {
        className: 'function',
        begin: '(' + GENERIC_IDENT_RE + '\\s+)+' + hljs.IDENT_RE + '\\s*\\(', returnBegin: true, end: /[{;=]/,
        excludeEnd: true,
        keywords: KEYWORDS,
        contains: [
          {
            begin: hljs.IDENT_RE + '\\s*\\(', returnBegin: true,
            contains: [hljs.TITLE_MODE],
            relevance: 0
          },
          {
            className: 'params',
            begin: /\(/, end: /\)/,
            excludeBegin: true,
            excludeEnd: true,
            keywords: KEYWORDS,
            relevance: 0,
            contains: [
              hljs.APOS_STRING_MODE,
              hljs.QUOTE_STRING_MODE,
              hljs.C_NUMBER_MODE,
              hljs.C_BLOCK_COMMENT_MODE
            ]
          },
          hljs.C_LINE_COMMENT_MODE,
          hljs.C_BLOCK_COMMENT_MODE
        ]
      }
    ]
  };
});

hljs.registerLanguage('css', function(hljs) {
  var IDENT_RE = '[a-zA-Z-][a-zA-Z0-9_-]*';
  var FUNCTION = {
    className: 'function',
    begin: IDENT_RE + '\\(',
    returnBegin: true,
    excludeEnd: true,
    end: '\\('
  };
  var RULE = {
    className: 'rule',
    begin: /[A-Z\_\.\-]+\s*:/, returnBegin: true, end: ';', endsWithParent: true,
    contains: [
      {
        className: 'attribute',
        begin: /\S/, end: ':', excludeEnd: true,
        starts: {
          className: 'value',
          endsWithParent: true, excludeEnd: true,
          contains: [
            FUNCTION,
            hljs.CSS_NUMBER_MODE,
            hljs.QUOTE_STRING_MODE,
            hljs.APOS_STRING_MODE,
            hljs.C_BLOCK_COMMENT_MODE,
            {
              className: 'hexcolor', begin: '#[0-9A-Fa-f]+'
            },
            {
              className: 'important', begin: '!important'
            }
          ]
        }
      }
    ]
  };

  return {
    case_insensitive: true,
    illegal: /[=\/|'\$]/,
    contains: [
      hljs.C_BLOCK_COMMENT_MODE,
      {
        className: 'id', begin: /\#[A-Za-z0-9_-]+/
      },
      {
        className: 'class', begin: /\.[A-Za-z0-9_-]+/
      },
      {
        className: 'attr_selector',
        begin: /\[/, end: /\]/,
        illegal: '$'
      },
      {
        className: 'pseudo',
        begin: /:(:)?[a-zA-Z0-9\_\-\+\(\)"']+/
      },
      {
        className: 'at_rule',
        begin: '@(font-face|page)',
        lexemes: '[a-z-]+',
        keywords: 'font-face page'
      },
      {
        className: 'at_rule',
        begin: '@', end: '[{;]', // at_rule eating first "{" is a good thing
                                 // because it doesn’t let it to be parsed as
                                 // a rule set but instead drops parser into
                                 // the default mode which is how it should be.
        contains: [
          {
            className: 'keyword',
            begin: /\S+/
          },
          {
            begin: /\s/, endsWithParent: true, excludeEnd: true,
            relevance: 0,
            contains: [
              FUNCTION,
              hljs.APOS_STRING_MODE, hljs.QUOTE_STRING_MODE,
              hljs.CSS_NUMBER_MODE
            ]
          }
        ]
      },
      {
        className: 'tag', begin: IDENT_RE,
        relevance: 0
      },
      {
        className: 'rules',
        begin: '{', end: '}',
        illegal: /\S/,
        contains: [
          hljs.C_BLOCK_COMMENT_MODE,
          RULE,
        ]
      }
    ]
  };
});

hljs.registerLanguage('d', /**
 * Known issues:
 *
 * - invalid hex string literals will be recognized as a double quoted strings
 *   but 'x' at the beginning of string will not be matched
 *
 * - delimited string literals are not checked for matching end delimiter
 *   (not possible to do with js regexp)
 *
 * - content of token string is colored as a string (i.e. no keyword coloring inside a token string)
 *   also, content of token string is not validated to contain only valid D tokens
 *
 * - special token sequence rule is not strictly following D grammar (anything following #line
 *   up to the end of line is matched as special token sequence)
 */

function(hljs) {
  /**
   * Language keywords
   *
   * @type {Object}
   */
  var D_KEYWORDS = {
    keyword:
      'abstract alias align asm assert auto body break byte case cast catch class ' +
      'const continue debug default delete deprecated do else enum export extern final ' +
      'finally for foreach foreach_reverse|10 goto if immutable import in inout int ' +
      'interface invariant is lazy macro mixin module new nothrow out override package ' +
      'pragma private protected public pure ref return scope shared static struct ' +
      'super switch synchronized template this throw try typedef typeid typeof union ' +
      'unittest version void volatile while with __FILE__ __LINE__ __gshared|10 ' +
      '__thread __traits __DATE__ __EOF__ __TIME__ __TIMESTAMP__ __VENDOR__ __VERSION__',
    built_in:
      'bool cdouble cent cfloat char creal dchar delegate double dstring float function ' +
      'idouble ifloat ireal long real short string ubyte ucent uint ulong ushort wchar ' +
      'wstring',
    literal:
      'false null true'
  };

  /**
   * Number literal regexps
   *
   * @type {String}
   */
  var decimal_integer_re = '(0|[1-9][\\d_]*)',
    decimal_integer_nosus_re = '(0|[1-9][\\d_]*|\\d[\\d_]*|[\\d_]+?\\d)',
    binary_integer_re = '0[bB][01_]+',
    hexadecimal_digits_re = '([\\da-fA-F][\\da-fA-F_]*|_[\\da-fA-F][\\da-fA-F_]*)',
    hexadecimal_integer_re = '0[xX]' + hexadecimal_digits_re,

    decimal_exponent_re = '([eE][+-]?' + decimal_integer_nosus_re + ')',
    decimal_float_re = '(' + decimal_integer_nosus_re + '(\\.\\d*|' + decimal_exponent_re + ')|' +
                '\\d+\\.' + decimal_integer_nosus_re + decimal_integer_nosus_re + '|' +
                '\\.' + decimal_integer_re + decimal_exponent_re + '?' +
              ')',
    hexadecimal_float_re = '(0[xX](' +
                  hexadecimal_digits_re + '\\.' + hexadecimal_digits_re + '|'+
                  '\\.?' + hexadecimal_digits_re +
                 ')[pP][+-]?' + decimal_integer_nosus_re + ')',

    integer_re = '(' +
      decimal_integer_re + '|' +
      binary_integer_re  + '|' +
       hexadecimal_integer_re   +
    ')',

    float_re = '(' +
      hexadecimal_float_re + '|' +
      decimal_float_re  +
    ')';

  /**
   * Escape sequence supported in D string and character literals
   *
   * @type {String}
   */
  var escape_sequence_re = '\\\\(' +
              '[\'"\\?\\\\abfnrtv]|' +  // common escapes
              'u[\\dA-Fa-f]{4}|' +     // four hex digit unicode codepoint
              '[0-7]{1,3}|' +       // one to three octal digit ascii char code
              'x[\\dA-Fa-f]{2}|' +    // two hex digit ascii char code
              'U[\\dA-Fa-f]{8}' +      // eight hex digit unicode codepoint
              ')|' +
              '&[a-zA-Z\\d]{2,};';      // named character entity

  /**
   * D integer number literals
   *
   * @type {Object}
   */
  var D_INTEGER_MODE = {
    className: 'number',
      begin: '\\b' + integer_re + '(L|u|U|Lu|LU|uL|UL)?',
      relevance: 0
  };

  /**
   * [D_FLOAT_MODE description]
   * @type {Object}
   */
  var D_FLOAT_MODE = {
    className: 'number',
    begin: '\\b(' +
        float_re + '([fF]|L|i|[fF]i|Li)?|' +
        integer_re + '(i|[fF]i|Li)' +
      ')',
    relevance: 0
  };

  /**
   * D character literal
   *
   * @type {Object}
   */
  var D_CHARACTER_MODE = {
    className: 'string',
    begin: '\'(' + escape_sequence_re + '|.)', end: '\'',
    illegal: '.'
  };

  /**
   * D string escape sequence
   *
   * @type {Object}
   */
  var D_ESCAPE_SEQUENCE = {
    begin: escape_sequence_re,
    relevance: 0
  };

  /**
   * D double quoted string literal
   *
   * @type {Object}
   */
  var D_STRING_MODE = {
    className: 'string',
    begin: '"',
    contains: [D_ESCAPE_SEQUENCE],
    end: '"[cwd]?'
  };

  /**
   * D wysiwyg and delimited string literals
   *
   * @type {Object}
   */
  var D_WYSIWYG_DELIMITED_STRING_MODE = {
    className: 'string',
    begin: '[rq]"',
    end: '"[cwd]?',
    relevance: 5
  };

  /**
   * D alternate wysiwyg string literal
   *
   * @type {Object}
   */
  var D_ALTERNATE_WYSIWYG_STRING_MODE = {
    className: 'string',
    begin: '`',
    end: '`[cwd]?'
  };

  /**
   * D hexadecimal string literal
   *
   * @type {Object}
   */
  var D_HEX_STRING_MODE = {
    className: 'string',
    begin: 'x"[\\da-fA-F\\s\\n\\r]*"[cwd]?',
    relevance: 10
  };

  /**
   * D delimited string literal
   *
   * @type {Object}
   */
  var D_TOKEN_STRING_MODE = {
    className: 'string',
    begin: 'q"\\{',
    end: '\\}"'
  };

  /**
   * Hashbang support
   *
   * @type {Object}
   */
  var D_HASHBANG_MODE = {
    className: 'shebang',
    begin: '^#!',
    end: '$',
    relevance: 5
  };

  /**
   * D special token sequence
   *
   * @type {Object}
   */
  var D_SPECIAL_TOKEN_SEQUENCE_MODE = {
    className: 'preprocessor',
    begin: '#(line)',
    end: '$',
    relevance: 5
  };

  /**
   * D attributes
   *
   * @type {Object}
   */
  var D_ATTRIBUTE_MODE = {
    className: 'keyword',
    begin: '@[a-zA-Z_][a-zA-Z_\\d]*'
  };

  /**
   * D nesting comment
   *
   * @type {Object}
   */
  var D_NESTING_COMMENT_MODE = hljs.COMMENT(
    '\\/\\+',
    '\\+\\/',
    {
      contains: ['self'],
      relevance: 10
    }
  );

  return {
    lexemes: hljs.UNDERSCORE_IDENT_RE,
    keywords: D_KEYWORDS,
    contains: [
      hljs.C_LINE_COMMENT_MODE,
        hljs.C_BLOCK_COMMENT_MODE,
        D_NESTING_COMMENT_MODE,
        D_HEX_STRING_MODE,
        D_STRING_MODE,
        D_WYSIWYG_DELIMITED_STRING_MODE,
        D_ALTERNATE_WYSIWYG_STRING_MODE,
        D_TOKEN_STRING_MODE,
        D_FLOAT_MODE,
        D_INTEGER_MODE,
        D_CHARACTER_MODE,
        D_HASHBANG_MODE,
        D_SPECIAL_TOKEN_SEQUENCE_MODE,
        D_ATTRIBUTE_MODE
    ]
  };
});

hljs.registerLanguage('markdown', function(hljs) {
  return {
    aliases: ['md', 'mkdown', 'mkd'],
    contains: [
      // highlight headers
      {
        className: 'header',
        variants: [
          { begin: '^#{1,6}', end: '$' },
          { begin: '^.+?\\n[=-]{2,}$' }
        ]
      },
      // inline html
      {
        begin: '<', end: '>',
        subLanguage: 'xml',
        relevance: 0
      },
      // lists (indicators only)
      {
        className: 'bullet',
        begin: '^([*+-]|(\\d+\\.))\\s+'
      },
      // strong segments
      {
        className: 'strong',
        begin: '[*_]{2}.+?[*_]{2}'
      },
      // emphasis segments
      {
        className: 'emphasis',
        variants: [
          { begin: '\\*.+?\\*' },
          { begin: '_.+?_'
          , relevance: 0
          }
        ]
      },
      // blockquotes
      {
        className: 'blockquote',
        begin: '^>\\s+', end: '$'
      },
      // code snippets
      {
        className: 'code',
        variants: [
          { begin: '`.+?`' },
          { begin: '^( {4}|\t)', end: '$'
          , relevance: 0
          }
        ]
      },
      // horizontal rules
      {
        className: 'horizontal_rule',
        begin: '^[-\\*]{3,}', end: '$'
      },
      // using links - title and link
      {
        begin: '\\[.+?\\][\\(\\[].*?[\\)\\]]',
        returnBegin: true,
        contains: [
          {
            className: 'link_label',
            begin: '\\[', end: '\\]',
            excludeBegin: true,
            returnEnd: true,
            relevance: 0
          },
          {
            className: 'link_url',
            begin: '\\]\\(', end: '\\)',
            excludeBegin: true, excludeEnd: true
          },
          {
            className: 'link_reference',
            begin: '\\]\\[', end: '\\]',
            excludeBegin: true, excludeEnd: true
          }
        ],
        relevance: 10
      },
      {
        begin: '^\\[\.+\\]:',
        returnBegin: true,
        contains: [
          {
            className: 'link_reference',
            begin: '\\[', end: '\\]:',
            excludeBegin: true, excludeEnd: true,
            starts: {
              className: 'link_url',
              end: '$'
            }
          }
        ]
      }
    ]
  };
});

hljs.registerLanguage('dart', function (hljs) {
  var SUBST = {
    className: 'subst',
    begin: '\\$\\{', end: '}',
    keywords: 'true false null this is new super'
  };

  var STRING = {
    className: 'string',
    variants: [
      {
        begin: 'r\'\'\'', end: '\'\'\''
      },
      {
        begin: 'r"""', end: '"""'
      },
      {
        begin: 'r\'', end: '\'',
        illegal: '\\n'
      },
      {
        begin: 'r"', end: '"',
        illegal: '\\n'
      },
      {
        begin: '\'\'\'', end: '\'\'\'',
        contains: [hljs.BACKSLASH_ESCAPE, SUBST]
      },
      {
        begin: '"""', end: '"""',
        contains: [hljs.BACKSLASH_ESCAPE, SUBST]
      },
      {
        begin: '\'', end: '\'',
        illegal: '\\n',
        contains: [hljs.BACKSLASH_ESCAPE, SUBST]
      },
      {
        begin: '"', end: '"',
        illegal: '\\n',
        contains: [hljs.BACKSLASH_ESCAPE, SUBST]
      }
    ]
  };
  SUBST.contains = [
    hljs.C_NUMBER_MODE, STRING
  ];

  var KEYWORDS = {
    keyword: 'assert break case catch class const continue default do else enum extends false final finally for if ' +
      'in is new null rethrow return super switch this throw true try var void while with',
    literal: 'abstract as dynamic export external factory get implements import library operator part set static typedef',
    built_in:
      // dart:core
      'print Comparable DateTime Duration Function Iterable Iterator List Map Match Null Object Pattern RegExp Set ' +
      'Stopwatch String StringBuffer StringSink Symbol Type Uri bool double int num ' +
      // dart:html
      'document window querySelector querySelectorAll Element ElementList'
  };

  return {
    keywords: KEYWORDS,
    contains: [
      STRING,
      hljs.COMMENT(
        '/\\*\\*',
        '\\*/',
        {
          subLanguage: 'markdown'
        }
      ),
      hljs.COMMENT(
        '///',
        '$',
        {
          subLanguage: 'markdown'
        }
      ),
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      {
        className: 'class',
        beginKeywords: 'class interface', end: '{', excludeEnd: true,
        contains: [
          {
            beginKeywords: 'extends implements'
          },
          hljs.UNDERSCORE_TITLE_MODE
        ]
      },
      hljs.C_NUMBER_MODE,
      {
        className: 'annotation', begin: '@[A-Za-z]+'
      },
      {
        begin: '=>' // No markup, just a relevance booster
      }
    ]
  }
});

hljs.registerLanguage('delphi', function(hljs) {
  var KEYWORDS =
    'exports register file shl array record property for mod while set ally label uses raise not ' +
    'stored class safecall var interface or private static exit index inherited to else stdcall ' +
    'override shr asm far resourcestring finalization packed virtual out and protected library do ' +
    'xorwrite goto near function end div overload object unit begin string on inline repeat until ' +
    'destructor write message program with read initialization except default nil if case cdecl in ' +
    'downto threadvar of try pascal const external constructor type public then implementation ' +
    'finally published procedure';
  var COMMENT_MODES = [
    hljs.C_LINE_COMMENT_MODE,
    hljs.COMMENT(
      /\{/,
      /\}/,
      {
        relevance: 0
      }
    ),
    hljs.COMMENT(
      /\(\*/,
      /\*\)/,
      {
        relevance: 10
      }
    )
  ];
  var STRING = {
    className: 'string',
    begin: /'/, end: /'/,
    contains: [{begin: /''/}]
  };
  var CHAR_STRING = {
    className: 'string', begin: /(#\d+)+/
  };
  var CLASS = {
    begin: hljs.IDENT_RE + '\\s*=\\s*class\\s*\\(', returnBegin: true,
    contains: [
      hljs.TITLE_MODE
    ]
  };
  var FUNCTION = {
    className: 'function',
    beginKeywords: 'function constructor destructor procedure', end: /[:;]/,
    keywords: 'function constructor|10 destructor|10 procedure|10',
    contains: [
      hljs.TITLE_MODE,
      {
        className: 'params',
        begin: /\(/, end: /\)/,
        keywords: KEYWORDS,
        contains: [STRING, CHAR_STRING]
      }
    ].concat(COMMENT_MODES)
  };
  return {
    case_insensitive: true,
    keywords: KEYWORDS,
    illegal: /"|\$[G-Zg-z]|\/\*|<\/|\|/,
    contains: [
      STRING, CHAR_STRING,
      hljs.NUMBER_MODE,
      CLASS,
      FUNCTION
    ].concat(COMMENT_MODES)
  };
});

hljs.registerLanguage('diff', function(hljs) {
  return {
    aliases: ['patch'],
    contains: [
      {
        className: 'chunk',
        relevance: 10,
        variants: [
          {begin: /^@@ +\-\d+,\d+ +\+\d+,\d+ +@@$/},
          {begin: /^\*\*\* +\d+,\d+ +\*\*\*\*$/},
          {begin: /^\-\-\- +\d+,\d+ +\-\-\-\-$/}
        ]
      },
      {
        className: 'header',
        variants: [
          {begin: /Index: /, end: /$/},
          {begin: /=====/, end: /=====$/},
          {begin: /^\-\-\-/, end: /$/},
          {begin: /^\*{3} /, end: /$/},
          {begin: /^\+\+\+/, end: /$/},
          {begin: /\*{5}/, end: /\*{5}$/}
        ]
      },
      {
        className: 'addition',
        begin: '^\\+', end: '$'
      },
      {
        className: 'deletion',
        begin: '^\\-', end: '$'
      },
      {
        className: 'change',
        begin: '^\\!', end: '$'
      }
    ]
  };
});

hljs.registerLanguage('django', function(hljs) {
  var FILTER = {
    className: 'filter',
    begin: /\|[A-Za-z]+:?/,
    keywords:
      'truncatewords removetags linebreaksbr yesno get_digit timesince random striptags ' +
      'filesizeformat escape linebreaks length_is ljust rjust cut urlize fix_ampersands ' +
      'title floatformat capfirst pprint divisibleby add make_list unordered_list urlencode ' +
      'timeuntil urlizetrunc wordcount stringformat linenumbers slice date dictsort ' +
      'dictsortreversed default_if_none pluralize lower join center default ' +
      'truncatewords_html upper length phone2numeric wordwrap time addslashes slugify first ' +
      'escapejs force_escape iriencode last safe safeseq truncatechars localize unlocalize ' +
      'localtime utc timezone',
    contains: [
      {className: 'argument', begin: /"/, end: /"/},
      {className: 'argument', begin: /'/, end: /'/}
    ]
  };

  return {
    aliases: ['jinja'],
    case_insensitive: true,
    subLanguage: 'xml',
    contains: [
      hljs.COMMENT(/\{%\s*comment\s*%}/, /\{%\s*endcomment\s*%}/),
      hljs.COMMENT(/\{#/, /#}/),
      {
        className: 'template_tag',
        begin: /\{%/, end: /%}/,
        keywords:
          'comment endcomment load templatetag ifchanged endifchanged if endif firstof for ' +
          'endfor in ifnotequal endifnotequal widthratio extends include spaceless ' +
          'endspaceless regroup by as ifequal endifequal ssi now with cycle url filter ' +
          'endfilter debug block endblock else autoescape endautoescape csrf_token empty elif ' +
          'endwith static trans blocktrans endblocktrans get_static_prefix get_media_prefix ' +
          'plural get_current_language language get_available_languages ' +
          'get_current_language_bidi get_language_info get_language_info_list localize ' +
          'endlocalize localtime endlocaltime timezone endtimezone get_current_timezone ' +
          'verbatim',
        contains: [FILTER]
      },
      {
        className: 'variable',
        begin: /\{\{/, end: /}}/,
        contains: [FILTER]
      }
    ]
  };
});

hljs.registerLanguage('dns', function(hljs) {
  return {
    aliases: ['bind', 'zone'],
    keywords: {
      keyword:
        'IN A AAAA AFSDB APL CAA CDNSKEY CDS CERT CNAME DHCID DLV DNAME DNSKEY DS HIP IPSECKEY KEY KX ' +
        'LOC MX NAPTR NS NSEC NSEC3 NSEC3PARAM PTR RRSIG RP SIG SOA SRV SSHFP TA TKEY TLSA TSIG TXT'
    },
    contains: [
      hljs.COMMENT(';', '$'),
      {
        className: 'operator',
        beginKeywords: '$TTL $GENERATE $INCLUDE $ORIGIN'
      },
      // IPv6
      {
        className: 'number',
        begin: '((([0-9A-Fa-f]{1,4}:){7}([0-9A-Fa-f]{1,4}|:))|(([0-9A-Fa-f]{1,4}:){6}(:[0-9A-Fa-f]{1,4}|((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)){3})|:))|(([0-9A-Fa-f]{1,4}:){5}(((:[0-9A-Fa-f]{1,4}){1,2})|:((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)){3})|:))|(([0-9A-Fa-f]{1,4}:){4}(((:[0-9A-Fa-f]{1,4}){1,3})|((:[0-9A-Fa-f]{1,4})?:((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)){3}))|:))|(([0-9A-Fa-f]{1,4}:){3}(((:[0-9A-Fa-f]{1,4}){1,4})|((:[0-9A-Fa-f]{1,4}){0,2}:((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)){3}))|:))|(([0-9A-Fa-f]{1,4}:){2}(((:[0-9A-Fa-f]{1,4}){1,5})|((:[0-9A-Fa-f]{1,4}){0,3}:((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)){3}))|:))|(([0-9A-Fa-f]{1,4}:){1}(((:[0-9A-Fa-f]{1,4}){1,6})|((:[0-9A-Fa-f]{1,4}){0,4}:((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)){3}))|:))|(:(((:[0-9A-Fa-f]{1,4}){1,7})|((:[0-9A-Fa-f]{1,4}){0,5}:((25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)(\\.(25[0-5]|2[0-4]\\d|1\\d\\d|[1-9]?\\d)){3}))|:)))'
      },
      // IPv4
      {
        className: 'number',
        begin: '((25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])\.){3,3}(25[0-5]|(2[0-4]|1{0,1}[0-9]){0,1}[0-9])'
      }
    ]
  };
});

hljs.registerLanguage('dockerfile', function(hljs) {
  return {
    aliases: ['docker'],
    case_insensitive: true,
    keywords: {
      built_ins: 'from maintainer cmd expose add copy entrypoint volume user workdir onbuild run env label'
    },
    contains: [
      hljs.HASH_COMMENT_MODE,
      {
        keywords : {
          built_in: 'run cmd entrypoint volume add copy workdir onbuild label'
        },
        begin: /^ *(onbuild +)?(run|cmd|entrypoint|volume|add|copy|workdir|label) +/,
        starts: {
          end: /[^\\]\n/,
          subLanguage: 'bash'
        }
      },
      {
        keywords: {
          built_in: 'from maintainer expose env user onbuild'
        },
        begin: /^ *(onbuild +)?(from|maintainer|expose|env|user|onbuild) +/, end: /[^\\]\n/,
        contains: [
          hljs.APOS_STRING_MODE,
          hljs.QUOTE_STRING_MODE,
          hljs.NUMBER_MODE,
          hljs.HASH_COMMENT_MODE
        ]
      }
    ]
  }
});

hljs.registerLanguage('dos', function(hljs) {
  var COMMENT = hljs.COMMENT(
    /@?rem\b/, /$/,
    {
      relevance: 10
    }
  );
  var LABEL = {
    className: 'label',
    begin: '^\\s*[A-Za-z._?][A-Za-z0-9_$#@~.?]*(:|\\s+label)',
    relevance: 0
  };
  return {
    aliases: ['bat', 'cmd'],
    case_insensitive: true,
    illegal: /\/\*/,
    keywords: {
      flow: 'if else goto for in do call exit not exist errorlevel defined',
      operator: 'equ neq lss leq gtr geq',
      keyword: 'shift cd dir echo setlocal endlocal set pause copy',
      stream: 'prn nul lpt3 lpt2 lpt1 con com4 com3 com2 com1 aux',
      winutils: 'ping net ipconfig taskkill xcopy ren del',
      built_in: 'append assoc at attrib break cacls cd chcp chdir chkdsk chkntfs cls cmd color ' +
        'comp compact convert date dir diskcomp diskcopy doskey erase fs ' +
        'find findstr format ftype graftabl help keyb label md mkdir mode more move path ' +
        'pause print popd pushd promt rd recover rem rename replace restore rmdir shift' +
        'sort start subst time title tree type ver verify vol'
    },
    contains: [
      {
        className: 'envvar', begin: /%%[^ ]|%[^ ]+?%|![^ ]+?!/
      },
      {
        className: 'function',
        begin: LABEL.begin, end: 'goto:eof',
        contains: [
          hljs.inherit(hljs.TITLE_MODE, {begin: '([_a-zA-Z]\\w*\\.)*([_a-zA-Z]\\w*:)?[_a-zA-Z]\\w*'}),
          COMMENT
        ]
      },
      {
        className: 'number', begin: '\\b\\d+',
        relevance: 0
      },
      COMMENT
    ]
  };
});

hljs.registerLanguage('dust', function(hljs) {
  var EXPRESSION_KEYWORDS = 'if eq ne lt lte gt gte select default math sep';
  return {
    aliases: ['dst'],
    case_insensitive: true,
    subLanguage: 'xml',
    contains: [
      {
        className: 'expression',
        begin: '{', end: '}',
        relevance: 0,
        contains: [
          {
            className: 'begin-block', begin: '\#[a-zA-Z\-\ \.]+',
            keywords: EXPRESSION_KEYWORDS
          },
          {
            className: 'string',
            begin: '"', end: '"'
          },
          {
            className: 'end-block', begin: '\\\/[a-zA-Z\-\ \.]+',
            keywords: EXPRESSION_KEYWORDS
          },
          {
            className: 'variable', begin: '[a-zA-Z\-\.]+',
            keywords: EXPRESSION_KEYWORDS,
            relevance: 0
          }
        ]
      }
    ]
  };
});

hljs.registerLanguage('elixir', function(hljs) {
  var ELIXIR_IDENT_RE = '[a-zA-Z_][a-zA-Z0-9_]*(\\!|\\?)?';
  var ELIXIR_METHOD_RE = '[a-zA-Z_]\\w*[!?=]?|[-+~]\\@|<<|>>|=~|===?|<=>|[<>]=?|\\*\\*|[-/+%^&*~`|]|\\[\\]=?';
  var ELIXIR_KEYWORDS =
    'and false then defined module in return redo retry end for true self when ' +
    'next until do begin unless nil break not case cond alias while ensure or ' +
    'include use alias fn quote';
  var SUBST = {
    className: 'subst',
    begin: '#\\{', end: '}',
    lexemes: ELIXIR_IDENT_RE,
    keywords: ELIXIR_KEYWORDS
  };
  var STRING = {
    className: 'string',
    contains: [hljs.BACKSLASH_ESCAPE, SUBST],
    variants: [
      {
        begin: /'/, end: /'/
      },
      {
        begin: /"/, end: /"/
      }
    ]
  };
  var FUNCTION = {
    className: 'function',
    beginKeywords: 'def defp defmacro', end: /\B\b/, // the mode is ended by the title
    contains: [
      hljs.inherit(hljs.TITLE_MODE, {
        begin: ELIXIR_IDENT_RE,
        endsParent: true
      })
    ]
  };
  var CLASS = hljs.inherit(FUNCTION, {
    className: 'class',
    beginKeywords: 'defmodule defrecord', end: /\bdo\b|$|;/
  });
  var ELIXIR_DEFAULT_CONTAINS = [
    STRING,
    hljs.HASH_COMMENT_MODE,
    CLASS,
    FUNCTION,
    {
      className: 'constant',
      begin: '(\\b[A-Z_]\\w*(.)?)+',
      relevance: 0
    },
    {
      className: 'symbol',
      begin: ':',
      contains: [STRING, {begin: ELIXIR_METHOD_RE}],
      relevance: 0
    },
    {
      className: 'symbol',
      begin: ELIXIR_IDENT_RE + ':',
      relevance: 0
    },
    {
      className: 'number',
      begin: '(\\b0[0-7_]+)|(\\b0x[0-9a-fA-F_]+)|(\\b[1-9][0-9_]*(\\.[0-9_]+)?)|[0_]\\b',
      relevance: 0
    },
    {
      className: 'variable',
      begin: '(\\$\\W)|((\\$|\\@\\@?)(\\w+))'
    },
    {
      begin: '->'
    },
    { // regexp container
      begin: '(' + hljs.RE_STARTERS_RE + ')\\s*',
      contains: [
        hljs.HASH_COMMENT_MODE,
        {
          className: 'regexp',
          illegal: '\\n',
          contains: [hljs.BACKSLASH_ESCAPE, SUBST],
          variants: [
            {
              begin: '/', end: '/[a-z]*'
            },
            {
              begin: '%r\\[', end: '\\][a-z]*'
            }
          ]
        }
      ],
      relevance: 0
    }
  ];
  SUBST.contains = ELIXIR_DEFAULT_CONTAINS;

  return {
    lexemes: ELIXIR_IDENT_RE,
    keywords: ELIXIR_KEYWORDS,
    contains: ELIXIR_DEFAULT_CONTAINS
  };
});

hljs.registerLanguage('elm', function(hljs) {
  var COMMENT_MODES = [
    hljs.COMMENT('--', '$'),
    hljs.COMMENT(
      '{-',
      '-}',
      {
        contains: ['self']
      }
    )
  ];

  var CONSTRUCTOR = {
    className: 'type',
    begin: '\\b[A-Z][\\w\']*', // TODO: other constructors (build-in, infix).
    relevance: 0
  };

  var LIST = {
    className: 'container',
    begin: '\\(', end: '\\)',
    illegal: '"',
    contains: [
      {className: 'type', begin: '\\b[A-Z][\\w]*(\\((\\.\\.|,|\\w+)\\))?'}
    ].concat(COMMENT_MODES)
  };

  var RECORD = {
    className: 'container',
    begin: '{', end: '}',
    contains: LIST.contains
  };

  return {
    keywords:
      'let in if then else case of where module import exposing ' +
      'type alias as infix infixl infixr port',
    contains: [

      // Top-level constructions.

      {
        className: 'module',
        begin: '\\bmodule\\b', end: 'where',
        keywords: 'module where',
        contains: [LIST].concat(COMMENT_MODES),
        illegal: '\\W\\.|;'
      },
      {
        className: 'import',
        begin: '\\bimport\\b', end: '$',
        keywords: 'import|0 as exposing',
        contains: [LIST].concat(COMMENT_MODES),
        illegal: '\\W\\.|;'
      },
      {
        className: 'typedef',
        begin: '\\btype\\b', end: '$',
        keywords: 'type alias',
        contains: [CONSTRUCTOR, LIST, RECORD].concat(COMMENT_MODES)
      },
      {
        className: 'infix',
        beginKeywords: 'infix infixl infixr', end: '$',
        contains: [hljs.C_NUMBER_MODE].concat(COMMENT_MODES)
      },
      {
        className: 'foreign',
        begin: '\\bport\\b', end: '$',
        keywords: 'port',
        contains: COMMENT_MODES
      },

      // Literals and names.

      // TODO: characters.
      hljs.QUOTE_STRING_MODE,
      hljs.C_NUMBER_MODE,
      CONSTRUCTOR,
      hljs.inherit(hljs.TITLE_MODE, {begin: '^[_a-z][\\w\']*'}),

      {begin: '->|<-'} // No markup, relevance booster
    ].concat(COMMENT_MODES)
  };
});

hljs.registerLanguage('ruby', function(hljs) {
  var RUBY_METHOD_RE = '[a-zA-Z_]\\w*[!?=]?|[-+~]\\@|<<|>>|=~|===?|<=>|[<>]=?|\\*\\*|[-/+%^&*~`|]|\\[\\]=?';
  var RUBY_KEYWORDS =
    'and false then defined module in return redo if BEGIN retry end for true self when ' +
    'next until do begin unless END rescue nil else break undef not super class case ' +
    'require yield alias while ensure elsif or include attr_reader attr_writer attr_accessor';
  var YARDOCTAG = {
    className: 'doctag',
    begin: '@[A-Za-z]+'
  };
  var IRB_OBJECT = {
    className: 'value',
    begin: '#<', end: '>'
  };
  var COMMENT_MODES = [
    hljs.COMMENT(
      '#',
      '$',
      {
        contains: [YARDOCTAG]
      }
    ),
    hljs.COMMENT(
      '^\\=begin',
      '^\\=end',
      {
        contains: [YARDOCTAG],
        relevance: 10
      }
    ),
    hljs.COMMENT('^__END__', '\\n$')
  ];
  var SUBST = {
    className: 'subst',
    begin: '#\\{', end: '}',
    keywords: RUBY_KEYWORDS
  };
  var STRING = {
    className: 'string',
    contains: [hljs.BACKSLASH_ESCAPE, SUBST],
    variants: [
      {begin: /'/, end: /'/},
      {begin: /"/, end: /"/},
      {begin: /`/, end: /`/},
      {begin: '%[qQwWx]?\\(', end: '\\)'},
      {begin: '%[qQwWx]?\\[', end: '\\]'},
      {begin: '%[qQwWx]?{', end: '}'},
      {begin: '%[qQwWx]?<', end: '>'},
      {begin: '%[qQwWx]?/', end: '/'},
      {begin: '%[qQwWx]?%', end: '%'},
      {begin: '%[qQwWx]?-', end: '-'},
      {begin: '%[qQwWx]?\\|', end: '\\|'},
      {
        // \B in the beginning suppresses recognition of ?-sequences where ?
        // is the last character of a preceding identifier, as in: `func?4`
        begin: /\B\?(\\\d{1,3}|\\x[A-Fa-f0-9]{1,2}|\\u[A-Fa-f0-9]{4}|\\?\S)\b/
      }
    ]
  };
  var PARAMS = {
    className: 'params',
    begin: '\\(', end: '\\)',
    keywords: RUBY_KEYWORDS
  };

  var RUBY_DEFAULT_CONTAINS = [
    STRING,
    IRB_OBJECT,
    {
      className: 'class',
      beginKeywords: 'class module', end: '$|;',
      illegal: /=/,
      contains: [
        hljs.inherit(hljs.TITLE_MODE, {begin: '[A-Za-z_]\\w*(::\\w+)*(\\?|\\!)?'}),
        {
          className: 'inheritance',
          begin: '<\\s*',
          contains: [{
            className: 'parent',
            begin: '(' + hljs.IDENT_RE + '::)?' + hljs.IDENT_RE
          }]
        }
      ].concat(COMMENT_MODES)
    },
    {
      className: 'function',
      beginKeywords: 'def', end: '$|;',
      contains: [
        hljs.inherit(hljs.TITLE_MODE, {begin: RUBY_METHOD_RE}),
        PARAMS
      ].concat(COMMENT_MODES)
    },
    {
      className: 'constant',
      begin: '(::)?(\\b[A-Z]\\w*(::)?)+',
      relevance: 0
    },
    {
      className: 'symbol',
      begin: hljs.UNDERSCORE_IDENT_RE + '(\\!|\\?)?:',
      relevance: 0
    },
    {
      className: 'symbol',
      begin: ':',
      contains: [STRING, {begin: RUBY_METHOD_RE}],
      relevance: 0
    },
    {
      className: 'number',
      begin: '(\\b0[0-7_]+)|(\\b0x[0-9a-fA-F_]+)|(\\b[1-9][0-9_]*(\\.[0-9_]+)?)|[0_]\\b',
      relevance: 0
    },
    {
      className: 'variable',
      begin: '(\\$\\W)|((\\$|\\@\\@?)(\\w+))'
    },
    { // regexp container
      begin: '(' + hljs.RE_STARTERS_RE + ')\\s*',
      contains: [
        IRB_OBJECT,
        {
          className: 'regexp',
          contains: [hljs.BACKSLASH_ESCAPE, SUBST],
          illegal: /\n/,
          variants: [
            {begin: '/', end: '/[a-z]*'},
            {begin: '%r{', end: '}[a-z]*'},
            {begin: '%r\\(', end: '\\)[a-z]*'},
            {begin: '%r!', end: '![a-z]*'},
            {begin: '%r\\[', end: '\\][a-z]*'}
          ]
        }
      ].concat(COMMENT_MODES),
      relevance: 0
    }
  ].concat(COMMENT_MODES);

  SUBST.contains = RUBY_DEFAULT_CONTAINS;
  PARAMS.contains = RUBY_DEFAULT_CONTAINS;

  var SIMPLE_PROMPT = "[>?]>";
  var DEFAULT_PROMPT = "[\\w#]+\\(\\w+\\):\\d+:\\d+>";
  var RVM_PROMPT = "(\\w+-)?\\d+\\.\\d+\\.\\d(p\\d+)?[^>]+>";

  var IRB_DEFAULT = [
    {
      begin: /^\s*=>/,
      className: 'status',
      starts: {
        end: '$', contains: RUBY_DEFAULT_CONTAINS
      }
    },
    {
      className: 'prompt',
      begin: '^('+SIMPLE_PROMPT+"|"+DEFAULT_PROMPT+'|'+RVM_PROMPT+')',
      starts: {
        end: '$', contains: RUBY_DEFAULT_CONTAINS
      }
    }
  ];

  return {
    aliases: ['rb', 'gemspec', 'podspec', 'thor', 'irb'],
    keywords: RUBY_KEYWORDS,
    illegal: /\/\*/,
    contains: COMMENT_MODES.concat(IRB_DEFAULT).concat(RUBY_DEFAULT_CONTAINS)
  };
});

hljs.registerLanguage('erb', function(hljs) {
  return {
    subLanguage: 'xml',
    contains: [
      hljs.COMMENT('<%#', '%>'),
      {
        begin: '<%[%=-]?', end: '[%-]?%>',
        subLanguage: 'ruby',
        excludeBegin: true,
        excludeEnd: true
      }
    ]
  };
});

hljs.registerLanguage('erlang-repl', function(hljs) {
  return {
    keywords: {
      special_functions:
        'spawn spawn_link self',
      reserved:
        'after and andalso|10 band begin bnot bor bsl bsr bxor case catch cond div end fun if ' +
        'let not of or orelse|10 query receive rem try when xor'
    },
    contains: [
      {
        className: 'prompt', begin: '^[0-9]+> ',
        relevance: 10
      },
      hljs.COMMENT('%', '$'),
      {
        className: 'number',
        begin: '\\b(\\d+#[a-fA-F0-9]+|\\d+(\\.\\d+)?([eE][-+]?\\d+)?)',
        relevance: 0
      },
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      {
        className: 'constant', begin: '\\?(::)?([A-Z]\\w*(::)?)+'
      },
      {
        className: 'arrow', begin: '->'
      },
      {
        className: 'ok', begin: 'ok'
      },
      {
        className: 'exclamation_mark', begin: '!'
      },
      {
        className: 'function_or_atom',
        begin: '(\\b[a-z\'][a-zA-Z0-9_\']*:[a-z\'][a-zA-Z0-9_\']*)|(\\b[a-z\'][a-zA-Z0-9_\']*)',
        relevance: 0
      },
      {
        className: 'variable',
        begin: '[A-Z][a-zA-Z0-9_\']*',
        relevance: 0
      }
    ]
  };
});

hljs.registerLanguage('erlang', function(hljs) {
  var BASIC_ATOM_RE = '[a-z\'][a-zA-Z0-9_\']*';
  var FUNCTION_NAME_RE = '(' + BASIC_ATOM_RE + ':' + BASIC_ATOM_RE + '|' + BASIC_ATOM_RE + ')';
  var ERLANG_RESERVED = {
    keyword:
      'after and andalso|10 band begin bnot bor bsl bzr bxor case catch cond div end fun if ' +
      'let not of orelse|10 query receive rem try when xor',
    literal:
      'false true'
  };

  var COMMENT = hljs.COMMENT('%', '$');
  var NUMBER = {
    className: 'number',
    begin: '\\b(\\d+#[a-fA-F0-9]+|\\d+(\\.\\d+)?([eE][-+]?\\d+)?)',
    relevance: 0
  };
  var NAMED_FUN = {
    begin: 'fun\\s+' + BASIC_ATOM_RE + '/\\d+'
  };
  var FUNCTION_CALL = {
    begin: FUNCTION_NAME_RE + '\\(', end: '\\)',
    returnBegin: true,
    relevance: 0,
    contains: [
      {
        className: 'function_name', begin: FUNCTION_NAME_RE,
        relevance: 0
      },
      {
        begin: '\\(', end: '\\)', endsWithParent: true,
        returnEnd: true,
        relevance: 0
        // "contains" defined later
      }
    ]
  };
  var TUPLE = {
    className: 'tuple',
    begin: '{', end: '}',
    relevance: 0
    // "contains" defined later
  };
  var VAR1 = {
    className: 'variable',
    begin: '\\b_([A-Z][A-Za-z0-9_]*)?',
    relevance: 0
  };
  var VAR2 = {
    className: 'variable',
    begin: '[A-Z][a-zA-Z0-9_]*',
    relevance: 0
  };
  var RECORD_ACCESS = {
    begin: '#' + hljs.UNDERSCORE_IDENT_RE,
    relevance: 0,
    returnBegin: true,
    contains: [
      {
        className: 'record_name',
        begin: '#' + hljs.UNDERSCORE_IDENT_RE,
        relevance: 0
      },
      {
        begin: '{', end: '}',
        relevance: 0
        // "contains" defined later
      }
    ]
  };

  var BLOCK_STATEMENTS = {
    beginKeywords: 'fun receive if try case', end: 'end',
    keywords: ERLANG_RESERVED
  };
  BLOCK_STATEMENTS.contains = [
    COMMENT,
    NAMED_FUN,
    hljs.inherit(hljs.APOS_STRING_MODE, {className: ''}),
    BLOCK_STATEMENTS,
    FUNCTION_CALL,
    hljs.QUOTE_STRING_MODE,
    NUMBER,
    TUPLE,
    VAR1, VAR2,
    RECORD_ACCESS
  ];

  var BASIC_MODES = [
    COMMENT,
    NAMED_FUN,
    BLOCK_STATEMENTS,
    FUNCTION_CALL,
    hljs.QUOTE_STRING_MODE,
    NUMBER,
    TUPLE,
    VAR1, VAR2,
    RECORD_ACCESS
  ];
  FUNCTION_CALL.contains[1].contains = BASIC_MODES;
  TUPLE.contains = BASIC_MODES;
  RECORD_ACCESS.contains[1].contains = BASIC_MODES;

  var PARAMS = {
    className: 'params',
    begin: '\\(', end: '\\)',
    contains: BASIC_MODES
  };
  return {
    aliases: ['erl'],
    keywords: ERLANG_RESERVED,
    illegal: '(</|\\*=|\\+=|-=|/\\*|\\*/|\\(\\*|\\*\\))',
    contains: [
      {
        className: 'function',
        begin: '^' + BASIC_ATOM_RE + '\\s*\\(', end: '->',
        returnBegin: true,
        illegal: '\\(|#|//|/\\*|\\\\|:|;',
        contains: [
          PARAMS,
          hljs.inherit(hljs.TITLE_MODE, {begin: BASIC_ATOM_RE})
        ],
        starts: {
          end: ';|\\.',
          keywords: ERLANG_RESERVED,
          contains: BASIC_MODES
        }
      },
      COMMENT,
      {
        className: 'pp',
        begin: '^-', end: '\\.',
        relevance: 0,
        excludeEnd: true,
        returnBegin: true,
        lexemes: '-' + hljs.IDENT_RE,
        keywords:
          '-module -record -undef -export -ifdef -ifndef -author -copyright -doc -vsn ' +
          '-import -include -include_lib -compile -define -else -endif -file -behaviour ' +
          '-behavior -spec',
        contains: [PARAMS]
      },
      NUMBER,
      hljs.QUOTE_STRING_MODE,
      RECORD_ACCESS,
      VAR1, VAR2,
      TUPLE,
      {begin: /\.$/} // relevance booster
    ]
  };
});

hljs.registerLanguage('fix', function(hljs) {
  return {
    contains: [
    {
      begin: /[^\u2401\u0001]+/,
      end: /[\u2401\u0001]/,
      excludeEnd: true,
      returnBegin: true,
      returnEnd: false,
      contains: [
      {
        begin: /([^\u2401\u0001=]+)/,
        end: /=([^\u2401\u0001=]+)/,
        returnEnd: true,
        returnBegin: false,
        className: 'attribute'
      },
      {
        begin: /=/,
        end: /([\u2401\u0001])/,
        excludeEnd: true,
        excludeBegin: true,
        className: 'string'
      }]
    }],
    case_insensitive: true
  };
});

hljs.registerLanguage('fortran', function(hljs) {
  var PARAMS = {
    className: 'params',
    begin: '\\(', end: '\\)'
  };

  var F_KEYWORDS = {
    constant: '.False. .True.',
    type: 'integer real character complex logical dimension allocatable|10 parameter ' +
      'external implicit|10 none double precision assign intent optional pointer ' +
      'target in out common equivalence data',
    keyword: 'kind do while private call intrinsic where elsewhere ' +
      'type endtype endmodule endselect endinterface end enddo endif if forall endforall only contains default return stop then ' +
      'public subroutine|10 function program .and. .or. .not. .le. .eq. .ge. .gt. .lt. ' +
      'goto save else use module select case ' +
      'access blank direct exist file fmt form formatted iostat name named nextrec number opened rec recl sequential status unformatted unit ' +
      'continue format pause cycle exit ' +
      'c_null_char c_alert c_backspace c_form_feed flush wait decimal round iomsg ' +
      'synchronous nopass non_overridable pass protected volatile abstract extends import ' +
      'non_intrinsic value deferred generic final enumerator class associate bind enum ' +
      'c_int c_short c_long c_long_long c_signed_char c_size_t c_int8_t c_int16_t c_int32_t c_int64_t c_int_least8_t c_int_least16_t ' +
      'c_int_least32_t c_int_least64_t c_int_fast8_t c_int_fast16_t c_int_fast32_t c_int_fast64_t c_intmax_t C_intptr_t c_float c_double ' +
      'c_long_double c_float_complex c_double_complex c_long_double_complex c_bool c_char c_null_ptr c_null_funptr ' +
      'c_new_line c_carriage_return c_horizontal_tab c_vertical_tab iso_c_binding c_loc c_funloc c_associated  c_f_pointer ' +
      'c_ptr c_funptr iso_fortran_env character_storage_size error_unit file_storage_size input_unit iostat_end iostat_eor ' +
      'numeric_storage_size output_unit c_f_procpointer ieee_arithmetic ieee_support_underflow_control ' +
      'ieee_get_underflow_mode ieee_set_underflow_mode newunit contiguous recursive ' +
      'pad position action delim readwrite eor advance nml interface procedure namelist include sequence elemental pure',
    built_in: 'alog alog10 amax0 amax1 amin0 amin1 amod cabs ccos cexp clog csin csqrt dabs dacos dasin datan datan2 dcos dcosh ddim dexp dint ' +
      'dlog dlog10 dmax1 dmin1 dmod dnint dsign dsin dsinh dsqrt dtan dtanh float iabs idim idint idnint ifix isign max0 max1 min0 min1 sngl ' +
      'algama cdabs cdcos cdexp cdlog cdsin cdsqrt cqabs cqcos cqexp cqlog cqsin cqsqrt dcmplx dconjg derf derfc dfloat dgamma dimag dlgama ' +
      'iqint qabs qacos qasin qatan qatan2 qcmplx qconjg qcos qcosh qdim qerf qerfc qexp qgamma qimag qlgama qlog qlog10 qmax1 qmin1 qmod ' +
      'qnint qsign qsin qsinh qsqrt qtan qtanh abs acos aimag aint anint asin atan atan2 char cmplx conjg cos cosh exp ichar index int log ' +
      'log10 max min nint sign sin sinh sqrt tan tanh print write dim lge lgt lle llt mod nullify allocate deallocate ' +
      'adjustl adjustr all allocated any associated bit_size btest ceiling count cshift date_and_time digits dot_product ' +
      'eoshift epsilon exponent floor fraction huge iand ibclr ibits ibset ieor ior ishft ishftc lbound len_trim matmul ' +
      'maxexponent maxloc maxval merge minexponent minloc minval modulo mvbits nearest pack present product ' +
      'radix random_number random_seed range repeat reshape rrspacing scale scan selected_int_kind selected_real_kind ' +
      'set_exponent shape size spacing spread sum system_clock tiny transpose trim ubound unpack verify achar iachar transfer ' +
      'dble entry dprod cpu_time command_argument_count get_command get_command_argument get_environment_variable is_iostat_end ' +
      'ieee_arithmetic ieee_support_underflow_control ieee_get_underflow_mode ieee_set_underflow_mode ' +
      'is_iostat_eor move_alloc new_line selected_char_kind same_type_as extends_type_of'  +
      'acosh asinh atanh bessel_j0 bessel_j1 bessel_jn bessel_y0 bessel_y1 bessel_yn erf erfc erfc_scaled gamma log_gamma hypot norm2 ' +
      'atomic_define atomic_ref execute_command_line leadz trailz storage_size merge_bits ' +
      'bge bgt ble blt dshiftl dshiftr findloc iall iany iparity image_index lcobound ucobound maskl maskr ' +
      'num_images parity popcnt poppar shifta shiftl shiftr this_image'
  };
  return {
    case_insensitive: true,
    aliases: ['f90', 'f95'],
    keywords: F_KEYWORDS,
    illegal: /\/\*/,
    contains: [
      hljs.inherit(hljs.APOS_STRING_MODE, {className: 'string', relevance: 0}),
      hljs.inherit(hljs.QUOTE_STRING_MODE, {className: 'string', relevance: 0}),
      {
        className: 'function',
        beginKeywords: 'subroutine function program',
        illegal: '[${=\\n]',
        contains: [hljs.UNDERSCORE_TITLE_MODE, PARAMS]
      },
      hljs.COMMENT('!', '$', {relevance: 0}),
      {
        className: 'number',
        begin: '(?=\\b|\\+|\\-|\\.)(?=\\.\\d|\\d)(?:\\d+)?(?:\\.?\\d*)(?:[de][+-]?\\d+)?\\b\\.?',
        relevance: 0
      }
    ]
  };
});

hljs.registerLanguage('fsharp', function(hljs) {
  var TYPEPARAM = {
    begin: '<', end: '>',
    contains: [
      hljs.inherit(hljs.TITLE_MODE, {begin: /'[a-zA-Z0-9_]+/})
    ]
  };

  return {
    aliases: ['fs'],
    keywords:
      'abstract and as assert base begin class default delegate do done ' +
      'downcast downto elif else end exception extern false finally for ' +
      'fun function global if in inherit inline interface internal lazy let ' +
      'match member module mutable namespace new null of open or ' +
      'override private public rec return sig static struct then to ' +
      'true try type upcast use val void when while with yield',
    illegal: /\/\*/,
    contains: [
      {
        // monad builder keywords (matches before non-bang kws)
        className: 'keyword',
        begin: /\b(yield|return|let|do)!/
      },
      {
        className: 'string',
        begin: '@"', end: '"',
        contains: [{begin: '""'}]
      },
      {
        className: 'string',
        begin: '"""', end: '"""'
      },
      hljs.COMMENT('\\(\\*', '\\*\\)'),
      {
        className: 'class',
        beginKeywords: 'type', end: '\\(|=|$', excludeEnd: true,
        contains: [
          hljs.UNDERSCORE_TITLE_MODE,
          TYPEPARAM
        ]
      },
      {
        className: 'annotation',
        begin: '\\[<', end: '>\\]',
        relevance: 10
      },
      {
        className: 'attribute',
        begin: '\\B(\'[A-Za-z])\\b',
        contains: [hljs.BACKSLASH_ESCAPE]
      },
      hljs.C_LINE_COMMENT_MODE,
      hljs.inherit(hljs.QUOTE_STRING_MODE, {illegal: null}),
      hljs.C_NUMBER_MODE
    ]
  };
});

hljs.registerLanguage('gams', function (hljs) {
  var KEYWORDS =
    'abort acronym acronyms alias all and assign binary card diag display else1 eps eq equation equations file files ' +
    'for1 free ge gt if inf integer le loop lt maximizing minimizing model models na ne negative no not option ' +
    'options or ord parameter parameters positive prod putpage puttl repeat sameas scalar scalars semicont semiint ' +
    'set1 sets smax smin solve sos1 sos2 sum system table then until using variable variables while1 xor yes';

  return {
    aliases: ['gms'],
    case_insensitive: true,
    keywords: KEYWORDS,
    contains: [
      {
        className: 'section',
        beginKeywords: 'sets parameters variables equations',
        end: ';',
        contains: [
          {
            begin: '/',
            end: '/',
            contains: [hljs.NUMBER_MODE]
          }
        ]
      },
      {
        className: 'string',
        begin: '\\*{3}', end: '\\*{3}'
      },
      hljs.NUMBER_MODE,
      {
        className: 'number',
        begin: '\\$[a-zA-Z0-9]+'
      }
    ]
  };
});

hljs.registerLanguage('gcode', function(hljs) {
    var GCODE_IDENT_RE = '[A-Z_][A-Z0-9_.]*';
    var GCODE_CLOSE_RE = '\\%';
    var GCODE_KEYWORDS = {
        literal:
            '',
        built_in:
            '',
        keyword:
            'IF DO WHILE ENDWHILE CALL ENDIF SUB ENDSUB GOTO REPEAT ENDREPEAT ' +
            'EQ LT GT NE GE LE OR XOR'
    };
    var GCODE_START = {
        className: 'preprocessor',
        begin: '([O])([0-9]+)'
    };
    var GCODE_CODE = [
        hljs.C_LINE_COMMENT_MODE,
        hljs.C_BLOCK_COMMENT_MODE,
        hljs.COMMENT(/\(/, /\)/),
        hljs.inherit(hljs.C_NUMBER_MODE, {begin: '([-+]?([0-9]*\\.?[0-9]+\\.?))|' + hljs.C_NUMBER_RE}),
        hljs.inherit(hljs.APOS_STRING_MODE, {illegal: null}),
        hljs.inherit(hljs.QUOTE_STRING_MODE, {illegal: null}),
        {
            className: 'keyword',
            begin: '([G])([0-9]+\\.?[0-9]?)'
        },
        {
            className: 'title',
            begin: '([M])([0-9]+\\.?[0-9]?)'
        },
        {
            className: 'title',
            begin: '(VC|VS|#)',
            end: '(\\d+)'
        },
        {
            className: 'title',
            begin: '(VZOFX|VZOFY|VZOFZ)'
        },
        {
            className: 'built_in',
            begin: '(ATAN|ABS|ACOS|ASIN|SIN|COS|EXP|FIX|FUP|ROUND|LN|TAN)(\\[)',
            end: '([-+]?([0-9]*\\.?[0-9]+\\.?))(\\])'
        },
        {
            className: 'label',
            variants: [
                {
                    begin: 'N', end: '\\d+',
                    illegal: '\\W'
                }
            ]
        }
    ];

    return {
        aliases: ['nc'],
        // Some implementations (CNC controls) of G-code are interoperable with uppercase and lowercase letters seamlessly.
        // However, most prefer all uppercase and uppercase is customary.
        case_insensitive: true,
        lexemes: GCODE_IDENT_RE,
        keywords: GCODE_KEYWORDS,
        contains: [
            {
                className: 'preprocessor',
                begin: GCODE_CLOSE_RE
            },
            GCODE_START
        ].concat(GCODE_CODE)
    };
});

hljs.registerLanguage('gherkin', function (hljs) {
  return {
    aliases: ['feature'],
    keywords: 'Feature Background Ability Business\ Need Scenario Scenarios Scenario\ Outline Scenario\ Template Examples Given And Then But When',
    contains: [
      {
        className: 'keyword',
        begin: '\\*'
      },
      hljs.COMMENT('@[^@\r\n\t ]+', '$'),
      {
        begin: '\\|', end: '\\|\\w*$',
        contains: [
          {
            className: 'string',
            begin: '[^|]+'
          }
        ]
      },
      {
        className: 'variable',
        begin: '<', end: '>'
      },
      hljs.HASH_COMMENT_MODE,
      {
        className: 'string',
        begin: '"""', end: '"""'
      },
      hljs.QUOTE_STRING_MODE
    ]
  };
});

hljs.registerLanguage('glsl', function(hljs) {
  return {
    keywords: {
      keyword:
        'atomic_uint attribute bool break bvec2 bvec3 bvec4 case centroid coherent const continue default ' +
        'discard dmat2 dmat2x2 dmat2x3 dmat2x4 dmat3 dmat3x2 dmat3x3 dmat3x4 dmat4 dmat4x2 dmat4x3 ' +
        'dmat4x4 do double dvec2 dvec3 dvec4 else flat float for highp if iimage1D iimage1DArray ' +
        'iimage2D iimage2DArray iimage2DMS iimage2DMSArray iimage2DRect iimage3D iimageBuffer iimageCube ' +
        'iimageCubeArray image1D image1DArray image2D image2DArray image2DMS image2DMSArray image2DRect ' +
        'image3D imageBuffer imageCube imageCubeArray in inout int invariant isampler1D isampler1DArray ' +
        'isampler2D isampler2DArray isampler2DMS isampler2DMSArray isampler2DRect isampler3D isamplerBuffer ' +
        'isamplerCube isamplerCubeArray ivec2 ivec3 ivec4 layout lowp mat2 mat2x2 mat2x3 mat2x4 mat3 mat3x2 ' +
        'mat3x3 mat3x4 mat4 mat4x2 mat4x3 mat4x4 mediump noperspective out patch precision readonly restrict ' +
        'return sample sampler1D sampler1DArray sampler1DArrayShadow sampler1DShadow sampler2D sampler2DArray ' +
        'sampler2DArrayShadow sampler2DMS sampler2DMSArray sampler2DRect sampler2DRectShadow sampler2DShadow ' +
        'sampler3D samplerBuffer samplerCube samplerCubeArray samplerCubeArrayShadow samplerCubeShadow smooth ' +
        'struct subroutine switch uimage1D uimage1DArray uimage2D uimage2DArray uimage2DMS uimage2DMSArray ' +
        'uimage2DRect uimage3D uimageBuffer uimageCube uimageCubeArray uint uniform usampler1D usampler1DArray ' +
        'usampler2D usampler2DArray usampler2DMS usampler2DMSArray usampler2DRect usampler3D usamplerBuffer ' +
        'usamplerCube usamplerCubeArray uvec2 uvec3 uvec4 varying vec2 vec3 vec4 void volatile while writeonly',
      built_in:
        'gl_BackColor gl_BackLightModelProduct gl_BackLightProduct gl_BackMaterial ' +
        'gl_BackSecondaryColor gl_ClipDistance gl_ClipPlane gl_ClipVertex gl_Color ' +
        'gl_DepthRange gl_EyePlaneQ gl_EyePlaneR gl_EyePlaneS gl_EyePlaneT gl_Fog gl_FogCoord ' +
        'gl_FogFragCoord gl_FragColor gl_FragCoord gl_FragData gl_FragDepth gl_FrontColor ' +
        'gl_FrontFacing gl_FrontLightModelProduct gl_FrontLightProduct gl_FrontMaterial ' +
        'gl_FrontSecondaryColor gl_InstanceID gl_InvocationID gl_Layer gl_LightModel ' +
        'gl_LightSource gl_MaxAtomicCounterBindings gl_MaxAtomicCounterBufferSize ' +
        'gl_MaxClipDistances gl_MaxClipPlanes gl_MaxCombinedAtomicCounterBuffers ' +
        'gl_MaxCombinedAtomicCounters gl_MaxCombinedImageUniforms gl_MaxCombinedImageUnitsAndFragmentOutputs ' +
        'gl_MaxCombinedTextureImageUnits gl_MaxDrawBuffers gl_MaxFragmentAtomicCounterBuffers ' +
        'gl_MaxFragmentAtomicCounters gl_MaxFragmentImageUniforms gl_MaxFragmentInputComponents ' +
        'gl_MaxFragmentUniformComponents gl_MaxFragmentUniformVectors gl_MaxGeometryAtomicCounterBuffers ' +
        'gl_MaxGeometryAtomicCounters gl_MaxGeometryImageUniforms gl_MaxGeometryInputComponents ' +
        'gl_MaxGeometryOutputComponents gl_MaxGeometryOutputVertices gl_MaxGeometryTextureImageUnits ' +
        'gl_MaxGeometryTotalOutputComponents gl_MaxGeometryUniformComponents gl_MaxGeometryVaryingComponents ' +
        'gl_MaxImageSamples gl_MaxImageUnits gl_MaxLights gl_MaxPatchVertices gl_MaxProgramTexelOffset ' +
        'gl_MaxTessControlAtomicCounterBuffers gl_MaxTessControlAtomicCounters gl_MaxTessControlImageUniforms ' +
        'gl_MaxTessControlInputComponents gl_MaxTessControlOutputComponents gl_MaxTessControlTextureImageUnits ' +
        'gl_MaxTessControlTotalOutputComponents gl_MaxTessControlUniformComponents ' +
        'gl_MaxTessEvaluationAtomicCounterBuffers gl_MaxTessEvaluationAtomicCounters ' +
        'gl_MaxTessEvaluationImageUniforms gl_MaxTessEvaluationInputComponents gl_MaxTessEvaluationOutputComponents ' +
        'gl_MaxTessEvaluationTextureImageUnits gl_MaxTessEvaluationUniformComponents ' +
        'gl_MaxTessGenLevel gl_MaxTessPatchComponents gl_MaxTextureCoords gl_MaxTextureImageUnits ' +
        'gl_MaxTextureUnits gl_MaxVaryingComponents gl_MaxVaryingFloats gl_MaxVaryingVectors ' +
        'gl_MaxVertexAtomicCounterBuffers gl_MaxVertexAtomicCounters gl_MaxVertexAttribs ' +
        'gl_MaxVertexImageUniforms gl_MaxVertexOutputComponents gl_MaxVertexTextureImageUnits ' +
        'gl_MaxVertexUniformComponents gl_MaxVertexUniformVectors gl_MaxViewports gl_MinProgramTexelOffset'+
        'gl_ModelViewMatrix gl_ModelViewMatrixInverse gl_ModelViewMatrixInverseTranspose ' +
        'gl_ModelViewMatrixTranspose gl_ModelViewProjectionMatrix gl_ModelViewProjectionMatrixInverse ' +
        'gl_ModelViewProjectionMatrixInverseTranspose gl_ModelViewProjectionMatrixTranspose ' +
        'gl_MultiTexCoord0 gl_MultiTexCoord1 gl_MultiTexCoord2 gl_MultiTexCoord3 gl_MultiTexCoord4 ' +
        'gl_MultiTexCoord5 gl_MultiTexCoord6 gl_MultiTexCoord7 gl_Normal gl_NormalMatrix ' +
        'gl_NormalScale gl_ObjectPlaneQ gl_ObjectPlaneR gl_ObjectPlaneS gl_ObjectPlaneT gl_PatchVerticesIn ' +
        'gl_PerVertex gl_Point gl_PointCoord gl_PointSize gl_Position gl_PrimitiveID gl_PrimitiveIDIn ' +
        'gl_ProjectionMatrix gl_ProjectionMatrixInverse gl_ProjectionMatrixInverseTranspose ' +
        'gl_ProjectionMatrixTranspose gl_SampleID gl_SampleMask gl_SampleMaskIn gl_SamplePosition ' +
        'gl_SecondaryColor gl_TessCoord gl_TessLevelInner gl_TessLevelOuter gl_TexCoord gl_TextureEnvColor ' +
        'gl_TextureMatrixInverseTranspose gl_TextureMatrixTranspose gl_Vertex gl_VertexID ' +
        'gl_ViewportIndex gl_in gl_out EmitStreamVertex EmitVertex EndPrimitive EndStreamPrimitive ' +
        'abs acos acosh all any asin asinh atan atanh atomicCounter atomicCounterDecrement ' +
        'atomicCounterIncrement barrier bitCount bitfieldExtract bitfieldInsert bitfieldReverse ' +
        'ceil clamp cos cosh cross dFdx dFdy degrees determinant distance dot equal exp exp2 faceforward ' +
        'findLSB findMSB floatBitsToInt floatBitsToUint floor fma fract frexp ftransform fwidth greaterThan ' +
        'greaterThanEqual imageAtomicAdd imageAtomicAnd imageAtomicCompSwap imageAtomicExchange ' +
        'imageAtomicMax imageAtomicMin imageAtomicOr imageAtomicXor imageLoad imageStore imulExtended ' +
        'intBitsToFloat interpolateAtCentroid interpolateAtOffset interpolateAtSample inverse inversesqrt ' +
        'isinf isnan ldexp length lessThan lessThanEqual log log2 matrixCompMult max memoryBarrier ' +
        'min mix mod modf noise1 noise2 noise3 noise4 normalize not notEqual outerProduct packDouble2x32 ' +
        'packHalf2x16 packSnorm2x16 packSnorm4x8 packUnorm2x16 packUnorm4x8 pow radians reflect refract ' +
        'round roundEven shadow1D shadow1DLod shadow1DProj shadow1DProjLod shadow2D shadow2DLod shadow2DProj ' +
        'shadow2DProjLod sign sin sinh smoothstep sqrt step tan tanh texelFetch texelFetchOffset texture ' +
        'texture1D texture1DLod texture1DProj texture1DProjLod texture2D texture2DLod texture2DProj ' +
        'texture2DProjLod texture3D texture3DLod texture3DProj texture3DProjLod textureCube textureCubeLod ' +
        'textureGather textureGatherOffset textureGatherOffsets textureGrad textureGradOffset textureLod ' +
        'textureLodOffset textureOffset textureProj textureProjGrad textureProjGradOffset textureProjLod ' +
        'textureProjLodOffset textureProjOffset textureQueryLod textureSize transpose trunc uaddCarry ' +
        'uintBitsToFloat umulExtended unpackDouble2x32 unpackHalf2x16 unpackSnorm2x16 unpackSnorm4x8 ' +
        'unpackUnorm2x16 unpackUnorm4x8 usubBorrow gl_TextureMatrix gl_TextureMatrixInverse',
      literal: 'true false'
    },
    illegal: '"',
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.C_NUMBER_MODE,
      {
        className: 'preprocessor',
        begin: '#', end: '$'
      }
    ]
  };
});

hljs.registerLanguage('go', function(hljs) {
  var GO_KEYWORDS = {
    keyword:
      'break default func interface select case map struct chan else goto package switch ' +
      'const fallthrough if range type continue for import return var go defer',
    constant:
       'true false iota nil',
    typename:
      'bool byte complex64 complex128 float32 float64 int8 int16 int32 int64 string uint8 ' +
      'uint16 uint32 uint64 int uint uintptr rune',
    built_in:
      'append cap close complex copy imag len make new panic print println real recover delete'
  };
  return {
    aliases: ["golang"],
    keywords: GO_KEYWORDS,
    illegal: '</',
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.QUOTE_STRING_MODE,
      {
        className: 'string',
        begin: '\'', end: '[^\\\\]\''
      },
      {
        className: 'string',
        begin: '`', end: '`'
      },
      {
        className: 'number',
        begin: hljs.C_NUMBER_RE + '[dflsi]?',
        relevance: 0
      },
      hljs.C_NUMBER_MODE
    ]
  };
});

hljs.registerLanguage('golo', function(hljs) {
    return {
      keywords: {
        keyword:
          'println readln print import module function local return let var ' +
          'while for foreach times in case when match with break continue ' +
          'augment augmentation each find filter reduce ' +
          'if then else otherwise try catch finally raise throw orIfNull',
        typename:
          'DynamicObject|10 DynamicVariable struct Observable map set vector list array',
        literal:
          'true false null'
      },
      contains: [
        hljs.HASH_COMMENT_MODE,
        hljs.QUOTE_STRING_MODE,
        hljs.C_NUMBER_MODE,
        {
          className: 'annotation', begin: '@[A-Za-z]+'
        }
      ]
    }
});

hljs.registerLanguage('gradle', function(hljs) {
  return {
    case_insensitive: true,
    keywords: {
      keyword:
        'task project allprojects subprojects artifacts buildscript configurations ' +
        'dependencies repositories sourceSets description delete from into include ' +
        'exclude source classpath destinationDir includes options sourceCompatibility ' +
        'targetCompatibility group flatDir doLast doFirst flatten todir fromdir ant ' +
        'def abstract break case catch continue default do else extends final finally ' +
        'for if implements instanceof native new private protected public return static ' +
        'switch synchronized throw throws transient try volatile while strictfp package ' +
        'import false null super this true antlrtask checkstyle codenarc copy boolean ' +
        'byte char class double float int interface long short void compile runTime ' +
        'file fileTree abs any append asList asWritable call collect compareTo count ' +
        'div dump each eachByte eachFile eachLine every find findAll flatten getAt ' +
        'getErr getIn getOut getText grep immutable inject inspect intersect invokeMethods ' +
        'isCase join leftShift minus multiply newInputStream newOutputStream newPrintWriter ' +
        'newReader newWriter next plus pop power previous print println push putAt read ' +
        'readBytes readLines reverse reverseEach round size sort splitEachLine step subMap ' +
        'times toInteger toList tokenize upto waitForOrKill withPrintWriter withReader ' +
        'withStream withWriter withWriterAppend write writeLine'
    },
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      hljs.NUMBER_MODE,
      hljs.REGEXP_MODE

    ]
  }
});

hljs.registerLanguage('groovy', function(hljs) {
    return {
        keywords: {
            typename: 'byte short char int long boolean float double void',
            literal : 'true false null',
            keyword:
            // groovy specific keywords
            'def as in assert trait ' +
            // common keywords with Java
            'super this abstract static volatile transient public private protected synchronized final ' +
            'class interface enum if else for while switch case break default continue ' +
            'throw throws try catch finally implements extends new import package return instanceof'
        },

        contains: [
            hljs.COMMENT(
                '/\\*\\*',
                '\\*/',
                {
                    relevance : 0,
                    contains : [{
                        className : 'doctag',
                        begin : '@[A-Za-z]+'
                    }]
                }
            ),
            hljs.C_LINE_COMMENT_MODE,
            hljs.C_BLOCK_COMMENT_MODE,
            {
                className: 'string',
                begin: '"""', end: '"""'
            },
            {
                className: 'string',
                begin: "'''", end: "'''"
            },
            {
                className: 'string',
                begin: "\\$/", end: "/\\$",
                relevance: 10
            },
            hljs.APOS_STRING_MODE,
            {
                className: 'regexp',
                begin: /~?\/[^\/\n]+\//,
                contains: [
                    hljs.BACKSLASH_ESCAPE
                ]
            },
            hljs.QUOTE_STRING_MODE,
            {
                className: 'shebang',
                begin: "^#!/usr/bin/env", end: '$',
                illegal: '\n'
            },
            hljs.BINARY_NUMBER_MODE,
            {
                className: 'class',
                beginKeywords: 'class interface trait enum', end: '{',
                illegal: ':',
                contains: [
                    {beginKeywords: 'extends implements'},
                    hljs.UNDERSCORE_TITLE_MODE,
                ]
            },
            hljs.C_NUMBER_MODE,
            {
                className: 'annotation', begin: '@[A-Za-z]+'
            },
            {
                // highlight map keys and named parameters as strings
                className: 'string', begin: /[^\?]{0}[A-Za-z0-9_$]+ *:/
            },
            {
                // catch middle element of the ternary operator
                // to avoid highlight it as a label, named parameter, or map key
                begin: /\?/, end: /\:/
            },
            {
                // highlight labeled statements
                className: 'label', begin: '^\\s*[A-Za-z0-9_$]+:',
                relevance: 0
            },
        ],
        illegal: /#/
    }
});

hljs.registerLanguage('haml', // TODO support filter tags like :javascript, support inline HTML
function(hljs) {
  return {
    case_insensitive: true,
    contains: [
      {
        className: 'doctype',
        begin: '^!!!( (5|1\\.1|Strict|Frameset|Basic|Mobile|RDFa|XML\\b.*))?$',
        relevance: 10
      },
      // FIXME these comments should be allowed to span indented lines
      hljs.COMMENT(
        '^\\s*(!=#|=#|-#|/).*$',
        false,
        {
          relevance: 0
        }
      ),
      {
        begin: '^\\s*(-|=|!=)(?!#)',
        starts: {
          end: '\\n',
          subLanguage: 'ruby'
        }
      },
      {
        className: 'tag',
        begin: '^\\s*%',
        contains: [
          {
            className: 'title',
            begin: '\\w+'
          },
          {
            className: 'value',
            begin: '[#\\.][\\w-]+'
          },
          {
            begin: '{\\s*',
            end: '\\s*}',
            excludeEnd: true,
            contains: [
              {
                //className: 'attribute',
                begin: ':\\w+\\s*=>',
                end: ',\\s+',
                returnBegin: true,
                endsWithParent: true,
                contains: [
                  {
                    className: 'symbol',
                    begin: ':\\w+'
                  },
                  hljs.APOS_STRING_MODE,
                  hljs.QUOTE_STRING_MODE,
                  {
                    begin: '\\w+',
                    relevance: 0
                  }
                ]
              }
            ]
          },
          {
            begin: '\\(\\s*',
            end: '\\s*\\)',
            excludeEnd: true,
            contains: [
              {
                //className: 'attribute',
                begin: '\\w+\\s*=',
                end: '\\s+',
                returnBegin: true,
                endsWithParent: true,
                contains: [
                  {
                    className: 'attribute',
                    begin: '\\w+',
                    relevance: 0
                  },
                  hljs.APOS_STRING_MODE,
                  hljs.QUOTE_STRING_MODE,
                  {
                    begin: '\\w+',
                    relevance: 0
                  }
                ]
              }
            ]
          }
        ]
      },
      {
        className: 'bullet',
        begin: '^\\s*[=~]\\s*',
        relevance: 0
      },
      {
        begin: '#{',
        starts: {
          end: '}',
          subLanguage: 'ruby'
        }
      }
    ]
  };
});

hljs.registerLanguage('handlebars', function(hljs) {
  var EXPRESSION_KEYWORDS = 'each in with if else unless bindattr action collection debugger log outlet template unbound view yield';
  return {
    aliases: ['hbs', 'html.hbs', 'html.handlebars'],
    case_insensitive: true,
    subLanguage: 'xml',
    contains: [
      {
        className: 'expression',
        begin: '{{', end: '}}',
        contains: [
          {
            className: 'begin-block', begin: '\#[a-zA-Z\-\ \.]+',
            keywords: EXPRESSION_KEYWORDS
          },
          {
            className: 'string',
            begin: '"', end: '"'
          },
          {
            className: 'end-block', begin: '\\\/[a-zA-Z\-\ \.]+',
            keywords: EXPRESSION_KEYWORDS
          },
          {
            className: 'variable', begin: '[a-zA-Z\-\.]+',
            keywords: EXPRESSION_KEYWORDS
          }
        ]
      }
    ]
  };
});

hljs.registerLanguage('haskell', function(hljs) {
  var COMMENT_MODES = [
    hljs.COMMENT('--', '$'),
    hljs.COMMENT(
      '{-',
      '-}',
      {
        contains: ['self']
      }
    )
  ];

  var PRAGMA = {
    className: 'pragma',
    begin: '{-#', end: '#-}'
  };

  var PREPROCESSOR = {
    className: 'preprocessor',
    begin: '^#', end: '$'
  };

  var CONSTRUCTOR = {
    className: 'type',
    begin: '\\b[A-Z][\\w\']*', // TODO: other constructors (build-in, infix).
    relevance: 0
  };

  var LIST = {
    className: 'container',
    begin: '\\(', end: '\\)',
    illegal: '"',
    contains: [
      PRAGMA,
      PREPROCESSOR,
      {className: 'type', begin: '\\b[A-Z][\\w]*(\\((\\.\\.|,|\\w+)\\))?'},
      hljs.inherit(hljs.TITLE_MODE, {begin: '[_a-z][\\w\']*'})
    ].concat(COMMENT_MODES)
  };

  var RECORD = {
    className: 'container',
    begin: '{', end: '}',
    contains: LIST.contains
  };

  return {
    aliases: ['hs'],
    keywords:
      'let in if then else case of where do module import hiding ' +
      'qualified type data newtype deriving class instance as default ' +
      'infix infixl infixr foreign export ccall stdcall cplusplus ' +
      'jvm dotnet safe unsafe family forall mdo proc rec',
    contains: [

      // Top-level constructions.

      {
        className: 'module',
        begin: '\\bmodule\\b', end: 'where',
        keywords: 'module where',
        contains: [LIST].concat(COMMENT_MODES),
        illegal: '\\W\\.|;'
      },
      {
        className: 'import',
        begin: '\\bimport\\b', end: '$',
        keywords: 'import|0 qualified as hiding',
        contains: [LIST].concat(COMMENT_MODES),
        illegal: '\\W\\.|;'
      },

      {
        className: 'class',
        begin: '^(\\s*)?(class|instance)\\b', end: 'where',
        keywords: 'class family instance where',
        contains: [CONSTRUCTOR, LIST].concat(COMMENT_MODES)
      },
      {
        className: 'typedef',
        begin: '\\b(data|(new)?type)\\b', end: '$',
        keywords: 'data family type newtype deriving',
        contains: [PRAGMA, CONSTRUCTOR, LIST, RECORD].concat(COMMENT_MODES)
      },
      {
        className: 'default',
        beginKeywords: 'default', end: '$',
        contains: [CONSTRUCTOR, LIST].concat(COMMENT_MODES)
      },
      {
        className: 'infix',
        beginKeywords: 'infix infixl infixr', end: '$',
        contains: [hljs.C_NUMBER_MODE].concat(COMMENT_MODES)
      },
      {
        className: 'foreign',
        begin: '\\bforeign\\b', end: '$',
        keywords: 'foreign import export ccall stdcall cplusplus jvm ' +
                  'dotnet safe unsafe',
        contains: [CONSTRUCTOR, hljs.QUOTE_STRING_MODE].concat(COMMENT_MODES)
      },
      {
        className: 'shebang',
        begin: '#!\\/usr\\/bin\\/env\ runhaskell', end: '$'
      },

      // "Whitespaces".

      PRAGMA,
      PREPROCESSOR,

      // Literals and names.

      // TODO: characters.
      hljs.QUOTE_STRING_MODE,
      hljs.C_NUMBER_MODE,
      CONSTRUCTOR,
      hljs.inherit(hljs.TITLE_MODE, {begin: '^[_a-z][\\w\']*'}),

      {begin: '->|<-'} // No markup, relevance booster
    ].concat(COMMENT_MODES)
  };
});

hljs.registerLanguage('haxe', function(hljs) {
  var IDENT_RE = '[a-zA-Z_$][a-zA-Z0-9_$]*';
  var IDENT_FUNC_RETURN_TYPE_RE = '([*]|[a-zA-Z_$][a-zA-Z0-9_$]*)';

  return {
    aliases: ['hx'],
    keywords: {
      keyword: 'break callback case cast catch class continue default do dynamic else enum extends extern ' +
    'for function here if implements import in inline interface never new override package private ' +
    'public return static super switch this throw trace try typedef untyped using var while',
      literal: 'true false null'
    },
    contains: [
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.C_NUMBER_MODE,
      {
        className: 'class',
        beginKeywords: 'class interface', end: '{', excludeEnd: true,
        contains: [
          {
            beginKeywords: 'extends implements'
          },
          hljs.TITLE_MODE
        ]
      },
      {
        className: 'preprocessor',
        begin: '#', end: '$',
        keywords: 'if else elseif end error'
      },
      {
        className: 'function',
        beginKeywords: 'function', end: '[{;]', excludeEnd: true,
        illegal: '\\S',
        contains: [
          hljs.TITLE_MODE,
          {
            className: 'params',
            begin: '\\(', end: '\\)',
            contains: [
              hljs.APOS_STRING_MODE,
              hljs.QUOTE_STRING_MODE,
              hljs.C_LINE_COMMENT_MODE,
              hljs.C_BLOCK_COMMENT_MODE
            ]
          },
          {
            className: 'type',
            begin: ':',
            end: IDENT_FUNC_RETURN_TYPE_RE,
            relevance: 10
          }
        ]
      }
    ]
  };
});

hljs.registerLanguage('http', function(hljs) {
  return {
    aliases: ['https'],
    illegal: '\\S',
    contains: [
      {
        className: 'status',
        begin: '^HTTP/[0-9\\.]+', end: '$',
        contains: [{className: 'number', begin: '\\b\\d{3}\\b'}]
      },
      {
        className: 'request',
        begin: '^[A-Z]+ (.*?) HTTP/[0-9\\.]+$', returnBegin: true, end: '$',
        contains: [
          {
            className: 'string',
            begin: ' ', end: ' ',
            excludeBegin: true, excludeEnd: true
          }
        ]
      },
      {
        className: 'attribute',
        begin: '^\\w', end: ': ', excludeEnd: true,
        illegal: '\\n|\\s|=',
        starts: {className: 'string', end: '$'}
      },
      {
        begin: '\\n\\n',
        starts: {subLanguage: [], endsWithParent: true}
      }
    ]
  };
});

hljs.registerLanguage('inform7', function(hljs) {
  var START_BRACKET = '\\[';
  var END_BRACKET = '\\]';
  return {
    aliases: ['i7'],
    case_insensitive: true,
    keywords: {
      // Some keywords more or less unique to I7, for relevance.
      keyword:
        // kind:
        'thing room person man woman animal container ' +
        'supporter backdrop door ' +
        // characteristic:
        'scenery open closed locked inside gender ' +
        // verb:
        'is are say understand ' +
        // misc keyword:
        'kind of rule'
    },
    contains: [
      {
        className: 'string',
        begin: '"', end: '"',
        relevance: 0,
        contains: [
          {
            className: 'subst',
            begin: START_BRACKET, end: END_BRACKET
          }
        ]
      },
      {
        className: 'title',
        begin: /^(Volume|Book|Part|Chapter|Section|Table)\b/,
        end: '$'
      },
      {
        // Rule definition
        // This is here for relevance.
        begin: /^(Check|Carry out|Report|Instead of|To|Rule|When|Before|After)\b/,
        end: ':',
        contains: [
          {
            //Rule name
            begin: '\\b\\(This',
            end: '\\)'
          }
        ]
      },
      {
        className: 'comment',
        begin: START_BRACKET, end: END_BRACKET,
        contains: ['self']
      }
    ]
  };
});

hljs.registerLanguage('ini', function(hljs) {
  var STRING = {
    className: "string",
    contains: [hljs.BACKSLASH_ESCAPE],
    variants: [
      {
        begin: "'''", end: "'''",
        relevance: 10
      }, {
        begin: '"""', end: '"""',
        relevance: 10
      }, {
        begin: '"', end: '"'
      }, {
        begin: "'", end: "'"
      }
    ]
  };
  return {
    aliases: ['toml'],
    case_insensitive: true,
    illegal: /\S/,
    contains: [
      hljs.COMMENT(';', '$'),
      hljs.HASH_COMMENT_MODE,
      {
        className: 'title',
        begin: /^\s*\[+/, end: /\]+/
      },
      {
        className: 'setting',
        begin: /^[a-z0-9\[\]_-]+\s*=\s*/, end: '$',
        contains: [
          {
            className: 'value',
            endsWithParent: true,
            keywords: 'on off true false yes no',
            contains: [
              {
                className: 'variable',
                variants: [
                  {begin: /\$[\w\d"][\w\d_]*/},
                  {begin: /\$\{(.*?)}/}
                ]
              },
              STRING,
              {
                className: 'number',
                begin: /([\+\-]+)?[\d]+_[\d_]+/
              },
              hljs.NUMBER_MODE
            ],
            relevance: 0
          }
        ]
      }
    ]
  };
});

hljs.registerLanguage('irpf90', function(hljs) {
  var PARAMS = {
    className: 'params',
    begin: '\\(', end: '\\)'
  };

  var F_KEYWORDS = {
    constant: '.False. .True.',
    type: 'integer real character complex logical dimension allocatable|10 parameter ' +
      'external implicit|10 none double precision assign intent optional pointer ' +
      'target in out common equivalence data',
    keyword: 'kind do while private call intrinsic where elsewhere ' +
      'type endtype endmodule endselect endinterface end enddo endif if forall endforall only contains default return stop then ' +
      'public subroutine|10 function program .and. .or. .not. .le. .eq. .ge. .gt. .lt. ' +
      'goto save else use module select case ' +
      'access blank direct exist file fmt form formatted iostat name named nextrec number opened rec recl sequential status unformatted unit ' +
      'continue format pause cycle exit ' +
      'c_null_char c_alert c_backspace c_form_feed flush wait decimal round iomsg ' +
      'synchronous nopass non_overridable pass protected volatile abstract extends import ' +
      'non_intrinsic value deferred generic final enumerator class associate bind enum ' +
      'c_int c_short c_long c_long_long c_signed_char c_size_t c_int8_t c_int16_t c_int32_t c_int64_t c_int_least8_t c_int_least16_t ' +
      'c_int_least32_t c_int_least64_t c_int_fast8_t c_int_fast16_t c_int_fast32_t c_int_fast64_t c_intmax_t C_intptr_t c_float c_double ' +
      'c_long_double c_float_complex c_double_complex c_long_double_complex c_bool c_char c_null_ptr c_null_funptr ' +
      'c_new_line c_carriage_return c_horizontal_tab c_vertical_tab iso_c_binding c_loc c_funloc c_associated  c_f_pointer ' +
      'c_ptr c_funptr iso_fortran_env character_storage_size error_unit file_storage_size input_unit iostat_end iostat_eor ' +
      'numeric_storage_size output_unit c_f_procpointer ieee_arithmetic ieee_support_underflow_control ' +
      'ieee_get_underflow_mode ieee_set_underflow_mode newunit contiguous recursive ' +
      'pad position action delim readwrite eor advance nml interface procedure namelist include sequence elemental pure ' +
      // IRPF90 special keywords
      'begin_provider &begin_provider end_provider begin_shell end_shell begin_template end_template subst assert touch ' +
      'soft_touch provide no_dep free irp_if irp_else irp_endif irp_write irp_read',
    built_in: 'alog alog10 amax0 amax1 amin0 amin1 amod cabs ccos cexp clog csin csqrt dabs dacos dasin datan datan2 dcos dcosh ddim dexp dint ' +
      'dlog dlog10 dmax1 dmin1 dmod dnint dsign dsin dsinh dsqrt dtan dtanh float iabs idim idint idnint ifix isign max0 max1 min0 min1 sngl ' +
      'algama cdabs cdcos cdexp cdlog cdsin cdsqrt cqabs cqcos cqexp cqlog cqsin cqsqrt dcmplx dconjg derf derfc dfloat dgamma dimag dlgama ' +
      'iqint qabs qacos qasin qatan qatan2 qcmplx qconjg qcos qcosh qdim qerf qerfc qexp qgamma qimag qlgama qlog qlog10 qmax1 qmin1 qmod ' +
      'qnint qsign qsin qsinh qsqrt qtan qtanh abs acos aimag aint anint asin atan atan2 char cmplx conjg cos cosh exp ichar index int log ' +
      'log10 max min nint sign sin sinh sqrt tan tanh print write dim lge lgt lle llt mod nullify allocate deallocate ' +
      'adjustl adjustr all allocated any associated bit_size btest ceiling count cshift date_and_time digits dot_product ' +
      'eoshift epsilon exponent floor fraction huge iand ibclr ibits ibset ieor ior ishft ishftc lbound len_trim matmul ' +
      'maxexponent maxloc maxval merge minexponent minloc minval modulo mvbits nearest pack present product ' +
      'radix random_number random_seed range repeat reshape rrspacing scale scan selected_int_kind selected_real_kind ' +
      'set_exponent shape size spacing spread sum system_clock tiny transpose trim ubound unpack verify achar iachar transfer ' +
      'dble entry dprod cpu_time command_argument_count get_command get_command_argument get_environment_variable is_iostat_end ' +
      'ieee_arithmetic ieee_support_underflow_control ieee_get_underflow_mode ieee_set_underflow_mode ' +
      'is_iostat_eor move_alloc new_line selected_char_kind same_type_as extends_type_of'  +
      'acosh asinh atanh bessel_j0 bessel_j1 bessel_jn bessel_y0 bessel_y1 bessel_yn erf erfc erfc_scaled gamma log_gamma hypot norm2 ' +
      'atomic_define atomic_ref execute_command_line leadz trailz storage_size merge_bits ' +
      'bge bgt ble blt dshiftl dshiftr findloc iall iany iparity image_index lcobound ucobound maskl maskr ' +
      'num_images parity popcnt poppar shifta shiftl shiftr this_image ' +
      // IRPF90 special built_ins
      'IRP_ALIGN irp_here'
  };
  return {
    case_insensitive: true,
    keywords: F_KEYWORDS,
    illegal: /\/\*/,
    contains: [
      hljs.inherit(hljs.APOS_STRING_MODE, {className: 'string', relevance: 0}),
      hljs.inherit(hljs.QUOTE_STRING_MODE, {className: 'string', relevance: 0}),
      {
        className: 'function',
        beginKeywords: 'subroutine function program',
        illegal: '[${=\\n]',
        contains: [hljs.UNDERSCORE_TITLE_MODE, PARAMS]
      },
      hljs.COMMENT('!', '$', {relevance: 0}),
      hljs.COMMENT('begin_doc', 'end_doc', {relevance: 10}),
      {
        className: 'number',
        begin: '(?=\\b|\\+|\\-|\\.)(?=\\.\\d|\\d)(?:\\d+)?(?:\\.?\\d*)(?:[de][+-]?\\d+)?\\b\\.?',
        relevance: 0
      }
    ]
  };
});

hljs.registerLanguage('java', function(hljs) {
  var GENERIC_IDENT_RE = hljs.UNDERSCORE_IDENT_RE + '(<' + hljs.UNDERSCORE_IDENT_RE + '>)?';
  var KEYWORDS =
    'false synchronized int abstract float private char boolean static null if const ' +
    'for true while long strictfp finally protected import native final void ' +
    'enum else break transient catch instanceof byte super volatile case assert short ' +
    'package default double public try this switch continue throws protected public private';

  // https://docs.oracle.com/javase/7/docs/technotes/guides/language/underscores-literals.html
  var JAVA_NUMBER_RE = '\\b' +
    '(' +
      '0[bB]([01]+[01_]+[01]+|[01]+)' + // 0b...
      '|' +
      '0[xX]([a-fA-F0-9]+[a-fA-F0-9_]+[a-fA-F0-9]+|[a-fA-F0-9]+)' + // 0x...
      '|' +
      '(' +
        '([\\d]+[\\d_]+[\\d]+|[\\d]+)(\\.([\\d]+[\\d_]+[\\d]+|[\\d]+))?' +
        '|' +
        '\\.([\\d]+[\\d_]+[\\d]+|[\\d]+)' +
      ')' +
      '([eE][-+]?\\d+)?' + // octal, decimal, float
    ')' +
    '[lLfF]?';
  var JAVA_NUMBER_MODE = {
    className: 'number',
    begin: JAVA_NUMBER_RE,
    relevance: 0
  };

  return {
    aliases: ['jsp'],
    keywords: KEYWORDS,
    illegal: /<\/|#/,
    contains: [
      hljs.COMMENT(
        '/\\*\\*',
        '\\*/',
        {
          relevance : 0,
          contains : [{
            className : 'doctag',
            begin : '@[A-Za-z]+'
          }]
        }
      ),
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      {
        className: 'class',
        beginKeywords: 'class interface', end: /[{;=]/, excludeEnd: true,
        keywords: 'class interface',
        illegal: /[:"\[\]]/,
        contains: [
          {beginKeywords: 'extends implements'},
          hljs.UNDERSCORE_TITLE_MODE
        ]
      },
      {
        // Expression keywords prevent 'keyword Name(...)' from being
        // recognized as a function definition
        beginKeywords: 'new throw return else',
        relevance: 0
      },
      {
        className: 'function',
        begin: '(' + GENERIC_IDENT_RE + '\\s+)+' + hljs.UNDERSCORE_IDENT_RE + '\\s*\\(', returnBegin: true, end: /[{;=]/,
        excludeEnd: true,
        keywords: KEYWORDS,
        contains: [
          {
            begin: hljs.UNDERSCORE_IDENT_RE + '\\s*\\(', returnBegin: true,
            relevance: 0,
            contains: [hljs.UNDERSCORE_TITLE_MODE]
          },
          {
            className: 'params',
            begin: /\(/, end: /\)/,
            keywords: KEYWORDS,
            relevance: 0,
            contains: [
              hljs.APOS_STRING_MODE,
              hljs.QUOTE_STRING_MODE,
              hljs.C_NUMBER_MODE,
              hljs.C_BLOCK_COMMENT_MODE
            ]
          },
          hljs.C_LINE_COMMENT_MODE,
          hljs.C_BLOCK_COMMENT_MODE
        ]
      },
      JAVA_NUMBER_MODE,
      {
        className: 'annotation', begin: '@[A-Za-z]+'
      }
    ]
  };
});

hljs.registerLanguage('javascript', function(hljs) {
  return {
    aliases: ['js'],
    keywords: {
      keyword:
        'in of if for while finally var new function do return void else break catch ' +
        'instanceof with throw case default try this switch continue typeof delete ' +
        'let yield const export super debugger as async await',
      literal:
        'true false null undefined NaN Infinity',
      built_in:
        'eval isFinite isNaN parseFloat parseInt decodeURI decodeURIComponent ' +
        'encodeURI encodeURIComponent escape unescape Object Function Boolean Error ' +
        'EvalError InternalError RangeError ReferenceError StopIteration SyntaxError ' +
        'TypeError URIError Number Math Date String RegExp Array Float32Array ' +
        'Float64Array Int16Array Int32Array Int8Array Uint16Array Uint32Array ' +
        'Uint8Array Uint8ClampedArray ArrayBuffer DataView JSON Intl arguments require ' +
        'module console window document Symbol Set Map WeakSet WeakMap Proxy Reflect ' +
        'Promise'
    },
    contains: [
      {
        className: 'pi',
        relevance: 10,
        begin: /^\s*['"]use (strict|asm)['"]/
      },
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      { // template string
        className: 'string',
        begin: '`', end: '`',
        contains: [
          hljs.BACKSLASH_ESCAPE,
          {
            className: 'subst',
            begin: '\\$\\{', end: '\\}'
          }
        ]
      },
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      {
        className: 'number',
        variants: [
          { begin: '\\b(0[bB][01]+)' },
          { begin: '\\b(0[oO][0-7]+)' },
          { begin: hljs.C_NUMBER_RE }
        ],
        relevance: 0
      },
      { // "value" container
        begin: '(' + hljs.RE_STARTERS_RE + '|\\b(case|return|throw)\\b)\\s*',
        keywords: 'return throw case',
        contains: [
          hljs.C_LINE_COMMENT_MODE,
          hljs.C_BLOCK_COMMENT_MODE,
          hljs.REGEXP_MODE,
          { // E4X / JSX
            begin: /</, end: />\s*[);\]]/,
            relevance: 0,
            subLanguage: 'xml'
          }
        ],
        relevance: 0
      },
      {
        className: 'function',
        beginKeywords: 'function', end: /\{/, excludeEnd: true,
        contains: [
          hljs.inherit(hljs.TITLE_MODE, {begin: /[A-Za-z$_][0-9A-Za-z$_]*/}),
          {
            className: 'params',
            begin: /\(/, end: /\)/,
            excludeBegin: true,
            excludeEnd: true,
            contains: [
              hljs.C_LINE_COMMENT_MODE,
              hljs.C_BLOCK_COMMENT_MODE
            ]
          }
        ],
        illegal: /\[|%/
      },
      {
        begin: /\$[(.]/ // relevance booster for a pattern common to JS libs: `$(something)` and `$.something`
      },
      {
        begin: '\\.' + hljs.IDENT_RE, relevance: 0 // hack: prevents detection of keywords after dots
      },
      // ECMAScript 6 modules import
      {
        beginKeywords: 'import', end: '[;$]',
        keywords: 'import from as',
        contains: [
          hljs.APOS_STRING_MODE,
          hljs.QUOTE_STRING_MODE
        ]
      },
      { // ES6 class
        className: 'class',
        beginKeywords: 'class', end: /[{;=]/, excludeEnd: true,
        illegal: /[:"\[\]]/,
        contains: [
          {beginKeywords: 'extends'},
          hljs.UNDERSCORE_TITLE_MODE
        ]
      }
    ],
    illegal: /#/
  };
});

hljs.registerLanguage('json', function(hljs) {
  var LITERALS = {literal: 'true false null'};
  var TYPES = [
    hljs.QUOTE_STRING_MODE,
    hljs.C_NUMBER_MODE
  ];
  var VALUE_CONTAINER = {
    className: 'value',
    end: ',', endsWithParent: true, excludeEnd: true,
    contains: TYPES,
    keywords: LITERALS
  };
  var OBJECT = {
    begin: '{', end: '}',
    contains: [
      {
        className: 'attribute',
        begin: '\\s*"', end: '"\\s*:\\s*', excludeBegin: true, excludeEnd: true,
        contains: [hljs.BACKSLASH_ESCAPE],
        illegal: '\\n',
        starts: VALUE_CONTAINER
      }
    ],
    illegal: '\\S'
  };
  var ARRAY = {
    begin: '\\[', end: '\\]',
    contains: [hljs.inherit(VALUE_CONTAINER, {className: null})], // inherit is also a workaround for a bug that makes shared modes with endsWithParent compile only the ending of one of the parents
    illegal: '\\S'
  };
  TYPES.splice(TYPES.length, 0, OBJECT, ARRAY);
  return {
    contains: TYPES,
    keywords: LITERALS,
    illegal: '\\S'
  };
});

hljs.registerLanguage('julia', function(hljs) {
  // Since there are numerous special names in Julia, it is too much trouble
  // to maintain them by hand. Hence these names (i.e. keywords, literals and
  // built-ins) are automatically generated from Julia (v0.3.0) itself through
  // following scripts for each.

  var KEYWORDS = {
    // # keyword generator
    // println("\"in\",")
    // for kw in Base.REPLCompletions.complete_keyword("")
    //     println("\"$kw\",")
    // end
    keyword:
      'in abstract baremodule begin bitstype break catch ccall const continue do else elseif end export ' +
      'finally for function global if immutable import importall let local macro module quote return try type ' +
      'typealias using while',

    // # literal generator
    // println("\"true\",\n\"false\"")
    // for name in Base.REPLCompletions.completions("", 0)[1]
    //     try
    //         s = symbol(name)
    //         v = eval(s)
    //         if !isa(v, Function) &&
    //            !isa(v, DataType) &&
    //            !issubtype(typeof(v), Tuple) &&
    //            !isa(v, UnionType) &&
    //            !isa(v, Module) &&
    //            !isa(v, TypeConstructor) &&
    //            !isa(v, Colon)
    //             println("\"$name\",")
    //         end
    //     end
    // end
    literal:
      'true false ANY ARGS CPU_CORES C_NULL DL_LOAD_PATH DevNull ENDIAN_BOM ENV I|0 Inf Inf16 Inf32 ' +
      'InsertionSort JULIA_HOME LOAD_PATH MS_ASYNC MS_INVALIDATE MS_SYNC MergeSort NaN NaN16 NaN32 OS_NAME QuickSort ' +
      'RTLD_DEEPBIND RTLD_FIRST RTLD_GLOBAL RTLD_LAZY RTLD_LOCAL RTLD_NODELETE RTLD_NOLOAD RTLD_NOW RoundDown ' +
      'RoundFromZero RoundNearest RoundToZero RoundUp STDERR STDIN STDOUT VERSION WORD_SIZE catalan cglobal e|0 eu|0 ' +
      'eulergamma golden im nothing pi γ π φ',

    // # built_in generator:
    // for name in Base.REPLCompletions.completions("", 0)[1]
    //     try
    //         v = eval(symbol(name))
    //         if isa(v, DataType)
    //             println("\"$name\",")
    //         end
    //     end
    // end
    built_in:
      'ASCIIString AbstractArray AbstractRNG AbstractSparseArray Any ArgumentError Array Associative Base64Pipe ' +
      'Bidiagonal BigFloat BigInt BitArray BitMatrix BitVector Bool BoundsError Box CFILE Cchar Cdouble Cfloat Char ' +
      'CharString Cint Clong Clonglong ClusterManager Cmd Coff_t Colon Complex Complex128 Complex32 Complex64 ' +
      'Condition Cptrdiff_t Cshort Csize_t Cssize_t Cuchar Cuint Culong Culonglong Cushort Cwchar_t DArray DataType ' +
      'DenseArray Diagonal Dict DimensionMismatch DirectIndexString Display DivideError DomainError EOFError ' +
      'EachLine Enumerate ErrorException Exception Expr Factorization FileMonitor FileOffset Filter Float16 Float32 ' +
      'Float64 FloatRange FloatingPoint Function GetfieldNode GotoNode Hermitian IO IOBuffer IOStream IPv4 IPv6 ' +
      'InexactError Int Int128 Int16 Int32 Int64 Int8 IntSet Integer InterruptException IntrinsicFunction KeyError ' +
      'LabelNode LambdaStaticData LineNumberNode LoadError LocalProcess MIME MathConst MemoryError MersenneTwister ' +
      'Method MethodError MethodTable Module NTuple NewvarNode Nothing Number ObjectIdDict OrdinalRange ' +
      'OverflowError ParseError PollingFileWatcher ProcessExitedException ProcessGroup Ptr QuoteNode Range Range1 ' +
      'Ranges Rational RawFD Real Regex RegexMatch RemoteRef RepString RevString RopeString RoundingMode Set ' +
      'SharedArray Signed SparseMatrixCSC StackOverflowError Stat StatStruct StepRange String SubArray SubString ' +
      'SymTridiagonal Symbol SymbolNode Symmetric SystemError Task TextDisplay Timer TmStruct TopNode Triangular ' +
      'Tridiagonal Type TypeConstructor TypeError TypeName TypeVar UTF16String UTF32String UTF8String UdpSocket ' +
      'Uint Uint128 Uint16 Uint32 Uint64 Uint8 UndefRefError UndefVarError UniformScaling UnionType UnitRange ' +
      'Unsigned Vararg VersionNumber WString WeakKeyDict WeakRef Woodbury Zip'
  };

  // ref: http://julia.readthedocs.org/en/latest/manual/variables/#allowed-variable-names
  var VARIABLE_NAME_RE = "[A-Za-z_\\u00A1-\\uFFFF][A-Za-z_0-9\\u00A1-\\uFFFF]*";

  // placeholder for recursive self-reference
  var DEFAULT = { lexemes: VARIABLE_NAME_RE, keywords: KEYWORDS };

  var TYPE_ANNOTATION = {
    className: "type-annotation",
    begin: /::/
  };

  var SUBTYPE = {
    className: "subtype",
    begin: /<:/
  };

  // ref: http://julia.readthedocs.org/en/latest/manual/integers-and-floating-point-numbers/
  var NUMBER = {
    className: "number",
    // supported numeric literals:
    //  * binary literal (e.g. 0x10)
    //  * octal literal (e.g. 0o76543210)
    //  * hexadecimal literal (e.g. 0xfedcba876543210)
    //  * hexadecimal floating point literal (e.g. 0x1p0, 0x1.2p2)
    //  * decimal literal (e.g. 9876543210, 100_000_000)
    //  * floating pointe literal (e.g. 1.2, 1.2f, .2, 1., 1.2e10, 1.2e-10)
    begin: /(\b0x[\d_]*(\.[\d_]*)?|0x\.\d[\d_]*)p[-+]?\d+|\b0[box][a-fA-F0-9][a-fA-F0-9_]*|(\b\d[\d_]*(\.[\d_]*)?|\.\d[\d_]*)([eEfF][-+]?\d+)?/,
    relevance: 0
  };

  var CHAR = {
    className: "char",
    begin: /'(.|\\[xXuU][a-zA-Z0-9]+)'/
  };

  var INTERPOLATION = {
    className: 'subst',
    begin: /\$\(/, end: /\)/,
    keywords: KEYWORDS
  };

  var INTERPOLATED_VARIABLE = {
    className: 'variable',
    begin: "\\$" + VARIABLE_NAME_RE
  };

  // TODO: neatly escape normal code in string literal
  var STRING = {
    className: "string",
    contains: [hljs.BACKSLASH_ESCAPE, INTERPOLATION, INTERPOLATED_VARIABLE],
    variants: [
      { begin: /\w*"/, end: /"\w*/ },
      { begin: /\w*"""/, end: /"""\w*/ }
    ]
  };

  var COMMAND = {
    className: "string",
    contains: [hljs.BACKSLASH_ESCAPE, INTERPOLATION, INTERPOLATED_VARIABLE],
    begin: '`', end: '`'
  };

  var MACROCALL = {
    className: "macrocall",
    begin: "@" + VARIABLE_NAME_RE
  };

  var COMMENT = {
    className: "comment",
    variants: [
      { begin: "#=", end: "=#", relevance: 10 },
      { begin: '#', end: '$' }
    ]
  };

  DEFAULT.contains = [
    NUMBER,
    CHAR,
    TYPE_ANNOTATION,
    SUBTYPE,
    STRING,
    COMMAND,
    MACROCALL,
    COMMENT,
    hljs.HASH_COMMENT_MODE
  ];
  INTERPOLATION.contains = DEFAULT.contains;

  return DEFAULT;
});

hljs.registerLanguage('kotlin', function (hljs) {
  var KEYWORDS = 'val var get set class trait object public open private protected ' +
    'final enum if else do while for when break continue throw try catch finally ' +
    'import package is as in return fun override default companion reified inline volatile transient native';

  return {
    keywords: {
      typename: 'Byte Short Char Int Long Boolean Float Double Void Unit Nothing',
      literal: 'true false null',
      keyword: KEYWORDS
    },
    contains : [
      hljs.COMMENT(
        '/\\*\\*',
        '\\*/',
        {
          relevance : 0,
          contains : [{
            className : 'doctag',
            begin : '@[A-Za-z]+'
          }]
        }
      ),
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      {
        className: 'type',
        begin: /</, end: />/,
        returnBegin: true,
        excludeEnd: false,
        relevance: 0
      },
      {
        className: 'function',
        beginKeywords: 'fun', end: '[(]|$',
        returnBegin: true,
        excludeEnd: true,
        keywords: KEYWORDS,
        illegal: /fun\s+(<.*>)?[^\s\(]+(\s+[^\s\(]+)\s*=/,
        relevance: 5,
        contains: [
          {
            begin: hljs.UNDERSCORE_IDENT_RE + '\\s*\\(', returnBegin: true,
            relevance: 0,
            contains: [hljs.UNDERSCORE_TITLE_MODE]
          },
          {
            className: 'type',
            begin: /</, end: />/, keywords: 'reified',
            relevance: 0
          },
          {
            className: 'params',
            begin: /\(/, end: /\)/,
            keywords: KEYWORDS,
            relevance: 0,
            illegal: /\([^\(,\s:]+,/,
            contains: [
              {
                className: 'typename',
                begin: /:\s*/, end: /\s*[=\)]/, excludeBegin: true, returnEnd: true,
                relevance: 0
              }
            ]
          },
          hljs.C_LINE_COMMENT_MODE,
          hljs.C_BLOCK_COMMENT_MODE
        ]
      },
      {
        className: 'class',
        beginKeywords: 'class trait', end: /[:\{(]|$/,
        excludeEnd: true,
        illegal: 'extends implements',
        contains: [
          hljs.UNDERSCORE_TITLE_MODE,
          {
            className: 'type',
            begin: /</, end: />/, excludeBegin: true, excludeEnd: true,
            relevance: 0
          },
          {
            className: 'typename',
            begin: /[,:]\s*/, end: /[<\(,]|$/, excludeBegin: true, returnEnd: true
          }
        ]
      },
      {
        className: 'variable', beginKeywords: 'var val', end: /\s*[=:$]/, excludeEnd: true
      },
      hljs.QUOTE_STRING_MODE,
      {
        className: 'shebang',
        begin: "^#!/usr/bin/env", end: '$',
        illegal: '\n'
      },
      hljs.C_NUMBER_MODE
    ]
  };
});

hljs.registerLanguage('lasso', function(hljs) {
  var LASSO_IDENT_RE = '[a-zA-Z_][a-zA-Z0-9_.]*';
  var LASSO_ANGLE_RE = '<\\?(lasso(script)?|=)';
  var LASSO_CLOSE_RE = '\\]|\\?>';
  var LASSO_KEYWORDS = {
    literal:
      'true false none minimal full all void ' +
      'bw nbw ew new cn ncn lt lte gt gte eq neq rx nrx ft',
    built_in:
      'array date decimal duration integer map pair string tag xml null ' +
      'boolean bytes keyword list locale queue set stack staticarray ' +
      'local var variable global data self inherited currentcapture givenblock',
    keyword:
      'error_code error_msg error_pop error_push error_reset cache ' +
      'database_names database_schemanames database_tablenames define_tag ' +
      'define_type email_batch encode_set html_comment handle handle_error ' +
      'header if inline iterate ljax_target link link_currentaction ' +
      'link_currentgroup link_currentrecord link_detail link_firstgroup ' +
      'link_firstrecord link_lastgroup link_lastrecord link_nextgroup ' +
      'link_nextrecord link_prevgroup link_prevrecord log loop ' +
      'namespace_using output_none portal private protect records referer ' +
      'referrer repeating resultset rows search_args search_arguments ' +
      'select sort_args sort_arguments thread_atomic value_list while ' +
      'abort case else if_empty if_false if_null if_true loop_abort ' +
      'loop_continue loop_count params params_up return return_value ' +
      'run_children soap_definetag soap_lastrequest soap_lastresponse ' +
      'tag_name ascending average by define descending do equals ' +
      'frozen group handle_failure import in into join let match max ' +
      'min on order parent protected provide public require returnhome ' +
      'skip split_thread sum take thread to trait type where with ' +
      'yield yieldhome'
  };
  var HTML_COMMENT = hljs.COMMENT(
    '<!--',
    '-->',
    {
      relevance: 0
    }
  );
  var LASSO_NOPROCESS = {
    className: 'preprocessor',
    begin: '\\[noprocess\\]',
    starts: {
      className: 'markup',
      end: '\\[/noprocess\\]',
      returnEnd: true,
      contains: [HTML_COMMENT]
    }
  };
  var LASSO_START = {
    className: 'preprocessor',
    begin: '\\[/noprocess|' + LASSO_ANGLE_RE
  };
  var LASSO_DATAMEMBER = {
    className: 'variable',
    begin: '\'' + LASSO_IDENT_RE + '\''
  };
  var LASSO_CODE = [
    hljs.COMMENT(
      '/\\*\\*!',
      '\\*/'
    ),
    hljs.C_LINE_COMMENT_MODE,
    hljs.C_BLOCK_COMMENT_MODE,
    hljs.inherit(hljs.C_NUMBER_MODE, {begin: hljs.C_NUMBER_RE + '|(infinity|nan)\\b'}),
    hljs.inherit(hljs.APOS_STRING_MODE, {illegal: null}),
    hljs.inherit(hljs.QUOTE_STRING_MODE, {illegal: null}),
    {
      className: 'string',
      begin: '`', end: '`'
    },
    {
      className: 'variable',
      variants: [
        {
          begin: '[#$]' + LASSO_IDENT_RE
        },
        {
          begin: '#', end: '\\d+',
          illegal: '\\W'
        }
      ]
    },
    {
      className: 'tag',
      begin: '::\\s*', end: LASSO_IDENT_RE,
      illegal: '\\W'
    },
    {
      className: 'attribute',
      variants: [
        {
          begin: '-(?!infinity)' + hljs.UNDERSCORE_IDENT_RE,
          relevance: 0
        },
        {
          begin: '(\\.\\.\\.)'
        }
      ]
    },
    {
      className: 'subst',
      variants: [
        {
          begin: '->\\s*',
          contains: [LASSO_DATAMEMBER]
        },
        {
          begin: '->|\\\\|&&?|\\|\\||!(?!=|>)|(and|or|not)\\b',
          relevance: 0
        }
      ]
    },
    {
      className: 'built_in',
      begin: '\\.\\.?\\s*',
      relevance: 0,
      contains: [LASSO_DATAMEMBER]
    },
    {
      className: 'class',
      beginKeywords: 'define',
      returnEnd: true, end: '\\(|=>',
      contains: [
        hljs.inherit(hljs.TITLE_MODE, {begin: hljs.UNDERSCORE_IDENT_RE + '(=(?!>))?'})
      ]
    }
  ];
  return {
    aliases: ['ls', 'lassoscript'],
    case_insensitive: true,
    lexemes: LASSO_IDENT_RE + '|&[lg]t;',
    keywords: LASSO_KEYWORDS,
    contains: [
      {
        className: 'preprocessor',
        begin: LASSO_CLOSE_RE,
        relevance: 0,
        starts: {
          className: 'markup',
          end: '\\[|' + LASSO_ANGLE_RE,
          returnEnd: true,
          relevance: 0,
          contains: [HTML_COMMENT]
        }
      },
      LASSO_NOPROCESS,
      LASSO_START,
      {
        className: 'preprocessor',
        begin: '\\[no_square_brackets',
        starts: {
          end: '\\[/no_square_brackets\\]', // not implemented in the language
          lexemes: LASSO_IDENT_RE + '|&[lg]t;',
          keywords: LASSO_KEYWORDS,
          contains: [
            {
              className: 'preprocessor',
              begin: LASSO_CLOSE_RE,
              relevance: 0,
              starts: {
                className: 'markup',
                end: '\\[noprocess\\]|' + LASSO_ANGLE_RE,
                returnEnd: true,
                contains: [HTML_COMMENT]
              }
            },
            LASSO_NOPROCESS,
            LASSO_START
          ].concat(LASSO_CODE)
        }
      },
      {
        className: 'preprocessor',
        begin: '\\[',
        relevance: 0
      },
      {
        className: 'shebang',
        begin: '^#!.+lasso9\\b',
        relevance: 10
      }
    ].concat(LASSO_CODE)
  };
});

hljs.registerLanguage('less', function(hljs) {
  var IDENT_RE        = '[\\w-]+'; // yes, Less identifiers may begin with a digit
  var INTERP_IDENT_RE = '(' + IDENT_RE + '|@{' + IDENT_RE + '})';

  /* Generic Modes */

  var RULES = [], VALUE = []; // forward def. for recursive modes

  var STRING_MODE = function(c) { return {
    // Less strings are not multiline (also include '~' for more consistent coloring of "escaped" strings)
    className: 'string', begin: '~?' + c + '.*?' + c
  };};

  var IDENT_MODE = function(name, begin, relevance) { return {
    className: name, begin: begin, relevance: relevance
  };};

  var FUNCT_MODE = function(name, ident, obj) {
    return hljs.inherit({
        className: name, begin: ident + '\\(', end: '\\(',
        returnBegin: true, excludeEnd: true, relevance: 0
    }, obj);
  };

  var PARENS_MODE = {
    // used only to properly balance nested parens inside mixin call, def. arg list
    begin: '\\(', end: '\\)', contains: VALUE, relevance: 0
  };

  // generic Less highlighter (used almost everywhere except selectors):
  VALUE.push(
    hljs.C_LINE_COMMENT_MODE,
    hljs.C_BLOCK_COMMENT_MODE,
    STRING_MODE("'"),
    STRING_MODE('"'),
    hljs.CSS_NUMBER_MODE, // fixme: it does not include dot for numbers like .5em :(
    IDENT_MODE('hexcolor', '#[0-9A-Fa-f]+\\b'),
    FUNCT_MODE('function', '(url|data-uri)', {
      starts: {className: 'string', end: '[\\)\\n]', excludeEnd: true}
    }),
    FUNCT_MODE('function', IDENT_RE),
    PARENS_MODE,
    IDENT_MODE('variable', '@@?' + IDENT_RE, 10),
    IDENT_MODE('variable', '@{'  + IDENT_RE + '}'),
    IDENT_MODE('built_in', '~?`[^`]*?`'), // inline javascript (or whatever host language) *multiline* string
    { // @media features (it’s here to not duplicate things in AT_RULE_MODE with extra PARENS_MODE overriding):
      className: 'attribute', begin: IDENT_RE + '\\s*:', end: ':', returnBegin: true, excludeEnd: true
    }
  );

  var VALUE_WITH_RULESETS = VALUE.concat({
    begin: '{', end: '}', contains: RULES
  });

  var MIXIN_GUARD_MODE = {
    beginKeywords: 'when', endsWithParent: true,
    contains: [{beginKeywords: 'and not'}].concat(VALUE) // using this form to override VALUE’s 'function' match
  };

  /* Rule-Level Modes */

  var RULE_MODE = {
    className: 'attribute',
    begin: INTERP_IDENT_RE, end: ':', excludeEnd: true,
    contains: [hljs.C_LINE_COMMENT_MODE, hljs.C_BLOCK_COMMENT_MODE],
    illegal: /\S/,
    starts: {end: '[;}]', returnEnd: true, contains: VALUE, illegal: '[<=$]'}
  };

  var AT_RULE_MODE = {
    className: 'at_rule', // highlight only at-rule keyword
    begin: '@(import|media|charset|font-face|(-[a-z]+-)?keyframes|supports|document|namespace|page|viewport|host)\\b',
    starts: {end: '[;{}]', returnEnd: true, contains: VALUE, relevance: 0}
  };

  // variable definitions and calls
  var VAR_RULE_MODE = {
    className: 'variable',
    variants: [
      // using more strict pattern for higher relevance to increase chances of Less detection.
      // this is *the only* Less specific statement used in most of the sources, so...
      // (we’ll still often loose to the css-parser unless there's '//' comment,
      // simply because 1 variable just can't beat 99 properties :)
      {begin: '@' + IDENT_RE + '\\s*:', relevance: 15},
      {begin: '@' + IDENT_RE}
    ],
    starts: {end: '[;}]', returnEnd: true, contains: VALUE_WITH_RULESETS}
  };

  var SELECTOR_MODE = {
    // first parse unambiguous selectors (i.e. those not starting with tag)
    // then fall into the scary lookahead-discriminator variant.
    // this mode also handles mixin definitions and calls
    variants: [{
      begin: '[\\.#:&\\[]', end: '[;{}]'  // mixin calls end with ';'
      }, {
      begin: INTERP_IDENT_RE + '[^;]*{',
      end: '{'
    }],
    returnBegin: true,
    returnEnd:   true,
    illegal: '[<=\'$"]',
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      MIXIN_GUARD_MODE,
      IDENT_MODE('keyword',  'all\\b'),
      IDENT_MODE('variable', '@{'  + IDENT_RE + '}'),     // otherwise it’s identified as tag
      IDENT_MODE('tag',       INTERP_IDENT_RE + '%?', 0), // '%' for more consistent coloring of @keyframes "tags"
      IDENT_MODE('id',       '#'   + INTERP_IDENT_RE),
      IDENT_MODE('class',    '\\.' + INTERP_IDENT_RE, 0),
      IDENT_MODE('keyword',  '&', 0),
      FUNCT_MODE('pseudo',   ':not'),
      FUNCT_MODE('keyword',  ':extend'),
      IDENT_MODE('pseudo',   '::?' + INTERP_IDENT_RE),
      {className: 'attr_selector', begin: '\\[', end: '\\]'},
      {begin: '\\(', end: '\\)', contains: VALUE_WITH_RULESETS}, // argument list of parametric mixins
      {begin: '!important'} // eat !important after mixin call or it will be colored as tag
    ]
  };

  RULES.push(
    hljs.C_LINE_COMMENT_MODE,
    hljs.C_BLOCK_COMMENT_MODE,
    AT_RULE_MODE,
    VAR_RULE_MODE,
    SELECTOR_MODE,
    RULE_MODE
  );

  return {
    case_insensitive: true,
    illegal: '[=>\'/<($"]',
    contains: RULES
  };
});

hljs.registerLanguage('lisp', function(hljs) {
  var LISP_IDENT_RE = '[a-zA-Z_\\-\\+\\*\\/\\<\\=\\>\\&\\#][a-zA-Z0-9_\\-\\+\\*\\/\\<\\=\\>\\&\\#!]*';
  var MEC_RE = '\\|[^]*?\\|';
  var LISP_SIMPLE_NUMBER_RE = '(\\-|\\+)?\\d+(\\.\\d+|\\/\\d+)?((d|e|f|l|s|D|E|F|L|S)(\\+|\\-)?\\d+)?';
  var SHEBANG = {
    className: 'shebang',
    begin: '^#!', end: '$'
  };
  var LITERAL = {
    className: 'literal',
    begin: '\\b(t{1}|nil)\\b'
  };
  var NUMBER = {
    className: 'number',
    variants: [
      {begin: LISP_SIMPLE_NUMBER_RE, relevance: 0},
      {begin: '#(b|B)[0-1]+(/[0-1]+)?'},
      {begin: '#(o|O)[0-7]+(/[0-7]+)?'},
      {begin: '#(x|X)[0-9a-fA-F]+(/[0-9a-fA-F]+)?'},
      {begin: '#(c|C)\\(' + LISP_SIMPLE_NUMBER_RE + ' +' + LISP_SIMPLE_NUMBER_RE, end: '\\)'}
    ]
  };
  var STRING = hljs.inherit(hljs.QUOTE_STRING_MODE, {illegal: null});
  var COMMENT = hljs.COMMENT(
    ';', '$',
    {
      relevance: 0
    }
  );
  var VARIABLE = {
    className: 'variable',
    begin: '\\*', end: '\\*'
  };
  var KEYWORD = {
    className: 'keyword',
    begin: '[:&]' + LISP_IDENT_RE
  };
  var IDENT = {
    begin: LISP_IDENT_RE,
    relevance: 0
  };
  var MEC = {
    begin: MEC_RE
  };
  var QUOTED_LIST = {
    begin: '\\(', end: '\\)',
    contains: ['self', LITERAL, STRING, NUMBER, IDENT]
  };
  var QUOTED = {
    className: 'quoted',
    contains: [NUMBER, STRING, VARIABLE, KEYWORD, QUOTED_LIST, IDENT],
    variants: [
      {
        begin: '[\'`]\\(', end: '\\)'
      },
      {
        begin: '\\(quote ', end: '\\)',
        keywords: 'quote'
      },
      {
        begin: '\'' + MEC_RE
      }
    ]
  };
  var QUOTED_ATOM = {
    className: 'quoted',
    variants: [
      {begin: '\'' + LISP_IDENT_RE},
      {begin: '#\'' + LISP_IDENT_RE + '(::' + LISP_IDENT_RE + ')*'}
    ]
  };
  var LIST = {
    className: 'list',
    begin: '\\(\\s*', end: '\\)'
  };
  var BODY = {
    endsWithParent: true,
    relevance: 0
  };
  LIST.contains = [
    {
      className: 'keyword',
      variants: [
        {begin: LISP_IDENT_RE},
        {begin: MEC_RE}
      ]
    },
    BODY
  ];
  BODY.contains = [QUOTED, QUOTED_ATOM, LIST, LITERAL, NUMBER, STRING, COMMENT, VARIABLE, KEYWORD, MEC, IDENT];

  return {
    illegal: /\S/,
    contains: [
      NUMBER,
      SHEBANG,
      LITERAL,
      STRING,
      COMMENT,
      QUOTED,
      QUOTED_ATOM,
      LIST,
      IDENT
    ]
  };
});

hljs.registerLanguage('livecodeserver', function(hljs) {
  var VARIABLE = {
    className: 'variable', begin: '\\b[gtps][A-Z]+[A-Za-z0-9_\\-]*\\b|\\$_[A-Z]+',
    relevance: 0
  };
  var COMMENT_MODES = [
    hljs.C_BLOCK_COMMENT_MODE,
    hljs.HASH_COMMENT_MODE,
    hljs.COMMENT('--', '$'),
    hljs.COMMENT('[^:]//', '$')
  ];
  var TITLE1 = hljs.inherit(hljs.TITLE_MODE, {
    variants: [
      {begin: '\\b_*rig[A-Z]+[A-Za-z0-9_\\-]*'},
      {begin: '\\b_[a-z0-9\\-]+'}
    ]
  });
  var TITLE2 = hljs.inherit(hljs.TITLE_MODE, {begin: '\\b([A-Za-z0-9_\\-]+)\\b'});
  return {
    case_insensitive: false,
    keywords: {
      keyword:
        '$_COOKIE $_FILES $_GET $_GET_BINARY $_GET_RAW $_POST $_POST_BINARY $_POST_RAW $_SESSION $_SERVER ' +
        'codepoint codepoints segment segments codeunit codeunits sentence sentences trueWord trueWords paragraph ' +
        'after byte bytes english the until http forever descending using line real8 with seventh ' +
        'for stdout finally element word words fourth before black ninth sixth characters chars stderr ' +
        'uInt1 uInt1s uInt2 uInt2s stdin string lines relative rel any fifth items from middle mid ' +
        'at else of catch then third it file milliseconds seconds second secs sec int1 int1s int4 ' +
        'int4s internet int2 int2s normal text item last long detailed effective uInt4 uInt4s repeat ' +
        'end repeat URL in try into switch to words https token binfile each tenth as ticks tick ' +
        'system real4 by dateItems without char character ascending eighth whole dateTime numeric short ' +
        'first ftp integer abbreviated abbr abbrev private case while if',
      constant:
        'SIX TEN FORMFEED NINE ZERO NONE SPACE FOUR FALSE COLON CRLF PI COMMA ENDOFFILE EOF EIGHT FIVE ' +
        'QUOTE EMPTY ONE TRUE RETURN CR LINEFEED RIGHT BACKSLASH NULL SEVEN TAB THREE TWO ' +
        'six ten formfeed nine zero none space four false colon crlf pi comma endoffile eof eight five ' +
        'quote empty one true return cr linefeed right backslash null seven tab three two ' +
        'RIVERSION RISTATE FILE_READ_MODE FILE_WRITE_MODE FILE_WRITE_MODE DIR_WRITE_MODE FILE_READ_UMASK ' +
        'FILE_WRITE_UMASK DIR_READ_UMASK DIR_WRITE_UMASK',
      operator:
        'div mod wrap and or bitAnd bitNot bitOr bitXor among not in a an within ' +
        'contains ends with begins the keys of keys',
      built_in:
        'put abs acos aliasReference annuity arrayDecode arrayEncode asin atan atan2 average avg avgDev base64Decode ' +
        'base64Encode baseConvert binaryDecode binaryEncode byteOffset byteToNum cachedURL cachedURLs charToNum ' +
        'cipherNames codepointOffset codepointProperty codepointToNum codeunitOffset commandNames compound compress ' +
        'constantNames cos date dateFormat decompress directories ' +
        'diskSpace DNSServers exp exp1 exp2 exp10 extents files flushEvents folders format functionNames geometricMean global ' +
        'globals hasMemory harmonicMean hostAddress hostAddressToName hostName hostNameToAddress isNumber ISOToMac itemOffset ' +
        'keys len length libURLErrorData libUrlFormData libURLftpCommand libURLLastHTTPHeaders libURLLastRHHeaders ' +
        'libUrlMultipartFormAddPart libUrlMultipartFormData libURLVersion lineOffset ln ln1 localNames log log2 log10 ' +
        'longFilePath lower macToISO matchChunk matchText matrixMultiply max md5Digest median merge millisec ' +
        'millisecs millisecond milliseconds min monthNames nativeCharToNum normalizeText num number numToByte numToChar ' +
        'numToCodepoint numToNativeChar offset open openfiles openProcesses openProcessIDs openSockets ' +
        'paragraphOffset paramCount param params peerAddress pendingMessages platform popStdDev populationStandardDeviation ' +
        'populationVariance popVariance processID random randomBytes replaceText result revCreateXMLTree revCreateXMLTreeFromFile ' +
        'revCurrentRecord revCurrentRecordIsFirst revCurrentRecordIsLast revDatabaseColumnCount revDatabaseColumnIsNull ' +
        'revDatabaseColumnLengths revDatabaseColumnNames revDatabaseColumnNamed revDatabaseColumnNumbered ' +
        'revDatabaseColumnTypes revDatabaseConnectResult revDatabaseCursors revDatabaseID revDatabaseTableNames ' +
        'revDatabaseType revDataFromQuery revdb_closeCursor revdb_columnbynumber revdb_columncount revdb_columnisnull ' +
        'revdb_columnlengths revdb_columnnames revdb_columntypes revdb_commit revdb_connect revdb_connections ' +
        'revdb_connectionerr revdb_currentrecord revdb_cursorconnection revdb_cursorerr revdb_cursors revdb_dbtype ' +
        'revdb_disconnect revdb_execute revdb_iseof revdb_isbof revdb_movefirst revdb_movelast revdb_movenext ' +
        'revdb_moveprev revdb_query revdb_querylist revdb_recordcount revdb_rollback revdb_tablenames ' +
        'revGetDatabaseDriverPath revNumberOfRecords revOpenDatabase revOpenDatabases revQueryDatabase ' +
        'revQueryDatabaseBlob revQueryResult revQueryIsAtStart revQueryIsAtEnd revUnixFromMacPath revXMLAttribute ' +
        'revXMLAttributes revXMLAttributeValues revXMLChildContents revXMLChildNames revXMLCreateTreeFromFileWithNamespaces ' +
        'revXMLCreateTreeWithNamespaces revXMLDataFromXPathQuery revXMLEvaluateXPath revXMLFirstChild revXMLMatchingNode ' +
        'revXMLNextSibling revXMLNodeContents revXMLNumberOfChildren revXMLParent revXMLPreviousSibling ' +
        'revXMLRootNode revXMLRPC_CreateRequest revXMLRPC_Documents revXMLRPC_Error ' +
        'revXMLRPC_GetHost revXMLRPC_GetMethod revXMLRPC_GetParam revXMLText revXMLRPC_Execute ' +
        'revXMLRPC_GetParamCount revXMLRPC_GetParamNode revXMLRPC_GetParamType revXMLRPC_GetPath revXMLRPC_GetPort ' +
        'revXMLRPC_GetProtocol revXMLRPC_GetRequest revXMLRPC_GetResponse revXMLRPC_GetSocket revXMLTree ' +
        'revXMLTrees revXMLValidateDTD revZipDescribeItem revZipEnumerateItems revZipOpenArchives round sampVariance ' +
        'sec secs seconds sentenceOffset sha1Digest shell shortFilePath sin specialFolderPath sqrt standardDeviation statRound ' +
        'stdDev sum sysError systemVersion tan tempName textDecode textEncode tick ticks time to tokenOffset toLower toUpper ' +
        'transpose truewordOffset trunc uniDecode uniEncode upper URLDecode URLEncode URLStatus uuid value variableNames ' +
        'variance version waitDepth weekdayNames wordOffset xsltApplyStylesheet xsltApplyStylesheetFromFile xsltLoadStylesheet ' +
        'xsltLoadStylesheetFromFile add breakpoint cancel clear local variable file word line folder directory URL close socket process ' +
        'combine constant convert create new alias folder directory decrypt delete variable word line folder ' +
        'directory URL dispatch divide do encrypt filter get include intersect kill libURLDownloadToFile ' +
        'libURLFollowHttpRedirects libURLftpUpload libURLftpUploadFile libURLresetAll libUrlSetAuthCallback ' +
        'libURLSetCustomHTTPHeaders libUrlSetExpect100 libURLSetFTPListCommand libURLSetFTPMode libURLSetFTPStopTime ' +
        'libURLSetStatusCallback load multiply socket prepare process post seek rel relative read from process rename ' +
        'replace require resetAll resolve revAddXMLNode revAppendXML revCloseCursor revCloseDatabase revCommitDatabase ' +
        'revCopyFile revCopyFolder revCopyXMLNode revDeleteFolder revDeleteXMLNode revDeleteAllXMLTrees ' +
        'revDeleteXMLTree revExecuteSQL revGoURL revInsertXMLNode revMoveFolder revMoveToFirstRecord revMoveToLastRecord ' +
        'revMoveToNextRecord revMoveToPreviousRecord revMoveToRecord revMoveXMLNode revPutIntoXMLNode revRollBackDatabase ' +
        'revSetDatabaseDriverPath revSetXMLAttribute revXMLRPC_AddParam revXMLRPC_DeleteAllDocuments revXMLAddDTD ' +
        'revXMLRPC_Free revXMLRPC_FreeAll revXMLRPC_DeleteDocument revXMLRPC_DeleteParam revXMLRPC_SetHost ' +
        'revXMLRPC_SetMethod revXMLRPC_SetPort revXMLRPC_SetProtocol revXMLRPC_SetSocket revZipAddItemWithData ' +
        'revZipAddItemWithFile revZipAddUncompressedItemWithData revZipAddUncompressedItemWithFile revZipCancel ' +
        'revZipCloseArchive revZipDeleteItem revZipExtractItemToFile revZipExtractItemToVariable revZipSetProgressCallback ' +
        'revZipRenameItem revZipReplaceItemWithData revZipReplaceItemWithFile revZipOpenArchive send set sort split start stop ' +
        'subtract union unload wait write'
    },
    contains: [
      VARIABLE,
      {
        className: 'keyword',
        begin: '\\bend\\sif\\b'
      },
      {
        className: 'function',
        beginKeywords: 'function', end: '$',
        contains: [
          VARIABLE,
          TITLE2,
          hljs.APOS_STRING_MODE,
          hljs.QUOTE_STRING_MODE,
          hljs.BINARY_NUMBER_MODE,
          hljs.C_NUMBER_MODE,
          TITLE1
        ]
      },
      {
        className: 'function',
        begin: '\\bend\\s+', end: '$',
        keywords: 'end',
        contains: [
          TITLE2,
          TITLE1
        ]
      },
      {
        className: 'command',
        beginKeywords: 'command on', end: '$',
        contains: [
          VARIABLE,
          TITLE2,
          hljs.APOS_STRING_MODE,
          hljs.QUOTE_STRING_MODE,
          hljs.BINARY_NUMBER_MODE,
          hljs.C_NUMBER_MODE,
          TITLE1
        ]
      },
      {
        className: 'preprocessor',
        variants: [
          {
            begin: '<\\?(rev|lc|livecode)',
            relevance: 10
          },
          { begin: '<\\?' },
          { begin: '\\?>' }
        ]
      },
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      hljs.BINARY_NUMBER_MODE,
      hljs.C_NUMBER_MODE,
      TITLE1
    ].concat(COMMENT_MODES),
    illegal: ';$|^\\[|^='
  };
});

hljs.registerLanguage('livescript', function(hljs) {
  var KEYWORDS = {
    keyword:
      // JS keywords
      'in if for while finally new do return else break catch instanceof throw try this ' +
      'switch continue typeof delete debugger case default function var with ' +
      // LiveScript keywords
      'then unless until loop of by when and or is isnt not it that otherwise from to til fallthrough super ' +
      'case default function var void const let enum export import native ' +
      '__hasProp __extends __slice __bind __indexOf',
    literal:
      // JS literals
      'true false null undefined ' +
      // LiveScript literals
      'yes no on off it that void',
    built_in:
      'npm require console print module global window document'
  };
  var JS_IDENT_RE = '[A-Za-z$_](?:\-[0-9A-Za-z$_]|[0-9A-Za-z$_])*';
  var TITLE = hljs.inherit(hljs.TITLE_MODE, {begin: JS_IDENT_RE});
  var SUBST = {
    className: 'subst',
    begin: /#\{/, end: /}/,
    keywords: KEYWORDS
  };
  var SUBST_SIMPLE = {
    className: 'subst',
    begin: /#[A-Za-z$_]/, end: /(?:\-[0-9A-Za-z$_]|[0-9A-Za-z$_])*/,
    keywords: KEYWORDS
  };
  var EXPRESSIONS = [
    hljs.BINARY_NUMBER_MODE,
    {
      className: 'number',
      begin: '(\\b0[xX][a-fA-F0-9_]+)|(\\b\\d(\\d|_\\d)*(\\.(\\d(\\d|_\\d)*)?)?(_*[eE]([-+]\\d(_\\d|\\d)*)?)?[_a-z]*)',
      relevance: 0,
      starts: {end: '(\\s*/)?', relevance: 0} // a number tries to eat the following slash to prevent treating it as a regexp
    },
    {
      className: 'string',
      variants: [
        {
          begin: /'''/, end: /'''/,
          contains: [hljs.BACKSLASH_ESCAPE]
        },
        {
          begin: /'/, end: /'/,
          contains: [hljs.BACKSLASH_ESCAPE]
        },
        {
          begin: /"""/, end: /"""/,
          contains: [hljs.BACKSLASH_ESCAPE, SUBST, SUBST_SIMPLE]
        },
        {
          begin: /"/, end: /"/,
          contains: [hljs.BACKSLASH_ESCAPE, SUBST, SUBST_SIMPLE]
        },
        {
          begin: /\\/, end: /(\s|$)/,
          excludeEnd: true
        }
      ]
    },
    {
      className: 'pi',
      variants: [
        {
          begin: '//', end: '//[gim]*',
          contains: [SUBST, hljs.HASH_COMMENT_MODE]
        },
        {
          // regex can't start with space to parse x / 2 / 3 as two divisions
          // regex can't start with *, and it supports an "illegal" in the main mode
          begin: /\/(?![ *])(\\\/|.)*?\/[gim]*(?=\W|$)/
        }
      ]
    },
    {
      className: 'property',
      begin: '@' + JS_IDENT_RE
    },
    {
      begin: '``', end: '``',
      excludeBegin: true, excludeEnd: true,
      subLanguage: 'javascript'
    }
  ];
  SUBST.contains = EXPRESSIONS;

  var PARAMS = {
    className: 'params',
    begin: '\\(', returnBegin: true,
    /* We need another contained nameless mode to not have every nested
    pair of parens to be called "params" */
    contains: [
      {
        begin: /\(/, end: /\)/,
        keywords: KEYWORDS,
        contains: ['self'].concat(EXPRESSIONS)
      }
    ]
  };

  return {
    aliases: ['ls'],
    keywords: KEYWORDS,
    illegal: /\/\*/,
    contains: EXPRESSIONS.concat([
      hljs.COMMENT('\\/\\*', '\\*\\/'),
      hljs.HASH_COMMENT_MODE,
      {
        className: 'function',
        contains: [TITLE, PARAMS],
        returnBegin: true,
        variants: [
          {
            begin: '(' + JS_IDENT_RE + '\\s*(?:=|:=)\\s*)?(\\(.*\\))?\\s*\\B\\->\\*?', end: '\\->\\*?'
          },
          {
            begin: '(' + JS_IDENT_RE + '\\s*(?:=|:=)\\s*)?!?(\\(.*\\))?\\s*\\B[-~]{1,2}>\\*?', end: '[-~]{1,2}>\\*?'
          },
          {
            begin: '(' + JS_IDENT_RE + '\\s*(?:=|:=)\\s*)?(\\(.*\\))?\\s*\\B!?[-~]{1,2}>\\*?', end: '!?[-~]{1,2}>\\*?'
          }
        ]
      },
      {
        className: 'class',
        beginKeywords: 'class',
        end: '$',
        illegal: /[:="\[\]]/,
        contains: [
          {
            beginKeywords: 'extends',
            endsWithParent: true,
            illegal: /[:="\[\]]/,
            contains: [TITLE]
          },
          TITLE
        ]
      },
      {
        className: 'attribute',
        begin: JS_IDENT_RE + ':', end: ':',
        returnBegin: true, returnEnd: true,
        relevance: 0
      }
    ])
  };
});

hljs.registerLanguage('lua', function(hljs) {
  var OPENING_LONG_BRACKET = '\\[=*\\[';
  var CLOSING_LONG_BRACKET = '\\]=*\\]';
  var LONG_BRACKETS = {
    begin: OPENING_LONG_BRACKET, end: CLOSING_LONG_BRACKET,
    contains: ['self']
  };
  var COMMENTS = [
    hljs.COMMENT('--(?!' + OPENING_LONG_BRACKET + ')', '$'),
    hljs.COMMENT(
      '--' + OPENING_LONG_BRACKET,
      CLOSING_LONG_BRACKET,
      {
        contains: [LONG_BRACKETS],
        relevance: 10
      }
    )
  ];
  return {
    lexemes: hljs.UNDERSCORE_IDENT_RE,
    keywords: {
      keyword:
        'and break do else elseif end false for if in local nil not or repeat return then ' +
        'true until while',
      built_in:
        '_G _VERSION assert collectgarbage dofile error getfenv getmetatable ipairs load ' +
        'loadfile loadstring module next pairs pcall print rawequal rawget rawset require ' +
        'select setfenv setmetatable tonumber tostring type unpack xpcall coroutine debug ' +
        'io math os package string table'
    },
    contains: COMMENTS.concat([
      {
        className: 'function',
        beginKeywords: 'function', end: '\\)',
        contains: [
          hljs.inherit(hljs.TITLE_MODE, {begin: '([_a-zA-Z]\\w*\\.)*([_a-zA-Z]\\w*:)?[_a-zA-Z]\\w*'}),
          {
            className: 'params',
            begin: '\\(', endsWithParent: true,
            contains: COMMENTS
          }
        ].concat(COMMENTS)
      },
      hljs.C_NUMBER_MODE,
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      {
        className: 'string',
        begin: OPENING_LONG_BRACKET, end: CLOSING_LONG_BRACKET,
        contains: [LONG_BRACKETS],
        relevance: 5
      }
    ])
  };
});

hljs.registerLanguage('makefile', function(hljs) {
  var VARIABLE = {
    className: 'variable',
    begin: /\$\(/, end: /\)/,
    contains: [hljs.BACKSLASH_ESCAPE]
  };
  return {
    aliases: ['mk', 'mak'],
    contains: [
      hljs.HASH_COMMENT_MODE,
      {
        begin: /^\w+\s*\W*=/, returnBegin: true,
        relevance: 0,
        starts: {
          className: 'constant',
          end: /\s*\W*=/, excludeEnd: true,
          starts: {
            end: /$/,
            relevance: 0,
            contains: [
              VARIABLE
            ]
          }
        }
      },
      {
        className: 'title',
        begin: /^[\w]+:\s*$/
      },
      {
        className: 'phony',
        begin: /^\.PHONY:/, end: /$/,
        keywords: '.PHONY', lexemes: /[\.\w]+/
      },
      {
        begin: /^\t+/, end: /$/,
        relevance: 0,
        contains: [
          hljs.QUOTE_STRING_MODE,
          VARIABLE
        ]
      }
    ]
  };
});

hljs.registerLanguage('mathematica', function(hljs) {
  return {
    aliases: ['mma'],
    lexemes: '(\\$|\\b)' + hljs.IDENT_RE + '\\b',
    keywords: 'AbelianGroup Abort AbortKernels AbortProtect Above Abs Absolute AbsoluteCorrelation AbsoluteCorrelationFunction AbsoluteCurrentValue AbsoluteDashing AbsoluteFileName AbsoluteOptions AbsolutePointSize AbsoluteThickness AbsoluteTime AbsoluteTiming AccountingForm Accumulate Accuracy AccuracyGoal ActionDelay ActionMenu ActionMenuBox ActionMenuBoxOptions Active ActiveItem ActiveStyle AcyclicGraphQ AddOnHelpPath AddTo AdjacencyGraph AdjacencyList AdjacencyMatrix AdjustmentBox AdjustmentBoxOptions AdjustTimeSeriesForecast AffineTransform After AiryAi AiryAiPrime AiryAiZero AiryBi AiryBiPrime AiryBiZero AlgebraicIntegerQ AlgebraicNumber AlgebraicNumberDenominator AlgebraicNumberNorm AlgebraicNumberPolynomial AlgebraicNumberTrace AlgebraicRules AlgebraicRulesData Algebraics AlgebraicUnitQ Alignment AlignmentMarker AlignmentPoint All AllowedDimensions AllowGroupClose AllowInlineCells AllowKernelInitialization AllowReverseGroupClose AllowScriptLevelChange AlphaChannel AlternatingGroup AlternativeHypothesis Alternatives AmbientLight Analytic AnchoredSearch And AndersonDarlingTest AngerJ AngleBracket AngularGauge Animate AnimationCycleOffset AnimationCycleRepetitions AnimationDirection AnimationDisplayTime AnimationRate AnimationRepetitions AnimationRunning Animator AnimatorBox AnimatorBoxOptions AnimatorElements Annotation Annuity AnnuityDue Antialiasing Antisymmetric Apart ApartSquareFree Appearance AppearanceElements AppellF1 Append AppendTo Apply ArcCos ArcCosh ArcCot ArcCoth ArcCsc ArcCsch ArcSec ArcSech ArcSin ArcSinDistribution ArcSinh ArcTan ArcTanh Arg ArgMax ArgMin ArgumentCountQ ARIMAProcess ArithmeticGeometricMean ARMAProcess ARProcess Array ArrayComponents ArrayDepth ArrayFlatten ArrayPad ArrayPlot ArrayQ ArrayReshape ArrayRules Arrays Arrow Arrow3DBox ArrowBox Arrowheads AspectRatio AspectRatioFixed Assert Assuming Assumptions AstronomicalData Asynchronous AsynchronousTaskObject AsynchronousTasks AtomQ Attributes AugmentedSymmetricPolynomial AutoAction AutoDelete AutoEvaluateEvents AutoGeneratedPackage AutoIndent AutoIndentSpacings AutoItalicWords AutoloadPath AutoMatch Automatic AutomaticImageSize AutoMultiplicationSymbol AutoNumberFormatting AutoOpenNotebooks AutoOpenPalettes AutorunSequencing AutoScaling AutoScroll AutoSpacing AutoStyleOptions AutoStyleWords Axes AxesEdge AxesLabel AxesOrigin AxesStyle Axis ' +
      'BabyMonsterGroupB Back Background BackgroundTasksSettings Backslash Backsubstitution Backward Band BandpassFilter BandstopFilter BarabasiAlbertGraphDistribution BarChart BarChart3D BarLegend BarlowProschanImportance BarnesG BarOrigin BarSpacing BartlettHannWindow BartlettWindow BaseForm Baseline BaselinePosition BaseStyle BatesDistribution BattleLemarieWavelet Because BeckmannDistribution Beep Before Begin BeginDialogPacket BeginFrontEndInteractionPacket BeginPackage BellB BellY Below BenfordDistribution BeniniDistribution BenktanderGibratDistribution BenktanderWeibullDistribution BernoulliB BernoulliDistribution BernoulliGraphDistribution BernoulliProcess BernsteinBasis BesselFilterModel BesselI BesselJ BesselJZero BesselK BesselY BesselYZero Beta BetaBinomialDistribution BetaDistribution BetaNegativeBinomialDistribution BetaPrimeDistribution BetaRegularized BetweennessCentrality BezierCurve BezierCurve3DBox BezierCurve3DBoxOptions BezierCurveBox BezierCurveBoxOptions BezierFunction BilateralFilter Binarize BinaryFormat BinaryImageQ BinaryRead BinaryReadList BinaryWrite BinCounts BinLists Binomial BinomialDistribution BinomialProcess BinormalDistribution BiorthogonalSplineWavelet BipartiteGraphQ BirnbaumImportance BirnbaumSaundersDistribution BitAnd BitClear BitGet BitLength BitNot BitOr BitSet BitShiftLeft BitShiftRight BitXor Black BlackmanHarrisWindow BlackmanNuttallWindow BlackmanWindow Blank BlankForm BlankNullSequence BlankSequence Blend Block BlockRandom BlomqvistBeta BlomqvistBetaTest Blue Blur BodePlot BohmanWindow Bold Bookmarks Boole BooleanConsecutiveFunction BooleanConvert BooleanCountingFunction BooleanFunction BooleanGraph BooleanMaxterms BooleanMinimize BooleanMinterms Booleans BooleanTable BooleanVariables BorderDimensions BorelTannerDistribution Bottom BottomHatTransform BoundaryStyle Bounds Box BoxBaselineShift BoxData BoxDimensions Boxed Boxes BoxForm BoxFormFormatTypes BoxFrame BoxID BoxMargins BoxMatrix BoxRatios BoxRotation BoxRotationPoint BoxStyle BoxWhiskerChart Bra BracketingBar BraKet BrayCurtisDistance BreadthFirstScan Break Brown BrownForsytheTest BrownianBridgeProcess BrowserCategory BSplineBasis BSplineCurve BSplineCurve3DBox BSplineCurveBox BSplineCurveBoxOptions BSplineFunction BSplineSurface BSplineSurface3DBox BubbleChart BubbleChart3D BubbleScale BubbleSizes BulletGauge BusinessDayQ ButterflyGraph ButterworthFilterModel Button ButtonBar ButtonBox ButtonBoxOptions ButtonCell ButtonContents ButtonData ButtonEvaluator ButtonExpandable ButtonFrame ButtonFunction ButtonMargins ButtonMinHeight ButtonNote ButtonNotebook ButtonSource ButtonStyle ButtonStyleMenuListing Byte ByteCount ByteOrdering ' +
      'C CachedValue CacheGraphics CalendarData CalendarType CallPacket CanberraDistance Cancel CancelButton CandlestickChart Cap CapForm CapitalDifferentialD CardinalBSplineBasis CarmichaelLambda Cases Cashflow Casoratian Catalan CatalanNumber Catch CauchyDistribution CauchyWindow CayleyGraph CDF CDFDeploy CDFInformation CDFWavelet Ceiling Cell CellAutoOverwrite CellBaseline CellBoundingBox CellBracketOptions CellChangeTimes CellContents CellContext CellDingbat CellDynamicExpression CellEditDuplicate CellElementsBoundingBox CellElementSpacings CellEpilog CellEvaluationDuplicate CellEvaluationFunction CellEventActions CellFrame CellFrameColor CellFrameLabelMargins CellFrameLabels CellFrameMargins CellGroup CellGroupData CellGrouping CellGroupingRules CellHorizontalScrolling CellID CellLabel CellLabelAutoDelete CellLabelMargins CellLabelPositioning CellMargins CellObject CellOpen CellPrint CellProlog Cells CellSize CellStyle CellTags CellularAutomaton CensoredDistribution Censoring Center CenterDot CentralMoment CentralMomentGeneratingFunction CForm ChampernowneNumber ChanVeseBinarize Character CharacterEncoding CharacterEncodingsPath CharacteristicFunction CharacteristicPolynomial CharacterRange Characters ChartBaseStyle ChartElementData ChartElementDataFunction ChartElementFunction ChartElements ChartLabels ChartLayout ChartLegends ChartStyle Chebyshev1FilterModel Chebyshev2FilterModel ChebyshevDistance ChebyshevT ChebyshevU Check CheckAbort CheckAll Checkbox CheckboxBar CheckboxBox CheckboxBoxOptions ChemicalData ChessboardDistance ChiDistribution ChineseRemainder ChiSquareDistribution ChoiceButtons ChoiceDialog CholeskyDecomposition Chop Circle CircleBox CircleDot CircleMinus CirclePlus CircleTimes CirculantGraph CityData Clear ClearAll ClearAttributes ClearSystemCache ClebschGordan ClickPane Clip ClipboardNotebook ClipFill ClippingStyle ClipPlanes ClipRange Clock ClockGauge ClockwiseContourIntegral Close Closed CloseKernels ClosenessCentrality Closing ClosingAutoSave ClosingEvent ClusteringComponents CMYKColor Coarse Coefficient CoefficientArrays CoefficientDomain CoefficientList CoefficientRules CoifletWavelet Collect Colon ColonForm ColorCombine ColorConvert ColorData ColorDataFunction ColorFunction ColorFunctionScaling Colorize ColorNegate ColorOutput ColorProfileData ColorQuantize ColorReplace ColorRules ColorSelectorSettings ColorSeparate ColorSetter ColorSetterBox ColorSetterBoxOptions ColorSlider ColorSpace Column ColumnAlignments ColumnBackgrounds ColumnForm ColumnLines ColumnsEqual ColumnSpacings ColumnWidths CommonDefaultFormatTypes Commonest CommonestFilter CommonUnits CommunityBoundaryStyle CommunityGraphPlot CommunityLabels CommunityRegionStyle CompatibleUnitQ CompilationOptions CompilationTarget Compile Compiled CompiledFunction Complement CompleteGraph CompleteGraphQ CompleteKaryTree CompletionsListPacket Complex Complexes ComplexExpand ComplexInfinity ComplexityFunction ComponentMeasurements ' +
      'ComponentwiseContextMenu Compose ComposeList ComposeSeries Composition CompoundExpression CompoundPoissonDistribution CompoundPoissonProcess CompoundRenewalProcess Compress CompressedData Condition ConditionalExpression Conditioned Cone ConeBox ConfidenceLevel ConfidenceRange ConfidenceTransform ConfigurationPath Congruent Conjugate ConjugateTranspose Conjunction Connect ConnectedComponents ConnectedGraphQ ConnesWindow ConoverTest ConsoleMessage ConsoleMessagePacket ConsolePrint Constant ConstantArray Constants ConstrainedMax ConstrainedMin ContentPadding ContentsBoundingBox ContentSelectable ContentSize Context ContextMenu Contexts ContextToFilename ContextToFileName Continuation Continue ContinuedFraction ContinuedFractionK ContinuousAction ContinuousMarkovProcess ContinuousTimeModelQ ContinuousWaveletData ContinuousWaveletTransform ContourDetect ContourGraphics ContourIntegral ContourLabels ContourLines ContourPlot ContourPlot3D Contours ContourShading ContourSmoothing ContourStyle ContraharmonicMean Control ControlActive ControlAlignment ControllabilityGramian ControllabilityMatrix ControllableDecomposition ControllableModelQ ControllerDuration ControllerInformation ControllerInformationData ControllerLinking ControllerManipulate ControllerMethod ControllerPath ControllerState ControlPlacement ControlsRendering ControlType Convergents ConversionOptions ConversionRules ConvertToBitmapPacket ConvertToPostScript ConvertToPostScriptPacket Convolve ConwayGroupCo1 ConwayGroupCo2 ConwayGroupCo3 CoordinateChartData CoordinatesToolOptions CoordinateTransform CoordinateTransformData CoprimeQ Coproduct CopulaDistribution Copyable CopyDirectory CopyFile CopyTag CopyToClipboard CornerFilter CornerNeighbors Correlation CorrelationDistance CorrelationFunction CorrelationTest Cos Cosh CoshIntegral CosineDistance CosineWindow CosIntegral Cot Coth Count CounterAssignments CounterBox CounterBoxOptions CounterClockwiseContourIntegral CounterEvaluator CounterFunction CounterIncrements CounterStyle CounterStyleMenuListing CountRoots CountryData Covariance CovarianceEstimatorFunction CovarianceFunction CoxianDistribution CoxIngersollRossProcess CoxModel CoxModelFit CramerVonMisesTest CreateArchive CreateDialog CreateDirectory CreateDocument CreateIntermediateDirectories CreatePalette CreatePalettePacket CreateScheduledTask CreateTemporary CreateWindow CriticalityFailureImportance CriticalitySuccessImportance CriticalSection Cross CrossingDetect CrossMatrix Csc Csch CubeRoot Cubics Cuboid CuboidBox Cumulant CumulantGeneratingFunction Cup CupCap Curl CurlyDoubleQuote CurlyQuote CurrentImage CurrentlySpeakingPacket CurrentValue CurvatureFlowFilter CurveClosed Cyan CycleGraph CycleIndexPolynomial Cycles CyclicGroup Cyclotomic Cylinder CylinderBox CylindricalDecomposition ' +
      'D DagumDistribution DamerauLevenshteinDistance DampingFactor Darker Dashed Dashing DataCompression DataDistribution DataRange DataReversed Date DateDelimiters DateDifference DateFunction DateList DateListLogPlot DateListPlot DatePattern DatePlus DateRange DateString DateTicksFormat DaubechiesWavelet DavisDistribution DawsonF DayCount DayCountConvention DayMatchQ DayName DayPlus DayRange DayRound DeBruijnGraph Debug DebugTag Decimal DeclareKnownSymbols DeclarePackage Decompose Decrement DedekindEta Default DefaultAxesStyle DefaultBaseStyle DefaultBoxStyle DefaultButton DefaultColor DefaultControlPlacement DefaultDuplicateCellStyle DefaultDuration DefaultElement DefaultFaceGridsStyle DefaultFieldHintStyle DefaultFont DefaultFontProperties DefaultFormatType DefaultFormatTypeForStyle DefaultFrameStyle DefaultFrameTicksStyle DefaultGridLinesStyle DefaultInlineFormatType DefaultInputFormatType DefaultLabelStyle DefaultMenuStyle DefaultNaturalLanguage DefaultNewCellStyle DefaultNewInlineCellStyle DefaultNotebook DefaultOptions DefaultOutputFormatType DefaultStyle DefaultStyleDefinitions DefaultTextFormatType DefaultTextInlineFormatType DefaultTicksStyle DefaultTooltipStyle DefaultValues Defer DefineExternal DefineInputStreamMethod DefineOutputStreamMethod Definition Degree DegreeCentrality DegreeGraphDistribution DegreeLexicographic DegreeReverseLexicographic Deinitialization Del Deletable Delete DeleteBorderComponents DeleteCases DeleteContents DeleteDirectory DeleteDuplicates DeleteFile DeleteSmallComponents DeleteWithContents DeletionWarning Delimiter DelimiterFlashTime DelimiterMatching Delimiters Denominator DensityGraphics DensityHistogram DensityPlot DependentVariables Deploy Deployed Depth DepthFirstScan Derivative DerivativeFilter DescriptorStateSpace DesignMatrix Det DGaussianWavelet DiacriticalPositioning Diagonal DiagonalMatrix Dialog DialogIndent DialogInput DialogLevel DialogNotebook DialogProlog DialogReturn DialogSymbols Diamond DiamondMatrix DiceDissimilarity DictionaryLookup DifferenceDelta DifferenceOrder DifferenceRoot DifferenceRootReduce Differences DifferentialD DifferentialRoot DifferentialRootReduce DifferentiatorFilter DigitBlock DigitBlockMinimum DigitCharacter DigitCount DigitQ DihedralGroup Dilation Dimensions DiracComb DiracDelta DirectedEdge DirectedEdges DirectedGraph DirectedGraphQ DirectedInfinity Direction Directive Directory DirectoryName DirectoryQ DirectoryStack DirichletCharacter DirichletConvolve DirichletDistribution DirichletL DirichletTransform DirichletWindow DisableConsolePrintPacket DiscreteChirpZTransform DiscreteConvolve DiscreteDelta DiscreteHadamardTransform DiscreteIndicator DiscreteLQEstimatorGains DiscreteLQRegulatorGains DiscreteLyapunovSolve DiscreteMarkovProcess DiscretePlot DiscretePlot3D DiscreteRatio DiscreteRiccatiSolve DiscreteShift DiscreteTimeModelQ DiscreteUniformDistribution DiscreteVariables DiscreteWaveletData DiscreteWaveletPacketTransform ' +
      'DiscreteWaveletTransform Discriminant Disjunction Disk DiskBox DiskMatrix Dispatch DispersionEstimatorFunction Display DisplayAllSteps DisplayEndPacket DisplayFlushImagePacket DisplayForm DisplayFunction DisplayPacket DisplayRules DisplaySetSizePacket DisplayString DisplayTemporary DisplayWith DisplayWithRef DisplayWithVariable DistanceFunction DistanceTransform Distribute Distributed DistributedContexts DistributeDefinitions DistributionChart DistributionDomain DistributionFitTest DistributionParameterAssumptions DistributionParameterQ Dithering Div Divergence Divide DivideBy Dividers Divisible Divisors DivisorSigma DivisorSum DMSList DMSString Do DockedCells DocumentNotebook DominantColors DOSTextFormat Dot DotDashed DotEqual Dotted DoubleBracketingBar DoubleContourIntegral DoubleDownArrow DoubleLeftArrow DoubleLeftRightArrow DoubleLeftTee DoubleLongLeftArrow DoubleLongLeftRightArrow DoubleLongRightArrow DoubleRightArrow DoubleRightTee DoubleUpArrow DoubleUpDownArrow DoubleVerticalBar DoublyInfinite Down DownArrow DownArrowBar DownArrowUpArrow DownLeftRightVector DownLeftTeeVector DownLeftVector DownLeftVectorBar DownRightTeeVector DownRightVector DownRightVectorBar Downsample DownTee DownTeeArrow DownValues DragAndDrop DrawEdges DrawFrontFaces DrawHighlighted Drop DSolve Dt DualLinearProgramming DualSystemsModel DumpGet DumpSave DuplicateFreeQ Dynamic DynamicBox DynamicBoxOptions DynamicEvaluationTimeout DynamicLocation DynamicModule DynamicModuleBox DynamicModuleBoxOptions DynamicModuleParent DynamicModuleValues DynamicName DynamicNamespace DynamicReference DynamicSetting DynamicUpdating DynamicWrapper DynamicWrapperBox DynamicWrapperBoxOptions ' +
      'E EccentricityCentrality EdgeAdd EdgeBetweennessCentrality EdgeCapacity EdgeCapForm EdgeColor EdgeConnectivity EdgeCost EdgeCount EdgeCoverQ EdgeDashing EdgeDelete EdgeDetect EdgeForm EdgeIndex EdgeJoinForm EdgeLabeling EdgeLabels EdgeLabelStyle EdgeList EdgeOpacity EdgeQ EdgeRenderingFunction EdgeRules EdgeShapeFunction EdgeStyle EdgeThickness EdgeWeight Editable EditButtonSettings EditCellTagsSettings EditDistance EffectiveInterest Eigensystem Eigenvalues EigenvectorCentrality Eigenvectors Element ElementData Eliminate EliminationOrder EllipticE EllipticExp EllipticExpPrime EllipticF EllipticFilterModel EllipticK EllipticLog EllipticNomeQ EllipticPi EllipticReducedHalfPeriods EllipticTheta EllipticThetaPrime EmitSound EmphasizeSyntaxErrors EmpiricalDistribution Empty EmptyGraphQ EnableConsolePrintPacket Enabled Encode End EndAdd EndDialogPacket EndFrontEndInteractionPacket EndOfFile EndOfLine EndOfString EndPackage EngineeringForm Enter EnterExpressionPacket EnterTextPacket Entropy EntropyFilter Environment Epilog Equal EqualColumns EqualRows EqualTilde EquatedTo Equilibrium EquirippleFilterKernel Equivalent Erf Erfc Erfi ErlangB ErlangC ErlangDistribution Erosion ErrorBox ErrorBoxOptions ErrorNorm ErrorPacket ErrorsDialogSettings EstimatedDistribution EstimatedProcess EstimatorGains EstimatorRegulator EuclideanDistance EulerE EulerGamma EulerianGraphQ EulerPhi Evaluatable Evaluate Evaluated EvaluatePacket EvaluationCell EvaluationCompletionAction EvaluationElements EvaluationMode EvaluationMonitor EvaluationNotebook EvaluationObject EvaluationOrder Evaluator EvaluatorNames EvenQ EventData EventEvaluator EventHandler EventHandlerTag EventLabels ExactBlackmanWindow ExactNumberQ ExactRootIsolation ExampleData Except ExcludedForms ExcludePods Exclusions ExclusionsStyle Exists Exit ExitDialog Exp Expand ExpandAll ExpandDenominator ExpandFileName ExpandNumerator Expectation ExpectationE ExpectedValue ExpGammaDistribution ExpIntegralE ExpIntegralEi Exponent ExponentFunction ExponentialDistribution ExponentialFamily ExponentialGeneratingFunction ExponentialMovingAverage ExponentialPowerDistribution ExponentPosition ExponentStep Export ExportAutoReplacements ExportPacket ExportString Expression ExpressionCell ExpressionPacket ExpToTrig ExtendedGCD Extension ExtentElementFunction ExtentMarkers ExtentSize ExternalCall ExternalDataCharacterEncoding Extract ExtractArchive ExtremeValueDistribution ' +
      'FaceForm FaceGrids FaceGridsStyle Factor FactorComplete Factorial Factorial2 FactorialMoment FactorialMomentGeneratingFunction FactorialPower FactorInteger FactorList FactorSquareFree FactorSquareFreeList FactorTerms FactorTermsList Fail FailureDistribution False FARIMAProcess FEDisableConsolePrintPacket FeedbackSector FeedbackSectorStyle FeedbackType FEEnableConsolePrintPacket Fibonacci FieldHint FieldHintStyle FieldMasked FieldSize File FileBaseName FileByteCount FileDate FileExistsQ FileExtension FileFormat FileHash FileInformation FileName FileNameDepth FileNameDialogSettings FileNameDrop FileNameJoin FileNames FileNameSetter FileNameSplit FileNameTake FilePrint FileType FilledCurve FilledCurveBox Filling FillingStyle FillingTransform FilterRules FinancialBond FinancialData FinancialDerivative FinancialIndicator Find FindArgMax FindArgMin FindClique FindClusters FindCurvePath FindDistributionParameters FindDivisions FindEdgeCover FindEdgeCut FindEulerianCycle FindFaces FindFile FindFit FindGeneratingFunction FindGeoLocation FindGeometricTransform FindGraphCommunities FindGraphIsomorphism FindGraphPartition FindHamiltonianCycle FindIndependentEdgeSet FindIndependentVertexSet FindInstance FindIntegerNullVector FindKClan FindKClique FindKClub FindKPlex FindLibrary FindLinearRecurrence FindList FindMaximum FindMaximumFlow FindMaxValue FindMinimum FindMinimumCostFlow FindMinimumCut FindMinValue FindPermutation FindPostmanTour FindProcessParameters FindRoot FindSequenceFunction FindSettings FindShortestPath FindShortestTour FindThreshold FindVertexCover FindVertexCut Fine FinishDynamic FiniteAbelianGroupCount FiniteGroupCount FiniteGroupData First FirstPassageTimeDistribution FischerGroupFi22 FischerGroupFi23 FischerGroupFi24Prime FisherHypergeometricDistribution FisherRatioTest FisherZDistribution Fit FitAll FittedModel FixedPoint FixedPointList FlashSelection Flat Flatten FlattenAt FlatTopWindow FlipView Floor FlushPrintOutputPacket Fold FoldList Font FontColor FontFamily FontForm FontName FontOpacity FontPostScriptName FontProperties FontReencoding FontSize FontSlant FontSubstitutions FontTracking FontVariations FontWeight For ForAll Format FormatRules FormatType FormatTypeAutoConvert FormatValues FormBox FormBoxOptions FortranForm Forward ForwardBackward Fourier FourierCoefficient FourierCosCoefficient FourierCosSeries FourierCosTransform FourierDCT FourierDCTFilter FourierDCTMatrix FourierDST FourierDSTMatrix FourierMatrix FourierParameters FourierSequenceTransform FourierSeries FourierSinCoefficient FourierSinSeries FourierSinTransform FourierTransform FourierTrigSeries FractionalBrownianMotionProcess FractionalPart FractionBox FractionBoxOptions FractionLine Frame FrameBox FrameBoxOptions Framed FrameInset FrameLabel Frameless FrameMargins FrameStyle FrameTicks FrameTicksStyle FRatioDistribution FrechetDistribution FreeQ FrequencySamplingFilterKernel FresnelC FresnelS Friday FrobeniusNumber FrobeniusSolve ' +
      'FromCharacterCode FromCoefficientRules FromContinuedFraction FromDate FromDigits FromDMS Front FrontEndDynamicExpression FrontEndEventActions FrontEndExecute FrontEndObject FrontEndResource FrontEndResourceString FrontEndStackSize FrontEndToken FrontEndTokenExecute FrontEndValueCache FrontEndVersion FrontFaceColor FrontFaceOpacity Full FullAxes FullDefinition FullForm FullGraphics FullOptions FullSimplify Function FunctionExpand FunctionInterpolation FunctionSpace FussellVeselyImportance ' +
      'GaborFilter GaborMatrix GaborWavelet GainMargins GainPhaseMargins Gamma GammaDistribution GammaRegularized GapPenalty Gather GatherBy GaugeFaceElementFunction GaugeFaceStyle GaugeFrameElementFunction GaugeFrameSize GaugeFrameStyle GaugeLabels GaugeMarkers GaugeStyle GaussianFilter GaussianIntegers GaussianMatrix GaussianWindow GCD GegenbauerC General GeneralizedLinearModelFit GenerateConditions GeneratedCell GeneratedParameters GeneratingFunction Generic GenericCylindricalDecomposition GenomeData GenomeLookup GeodesicClosing GeodesicDilation GeodesicErosion GeodesicOpening GeoDestination GeodesyData GeoDirection GeoDistance GeoGridPosition GeometricBrownianMotionProcess GeometricDistribution GeometricMean GeometricMeanFilter GeometricTransformation GeometricTransformation3DBox GeometricTransformation3DBoxOptions GeometricTransformationBox GeometricTransformationBoxOptions GeoPosition GeoPositionENU GeoPositionXYZ GeoProjectionData GestureHandler GestureHandlerTag Get GetBoundingBoxSizePacket GetContext GetEnvironment GetFileName GetFrontEndOptionsDataPacket GetLinebreakInformationPacket GetMenusPacket GetPageBreakInformationPacket Glaisher GlobalClusteringCoefficient GlobalPreferences GlobalSession Glow GoldenRatio GompertzMakehamDistribution GoodmanKruskalGamma GoodmanKruskalGammaTest Goto Grad Gradient GradientFilter GradientOrientationFilter Graph GraphAssortativity GraphCenter GraphComplement GraphData GraphDensity GraphDiameter GraphDifference GraphDisjointUnion ' +
      'GraphDistance GraphDistanceMatrix GraphElementData GraphEmbedding GraphHighlight GraphHighlightStyle GraphHub Graphics Graphics3D Graphics3DBox Graphics3DBoxOptions GraphicsArray GraphicsBaseline GraphicsBox GraphicsBoxOptions GraphicsColor GraphicsColumn GraphicsComplex GraphicsComplex3DBox GraphicsComplex3DBoxOptions GraphicsComplexBox GraphicsComplexBoxOptions GraphicsContents GraphicsData GraphicsGrid GraphicsGridBox GraphicsGroup GraphicsGroup3DBox GraphicsGroup3DBoxOptions GraphicsGroupBox GraphicsGroupBoxOptions GraphicsGrouping GraphicsHighlightColor GraphicsRow GraphicsSpacing GraphicsStyle GraphIntersection GraphLayout GraphLinkEfficiency GraphPeriphery GraphPlot GraphPlot3D GraphPower GraphPropertyDistribution GraphQ GraphRadius GraphReciprocity GraphRoot GraphStyle GraphUnion Gray GrayLevel GreatCircleDistance Greater GreaterEqual GreaterEqualLess GreaterFullEqual GreaterGreater GreaterLess GreaterSlantEqual GreaterTilde Green Grid GridBaseline GridBox GridBoxAlignment GridBoxBackground GridBoxDividers GridBoxFrame GridBoxItemSize GridBoxItemStyle GridBoxOptions GridBoxSpacings GridCreationSettings GridDefaultElement GridElementStyleOptions GridFrame GridFrameMargins GridGraph GridLines GridLinesStyle GroebnerBasis GroupActionBase GroupCentralizer GroupElementFromWord GroupElementPosition GroupElementQ GroupElements GroupElementToWord GroupGenerators GroupMultiplicationTable GroupOrbits GroupOrder GroupPageBreakWithin GroupSetwiseStabilizer GroupStabilizer GroupStabilizerChain Gudermannian GumbelDistribution ' +
      'HaarWavelet HadamardMatrix HalfNormalDistribution HamiltonianGraphQ HammingDistance HammingWindow HankelH1 HankelH2 HankelMatrix HannPoissonWindow HannWindow HaradaNortonGroupHN HararyGraph HarmonicMean HarmonicMeanFilter HarmonicNumber Hash HashTable Haversine HazardFunction Head HeadCompose Heads HeavisideLambda HeavisidePi HeavisideTheta HeldGroupHe HeldPart HelpBrowserLookup HelpBrowserNotebook HelpBrowserSettings HermiteDecomposition HermiteH HermitianMatrixQ HessenbergDecomposition Hessian HexadecimalCharacter Hexahedron HexahedronBox HexahedronBoxOptions HiddenSurface HighlightGraph HighlightImage HighpassFilter HigmanSimsGroupHS HilbertFilter HilbertMatrix Histogram Histogram3D HistogramDistribution HistogramList HistogramTransform HistogramTransformInterpolation HitMissTransform HITSCentrality HodgeDual HoeffdingD HoeffdingDTest Hold HoldAll HoldAllComplete HoldComplete HoldFirst HoldForm HoldPattern HoldRest HolidayCalendar HomeDirectory HomePage Horizontal HorizontalForm HorizontalGauge HorizontalScrollPosition HornerForm HotellingTSquareDistribution HoytDistribution HTMLSave Hue HumpDownHump HumpEqual HurwitzLerchPhi HurwitzZeta HyperbolicDistribution HypercubeGraph HyperexponentialDistribution Hyperfactorial Hypergeometric0F1 Hypergeometric0F1Regularized Hypergeometric1F1 Hypergeometric1F1Regularized Hypergeometric2F1 Hypergeometric2F1Regularized HypergeometricDistribution HypergeometricPFQ HypergeometricPFQRegularized HypergeometricU Hyperlink HyperlinkCreationSettings Hyphenation HyphenationOptions HypoexponentialDistribution HypothesisTestData ' +
      'I Identity IdentityMatrix If IgnoreCase Im Image Image3D Image3DSlices ImageAccumulate ImageAdd ImageAdjust ImageAlign ImageApply ImageAspectRatio ImageAssemble ImageCache ImageCacheValid ImageCapture ImageChannels ImageClip ImageColorSpace ImageCompose ImageConvolve ImageCooccurrence ImageCorners ImageCorrelate ImageCorrespondingPoints ImageCrop ImageData ImageDataPacket ImageDeconvolve ImageDemosaic ImageDifference ImageDimensions ImageDistance ImageEffect ImageFeatureTrack ImageFileApply ImageFileFilter ImageFileScan ImageFilter ImageForestingComponents ImageForwardTransformation ImageHistogram ImageKeypoints ImageLevels ImageLines ImageMargins ImageMarkers ImageMeasurements ImageMultiply ImageOffset ImagePad ImagePadding ImagePartition ImagePeriodogram ImagePerspectiveTransformation ImageQ ImageRangeCache ImageReflect ImageRegion ImageResize ImageResolution ImageRotate ImageRotated ImageScaled ImageScan ImageSize ImageSizeAction ImageSizeCache ImageSizeMultipliers ImageSizeRaw ImageSubtract ImageTake ImageTransformation ImageTrim ImageType ImageValue ImageValuePositions Implies Import ImportAutoReplacements ImportString ImprovementImportance In IncidenceGraph IncidenceList IncidenceMatrix IncludeConstantBasis IncludeFileExtension IncludePods IncludeSingularTerm Increment Indent IndentingNewlineSpacings IndentMaxFraction IndependenceTest IndependentEdgeSetQ IndependentUnit IndependentVertexSetQ Indeterminate IndexCreationOptions Indexed IndexGraph IndexTag Inequality InexactNumberQ InexactNumbers Infinity Infix Information Inherited InheritScope Initialization InitializationCell InitializationCellEvaluation InitializationCellWarning InlineCounterAssignments InlineCounterIncrements InlineRules Inner Inpaint Input InputAliases InputAssumptions InputAutoReplacements InputField InputFieldBox InputFieldBoxOptions InputForm InputGrouping InputNamePacket InputNotebook InputPacket InputSettings InputStream InputString InputStringPacket InputToBoxFormPacket Insert InsertionPointObject InsertResults Inset Inset3DBox Inset3DBoxOptions InsetBox InsetBoxOptions Install InstallService InString Integer IntegerDigits IntegerExponent IntegerLength IntegerPart IntegerPartitions IntegerQ Integers IntegerString Integral Integrate Interactive InteractiveTradingChart Interlaced Interleaving InternallyBalancedDecomposition InterpolatingFunction InterpolatingPolynomial Interpolation InterpolationOrder InterpolationPoints InterpolationPrecision Interpretation InterpretationBox InterpretationBoxOptions InterpretationFunction ' +
      'InterpretTemplate InterquartileRange Interrupt InterruptSettings Intersection Interval IntervalIntersection IntervalMemberQ IntervalUnion Inverse InverseBetaRegularized InverseCDF InverseChiSquareDistribution InverseContinuousWaveletTransform InverseDistanceTransform InverseEllipticNomeQ InverseErf InverseErfc InverseFourier InverseFourierCosTransform InverseFourierSequenceTransform InverseFourierSinTransform InverseFourierTransform InverseFunction InverseFunctions InverseGammaDistribution InverseGammaRegularized InverseGaussianDistribution InverseGudermannian InverseHaversine InverseJacobiCD InverseJacobiCN InverseJacobiCS InverseJacobiDC InverseJacobiDN InverseJacobiDS InverseJacobiNC InverseJacobiND InverseJacobiNS InverseJacobiSC InverseJacobiSD InverseJacobiSN InverseLaplaceTransform InversePermutation InverseRadon InverseSeries InverseSurvivalFunction InverseWaveletTransform InverseWeierstrassP InverseZTransform Invisible InvisibleApplication InvisibleTimes IrreduciblePolynomialQ IsolatingInterval IsomorphicGraphQ IsotopeData Italic Item ItemBox ItemBoxOptions ItemSize ItemStyle ItoProcess ' +
      'JaccardDissimilarity JacobiAmplitude Jacobian JacobiCD JacobiCN JacobiCS JacobiDC JacobiDN JacobiDS JacobiNC JacobiND JacobiNS JacobiP JacobiSC JacobiSD JacobiSN JacobiSymbol JacobiZeta JankoGroupJ1 JankoGroupJ2 JankoGroupJ3 JankoGroupJ4 JarqueBeraALMTest JohnsonDistribution Join Joined JoinedCurve JoinedCurveBox JoinForm JordanDecomposition JordanModelDecomposition ' +
      'K KagiChart KaiserBesselWindow KaiserWindow KalmanEstimator KalmanFilter KarhunenLoeveDecomposition KaryTree KatzCentrality KCoreComponents KDistribution KelvinBei KelvinBer KelvinKei KelvinKer KendallTau KendallTauTest KernelExecute KernelMixtureDistribution KernelObject Kernels Ket Khinchin KirchhoffGraph KirchhoffMatrix KleinInvariantJ KnightTourGraph KnotData KnownUnitQ KolmogorovSmirnovTest KroneckerDelta KroneckerModelDecomposition KroneckerProduct KroneckerSymbol KuiperTest KumaraswamyDistribution Kurtosis KuwaharaFilter ' +
      'Label Labeled LabeledSlider LabelingFunction LabelStyle LaguerreL LambdaComponents LambertW LanczosWindow LandauDistribution Language LanguageCategory LaplaceDistribution LaplaceTransform Laplacian LaplacianFilter LaplacianGaussianFilter Large Larger Last Latitude LatitudeLongitude LatticeData LatticeReduce Launch LaunchKernels LayeredGraphPlot LayerSizeFunction LayoutInformation LCM LeafCount LeapYearQ LeastSquares LeastSquaresFilterKernel Left LeftArrow LeftArrowBar LeftArrowRightArrow LeftDownTeeVector LeftDownVector LeftDownVectorBar LeftRightArrow LeftRightVector LeftTee LeftTeeArrow LeftTeeVector LeftTriangle LeftTriangleBar LeftTriangleEqual LeftUpDownVector LeftUpTeeVector LeftUpVector LeftUpVectorBar LeftVector LeftVectorBar LegendAppearance Legended LegendFunction LegendLabel LegendLayout LegendMargins LegendMarkers LegendMarkerSize LegendreP LegendreQ LegendreType Length LengthWhile LerchPhi Less LessEqual LessEqualGreater LessFullEqual LessGreater LessLess LessSlantEqual LessTilde LetterCharacter LetterQ Level LeveneTest LeviCivitaTensor LevyDistribution Lexicographic LibraryFunction LibraryFunctionError LibraryFunctionInformation LibraryFunctionLoad LibraryFunctionUnload LibraryLoad LibraryUnload LicenseID LiftingFilterData LiftingWaveletTransform LightBlue LightBrown LightCyan Lighter LightGray LightGreen Lighting LightingAngle LightMagenta LightOrange LightPink LightPurple LightRed LightSources LightYellow Likelihood Limit LimitsPositioning LimitsPositioningTokens LindleyDistribution Line Line3DBox LinearFilter LinearFractionalTransform LinearModelFit LinearOffsetFunction LinearProgramming LinearRecurrence LinearSolve LinearSolveFunction LineBox LineBreak LinebreakAdjustments LineBreakChart LineBreakWithin LineColor LineForm LineGraph LineIndent LineIndentMaxFraction LineIntegralConvolutionPlot LineIntegralConvolutionScale LineLegend LineOpacity LineSpacing LineWrapParts LinkActivate LinkClose LinkConnect LinkConnectedQ LinkCreate LinkError LinkFlush LinkFunction LinkHost LinkInterrupt LinkLaunch LinkMode LinkObject LinkOpen LinkOptions LinkPatterns LinkProtocol LinkRead LinkReadHeld LinkReadyQ Links LinkWrite LinkWriteHeld LiouvilleLambda List Listable ListAnimate ListContourPlot ListContourPlot3D ListConvolve ListCorrelate ListCurvePathPlot ListDeconvolve ListDensityPlot Listen ListFourierSequenceTransform ListInterpolation ListLineIntegralConvolutionPlot ListLinePlot ListLogLinearPlot ListLogLogPlot ListLogPlot ListPicker ListPickerBox ListPickerBoxBackground ListPickerBoxOptions ListPlay ListPlot ListPlot3D ListPointPlot3D ListPolarPlot ListQ ListStreamDensityPlot ListStreamPlot ListSurfacePlot3D ListVectorDensityPlot ListVectorPlot ListVectorPlot3D ListZTransform Literal LiteralSearch LocalClusteringCoefficient LocalizeVariables LocationEquivalenceTest LocationTest Locator LocatorAutoCreate LocatorBox LocatorBoxOptions LocatorCentering LocatorPane LocatorPaneBox LocatorPaneBoxOptions ' +
      'LocatorRegion Locked Log Log10 Log2 LogBarnesG LogGamma LogGammaDistribution LogicalExpand LogIntegral LogisticDistribution LogitModelFit LogLikelihood LogLinearPlot LogLogisticDistribution LogLogPlot LogMultinormalDistribution LogNormalDistribution LogPlot LogRankTest LogSeriesDistribution LongEqual Longest LongestAscendingSequence LongestCommonSequence LongestCommonSequencePositions LongestCommonSubsequence LongestCommonSubsequencePositions LongestMatch LongForm Longitude LongLeftArrow LongLeftRightArrow LongRightArrow Loopback LoopFreeGraphQ LowerCaseQ LowerLeftArrow LowerRightArrow LowerTriangularize LowpassFilter LQEstimatorGains LQGRegulator LQOutputRegulatorGains LQRegulatorGains LUBackSubstitution LucasL LuccioSamiComponents LUDecomposition LyapunovSolve LyonsGroupLy ' +
      'MachineID MachineName MachineNumberQ MachinePrecision MacintoshSystemPageSetup Magenta Magnification Magnify MainSolve MaintainDynamicCaches Majority MakeBoxes MakeExpression MakeRules MangoldtLambda ManhattanDistance Manipulate Manipulator MannWhitneyTest MantissaExponent Manual Map MapAll MapAt MapIndexed MAProcess MapThread MarcumQ MardiaCombinedTest MardiaKurtosisTest MardiaSkewnessTest MarginalDistribution MarkovProcessProperties Masking MatchingDissimilarity MatchLocalNameQ MatchLocalNames MatchQ Material MathematicaNotation MathieuC MathieuCharacteristicA MathieuCharacteristicB MathieuCharacteristicExponent MathieuCPrime MathieuGroupM11 MathieuGroupM12 MathieuGroupM22 MathieuGroupM23 MathieuGroupM24 MathieuS MathieuSPrime MathMLForm MathMLText Matrices MatrixExp MatrixForm MatrixFunction MatrixLog MatrixPlot MatrixPower MatrixQ MatrixRank Max MaxBend MaxDetect MaxExtraBandwidths MaxExtraConditions MaxFeatures MaxFilter Maximize MaxIterations MaxMemoryUsed MaxMixtureKernels MaxPlotPoints MaxPoints MaxRecursion MaxStableDistribution MaxStepFraction MaxSteps MaxStepSize MaxValue MaxwellDistribution McLaughlinGroupMcL Mean MeanClusteringCoefficient MeanDegreeConnectivity MeanDeviation MeanFilter MeanGraphDistance MeanNeighborDegree MeanShift MeanShiftFilter Median MedianDeviation MedianFilter Medium MeijerG MeixnerDistribution MemberQ MemoryConstrained MemoryInUse Menu MenuAppearance MenuCommandKey MenuEvaluator MenuItem MenuPacket MenuSortingValue MenuStyle MenuView MergeDifferences Mesh MeshFunctions MeshRange MeshShading MeshStyle Message MessageDialog MessageList MessageName MessageOptions MessagePacket Messages MessagesNotebook MetaCharacters MetaInformation Method MethodOptions MexicanHatWavelet MeyerWavelet Min MinDetect MinFilter MinimalPolynomial MinimalStateSpaceModel Minimize Minors MinRecursion MinSize MinStableDistribution Minus MinusPlus MinValue Missing MissingDataMethod MittagLefflerE MixedRadix MixedRadixQuantity MixtureDistribution Mod Modal Mode Modular ModularLambda Module Modulus MoebiusMu Moment Momentary MomentConvert MomentEvaluate MomentGeneratingFunction Monday Monitor MonomialList MonomialOrder MonsterGroupM MorletWavelet MorphologicalBinarize MorphologicalBranchPoints MorphologicalComponents MorphologicalEulerNumber MorphologicalGraph MorphologicalPerimeter MorphologicalTransform Most MouseAnnotation MouseAppearance MouseAppearanceTag MouseButtons Mouseover MousePointerNote MousePosition MovingAverage MovingMedian MoyalDistribution MultiedgeStyle MultilaunchWarning MultiLetterItalics MultiLetterStyle MultilineFunction Multinomial MultinomialDistribution MultinormalDistribution MultiplicativeOrder Multiplicity Multiselection MultivariateHypergeometricDistribution MultivariatePoissonDistribution MultivariateTDistribution ' +
      'N NakagamiDistribution NameQ Names NamespaceBox Nand NArgMax NArgMin NBernoulliB NCache NDSolve NDSolveValue Nearest NearestFunction NeedCurrentFrontEndPackagePacket NeedCurrentFrontEndSymbolsPacket NeedlemanWunschSimilarity Needs Negative NegativeBinomialDistribution NegativeMultinomialDistribution NeighborhoodGraph Nest NestedGreaterGreater NestedLessLess NestedScriptRules NestList NestWhile NestWhileList NevilleThetaC NevilleThetaD NevilleThetaN NevilleThetaS NewPrimitiveStyle NExpectation Next NextPrime NHoldAll NHoldFirst NHoldRest NicholsGridLines NicholsPlot NIntegrate NMaximize NMaxValue NMinimize NMinValue NominalVariables NonAssociative NoncentralBetaDistribution NoncentralChiSquareDistribution NoncentralFRatioDistribution NoncentralStudentTDistribution NonCommutativeMultiply NonConstants None NonlinearModelFit NonlocalMeansFilter NonNegative NonPositive Nor NorlundB Norm Normal NormalDistribution NormalGrouping Normalize NormalizedSquaredEuclideanDistance NormalsFunction NormFunction Not NotCongruent NotCupCap NotDoubleVerticalBar Notebook NotebookApply NotebookAutoSave NotebookClose NotebookConvertSettings NotebookCreate NotebookCreateReturnObject NotebookDefault NotebookDelete NotebookDirectory NotebookDynamicExpression NotebookEvaluate NotebookEventActions NotebookFileName NotebookFind NotebookFindReturnObject NotebookGet NotebookGetLayoutInformationPacket NotebookGetMisspellingsPacket NotebookInformation NotebookInterfaceObject NotebookLocate NotebookObject NotebookOpen NotebookOpenReturnObject NotebookPath NotebookPrint NotebookPut NotebookPutReturnObject NotebookRead NotebookResetGeneratedCells Notebooks NotebookSave NotebookSaveAs NotebookSelection NotebookSetupLayoutInformationPacket NotebooksMenu NotebookWrite NotElement NotEqualTilde NotExists NotGreater NotGreaterEqual NotGreaterFullEqual NotGreaterGreater NotGreaterLess NotGreaterSlantEqual NotGreaterTilde NotHumpDownHump NotHumpEqual NotLeftTriangle NotLeftTriangleBar NotLeftTriangleEqual NotLess NotLessEqual NotLessFullEqual NotLessGreater NotLessLess NotLessSlantEqual NotLessTilde NotNestedGreaterGreater NotNestedLessLess NotPrecedes NotPrecedesEqual NotPrecedesSlantEqual NotPrecedesTilde NotReverseElement NotRightTriangle NotRightTriangleBar NotRightTriangleEqual NotSquareSubset NotSquareSubsetEqual NotSquareSuperset NotSquareSupersetEqual NotSubset NotSubsetEqual NotSucceeds NotSucceedsEqual NotSucceedsSlantEqual NotSucceedsTilde NotSuperset NotSupersetEqual NotTilde NotTildeEqual NotTildeFullEqual NotTildeTilde NotVerticalBar NProbability NProduct NProductFactors NRoots NSolve NSum NSumTerms Null NullRecords NullSpace NullWords Number NumberFieldClassNumber NumberFieldDiscriminant NumberFieldFundamentalUnits NumberFieldIntegralBasis NumberFieldNormRepresentatives NumberFieldRegulator NumberFieldRootsOfUnity NumberFieldSignature NumberForm NumberFormat NumberMarks NumberMultiplier NumberPadding NumberPoint NumberQ NumberSeparator ' +
      'NumberSigns NumberString Numerator NumericFunction NumericQ NuttallWindow NValues NyquistGridLines NyquistPlot ' +
      'O ObservabilityGramian ObservabilityMatrix ObservableDecomposition ObservableModelQ OddQ Off Offset OLEData On ONanGroupON OneIdentity Opacity Open OpenAppend Opener OpenerBox OpenerBoxOptions OpenerView OpenFunctionInspectorPacket Opening OpenRead OpenSpecialOptions OpenTemporary OpenWrite Operate OperatingSystem OptimumFlowData Optional OptionInspectorSettings OptionQ Options OptionsPacket OptionsPattern OptionValue OptionValueBox OptionValueBoxOptions Or Orange Order OrderDistribution OrderedQ Ordering Orderless OrnsteinUhlenbeckProcess Orthogonalize Out Outer OutputAutoOverwrite OutputControllabilityMatrix OutputControllableModelQ OutputForm OutputFormData OutputGrouping OutputMathEditExpression OutputNamePacket OutputResponse OutputSizeLimit OutputStream Over OverBar OverDot Overflow OverHat Overlaps Overlay OverlayBox OverlayBoxOptions Overscript OverscriptBox OverscriptBoxOptions OverTilde OverVector OwenT OwnValues ' +
      'PackingMethod PaddedForm Padding PadeApproximant PadLeft PadRight PageBreakAbove PageBreakBelow PageBreakWithin PageFooterLines PageFooters PageHeaderLines PageHeaders PageHeight PageRankCentrality PageWidth PairedBarChart PairedHistogram PairedSmoothHistogram PairedTTest PairedZTest PaletteNotebook PalettePath Pane PaneBox PaneBoxOptions Panel PanelBox PanelBoxOptions Paneled PaneSelector PaneSelectorBox PaneSelectorBoxOptions PaperWidth ParabolicCylinderD ParagraphIndent ParagraphSpacing ParallelArray ParallelCombine ParallelDo ParallelEvaluate Parallelization Parallelize ParallelMap ParallelNeeds ParallelProduct ParallelSubmit ParallelSum ParallelTable ParallelTry Parameter ParameterEstimator ParameterMixtureDistribution ParameterVariables ParametricFunction ParametricNDSolve ParametricNDSolveValue ParametricPlot ParametricPlot3D ParentConnect ParentDirectory ParentForm Parenthesize ParentList ParetoDistribution Part PartialCorrelationFunction PartialD ParticleData Partition PartitionsP PartitionsQ ParzenWindow PascalDistribution PassEventsDown PassEventsUp Paste PasteBoxFormInlineCells PasteButton Path PathGraph PathGraphQ Pattern PatternSequence PatternTest PauliMatrix PaulWavelet Pause PausedTime PDF PearsonChiSquareTest PearsonCorrelationTest PearsonDistribution PerformanceGoal PeriodicInterpolation Periodogram PeriodogramArray PermutationCycles PermutationCyclesQ PermutationGroup PermutationLength PermutationList PermutationListQ PermutationMax PermutationMin PermutationOrder PermutationPower PermutationProduct PermutationReplace Permutations PermutationSupport Permute PeronaMalikFilter Perpendicular PERTDistribution PetersenGraph PhaseMargins Pi Pick PIDData PIDDerivativeFilter PIDFeedforward PIDTune Piecewise PiecewiseExpand PieChart PieChart3D PillaiTrace PillaiTraceTest Pink Pivoting PixelConstrained PixelValue PixelValuePositions Placed Placeholder PlaceholderReplace Plain PlanarGraphQ Play PlayRange Plot Plot3D Plot3Matrix PlotDivision PlotJoined PlotLabel PlotLayout PlotLegends PlotMarkers PlotPoints PlotRange PlotRangeClipping PlotRangePadding PlotRegion PlotStyle Plus PlusMinus Pochhammer PodStates PodWidth Point Point3DBox PointBox PointFigureChart PointForm PointLegend PointSize PoissonConsulDistribution PoissonDistribution PoissonProcess PoissonWindow PolarAxes PolarAxesOrigin PolarGridLines PolarPlot PolarTicks PoleZeroMarkers PolyaAeppliDistribution PolyGamma Polygon Polygon3DBox Polygon3DBoxOptions PolygonBox PolygonBoxOptions PolygonHoleScale PolygonIntersections PolygonScale PolyhedronData PolyLog PolynomialExtendedGCD PolynomialForm PolynomialGCD PolynomialLCM PolynomialMod PolynomialQ PolynomialQuotient PolynomialQuotientRemainder PolynomialReduce PolynomialRemainder Polynomials PopupMenu PopupMenuBox PopupMenuBoxOptions PopupView PopupWindow Position Positive PositiveDefiniteMatrixQ PossibleZeroQ Postfix PostScript Power PowerDistribution PowerExpand PowerMod PowerModList ' +
      'PowerSpectralDensity PowersRepresentations PowerSymmetricPolynomial Precedence PrecedenceForm Precedes PrecedesEqual PrecedesSlantEqual PrecedesTilde Precision PrecisionGoal PreDecrement PredictionRoot PreemptProtect PreferencesPath Prefix PreIncrement Prepend PrependTo PreserveImageOptions Previous PriceGraphDistribution PrimaryPlaceholder Prime PrimeNu PrimeOmega PrimePi PrimePowerQ PrimeQ Primes PrimeZetaP PrimitiveRoot PrincipalComponents PrincipalValue Print PrintAction PrintForm PrintingCopies PrintingOptions PrintingPageRange PrintingStartingPageNumber PrintingStyleEnvironment PrintPrecision PrintTemporary Prism PrismBox PrismBoxOptions PrivateCellOptions PrivateEvaluationOptions PrivateFontOptions PrivateFrontEndOptions PrivateNotebookOptions PrivatePaths Probability ProbabilityDistribution ProbabilityPlot ProbabilityPr ProbabilityScalePlot ProbitModelFit ProcessEstimator ProcessParameterAssumptions ProcessParameterQ ProcessStateDomain ProcessTimeDomain Product ProductDistribution ProductLog ProgressIndicator ProgressIndicatorBox ProgressIndicatorBoxOptions Projection Prolog PromptForm Properties Property PropertyList PropertyValue Proportion Proportional Protect Protected ProteinData Pruning PseudoInverse Purple Put PutAppend Pyramid PyramidBox PyramidBoxOptions ' +
      'QBinomial QFactorial QGamma QHypergeometricPFQ QPochhammer QPolyGamma QRDecomposition QuadraticIrrationalQ Quantile QuantilePlot Quantity QuantityForm QuantityMagnitude QuantityQ QuantityUnit Quartics QuartileDeviation Quartiles QuartileSkewness QueueingNetworkProcess QueueingProcess QueueProperties Quiet Quit Quotient QuotientRemainder ' +
      'RadialityCentrality RadicalBox RadicalBoxOptions RadioButton RadioButtonBar RadioButtonBox RadioButtonBoxOptions Radon RamanujanTau RamanujanTauL RamanujanTauTheta RamanujanTauZ Random RandomChoice RandomComplex RandomFunction RandomGraph RandomImage RandomInteger RandomPermutation RandomPrime RandomReal RandomSample RandomSeed RandomVariate RandomWalkProcess Range RangeFilter RangeSpecification RankedMax RankedMin Raster Raster3D Raster3DBox Raster3DBoxOptions RasterArray RasterBox RasterBoxOptions Rasterize RasterSize Rational RationalFunctions Rationalize Rationals Ratios Raw RawArray RawBoxes RawData RawMedium RayleighDistribution Re Read ReadList ReadProtected Real RealBlockDiagonalForm RealDigits RealExponent Reals Reap Record RecordLists RecordSeparators Rectangle RectangleBox RectangleBoxOptions RectangleChart RectangleChart3D RecurrenceFilter RecurrenceTable RecurringDigitsForm Red Reduce RefBox ReferenceLineStyle ReferenceMarkers ReferenceMarkerStyle Refine ReflectionMatrix ReflectionTransform Refresh RefreshRate RegionBinarize RegionFunction RegionPlot RegionPlot3D RegularExpression Regularization Reinstall Release ReleaseHold ReliabilityDistribution ReliefImage ReliefPlot Remove RemoveAlphaChannel RemoveAsynchronousTask Removed RemoveInputStreamMethod RemoveOutputStreamMethod RemoveProperty RemoveScheduledTask RenameDirectory RenameFile RenderAll RenderingOptions RenewalProcess RenkoChart Repeated RepeatedNull RepeatedString Replace ReplaceAll ReplaceHeldPart ReplaceImageValue ReplaceList ReplacePart ReplacePixelValue ReplaceRepeated Resampling Rescale RescalingTransform ResetDirectory ResetMenusPacket ResetScheduledTask Residue Resolve Rest Resultant ResumePacket Return ReturnExpressionPacket ReturnInputFormPacket ReturnPacket ReturnTextPacket Reverse ReverseBiorthogonalSplineWavelet ReverseElement ReverseEquilibrium ReverseGraph ReverseUpEquilibrium RevolutionAxis RevolutionPlot3D RGBColor RiccatiSolve RiceDistribution RidgeFilter RiemannR RiemannSiegelTheta RiemannSiegelZ Riffle Right RightArrow RightArrowBar RightArrowLeftArrow RightCosetRepresentative RightDownTeeVector RightDownVector RightDownVectorBar RightTee RightTeeArrow RightTeeVector RightTriangle RightTriangleBar RightTriangleEqual RightUpDownVector RightUpTeeVector RightUpVector RightUpVectorBar RightVector RightVectorBar RiskAchievementImportance RiskReductionImportance RogersTanimotoDissimilarity Root RootApproximant RootIntervals RootLocusPlot RootMeanSquare RootOfUnityQ RootReduce Roots RootSum Rotate RotateLabel RotateLeft RotateRight RotationAction RotationBox RotationBoxOptions RotationMatrix RotationTransform Round RoundImplies RoundingRadius Row RowAlignments RowBackgrounds RowBox RowHeights RowLines RowMinHeight RowReduce RowsEqual RowSpacings RSolve RudvalisGroupRu Rule RuleCondition RuleDelayed RuleForm RulerUnits Run RunScheduledTask RunThrough RuntimeAttributes RuntimeOptions RussellRaoDissimilarity ' +
      'SameQ SameTest SampleDepth SampledSoundFunction SampledSoundList SampleRate SamplingPeriod SARIMAProcess SARMAProcess SatisfiabilityCount SatisfiabilityInstances SatisfiableQ Saturday Save Saveable SaveAutoDelete SaveDefinitions SawtoothWave Scale Scaled ScaleDivisions ScaledMousePosition ScaleOrigin ScalePadding ScaleRanges ScaleRangeStyle ScalingFunctions ScalingMatrix ScalingTransform Scan ScheduledTaskActiveQ ScheduledTaskData ScheduledTaskObject ScheduledTasks SchurDecomposition ScientificForm ScreenRectangle ScreenStyleEnvironment ScriptBaselineShifts ScriptLevel ScriptMinSize ScriptRules ScriptSizeMultipliers Scrollbars ScrollingOptions ScrollPosition Sec Sech SechDistribution SectionGrouping SectorChart SectorChart3D SectorOrigin SectorSpacing SeedRandom Select Selectable SelectComponents SelectedCells SelectedNotebook Selection SelectionAnimate SelectionCell SelectionCellCreateCell SelectionCellDefaultStyle SelectionCellParentStyle SelectionCreateCell SelectionDebuggerTag SelectionDuplicateCell SelectionEvaluate SelectionEvaluateCreateCell SelectionMove SelectionPlaceholder SelectionSetStyle SelectWithContents SelfLoops SelfLoopStyle SemialgebraicComponentInstances SendMail Sequence SequenceAlignment SequenceForm SequenceHold SequenceLimit Series SeriesCoefficient SeriesData SessionTime Set SetAccuracy SetAlphaChannel SetAttributes Setbacks SetBoxFormNamesPacket SetDelayed SetDirectory SetEnvironment SetEvaluationNotebook SetFileDate SetFileLoadingContext SetNotebookStatusLine SetOptions SetOptionsPacket SetPrecision SetProperty SetSelectedNotebook SetSharedFunction SetSharedVariable SetSpeechParametersPacket SetStreamPosition SetSystemOptions Setter SetterBar SetterBox SetterBoxOptions Setting SetValue Shading Shallow ShannonWavelet ShapiroWilkTest Share Sharpen ShearingMatrix ShearingTransform ShenCastanMatrix Short ShortDownArrow Shortest ShortestMatch ShortestPathFunction ShortLeftArrow ShortRightArrow ShortUpArrow Show ShowAutoStyles ShowCellBracket ShowCellLabel ShowCellTags ShowClosedCellArea ShowContents ShowControls ShowCursorTracker ShowGroupOpenCloseIcon ShowGroupOpener ShowInvisibleCharacters ShowPageBreaks ShowPredictiveInterface ShowSelection ShowShortBoxForm ShowSpecialCharacters ShowStringCharacters ShowSyntaxStyles ShrinkingDelay ShrinkWrapBoundingBox SiegelTheta SiegelTukeyTest Sign Signature SignedRankTest SignificanceLevel SignPadding SignTest SimilarityRules SimpleGraph SimpleGraphQ Simplify Sin Sinc SinghMaddalaDistribution SingleEvaluation SingleLetterItalics SingleLetterStyle SingularValueDecomposition SingularValueList SingularValuePlot SingularValues Sinh SinhIntegral SinIntegral SixJSymbol Skeleton SkeletonTransform SkellamDistribution Skewness SkewNormalDistribution Skip SliceDistribution Slider Slider2D Slider2DBox Slider2DBoxOptions SliderBox SliderBoxOptions SlideView Slot SlotSequence Small SmallCircle Smaller SmithDelayCompensator SmithWatermanSimilarity ' +
      'SmoothDensityHistogram SmoothHistogram SmoothHistogram3D SmoothKernelDistribution SocialMediaData Socket SokalSneathDissimilarity Solve SolveAlways SolveDelayed Sort SortBy Sound SoundAndGraphics SoundNote SoundVolume Sow Space SpaceForm Spacer Spacings Span SpanAdjustments SpanCharacterRounding SpanFromAbove SpanFromBoth SpanFromLeft SpanLineThickness SpanMaxSize SpanMinSize SpanningCharacters SpanSymmetric SparseArray SpatialGraphDistribution Speak SpeakTextPacket SpearmanRankTest SpearmanRho Spectrogram SpectrogramArray Specularity SpellingCorrection SpellingDictionaries SpellingDictionariesPath SpellingOptions SpellingSuggestionsPacket Sphere SphereBox SphericalBesselJ SphericalBesselY SphericalHankelH1 SphericalHankelH2 SphericalHarmonicY SphericalPlot3D SphericalRegion SpheroidalEigenvalue SpheroidalJoiningFactor SpheroidalPS SpheroidalPSPrime SpheroidalQS SpheroidalQSPrime SpheroidalRadialFactor SpheroidalS1 SpheroidalS1Prime SpheroidalS2 SpheroidalS2Prime Splice SplicedDistribution SplineClosed SplineDegree SplineKnots SplineWeights Split SplitBy SpokenString Sqrt SqrtBox SqrtBoxOptions Square SquaredEuclideanDistance SquareFreeQ SquareIntersection SquaresR SquareSubset SquareSubsetEqual SquareSuperset SquareSupersetEqual SquareUnion SquareWave StabilityMargins StabilityMarginsStyle StableDistribution Stack StackBegin StackComplete StackInhibit StandardDeviation StandardDeviationFilter StandardForm Standardize StandbyDistribution Star StarGraph StartAsynchronousTask StartingStepSize StartOfLine StartOfString StartScheduledTask StartupSound StateDimensions StateFeedbackGains StateOutputEstimator StateResponse StateSpaceModel StateSpaceRealization StateSpaceTransform StationaryDistribution StationaryWaveletPacketTransform StationaryWaveletTransform StatusArea StatusCentrality StepMonitor StieltjesGamma StirlingS1 StirlingS2 StopAsynchronousTask StopScheduledTask StrataVariables StratonovichProcess StreamColorFunction StreamColorFunctionScaling StreamDensityPlot StreamPlot StreamPoints StreamPosition Streams StreamScale StreamStyle String StringBreak StringByteCount StringCases StringCount StringDrop StringExpression StringForm StringFormat StringFreeQ StringInsert StringJoin StringLength StringMatchQ StringPosition StringQ StringReplace StringReplaceList StringReplacePart StringReverse StringRotateLeft StringRotateRight StringSkeleton StringSplit StringTake StringToStream StringTrim StripBoxes StripOnInput StripWrapperBoxes StrokeForm StructuralImportance StructuredArray StructuredSelection StruveH StruveL Stub StudentTDistribution Style StyleBox StyleBoxAutoDelete StyleBoxOptions StyleData StyleDefinitions StyleForm StyleKeyMapping StyleMenuListing StyleNameDialogSettings StyleNames StylePrint StyleSheetPath Subfactorial Subgraph SubMinus SubPlus SubresultantPolynomialRemainders ' +
      'SubresultantPolynomials Subresultants Subscript SubscriptBox SubscriptBoxOptions Subscripted Subset SubsetEqual Subsets SubStar Subsuperscript SubsuperscriptBox SubsuperscriptBoxOptions Subtract SubtractFrom SubValues Succeeds SucceedsEqual SucceedsSlantEqual SucceedsTilde SuchThat Sum SumConvergence Sunday SuperDagger SuperMinus SuperPlus Superscript SuperscriptBox SuperscriptBoxOptions Superset SupersetEqual SuperStar Surd SurdForm SurfaceColor SurfaceGraphics SurvivalDistribution SurvivalFunction SurvivalModel SurvivalModelFit SuspendPacket SuzukiDistribution SuzukiGroupSuz SwatchLegend Switch Symbol SymbolName SymletWavelet Symmetric SymmetricGroup SymmetricMatrixQ SymmetricPolynomial SymmetricReduction Symmetrize SymmetrizedArray SymmetrizedArrayRules SymmetrizedDependentComponents SymmetrizedIndependentComponents SymmetrizedReplacePart SynchronousInitialization SynchronousUpdating Syntax SyntaxForm SyntaxInformation SyntaxLength SyntaxPacket SyntaxQ SystemDialogInput SystemException SystemHelpPath SystemInformation SystemInformationData SystemOpen SystemOptions SystemsModelDelay SystemsModelDelayApproximate SystemsModelDelete SystemsModelDimensions SystemsModelExtract SystemsModelFeedbackConnect SystemsModelLabels SystemsModelOrder SystemsModelParallelConnect SystemsModelSeriesConnect SystemsModelStateFeedbackConnect SystemStub ' +
      'Tab TabFilling Table TableAlignments TableDepth TableDirections TableForm TableHeadings TableSpacing TableView TableViewBox TabSpacings TabView TabViewBox TabViewBoxOptions TagBox TagBoxNote TagBoxOptions TaggingRules TagSet TagSetDelayed TagStyle TagUnset Take TakeWhile Tally Tan Tanh TargetFunctions TargetUnits TautologyQ TelegraphProcess TemplateBox TemplateBoxOptions TemplateSlotSequence TemporalData Temporary TemporaryVariable TensorContract TensorDimensions TensorExpand TensorProduct TensorQ TensorRank TensorReduce TensorSymmetry TensorTranspose TensorWedge Tetrahedron TetrahedronBox TetrahedronBoxOptions TeXForm TeXSave Text Text3DBox Text3DBoxOptions TextAlignment TextBand TextBoundingBox TextBox TextCell TextClipboardType TextData TextForm TextJustification TextLine TextPacket TextParagraph TextRecognize TextRendering TextStyle Texture TextureCoordinateFunction TextureCoordinateScaling Therefore ThermometerGauge Thick Thickness Thin Thinning ThisLink ThompsonGroupTh Thread ThreeJSymbol Threshold Through Throw Thumbnail Thursday Ticks TicksStyle Tilde TildeEqual TildeFullEqual TildeTilde TimeConstrained TimeConstraint Times TimesBy TimeSeriesForecast TimeSeriesInvertibility TimeUsed TimeValue TimeZone Timing Tiny TitleGrouping TitsGroupT ToBoxes ToCharacterCode ToColor ToContinuousTimeModel ToDate ToDiscreteTimeModel ToeplitzMatrix ToExpression ToFileName Together Toggle ToggleFalse Toggler TogglerBar TogglerBox TogglerBoxOptions ToHeldExpression ToInvertibleTimeSeries TokenWords Tolerance ToLowerCase ToNumberField TooBig Tooltip TooltipBox TooltipBoxOptions TooltipDelay TooltipStyle Top TopHatTransform TopologicalSort ToRadicals ToRules ToString Total TotalHeight TotalVariationFilter TotalWidth TouchscreenAutoZoom TouchscreenControlPlacement ToUpperCase Tr Trace TraceAbove TraceAction TraceBackward TraceDepth TraceDialog TraceForward TraceInternal TraceLevel TraceOff TraceOn TraceOriginal TracePrint TraceScan TrackedSymbols TradingChart TraditionalForm TraditionalFunctionNotation TraditionalNotation TraditionalOrder TransferFunctionCancel TransferFunctionExpand TransferFunctionFactor TransferFunctionModel TransferFunctionPoles TransferFunctionTransform TransferFunctionZeros TransformationFunction TransformationFunctions TransformationMatrix TransformedDistribution TransformedField Translate TranslationTransform TransparentColor Transpose TreeForm TreeGraph TreeGraphQ TreePlot TrendStyle TriangleWave TriangularDistribution Trig TrigExpand TrigFactor TrigFactorList Trigger TrigReduce TrigToExp TrimmedMean True TrueQ TruncatedDistribution TsallisQExponentialDistribution TsallisQGaussianDistribution TTest Tube TubeBezierCurveBox TubeBezierCurveBoxOptions TubeBox TubeBSplineCurveBox TubeBSplineCurveBoxOptions Tuesday TukeyLambdaDistribution TukeyWindow Tuples TuranGraph TuringMachine ' +
      'Transparent ' +
      'UnateQ Uncompress Undefined UnderBar Underflow Underlined Underoverscript UnderoverscriptBox UnderoverscriptBoxOptions Underscript UnderscriptBox UnderscriptBoxOptions UndirectedEdge UndirectedGraph UndirectedGraphQ UndocumentedTestFEParserPacket UndocumentedTestGetSelectionPacket Unequal Unevaluated UniformDistribution UniformGraphDistribution UniformSumDistribution Uninstall Union UnionPlus Unique UnitBox UnitConvert UnitDimensions Unitize UnitRootTest UnitSimplify UnitStep UnitTriangle UnitVector Unprotect UnsameQ UnsavedVariables Unset UnsetShared UntrackedVariables Up UpArrow UpArrowBar UpArrowDownArrow Update UpdateDynamicObjects UpdateDynamicObjectsSynchronous UpdateInterval UpDownArrow UpEquilibrium UpperCaseQ UpperLeftArrow UpperRightArrow UpperTriangularize Upsample UpSet UpSetDelayed UpTee UpTeeArrow UpValues URL URLFetch URLFetchAsynchronous URLSave URLSaveAsynchronous UseGraphicsRange Using UsingFrontEnd ' +
      'V2Get ValidationLength Value ValueBox ValueBoxOptions ValueForm ValueQ ValuesData Variables Variance VarianceEquivalenceTest VarianceEstimatorFunction VarianceGammaDistribution VarianceTest VectorAngle VectorColorFunction VectorColorFunctionScaling VectorDensityPlot VectorGlyphData VectorPlot VectorPlot3D VectorPoints VectorQ Vectors VectorScale VectorStyle Vee Verbatim Verbose VerboseConvertToPostScriptPacket VerifyConvergence VerifySolutions VerifyTestAssumptions Version VersionNumber VertexAdd VertexCapacity VertexColors VertexComponent VertexConnectivity VertexCoordinateRules VertexCoordinates VertexCorrelationSimilarity VertexCosineSimilarity VertexCount VertexCoverQ VertexDataCoordinates VertexDegree VertexDelete VertexDiceSimilarity VertexEccentricity VertexInComponent VertexInDegree VertexIndex VertexJaccardSimilarity VertexLabeling VertexLabels VertexLabelStyle VertexList VertexNormals VertexOutComponent VertexOutDegree VertexQ VertexRenderingFunction VertexReplace VertexShape VertexShapeFunction VertexSize VertexStyle VertexTextureCoordinates VertexWeight Vertical VerticalBar VerticalForm VerticalGauge VerticalSeparator VerticalSlider VerticalTilde ViewAngle ViewCenter ViewMatrix ViewPoint ViewPointSelectorSettings ViewPort ViewRange ViewVector ViewVertical VirtualGroupData Visible VisibleCell VoigtDistribution VonMisesDistribution ' +
      'WaitAll WaitAsynchronousTask WaitNext WaitUntil WakebyDistribution WalleniusHypergeometricDistribution WaringYuleDistribution WatershedComponents WatsonUSquareTest WattsStrogatzGraphDistribution WaveletBestBasis WaveletFilterCoefficients WaveletImagePlot WaveletListPlot WaveletMapIndexed WaveletMatrixPlot WaveletPhi WaveletPsi WaveletScale WaveletScalogram WaveletThreshold WeaklyConnectedComponents WeaklyConnectedGraphQ WeakStationarity WeatherData WeberE Wedge Wednesday WeibullDistribution WeierstrassHalfPeriods WeierstrassInvariants WeierstrassP WeierstrassPPrime WeierstrassSigma WeierstrassZeta WeightedAdjacencyGraph WeightedAdjacencyMatrix WeightedData WeightedGraphQ Weights WelchWindow WheelGraph WhenEvent Which While White Whitespace WhitespaceCharacter WhittakerM WhittakerW WienerFilter WienerProcess WignerD WignerSemicircleDistribution WilksW WilksWTest WindowClickSelect WindowElements WindowFloating WindowFrame WindowFrameElements WindowMargins WindowMovable WindowOpacity WindowSelected WindowSize WindowStatusArea WindowTitle WindowToolbars WindowWidth With WolframAlpha WolframAlphaDate WolframAlphaQuantity WolframAlphaResult Word WordBoundary WordCharacter WordData WordSearch WordSeparators WorkingPrecision Write WriteString Wronskian ' +
      'XMLElement XMLObject Xnor Xor ' +
      'Yellow YuleDissimilarity ' +
      'ZernikeR ZeroSymmetric ZeroTest ZeroWidthTimes Zeta ZetaZero ZipfDistribution ZTest ZTransform ' +
      '$Aborted $ActivationGroupID $ActivationKey $ActivationUserRegistered $AddOnsDirectory $AssertFunction $Assumptions $AsynchronousTask $BaseDirectory $BatchInput $BatchOutput $BoxForms $ByteOrdering $Canceled $CharacterEncoding $CharacterEncodings $CommandLine $CompilationTarget $ConditionHold $ConfiguredKernels $Context $ContextPath $ControlActiveSetting $CreationDate $CurrentLink $DateStringFormat $DefaultFont $DefaultFrontEnd $DefaultImagingDevice $DefaultPath $Display $DisplayFunction $DistributedContexts $DynamicEvaluation $Echo $Epilog $ExportFormats $Failed $FinancialDataSource $FormatType $FrontEnd $FrontEndSession $GeoLocation $HistoryLength $HomeDirectory $HTTPCookies $IgnoreEOF $ImagingDevices $ImportFormats $InitialDirectory $Input $InputFileName $InputStreamMethods $Inspector $InstallationDate $InstallationDirectory $InterfaceEnvironment $IterationLimit $KernelCount $KernelID $Language $LaunchDirectory $LibraryPath $LicenseExpirationDate $LicenseID $LicenseProcesses $LicenseServer $LicenseSubprocesses $LicenseType $Line $Linked $LinkSupported $LoadedFiles $MachineAddresses $MachineDomain $MachineDomains $MachineEpsilon $MachineID $MachineName $MachinePrecision $MachineType $MaxExtraPrecision $MaxLicenseProcesses $MaxLicenseSubprocesses $MaxMachineNumber $MaxNumber $MaxPiecewiseCases $MaxPrecision $MaxRootDegree $MessageGroups $MessageList $MessagePrePrint $Messages $MinMachineNumber $MinNumber $MinorReleaseNumber $MinPrecision $ModuleNumber $NetworkLicense $NewMessage $NewSymbol $Notebooks $NumberMarks $Off $OperatingSystem $Output $OutputForms $OutputSizeLimit $OutputStreamMethods $Packages $ParentLink $ParentProcessID $PasswordFile $PatchLevelID $Path $PathnameSeparator $PerformanceGoal $PipeSupported $Post $Pre $PreferencesDirectory $PrePrint $PreRead $PrintForms $PrintLiteral $ProcessID $ProcessorCount $ProcessorType $ProductInformation $ProgramName $RandomState $RecursionLimit $ReleaseNumber $RootDirectory $ScheduledTask $ScriptCommandLine $SessionID $SetParentLink $SharedFunctions $SharedVariables $SoundDisplay $SoundDisplayFunction $SuppressInputFormHeads $SynchronousEvaluation $SyntaxHandler $System $SystemCharacterEncoding $SystemID $SystemWordLength $TemporaryDirectory $TemporaryPrefix $TextStyle $TimedOut $TimeUnit $TimeZone $TopDirectory $TraceOff $TraceOn $TracePattern $TracePostAction $TracePreAction $Urgent $UserAddOnsDirectory $UserBaseDirectory $UserDocumentsDirectory $UserName $Version $VersionNumber',
    contains: [
      {
        className: "comment",
        begin: /\(\*/, end: /\*\)/
      },
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      hljs.C_NUMBER_MODE,
      {
        className: 'list',
        begin: /\{/, end: /\}/,
        illegal: /:/
      }
    ]
  };
});

hljs.registerLanguage('matlab', function(hljs) {
  var COMMON_CONTAINS = [
    hljs.C_NUMBER_MODE,
    {
      className: 'string',
      begin: '\'', end: '\'',
      contains: [hljs.BACKSLASH_ESCAPE, {begin: '\'\''}]
    }
  ];
  var TRANSPOSE = {
    relevance: 0,
    contains: [
      {
        className: 'operator', begin: /'['\.]*/
      }
    ]
  };

  return {
    keywords: {
      keyword:
        'break case catch classdef continue else elseif end enumerated events for function ' +
        'global if methods otherwise parfor persistent properties return spmd switch try while',
      built_in:
        'sin sind sinh asin asind asinh cos cosd cosh acos acosd acosh tan tand tanh atan ' +
        'atand atan2 atanh sec secd sech asec asecd asech csc cscd csch acsc acscd acsch cot ' +
        'cotd coth acot acotd acoth hypot exp expm1 log log1p log10 log2 pow2 realpow reallog ' +
        'realsqrt sqrt nthroot nextpow2 abs angle complex conj imag real unwrap isreal ' +
        'cplxpair fix floor ceil round mod rem sign airy besselj bessely besselh besseli ' +
        'besselk beta betainc betaln ellipj ellipke erf erfc erfcx erfinv expint gamma ' +
        'gammainc gammaln psi legendre cross dot factor isprime primes gcd lcm rat rats perms ' +
        'nchoosek factorial cart2sph cart2pol pol2cart sph2cart hsv2rgb rgb2hsv zeros ones ' +
        'eye repmat rand randn linspace logspace freqspace meshgrid accumarray size length ' +
        'ndims numel disp isempty isequal isequalwithequalnans cat reshape diag blkdiag tril ' +
        'triu fliplr flipud flipdim rot90 find sub2ind ind2sub bsxfun ndgrid permute ipermute ' +
        'shiftdim circshift squeeze isscalar isvector ans eps realmax realmin pi i inf nan ' +
        'isnan isinf isfinite j why compan gallery hadamard hankel hilb invhilb magic pascal ' +
        'rosser toeplitz vander wilkinson'
    },
    illegal: '(//|"|#|/\\*|\\s+/\\w+)',
    contains: [
      {
        className: 'function',
        beginKeywords: 'function', end: '$',
        contains: [
          hljs.UNDERSCORE_TITLE_MODE,
          {
              className: 'params',
              begin: '\\(', end: '\\)'
          },
          {
              className: 'params',
              begin: '\\[', end: '\\]'
          }
        ]
      },
      {
        begin: /[a-zA-Z_][a-zA-Z_0-9]*'['\.]*/,
        returnBegin: true,
        relevance: 0,
        contains: [
          {begin: /[a-zA-Z_][a-zA-Z_0-9]*/, relevance: 0},
          TRANSPOSE.contains[0]
        ]
      },
      {
        className: 'matrix',
        begin: '\\[', end: '\\]',
        contains: COMMON_CONTAINS,
        relevance: 0,
        starts: TRANSPOSE
      },
      {
        className: 'cell',
        begin: '\\{', end: /}/,
        contains: COMMON_CONTAINS,
        relevance: 0,
        starts: TRANSPOSE
      },
      {
        // transpose operators at the end of a function call
        begin: /\)/,
        relevance: 0,
        starts: TRANSPOSE
      },
      hljs.COMMENT('^\\s*\\%\\{\\s*$', '^\\s*\\%\\}\\s*$'),
      hljs.COMMENT('\\%', '$')
    ].concat(COMMON_CONTAINS)
  };
});

hljs.registerLanguage('mel', function(hljs) {
  return {
    keywords:
      'int float string vector matrix if else switch case default while do for in break ' +
      'continue global proc return about abs addAttr addAttributeEditorNodeHelp addDynamic ' +
      'addNewShelfTab addPP addPanelCategory addPrefixToName advanceToNextDrivenKey ' +
      'affectedNet affects aimConstraint air alias aliasAttr align alignCtx alignCurve ' +
      'alignSurface allViewFit ambientLight angle angleBetween animCone animCurveEditor ' +
      'animDisplay animView annotate appendStringArray applicationName applyAttrPreset ' +
      'applyTake arcLenDimContext arcLengthDimension arclen arrayMapper art3dPaintCtx ' +
      'artAttrCtx artAttrPaintVertexCtx artAttrSkinPaintCtx artAttrTool artBuildPaintMenu ' +
      'artFluidAttrCtx artPuttyCtx artSelectCtx artSetPaintCtx artUserPaintCtx assignCommand ' +
      'assignInputDevice assignViewportFactories attachCurve attachDeviceAttr attachSurface ' +
      'attrColorSliderGrp attrCompatibility attrControlGrp attrEnumOptionMenu ' +
      'attrEnumOptionMenuGrp attrFieldGrp attrFieldSliderGrp attrNavigationControlGrp ' +
      'attrPresetEditWin attributeExists attributeInfo attributeMenu attributeQuery ' +
      'autoKeyframe autoPlace bakeClip bakeFluidShading bakePartialHistory bakeResults ' +
      'bakeSimulation basename basenameEx batchRender bessel bevel bevelPlus binMembership ' +
      'bindSkin blend2 blendShape blendShapeEditor blendShapePanel blendTwoAttr blindDataType ' +
      'boneLattice boundary boxDollyCtx boxZoomCtx bufferCurve buildBookmarkMenu ' +
      'buildKeyframeMenu button buttonManip CBG cacheFile cacheFileCombine cacheFileMerge ' +
      'cacheFileTrack camera cameraView canCreateManip canvas capitalizeString catch ' +
      'catchQuiet ceil changeSubdivComponentDisplayLevel changeSubdivRegion channelBox ' +
      'character characterMap characterOutlineEditor characterize chdir checkBox checkBoxGrp ' +
      'checkDefaultRenderGlobals choice circle circularFillet clamp clear clearCache clip ' +
      'clipEditor clipEditorCurrentTimeCtx clipSchedule clipSchedulerOutliner clipTrimBefore ' +
      'closeCurve closeSurface cluster cmdFileOutput cmdScrollFieldExecuter ' +
      'cmdScrollFieldReporter cmdShell coarsenSubdivSelectionList collision color ' +
      'colorAtPoint colorEditor colorIndex colorIndexSliderGrp colorSliderButtonGrp ' +
      'colorSliderGrp columnLayout commandEcho commandLine commandPort compactHairSystem ' +
      'componentEditor compositingInterop computePolysetVolume condition cone confirmDialog ' +
      'connectAttr connectControl connectDynamic connectJoint connectionInfo constrain ' +
      'constrainValue constructionHistory container containsMultibyte contextInfo control ' +
      'convertFromOldLayers convertIffToPsd convertLightmap convertSolidTx convertTessellation ' +
      'convertUnit copyArray copyFlexor copyKey copySkinWeights cos cpButton cpCache ' +
      'cpClothSet cpCollision cpConstraint cpConvClothToMesh cpForces cpGetSolverAttr cpPanel ' +
      'cpProperty cpRigidCollisionFilter cpSeam cpSetEdit cpSetSolverAttr cpSolver ' +
      'cpSolverTypes cpTool cpUpdateClothUVs createDisplayLayer createDrawCtx createEditor ' +
      'createLayeredPsdFile createMotionField createNewShelf createNode createRenderLayer ' +
      'createSubdivRegion cross crossProduct ctxAbort ctxCompletion ctxEditMode ctxTraverse ' +
      'currentCtx currentTime currentTimeCtx currentUnit curve curveAddPtCtx ' +
      'curveCVCtx curveEPCtx curveEditorCtx curveIntersect curveMoveEPCtx curveOnSurface ' +
      'curveSketchCtx cutKey cycleCheck cylinder dagPose date defaultLightListCheckBox ' +
      'defaultNavigation defineDataServer defineVirtualDevice deformer deg_to_rad delete ' +
      'deleteAttr deleteShadingGroupsAndMaterials deleteShelfTab deleteUI deleteUnusedBrushes ' +
      'delrandstr detachCurve detachDeviceAttr detachSurface deviceEditor devicePanel dgInfo ' +
      'dgdirty dgeval dgtimer dimWhen directKeyCtx directionalLight dirmap dirname disable ' +
      'disconnectAttr disconnectJoint diskCache displacementToPoly displayAffected ' +
      'displayColor displayCull displayLevelOfDetail displayPref displayRGBColor ' +
      'displaySmoothness displayStats displayString displaySurface distanceDimContext ' +
      'distanceDimension doBlur dolly dollyCtx dopeSheetEditor dot dotProduct ' +
      'doubleProfileBirailSurface drag dragAttrContext draggerContext dropoffLocator ' +
      'duplicate duplicateCurve duplicateSurface dynCache dynControl dynExport dynExpression ' +
      'dynGlobals dynPaintEditor dynParticleCtx dynPref dynRelEdPanel dynRelEditor ' +
      'dynamicLoad editAttrLimits editDisplayLayerGlobals editDisplayLayerMembers ' +
      'editRenderLayerAdjustment editRenderLayerGlobals editRenderLayerMembers editor ' +
      'editorTemplate effector emit emitter enableDevice encodeString endString endsWith env ' +
      'equivalent equivalentTol erf error eval evalDeferred evalEcho event ' +
      'exactWorldBoundingBox exclusiveLightCheckBox exec executeForEachObject exists exp ' +
      'expression expressionEditorListen extendCurve extendSurface extrude fcheck fclose feof ' +
      'fflush fgetline fgetword file fileBrowserDialog fileDialog fileExtension fileInfo ' +
      'filetest filletCurve filter filterCurve filterExpand filterStudioImport ' +
      'findAllIntersections findAnimCurves findKeyframe findMenuItem findRelatedSkinCluster ' +
      'finder firstParentOf fitBspline flexor floatEq floatField floatFieldGrp floatScrollBar ' +
      'floatSlider floatSlider2 floatSliderButtonGrp floatSliderGrp floor flow fluidCacheInfo ' +
      'fluidEmitter fluidVoxelInfo flushUndo fmod fontDialog fopen formLayout format fprint ' +
      'frameLayout fread freeFormFillet frewind fromNativePath fwrite gamma gauss ' +
      'geometryConstraint getApplicationVersionAsFloat getAttr getClassification ' +
      'getDefaultBrush getFileList getFluidAttr getInputDeviceRange getMayaPanelTypes ' +
      'getModifiers getPanel getParticleAttr getPluginResource getenv getpid glRender ' +
      'glRenderEditor globalStitch gmatch goal gotoBindPose grabColor gradientControl ' +
      'gradientControlNoAttr graphDollyCtx graphSelectContext graphTrackCtx gravity grid ' +
      'gridLayout group groupObjectsByName HfAddAttractorToAS HfAssignAS HfBuildEqualMap ' +
      'HfBuildFurFiles HfBuildFurImages HfCancelAFR HfConnectASToHF HfCreateAttractor ' +
      'HfDeleteAS HfEditAS HfPerformCreateAS HfRemoveAttractorFromAS HfSelectAttached ' +
      'HfSelectAttractors HfUnAssignAS hardenPointCurve hardware hardwareRenderPanel ' +
      'headsUpDisplay headsUpMessage help helpLine hermite hide hilite hitTest hotBox hotkey ' +
      'hotkeyCheck hsv_to_rgb hudButton hudSlider hudSliderButton hwReflectionMap hwRender ' +
      'hwRenderLoad hyperGraph hyperPanel hyperShade hypot iconTextButton iconTextCheckBox ' +
      'iconTextRadioButton iconTextRadioCollection iconTextScrollList iconTextStaticLabel ' +
      'ikHandle ikHandleCtx ikHandleDisplayScale ikSolver ikSplineHandleCtx ikSystem ' +
      'ikSystemInfo ikfkDisplayMethod illustratorCurves image imfPlugins inheritTransform ' +
      'insertJoint insertJointCtx insertKeyCtx insertKnotCurve insertKnotSurface instance ' +
      'instanceable instancer intField intFieldGrp intScrollBar intSlider intSliderGrp ' +
      'interToUI internalVar intersect iprEngine isAnimCurve isConnected isDirty isParentOf ' +
      'isSameObject isTrue isValidObjectName isValidString isValidUiName isolateSelect ' +
      'itemFilter itemFilterAttr itemFilterRender itemFilterType joint jointCluster jointCtx ' +
      'jointDisplayScale jointLattice keyTangent keyframe keyframeOutliner ' +
      'keyframeRegionCurrentTimeCtx keyframeRegionDirectKeyCtx keyframeRegionDollyCtx ' +
      'keyframeRegionInsertKeyCtx keyframeRegionMoveKeyCtx keyframeRegionScaleKeyCtx ' +
      'keyframeRegionSelectKeyCtx keyframeRegionSetKeyCtx keyframeRegionTrackCtx ' +
      'keyframeStats lassoContext lattice latticeDeformKeyCtx launch launchImageEditor ' +
      'layerButton layeredShaderPort layeredTexturePort layout layoutDialog lightList ' +
      'lightListEditor lightListPanel lightlink lineIntersection linearPrecision linstep ' +
      'listAnimatable listAttr listCameras listConnections listDeviceAttachments listHistory ' +
      'listInputDeviceAxes listInputDeviceButtons listInputDevices listMenuAnnotation ' +
      'listNodeTypes listPanelCategories listRelatives listSets listTransforms ' +
      'listUnselected listerEditor loadFluid loadNewShelf loadPlugin ' +
      'loadPluginLanguageResources loadPrefObjects localizedPanelLabel lockNode loft log ' +
      'longNameOf lookThru ls lsThroughFilter lsType lsUI Mayatomr mag makeIdentity makeLive ' +
      'makePaintable makeRoll makeSingleSurface makeTubeOn makebot manipMoveContext ' +
      'manipMoveLimitsCtx manipOptions manipRotateContext manipRotateLimitsCtx ' +
      'manipScaleContext manipScaleLimitsCtx marker match max memory menu menuBarLayout ' +
      'menuEditor menuItem menuItemToShelf menuSet menuSetPref messageLine min minimizeApp ' +
      'mirrorJoint modelCurrentTimeCtx modelEditor modelPanel mouse movIn movOut move ' +
      'moveIKtoFK moveKeyCtx moveVertexAlongDirection multiProfileBirailSurface mute ' +
      'nParticle nameCommand nameField namespace namespaceInfo newPanelItems newton nodeCast ' +
      'nodeIconButton nodeOutliner nodePreset nodeType noise nonLinear normalConstraint ' +
      'normalize nurbsBoolean nurbsCopyUVSet nurbsCube nurbsEditUV nurbsPlane nurbsSelect ' +
      'nurbsSquare nurbsToPoly nurbsToPolygonsPref nurbsToSubdiv nurbsToSubdivPref ' +
      'nurbsUVSet nurbsViewDirectionVector objExists objectCenter objectLayer objectType ' +
      'objectTypeUI obsoleteProc oceanNurbsPreviewPlane offsetCurve offsetCurveOnSurface ' +
      'offsetSurface openGLExtension openMayaPref optionMenu optionMenuGrp optionVar orbit ' +
      'orbitCtx orientConstraint outlinerEditor outlinerPanel overrideModifier ' +
      'paintEffectsDisplay pairBlend palettePort paneLayout panel panelConfiguration ' +
      'panelHistory paramDimContext paramDimension paramLocator parent parentConstraint ' +
      'particle particleExists particleInstancer particleRenderInfo partition pasteKey ' +
      'pathAnimation pause pclose percent performanceOptions pfxstrokes pickWalk picture ' +
      'pixelMove planarSrf plane play playbackOptions playblast plugAttr plugNode pluginInfo ' +
      'pluginResourceUtil pointConstraint pointCurveConstraint pointLight pointMatrixMult ' +
      'pointOnCurve pointOnSurface pointPosition poleVectorConstraint polyAppend ' +
      'polyAppendFacetCtx polyAppendVertex polyAutoProjection polyAverageNormal ' +
      'polyAverageVertex polyBevel polyBlendColor polyBlindData polyBoolOp polyBridgeEdge ' +
      'polyCacheMonitor polyCheck polyChipOff polyClipboard polyCloseBorder polyCollapseEdge ' +
      'polyCollapseFacet polyColorBlindData polyColorDel polyColorPerVertex polyColorSet ' +
      'polyCompare polyCone polyCopyUV polyCrease polyCreaseCtx polyCreateFacet ' +
      'polyCreateFacetCtx polyCube polyCut polyCutCtx polyCylinder polyCylindricalProjection ' +
      'polyDelEdge polyDelFacet polyDelVertex polyDuplicateAndConnect polyDuplicateEdge ' +
      'polyEditUV polyEditUVShell polyEvaluate polyExtrudeEdge polyExtrudeFacet ' +
      'polyExtrudeVertex polyFlipEdge polyFlipUV polyForceUV polyGeoSampler polyHelix ' +
      'polyInfo polyInstallAction polyLayoutUV polyListComponentConversion polyMapCut ' +
      'polyMapDel polyMapSew polyMapSewMove polyMergeEdge polyMergeEdgeCtx polyMergeFacet ' +
      'polyMergeFacetCtx polyMergeUV polyMergeVertex polyMirrorFace polyMoveEdge ' +
      'polyMoveFacet polyMoveFacetUV polyMoveUV polyMoveVertex polyNormal polyNormalPerVertex ' +
      'polyNormalizeUV polyOptUvs polyOptions polyOutput polyPipe polyPlanarProjection ' +
      'polyPlane polyPlatonicSolid polyPoke polyPrimitive polyPrism polyProjection ' +
      'polyPyramid polyQuad polyQueryBlindData polyReduce polySelect polySelectConstraint ' +
      'polySelectConstraintMonitor polySelectCtx polySelectEditCtx polySeparate ' +
      'polySetToFaceNormal polySewEdge polyShortestPathCtx polySmooth polySoftEdge ' +
      'polySphere polySphericalProjection polySplit polySplitCtx polySplitEdge polySplitRing ' +
      'polySplitVertex polyStraightenUVBorder polySubdivideEdge polySubdivideFacet ' +
      'polyToSubdiv polyTorus polyTransfer polyTriangulate polyUVSet polyUnite polyWedgeFace ' +
      'popen popupMenu pose pow preloadRefEd print progressBar progressWindow projFileViewer ' +
      'projectCurve projectTangent projectionContext projectionManip promptDialog propModCtx ' +
      'propMove psdChannelOutliner psdEditTextureFile psdExport psdTextureFile putenv pwd ' +
      'python querySubdiv quit rad_to_deg radial radioButton radioButtonGrp radioCollection ' +
      'radioMenuItemCollection rampColorPort rand randomizeFollicles randstate rangeControl ' +
      'readTake rebuildCurve rebuildSurface recordAttr recordDevice redo reference ' +
      'referenceEdit referenceQuery refineSubdivSelectionList refresh refreshAE ' +
      'registerPluginResource rehash reloadImage removeJoint removeMultiInstance ' +
      'removePanelCategory rename renameAttr renameSelectionList renameUI render ' +
      'renderGlobalsNode renderInfo renderLayerButton renderLayerParent ' +
      'renderLayerPostProcess renderLayerUnparent renderManip renderPartition ' +
      'renderQualityNode renderSettings renderThumbnailUpdate renderWindowEditor ' +
      'renderWindowSelectContext renderer reorder reorderDeformers requires reroot ' +
      'resampleFluid resetAE resetPfxToPolyCamera resetTool resolutionNode retarget ' +
      'reverseCurve reverseSurface revolve rgb_to_hsv rigidBody rigidSolver roll rollCtx ' +
      'rootOf rot rotate rotationInterpolation roundConstantRadius rowColumnLayout rowLayout ' +
      'runTimeCommand runup sampleImage saveAllShelves saveAttrPreset saveFluid saveImage ' +
      'saveInitialState saveMenu savePrefObjects savePrefs saveShelf saveToolSettings scale ' +
      'scaleBrushBrightness scaleComponents scaleConstraint scaleKey scaleKeyCtx sceneEditor ' +
      'sceneUIReplacement scmh scriptCtx scriptEditorInfo scriptJob scriptNode scriptTable ' +
      'scriptToShelf scriptedPanel scriptedPanelType scrollField scrollLayout sculpt ' +
      'searchPathArray seed selLoadSettings select selectContext selectCurveCV selectKey ' +
      'selectKeyCtx selectKeyframeRegionCtx selectMode selectPref selectPriority selectType ' +
      'selectedNodes selectionConnection separator setAttr setAttrEnumResource ' +
      'setAttrMapping setAttrNiceNameResource setConstraintRestPosition ' +
      'setDefaultShadingGroup setDrivenKeyframe setDynamic setEditCtx setEditor setFluidAttr ' +
      'setFocus setInfinity setInputDeviceMapping setKeyCtx setKeyPath setKeyframe ' +
      'setKeyframeBlendshapeTargetWts setMenuMode setNodeNiceNameResource setNodeTypeFlag ' +
      'setParent setParticleAttr setPfxToPolyCamera setPluginResource setProject ' +
      'setStampDensity setStartupMessage setState setToolTo setUITemplate setXformManip sets ' +
      'shadingConnection shadingGeometryRelCtx shadingLightRelCtx shadingNetworkCompare ' +
      'shadingNode shapeCompare shelfButton shelfLayout shelfTabLayout shellField ' +
      'shortNameOf showHelp showHidden showManipCtx showSelectionInTitle ' +
      'showShadingGroupAttrEditor showWindow sign simplify sin singleProfileBirailSurface ' +
      'size sizeBytes skinCluster skinPercent smoothCurve smoothTangentSurface smoothstep ' +
      'snap2to2 snapKey snapMode snapTogetherCtx snapshot soft softMod softModCtx sort sound ' +
      'soundControl source spaceLocator sphere sphrand spotLight spotLightPreviewPort ' +
      'spreadSheetEditor spring sqrt squareSurface srtContext stackTrace startString ' +
      'startsWith stitchAndExplodeShell stitchSurface stitchSurfacePoints strcmp ' +
      'stringArrayCatenate stringArrayContains stringArrayCount stringArrayInsertAtIndex ' +
      'stringArrayIntersector stringArrayRemove stringArrayRemoveAtIndex ' +
      'stringArrayRemoveDuplicates stringArrayRemoveExact stringArrayToString ' +
      'stringToStringArray strip stripPrefixFromName stroke subdAutoProjection ' +
      'subdCleanTopology subdCollapse subdDuplicateAndConnect subdEditUV ' +
      'subdListComponentConversion subdMapCut subdMapSewMove subdMatchTopology subdMirror ' +
      'subdToBlind subdToPoly subdTransferUVsToCache subdiv subdivCrease ' +
      'subdivDisplaySmoothness substitute substituteAllString substituteGeometry substring ' +
      'surface surfaceSampler surfaceShaderList swatchDisplayPort switchTable symbolButton ' +
      'symbolCheckBox sysFile system tabLayout tan tangentConstraint texLatticeDeformContext ' +
      'texManipContext texMoveContext texMoveUVShellContext texRotateContext texScaleContext ' +
      'texSelectContext texSelectShortestPathCtx texSmudgeUVContext texWinToolCtx text ' +
      'textCurves textField textFieldButtonGrp textFieldGrp textManip textScrollList ' +
      'textToShelf textureDisplacePlane textureHairColor texturePlacementContext ' +
      'textureWindow threadCount threePointArcCtx timeControl timePort timerX toNativePath ' +
      'toggle toggleAxis toggleWindowVisibility tokenize tokenizeList tolerance tolower ' +
      'toolButton toolCollection toolDropped toolHasOptions toolPropertyWindow torus toupper ' +
      'trace track trackCtx transferAttributes transformCompare transformLimits translator ' +
      'trim trunc truncateFluidCache truncateHairCache tumble tumbleCtx turbulence ' +
      'twoPointArcCtx uiRes uiTemplate unassignInputDevice undo undoInfo ungroup uniform unit ' +
      'unloadPlugin untangleUV untitledFileName untrim upAxis updateAE userCtx uvLink ' +
      'uvSnapshot validateShelfName vectorize view2dToolCtx viewCamera viewClipPlane ' +
      'viewFit viewHeadOn viewLookAt viewManip viewPlace viewSet visor volumeAxis vortex ' +
      'waitCursor warning webBrowser webBrowserPrefs whatIs window windowPref wire ' +
      'wireContext workspace wrinkle wrinkleContext writeTake xbmLangPathList xform',
    illegal: '</',
    contains: [
      hljs.C_NUMBER_MODE,
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      {
        className: 'string',
        begin: '`', end: '`',
        contains: [hljs.BACKSLASH_ESCAPE]
      },
      {
        className: 'variable',
        variants: [
          {begin: '\\$\\d'},
          {begin: '[\\$\\%\\@](\\^\\w\\b|#\\w+|[^\\s\\w{]|{\\w+}|\\w+)'},
          {begin: '\\*(\\^\\w\\b|#\\w+|[^\\s\\w{]|{\\w+}|\\w+)', relevance: 0}
        ]
      },
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE
    ]
  };
});

hljs.registerLanguage('mercury', function(hljs) {
  var KEYWORDS = {
    keyword:
      'module use_module import_module include_module end_module initialise ' +
      'mutable initialize finalize finalise interface implementation pred ' +
      'mode func type inst solver any_pred any_func is semidet det nondet ' +
      'multi erroneous failure cc_nondet cc_multi typeclass instance where ' +
      'pragma promise external trace atomic or_else require_complete_switch ' +
      'require_det require_semidet require_multi require_nondet ' +
      'require_cc_multi require_cc_nondet require_erroneous require_failure',
    pragma:
      'inline no_inline type_spec source_file fact_table obsolete memo ' +
      'loop_check minimal_model terminates does_not_terminate ' +
      'check_termination promise_equivalent_clauses',
    preprocessor:
      'foreign_proc foreign_decl foreign_code foreign_type ' +
      'foreign_import_module foreign_export_enum foreign_export ' +
      'foreign_enum may_call_mercury will_not_call_mercury thread_safe ' +
      'not_thread_safe maybe_thread_safe promise_pure promise_semipure ' +
      'tabled_for_io local untrailed trailed attach_to_io_state ' +
      'can_pass_as_mercury_type stable will_not_throw_exception ' +
      'may_modify_trail will_not_modify_trail may_duplicate ' +
      'may_not_duplicate affects_liveness does_not_affect_liveness ' +
      'doesnt_affect_liveness no_sharing unknown_sharing sharing',
    built_in:
      'some all not if then else true fail false try catch catch_any ' +
      'semidet_true semidet_false semidet_fail impure_true impure semipure'
  };

  var TODO = {
    className: 'label',
    begin: 'XXX', end: '$', endsWithParent: true,
    relevance: 0
  };
  var COMMENT = hljs.inherit(hljs.C_LINE_COMMENT_MODE, {begin: '%'});
  var CCOMMENT = hljs.inherit(hljs.C_BLOCK_COMMENT_MODE, {relevance: 0});
  COMMENT.contains.push(TODO);
  CCOMMENT.contains.push(TODO);

  var NUMCODE = {
    className: 'number',
    begin: "0'.\\|0[box][0-9a-fA-F]*"
  };

  var ATOM = hljs.inherit(hljs.APOS_STRING_MODE, {relevance: 0});
  var STRING = hljs.inherit(hljs.QUOTE_STRING_MODE, {relevance: 0});
  var STRING_FMT = {
    className: 'constant',
    begin: '\\\\[abfnrtv]\\|\\\\x[0-9a-fA-F]*\\\\\\|%[-+# *.0-9]*[dioxXucsfeEgGp]',
    relevance: 0
  };
  STRING.contains.push(STRING_FMT);

  var IMPLICATION = {
    className: 'built_in',
    variants: [
      {begin: '<=>'},
      {begin: '<=', relevance: 0},
      {begin: '=>', relevance: 0},
      {begin: '/\\\\'},
      {begin: '\\\\/'}
    ]
  };

  var HEAD_BODY_CONJUNCTION = {
    className: 'built_in',
    variants: [
      {begin: ':-\\|-->'},
      {begin: '=', relevance: 0}
    ]
  };

  return {
    aliases: ['m', 'moo'],
    keywords: KEYWORDS,
    contains: [
      IMPLICATION,
      HEAD_BODY_CONJUNCTION,
      COMMENT,
      CCOMMENT,
      NUMCODE,
      hljs.NUMBER_MODE,
      ATOM,
      STRING,
      {begin: /:-/} // relevance booster
    ]
  };
});

hljs.registerLanguage('mizar', function(hljs) {
  return {
    keywords:
      'environ vocabularies notations constructors definitions ' +
      'registrations theorems schemes requirements begin end definition ' +
      'registration cluster existence pred func defpred deffunc theorem ' +
      'proof let take assume then thus hence ex for st holds consider ' +
      'reconsider such that and in provided of as from be being by means ' +
      'equals implies iff redefine define now not or attr is mode ' +
      'suppose per cases set thesis contradiction scheme reserve struct ' +
      'correctness compatibility coherence symmetry assymetry ' +
      'reflexivity irreflexivity connectedness uniqueness commutativity ' +
      'idempotence involutiveness projectivity',
    contains: [
      hljs.COMMENT('::', '$')
    ]
  };
});

hljs.registerLanguage('perl', function(hljs) {
  var PERL_KEYWORDS = 'getpwent getservent quotemeta msgrcv scalar kill dbmclose undef lc ' +
    'ma syswrite tr send umask sysopen shmwrite vec qx utime local oct semctl localtime ' +
    'readpipe do return format read sprintf dbmopen pop getpgrp not getpwnam rewinddir qq' +
    'fileno qw endprotoent wait sethostent bless s|0 opendir continue each sleep endgrent ' +
    'shutdown dump chomp connect getsockname die socketpair close flock exists index shmget' +
    'sub for endpwent redo lstat msgctl setpgrp abs exit select print ref gethostbyaddr ' +
    'unshift fcntl syscall goto getnetbyaddr join gmtime symlink semget splice x|0 ' +
    'getpeername recv log setsockopt cos last reverse gethostbyname getgrnam study formline ' +
    'endhostent times chop length gethostent getnetent pack getprotoent getservbyname rand ' +
    'mkdir pos chmod y|0 substr endnetent printf next open msgsnd readdir use unlink ' +
    'getsockopt getpriority rindex wantarray hex system getservbyport endservent int chr ' +
    'untie rmdir prototype tell listen fork shmread ucfirst setprotoent else sysseek link ' +
    'getgrgid shmctl waitpid unpack getnetbyname reset chdir grep split require caller ' +
    'lcfirst until warn while values shift telldir getpwuid my getprotobynumber delete and ' +
    'sort uc defined srand accept package seekdir getprotobyname semop our rename seek if q|0 ' +
    'chroot sysread setpwent no crypt getc chown sqrt write setnetent setpriority foreach ' +
    'tie sin msgget map stat getlogin unless elsif truncate exec keys glob tied closedir' +
    'ioctl socket readlink eval xor readline binmode setservent eof ord bind alarm pipe ' +
    'atan2 getgrent exp time push setgrent gt lt or ne m|0 break given say state when';
  var SUBST = {
    className: 'subst',
    begin: '[$@]\\{', end: '\\}',
    keywords: PERL_KEYWORDS
  };
  var METHOD = {
    begin: '->{', end: '}'
    // contains defined later
  };
  var VAR = {
    className: 'variable',
    variants: [
      {begin: /\$\d/},
      {begin: /[\$%@](\^\w\b|#\w+(::\w+)*|{\w+}|\w+(::\w*)*)/},
      {begin: /[\$%@][^\s\w{]/, relevance: 0}
    ]
  };
  var STRING_CONTAINS = [hljs.BACKSLASH_ESCAPE, SUBST, VAR];
  var PERL_DEFAULT_CONTAINS = [
    VAR,
    hljs.HASH_COMMENT_MODE,
    hljs.COMMENT(
      '^\\=\\w',
      '\\=cut',
      {
        endsWithParent: true
      }
    ),
    METHOD,
    {
      className: 'string',
      contains: STRING_CONTAINS,
      variants: [
        {
          begin: 'q[qwxr]?\\s*\\(', end: '\\)',
          relevance: 5
        },
        {
          begin: 'q[qwxr]?\\s*\\[', end: '\\]',
          relevance: 5
        },
        {
          begin: 'q[qwxr]?\\s*\\{', end: '\\}',
          relevance: 5
        },
        {
          begin: 'q[qwxr]?\\s*\\|', end: '\\|',
          relevance: 5
        },
        {
          begin: 'q[qwxr]?\\s*\\<', end: '\\>',
          relevance: 5
        },
        {
          begin: 'qw\\s+q', end: 'q',
          relevance: 5
        },
        {
          begin: '\'', end: '\'',
          contains: [hljs.BACKSLASH_ESCAPE]
        },
        {
          begin: '"', end: '"'
        },
        {
          begin: '`', end: '`',
          contains: [hljs.BACKSLASH_ESCAPE]
        },
        {
          begin: '{\\w+}',
          contains: [],
          relevance: 0
        },
        {
          begin: '\-?\\w+\\s*\\=\\>',
          contains: [],
          relevance: 0
        }
      ]
    },
    {
      className: 'number',
      begin: '(\\b0[0-7_]+)|(\\b0x[0-9a-fA-F_]+)|(\\b[1-9][0-9_]*(\\.[0-9_]+)?)|[0_]\\b',
      relevance: 0
    },
    { // regexp container
      begin: '(\\/\\/|' + hljs.RE_STARTERS_RE + '|\\b(split|return|print|reverse|grep)\\b)\\s*',
      keywords: 'split return print reverse grep',
      relevance: 0,
      contains: [
        hljs.HASH_COMMENT_MODE,
        {
          className: 'regexp',
          begin: '(s|tr|y)/(\\\\.|[^/])*/(\\\\.|[^/])*/[a-z]*',
          relevance: 10
        },
        {
          className: 'regexp',
          begin: '(m|qr)?/', end: '/[a-z]*',
          contains: [hljs.BACKSLASH_ESCAPE],
          relevance: 0 // allows empty "//" which is a common comment delimiter in other languages
        }
      ]
    },
    {
      className: 'sub',
      beginKeywords: 'sub', end: '(\\s*\\(.*?\\))?[;{]',
      relevance: 5
    },
    {
      className: 'operator',
      begin: '-\\w\\b',
      relevance: 0
    },
    {
      begin: "^__DATA__$",
      end: "^__END__$",
      subLanguage: 'mojolicious',
      contains: [
        {
            begin: "^@@.*",
            end: "$",
            className: "comment"
        }
      ]
    }
  ];
  SUBST.contains = PERL_DEFAULT_CONTAINS;
  METHOD.contains = PERL_DEFAULT_CONTAINS;

  return {
    aliases: ['pl'],
    keywords: PERL_KEYWORDS,
    contains: PERL_DEFAULT_CONTAINS
  };
});

hljs.registerLanguage('mojolicious', function(hljs) {
  return {
    subLanguage: 'xml',
    contains: [
      {
        className: 'preprocessor',
        begin: '^__(END|DATA)__$'
      },
    // mojolicious line
      {
        begin: "^\\s*%{1,2}={0,2}", end: '$',
        subLanguage: 'perl'
      },
    // mojolicious block
      {
        begin: "<%{1,2}={0,2}",
        end: "={0,1}%>",
        subLanguage: 'perl',
        excludeBegin: true,
        excludeEnd: true
      }
    ]
  };
});

hljs.registerLanguage('monkey', function(hljs) {
  var NUMBER = {
    className: 'number', relevance: 0,
    variants: [
      {
        begin: '[$][a-fA-F0-9]+'
      },
      hljs.NUMBER_MODE
    ]
  };

  return {
    case_insensitive: true,
    keywords: {
      keyword: 'public private property continue exit extern new try catch ' +
        'eachin not abstract final select case default const local global field ' +
        'end if then else elseif endif while wend repeat until forever for to step next return module inline throw',

      built_in: 'DebugLog DebugStop Error Print ACos ACosr ASin ASinr ATan ATan2 ATan2r ATanr Abs Abs Ceil ' +
        'Clamp Clamp Cos Cosr Exp Floor Log Max Max Min Min Pow Sgn Sgn Sin Sinr Sqrt Tan Tanr Seed PI HALFPI TWOPI',

      literal: 'true false null and or shl shr mod'
    },
    illegal: /\/\*/,
    contains: [
      hljs.COMMENT('#rem', '#end'),
      hljs.COMMENT(
        "'",
        '$',
        {
          relevance: 0
        }
      ),
      {
        className: 'function',
        beginKeywords: 'function method', end: '[(=:]|$',
        illegal: /\n/,
        contains: [
          hljs.UNDERSCORE_TITLE_MODE
        ]
      },
      {
        className: 'class',
        beginKeywords: 'class interface', end: '$',
        contains: [
          {
            beginKeywords: 'extends implements'
          },
          hljs.UNDERSCORE_TITLE_MODE
        ]
      },
      {
        className: 'variable',
        begin: '\\b(self|super)\\b'
      },
      {
        className: 'preprocessor',
        beginKeywords: 'import',
        end: '$'
      },
      {
        className: 'preprocessor',
        begin: '\\s*#', end: '$',
        keywords: 'if else elseif endif end then'
      },
      {
        className: 'pi',
        begin: '^\\s*strict\\b'
      },
      {
        beginKeywords: 'alias', end: '=',
        contains: [hljs.UNDERSCORE_TITLE_MODE]
      },
      hljs.QUOTE_STRING_MODE,
      NUMBER
    ]
  }
});

hljs.registerLanguage('nginx', function(hljs) {
  var VAR = {
    className: 'variable',
    variants: [
      {begin: /\$\d+/},
      {begin: /\$\{/, end: /}/},
      {begin: '[\\$\\@]' + hljs.UNDERSCORE_IDENT_RE}
    ]
  };
  var DEFAULT = {
    endsWithParent: true,
    lexemes: '[a-z/_]+',
    keywords: {
      built_in:
        'on off yes no true false none blocked debug info notice warn error crit ' +
        'select break last permanent redirect kqueue rtsig epoll poll /dev/poll'
    },
    relevance: 0,
    illegal: '=>',
    contains: [
      hljs.HASH_COMMENT_MODE,
      {
        className: 'string',
        contains: [hljs.BACKSLASH_ESCAPE, VAR],
        variants: [
          {begin: /"/, end: /"/},
          {begin: /'/, end: /'/}
        ]
      },
      {
        className: 'url',
        begin: '([a-z]+):/', end: '\\s', endsWithParent: true, excludeEnd: true,
        contains: [VAR]
      },
      {
        className: 'regexp',
        contains: [hljs.BACKSLASH_ESCAPE, VAR],
        variants: [
          {begin: "\\s\\^", end: "\\s|{|;", returnEnd: true},
          // regexp locations (~, ~*)
          {begin: "~\\*?\\s+", end: "\\s|{|;", returnEnd: true},
          // *.example.com
          {begin: "\\*(\\.[a-z\\-]+)+"},
          // sub.example.*
          {begin: "([a-z\\-]+\\.)+\\*"}
        ]
      },
      // IP
      {
        className: 'number',
        begin: '\\b\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}(:\\d{1,5})?\\b'
      },
      // units
      {
        className: 'number',
        begin: '\\b\\d+[kKmMgGdshdwy]*\\b',
        relevance: 0
      },
      VAR
    ]
  };

  return {
    aliases: ['nginxconf'],
    contains: [
      hljs.HASH_COMMENT_MODE,
      {
        begin: hljs.UNDERSCORE_IDENT_RE + '\\s', end: ';|{', returnBegin: true,
        contains: [
          {
            className: 'title',
            begin: hljs.UNDERSCORE_IDENT_RE,
            starts: DEFAULT
          }
        ],
        relevance: 0
      }
    ],
    illegal: '[^\\s\\}]'
  };
});

hljs.registerLanguage('nimrod', function(hljs) {
  return {
    aliases: ['nim'],
    keywords: {
      keyword: 'addr and as asm bind block break|0 case|0 cast const|0 continue|0 converter discard distinct|10 div do elif else|0 end|0 enum|0 except export finally for from generic if|0 import|0 in include|0 interface is isnot|10 iterator|10 let|0 macro method|10 mixin mod nil not notin|10 object|0 of or out proc|10 ptr raise ref|10 return shl shr static template try|0 tuple type|0 using|0 var|0 when while|0 with without xor yield',
      literal: 'shared guarded stdin stdout stderr result|10 true false'
    },
    contains: [ {
        className: 'decorator', // Actually pragma
        begin: /{\./,
        end: /\.}/,
        relevance: 10
      }, {
        className: 'string',
        begin: /[a-zA-Z]\w*"/,
        end: /"/,
        contains: [{begin: /""/}]
      }, {
        className: 'string',
        begin: /([a-zA-Z]\w*)?"""/,
        end: /"""/
      },
      hljs.QUOTE_STRING_MODE,
      {
        className: 'type',
        begin: /\b[A-Z]\w+\b/,
        relevance: 0
      }, {
        className: 'type',
        begin: /\b(int|int8|int16|int32|int64|uint|uint8|uint16|uint32|uint64|float|float32|float64|bool|char|string|cstring|pointer|expr|stmt|void|auto|any|range|array|openarray|varargs|seq|set|clong|culong|cchar|cschar|cshort|cint|csize|clonglong|cfloat|cdouble|clongdouble|cuchar|cushort|cuint|culonglong|cstringarray|semistatic)\b/
      }, {
        className: 'number',
        begin: /\b(0[xX][0-9a-fA-F][_0-9a-fA-F]*)('?[iIuU](8|16|32|64))?/,
        relevance: 0
      }, {
        className: 'number',
        begin: /\b(0o[0-7][_0-7]*)('?[iIuUfF](8|16|32|64))?/,
        relevance: 0
      }, {
        className: 'number',
        begin: /\b(0(b|B)[01][_01]*)('?[iIuUfF](8|16|32|64))?/,
        relevance: 0
      }, {
        className: 'number',
        begin: /\b(\d[_\d]*)('?[iIuUfF](8|16|32|64))?/,
        relevance: 0
      },
      hljs.HASH_COMMENT_MODE
    ]
  }
});

hljs.registerLanguage('nix', function(hljs) {
  var NIX_KEYWORDS = {
    keyword: 'rec with let in inherit assert if else then',
    constant: 'true false or and null',
    built_in:
      'import abort baseNameOf dirOf isNull builtins map removeAttrs throw toString derivation'
  };
  var ANTIQUOTE = {
    className: 'subst',
    begin: /\$\{/,
    end: /}/,
    keywords: NIX_KEYWORDS
  };
  var ATTRS = {
    className: 'variable',
    // TODO: we have to figure out a way how to exclude \s*=
    begin: /[a-zA-Z0-9-_]+(\s*=)/,
    relevance: 0
  };
  var SINGLE_QUOTE = {
    className: 'string',
    begin: "''",
    end: "''",
    contains: [
      ANTIQUOTE
    ]
  };
  var DOUBLE_QUOTE = {
    className: 'string',
    begin: '"',
    end: '"',
    contains: [
      ANTIQUOTE
    ]
  };
  var EXPRESSIONS = [
    hljs.NUMBER_MODE,
    hljs.HASH_COMMENT_MODE,
    hljs.C_BLOCK_COMMENT_MODE,
    SINGLE_QUOTE,
    DOUBLE_QUOTE,
    ATTRS
  ];
  ANTIQUOTE.contains = EXPRESSIONS;
  return {
    aliases: ["nixos"],
    keywords: NIX_KEYWORDS,
    contains: EXPRESSIONS
  };
});

hljs.registerLanguage('nsis', function(hljs) {
  var CONSTANTS = {
    className: 'symbol',
    begin: '\\$(ADMINTOOLS|APPDATA|CDBURN_AREA|CMDLINE|COMMONFILES32|COMMONFILES64|COMMONFILES|COOKIES|DESKTOP|DOCUMENTS|EXEDIR|EXEFILE|EXEPATH|FAVORITES|FONTS|HISTORY|HWNDPARENT|INSTDIR|INTERNET_CACHE|LANGUAGE|LOCALAPPDATA|MUSIC|NETHOOD|OUTDIR|PICTURES|PLUGINSDIR|PRINTHOOD|PROFILE|PROGRAMFILES32|PROGRAMFILES64|PROGRAMFILES|QUICKLAUNCH|RECENT|RESOURCES_LOCALIZED|RESOURCES|SENDTO|SMPROGRAMS|SMSTARTUP|STARTMENU|SYSDIR|TEMP|TEMPLATES|VIDEOS|WINDIR)'
  };

  var DEFINES = {
    // ${defines}
    className: 'constant',
    begin: '\\$+{[a-zA-Z0-9_]+}'
  };

  var VARIABLES = {
    // $variables
    className: 'variable',
    begin: '\\$+[a-zA-Z0-9_]+',
    illegal: '\\(\\){}'
  };

  var LANGUAGES = {
    // $(language_strings)
    className: 'constant',
    begin: '\\$+\\([a-zA-Z0-9_]+\\)'
  };

  var PARAMETERS = {
    // command parameters
    className: 'params',
    begin: '(ARCHIVE|FILE_ATTRIBUTE_ARCHIVE|FILE_ATTRIBUTE_NORMAL|FILE_ATTRIBUTE_OFFLINE|FILE_ATTRIBUTE_READONLY|FILE_ATTRIBUTE_SYSTEM|FILE_ATTRIBUTE_TEMPORARY|HKCR|HKCU|HKDD|HKEY_CLASSES_ROOT|HKEY_CURRENT_CONFIG|HKEY_CURRENT_USER|HKEY_DYN_DATA|HKEY_LOCAL_MACHINE|HKEY_PERFORMANCE_DATA|HKEY_USERS|HKLM|HKPD|HKU|IDABORT|IDCANCEL|IDIGNORE|IDNO|IDOK|IDRETRY|IDYES|MB_ABORTRETRYIGNORE|MB_DEFBUTTON1|MB_DEFBUTTON2|MB_DEFBUTTON3|MB_DEFBUTTON4|MB_ICONEXCLAMATION|MB_ICONINFORMATION|MB_ICONQUESTION|MB_ICONSTOP|MB_OK|MB_OKCANCEL|MB_RETRYCANCEL|MB_RIGHT|MB_RTLREADING|MB_SETFOREGROUND|MB_TOPMOST|MB_USERICON|MB_YESNO|NORMAL|OFFLINE|READONLY|SHCTX|SHELL_CONTEXT|SYSTEM|TEMPORARY)'
  };

  var COMPILER ={
    // !compiler_flags
    className: 'constant',
    begin: '\\!(addincludedir|addplugindir|appendfile|cd|define|delfile|echo|else|endif|error|execute|finalize|getdllversionsystem|ifdef|ifmacrodef|ifmacrondef|ifndef|if|include|insertmacro|macroend|macro|makensis|packhdr|searchparse|searchreplace|tempfile|undef|verbose|warning)'
  };

  return {
    case_insensitive: false,
    keywords: {
      keyword:
      'Abort AddBrandingImage AddSize AllowRootDirInstall AllowSkipFiles AutoCloseWindow BGFont BGGradient BrandingText BringToFront Call CallInstDLL Caption ChangeUI CheckBitmap ClearErrors CompletedText ComponentText CopyFiles CRCCheck CreateDirectory CreateFont CreateShortCut Delete DeleteINISec DeleteINIStr DeleteRegKey DeleteRegValue DetailPrint DetailsButtonText DirText DirVar DirVerify EnableWindow EnumRegKey EnumRegValue Exch Exec ExecShell ExecWait ExpandEnvStrings File FileBufSize FileClose FileErrorText FileOpen FileRead FileReadByte FileReadUTF16LE FileReadWord FileSeek FileWrite FileWriteByte FileWriteUTF16LE FileWriteWord FindClose FindFirst FindNext FindWindow FlushINI FunctionEnd GetCurInstType GetCurrentAddress GetDlgItem GetDLLVersion GetDLLVersionLocal GetErrorLevel GetFileTime GetFileTimeLocal GetFullPathName GetFunctionAddress GetInstDirError GetLabelAddress GetTempFileName Goto HideWindow Icon IfAbort IfErrors IfFileExists IfRebootFlag IfSilent InitPluginsDir InstallButtonText InstallColors InstallDir InstallDirRegKey InstProgressFlags InstType InstTypeGetText InstTypeSetText IntCmp IntCmpU IntFmt IntOp IsWindow LangString LicenseBkColor LicenseData LicenseForceSelection LicenseLangString LicenseText LoadLanguageFile LockWindow LogSet LogText ManifestDPIAware ManifestSupportedOS MessageBox MiscButtonText Name Nop OutFile Page PageCallbacks PageExEnd Pop Push Quit ReadEnvStr ReadINIStr ReadRegDWORD ReadRegStr Reboot RegDLL Rename RequestExecutionLevel ReserveFile Return RMDir SearchPath SectionEnd SectionGetFlags SectionGetInstTypes SectionGetSize SectionGetText SectionGroupEnd SectionIn SectionSetFlags SectionSetInstTypes SectionSetSize SectionSetText SendMessage SetAutoClose SetBrandingImage SetCompress SetCompressor SetCompressorDictSize SetCtlColors SetCurInstType SetDatablockOptimize SetDateSave SetDetailsPrint SetDetailsView SetErrorLevel SetErrors SetFileAttributes SetFont SetOutPath SetOverwrite SetPluginUnload SetRebootFlag SetRegView SetShellVarContext SetSilent ShowInstDetails ShowUninstDetails ShowWindow SilentInstall SilentUnInstall Sleep SpaceTexts StrCmp StrCmpS StrCpy StrLen SubCaption SubSectionEnd Unicode UninstallButtonText UninstallCaption UninstallIcon UninstallSubCaption UninstallText UninstPage UnRegDLL Var VIAddVersionKey VIFileVersion VIProductVersion WindowIcon WriteINIStr WriteRegBin WriteRegDWORD WriteRegExpandStr WriteRegStr WriteUninstaller XPStyle',
      literal:
      'admin all auto both colored current false force hide highest lastused leave listonly none normal notset off on open print show silent silentlog smooth textonly true user '
    },
    contains: [
      hljs.HASH_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      {
        className: 'string',
        begin: '"', end: '"',
        illegal: '\\n',
        contains: [
          { // $\n, $\r, $\t, $$
            className: 'symbol',
            begin: '\\$(\\\\(n|r|t)|\\$)'
          },
          CONSTANTS,
          DEFINES,
          VARIABLES,
          LANGUAGES
        ]
      },
      hljs.COMMENT(
        ';',
        '$',
        {
          relevance: 0
        }
      ),
      {
        className: 'function',
        beginKeywords: 'Function PageEx Section SectionGroup SubSection', end: '$'
      },
      COMPILER,
      DEFINES,
      VARIABLES,
      LANGUAGES,
      PARAMETERS,
      hljs.NUMBER_MODE,
      { // plug::ins
        className: 'literal',
        begin: hljs.IDENT_RE + '::' + hljs.IDENT_RE
      }
    ]
  };
});

hljs.registerLanguage('objectivec', function(hljs) {
  var API_CLASS = {
    className: 'built_in',
    begin: '(AV|CA|CF|CG|CI|MK|MP|NS|UI)\\w+',
  };
  var OBJC_KEYWORDS = {
    keyword:
      'int float while char export sizeof typedef const struct for union ' +
      'unsigned long volatile static bool mutable if do return goto void ' +
      'enum else break extern asm case short default double register explicit ' +
      'signed typename this switch continue wchar_t inline readonly assign ' +
      'readwrite self @synchronized id typeof ' +
      'nonatomic super unichar IBOutlet IBAction strong weak copy ' +
      'in out inout bycopy byref oneway __strong __weak __block __autoreleasing ' +
      '@private @protected @public @try @property @end @throw @catch @finally ' +
      '@autoreleasepool @synthesize @dynamic @selector @optional @required',
    literal:
      'false true FALSE TRUE nil YES NO NULL',
    built_in:
      'BOOL dispatch_once_t dispatch_queue_t dispatch_sync dispatch_async dispatch_once'
  };
  var LEXEMES = /[a-zA-Z@][a-zA-Z0-9_]*/;
  var CLASS_KEYWORDS = '@interface @class @protocol @implementation';
  return {
    aliases: ['mm', 'objc', 'obj-c'],
    keywords: OBJC_KEYWORDS,
    lexemes: LEXEMES,
    illegal: '</',
    contains: [
      API_CLASS,
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.C_NUMBER_MODE,
      hljs.QUOTE_STRING_MODE,
      {
        className: 'string',
        variants: [
          {
            begin: '@"', end: '"',
            illegal: '\\n',
            contains: [hljs.BACKSLASH_ESCAPE]
          },
          {
            begin: '\'', end: '[^\\\\]\'',
            illegal: '[^\\\\][^\']'
          }
        ]
      },
      {
        className: 'preprocessor',
        begin: '#',
        end: '$',
        contains: [
          {
            className: 'title',
            variants: [
              { begin: '\"', end: '\"' },
              { begin: '<', end: '>' }
            ]
          }
        ]
      },
      {
        className: 'class',
        begin: '(' + CLASS_KEYWORDS.split(' ').join('|') + ')\\b', end: '({|$)', excludeEnd: true,
        keywords: CLASS_KEYWORDS, lexemes: LEXEMES,
        contains: [
          hljs.UNDERSCORE_TITLE_MODE
        ]
      },
      {
        className: 'variable',
        begin: '\\.'+hljs.UNDERSCORE_IDENT_RE,
        relevance: 0
      }
    ]
  };
});

hljs.registerLanguage('ocaml', function(hljs) {
  /* missing support for heredoc-like string (OCaml 4.0.2+) */
  return {
    aliases: ['ml'],
    keywords: {
      keyword:
        'and as assert asr begin class constraint do done downto else end ' +
        'exception external for fun function functor if in include ' +
        'inherit! inherit initializer land lazy let lor lsl lsr lxor match method!|10 method ' +
        'mod module mutable new object of open! open or private rec sig struct ' +
        'then to try type val! val virtual when while with ' +
        /* camlp4 */
        'parser value',
      built_in:
        /* built-in types */
        'array bool bytes char exn|5 float int int32 int64 list lazy_t|5 nativeint|5 string unit ' +
        /* (some) types in Pervasives */
        'in_channel out_channel ref',
      literal:
        'true false'
    },
    illegal: /\/\/|>>/,
    lexemes: '[a-z_]\\w*!?',
    contains: [
      {
        className: 'literal',
        begin: '\\[(\\|\\|)?\\]|\\(\\)',
        relevance: 0
      },
      hljs.COMMENT(
        '\\(\\*',
        '\\*\\)',
        {
          contains: ['self']
        }
      ),
      { /* type variable */
        className: 'symbol',
        begin: '\'[A-Za-z_](?!\')[\\w\']*'
        /* the grammar is ambiguous on how 'a'b should be interpreted but not the compiler */
      },
      { /* polymorphic variant */
        className: 'tag',
        begin: '`[A-Z][\\w\']*'
      },
      { /* module or constructor */
        className: 'type',
        begin: '\\b[A-Z][\\w\']*',
        relevance: 0
      },
      { /* don't color identifiers, but safely catch all identifiers with '*/
        begin: '[a-z_]\\w*\'[\\w\']*'
      },
      hljs.inherit(hljs.APOS_STRING_MODE, {className: 'char', relevance: 0}),
      hljs.inherit(hljs.QUOTE_STRING_MODE, {illegal: null}),
      {
        className: 'number',
        begin:
          '\\b(0[xX][a-fA-F0-9_]+[Lln]?|' +
          '0[oO][0-7_]+[Lln]?|' +
          '0[bB][01_]+[Lln]?|' +
          '[0-9][0-9_]*([Lln]|(\\.[0-9_]*)?([eE][-+]?[0-9_]+)?)?)',
        relevance: 0
      },
      {
        begin: /[-=]>/ // relevance booster
      }
    ]
  }
});

hljs.registerLanguage('openscad', function(hljs) {
	var SPECIAL_VARS = {
		className: 'keyword',
		begin: '\\$(f[asn]|t|vp[rtd]|children)'
	},
	LITERALS = {
		className: 'literal',
		begin: 'false|true|PI|undef'
	},
	NUMBERS = {
		className: 'number',
		begin: '\\b\\d+(\\.\\d+)?(e-?\\d+)?', //adds 1e5, 1e-10
		relevance: 0
	},
	STRING = hljs.inherit(hljs.QUOTE_STRING_MODE,{illegal: null}),
	PREPRO = {
		className: 'preprocessor',
		keywords: 'include use',
		begin: 'include|use <',
		end: '>'
	},
	PARAMS = {
		className: 'params',
		begin: '\\(', end: '\\)',
		contains: ['self', NUMBERS, STRING, SPECIAL_VARS, LITERALS]
	},
	MODIFIERS = {
		className: 'built_in',
		begin: '[*!#%]',
		relevance: 0
	},
	FUNCTIONS = {
		className: 'function',
		beginKeywords: 'module function',
		end: '\\=|\\{',
		contains: [PARAMS, hljs.UNDERSCORE_TITLE_MODE]
	};

	return {
		aliases: ['scad'],
		keywords: {
			keyword: 'function module include use for intersection_for if else \\%',
			literal: 'false true PI undef',
			built_in: 'circle square polygon text sphere cube cylinder polyhedron translate rotate scale resize mirror multmatrix color offset hull minkowski union difference intersection abs sign sin cos tan acos asin atan atan2 floor round ceil ln log pow sqrt exp rands min max concat lookup str chr search version version_num norm cross parent_module echo import import_dxf dxf_linear_extrude linear_extrude rotate_extrude surface projection render children dxf_cross dxf_dim let assign'
		},
		contains: [
			hljs.C_LINE_COMMENT_MODE,
			hljs.C_BLOCK_COMMENT_MODE,
			NUMBERS,
			PREPRO,
			STRING,
			SPECIAL_VARS,
			MODIFIERS,
			FUNCTIONS
		]
	}
});

hljs.registerLanguage('oxygene', function(hljs) {
  var OXYGENE_KEYWORDS = 'abstract add and array as asc aspect assembly async begin break block by case class concat const copy constructor continue '+
    'create default delegate desc distinct div do downto dynamic each else empty end ensure enum equals event except exit extension external false '+
    'final finalize finalizer finally flags for forward from function future global group has if implementation implements implies in index inherited '+
    'inline interface into invariants is iterator join locked locking loop matching method mod module namespace nested new nil not notify nullable of '+
    'old on operator or order out override parallel params partial pinned private procedure property protected public queryable raise read readonly '+
    'record reintroduce remove repeat require result reverse sealed select self sequence set shl shr skip static step soft take then to true try tuple '+
    'type union unit unsafe until uses using var virtual raises volatile where while with write xor yield await mapped deprecated stdcall cdecl pascal '+
    'register safecall overload library platform reference packed strict published autoreleasepool selector strong weak unretained';
  var CURLY_COMMENT =  hljs.COMMENT(
    '{',
    '}',
    {
      relevance: 0
    }
  );
  var PAREN_COMMENT = hljs.COMMENT(
    '\\(\\*',
    '\\*\\)',
    {
      relevance: 10
    }
  );
  var STRING = {
    className: 'string',
    begin: '\'', end: '\'',
    contains: [{begin: '\'\''}]
  };
  var CHAR_STRING = {
    className: 'string', begin: '(#\\d+)+'
  };
  var FUNCTION = {
    className: 'function',
    beginKeywords: 'function constructor destructor procedure method', end: '[:;]',
    keywords: 'function constructor|10 destructor|10 procedure|10 method|10',
    contains: [
      hljs.TITLE_MODE,
      {
        className: 'params',
        begin: '\\(', end: '\\)',
        keywords: OXYGENE_KEYWORDS,
        contains: [STRING, CHAR_STRING]
      },
      CURLY_COMMENT, PAREN_COMMENT
    ]
  };
  return {
    case_insensitive: true,
    keywords: OXYGENE_KEYWORDS,
    illegal: '("|\\$[G-Zg-z]|\\/\\*|</|=>|->)',
    contains: [
      CURLY_COMMENT, PAREN_COMMENT, hljs.C_LINE_COMMENT_MODE,
      STRING, CHAR_STRING,
      hljs.NUMBER_MODE,
      FUNCTION,
      {
        className: 'class',
        begin: '=\\bclass\\b', end: 'end;',
        keywords: OXYGENE_KEYWORDS,
        contains: [
          STRING, CHAR_STRING,
          CURLY_COMMENT, PAREN_COMMENT, hljs.C_LINE_COMMENT_MODE,
          FUNCTION
        ]
      }
    ]
  };
});

hljs.registerLanguage('parser3', function(hljs) {
  var CURLY_SUBCOMMENT = hljs.COMMENT(
    '{',
    '}',
    {
      contains: ['self']
    }
  );
  return {
    subLanguage: 'xml', relevance: 0,
    contains: [
      hljs.COMMENT('^#', '$'),
      hljs.COMMENT(
        '\\^rem{',
        '}',
        {
          relevance: 10,
          contains: [
            CURLY_SUBCOMMENT
          ]
        }
      ),
      {
        className: 'preprocessor',
        begin: '^@(?:BASE|USE|CLASS|OPTIONS)$',
        relevance: 10
      },
      {
        className: 'title',
        begin: '@[\\w\\-]+\\[[\\w^;\\-]*\\](?:\\[[\\w^;\\-]*\\])?(?:.*)$'
      },
      {
        className: 'variable',
        begin: '\\$\\{?[\\w\\-\\.\\:]+\\}?'
      },
      {
        className: 'keyword',
        begin: '\\^[\\w\\-\\.\\:]+'
      },
      {
        className: 'number',
        begin: '\\^#[0-9a-fA-F]+'
      },
      hljs.C_NUMBER_MODE
    ]
  };
});

hljs.registerLanguage('pf', function(hljs) {
  var MACRO = {
    className: 'variable',
    begin: /\$[\w\d#@][\w\d_]*/
  };
  var TABLE = {
    className: 'variable',
    begin: /</, end: />/
  };
  var QUOTE_STRING = {
    className: 'string',
    begin: /"/, end: /"/
  };

  return {
    aliases: ['pf.conf'],
    lexemes: /[a-z0-9_<>-]+/,
    keywords: {
      built_in: /* block match pass are "actions" in pf.conf(5), the rest are
                 * lexically similar top-level commands.
                 */
        'block match pass load anchor|5 antispoof|10 set table',
      keyword:
        'in out log quick on rdomain inet inet6 proto from port os to route' +
        'allow-opts divert-packet divert-reply divert-to flags group icmp-type' +
        'icmp6-type label once probability recieved-on rtable prio queue' +
        'tos tag tagged user keep fragment for os drop' +
        'af-to|10 binat-to|10 nat-to|10 rdr-to|10 bitmask least-stats random round-robin' +
        'source-hash static-port' +
        'dup-to reply-to route-to' +
        'parent bandwidth default min max qlimit' +
        'block-policy debug fingerprints hostid limit loginterface optimization' +
        'reassemble ruleset-optimization basic none profile skip state-defaults' +
        'state-policy timeout' +
        'const counters persist' +
        'no modulate synproxy state|5 floating if-bound no-sync pflow|10 sloppy' +
        'source-track global rule max-src-nodes max-src-states max-src-conn' +
        'max-src-conn-rate overload flush' +
        'scrub|5 max-mss min-ttl no-df|10 random-id',
      literal:
        'all any no-route self urpf-failed egress|5 unknown'
    },
    contains: [
      hljs.HASH_COMMENT_MODE,
      hljs.NUMBER_MODE,
      hljs.QUOTE_STRING_MODE,
      MACRO,
      TABLE
    ]
  };
});

hljs.registerLanguage('php', function(hljs) {
  var VARIABLE = {
    className: 'variable', begin: '\\$+[a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*'
  };
  var PREPROCESSOR = {
    className: 'preprocessor', begin: /<\?(php)?|\?>/
  };
  var STRING = {
    className: 'string',
    contains: [hljs.BACKSLASH_ESCAPE, PREPROCESSOR],
    variants: [
      {
        begin: 'b"', end: '"'
      },
      {
        begin: 'b\'', end: '\''
      },
      hljs.inherit(hljs.APOS_STRING_MODE, {illegal: null}),
      hljs.inherit(hljs.QUOTE_STRING_MODE, {illegal: null})
    ]
  };
  var NUMBER = {variants: [hljs.BINARY_NUMBER_MODE, hljs.C_NUMBER_MODE]};
  return {
    aliases: ['php3', 'php4', 'php5', 'php6'],
    case_insensitive: true,
    keywords:
      'and include_once list abstract global private echo interface as static endswitch ' +
      'array null if endwhile or const for endforeach self var while isset public ' +
      'protected exit foreach throw elseif include __FILE__ empty require_once do xor ' +
      'return parent clone use __CLASS__ __LINE__ else break print eval new ' +
      'catch __METHOD__ case exception default die require __FUNCTION__ ' +
      'enddeclare final try switch continue endfor endif declare unset true false ' +
      'trait goto instanceof insteadof __DIR__ __NAMESPACE__ ' +
      'yield finally',
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.HASH_COMMENT_MODE,
      hljs.COMMENT(
        '/\\*',
        '\\*/',
        {
          contains: [
            {
              className: 'doctag',
              begin: '@[A-Za-z]+'
            },
            PREPROCESSOR
          ]
        }
      ),
      hljs.COMMENT(
        '__halt_compiler.+?;',
        false,
        {
          endsWithParent: true,
          keywords: '__halt_compiler',
          lexemes: hljs.UNDERSCORE_IDENT_RE
        }
      ),
      {
        className: 'string',
        begin: /<<<['"]?\w+['"]?$/, end: /^\w+;?$/,
        contains: [
          hljs.BACKSLASH_ESCAPE,
          {
            className: 'subst',
            variants: [
              {begin: /\$\w+/},
              {begin: /\{\$/, end: /\}/}
            ]
          }
        ]
      },
      PREPROCESSOR,
      VARIABLE,
      {
        // swallow composed identifiers to avoid parsing them as keywords
        begin: /(::|->)+[a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*/
      },
      {
        className: 'function',
        beginKeywords: 'function', end: /[;{]/, excludeEnd: true,
        illegal: '\\$|\\[|%',
        contains: [
          hljs.UNDERSCORE_TITLE_MODE,
          {
            className: 'params',
            begin: '\\(', end: '\\)',
            contains: [
              'self',
              VARIABLE,
              hljs.C_BLOCK_COMMENT_MODE,
              STRING,
              NUMBER
            ]
          }
        ]
      },
      {
        className: 'class',
        beginKeywords: 'class interface', end: '{', excludeEnd: true,
        illegal: /[:\(\$"]/,
        contains: [
          {beginKeywords: 'extends implements'},
          hljs.UNDERSCORE_TITLE_MODE
        ]
      },
      {
        beginKeywords: 'namespace', end: ';',
        illegal: /[\.']/,
        contains: [hljs.UNDERSCORE_TITLE_MODE]
      },
      {
        beginKeywords: 'use', end: ';',
        contains: [hljs.UNDERSCORE_TITLE_MODE]
      },
      {
        begin: '=>' // No markup, just a relevance booster
      },
      STRING,
      NUMBER
    ]
  };
});

hljs.registerLanguage('powershell', function(hljs) {
  var backtickEscape = {
    begin: '`[\\s\\S]',
    relevance: 0
  };
  var VAR = {
    className: 'variable',
    variants: [
      {begin: /\$[\w\d][\w\d_:]*/}
    ]
  };
  var QUOTE_STRING = {
    className: 'string',
    begin: /"/, end: /"/,
    contains: [
      backtickEscape,
      VAR,
      {
        className: 'variable',
        begin: /\$[A-z]/, end: /[^A-z]/
      }
    ]
  };
  var APOS_STRING = {
    className: 'string',
    begin: /'/, end: /'/
  };

  return {
    aliases: ['ps'],
    lexemes: /-?[A-z\.\-]+/,
    case_insensitive: true,
    keywords: {
      keyword: 'if else foreach return function do while until elseif begin for trap data dynamicparam end break throw param continue finally in switch exit filter try process catch',
      literal: '$null $true $false',
      built_in: 'Add-Content Add-History Add-Member Add-PSSnapin Clear-Content Clear-Item Clear-Item Property Clear-Variable Compare-Object ConvertFrom-SecureString Convert-Path ConvertTo-Html ConvertTo-SecureString Copy-Item Copy-ItemProperty Export-Alias Export-Clixml Export-Console Export-Csv ForEach-Object Format-Custom Format-List Format-Table Format-Wide Get-Acl Get-Alias Get-AuthenticodeSignature Get-ChildItem Get-Command Get-Content Get-Credential Get-Culture Get-Date Get-EventLog Get-ExecutionPolicy Get-Help Get-History Get-Host Get-Item Get-ItemProperty Get-Location Get-Member Get-PfxCertificate Get-Process Get-PSDrive Get-PSProvider Get-PSSnapin Get-Service Get-TraceSource Get-UICulture Get-Unique Get-Variable Get-WmiObject Group-Object Import-Alias Import-Clixml Import-Csv Invoke-Expression Invoke-History Invoke-Item Join-Path Measure-Command Measure-Object Move-Item Move-ItemProperty New-Alias New-Item New-ItemProperty New-Object New-PSDrive New-Service New-TimeSpan New-Variable Out-Default Out-File Out-Host Out-Null Out-Printer Out-String Pop-Location Push-Location Read-Host Remove-Item Remove-ItemProperty Remove-PSDrive Remove-PSSnapin Remove-Variable Rename-Item Rename-ItemProperty Resolve-Path Restart-Service Resume-Service Select-Object Select-String Set-Acl Set-Alias Set-AuthenticodeSignature Set-Content Set-Date Set-ExecutionPolicy Set-Item Set-ItemProperty Set-Location Set-PSDebug Set-Service Set-TraceSource Set-Variable Sort-Object Split-Path Start-Service Start-Sleep Start-Transcript Stop-Process Stop-Service Stop-Transcript Suspend-Service Tee-Object Test-Path Trace-Command Update-FormatData Update-TypeData Where-Object Write-Debug Write-Error Write-Host Write-Output Write-Progress Write-Verbose Write-Warning',
      operator: '-ne -eq -lt -gt -ge -le -not -like -notlike -match -notmatch -contains -notcontains -in -notin -replace'
    },
    contains: [
      hljs.HASH_COMMENT_MODE,
      hljs.NUMBER_MODE,
      QUOTE_STRING,
      APOS_STRING,
      VAR
    ]
  };
});

hljs.registerLanguage('processing', function(hljs) {
  return {
    keywords: {
      keyword: 'BufferedReader PVector PFont PImage PGraphics HashMap boolean byte char color ' +
        'double float int long String Array FloatDict FloatList IntDict IntList JSONArray JSONObject ' +
        'Object StringDict StringList Table TableRow XML ' +
        // Java keywords
        'false synchronized int abstract float private char boolean static null if const ' +
        'for true while long throw strictfp finally protected import native final return void ' +
        'enum else break transient new catch instanceof byte super volatile case assert short ' +
        'package default double public try this switch continue throws protected public private',
      constant: 'P2D P3D HALF_PI PI QUARTER_PI TAU TWO_PI',
      variable: 'displayHeight displayWidth mouseY mouseX mousePressed pmouseX pmouseY key ' +
        'keyCode pixels focused frameCount frameRate height width',
      title: 'setup draw',
      built_in: 'size createGraphics beginDraw createShape loadShape PShape arc ellipse line point ' +
        'quad rect triangle bezier bezierDetail bezierPoint bezierTangent curve curveDetail curvePoint ' +
        'curveTangent curveTightness shape shapeMode beginContour beginShape bezierVertex curveVertex ' +
        'endContour endShape quadraticVertex vertex ellipseMode noSmooth rectMode smooth strokeCap ' +
        'strokeJoin strokeWeight mouseClicked mouseDragged mouseMoved mousePressed mouseReleased ' +
        'mouseWheel keyPressed keyPressedkeyReleased keyTyped print println save saveFrame day hour ' +
        'millis minute month second year background clear colorMode fill noFill noStroke stroke alpha ' +
        'blue brightness color green hue lerpColor red saturation modelX modelY modelZ screenX screenY ' +
        'screenZ ambient emissive shininess specular add createImage beginCamera camera endCamera frustum ' +
        'ortho perspective printCamera printProjection cursor frameRate noCursor exit loop noLoop popStyle ' +
        'pushStyle redraw binary boolean byte char float hex int str unbinary unhex join match matchAll nf ' +
        'nfc nfp nfs split splitTokens trim append arrayCopy concat expand reverse shorten sort splice subset ' +
        'box sphere sphereDetail createInput createReader loadBytes loadJSONArray loadJSONObject loadStrings ' +
        'loadTable loadXML open parseXML saveTable selectFolder selectInput beginRaw beginRecord createOutput ' +
        'createWriter endRaw endRecord PrintWritersaveBytes saveJSONArray saveJSONObject saveStream saveStrings ' +
        'saveXML selectOutput popMatrix printMatrix pushMatrix resetMatrix rotate rotateX rotateY rotateZ scale ' +
        'shearX shearY translate ambientLight directionalLight lightFalloff lights lightSpecular noLights normal ' +
        'pointLight spotLight image imageMode loadImage noTint requestImage tint texture textureMode textureWrap ' +
        'blend copy filter get loadPixels set updatePixels blendMode loadShader PShaderresetShader shader createFont ' +
        'loadFont text textFont textAlign textLeading textMode textSize textWidth textAscent textDescent abs ceil ' +
        'constrain dist exp floor lerp log mag map max min norm pow round sq sqrt acos asin atan atan2 cos degrees ' +
        'radians sin tan noise noiseDetail noiseSeed random randomGaussian randomSeed'
    },
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      hljs.C_NUMBER_MODE
    ]
  };
});

hljs.registerLanguage('profile', function(hljs) {
  return {
    contains: [
      hljs.C_NUMBER_MODE,
      {
        className: 'built_in',
        begin: '{', end: '}$',
        excludeBegin: true, excludeEnd: true,
        contains: [hljs.APOS_STRING_MODE, hljs.QUOTE_STRING_MODE],
        relevance: 0
      },
      {
        className: 'filename',
        begin: '[a-zA-Z_][\\da-zA-Z_]+\\.[\\da-zA-Z_]{1,3}', end: ':',
        excludeEnd: true
      },
      {
        className: 'header',
        begin: '(ncalls|tottime|cumtime)', end: '$',
        keywords: 'ncalls tottime|10 cumtime|10 filename',
        relevance: 10
      },
      {
        className: 'summary',
        begin: 'function calls', end: '$',
        contains: [hljs.C_NUMBER_MODE],
        relevance: 10
      },
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      {
        className: 'function',
        begin: '\\(', end: '\\)$',
        contains: [
          hljs.UNDERSCORE_TITLE_MODE
        ],
        relevance: 0
      }
    ]
  };
});

hljs.registerLanguage('prolog', function(hljs) {

  var ATOM = {

    className: 'atom',
    begin: /[a-z][A-Za-z0-9_]*/,
    relevance: 0
  };

  var VAR = {

    className: 'name',
    variants: [
      {begin: /[A-Z][a-zA-Z0-9_]*/},
      {begin: /_[A-Za-z0-9_]*/},
    ],
    relevance: 0
  };

  var PARENTED = {

    begin: /\(/,
    end: /\)/,
    relevance: 0
  };

  var LIST = {

    begin: /\[/,
    end: /\]/
  };

  var LINE_COMMENT = {

    className: 'comment',
    begin: /%/, end: /$/,
    contains: [hljs.PHRASAL_WORDS_MODE]
  };

  var BACKTICK_STRING = {

    className: 'string',
    begin: /`/, end: /`/,
    contains: [hljs.BACKSLASH_ESCAPE]
  };

  var CHAR_CODE = {

    className: 'string', // 0'a etc.
    begin: /0\'(\\\'|.)/
  };

  var SPACE_CODE = {

    className: 'string',
    begin: /0\'\\s/ // 0'\s
  };

  var PRED_OP = { // relevance booster
    begin: /:-/
  };

  var inner = [

    ATOM,
    VAR,
    PARENTED,
    PRED_OP,
    LIST,
    LINE_COMMENT,
    hljs.C_BLOCK_COMMENT_MODE,
    hljs.QUOTE_STRING_MODE,
    hljs.APOS_STRING_MODE,
    BACKTICK_STRING,
    CHAR_CODE,
    SPACE_CODE,
    hljs.C_NUMBER_MODE
  ];

  PARENTED.contains = inner;
  LIST.contains = inner;

  return {
    contains: inner.concat([
      {begin: /\.$/} // relevance booster
    ])
  };
});

hljs.registerLanguage('protobuf', function(hljs) {
  return {
    keywords: {
      keyword: 'package import option optional required repeated group',
      built_in: 'double float int32 int64 uint32 uint64 sint32 sint64 ' +
        'fixed32 fixed64 sfixed32 sfixed64 bool string bytes',
      literal: 'true false'
    },
    contains: [
      hljs.QUOTE_STRING_MODE,
      hljs.NUMBER_MODE,
      hljs.C_LINE_COMMENT_MODE,
      {
        className: 'class',
        beginKeywords: 'message enum service', end: /\{/,
        illegal: /\n/,
        contains: [
          hljs.inherit(hljs.TITLE_MODE, {
            starts: {endsWithParent: true, excludeEnd: true} // hack: eating everything after the first title
          })
        ]
      },
      {
        className: 'function',
        beginKeywords: 'rpc',
        end: /;/, excludeEnd: true,
        keywords: 'rpc returns'
      },
      {
        className: 'constant',
        begin: /^\s*[A-Z_]+/,
        end: /\s*=/, excludeEnd: true
      }
    ]
  };
});

hljs.registerLanguage('puppet', function(hljs) {

  var PUPPET_KEYWORDS = {
    keyword:
    /* language keywords */
      'and case default else elsif false if in import enherits node or true undef unless main settings $string ',
    literal:
    /* metaparameters */
      'alias audit before loglevel noop require subscribe tag ' +
    /* normal attributes */
      'owner ensure group mode name|0 changes context force incl lens load_path onlyif provider returns root show_diff type_check ' +
      'en_address ip_address realname command environment hour monute month monthday special target weekday '+
      'creates cwd ogoutput refresh refreshonly tries try_sleep umask backup checksum content ctime force ignore ' +
      'links mtime purge recurse recurselimit replace selinux_ignore_defaults selrange selrole seltype seluser source ' +
      'souirce_permissions sourceselect validate_cmd validate_replacement allowdupe attribute_membership auth_membership forcelocal gid '+
      'ia_load_module members system host_aliases ip allowed_trunk_vlans description device_url duplex encapsulation etherchannel ' +
      'native_vlan speed principals allow_root auth_class auth_type authenticate_user k_of_n mechanisms rule session_owner shared options ' +
      'device fstype enable hasrestart directory present absent link atboot blockdevice device dump pass remounts poller_tag use ' +
      'message withpath adminfile allow_virtual allowcdrom category configfiles flavor install_options instance package_settings platform ' +
      'responsefile status uninstall_options vendor unless_system_user unless_uid binary control flags hasstatus manifest pattern restart running ' +
      'start stop allowdupe auths expiry gid groups home iterations key_membership keys managehome membership password password_max_age ' +
      'password_min_age profile_membership profiles project purge_ssh_keys role_membership roles salt shell uid baseurl cost descr enabled ' +
      'enablegroups exclude failovermethod gpgcheck gpgkey http_caching include includepkgs keepalive metadata_expire metalink mirrorlist ' +
      'priority protect proxy proxy_password proxy_username repo_gpgcheck s3_enabled skip_if_unavailable sslcacert sslclientcert sslclientkey ' +
      'sslverify mounted',
    built_in:
    /* core facts */
      'architecture augeasversion blockdevices boardmanufacturer boardproductname boardserialnumber cfkey dhcp_servers ' +
      'domain ec2_ ec2_userdata facterversion filesystems ldom fqdn gid hardwareisa hardwaremodel hostname id|0 interfaces '+
      'ipaddress ipaddress_ ipaddress6 ipaddress6_ iphostnumber is_virtual kernel kernelmajversion kernelrelease kernelversion ' +
      'kernelrelease kernelversion lsbdistcodename lsbdistdescription lsbdistid lsbdistrelease lsbmajdistrelease lsbminordistrelease ' +
      'lsbrelease macaddress macaddress_ macosx_buildversion macosx_productname macosx_productversion macosx_productverson_major ' +
      'macosx_productversion_minor manufacturer memoryfree memorysize netmask metmask_ network_ operatingsystem operatingsystemmajrelease '+
      'operatingsystemrelease osfamily partitions path physicalprocessorcount processor processorcount productname ps puppetversion '+
      'rubysitedir rubyversion selinux selinux_config_mode selinux_config_policy selinux_current_mode selinux_current_mode selinux_enforced '+
      'selinux_policyversion serialnumber sp_ sshdsakey sshecdsakey sshrsakey swapencrypted swapfree swapsize timezone type uniqueid uptime '+
      'uptime_days uptime_hours uptime_seconds uuid virtual vlans xendomains zfs_version zonenae zones zpool_version'
  };

  var COMMENT = hljs.COMMENT('#', '$');

  var IDENT_RE = '([A-Za-z_]|::)(\\w|::)*';

  var TITLE = hljs.inherit(hljs.TITLE_MODE, {begin: IDENT_RE});

  var VARIABLE = {className: 'variable', begin: '\\$' + IDENT_RE};

  var STRING = {
    className: 'string',
    contains: [hljs.BACKSLASH_ESCAPE, VARIABLE],
    variants: [
      {begin: /'/, end: /'/},
      {begin: /"/, end: /"/}
    ]
  };

  return {
    aliases: ['pp'],
    contains: [
      COMMENT,
      VARIABLE,
      STRING,
      {
        beginKeywords: 'class', end: '\\{|;',
        illegal: /=/,
        contains: [TITLE, COMMENT]
      },
      {
        beginKeywords: 'define', end: /\{/,
        contains: [
          {
            className: 'title', begin: hljs.IDENT_RE, endsParent: true
          }
        ]
      },
      {
        begin: hljs.IDENT_RE + '\\s+\\{', returnBegin: true,
        end: /\S/,
        contains: [
          {
            className: 'name',
            begin: hljs.IDENT_RE
          },
          {
            begin: /\{/, end: /\}/,
            keywords: PUPPET_KEYWORDS,
            relevance: 0,
            contains: [
              STRING,
              COMMENT,
              {
                begin:'[a-zA-Z_]+\\s*=>'
              },
              {
                className: 'number',
                begin: '(\\b0[0-7_]+)|(\\b0x[0-9a-fA-F_]+)|(\\b[1-9][0-9_]*(\\.[0-9_]+)?)|[0_]\\b',
                relevance: 0
              },
              VARIABLE
            ]
          }
        ],
        relevance: 0
      }
    ]
  }
});

hljs.registerLanguage('python', function(hljs) {
  var PROMPT = {
    className: 'prompt',  begin: /^(>>>|\.\.\.) /
  };
  var STRING = {
    className: 'string',
    contains: [hljs.BACKSLASH_ESCAPE],
    variants: [
      {
        begin: /(u|b)?r?'''/, end: /'''/,
        contains: [PROMPT],
        relevance: 10
      },
      {
        begin: /(u|b)?r?"""/, end: /"""/,
        contains: [PROMPT],
        relevance: 10
      },
      {
        begin: /(u|r|ur)'/, end: /'/,
        relevance: 10
      },
      {
        begin: /(u|r|ur)"/, end: /"/,
        relevance: 10
      },
      {
        begin: /(b|br)'/, end: /'/
      },
      {
        begin: /(b|br)"/, end: /"/
      },
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE
    ]
  };
  var NUMBER = {
    className: 'number', relevance: 0,
    variants: [
      {begin: hljs.BINARY_NUMBER_RE + '[lLjJ]?'},
      {begin: '\\b(0o[0-7]+)[lLjJ]?'},
      {begin: hljs.C_NUMBER_RE + '[lLjJ]?'}
    ]
  };
  var PARAMS = {
    className: 'params',
    begin: /\(/, end: /\)/,
    contains: ['self', PROMPT, NUMBER, STRING]
  };
  return {
    aliases: ['py', 'gyp'],
    keywords: {
      keyword:
        'and elif is global as in if from raise for except finally print import pass return ' +
        'exec else break not with class assert yield try while continue del or def lambda ' +
        'async await nonlocal|10 None True False',
      built_in:
        'Ellipsis NotImplemented'
    },
    illegal: /(<\/|->|\?)/,
    contains: [
      PROMPT,
      NUMBER,
      STRING,
      hljs.HASH_COMMENT_MODE,
      {
        variants: [
          {className: 'function', beginKeywords: 'def', relevance: 10},
          {className: 'class', beginKeywords: 'class'}
        ],
        end: /:/,
        illegal: /[${=;\n,]/,
        contains: [hljs.UNDERSCORE_TITLE_MODE, PARAMS]
      },
      {
        className: 'decorator',
        begin: /^[\t ]*@/, end: /$/
      },
      {
        begin: /\b(print|exec)\(/ // don’t highlight keywords-turned-functions in Python 3
      }
    ]
  };
});

hljs.registerLanguage('q', function(hljs) {
  var Q_KEYWORDS = {
  keyword:
    'do while select delete by update from',
  constant:
    '0b 1b',
  built_in:
    'neg not null string reciprocal floor ceiling signum mod xbar xlog and or each scan over prior mmu lsq inv md5 ltime gtime count first var dev med cov cor all any rand sums prds mins maxs fills deltas ratios avgs differ prev next rank reverse iasc idesc asc desc msum mcount mavg mdev xrank mmin mmax xprev rotate distinct group where flip type key til get value attr cut set upsert raze union inter except cross sv vs sublist enlist read0 read1 hopen hclose hdel hsym hcount peach system ltrim rtrim trim lower upper ssr view tables views cols xcols keys xkey xcol xasc xdesc fkeys meta lj aj aj0 ij pj asof uj ww wj wj1 fby xgroup ungroup ej save load rsave rload show csv parse eval min max avg wavg wsum sin cos tan sum',
  typename:
    '`float `double int `timestamp `timespan `datetime `time `boolean `symbol `char `byte `short `long `real `month `date `minute `second `guid'
  };
  return {
  aliases:['k', 'kdb'],
  keywords: Q_KEYWORDS,
  lexemes: /\b(`?)[A-Za-z0-9_]+\b/,
  contains: [
  hljs.C_LINE_COMMENT_MODE,
    hljs.QUOTE_STRING_MODE,
    hljs.C_NUMBER_MODE
     ]
  };
});

hljs.registerLanguage('r', function(hljs) {
  var IDENT_RE = '([a-zA-Z]|\\.[a-zA-Z.])[a-zA-Z0-9._]*';

  return {
    contains: [
      hljs.HASH_COMMENT_MODE,
      {
        begin: IDENT_RE,
        lexemes: IDENT_RE,
        keywords: {
          keyword:
            'function if in break next repeat else for return switch while try tryCatch ' +
            'stop warning require library attach detach source setMethod setGeneric ' +
            'setGroupGeneric setClass ...',
          literal:
            'NULL NA TRUE FALSE T F Inf NaN NA_integer_|10 NA_real_|10 NA_character_|10 ' +
            'NA_complex_|10'
        },
        relevance: 0
      },
      {
        // hex value
        className: 'number',
        begin: "0[xX][0-9a-fA-F]+[Li]?\\b",
        relevance: 0
      },
      {
        // explicit integer
        className: 'number',
        begin: "\\d+(?:[eE][+\\-]?\\d*)?L\\b",
        relevance: 0
      },
      {
        // number with trailing decimal
        className: 'number',
        begin: "\\d+\\.(?!\\d)(?:i\\b)?",
        relevance: 0
      },
      {
        // number
        className: 'number',
        begin: "\\d+(?:\\.\\d*)?(?:[eE][+\\-]?\\d*)?i?\\b",
        relevance: 0
      },
      {
        // number with leading decimal
        className: 'number',
        begin: "\\.\\d+(?:[eE][+\\-]?\\d*)?i?\\b",
        relevance: 0
      },

      {
        // escaped identifier
        begin: '`',
        end: '`',
        relevance: 0
      },

      {
        className: 'string',
        contains: [hljs.BACKSLASH_ESCAPE],
        variants: [
          {begin: '"', end: '"'},
          {begin: "'", end: "'"}
        ]
      }
    ]
  };
});

hljs.registerLanguage('rib', function(hljs) {
  return {
    keywords:
      'ArchiveRecord AreaLightSource Atmosphere Attribute AttributeBegin AttributeEnd Basis ' +
      'Begin Blobby Bound Clipping ClippingPlane Color ColorSamples ConcatTransform Cone ' +
      'CoordinateSystem CoordSysTransform CropWindow Curves Cylinder DepthOfField Detail ' +
      'DetailRange Disk Displacement Display End ErrorHandler Exposure Exterior Format ' +
      'FrameAspectRatio FrameBegin FrameEnd GeneralPolygon GeometricApproximation Geometry ' +
      'Hider Hyperboloid Identity Illuminate Imager Interior LightSource ' +
      'MakeCubeFaceEnvironment MakeLatLongEnvironment MakeShadow MakeTexture Matte ' +
      'MotionBegin MotionEnd NuPatch ObjectBegin ObjectEnd ObjectInstance Opacity Option ' +
      'Orientation Paraboloid Patch PatchMesh Perspective PixelFilter PixelSamples ' +
      'PixelVariance Points PointsGeneralPolygons PointsPolygons Polygon Procedural Projection ' +
      'Quantize ReadArchive RelativeDetail ReverseOrientation Rotate Scale ScreenWindow ' +
      'ShadingInterpolation ShadingRate Shutter Sides Skew SolidBegin SolidEnd Sphere ' +
      'SubdivisionMesh Surface TextureCoordinates Torus Transform TransformBegin TransformEnd ' +
      'TransformPoints Translate TrimCurve WorldBegin WorldEnd',
    illegal: '</',
    contains: [
      hljs.HASH_COMMENT_MODE,
      hljs.C_NUMBER_MODE,
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE
    ]
  };
});

hljs.registerLanguage('roboconf', function(hljs) {
  var IDENTIFIER = '[a-zA-Z-_][^\n{\r\n]+\\{';

  return {
    aliases: ['graph', 'instances'],
    case_insensitive: true,
    keywords: 'import',
    contains: [
      // Facet sections
      {
        className: 'facet',
        begin: '^facet ' + IDENTIFIER,
        end: '}',
        keywords: 'facet installer exports children extends',
        contains: [
          hljs.HASH_COMMENT_MODE
        ]
      },

      // Instance sections
      {
        className: 'instance-of',
        begin: '^instance of ' + IDENTIFIER,
        end: '}',
        keywords: 'name count channels instance-data instance-state instance of',
        contains: [
          // Instance overridden properties
          {
            className: 'keyword',
            begin: '[a-zA-Z-_]+( |\t)*:'
          },
          hljs.HASH_COMMENT_MODE
        ]
      },

      // Component sections
      {
        className: 'component',
        begin: '^' + IDENTIFIER,
        end: '}',
        lexemes: '\\(?[a-zA-Z]+\\)?',
        keywords: 'installer exports children extends imports facets alias (optional)',
        contains: [
          // Imported component variables
          {
            className: 'string',
            begin: '\\.[a-zA-Z-_]+',
            end: '\\s|,|;',
            excludeEnd: true
          },
          hljs.HASH_COMMENT_MODE
        ]
      },

      // Comments
      hljs.HASH_COMMENT_MODE
    ]
  };
});

hljs.registerLanguage('rsl', function(hljs) {
  return {
    keywords: {
      keyword:
        'float color point normal vector matrix while for if do return else break extern continue',
      built_in:
        'abs acos ambient area asin atan atmosphere attribute calculatenormal ceil cellnoise ' +
        'clamp comp concat cos degrees depth Deriv diffuse distance Du Dv environment exp ' +
        'faceforward filterstep floor format fresnel incident length lightsource log match ' +
        'max min mod noise normalize ntransform opposite option phong pnoise pow printf ' +
        'ptlined radians random reflect refract renderinfo round setcomp setxcomp setycomp ' +
        'setzcomp shadow sign sin smoothstep specular specularbrdf spline sqrt step tan ' +
        'texture textureinfo trace transform vtransform xcomp ycomp zcomp'
    },
    illegal: '</',
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.QUOTE_STRING_MODE,
      hljs.APOS_STRING_MODE,
      hljs.C_NUMBER_MODE,
      {
        className: 'preprocessor',
        begin: '#', end: '$'
      },
      {
        className: 'shader',
        beginKeywords: 'surface displacement light volume imager', end: '\\('
      },
      {
        className: 'shading',
        beginKeywords: 'illuminate illuminance gather', end: '\\('
      }
    ]
  };
});

hljs.registerLanguage('ruleslanguage', function(hljs) {
  return {
    keywords: {
       keyword: 'BILL_PERIOD BILL_START BILL_STOP RS_EFFECTIVE_START RS_EFFECTIVE_STOP RS_JURIS_CODE RS_OPCO_CODE ' +
         'INTDADDATTRIBUTE|5 INTDADDVMSG|5 INTDBLOCKOP|5 INTDBLOCKOPNA|5 INTDCLOSE|5 INTDCOUNT|5 ' +
         'INTDCOUNTSTATUSCODE|5 INTDCREATEMASK|5 INTDCREATEDAYMASK|5 INTDCREATEFACTORMASK|5 ' +
         'INTDCREATEHANDLE|5 INTDCREATEOVERRIDEDAYMASK|5 INTDCREATEOVERRIDEMASK|5 ' +
         'INTDCREATESTATUSCODEMASK|5 INTDCREATETOUPERIOD|5 INTDDELETE|5 INTDDIPTEST|5 INTDEXPORT|5 ' +
         'INTDGETERRORCODE|5 INTDGETERRORMESSAGE|5 INTDISEQUAL|5 INTDJOIN|5 INTDLOAD|5 INTDLOADACTUALCUT|5 ' +
         'INTDLOADDATES|5 INTDLOADHIST|5 INTDLOADLIST|5 INTDLOADLISTDATES|5 INTDLOADLISTENERGY|5 ' +
         'INTDLOADLISTHIST|5 INTDLOADRELATEDCHANNEL|5 INTDLOADSP|5 INTDLOADSTAGING|5 INTDLOADUOM|5 ' +
         'INTDLOADUOMDATES|5 INTDLOADUOMHIST|5 INTDLOADVERSION|5 INTDOPEN|5 INTDREADFIRST|5 INTDREADNEXT|5 ' +
         'INTDRECCOUNT|5 INTDRELEASE|5 INTDREPLACE|5 INTDROLLAVG|5 INTDROLLPEAK|5 INTDSCALAROP|5 INTDSCALE|5 ' +
         'INTDSETATTRIBUTE|5 INTDSETDSTPARTICIPANT|5 INTDSETSTRING|5 INTDSETVALUE|5 INTDSETVALUESTATUS|5 ' +
         'INTDSHIFTSTARTTIME|5 INTDSMOOTH|5 INTDSORT|5 INTDSPIKETEST|5 INTDSUBSET|5 INTDTOU|5 ' +
         'INTDTOURELEASE|5 INTDTOUVALUE|5 INTDUPDATESTATS|5 INTDVALUE|5 STDEV INTDDELETEEX|5 ' +
         'INTDLOADEXACTUAL|5 INTDLOADEXCUT|5 INTDLOADEXDATES|5 INTDLOADEX|5 INTDLOADEXRELATEDCHANNEL|5 ' +
         'INTDSAVEEX|5 MVLOAD|5 MVLOADACCT|5 MVLOADACCTDATES|5 MVLOADACCTHIST|5 MVLOADDATES|5 MVLOADHIST|5 ' +
         'MVLOADLIST|5 MVLOADLISTDATES|5 MVLOADLISTHIST|5 IF FOR NEXT DONE SELECT END CALL ABORT CLEAR CHANNEL FACTOR LIST NUMBER ' +
         'OVERRIDE SET WEEK DISTRIBUTIONNODE ELSE WHEN THEN OTHERWISE IENUM CSV INCLUDE LEAVE RIDER SAVE DELETE ' +
         'NOVALUE SECTION WARN SAVE_UPDATE DETERMINANT LABEL REPORT REVENUE EACH ' +
         'IN FROM TOTAL CHARGE BLOCK AND OR CSV_FILE RATE_CODE AUXILIARY_DEMAND ' +
         'UIDACCOUNT RS BILL_PERIOD_SELECT HOURS_PER_MONTH INTD_ERROR_STOP SEASON_SCHEDULE_NAME ' +
         'ACCOUNTFACTOR ARRAYUPPERBOUND CALLSTOREDPROC GETADOCONNECTION GETCONNECT GETDATASOURCE ' +
         'GETQUALIFIER GETUSERID HASVALUE LISTCOUNT LISTOP LISTUPDATE LISTVALUE PRORATEFACTOR RSPRORATE ' +
         'SETBINPATH SETDBMONITOR WQ_OPEN BILLINGHOURS DATE DATEFROMFLOAT DATETIMEFROMSTRING ' +
         'DATETIMETOSTRING DATETOFLOAT DAY DAYDIFF DAYNAME DBDATETIME HOUR MINUTE MONTH MONTHDIFF ' +
         'MONTHHOURS MONTHNAME ROUNDDATE SAMEWEEKDAYLASTYEAR SECOND WEEKDAY WEEKDIFF YEAR YEARDAY ' +
         'YEARSTR COMPSUM HISTCOUNT HISTMAX HISTMIN HISTMINNZ HISTVALUE MAXNRANGE MAXRANGE MINRANGE ' +
         'COMPIKVA COMPKVA COMPKVARFROMKQKW COMPLF IDATTR FLAG LF2KW LF2KWH MAXKW POWERFACTOR ' +
         'READING2USAGE AVGSEASON MAXSEASON MONTHLYMERGE SEASONVALUE SUMSEASON ACCTREADDATES ' +
         'ACCTTABLELOAD CONFIGADD CONFIGGET CREATEOBJECT CREATEREPORT EMAILCLIENT EXPBLKMDMUSAGE ' +
         'EXPMDMUSAGE EXPORT_USAGE FACTORINEFFECT GETUSERSPECIFIEDSTOP INEFFECT ISHOLIDAY RUNRATE ' +
         'SAVE_PROFILE SETREPORTTITLE USEREXIT WATFORRUNRATE TO TABLE ACOS ASIN ATAN ATAN2 BITAND CEIL ' +
         'COS COSECANT COSH COTANGENT DIVQUOT DIVREM EXP FABS FLOOR FMOD FREPM FREXPN LOG LOG10 MAX MAXN ' +
         'MIN MINNZ MODF POW ROUND ROUND2VALUE ROUNDINT SECANT SIN SINH SQROOT TAN TANH FLOAT2STRING ' +
         'FLOAT2STRINGNC INSTR LEFT LEN LTRIM MID RIGHT RTRIM STRING STRINGNC TOLOWER TOUPPER TRIM ' +
         'NUMDAYS READ_DATE STAGING',
       built_in: 'IDENTIFIER OPTIONS XML_ELEMENT XML_OP XML_ELEMENT_OF DOMDOCCREATE DOMDOCLOADFILE DOMDOCLOADXML ' +
         'DOMDOCSAVEFILE DOMDOCGETROOT DOMDOCADDPI DOMNODEGETNAME DOMNODEGETTYPE DOMNODEGETVALUE DOMNODEGETCHILDCT ' +
         'DOMNODEGETFIRSTCHILD DOMNODEGETSIBLING DOMNODECREATECHILDELEMENT DOMNODESETATTRIBUTE ' +
         'DOMNODEGETCHILDELEMENTCT DOMNODEGETFIRSTCHILDELEMENT DOMNODEGETSIBLINGELEMENT DOMNODEGETATTRIBUTECT ' +
         'DOMNODEGETATTRIBUTEI DOMNODEGETATTRIBUTEBYNAME DOMNODEGETBYNAME'
    },
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      hljs.C_NUMBER_MODE,
      {
        className: 'array',
        variants: [
          {begin: '#\\s+[a-zA-Z\\ \\.]*', relevance: 0}, // looks like #-comment
          {begin: '#[a-zA-Z\\ \\.]+'}
        ]
      }
    ]
  };
});

hljs.registerLanguage('rust', function(hljs) {
  var NUM_SUFFIX = '([uif](8|16|32|64|size))\?';
  var BLOCK_COMMENT = hljs.inherit(hljs.C_BLOCK_COMMENT_MODE);
  BLOCK_COMMENT.contains.push('self');
  return {
    aliases: ['rs'],
    keywords: {
      keyword:
        'alignof as be box break const continue crate do else enum extern ' +
        'false fn for if impl in let loop match mod mut offsetof once priv ' +
        'proc pub pure ref return self Self sizeof static struct super trait true ' +
        'type typeof unsafe unsized use virtual while where yield ' +
        'int i8 i16 i32 i64 ' +
        'uint u8 u32 u64 ' +
        'float f32 f64 ' +
        'str char bool',
      built_in:
        // prelude
        'Copy Send Sized Sync Drop Fn FnMut FnOnce drop Box ToOwned Clone ' +
        'PartialEq PartialOrd Eq Ord AsRef AsMut Into From Default Iterator ' +
        'Extend IntoIterator DoubleEndedIterator ExactSizeIterator Option ' +
        'Some None Result Ok Err SliceConcatExt String ToString Vec ' +
        // macros
        'assert! assert_eq! bitflags! bytes! cfg! col! concat! concat_idents! ' +
        'debug_assert! debug_assert_eq! env! panic! file! format! format_args! ' +
        'include_bin! include_str! line! local_data_key! module_path! ' +
        'option_env! print! println! select! stringify! try! unimplemented! ' +
        'unreachable! vec! write! writeln!'
    },
    lexemes: hljs.IDENT_RE + '!?',
    illegal: '</',
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      BLOCK_COMMENT,
      hljs.inherit(hljs.QUOTE_STRING_MODE, {illegal: null}),
      {
        className: 'string',
        variants: [
           { begin: /r(#*)".*?"\1(?!#)/ },
           { begin: /'\\?(x\w{2}|u\w{4}|U\w{8}|.)'/ },
           { begin: /'[a-zA-Z_][a-zA-Z0-9_]*/ }
        ]
      },
      {
        className: 'number',
        variants: [
          { begin: '\\b0b([01_]+)' + NUM_SUFFIX },
          { begin: '\\b0o([0-7_]+)' + NUM_SUFFIX },
          { begin: '\\b0x([A-Fa-f0-9_]+)' + NUM_SUFFIX },
          { begin: '\\b(\\d[\\d_]*(\\.[0-9_]+)?([eE][+-]?[0-9_]+)?)' +
                   NUM_SUFFIX
          }
        ],
        relevance: 0
      },
      {
        className: 'function',
        beginKeywords: 'fn', end: '(\\(|<)', excludeEnd: true,
        contains: [hljs.UNDERSCORE_TITLE_MODE]
      },
      {
        className: 'preprocessor',
        begin: '#\\!?\\[', end: '\\]'
      },
      {
        beginKeywords: 'type', end: '(=|<)',
        contains: [hljs.UNDERSCORE_TITLE_MODE],
        illegal: '\\S'
      },
      {
        beginKeywords: 'trait enum', end: '{',
        contains: [
          hljs.inherit(hljs.UNDERSCORE_TITLE_MODE, {endsParent: true})
        ],
        illegal: '[\\w\\d]'
      },
      {
        begin: hljs.IDENT_RE + '::'
      },
      {
        begin: '->'
      }
    ]
  };
});

hljs.registerLanguage('scala', function(hljs) {

  var ANNOTATION = {
    className: 'annotation', begin: '@[A-Za-z]+'
  };

  var STRING = {
    className: 'string',
    begin: 'u?r?"""', end: '"""',
    relevance: 10
  };

  var SYMBOL = {
    className: 'symbol',
    begin: '\'\\w[\\w\\d_]*(?!\')'
  };

  var TYPE = {
    className: 'type',
    begin: '\\b[A-Z][A-Za-z0-9_]*',
    relevance: 0
  };

  var NAME = {
    className: 'title',
    begin: /[^0-9\n\t "'(),.`{}\[\]:;][^\n\t "'(),.`{}\[\]:;]+|[^0-9\n\t "'(),.`{}\[\]:;=]/,
    relevance: 0
  };

  var CLASS = {
    className: 'class',
    beginKeywords: 'class object trait type',
    end: /[:={\[(\n;]/,
    contains: [{className: 'keyword', beginKeywords: 'extends with', relevance: 10}, NAME]
  };

  var METHOD = {
    className: 'function',
    beginKeywords: 'def',
    end: /[:={\[(\n;]/,
    contains: [NAME]
  };

  return {
    keywords: {
      literal: 'true false null',
      keyword: 'type yield lazy override def with val var sealed abstract private trait object if forSome for while throw finally protected extends import final return else break new catch super class case package default try this match continue throws implicit'
    },
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      STRING,
      hljs.QUOTE_STRING_MODE,
      SYMBOL,
      TYPE,
      METHOD,
      CLASS,
      hljs.C_NUMBER_MODE,
      ANNOTATION
    ]
  };
});

hljs.registerLanguage('scheme', function(hljs) {
  var SCHEME_IDENT_RE = '[^\\(\\)\\[\\]\\{\\}",\'`;#|\\\\\\s]+';
  var SCHEME_SIMPLE_NUMBER_RE = '(\\-|\\+)?\\d+([./]\\d+)?';
  var SCHEME_COMPLEX_NUMBER_RE = SCHEME_SIMPLE_NUMBER_RE + '[+\\-]' + SCHEME_SIMPLE_NUMBER_RE + 'i';
  var BUILTINS = {
    built_in:
      'case-lambda call/cc class define-class exit-handler field import ' +
      'inherit init-field interface let*-values let-values let/ec mixin ' +
      'opt-lambda override protect provide public rename require ' +
      'require-for-syntax syntax syntax-case syntax-error unit/sig unless ' +
      'when with-syntax and begin call-with-current-continuation ' +
      'call-with-input-file call-with-output-file case cond define ' +
      'define-syntax delay do dynamic-wind else for-each if lambda let let* ' +
      'let-syntax letrec letrec-syntax map or syntax-rules \' * + , ,@ - ... / ' +
      '; < <= = => > >= ` abs acos angle append apply asin assoc assq assv atan ' +
      'boolean? caar cadr call-with-input-file call-with-output-file ' +
      'call-with-values car cdddar cddddr cdr ceiling char->integer ' +
      'char-alphabetic? char-ci<=? char-ci<? char-ci=? char-ci>=? char-ci>? ' +
      'char-downcase char-lower-case? char-numeric? char-ready? char-upcase ' +
      'char-upper-case? char-whitespace? char<=? char<? char=? char>=? char>? ' +
      'char? close-input-port close-output-port complex? cons cos ' +
      'current-input-port current-output-port denominator display eof-object? ' +
      'eq? equal? eqv? eval even? exact->inexact exact? exp expt floor ' +
      'force gcd imag-part inexact->exact inexact? input-port? integer->char ' +
      'integer? interaction-environment lcm length list list->string ' +
      'list->vector list-ref list-tail list? load log magnitude make-polar ' +
      'make-rectangular make-string make-vector max member memq memv min ' +
      'modulo negative? newline not null-environment null? number->string ' +
      'number? numerator odd? open-input-file open-output-file output-port? ' +
      'pair? peek-char port? positive? procedure? quasiquote quote quotient ' +
      'rational? rationalize read read-char real-part real? remainder reverse ' +
      'round scheme-report-environment set! set-car! set-cdr! sin sqrt string ' +
      'string->list string->number string->symbol string-append string-ci<=? ' +
      'string-ci<? string-ci=? string-ci>=? string-ci>? string-copy ' +
      'string-fill! string-length string-ref string-set! string<=? string<? ' +
      'string=? string>=? string>? string? substring symbol->string symbol? ' +
      'tan transcript-off transcript-on truncate values vector ' +
      'vector->list vector-fill! vector-length vector-ref vector-set! ' +
      'with-input-from-file with-output-to-file write write-char zero?'
  };

  var SHEBANG = {
    className: 'shebang',
    begin: '^#!',
    end: '$'
  };

  var LITERAL = {
    className: 'literal',
    begin: '(#t|#f|#\\\\' + SCHEME_IDENT_RE + '|#\\\\.)'
  };

  var NUMBER = {
    className: 'number',
    variants: [
      { begin: SCHEME_SIMPLE_NUMBER_RE, relevance: 0 },
      { begin: SCHEME_COMPLEX_NUMBER_RE, relevance: 0 },
      { begin: '#b[0-1]+(/[0-1]+)?' },
      { begin: '#o[0-7]+(/[0-7]+)?' },
      { begin: '#x[0-9a-f]+(/[0-9a-f]+)?' }
    ]
  };

  var STRING = hljs.QUOTE_STRING_MODE;

  var REGULAR_EXPRESSION = {
    className: 'regexp',
    begin: '#[pr]x"',
    end: '[^\\\\]"'
  };

  var COMMENT_MODES = [
    hljs.COMMENT(
      ';',
      '$',
      {
        relevance: 0
      }
    ),
    hljs.COMMENT('#\\|', '\\|#')
  ];

  var IDENT = {
    begin: SCHEME_IDENT_RE,
    relevance: 0
  };

  var QUOTED_IDENT = {
    className: 'variable',
    begin: '\'' + SCHEME_IDENT_RE
  };

  var BODY = {
    endsWithParent: true,
    relevance: 0
  };

  var LIST = {
    className: 'list',
    variants: [
      { begin: '\\(', end: '\\)' },
      { begin: '\\[', end: '\\]' }
    ],
    contains: [
      {
        className: 'keyword',
        begin: SCHEME_IDENT_RE,
        lexemes: SCHEME_IDENT_RE,
        keywords: BUILTINS
      },
      BODY
    ]
  };

  BODY.contains = [LITERAL, NUMBER, STRING, IDENT, QUOTED_IDENT, LIST].concat(COMMENT_MODES);

  return {
    illegal: /\S/,
    contains: [SHEBANG, NUMBER, STRING, QUOTED_IDENT, LIST].concat(COMMENT_MODES)
  };
});

hljs.registerLanguage('scilab', function(hljs) {

  var COMMON_CONTAINS = [
    hljs.C_NUMBER_MODE,
    {
      className: 'string',
      begin: '\'|\"', end: '\'|\"',
      contains: [hljs.BACKSLASH_ESCAPE, {begin: '\'\''}]
    }
  ];

  return {
    aliases: ['sci'],
    keywords: {
      keyword: 'abort break case clear catch continue do elseif else endfunction end for function'+
        'global if pause return resume select try then while'+
        '%f %F %t %T %pi %eps %inf %nan %e %i %z %s',
      built_in: // Scilab has more than 2000 functions. Just list the most commons
       'abs and acos asin atan ceil cd chdir clearglobal cosh cos cumprod deff disp error'+
       'exec execstr exists exp eye gettext floor fprintf fread fsolve imag isdef isempty'+
       'isinfisnan isvector lasterror length load linspace list listfiles log10 log2 log'+
       'max min msprintf mclose mopen ones or pathconvert poly printf prod pwd rand real'+
       'round sinh sin size gsort sprintf sqrt strcat strcmps tring sum system tanh tan'+
       'type typename warning zeros matrix'
    },
    illegal: '("|#|/\\*|\\s+/\\w+)',
    contains: [
      {
        className: 'function',
        beginKeywords: 'function endfunction', end: '$',
        keywords: 'function endfunction|10',
        contains: [
          hljs.UNDERSCORE_TITLE_MODE,
          {
            className: 'params',
            begin: '\\(', end: '\\)'
          }
        ]
      },
      {
        className: 'transposed_variable',
        begin: '[a-zA-Z_][a-zA-Z_0-9]*(\'+[\\.\']*|[\\.\']+)', end: '',
        relevance: 0
      },
      {
        className: 'matrix',
        begin: '\\[', end: '\\]\'*[\\.\']*',
        relevance: 0,
        contains: COMMON_CONTAINS
      },
      hljs.COMMENT('//', '$')
    ].concat(COMMON_CONTAINS)
  };
});

hljs.registerLanguage('scss', function(hljs) {
  var IDENT_RE = '[a-zA-Z-][a-zA-Z0-9_-]*';
  var VARIABLE = {
    className: 'variable',
    begin: '(\\$' + IDENT_RE + ')\\b'
  };
  var FUNCTION = {
    className: 'function',
    begin: IDENT_RE + '\\(',
    returnBegin: true,
    excludeEnd: true,
    end: '\\('
  };
  var HEXCOLOR = {
    className: 'hexcolor', begin: '#[0-9A-Fa-f]+'
  };
  var DEF_INTERNALS = {
    className: 'attribute',
    begin: '[A-Z\\_\\.\\-]+', end: ':',
    excludeEnd: true,
    illegal: '[^\\s]',
    starts: {
      className: 'value',
      endsWithParent: true, excludeEnd: true,
      contains: [
        FUNCTION,
        HEXCOLOR,
        hljs.CSS_NUMBER_MODE,
        hljs.QUOTE_STRING_MODE,
        hljs.APOS_STRING_MODE,
        hljs.C_BLOCK_COMMENT_MODE,
        {
          className: 'important', begin: '!important'
        }
      ]
    }
  };
  return {
    case_insensitive: true,
    illegal: '[=/|\']',
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      FUNCTION,
      {
        className: 'id', begin: '\\#[A-Za-z0-9_-]+',
        relevance: 0
      },
      {
        className: 'class', begin: '\\.[A-Za-z0-9_-]+',
        relevance: 0
      },
      {
        className: 'attr_selector',
        begin: '\\[', end: '\\]',
        illegal: '$'
      },
      {
        className: 'tag', // begin: IDENT_RE, end: '[,|\\s]'
        begin: '\\b(a|abbr|acronym|address|area|article|aside|audio|b|base|big|blockquote|body|br|button|canvas|caption|cite|code|col|colgroup|command|datalist|dd|del|details|dfn|div|dl|dt|em|embed|fieldset|figcaption|figure|footer|form|frame|frameset|(h[1-6])|head|header|hgroup|hr|html|i|iframe|img|input|ins|kbd|keygen|label|legend|li|link|map|mark|meta|meter|nav|noframes|noscript|object|ol|optgroup|option|output|p|param|pre|progress|q|rp|rt|ruby|samp|script|section|select|small|span|strike|strong|style|sub|sup|table|tbody|td|textarea|tfoot|th|thead|time|title|tr|tt|ul|var|video)\\b',
        relevance: 0
      },
      {
        className: 'pseudo',
        begin: ':(visited|valid|root|right|required|read-write|read-only|out-range|optional|only-of-type|only-child|nth-of-type|nth-last-of-type|nth-last-child|nth-child|not|link|left|last-of-type|last-child|lang|invalid|indeterminate|in-range|hover|focus|first-of-type|first-line|first-letter|first-child|first|enabled|empty|disabled|default|checked|before|after|active)'
      },
      {
        className: 'pseudo',
        begin: '::(after|before|choices|first-letter|first-line|repeat-index|repeat-item|selection|value)'
      },
      VARIABLE,
      {
        className: 'attribute',
        begin: '\\b(z-index|word-wrap|word-spacing|word-break|width|widows|white-space|visibility|vertical-align|unicode-bidi|transition-timing-function|transition-property|transition-duration|transition-delay|transition|transform-style|transform-origin|transform|top|text-underline-position|text-transform|text-shadow|text-rendering|text-overflow|text-indent|text-decoration-style|text-decoration-line|text-decoration-color|text-decoration|text-align-last|text-align|tab-size|table-layout|right|resize|quotes|position|pointer-events|perspective-origin|perspective|page-break-inside|page-break-before|page-break-after|padding-top|padding-right|padding-left|padding-bottom|padding|overflow-y|overflow-x|overflow-wrap|overflow|outline-width|outline-style|outline-offset|outline-color|outline|orphans|order|opacity|object-position|object-fit|normal|none|nav-up|nav-right|nav-left|nav-index|nav-down|min-width|min-height|max-width|max-height|mask|marks|margin-top|margin-right|margin-left|margin-bottom|margin|list-style-type|list-style-position|list-style-image|list-style|line-height|letter-spacing|left|justify-content|initial|inherit|ime-mode|image-orientation|image-resolution|image-rendering|icon|hyphens|height|font-weight|font-variant-ligatures|font-variant|font-style|font-stretch|font-size-adjust|font-size|font-language-override|font-kerning|font-feature-settings|font-family|font|float|flex-wrap|flex-shrink|flex-grow|flex-flow|flex-direction|flex-basis|flex|filter|empty-cells|display|direction|cursor|counter-reset|counter-increment|content|column-width|column-span|column-rule-width|column-rule-style|column-rule-color|column-rule|column-gap|column-fill|column-count|columns|color|clip-path|clip|clear|caption-side|break-inside|break-before|break-after|box-sizing|box-shadow|box-decoration-break|bottom|border-width|border-top-width|border-top-style|border-top-right-radius|border-top-left-radius|border-top-color|border-top|border-style|border-spacing|border-right-width|border-right-style|border-right-color|border-right|border-radius|border-left-width|border-left-style|border-left-color|border-left|border-image-width|border-image-source|border-image-slice|border-image-repeat|border-image-outset|border-image|border-color|border-collapse|border-bottom-width|border-bottom-style|border-bottom-right-radius|border-bottom-left-radius|border-bottom-color|border-bottom|border|background-size|background-repeat|background-position|background-origin|background-image|background-color|background-clip|background-attachment|background-blend-mode|background|backface-visibility|auto|animation-timing-function|animation-play-state|animation-name|animation-iteration-count|animation-fill-mode|animation-duration|animation-direction|animation-delay|animation|align-self|align-items|align-content)\\b',
        illegal: '[^\\s]'
      },
      {
        className: 'value',
        begin: '\\b(whitespace|wait|w-resize|visible|vertical-text|vertical-ideographic|uppercase|upper-roman|upper-alpha|underline|transparent|top|thin|thick|text|text-top|text-bottom|tb-rl|table-header-group|table-footer-group|sw-resize|super|strict|static|square|solid|small-caps|separate|se-resize|scroll|s-resize|rtl|row-resize|ridge|right|repeat|repeat-y|repeat-x|relative|progress|pointer|overline|outside|outset|oblique|nowrap|not-allowed|normal|none|nw-resize|no-repeat|no-drop|newspaper|ne-resize|n-resize|move|middle|medium|ltr|lr-tb|lowercase|lower-roman|lower-alpha|loose|list-item|line|line-through|line-edge|lighter|left|keep-all|justify|italic|inter-word|inter-ideograph|inside|inset|inline|inline-block|inherit|inactive|ideograph-space|ideograph-parenthesis|ideograph-numeric|ideograph-alpha|horizontal|hidden|help|hand|groove|fixed|ellipsis|e-resize|double|dotted|distribute|distribute-space|distribute-letter|distribute-all-lines|disc|disabled|default|decimal|dashed|crosshair|collapse|col-resize|circle|char|center|capitalize|break-word|break-all|bottom|both|bolder|bold|block|bidi-override|below|baseline|auto|always|all-scroll|absolute|table|table-cell)\\b'
      },
      {
        className: 'value',
        begin: ':', end: ';',
        contains: [
          FUNCTION,
          VARIABLE,
          HEXCOLOR,
          hljs.CSS_NUMBER_MODE,
          hljs.QUOTE_STRING_MODE,
          hljs.APOS_STRING_MODE,
          {
            className: 'important', begin: '!important'
          }
        ]
      },
      {
        className: 'at_rule',
        begin: '@', end: '[{;]',
        keywords: 'mixin include extend for if else each while charset import debug media page content font-face namespace warn',
        contains: [
          FUNCTION,
          VARIABLE,
          hljs.QUOTE_STRING_MODE,
          hljs.APOS_STRING_MODE,
          HEXCOLOR,
          hljs.CSS_NUMBER_MODE,
          {
            className: 'preprocessor',
            begin: '\\s[A-Za-z0-9_.-]+',
            relevance: 0
          }
        ]
      }
    ]
  };
});

hljs.registerLanguage('smali', function(hljs) {
  var smali_instr_low_prio = ['add', 'and', 'cmp', 'cmpg', 'cmpl', 'const', 'div', 'double', 'float', 'goto', 'if', 'int', 'long', 'move', 'mul', 'neg', 'new', 'nop', 'not', 'or', 'rem', 'return', 'shl', 'shr', 'sput', 'sub', 'throw', 'ushr', 'xor'];
  var smali_instr_high_prio = ['aget', 'aput', 'array', 'check', 'execute', 'fill', 'filled', 'goto/16', 'goto/32', 'iget', 'instance', 'invoke', 'iput', 'monitor', 'packed', 'sget', 'sparse'];
  var smali_keywords = ['transient', 'constructor', 'abstract', 'final', 'synthetic', 'public', 'private', 'protected', 'static', 'bridge', 'system'];
  return {
    aliases: ['smali'],
    contains: [
      {
        className: 'string',
        begin: '"', end: '"',
        relevance: 0
      },
      hljs.COMMENT(
        '#',
        '$',
        {
          relevance: 0
        }
      ),
      {
        className: 'keyword',
        begin: '\\s*\\.end\\s[a-zA-Z0-9]*',
        relevance: 1
      },
      {
        className: 'keyword',
        begin: '^[ ]*\\.[a-zA-Z]*',
        relevance: 0
      },
      {
        className: 'keyword',
        begin: '\\s:[a-zA-Z_0-9]*',
        relevance: 0
      },
      {
        className: 'keyword',
        begin: '\\s('+smali_keywords.join('|')+')',
        relevance: 1
      },
      {
        className: 'keyword',
        begin: '\\[',
        relevance: 0
      },
      {
        className: 'instruction',
        begin: '\\s('+smali_instr_low_prio.join('|')+')\\s',
        relevance: 1
      },
      {
        className: 'instruction',
        begin: '\\s('+smali_instr_low_prio.join('|')+')((\\-|/)[a-zA-Z0-9]+)+\\s',
        relevance: 10
      },
      {
        className: 'instruction',
        begin: '\\s('+smali_instr_high_prio.join('|')+')((\\-|/)[a-zA-Z0-9]+)*\\s',
        relevance: 10
      },
      {
        className: 'class',
        begin: 'L[^\(;:\n]*;',
        relevance: 0
      },
      {
        className: 'function',
        begin: '( |->)[^(\n ;"]*\\(',
        relevance: 0
      },
      {
        className: 'function',
        begin: '\\)',
        relevance: 0
      },
      {
        className: 'variable',
        begin: '[vp][0-9]+',
        relevance: 0
      }
    ]
  };
});

hljs.registerLanguage('smalltalk', function(hljs) {
  var VAR_IDENT_RE = '[a-z][a-zA-Z0-9_]*';
  var CHAR = {
    className: 'char',
    begin: '\\$.{1}'
  };
  var SYMBOL = {
    className: 'symbol',
    begin: '#' + hljs.UNDERSCORE_IDENT_RE
  };
  return {
    aliases: ['st'],
    keywords: 'self super nil true false thisContext', // only 6
    contains: [
      hljs.COMMENT('"', '"'),
      hljs.APOS_STRING_MODE,
      {
        className: 'class',
        begin: '\\b[A-Z][A-Za-z0-9_]*',
        relevance: 0
      },
      {
        className: 'method',
        begin: VAR_IDENT_RE + ':',
        relevance: 0
      },
      hljs.C_NUMBER_MODE,
      SYMBOL,
      CHAR,
      {
        className: 'localvars',
        // This looks more complicated than needed to avoid combinatorial
        // explosion under V8. It effectively means `| var1 var2 ... |` with
        // whitespace adjacent to `|` being optional.
        begin: '\\|[ ]*' + VAR_IDENT_RE + '([ ]+' + VAR_IDENT_RE + ')*[ ]*\\|',
        returnBegin: true, end: /\|/,
        illegal: /\S/,
        contains: [{begin: '(\\|[ ]*)?' + VAR_IDENT_RE}]
      },
      {
        className: 'array',
        begin: '\\#\\(', end: '\\)',
        contains: [
          hljs.APOS_STRING_MODE,
          CHAR,
          hljs.C_NUMBER_MODE,
          SYMBOL
        ]
      }
    ]
  };
});

hljs.registerLanguage('sml', function(hljs) {
  return {
    aliases: ['ml'],
    keywords: {
      keyword:
        /* according to Definition of Standard ML 97  */
        'abstype and andalso as case datatype do else end eqtype ' +
        'exception fn fun functor handle if in include infix infixr ' +
        'let local nonfix of op open orelse raise rec sharing sig ' +
        'signature struct structure then type val with withtype where while',
      built_in:
        /* built-in types according to basis library */
        'array bool char exn int list option order real ref string substring vector unit word',
      literal:
        'true false NONE SOME LESS EQUAL GREATER nil'
    },
    illegal: /\/\/|>>/,
    lexemes: '[a-z_]\\w*!?',
    contains: [
      {
        className: 'literal',
        begin: '\\[(\\|\\|)?\\]|\\(\\)'
      },
      hljs.COMMENT(
        '\\(\\*',
        '\\*\\)',
        {
          contains: ['self']
        }
      ),
      { /* type variable */
        className: 'symbol',
        begin: '\'[A-Za-z_](?!\')[\\w\']*'
        /* the grammar is ambiguous on how 'a'b should be interpreted but not the compiler */
      },
      { /* polymorphic variant */
        className: 'tag',
        begin: '`[A-Z][\\w\']*'
      },
      { /* module or constructor */
        className: 'type',
        begin: '\\b[A-Z][\\w\']*',
        relevance: 0
      },
      { /* don't color identifiers, but safely catch all identifiers with '*/
        begin: '[a-z_]\\w*\'[\\w\']*'
      },
      hljs.inherit(hljs.APOS_STRING_MODE, {className: 'char', relevance: 0}),
      hljs.inherit(hljs.QUOTE_STRING_MODE, {illegal: null}),
      {
        className: 'number',
        begin:
          '\\b(0[xX][a-fA-F0-9_]+[Lln]?|' +
          '0[oO][0-7_]+[Lln]?|' +
          '0[bB][01_]+[Lln]?|' +
          '[0-9][0-9_]*([Lln]|(\\.[0-9_]*)?([eE][-+]?[0-9_]+)?)?)',
        relevance: 0
      },
      {
        begin: /[-=]>/ // relevance booster
      }
    ]
  };
});

hljs.registerLanguage('sqf', function(hljs) {
  var allCommands = ['!', '-', '+', '!=', '%', '&&', '*', '/', '=', '==', '>', '>=', '<', '<=', 'or', 'plus', '^', ':', '>>', 'abs', 'accTime', 'acos', 'action', 'actionKeys', 'actionKeysImages', 'actionKeysNames', 'actionKeysNamesArray', 'actionName', 'activateAddons', 'activatedAddons', 'activateKey', 'addAction', 'addBackpack', 'addBackpackCargo', 'addBackpackCargoGlobal', 'addBackpackGlobal', 'addCamShake', 'addCuratorAddons', 'addCuratorCameraArea', 'addCuratorEditableObjects', 'addCuratorEditingArea', 'addCuratorPoints', 'addEditorObject', 'addEventHandler', 'addGoggles', 'addGroupIcon', 'addHandgunItem', 'addHeadgear', 'addItem', 'addItemCargo', 'addItemCargoGlobal', 'addItemPool', 'addItemToBackpack', 'addItemToUniform', 'addItemToVest', 'addLiveStats', 'addMagazine', 'addMagazine array', 'addMagazineAmmoCargo', 'addMagazineCargo', 'addMagazineCargoGlobal', 'addMagazineGlobal', 'addMagazinePool', 'addMagazines', 'addMagazineTurret', 'addMenu', 'addMenuItem', 'addMissionEventHandler', 'addMPEventHandler', 'addMusicEventHandler', 'addPrimaryWeaponItem', 'addPublicVariableEventHandler', 'addRating', 'addResources', 'addScore', 'addScoreSide', 'addSecondaryWeaponItem', 'addSwitchableUnit', 'addTeamMember', 'addToRemainsCollector', 'addUniform', 'addVehicle', 'addVest', 'addWaypoint', 'addWeapon', 'addWeaponCargo', 'addWeaponCargoGlobal', 'addWeaponGlobal', 'addWeaponPool', 'addWeaponTurret', 'agent', 'agents', 'AGLToASL', 'aimedAtTarget', 'aimPos', 'airDensityRTD', 'airportSide', 'AISFinishHeal', 'alive', 'allControls', 'allCurators', 'allDead', 'allDeadMen', 'allDisplays', 'allGroups', 'allMapMarkers', 'allMines', 'allMissionObjects', 'allow3DMode', 'allowCrewInImmobile', 'allowCuratorLogicIgnoreAreas', 'allowDamage', 'allowDammage', 'allowFileOperations', 'allowFleeing', 'allowGetIn', 'allPlayers', 'allSites', 'allTurrets', 'allUnits', 'allUnitsUAV', 'allVariables', 'ammo', 'and', 'animate', 'animateDoor', 'animationPhase', 'animationState', 'append', 'armoryPoints', 'arrayIntersect', 'asin', 'ASLToAGL', 'ASLToATL', 'assert', 'assignAsCargo', 'assignAsCargoIndex', 'assignAsCommander', 'assignAsDriver', 'assignAsGunner', 'assignAsTurret', 'assignCurator', 'assignedCargo', 'assignedCommander', 'assignedDriver', 'assignedGunner', 'assignedItems', 'assignedTarget', 'assignedTeam', 'assignedVehicle', 'assignedVehicleRole', 'assignItem', 'assignTeam', 'assignToAirport', 'atan', 'atan2', 'atg', 'ATLToASL', 'attachedObject', 'attachedObjects', 'attachedTo', 'attachObject', 'attachTo', 'attackEnabled', 'backpack', 'backpackCargo', 'backpackContainer', 'backpackItems', 'backpackMagazines', 'backpackSpaceFor', 'behaviour', 'benchmark', 'binocular', 'blufor', 'boundingBox', 'boundingBoxReal', 'boundingCenter', 'breakOut', 'breakTo', 'briefingName', 'buildingExit', 'buildingPos', 'buttonAction', 'buttonSetAction', 'cadetMode', 'call', 'callExtension', 'camCommand', 'camCommit', 'camCommitPrepared', 'camCommitted', 'camConstuctionSetParams', 'camCreate', 'camDestroy', 'cameraEffect', 'cameraEffectEnableHUD', 'cameraInterest', 'cameraOn', 'cameraView', 'campaignConfigFile', 'camPreload', 'camPreloaded', 'camPrepareBank', 'camPrepareDir', 'camPrepareDive', 'camPrepareFocus', 'camPrepareFov', 'camPrepareFovRange', 'camPreparePos', 'camPrepareRelPos', 'camPrepareTarget', 'camSetBank', 'camSetDir', 'camSetDive', 'camSetFocus', 'camSetFov', 'camSetFovRange', 'camSetPos', 'camSetRelPos', 'camSetTarget', 'camTarget', 'camUseNVG', 'canAdd', 'canAddItemToBackpack', 'canAddItemToUniform', 'canAddItemToVest', 'cancelSimpleTaskDestination', 'canFire', 'canMove', 'canSlingLoad', 'canStand', 'canUnloadInCombat', 'captive', 'captiveNum', 'case', 'catch', 'cbChecked', 'cbSetChecked', 'ceil', 'cheatsEnabled', 'checkAIFeature', 'civilian', 'className', 'clearAllItemsFromBackpack', 'clearBackpackCargo', 'clearBackpackCargoGlobal', 'clearGroupIcons', 'clearItemCargo', 'clearItemCargoGlobal', 'clearItemPool', 'clearMagazineCargo', 'clearMagazineCargoGlobal', 'clearMagazinePool', 'clearOverlay', 'clearRadio', 'clearWeaponCargo', 'clearWeaponCargoGlobal', 'clearWeaponPool', 'closeDialog', 'closeDisplay', 'closeOverlay', 'collapseObjectTree', 'combatMode', 'commandArtilleryFire', 'commandChat', 'commander', 'commandFire', 'commandFollow', 'commandFSM', 'commandGetOut', 'commandingMenu', 'commandMove', 'commandRadio', 'commandStop', 'commandTarget', 'commandWatch', 'comment', 'commitOverlay', 'compile', 'compileFinal', 'completedFSM', 'composeText', 'configClasses', 'configFile', 'configHierarchy', 'configName', 'configProperties', 'configSourceMod', 'configSourceModList', 'connectTerminalToUAV', 'controlNull', 'controlsGroupCtrl', 'copyFromClipboard', 'copyToClipboard', 'copyWaypoints', 'cos', 'count', 'countEnemy', 'countFriendly', 'countSide', 'countType', 'countUnknown', 'createAgent', 'createCenter', 'createDialog', 'createDiaryLink', 'createDiaryRecord', 'createDiarySubject', 'createDisplay', 'createGearDialog', 'createGroup', 'createGuardedPoint', 'createLocation', 'createMarker', 'createMarkerLocal', 'createMenu', 'createMine', 'createMissionDisplay', 'createSimpleTask', 'createSite', 'createSoundSource', 'createTask', 'createTeam', 'createTrigger', 'createUnit', 'createUnit array', 'createVehicle', 'createVehicle array', 'createVehicleCrew', 'createVehicleLocal', 'crew', 'ctrlActivate', 'ctrlAddEventHandler', 'ctrlAutoScrollDelay', 'ctrlAutoScrollRewind', 'ctrlAutoScrollSpeed', 'ctrlChecked', 'ctrlClassName', 'ctrlCommit', 'ctrlCommitted', 'ctrlCreate', 'ctrlDelete', 'ctrlEnable', 'ctrlEnabled', 'ctrlFade', 'ctrlHTMLLoaded', 'ctrlIDC', 'ctrlIDD', 'ctrlMapAnimAdd', 'ctrlMapAnimClear', 'ctrlMapAnimCommit', 'ctrlMapAnimDone', 'ctrlMapCursor', 'ctrlMapMouseOver', 'ctrlMapScale', 'ctrlMapScreenToWorld', 'ctrlMapWorldToScreen', 'ctrlModel', 'ctrlModelDirAndUp', 'ctrlModelScale', 'ctrlParent', 'ctrlPosition', 'ctrlRemoveAllEventHandlers', 'ctrlRemoveEventHandler', 'ctrlScale', 'ctrlSetActiveColor', 'ctrlSetAutoScrollDelay', 'ctrlSetAutoScrollRewind', 'ctrlSetAutoScrollSpeed', 'ctrlSetBackgroundColor', 'ctrlSetChecked', 'ctrlSetEventHandler', 'ctrlSetFade', 'ctrlSetFocus', 'ctrlSetFont', 'ctrlSetFontH1', 'ctrlSetFontH1B', 'ctrlSetFontH2', 'ctrlSetFontH2B', 'ctrlSetFontH3', 'ctrlSetFontH3B', 'ctrlSetFontH4', 'ctrlSetFontH4B', 'ctrlSetFontH5', 'ctrlSetFontH5B', 'ctrlSetFontH6', 'ctrlSetFontH6B', 'ctrlSetFontHeight', 'ctrlSetFontHeightH1', 'ctrlSetFontHeightH2', 'ctrlSetFontHeightH3', 'ctrlSetFontHeightH4', 'ctrlSetFontHeightH5', 'ctrlSetFontHeightH6', 'ctrlSetFontP', 'ctrlSetFontPB', 'ctrlSetForegroundColor', 'ctrlSetModel', 'ctrlSetModelDirAndUp', 'ctrlSetModelScale', 'ctrlSetPosition', 'ctrlSetScale', 'ctrlSetStructuredText', 'ctrlSetText', 'ctrlSetTextColor', 'ctrlSetTooltip', 'ctrlSetTooltipColorBox', 'ctrlSetTooltipColorShade', 'ctrlSetTooltipColorText', 'ctrlShow', 'ctrlShown', 'ctrlText', 'ctrlTextHeight', 'ctrlType', 'ctrlVisible', 'curatorAddons', 'curatorCamera', 'curatorCameraArea', 'curatorCameraAreaCeiling', 'curatorCoef', 'curatorEditableObjects', 'curatorEditingArea', 'curatorEditingAreaType', 'curatorMouseOver', 'curatorPoints', 'curatorRegisteredObjects', 'curatorSelected', 'curatorWaypointCost', 'currentChannel', 'currentCommand', 'currentMagazine', 'currentMagazineDetail', 'currentMagazineDetailTurret', 'currentMagazineTurret', 'currentMuzzle', 'currentNamespace', 'currentTask', 'currentTasks', 'currentThrowable', 'currentVisionMode', 'currentWaypoint', 'currentWeapon', 'currentWeaponMode', 'currentWeaponTurret', 'currentZeroing', 'cursorTarget', 'customChat', 'customRadio', 'cutFadeOut', 'cutObj', 'cutRsc', 'cutText', 'damage', 'date', 'dateToNumber', 'daytime', 'deActivateKey', 'debriefingText', 'debugFSM', 'debugLog', 'default', 'deg', 'deleteAt', 'deleteCenter', 'deleteCollection', 'deleteEditorObject', 'deleteGroup', 'deleteIdentity', 'deleteLocation', 'deleteMarker', 'deleteMarkerLocal', 'deleteRange', 'deleteResources', 'deleteSite', 'deleteStatus', 'deleteTeam', 'deleteVehicle', 'deleteVehicleCrew', 'deleteWaypoint', 'detach', 'detectedMines', 'diag activeMissionFSMs', 'diag activeSQFScripts', 'diag activeSQSScripts', 'diag captureFrame', 'diag captureSlowFrame', 'diag fps', 'diag fpsMin', 'diag frameNo', 'diag log', 'diag logSlowFrame', 'diag tickTime', 'dialog', 'diarySubjectExists', 'didJIP', 'didJIPOwner', 'difficulty', 'difficultyEnabled', 'difficultyEnabledRTD', 'direction', 'directSay', 'disableAI', 'disableCollisionWith', 'disableConversation', 'disableDebriefingStats', 'disableSerialization', 'disableTIEquipment', 'disableUAVConnectability', 'disableUserInput', 'displayAddEventHandler', 'displayCtrl', 'displayNull', 'displayRemoveAllEventHandlers', 'displayRemoveEventHandler', 'displaySetEventHandler', 'dissolveTeam', 'distance', 'distance2D', 'distanceSqr', 'distributionRegion', 'do', 'doArtilleryFire', 'doFire', 'doFollow', 'doFSM', 'doGetOut', 'doMove', 'doorPhase', 'doStop', 'doTarget', 'doWatch', 'drawArrow', 'drawEllipse', 'drawIcon', 'drawIcon3D', 'drawLine', 'drawLine3D', 'drawLink', 'drawLocation', 'drawRectangle', 'driver', 'drop', 'east', 'echo', 'editObject', 'editorSetEventHandler', 'effectiveCommander', 'else', 'emptyPositions', 'enableAI', 'enableAIFeature', 'enableAttack', 'enableCamShake', 'enableCaustics', 'enableCollisionWith', 'enableCopilot', 'enableDebriefingStats', 'enableDiagLegend', 'enableEndDialog', 'enableEngineArtillery', 'enableEnvironment', 'enableFatigue', 'enableGunLights', 'enableIRLasers', 'enableMimics', 'enablePersonTurret', 'enableRadio', 'enableReload', 'enableRopeAttach', 'enableSatNormalOnDetail', 'enableSaving', 'enableSentences', 'enableSimulation', 'enableSimulationGlobal', 'enableTeamSwitch', 'enableUAVConnectability', 'enableUAVWaypoints', 'endLoadingScreen', 'endMission', 'engineOn', 'enginesIsOnRTD', 'enginesRpmRTD', 'enginesTorqueRTD', 'entities', 'estimatedEndServerTime', 'estimatedTimeLeft', 'evalObjectArgument', 'everyBackpack', 'everyContainer', 'exec', 'execEditorScript', 'execFSM', 'execVM', 'exit', 'exitWith', 'exp', 'expectedDestination', 'eyeDirection', 'eyePos', 'face', 'faction', 'fadeMusic', 'fadeRadio', 'fadeSound', 'fadeSpeech', 'failMission', 'false', 'fillWeaponsFromPool', 'find', 'findCover', 'findDisplay', 'findEditorObject', 'findEmptyPosition', 'findEmptyPositionReady', 'findNearestEnemy', 'finishMissionInit', 'finite', 'fire', 'fireAtTarget', 'firstBackpack', 'flag', 'flagOwner', 'fleeing', 'floor', 'flyInHeight', 'fog', 'fogForecast', 'fogParams', 'for', 'forceAddUniform', 'forceEnd', 'forceMap', 'forceRespawn', 'forceSpeed', 'forceWalk', 'forceWeaponFire', 'forceWeatherChange', 'forEach', 'forEachMember', 'forEachMemberAgent', 'forEachMemberTeam', 'format', 'formation', 'formationDirection', 'formationLeader', 'formationMembers', 'formationPosition', 'formationTask', 'formatText', 'formLeader', 'freeLook', 'from', 'fromEditor', 'fuel', 'fullCrew', 'gearSlotAmmoCount', 'gearSlotData', 'getAllHitPointsDamage', 'getAmmoCargo', 'getArray', 'getArtilleryAmmo', 'getArtilleryComputerSettings', 'getArtilleryETA', 'getAssignedCuratorLogic', 'getAssignedCuratorUnit', 'getBackpackCargo', 'getBleedingRemaining', 'getBurningValue', 'getCargoIndex', 'getCenterOfMass', 'getClientState', 'getConnectedUAV', 'getDammage', 'getDescription', 'getDir', 'getDirVisual', 'getDLCs', 'getEditorCamera', 'getEditorMode', 'getEditorObjectScope', 'getElevationOffset', 'getFatigue', 'getFriend', 'getFSMVariable', 'getFuelCargo', 'getGroupIcon', 'getGroupIconParams', 'getGroupIcons', 'getHideFrom', 'getHit', 'getHitIndex', 'getHitPointDamage', 'getItemCargo', 'getMagazineCargo', 'getMarkerColor', 'getMarkerPos', 'getMarkerSize', 'getMarkerType', 'getMass', 'getModelInfo', 'getNumber', 'getObjectArgument', 'getObjectChildren', 'getObjectDLC', 'getObjectMaterials', 'getObjectProxy', 'getObjectTextures', 'getObjectType', 'getObjectViewDistance', 'getOxygenRemaining', 'getPersonUsedDLCs', 'getPlayerChannel', 'getPlayerUID', 'getPos', 'getPosASL', 'getPosASLVisual', 'getPosASLW', 'getPosATL', 'getPosATLVisual', 'getPosVisual', 'getPosWorld', 'getRepairCargo', 'getResolution', 'getShadowDistance', 'getSlingLoad', 'getSpeed', 'getSuppression', 'getTerrainHeightASL', 'getText', 'getVariable', 'getWeaponCargo', 'getWPPos', 'glanceAt', 'globalChat', 'globalRadio', 'goggles', 'goto', 'group', 'groupChat', 'groupFromNetId', 'groupIconSelectable', 'groupIconsVisible', 'groupId', 'groupOwner', 'groupRadio', 'groupSelectedUnits', 'groupSelectUnit', 'grpNull', 'gunner', 'gusts', 'halt', 'handgunItems', 'handgunMagazine', 'handgunWeapon', 'handsHit', 'hasInterface', 'hasWeapon', 'hcAllGroups', 'hcGroupParams', 'hcLeader', 'hcRemoveAllGroups', 'hcRemoveGroup', 'hcSelected', 'hcSelectGroup', 'hcSetGroup', 'hcShowBar', 'hcShownBar', 'headgear', 'hideBody', 'hideObject', 'hideObjectGlobal', 'hint', 'hintC', 'hintCadet', 'hintSilent', 'hmd', 'hostMission', 'htmlLoad', 'HUDMovementLevels', 'humidity', 'if', 'image', 'importAllGroups', 'importance', 'in', 'incapacitatedState', 'independent', 'inflame', 'inflamed', 'inGameUISetEventHandler', 'inheritsFrom', 'initAmbientLife', 'inputAction', 'inRangeOfArtillery', 'insertEditorObject', 'intersect', 'isAbleToBreathe', 'isAgent', 'isArray', 'isAutoHoverOn', 'isAutonomous', 'isAutotest', 'isBleeding', 'isBurning', 'isClass', 'isCollisionLightOn', 'isCopilotEnabled', 'isDedicated', 'isDLCAvailable', 'isEngineOn', 'isEqualTo', 'isFlashlightOn', 'isFlatEmpty', 'isForcedWalk', 'isFormationLeader', 'isHidden', 'isInRemainsCollector', 'isInstructorFigureEnabled', 'isIRLaserOn', 'isKeyActive', 'isKindOf', 'isLightOn', 'isLocalized', 'isManualFire', 'isMarkedForCollection', 'isMultiplayer', 'isNil', 'isNull', 'isNumber', 'isObjectHidden', 'isObjectRTD', 'isOnRoad', 'isPipEnabled', 'isPlayer', 'isRealTime', 'isServer', 'isShowing3DIcons', 'isSteamMission', 'isStreamFriendlyUIEnabled', 'isText', 'isTouchingGround', 'isTurnedOut', 'isTutHintsEnabled', 'isUAVConnectable', 'isUAVConnected', 'isUniformAllowed', 'isWalking', 'isWeaponDeployed', 'isWeaponRested', 'itemCargo', 'items', 'itemsWithMagazines', 'join', 'joinAs', 'joinAsSilent', 'joinSilent', 'joinString', 'kbAddDatabase', 'kbAddDatabaseTargets', 'kbAddTopic', 'kbHasTopic', 'kbReact', 'kbRemoveTopic', 'kbTell', 'kbWasSaid', 'keyImage', 'keyName', 'knowsAbout', 'land', 'landAt', 'landResult', 'language', 'laserTarget', 'lbAdd', 'lbClear', 'lbColor', 'lbCurSel', 'lbData', 'lbDelete', 'lbIsSelected', 'lbPicture', 'lbSelection', 'lbSetColor', 'lbSetCurSel', 'lbSetData', 'lbSetPicture', 'lbSetPictureColor', 'lbSetPictureColorDisabled', 'lbSetPictureColorSelected', 'lbSetSelectColor', 'lbSetSelectColorRight', 'lbSetSelected', 'lbSetTooltip', 'lbSetValue', 'lbSize', 'lbSort', 'lbSortByValue', 'lbText', 'lbValue', 'leader', 'leaderboardDeInit', 'leaderboardGetRows', 'leaderboardInit', 'leaveVehicle', 'libraryCredits', 'libraryDisclaimers', 'lifeState', 'lightAttachObject', 'lightDetachObject', 'lightIsOn', 'lightnings', 'limitSpeed', 'linearConversion', 'lineBreak', 'lineIntersects', 'lineIntersectsObjs', 'lineIntersectsSurfaces', 'lineIntersectsWith', 'linkItem', 'list', 'listObjects', 'ln', 'lnbAddArray', 'lnbAddColumn', 'lnbAddRow', 'lnbClear', 'lnbColor', 'lnbCurSelRow', 'lnbData', 'lnbDeleteColumn', 'lnbDeleteRow', 'lnbGetColumnsPosition', 'lnbPicture', 'lnbSetColor', 'lnbSetColumnsPos', 'lnbSetCurSelRow', 'lnbSetData', 'lnbSetPicture', 'lnbSetText', 'lnbSetValue', 'lnbSize', 'lnbText', 'lnbValue', 'load', 'loadAbs', 'loadBackpack', 'loadFile', 'loadGame', 'loadIdentity', 'loadMagazine', 'loadOverlay', 'loadStatus', 'loadUniform', 'loadVest', 'local', 'localize', 'locationNull', 'locationPosition', 'lock', 'lockCameraTo', 'lockCargo', 'lockDriver', 'locked', 'lockedCargo', 'lockedDriver', 'lockedTurret', 'lockTurret', 'lockWP', 'log', 'logEntities', 'lookAt', 'lookAtPos', 'magazineCargo', 'magazines', 'magazinesAllTurrets', 'magazinesAmmo', 'magazinesAmmoCargo', 'magazinesAmmoFull', 'magazinesDetail', 'magazinesDetailBackpack', 'magazinesDetailUniform', 'magazinesDetailVest', 'magazinesTurret', 'magazineTurretAmmo', 'mapAnimAdd', 'mapAnimClear', 'mapAnimCommit', 'mapAnimDone', 'mapCenterOnCamera', 'mapGridPosition', 'markAsFinishedOnSteam', 'markerAlpha', 'markerBrush', 'markerColor', 'markerDir', 'markerPos', 'markerShape', 'markerSize', 'markerText', 'markerType', 'max', 'members', 'min', 'mineActive', 'mineDetectedBy', 'missionConfigFile', 'missionName', 'missionNamespace', 'missionStart', 'mod', 'modelToWorld', 'modelToWorldVisual', 'moonIntensity', 'morale', 'move', 'moveInAny', 'moveInCargo', 'moveInCommander', 'moveInDriver', 'moveInGunner', 'moveInTurret', 'moveObjectToEnd', 'moveOut', 'moveTime', 'moveTo', 'moveToCompleted', 'moveToFailed', 'musicVolume', 'name', 'name location', 'nameSound', 'nearEntities', 'nearestBuilding', 'nearestLocation', 'nearestLocations', 'nearestLocationWithDubbing', 'nearestObject', 'nearestObjects', 'nearObjects', 'nearObjectsReady', 'nearRoads', 'nearSupplies', 'nearTargets', 'needReload', 'netId', 'netObjNull', 'newOverlay', 'nextMenuItemIndex', 'nextWeatherChange', 'nil', 'nMenuItems', 'not', 'numberToDate', 'objectCurators', 'objectFromNetId', 'objectParent', 'objNull', 'objStatus', 'onBriefingGroup', 'onBriefingNotes', 'onBriefingPlan', 'onBriefingTeamSwitch', 'onCommandModeChanged', 'onDoubleClick', 'onEachFrame', 'onGroupIconClick', 'onGroupIconOverEnter', 'onGroupIconOverLeave', 'onHCGroupSelectionChanged', 'onMapSingleClick', 'onPlayerConnected', 'onPlayerDisconnected', 'onPreloadFinished', 'onPreloadStarted', 'onShowNewObject', 'onTeamSwitch', 'openCuratorInterface', 'openMap', 'openYoutubeVideo', 'opfor', 'or', 'orderGetIn', 'overcast', 'overcastForecast', 'owner', 'param', 'params', 'parseNumber', 'parseText', 'parsingNamespace', 'particlesQuality', 'pi', 'pickWeaponPool', 'pitch', 'playableSlotsNumber', 'playableUnits', 'playAction', 'playActionNow', 'player', 'playerRespawnTime', 'playerSide', 'playersNumber', 'playGesture', 'playMission', 'playMove', 'playMoveNow', 'playMusic', 'playScriptedMission', 'playSound', 'playSound3D', 'position', 'positionCameraToWorld', 'posScreenToWorld', 'posWorldToScreen', 'ppEffectAdjust', 'ppEffectCommit', 'ppEffectCommitted', 'ppEffectCreate', 'ppEffectDestroy', 'ppEffectEnable', 'ppEffectForceInNVG', 'precision', 'preloadCamera', 'preloadObject', 'preloadSound', 'preloadTitleObj', 'preloadTitleRsc', 'preprocessFile', 'preprocessFileLineNumbers', 'primaryWeapon', 'primaryWeaponItems', 'primaryWeaponMagazine', 'priority', 'private', 'processDiaryLink', 'productVersion', 'profileName', 'profileNamespace', 'profileNameSteam', 'progressLoadingScreen', 'progressPosition', 'progressSetPosition', 'publicVariable', 'publicVariableClient', 'publicVariableServer', 'pushBack', 'putWeaponPool', 'queryItemsPool', 'queryMagazinePool', 'queryWeaponPool', 'rad', 'radioChannelAdd', 'radioChannelCreate', 'radioChannelRemove', 'radioChannelSetCallSign', 'radioChannelSetLabel', 'radioVolume', 'rain', 'rainbow', 'random', 'rank', 'rankId', 'rating', 'rectangular', 'registeredTasks', 'registerTask', 'reload', 'reloadEnabled', 'remoteControl', 'remoteExec', 'remoteExecCall', 'removeAction', 'removeAllActions', 'removeAllAssignedItems', 'removeAllContainers', 'removeAllCuratorAddons', 'removeAllCuratorCameraAreas', 'removeAllCuratorEditingAreas', 'removeAllEventHandlers', 'removeAllHandgunItems', 'removeAllItems', 'removeAllItemsWithMagazines', 'removeAllMissionEventHandlers', 'removeAllMPEventHandlers', 'removeAllMusicEventHandlers', 'removeAllPrimaryWeaponItems', 'removeAllWeapons', 'removeBackpack', 'removeBackpackGlobal', 'removeCuratorAddons', 'removeCuratorCameraArea', 'removeCuratorEditableObjects', 'removeCuratorEditingArea', 'removeDrawIcon', 'removeDrawLinks', 'removeEventHandler', 'removeFromRemainsCollector', 'removeGoggles', 'removeGroupIcon', 'removeHandgunItem', 'removeHeadgear', 'removeItem', 'removeItemFromBackpack', 'removeItemFromUniform', 'removeItemFromVest', 'removeItems', 'removeMagazine', 'removeMagazineGlobal', 'removeMagazines', 'removeMagazinesTurret', 'removeMagazineTurret', 'removeMenuItem', 'removeMissionEventHandler', 'removeMPEventHandler', 'removeMusicEventHandler', 'removePrimaryWeaponItem', 'removeSecondaryWeaponItem', 'removeSimpleTask', 'removeSwitchableUnit', 'removeTeamMember', 'removeUniform', 'removeVest', 'removeWeapon', 'removeWeaponGlobal', 'removeWeaponTurret', 'requiredVersion', 'resetCamShake', 'resetSubgroupDirection', 'resistance', 'resize', 'resources', 'respawnVehicle', 'restartEditorCamera', 'reveal', 'revealMine', 'reverse', 'reversedMouseY', 'roadsConnectedTo', 'roleDescription', 'ropeAttachedObjects', 'ropeAttachedTo', 'ropeAttachEnabled', 'ropeAttachTo', 'ropeCreate', 'ropeCut', 'ropeEndPosition', 'ropeLength', 'ropes', 'ropeUnwind', 'ropeUnwound', 'rotorsForcesRTD', 'rotorsRpmRTD', 'round', 'runInitScript', 'safeZoneH', 'safeZoneW', 'safeZoneWAbs', 'safeZoneX', 'safeZoneXAbs', 'safeZoneY', 'saveGame', 'saveIdentity', 'saveJoysticks', 'saveOverlay', 'saveProfileNamespace', 'saveStatus', 'saveVar', 'savingEnabled', 'say', 'say2D', 'say3D', 'scopeName', 'score', 'scoreSide', 'screenToWorld', 'scriptDone', 'scriptName', 'scriptNull', 'scudState', 'secondaryWeapon', 'secondaryWeaponItems', 'secondaryWeaponMagazine', 'select', 'selectBestPlaces', 'selectDiarySubject', 'selectedEditorObjects', 'selectEditorObject', 'selectionPosition', 'selectLeader', 'selectNoPlayer', 'selectPlayer', 'selectWeapon', 'selectWeaponTurret', 'sendAUMessage', 'sendSimpleCommand', 'sendTask', 'sendTaskResult', 'sendUDPMessage', 'serverCommand', 'serverCommandAvailable', 'serverCommandExecutable', 'serverName', 'serverTime', 'set', 'setAccTime', 'setAirportSide', 'setAmmo', 'setAmmoCargo', 'setAperture', 'setApertureNew', 'setArmoryPoints', 'setAttributes', 'setAutonomous', 'setBehaviour', 'setBleedingRemaining', 'setCameraInterest', 'setCamShakeDefParams', 'setCamShakeParams', 'setCamUseTi', 'setCaptive', 'setCenterOfMass', 'setCollisionLight', 'setCombatMode', 'setCompassOscillation', 'setCuratorCameraAreaCeiling', 'setCuratorCoef', 'setCuratorEditingAreaType', 'setCuratorWaypointCost', 'setCurrentChannel', 'setCurrentTask', 'setCurrentWaypoint', 'setDamage', 'setDammage', 'setDate', 'setDebriefingText', 'setDefaultCamera', 'setDestination', 'setDetailMapBlendPars', 'setDir', 'setDirection', 'setDrawIcon', 'setDropInterval', 'setEditorMode', 'setEditorObjectScope', 'setEffectCondition', 'setFace', 'setFaceAnimation', 'setFatigue', 'setFlagOwner', 'setFlagSide', 'setFlagTexture', 'setFog', 'setFog array', 'setFormation', 'setFormationTask', 'setFormDir', 'setFriend', 'setFromEditor', 'setFSMVariable', 'setFuel', 'setFuelCargo', 'setGroupIcon', 'setGroupIconParams', 'setGroupIconsSelectable', 'setGroupIconsVisible', 'setGroupId', 'setGroupIdGlobal', 'setGroupOwner', 'setGusts', 'setHideBehind', 'setHit', 'setHitIndex', 'setHitPointDamage', 'setHorizonParallaxCoef', 'setHUDMovementLevels', 'setIdentity', 'setImportance', 'setLeader', 'setLightAmbient', 'setLightAttenuation', 'setLightBrightness', 'setLightColor', 'setLightDayLight', 'setLightFlareMaxDistance', 'setLightFlareSize', 'setLightIntensity', 'setLightnings', 'setLightUseFlare', 'setLocalWindParams', 'setMagazineTurretAmmo', 'setMarkerAlpha', 'setMarkerAlphaLocal', 'setMarkerBrush', 'setMarkerBrushLocal', 'setMarkerColor', 'setMarkerColorLocal', 'setMarkerDir', 'setMarkerDirLocal', 'setMarkerPos', 'setMarkerPosLocal', 'setMarkerShape', 'setMarkerShapeLocal', 'setMarkerSize', 'setMarkerSizeLocal', 'setMarkerText', 'setMarkerTextLocal', 'setMarkerType', 'setMarkerTypeLocal', 'setMass', 'setMimic', 'setMousePosition', 'setMusicEffect', 'setMusicEventHandler', 'setName', 'setNameSound', 'setObjectArguments', 'setObjectMaterial', 'setObjectProxy', 'setObjectTexture', 'setObjectTextureGlobal', 'setObjectViewDistance', 'setOvercast', 'setOwner', 'setOxygenRemaining', 'setParticleCircle', 'setParticleClass', 'setParticleFire', 'setParticleParams', 'setParticleRandom', 'setPilotLight', 'setPiPEffect', 'setPitch', 'setPlayable', 'setPlayerRespawnTime', 'setPos', 'setPosASL', 'setPosASL2', 'setPosASLW', 'setPosATL', 'setPosition', 'setPosWorld', 'setRadioMsg', 'setRain', 'setRainbow', 'setRandomLip', 'setRank', 'setRectangular', 'setRepairCargo', 'setShadowDistance', 'setSide', 'setSimpleTaskDescription', 'setSimpleTaskDestination', 'setSimpleTaskTarget', 'setSimulWeatherLayers', 'setSize', 'setSkill', 'setSkill array', 'setSlingLoad', 'setSoundEffect', 'setSpeaker', 'setSpeech', 'setSpeedMode', 'setStatValue', 'setSuppression', 'setSystemOfUnits', 'setTargetAge', 'setTaskResult', 'setTaskState', 'setTerrainGrid', 'setText', 'setTimeMultiplier', 'setTitleEffect', 'setTriggerActivation', 'setTriggerArea', 'setTriggerStatements', 'setTriggerText', 'setTriggerTimeout', 'setTriggerType', 'setType', 'setUnconscious', 'setUnitAbility', 'setUnitPos', 'setUnitPosWeak', 'setUnitRank', 'setUnitRecoilCoefficient', 'setUnloadInCombat', 'setUserActionText', 'setVariable', 'setVectorDir', 'setVectorDirAndUp', 'setVectorUp', 'setVehicleAmmo', 'setVehicleAmmoDef', 'setVehicleArmor', 'setVehicleId', 'setVehicleLock', 'setVehiclePosition', 'setVehicleTiPars', 'setVehicleVarName', 'setVelocity', 'setVelocityTransformation', 'setViewDistance', 'setVisibleIfTreeCollapsed', 'setWaves', 'setWaypointBehaviour', 'setWaypointCombatMode', 'setWaypointCompletionRadius', 'setWaypointDescription', 'setWaypointFormation', 'setWaypointHousePosition', 'setWaypointLoiterRadius', 'setWaypointLoiterType', 'setWaypointName', 'setWaypointPosition', 'setWaypointScript', 'setWaypointSpeed', 'setWaypointStatements', 'setWaypointTimeout', 'setWaypointType', 'setWaypointVisible', 'setWeaponReloadingTime', 'setWind', 'setWindDir', 'setWindForce', 'setWindStr', 'setWPPos', 'show3DIcons', 'showChat', 'showCinemaBorder', 'showCommandingMenu', 'showCompass', 'showCuratorCompass', 'showGPS', 'showHUD', 'showLegend', 'showMap', 'shownArtilleryComputer', 'shownChat', 'shownCompass', 'shownCuratorCompass', 'showNewEditorObject', 'shownGPS', 'shownHUD', 'shownMap', 'shownPad', 'shownRadio', 'shownUAVFeed', 'shownWarrant', 'shownWatch', 'showPad', 'showRadio', 'showSubtitles', 'showUAVFeed', 'showWarrant', 'showWatch', 'showWaypoint', 'side', 'sideChat', 'sideEnemy', 'sideFriendly', 'sideLogic', 'sideRadio', 'sideUnknown', 'simpleTasks', 'simulationEnabled', 'simulCloudDensity', 'simulCloudOcclusion', 'simulInClouds', 'simulWeatherSync', 'sin', 'size', 'sizeOf', 'skill', 'skillFinal', 'skipTime', 'sleep', 'sliderPosition', 'sliderRange', 'sliderSetPosition', 'sliderSetRange', 'sliderSetSpeed', 'sliderSpeed', 'slingLoadAssistantShown', 'soldierMagazines', 'someAmmo', 'sort', 'soundVolume', 'spawn', 'speaker', 'speed', 'speedMode', 'splitString', 'sqrt', 'squadParams', 'stance', 'startLoadingScreen', 'step', 'stop', 'stopped', 'str', 'sunOrMoon', 'supportInfo', 'suppressFor', 'surfaceIsWater', 'surfaceNormal', 'surfaceType', 'swimInDepth', 'switch', 'switchableUnits', 'switchAction', 'switchCamera', 'switchGesture', 'switchLight', 'switchMove', 'synchronizedObjects', 'synchronizedTriggers', 'synchronizedWaypoints', 'synchronizeObjectsAdd', 'synchronizeObjectsRemove', 'synchronizeTrigger', 'synchronizeWaypoint', 'synchronizeWaypoint trigger', 'systemChat', 'systemOfUnits', 'tan', 'targetKnowledge', 'targetsAggregate', 'targetsQuery', 'taskChildren', 'taskCompleted', 'taskDescription', 'taskDestination', 'taskHint', 'taskNull', 'taskParent', 'taskResult', 'taskState', 'teamMember', 'teamMemberNull', 'teamName', 'teams', 'teamSwitch', 'teamSwitchEnabled', 'teamType', 'terminate', 'terrainIntersect', 'terrainIntersectASL', 'text', 'text location', 'textLog', 'textLogFormat', 'tg', 'then', 'throw', 'time', 'timeMultiplier', 'titleCut', 'titleFadeOut', 'titleObj', 'titleRsc', 'titleText', 'to', 'toArray', 'toLower', 'toString', 'toUpper', 'triggerActivated', 'triggerActivation', 'triggerArea', 'triggerAttachedVehicle', 'triggerAttachObject', 'triggerAttachVehicle', 'triggerStatements', 'triggerText', 'triggerTimeout', 'triggerTimeoutCurrent', 'triggerType', 'true', 'try', 'turretLocal', 'turretOwner', 'turretUnit', 'tvAdd', 'tvClear', 'tvCollapse', 'tvCount', 'tvCurSel', 'tvData', 'tvDelete', 'tvExpand', 'tvPicture', 'tvSetCurSel', 'tvSetData', 'tvSetPicture', 'tvSetPictureColor', 'tvSetTooltip', 'tvSetValue', 'tvSort', 'tvSortByValue', 'tvText', 'tvValue', 'type', 'typeName', 'typeOf', 'UAVControl', 'uiNamespace', 'uiSleep', 'unassignCurator', 'unassignItem', 'unassignTeam', 'unassignVehicle', 'underwater', 'uniform', 'uniformContainer', 'uniformItems', 'uniformMagazines', 'unitAddons', 'unitBackpack', 'unitPos', 'unitReady', 'unitRecoilCoefficient', 'units', 'unitsBelowHeight', 'unlinkItem', 'unlockAchievement', 'unregisterTask', 'updateDrawIcon', 'updateMenuItem', 'updateObjectTree', 'useAudioTimeForMoves', 'vectorAdd', 'vectorCos', 'vectorCrossProduct', 'vectorDiff', 'vectorDir', 'vectorDirVisual', 'vectorDistance', 'vectorDistanceSqr', 'vectorDotProduct', 'vectorFromTo', 'vectorMagnitude', 'vectorMagnitudeSqr', 'vectorMultiply', 'vectorNormalized', 'vectorUp', 'vectorUpVisual', 'vehicle', 'vehicleChat', 'vehicleRadio', 'vehicles', 'vehicleVarName', 'velocity', 'velocityModelSpace', 'verifySignature', 'vest', 'vestContainer', 'vestItems', 'vestMagazines', 'viewDistance', 'visibleCompass', 'visibleGPS', 'visibleMap', 'visiblePosition', 'visiblePositionASL', 'visibleWatch', 'waitUntil', 'waves', 'waypointAttachedObject', 'waypointAttachedVehicle', 'waypointAttachObject', 'waypointAttachVehicle', 'waypointBehaviour', 'waypointCombatMode', 'waypointCompletionRadius', 'waypointDescription', 'waypointFormation', 'waypointHousePosition', 'waypointLoiterRadius', 'waypointLoiterType', 'waypointName', 'waypointPosition', 'waypoints', 'waypointScript', 'waypointsEnabledUAV', 'waypointShow', 'waypointSpeed', 'waypointStatements', 'waypointTimeout', 'waypointTimeoutCurrent', 'waypointType', 'waypointVisible', 'weaponAccessories', 'weaponCargo', 'weaponDirection', 'weaponLowered', 'weapons', 'weaponsItems', 'weaponsItemsCargo', 'weaponState', 'weaponsTurret', 'weightRTD', 'west', 'WFSideText', 'while', 'wind', 'windDir', 'windStr', 'wingsForcesRTD', 'with', 'worldName', 'worldSize', 'worldToModel', 'worldToModelVisual', 'worldToScreen'];
  var control = ['case', 'catch', 'default', 'do', 'else', 'exit', 'exitWith|5', 'for', 'forEach', 'from', 'if', 'switch', 'then', 'throw', 'to', 'try', 'while', 'with'];
  var operators = ['!', '-', '+', '!=', '%', '&&', '*', '/', '=', '==', '>', '>=', '<', '<=', '^', ':', '>>'];
  var specials = ['_forEachIndex|10', '_this|10', '_x|10'];
  var literals = ['true', 'false', 'nil'];
  var builtins = allCommands.filter(function (command) {
    return control.indexOf(command) == -1 &&
        literals.indexOf(command) == -1 &&
        operators.indexOf(command) == -1;
  });
  //Note: operators will not be treated as builtins due to the lexeme rules
  builtins = builtins.concat(specials);

  // In SQF strings, quotes matching the start are escaped by adding a consecutive.
  // Example of single escaped quotes: " "" " and  ' '' '.
  var STRINGS = {
    className: 'string',
    relevance: 0,
    variants: [
      {
        begin: '"',
        end: '"',
        contains: [{begin: '""'}]
      },
      {
        begin: '\'',
        end: '\'',
        contains: [{begin: '\'\''}]
      }
    ]
  };

  var NUMBERS = {
    className: 'number',
    begin: hljs.NUMBER_RE,
    relevance: 0
  };

  // Preprocessor definitions borrowed from C++
  var PREPROCESSOR_STRINGS = {
    className: 'string',
    variants: [
      hljs.QUOTE_STRING_MODE,
      {
        begin: '\'\\\\?.', end: '\'',
        illegal: '.'
      }
    ]
  };

  var PREPROCESSOR =       {
    className: 'preprocessor',
    begin: '#', end: '$',
    keywords: 'if else elif endif define undef warning error line ' +
              'pragma ifdef ifndef',
    contains: [
      {
        begin: /\\\n/, relevance: 0
      },
      {
        beginKeywords: 'include', end: '$',
        contains: [
          PREPROCESSOR_STRINGS,
          {
            className: 'string',
            begin: '<', end: '>',
            illegal: '\\n',
          }
        ]
      },
      PREPROCESSOR_STRINGS,
      NUMBERS,
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE
    ]
  };

  return {
    aliases: ['sqf'],
    case_insensitive: true,
    keywords: {
      keyword: control.join(' '),
      built_in: builtins.join(' '),
      literal: literals.join(' ')
    },
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      NUMBERS,
      STRINGS,
      PREPROCESSOR
    ]
  };
});

hljs.registerLanguage('sql', function(hljs) {
  var COMMENT_MODE = hljs.COMMENT('--', '$');
  return {
    case_insensitive: true,
    illegal: /[<>{}*]/,
    contains: [
      {
        className: 'operator',
        beginKeywords:
          'begin end start commit rollback savepoint lock alter create drop rename call ' +
          'delete do handler insert load replace select truncate update set show pragma grant ' +
          'merge describe use explain help declare prepare execute deallocate release ' +
          'unlock purge reset change stop analyze cache flush optimize repair kill ' +
          'install uninstall checksum restore check backup revoke',
        end: /;/, endsWithParent: true,
        keywords: {
          keyword:
            'abort abs absolute acc acce accep accept access accessed accessible account acos action activate add ' +
            'addtime admin administer advanced advise aes_decrypt aes_encrypt after agent aggregate ali alia alias ' +
            'allocate allow alter always analyze ancillary and any anydata anydataset anyschema anytype apply ' +
            'archive archived archivelog are as asc ascii asin assembly assertion associate asynchronous at atan ' +
            'atn2 attr attri attrib attribu attribut attribute attributes audit authenticated authentication authid ' +
            'authors auto autoallocate autodblink autoextend automatic availability avg backup badfile basicfile ' +
            'before begin beginning benchmark between bfile bfile_base big bigfile bin binary_double binary_float ' +
            'binlog bit_and bit_count bit_length bit_or bit_xor bitmap blob_base block blocksize body both bound ' +
            'buffer_cache buffer_pool build bulk by byte byteordermark bytes c cache caching call calling cancel ' +
            'capacity cascade cascaded case cast catalog category ceil ceiling chain change changed char_base ' +
            'char_length character_length characters characterset charindex charset charsetform charsetid check ' +
            'checksum checksum_agg child choose chr chunk class cleanup clear client clob clob_base clone close ' +
            'cluster_id cluster_probability cluster_set clustering coalesce coercibility col collate collation ' +
            'collect colu colum column column_value columns columns_updated comment commit compact compatibility ' +
            'compiled complete composite_limit compound compress compute concat concat_ws concurrent confirm conn ' +
            'connec connect connect_by_iscycle connect_by_isleaf connect_by_root connect_time connection ' +
            'consider consistent constant constraint constraints constructor container content contents context ' +
            'contributors controlfile conv convert convert_tz corr corr_k corr_s corresponding corruption cos cost ' +
            'count count_big counted covar_pop covar_samp cpu_per_call cpu_per_session crc32 create creation ' +
            'critical cross cube cume_dist curdate current current_date current_time current_timestamp current_user ' +
            'cursor curtime customdatum cycle d data database databases datafile datafiles datalength date_add ' +
            'date_cache date_format date_sub dateadd datediff datefromparts datename datepart datetime2fromparts ' +
            'day day_to_second dayname dayofmonth dayofweek dayofyear days db_role_change dbtimezone ddl deallocate ' +
            'declare decode decompose decrement decrypt deduplicate def defa defau defaul default defaults ' +
            'deferred defi defin define degrees delayed delegate delete delete_all delimited demand dense_rank ' +
            'depth dequeue des_decrypt des_encrypt des_key_file desc descr descri describ describe descriptor ' +
            'deterministic diagnostics difference dimension direct_load directory disable disable_all ' +
            'disallow disassociate discardfile disconnect diskgroup distinct distinctrow distribute distributed div ' +
            'do document domain dotnet double downgrade drop dumpfile duplicate duration e each edition editionable ' +
            'editions element ellipsis else elsif elt empty enable enable_all enclosed encode encoding encrypt ' +
            'end end-exec endian enforced engine engines enqueue enterprise entityescaping eomonth error errors ' +
            'escaped evalname evaluate event eventdata events except exception exceptions exchange exclude excluding ' +
            'execu execut execute exempt exists exit exp expire explain export export_set extended extent external ' +
            'external_1 external_2 externally extract f failed failed_login_attempts failover failure far fast ' +
            'feature_set feature_value fetch field fields file file_name_convert filesystem_like_logging final ' +
            'finish first first_value fixed flash_cache flashback floor flush following follows for forall force ' +
            'form forma format found found_rows freelist freelists freepools fresh from from_base64 from_days ' +
            'ftp full function g general generated get get_format get_lock getdate getutcdate global global_name ' +
            'globally go goto grant grants greatest group group_concat group_id grouping grouping_id groups ' +
            'gtid_subtract guarantee guard handler hash hashkeys having hea head headi headin heading heap help hex ' +
            'hierarchy high high_priority hosts hour http i id ident_current ident_incr ident_seed identified ' +
            'identity idle_time if ifnull ignore iif ilike ilm immediate import in include including increment ' +
            'index indexes indexing indextype indicator indices inet6_aton inet6_ntoa inet_aton inet_ntoa infile ' +
            'initial initialized initially initrans inmemory inner innodb input insert install instance instantiable ' +
            'instr interface interleaved intersect into invalidate invisible is is_free_lock is_ipv4 is_ipv4_compat ' +
            'is_not is_not_null is_used_lock isdate isnull isolation iterate java join json json_exists ' +
            'k keep keep_duplicates key keys kill l language large last last_day last_insert_id last_value lax lcase ' +
            'lead leading least leaves left len lenght length less level levels library like like2 like4 likec limit ' +
            'lines link list listagg little ln load load_file lob lobs local localtime localtimestamp locate ' +
            'locator lock locked log log10 log2 logfile logfiles logging logical logical_reads_per_call ' +
            'logoff logon logs long loop low low_priority lower lpad lrtrim ltrim m main make_set makedate maketime ' +
            'managed management manual map mapping mask master master_pos_wait match matched materialized max ' +
            'maxextents maximize maxinstances maxlen maxlogfiles maxloghistory maxlogmembers maxsize maxtrans ' +
            'md5 measures median medium member memcompress memory merge microsecond mid migration min minextents ' +
            'minimum mining minus minute minvalue missing mod mode model modification modify module monitoring month ' +
            'months mount move movement multiset mutex n name name_const names nan national native natural nav nchar ' +
            'nclob nested never new newline next nextval no no_write_to_binlog noarchivelog noaudit nobadfile ' +
            'nocheck nocompress nocopy nocycle nodelay nodiscardfile noentityescaping noguarantee nokeep nologfile ' +
            'nomapping nomaxvalue nominimize nominvalue nomonitoring none noneditionable nonschema noorder ' +
            'nopr nopro noprom nopromp noprompt norely noresetlogs noreverse normal norowdependencies noschemacheck ' +
            'noswitch not nothing notice notrim novalidate now nowait nth_value nullif nulls num numb numbe ' +
            'nvarchar nvarchar2 object ocicoll ocidate ocidatetime ociduration ociinterval ociloblocator ocinumber ' +
            'ociref ocirefcursor ocirowid ocistring ocitype oct octet_length of off offline offset oid oidindex old ' +
            'on online only opaque open operations operator optimal optimize option optionally or oracle oracle_date ' +
            'oradata ord ordaudio orddicom orddoc order ordimage ordinality ordvideo organization orlany orlvary ' +
            'out outer outfile outline output over overflow overriding p package pad parallel parallel_enable ' +
            'parameters parent parse partial partition partitions pascal passing password password_grace_time ' +
            'password_lock_time password_reuse_max password_reuse_time password_verify_function patch path patindex ' +
            'pctincrease pctthreshold pctused pctversion percent percent_rank percentile_cont percentile_disc ' +
            'performance period period_add period_diff permanent physical pi pipe pipelined pivot pluggable plugin ' +
            'policy position post_transaction pow power pragma prebuilt precedes preceding precision prediction ' +
            'prediction_cost prediction_details prediction_probability prediction_set prepare present preserve ' +
            'prior priority private private_sga privileges procedural procedure procedure_analyze processlist ' +
            'profiles project prompt protection public publishingservername purge quarter query quick quiesce quota ' +
            'quotename radians raise rand range rank raw read reads readsize rebuild record records ' +
            'recover recovery recursive recycle redo reduced ref reference referenced references referencing refresh ' +
            'regexp_like register regr_avgx regr_avgy regr_count regr_intercept regr_r2 regr_slope regr_sxx regr_sxy ' +
            'reject rekey relational relative relaylog release release_lock relies_on relocate rely rem remainder rename ' +
            'repair repeat replace replicate replication required reset resetlogs resize resource respect restore ' +
            'restricted result result_cache resumable resume retention return returning returns reuse reverse revoke ' +
            'right rlike role roles rollback rolling rollup round row row_count rowdependencies rowid rownum rows ' +
            'rtrim rules safe salt sample save savepoint sb1 sb2 sb4 scan schema schemacheck scn scope scroll ' +
            'sdo_georaster sdo_topo_geometry search sec_to_time second section securefile security seed segment select ' +
            'self sequence sequential serializable server servererror session session_user sessions_per_user set ' +
            'sets settings sha sha1 sha2 share shared shared_pool short show shrink shutdown si_averagecolor ' +
            'si_colorhistogram si_featurelist si_positionalcolor si_stillimage si_texture siblings sid sign sin ' +
            'size size_t sizes skip slave sleep smalldatetimefromparts smallfile snapshot some soname sort soundex ' +
            'source space sparse spfile split sql sql_big_result sql_buffer_result sql_cache sql_calc_found_rows ' +
            'sql_small_result sql_variant_property sqlcode sqldata sqlerror sqlname sqlstate sqrt square standalone ' +
            'standby start starting startup statement static statistics stats_binomial_test stats_crosstab ' +
            'stats_ks_test stats_mode stats_mw_test stats_one_way_anova stats_t_test_ stats_t_test_indep ' +
            'stats_t_test_one stats_t_test_paired stats_wsr_test status std stddev stddev_pop stddev_samp stdev ' +
            'stop storage store stored str str_to_date straight_join strcmp strict string struct stuff style subdate ' +
            'subpartition subpartitions substitutable substr substring subtime subtring_index subtype success sum ' +
            'suspend switch switchoffset switchover sync synchronous synonym sys sys_xmlagg sysasm sysaux sysdate ' +
            'sysdatetimeoffset sysdba sysoper system system_user sysutcdatetime t table tables tablespace tan tdo ' +
            'template temporary terminated tertiary_weights test than then thread through tier ties time time_format ' +
            'time_zone timediff timefromparts timeout timestamp timestampadd timestampdiff timezone_abbr ' +
            'timezone_minute timezone_region to to_base64 to_date to_days to_seconds todatetimeoffset trace tracking ' +
            'transaction transactional translate translation treat trigger trigger_nestlevel triggers trim truncate ' +
            'try_cast try_convert try_parse type ub1 ub2 ub4 ucase unarchived unbounded uncompress ' +
            'under undo unhex unicode uniform uninstall union unique unix_timestamp unknown unlimited unlock unpivot ' +
            'unrecoverable unsafe unsigned until untrusted unusable unused update updated upgrade upped upper upsert ' +
            'url urowid usable usage use use_stored_outlines user user_data user_resources users using utc_date ' +
            'utc_timestamp uuid uuid_short validate validate_password_strength validation valist value values var ' +
            'var_samp varcharc vari varia variab variabl variable variables variance varp varraw varrawc varray ' +
            'verify version versions view virtual visible void wait wallet warning warnings week weekday weekofyear ' +
            'wellformed when whene whenev wheneve whenever where while whitespace with within without work wrapped ' +
            'xdb xml xmlagg xmlattributes xmlcast xmlcolattval xmlelement xmlexists xmlforest xmlindex xmlnamespaces ' +
            'xmlpi xmlquery xmlroot xmlschema xmlserialize xmltable xmltype xor year year_to_month years yearweek',
          literal:
            'true false null',
          built_in:
            'array bigint binary bit blob boolean char character date dec decimal float int int8 integer interval number ' +
            'numeric real record serial serial8 smallint text varchar varying void'
        },
        contains: [
          {
            className: 'string',
            begin: '\'', end: '\'',
            contains: [hljs.BACKSLASH_ESCAPE, {begin: '\'\''}]
          },
          {
            className: 'string',
            begin: '"', end: '"',
            contains: [hljs.BACKSLASH_ESCAPE, {begin: '""'}]
          },
          {
            className: 'string',
            begin: '`', end: '`',
            contains: [hljs.BACKSLASH_ESCAPE]
          },
          hljs.C_NUMBER_MODE,
          hljs.C_BLOCK_COMMENT_MODE,
          COMMENT_MODE
        ]
      },
      hljs.C_BLOCK_COMMENT_MODE,
      COMMENT_MODE
    ]
  };
});

hljs.registerLanguage('stata', function(hljs) {
  return {
    aliases: ['do', 'ado'],
    case_insensitive: true,
    keywords: 'if else in foreach for forv forva forval forvalu forvalue forvalues by bys bysort xi quietly qui capture about ac ac_7 acprplot acprplot_7 adjust ado adopath adoupdate alpha ameans an ano anov anova anova_estat anova_terms anovadef aorder ap app appe appen append arch arch_dr arch_estat arch_p archlm areg areg_p args arima arima_dr arima_estat arima_p as asmprobit asmprobit_estat asmprobit_lf asmprobit_mfx__dlg asmprobit_p ass asse asser assert avplot avplot_7 avplots avplots_7 bcskew0 bgodfrey binreg bip0_lf biplot bipp_lf bipr_lf bipr_p biprobit bitest bitesti bitowt blogit bmemsize boot bootsamp bootstrap bootstrap_8 boxco_l boxco_p boxcox boxcox_6 boxcox_p bprobit br break brier bro brow brows browse brr brrstat bs bs_7 bsampl_w bsample bsample_7 bsqreg bstat bstat_7 bstat_8 bstrap bstrap_7 ca ca_estat ca_p cabiplot camat canon canon_8 canon_8_p canon_estat canon_p cap caprojection capt captu captur capture cat cc cchart cchart_7 cci cd censobs_table centile cf char chdir checkdlgfiles checkestimationsample checkhlpfiles checksum chelp ci cii cl class classutil clear cli clis clist clo clog clog_lf clog_p clogi clogi_sw clogit clogit_lf clogit_p clogitp clogl_sw cloglog clonevar clslistarray cluster cluster_measures cluster_stop cluster_tree cluster_tree_8 clustermat cmdlog cnr cnre cnreg cnreg_p cnreg_sw cnsreg codebook collaps4 collapse colormult_nb colormult_nw compare compress conf confi confir confirm conren cons const constr constra constrai constrain constraint continue contract copy copyright copysource cor corc corr corr2data corr_anti corr_kmo corr_smc corre correl correla correlat correlate corrgram cou coun count cox cox_p cox_sw coxbase coxhaz coxvar cprplot cprplot_7 crc cret cretu cretur creturn cross cs cscript cscript_log csi ct ct_is ctset ctst_5 ctst_st cttost cumsp cumsp_7 cumul cusum cusum_7 cutil d datasig datasign datasigna datasignat datasignatu datasignatur datasignature datetof db dbeta de dec deco decod decode deff des desc descr descri describ describe destring dfbeta dfgls dfuller di di_g dir dirstats dis discard disp disp_res disp_s displ displa display distinct do doe doed doedi doedit dotplot dotplot_7 dprobit drawnorm drop ds ds_util dstdize duplicates durbina dwstat dydx e ed edi edit egen eivreg emdef en enc enco encod encode eq erase ereg ereg_lf ereg_p ereg_sw ereghet ereghet_glf ereghet_glf_sh ereghet_gp ereghet_ilf ereghet_ilf_sh ereghet_ip eret eretu eretur ereturn err erro error est est_cfexist est_cfname est_clickable est_expand est_hold est_table est_unhold est_unholdok estat estat_default estat_summ estat_vce_only esti estimates etodow etof etomdy ex exi exit expand expandcl fac fact facto factor factor_estat factor_p factor_pca_rotated factor_rotate factormat fcast fcast_compute fcast_graph fdades fdadesc fdadescr fdadescri fdadescrib fdadescribe fdasav fdasave fdause fh_st file open file read file close file filefilter fillin find_hlp_file findfile findit findit_7 fit fl fli flis flist for5_0 form forma format fpredict frac_154 frac_adj frac_chk frac_cox frac_ddp frac_dis frac_dv frac_in frac_mun frac_pp frac_pq frac_pv frac_wgt frac_xo fracgen fracplot fracplot_7 fracpoly fracpred fron_ex fron_hn fron_p fron_tn fron_tn2 frontier ftodate ftoe ftomdy ftowdate g gamhet_glf gamhet_gp gamhet_ilf gamhet_ip gamma gamma_d2 gamma_p gamma_sw gammahet gdi_hexagon gdi_spokes ge gen gene gener genera generat generate genrank genstd genvmean gettoken gl gladder gladder_7 glim_l01 glim_l02 glim_l03 glim_l04 glim_l05 glim_l06 glim_l07 glim_l08 glim_l09 glim_l10 glim_l11 glim_l12 glim_lf glim_mu glim_nw1 glim_nw2 glim_nw3 glim_p glim_v1 glim_v2 glim_v3 glim_v4 glim_v5 glim_v6 glim_v7 glm glm_6 glm_p glm_sw glmpred glo glob globa global glogit glogit_8 glogit_p gmeans gnbre_lf gnbreg gnbreg_5 gnbreg_p gomp_lf gompe_sw gomper_p gompertz gompertzhet gomphet_glf gomphet_glf_sh gomphet_gp gomphet_ilf gomphet_ilf_sh gomphet_ip gphdot gphpen gphprint gprefs gprobi_p gprobit gprobit_8 gr gr7 gr_copy gr_current gr_db gr_describe gr_dir gr_draw gr_draw_replay gr_drop gr_edit gr_editviewopts gr_example gr_example2 gr_export gr_print gr_qscheme gr_query gr_read gr_rename gr_replay gr_save gr_set gr_setscheme gr_table gr_undo gr_use graph graph7 grebar greigen greigen_7 greigen_8 grmeanby grmeanby_7 gs_fileinfo gs_filetype gs_graphinfo gs_stat gsort gwood h hadimvo hareg hausman haver he heck_d2 heckma_p heckman heckp_lf heckpr_p heckprob hel help hereg hetpr_lf hetpr_p hetprob hettest hexdump hilite hist hist_7 histogram hlogit hlu hmeans hotel hotelling hprobit hreg hsearch icd9 icd9_ff icd9p iis impute imtest inbase include inf infi infil infile infix inp inpu input ins insheet insp inspe inspec inspect integ inten intreg intreg_7 intreg_p intrg2_ll intrg_ll intrg_ll2 ipolate iqreg ir irf irf_create irfm iri is_svy is_svysum isid istdize ivprob_1_lf ivprob_lf ivprobit ivprobit_p ivreg ivreg_footnote ivtob_1_lf ivtob_lf ivtobit ivtobit_p jackknife jacknife jknife jknife_6 jknife_8 jkstat joinby kalarma1 kap kap_3 kapmeier kappa kapwgt kdensity kdensity_7 keep ksm ksmirnov ktau kwallis l la lab labe label labelbook ladder levels levelsof leverage lfit lfit_p li lincom line linktest lis list lloghet_glf lloghet_glf_sh lloghet_gp lloghet_ilf lloghet_ilf_sh lloghet_ip llogi_sw llogis_p llogist llogistic llogistichet lnorm_lf lnorm_sw lnorma_p lnormal lnormalhet lnormhet_glf lnormhet_glf_sh lnormhet_gp lnormhet_ilf lnormhet_ilf_sh lnormhet_ip lnskew0 loadingplot loc loca local log logi logis_lf logistic logistic_p logit logit_estat logit_p loglogs logrank loneway lookfor lookup lowess lowess_7 lpredict lrecomp lroc lroc_7 lrtest ls lsens lsens_7 lsens_x lstat ltable ltable_7 ltriang lv lvr2plot lvr2plot_7 m ma mac macr macro makecns man manova manova_estat manova_p manovatest mantel mark markin markout marksample mat mat_capp mat_order mat_put_rr mat_rapp mata mata_clear mata_describe mata_drop mata_matdescribe mata_matsave mata_matuse mata_memory mata_mlib mata_mosave mata_rename mata_which matalabel matcproc matlist matname matr matri matrix matrix_input__dlg matstrik mcc mcci md0_ md1_ md1debug_ md2_ md2debug_ mds mds_estat mds_p mdsconfig mdslong mdsmat mdsshepard mdytoe mdytof me_derd mean means median memory memsize meqparse mer merg merge mfp mfx mhelp mhodds minbound mixed_ll mixed_ll_reparm mkassert mkdir mkmat mkspline ml ml_5 ml_adjs ml_bhhhs ml_c_d ml_check ml_clear ml_cnt ml_debug ml_defd ml_e0 ml_e0_bfgs ml_e0_cycle ml_e0_dfp ml_e0i ml_e1 ml_e1_bfgs ml_e1_bhhh ml_e1_cycle ml_e1_dfp ml_e2 ml_e2_cycle ml_ebfg0 ml_ebfr0 ml_ebfr1 ml_ebh0q ml_ebhh0 ml_ebhr0 ml_ebr0i ml_ecr0i ml_edfp0 ml_edfr0 ml_edfr1 ml_edr0i ml_eds ml_eer0i ml_egr0i ml_elf ml_elf_bfgs ml_elf_bhhh ml_elf_cycle ml_elf_dfp ml_elfi ml_elfs ml_enr0i ml_enrr0 ml_erdu0 ml_erdu0_bfgs ml_erdu0_bhhh ml_erdu0_bhhhq ml_erdu0_cycle ml_erdu0_dfp ml_erdu0_nrbfgs ml_exde ml_footnote ml_geqnr ml_grad0 ml_graph ml_hbhhh ml_hd0 ml_hold ml_init ml_inv ml_log ml_max ml_mlout ml_mlout_8 ml_model ml_nb0 ml_opt ml_p ml_plot ml_query ml_rdgrd ml_repor ml_s_e ml_score ml_searc ml_technique ml_unhold mleval mlf_ mlmatbysum mlmatsum mlog mlogi mlogit mlogit_footnote mlogit_p mlopts mlsum mlvecsum mnl0_ mor more mov move mprobit mprobit_lf mprobit_p mrdu0_ mrdu1_ mvdecode mvencode mvreg mvreg_estat n nbreg nbreg_al nbreg_lf nbreg_p nbreg_sw nestreg net newey newey_7 newey_p news nl nl_7 nl_9 nl_9_p nl_p nl_p_7 nlcom nlcom_p nlexp2 nlexp2_7 nlexp2a nlexp2a_7 nlexp3 nlexp3_7 nlgom3 nlgom3_7 nlgom4 nlgom4_7 nlinit nllog3 nllog3_7 nllog4 nllog4_7 nlog_rd nlogit nlogit_p nlogitgen nlogittree nlpred no nobreak noi nois noisi noisil noisily note notes notes_dlg nptrend numlabel numlist odbc old_ver olo olog ologi ologi_sw ologit ologit_p ologitp on one onew onewa oneway op_colnm op_comp op_diff op_inv op_str opr opro oprob oprob_sw oprobi oprobi_p oprobit oprobitp opts_exclusive order orthog orthpoly ou out outf outfi outfil outfile outs outsh outshe outshee outsheet ovtest pac pac_7 palette parse parse_dissim pause pca pca_8 pca_display pca_estat pca_p pca_rotate pcamat pchart pchart_7 pchi pchi_7 pcorr pctile pentium pergram pergram_7 permute permute_8 personal peto_st pkcollapse pkcross pkequiv pkexamine pkexamine_7 pkshape pksumm pksumm_7 pl plo plot plugin pnorm pnorm_7 poisgof poiss_lf poiss_sw poisso_p poisson poisson_estat post postclose postfile postutil pperron pr prais prais_e prais_e2 prais_p predict predictnl preserve print pro prob probi probit probit_estat probit_p proc_time procoverlay procrustes procrustes_estat procrustes_p profiler prog progr progra program prop proportion prtest prtesti pwcorr pwd q\\s qby qbys qchi qchi_7 qladder qladder_7 qnorm qnorm_7 qqplot qqplot_7 qreg qreg_c qreg_p qreg_sw qu quadchk quantile quantile_7 que quer query range ranksum ratio rchart rchart_7 rcof recast reclink recode reg reg3 reg3_p regdw regr regre regre_p2 regres regres_p regress regress_estat regriv_p remap ren rena renam rename renpfix repeat replace report reshape restore ret retu retur return rm rmdir robvar roccomp roccomp_7 roccomp_8 rocf_lf rocfit rocfit_8 rocgold rocplot rocplot_7 roctab roctab_7 rolling rologit rologit_p rot rota rotat rotate rotatemat rreg rreg_p ru run runtest rvfplot rvfplot_7 rvpplot rvpplot_7 sa safesum sample sampsi sav save savedresults saveold sc sca scal scala scalar scatter scm_mine sco scob_lf scob_p scobi_sw scobit scor score scoreplot scoreplot_help scree screeplot screeplot_help sdtest sdtesti se search separate seperate serrbar serrbar_7 serset set set_defaults sfrancia sh she shel shell shewhart shewhart_7 signestimationsample signrank signtest simul simul_7 simulate simulate_8 sktest sleep slogit slogit_d2 slogit_p smooth snapspan so sor sort spearman spikeplot spikeplot_7 spikeplt spline_x split sqreg sqreg_p sret sretu sretur sreturn ssc st st_ct st_hc st_hcd st_hcd_sh st_is st_issys st_note st_promo st_set st_show st_smpl st_subid stack statsby statsby_8 stbase stci stci_7 stcox stcox_estat stcox_fr stcox_fr_ll stcox_p stcox_sw stcoxkm stcoxkm_7 stcstat stcurv stcurve stcurve_7 stdes stem stepwise stereg stfill stgen stir stjoin stmc stmh stphplot stphplot_7 stphtest stphtest_7 stptime strate strate_7 streg streg_sw streset sts sts_7 stset stsplit stsum sttocc sttoct stvary stweib su suest suest_8 sum summ summa summar summari summariz summarize sunflower sureg survcurv survsum svar svar_p svmat svy svy_disp svy_dreg svy_est svy_est_7 svy_estat svy_get svy_gnbreg_p svy_head svy_header svy_heckman_p svy_heckprob_p svy_intreg_p svy_ivreg_p svy_logistic_p svy_logit_p svy_mlogit_p svy_nbreg_p svy_ologit_p svy_oprobit_p svy_poisson_p svy_probit_p svy_regress_p svy_sub svy_sub_7 svy_x svy_x_7 svy_x_p svydes svydes_8 svygen svygnbreg svyheckman svyheckprob svyintreg svyintreg_7 svyintrg svyivreg svylc svylog_p svylogit svymarkout svymarkout_8 svymean svymlog svymlogit svynbreg svyolog svyologit svyoprob svyoprobit svyopts svypois svypois_7 svypoisson svyprobit svyprobt svyprop svyprop_7 svyratio svyreg svyreg_p svyregress svyset svyset_7 svyset_8 svytab svytab_7 svytest svytotal sw sw_8 swcnreg swcox swereg swilk swlogis swlogit swologit swoprbt swpois swprobit swqreg swtobit swweib symmetry symmi symplot symplot_7 syntax sysdescribe sysdir sysuse szroeter ta tab tab1 tab2 tab_or tabd tabdi tabdis tabdisp tabi table tabodds tabodds_7 tabstat tabu tabul tabula tabulat tabulate te tempfile tempname tempvar tes test testnl testparm teststd tetrachoric time_it timer tis tob tobi tobit tobit_p tobit_sw token tokeni tokeniz tokenize tostring total translate translator transmap treat_ll treatr_p treatreg trim trnb_cons trnb_mean trpoiss_d2 trunc_ll truncr_p truncreg tsappend tset tsfill tsline tsline_ex tsreport tsrevar tsrline tsset tssmooth tsunab ttest ttesti tut_chk tut_wait tutorial tw tware_st two twoway twoway__fpfit_serset twoway__function_gen twoway__histogram_gen twoway__ipoint_serset twoway__ipoints_serset twoway__kdensity_gen twoway__lfit_serset twoway__normgen_gen twoway__pci_serset twoway__qfit_serset twoway__scatteri_serset twoway__sunflower_gen twoway_ksm_serset ty typ type typeof u unab unabbrev unabcmd update us use uselabel var var_mkcompanion var_p varbasic varfcast vargranger varirf varirf_add varirf_cgraph varirf_create varirf_ctable varirf_describe varirf_dir varirf_drop varirf_erase varirf_graph varirf_ograph varirf_rename varirf_set varirf_table varlist varlmar varnorm varsoc varstable varstable_w varstable_w2 varwle vce vec vec_fevd vec_mkphi vec_p vec_p_w vecirf_create veclmar veclmar_w vecnorm vecnorm_w vecrank vecstable verinst vers versi versio version view viewsource vif vwls wdatetof webdescribe webseek webuse weib1_lf weib2_lf weib_lf weib_lf0 weibhet_glf weibhet_glf_sh weibhet_glfa weibhet_glfa_sh weibhet_gp weibhet_ilf weibhet_ilf_sh weibhet_ilfa weibhet_ilfa_sh weibhet_ip weibu_sw weibul_p weibull weibull_c weibull_s weibullhet wh whelp whi which whil while wilc_st wilcoxon win wind windo window winexec wntestb wntestb_7 wntestq xchart xchart_7 xcorr xcorr_7 xi xi_6 xmlsav xmlsave xmluse xpose xsh xshe xshel xshell xt_iis xt_tis xtab_p xtabond xtbin_p xtclog xtcloglog xtcloglog_8 xtcloglog_d2 xtcloglog_pa_p xtcloglog_re_p xtcnt_p xtcorr xtdata xtdes xtfront_p xtfrontier xtgee xtgee_elink xtgee_estat xtgee_makeivar xtgee_p xtgee_plink xtgls xtgls_p xthaus xthausman xtht_p xthtaylor xtile xtint_p xtintreg xtintreg_8 xtintreg_d2 xtintreg_p xtivp_1 xtivp_2 xtivreg xtline xtline_ex xtlogit xtlogit_8 xtlogit_d2 xtlogit_fe_p xtlogit_pa_p xtlogit_re_p xtmixed xtmixed_estat xtmixed_p xtnb_fe xtnb_lf xtnbreg xtnbreg_pa_p xtnbreg_refe_p xtpcse xtpcse_p xtpois xtpoisson xtpoisson_d2 xtpoisson_pa_p xtpoisson_refe_p xtpred xtprobit xtprobit_8 xtprobit_d2 xtprobit_re_p xtps_fe xtps_lf xtps_ren xtps_ren_8 xtrar_p xtrc xtrc_p xtrchh xtrefe_p xtreg xtreg_be xtreg_fe xtreg_ml xtreg_pa_p xtreg_re xtregar xtrere_p xtset xtsf_ll xtsf_llti xtsum xttab xttest0 xttobit xttobit_8 xttobit_p xttrans yx yxview__barlike_draw yxview_area_draw yxview_bar_draw yxview_dot_draw yxview_dropline_draw yxview_function_draw yxview_iarrow_draw yxview_ilabels_draw yxview_normal_draw yxview_pcarrow_draw yxview_pcbarrow_draw yxview_pccapsym_draw yxview_pcscatter_draw yxview_pcspike_draw yxview_rarea_draw yxview_rbar_draw yxview_rbarm_draw yxview_rcap_draw yxview_rcapsym_draw yxview_rconnected_draw yxview_rline_draw yxview_rscatter_draw yxview_rspike_draw yxview_spike_draw yxview_sunflower_draw zap_s zinb zinb_llf zinb_plf zip zip_llf zip_p zip_plf zt_ct_5 zt_hc_5 zt_hcd_5 zt_is_5 zt_iss_5 zt_sho_5 zt_smp_5 ztbase_5 ztcox_5 ztdes_5 ztereg_5 ztfill_5 ztgen_5 ztir_5 ztjoin_5 ztnb ztnb_p ztp ztp_p zts_5 ztset_5 ztspli_5 ztsum_5 zttoct_5 ztvary_5 ztweib_5',
        contains: [
      {
        className: 'label',
        variants: [
          {begin: "\\$\\{?[a-zA-Z0-9_]+\\}?"},
          {begin: "`[a-zA-Z0-9_]+'"}

        ]
      },
      {
        className: 'string',
        variants: [
          {begin: '`"[^\r\n]*?"\''},
          {begin: '"[^\r\n"]*"'}
        ]
      },

      {
        className: 'literal',
        variants: [
          {
            begin: '\\b(abs|acos|asin|atan|atan2|atanh|ceil|cloglog|comb|cos|digamma|exp|floor|invcloglog|invlogit|ln|lnfact|lnfactorial|lngamma|log|log10|max|min|mod|reldif|round|sign|sin|sqrt|sum|tan|tanh|trigamma|trunc|betaden|Binomial|binorm|binormal|chi2|chi2tail|dgammapda|dgammapdada|dgammapdadx|dgammapdx|dgammapdxdx|F|Fden|Ftail|gammaden|gammap|ibeta|invbinomial|invchi2|invchi2tail|invF|invFtail|invgammap|invibeta|invnchi2|invnFtail|invnibeta|invnorm|invnormal|invttail|nbetaden|nchi2|nFden|nFtail|nibeta|norm|normal|normalden|normd|npnchi2|tden|ttail|uniform|abbrev|char|index|indexnot|length|lower|ltrim|match|plural|proper|real|regexm|regexr|regexs|reverse|rtrim|string|strlen|strlower|strltrim|strmatch|strofreal|strpos|strproper|strreverse|strrtrim|strtrim|strupper|subinstr|subinword|substr|trim|upper|word|wordcount|_caller|autocode|byteorder|chop|clip|cond|e|epsdouble|epsfloat|group|inlist|inrange|irecode|matrix|maxbyte|maxdouble|maxfloat|maxint|maxlong|mi|minbyte|mindouble|minfloat|minint|minlong|missing|r|recode|replay|return|s|scalar|d|date|day|dow|doy|halfyear|mdy|month|quarter|week|year|d|daily|dofd|dofh|dofm|dofq|dofw|dofy|h|halfyearly|hofd|m|mofd|monthly|q|qofd|quarterly|tin|twithin|w|weekly|wofd|y|yearly|yh|ym|yofd|yq|yw|cholesky|colnumb|colsof|corr|det|diag|diag0cnt|el|get|hadamard|I|inv|invsym|issym|issymmetric|J|matmissing|matuniform|mreldif|nullmat|rownumb|rowsof|sweep|syminv|trace|vec|vecdiag)(?=\\(|$)'
          }
        ]
      },

      hljs.COMMENT('^[ \t]*\\*.*$', false),
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE
    ]
  };
});

hljs.registerLanguage('step21', function(hljs) {
  var STEP21_IDENT_RE = '[A-Z_][A-Z0-9_.]*';
  var STEP21_CLOSE_RE = 'END-ISO-10303-21;';
  var STEP21_KEYWORDS = {
    literal: '',
    built_in: '',
    keyword:
    'HEADER ENDSEC DATA'
  };
  var STEP21_START = {
    className: 'preprocessor',
    begin: 'ISO-10303-21;',
    relevance: 10
  };
  var STEP21_CODE = [
    hljs.C_LINE_COMMENT_MODE,
    hljs.C_BLOCK_COMMENT_MODE,
    hljs.COMMENT('/\\*\\*!', '\\*/'),
    hljs.C_NUMBER_MODE,
    hljs.inherit(hljs.APOS_STRING_MODE, {illegal: null}),
    hljs.inherit(hljs.QUOTE_STRING_MODE, {illegal: null}),
    {
      className: 'string',
      begin: "'", end: "'"
    },
    {
      className: 'label',
      variants: [
        {
          begin: '#', end: '\\d+',
          illegal: '\\W'
        }
      ]
    }
  ];

  return {
    aliases: ['p21', 'step', 'stp'],
    case_insensitive: true, // STEP 21 is case insensitive in theory, in practice all non-comments are capitalized.
    lexemes: STEP21_IDENT_RE,
    keywords: STEP21_KEYWORDS,
    contains: [
      {
        className: 'preprocessor',
        begin: STEP21_CLOSE_RE,
        relevance: 10
      },
      STEP21_START
    ].concat(STEP21_CODE)
  };
});

hljs.registerLanguage('stylus', function(hljs) {

  var VARIABLE = {
    className: 'variable',
    begin: '\\$' + hljs.IDENT_RE
  };

  var HEX_COLOR = {
    className: 'hexcolor',
    begin: '#([a-fA-F0-9]{6}|[a-fA-F0-9]{3})',
    relevance: 10
  };

  var AT_KEYWORDS = [
    'charset',
    'css',
    'debug',
    'extend',
    'font-face',
    'for',
    'import',
    'include',
    'media',
    'mixin',
    'page',
    'warn',
    'while'
  ];

  var PSEUDO_SELECTORS = [
    'after',
    'before',
    'first-letter',
    'first-line',
    'active',
    'first-child',
    'focus',
    'hover',
    'lang',
    'link',
    'visited'
  ];

  var TAGS = [
    'a',
    'abbr',
    'address',
    'article',
    'aside',
    'audio',
    'b',
    'blockquote',
    'body',
    'button',
    'canvas',
    'caption',
    'cite',
    'code',
    'dd',
    'del',
    'details',
    'dfn',
    'div',
    'dl',
    'dt',
    'em',
    'fieldset',
    'figcaption',
    'figure',
    'footer',
    'form',
    'h1',
    'h2',
    'h3',
    'h4',
    'h5',
    'h6',
    'header',
    'hgroup',
    'html',
    'i',
    'iframe',
    'img',
    'input',
    'ins',
    'kbd',
    'label',
    'legend',
    'li',
    'mark',
    'menu',
    'nav',
    'object',
    'ol',
    'p',
    'q',
    'quote',
    'samp',
    'section',
    'span',
    'strong',
    'summary',
    'sup',
    'table',
    'tbody',
    'td',
    'textarea',
    'tfoot',
    'th',
    'thead',
    'time',
    'tr',
    'ul',
    'var',
    'video'
  ];

  var TAG_END = '[\\.\\s\\n\\[\\:,]';

  var ATTRIBUTES = [
    'align-content',
    'align-items',
    'align-self',
    'animation',
    'animation-delay',
    'animation-direction',
    'animation-duration',
    'animation-fill-mode',
    'animation-iteration-count',
    'animation-name',
    'animation-play-state',
    'animation-timing-function',
    'auto',
    'backface-visibility',
    'background',
    'background-attachment',
    'background-clip',
    'background-color',
    'background-image',
    'background-origin',
    'background-position',
    'background-repeat',
    'background-size',
    'border',
    'border-bottom',
    'border-bottom-color',
    'border-bottom-left-radius',
    'border-bottom-right-radius',
    'border-bottom-style',
    'border-bottom-width',
    'border-collapse',
    'border-color',
    'border-image',
    'border-image-outset',
    'border-image-repeat',
    'border-image-slice',
    'border-image-source',
    'border-image-width',
    'border-left',
    'border-left-color',
    'border-left-style',
    'border-left-width',
    'border-radius',
    'border-right',
    'border-right-color',
    'border-right-style',
    'border-right-width',
    'border-spacing',
    'border-style',
    'border-top',
    'border-top-color',
    'border-top-left-radius',
    'border-top-right-radius',
    'border-top-style',
    'border-top-width',
    'border-width',
    'bottom',
    'box-decoration-break',
    'box-shadow',
    'box-sizing',
    'break-after',
    'break-before',
    'break-inside',
    'caption-side',
    'clear',
    'clip',
    'clip-path',
    'color',
    'column-count',
    'column-fill',
    'column-gap',
    'column-rule',
    'column-rule-color',
    'column-rule-style',
    'column-rule-width',
    'column-span',
    'column-width',
    'columns',
    'content',
    'counter-increment',
    'counter-reset',
    'cursor',
    'direction',
    'display',
    'empty-cells',
    'filter',
    'flex',
    'flex-basis',
    'flex-direction',
    'flex-flow',
    'flex-grow',
    'flex-shrink',
    'flex-wrap',
    'float',
    'font',
    'font-family',
    'font-feature-settings',
    'font-kerning',
    'font-language-override',
    'font-size',
    'font-size-adjust',
    'font-stretch',
    'font-style',
    'font-variant',
    'font-variant-ligatures',
    'font-weight',
    'height',
    'hyphens',
    'icon',
    'image-orientation',
    'image-rendering',
    'image-resolution',
    'ime-mode',
    'inherit',
    'initial',
    'justify-content',
    'left',
    'letter-spacing',
    'line-height',
    'list-style',
    'list-style-image',
    'list-style-position',
    'list-style-type',
    'margin',
    'margin-bottom',
    'margin-left',
    'margin-right',
    'margin-top',
    'marks',
    'mask',
    'max-height',
    'max-width',
    'min-height',
    'min-width',
    'nav-down',
    'nav-index',
    'nav-left',
    'nav-right',
    'nav-up',
    'none',
    'normal',
    'object-fit',
    'object-position',
    'opacity',
    'order',
    'orphans',
    'outline',
    'outline-color',
    'outline-offset',
    'outline-style',
    'outline-width',
    'overflow',
    'overflow-wrap',
    'overflow-x',
    'overflow-y',
    'padding',
    'padding-bottom',
    'padding-left',
    'padding-right',
    'padding-top',
    'page-break-after',
    'page-break-before',
    'page-break-inside',
    'perspective',
    'perspective-origin',
    'pointer-events',
    'position',
    'quotes',
    'resize',
    'right',
    'tab-size',
    'table-layout',
    'text-align',
    'text-align-last',
    'text-decoration',
    'text-decoration-color',
    'text-decoration-line',
    'text-decoration-style',
    'text-indent',
    'text-overflow',
    'text-rendering',
    'text-shadow',
    'text-transform',
    'text-underline-position',
    'top',
    'transform',
    'transform-origin',
    'transform-style',
    'transition',
    'transition-delay',
    'transition-duration',
    'transition-property',
    'transition-timing-function',
    'unicode-bidi',
    'vertical-align',
    'visibility',
    'white-space',
    'widows',
    'width',
    'word-break',
    'word-spacing',
    'word-wrap',
    'z-index'
  ];

  // illegals
  var ILLEGAL = [
    '\\{',
    '\\}',
    '\\?',
    '(\\bReturn\\b)', // monkey
    '(\\bEnd\\b)', // monkey
    '(\\bend\\b)', // vbscript
    ';', // sql
    '#\\s', // markdown
    '\\*\\s', // markdown
    '===\\s', // markdown
    '\\|',
    '%', // prolog
  ];

  return {
    aliases: ['styl'],
    case_insensitive: false,
    illegal: '(' + ILLEGAL.join('|') + ')',
    keywords: 'if else for in',
    contains: [

      // strings
      hljs.QUOTE_STRING_MODE,
      hljs.APOS_STRING_MODE,

      // comments
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,

      // hex colors
      HEX_COLOR,

      // class tag
      {
        begin: '\\.[a-zA-Z][a-zA-Z0-9_-]*' + TAG_END,
        returnBegin: true,
        contains: [
          {className: 'class', begin: '\\.[a-zA-Z][a-zA-Z0-9_-]*'}
        ]
      },

      // id tag
      {
        begin: '\\#[a-zA-Z][a-zA-Z0-9_-]*' + TAG_END,
        returnBegin: true,
        contains: [
          {className: 'id', begin: '\\#[a-zA-Z][a-zA-Z0-9_-]*'}
        ]
      },

      // tags
      {
        begin: '\\b(' + TAGS.join('|') + ')' + TAG_END,
        returnBegin: true,
        contains: [
          {className: 'tag', begin: '\\b[a-zA-Z][a-zA-Z0-9_-]*'}
        ]
      },

      // psuedo selectors
      {
        className: 'pseudo',
        begin: '&?:?:\\b(' + PSEUDO_SELECTORS.join('|') + ')' + TAG_END
      },

      // @ keywords
      {
        className: 'at_rule',
        begin: '\@(' + AT_KEYWORDS.join('|') + ')\\b'
      },

      // variables
      VARIABLE,

      // dimension
      hljs.CSS_NUMBER_MODE,

      // number
      hljs.NUMBER_MODE,

      // functions
      //  - only from beginning of line + whitespace
      {
        className: 'function',
        begin: '\\b[a-zA-Z][a-zA-Z0-9_\-]*\\(.*\\)',
        illegal: '[\\n]',
        returnBegin: true,
        contains: [
          {className: 'title', begin: '\\b[a-zA-Z][a-zA-Z0-9_\-]*'},
          {
            className: 'params',
            begin: /\(/,
            end: /\)/,
            contains: [
              HEX_COLOR,
              VARIABLE,
              hljs.APOS_STRING_MODE,
              hljs.CSS_NUMBER_MODE,
              hljs.NUMBER_MODE,
              hljs.QUOTE_STRING_MODE
            ]
          }
        ]
      },

      // attributes
      //  - only from beginning of line + whitespace
      //  - must have whitespace after it
      {
        className: 'attribute',
        begin: '\\b(' + ATTRIBUTES.reverse().join('|') + ')\\b'
      }
    ]
  };
});

hljs.registerLanguage('swift', function(hljs) {
  var SWIFT_KEYWORDS = {
      keyword: '__COLUMN__ __FILE__ __FUNCTION__ __LINE__ as as! as? associativity ' +
        'break case catch class continue convenience default defer deinit didSet do ' +
        'dynamic dynamicType else enum extension fallthrough false final for func ' +
        'get guard if import in indirect infix init inout internal is lazy left let ' +
        'mutating nil none nonmutating operator optional override postfix precedence ' +
        'prefix private protocol Protocol public repeat required rethrows return ' +
        'right self Self set static struct subscript super switch throw throws true ' +
        'try try! try? Type typealias unowned var weak where while willSet',
      literal: 'true false nil',
      built_in: 'abs advance alignof alignofValue anyGenerator assert assertionFailure ' +
        'bridgeFromObjectiveC bridgeFromObjectiveCUnconditional bridgeToObjectiveC ' +
        'bridgeToObjectiveCUnconditional c contains count countElements countLeadingZeros ' +
        'debugPrint debugPrintln distance dropFirst dropLast dump encodeBitsAsWords ' +
        'enumerate equal fatalError filter find getBridgedObjectiveCType getVaList ' +
        'indices insertionSort isBridgedToObjectiveC isBridgedVerbatimToObjectiveC ' +
        'isUniquelyReferenced isUniquelyReferencedNonObjC join lazy lexicographicalCompare ' +
        'map max maxElement min minElement numericCast overlaps partition posix ' +
        'precondition preconditionFailure print println quickSort readLine reduce reflect ' +
        'reinterpretCast reverse roundUpToAlignment sizeof sizeofValue sort split ' +
        'startsWith stride strideof strideofValue swap toString transcode ' +
        'underestimateCount unsafeAddressOf unsafeBitCast unsafeDowncast unsafeUnwrap ' +
        'unsafeReflect withExtendedLifetime withObjectAtPlusZero withUnsafePointer ' +
        'withUnsafePointerToObject withUnsafeMutablePointer withUnsafeMutablePointers ' +
        'withUnsafePointer withUnsafePointers withVaList zip'
    };

  var TYPE = {
    className: 'type',
    begin: '\\b[A-Z][\\w\']*',
    relevance: 0
  };
  var BLOCK_COMMENT = hljs.COMMENT(
    '/\\*',
    '\\*/',
    {
      contains: ['self']
    }
  );
  var SUBST = {
    className: 'subst',
    begin: /\\\(/, end: '\\)',
    keywords: SWIFT_KEYWORDS,
    contains: [] // assigned later
  };
  var NUMBERS = {
      className: 'number',
      begin: '\\b([\\d_]+(\\.[\\deE_]+)?|0x[a-fA-F0-9_]+(\\.[a-fA-F0-9p_]+)?|0b[01_]+|0o[0-7_]+)\\b',
      relevance: 0
  };
  var QUOTE_STRING_MODE = hljs.inherit(hljs.QUOTE_STRING_MODE, {
    contains: [SUBST, hljs.BACKSLASH_ESCAPE]
  });
  SUBST.contains = [NUMBERS];

  return {
    keywords: SWIFT_KEYWORDS,
    contains: [
      QUOTE_STRING_MODE,
      hljs.C_LINE_COMMENT_MODE,
      BLOCK_COMMENT,
      TYPE,
      NUMBERS,
      {
        className: 'func',
        beginKeywords: 'func', end: '{', excludeEnd: true,
        contains: [
          hljs.inherit(hljs.TITLE_MODE, {
            begin: /[A-Za-z$_][0-9A-Za-z$_]*/,
            illegal: /\(/
          }),
          {
            className: 'generics',
            begin: /</, end: />/,
            illegal: />/
          },
          {
            className: 'params',
            begin: /\(/, end: /\)/, endsParent: true,
            keywords: SWIFT_KEYWORDS,
            contains: [
              'self',
              NUMBERS,
              QUOTE_STRING_MODE,
              hljs.C_BLOCK_COMMENT_MODE,
              {begin: ':'} // relevance booster
            ],
            illegal: /["']/
          }
        ],
        illegal: /\[|%/
      },
      {
        className: 'class',
        beginKeywords: 'struct protocol class extension enum',
        keywords: SWIFT_KEYWORDS,
        end: '\\{',
        excludeEnd: true,
        contains: [
          hljs.inherit(hljs.TITLE_MODE, {begin: /[A-Za-z$_][0-9A-Za-z$_]*/})
        ]
      },
      {
        className: 'preprocessor', // @attributes
        begin: '(@warn_unused_result|@exported|@lazy|@noescape|' +
                  '@NSCopying|@NSManaged|@objc|@convention|@required|' +
                  '@noreturn|@IBAction|@IBDesignable|@IBInspectable|@IBOutlet|' +
                  '@infix|@prefix|@postfix|@autoclosure|@testable|@available|' +
                  '@nonobjc|@NSApplicationMain|@UIApplicationMain)'

      },
      {
        beginKeywords: 'import', end: /$/,
        contains: [hljs.C_LINE_COMMENT_MODE, BLOCK_COMMENT]
      }
    ]
  };
});

hljs.registerLanguage('tcl', function(hljs) {
  return {
    aliases: ['tk'],
    keywords: 'after append apply array auto_execok auto_import auto_load auto_mkindex ' +
      'auto_mkindex_old auto_qualify auto_reset bgerror binary break catch cd chan clock ' +
      'close concat continue dde dict encoding eof error eval exec exit expr fblocked ' +
      'fconfigure fcopy file fileevent filename flush for foreach format gets glob global ' +
      'history http if incr info interp join lappend|10 lassign|10 lindex|10 linsert|10 list ' +
      'llength|10 load lrange|10 lrepeat|10 lreplace|10 lreverse|10 lsearch|10 lset|10 lsort|10 '+
      'mathfunc mathop memory msgcat namespace open package parray pid pkg::create pkg_mkIndex '+
      'platform platform::shell proc puts pwd read refchan regexp registry regsub|10 rename '+
      'return safe scan seek set socket source split string subst switch tcl_endOfWord '+
      'tcl_findLibrary tcl_startOfNextWord tcl_startOfPreviousWord tcl_wordBreakAfter '+
      'tcl_wordBreakBefore tcltest tclvars tell time tm trace unknown unload unset update '+
      'uplevel upvar variable vwait while',
    contains: [
      hljs.COMMENT(';[ \\t]*#', '$'),
      hljs.COMMENT('^[ \\t]*#', '$'),
      {
        beginKeywords: 'proc',
        end: '[\\{]',
        excludeEnd: true,
        contains: [
          {
            className: 'symbol',
            begin: '[ \\t\\n\\r]+(::)?[a-zA-Z_]((::)?[a-zA-Z0-9_])*',
            end: '[ \\t\\n\\r]',
            endsWithParent: true,
            excludeEnd: true
          }
        ]
      },
      {
        className: 'variable',
        excludeEnd: true,
        variants: [
          {
            begin: '\\$(\\{)?(::)?[a-zA-Z_]((::)?[a-zA-Z0-9_])*\\(([a-zA-Z0-9_])*\\)',
            end: '[^a-zA-Z0-9_\\}\\$]'
          },
          {
            begin: '\\$(\\{)?(::)?[a-zA-Z_]((::)?[a-zA-Z0-9_])*',
            end: '(\\))?[^a-zA-Z0-9_\\}\\$]'
          }
        ]
      },
      {
        className: 'string',
        contains: [hljs.BACKSLASH_ESCAPE],
        variants: [
          hljs.inherit(hljs.APOS_STRING_MODE, {illegal: null}),
          hljs.inherit(hljs.QUOTE_STRING_MODE, {illegal: null})
        ]
      },
      {
        className: 'number',
        variants: [hljs.BINARY_NUMBER_MODE, hljs.C_NUMBER_MODE]
      }
    ]
  }
});

hljs.registerLanguage('tex', function(hljs) {
  var COMMAND1 = {
    className: 'command',
    begin: '\\\\[a-zA-Zа-яА-я]+[\\*]?'
  };
  var COMMAND2 = {
    className: 'command',
    begin: '\\\\[^a-zA-Zа-яА-я0-9]'
  };
  var SPECIAL = {
    className: 'special',
    begin: '[{}\\[\\]\\&#~]',
    relevance: 0
  };

  return {
    contains: [
      { // parameter
        begin: '\\\\[a-zA-Zа-яА-я]+[\\*]? *= *-?\\d*\\.?\\d+(pt|pc|mm|cm|in|dd|cc|ex|em)?',
        returnBegin: true,
        contains: [
          COMMAND1, COMMAND2,
          {
            className: 'number',
            begin: ' *=', end: '-?\\d*\\.?\\d+(pt|pc|mm|cm|in|dd|cc|ex|em)?',
            excludeBegin: true
          }
        ],
        relevance: 10
      },
      COMMAND1, COMMAND2,
      SPECIAL,
      {
        className: 'formula',
        begin: '\\$\\$', end: '\\$\\$',
        contains: [COMMAND1, COMMAND2, SPECIAL],
        relevance: 0
      },
      {
        className: 'formula',
        begin: '\\$', end: '\\$',
        contains: [COMMAND1, COMMAND2, SPECIAL],
        relevance: 0
      },
      hljs.COMMENT(
        '%',
        '$',
        {
          relevance: 0
        }
      )
    ]
  };
});

hljs.registerLanguage('thrift', function(hljs) {
  var BUILT_IN_TYPES = 'bool byte i16 i32 i64 double string binary';
  return {
    keywords: {
      keyword:
        'namespace const typedef struct enum service exception void oneway set list map required optional',
      built_in:
        BUILT_IN_TYPES,
      literal:
        'true false'
    },
    contains: [
      hljs.QUOTE_STRING_MODE,
      hljs.NUMBER_MODE,
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      {
        className: 'class',
        beginKeywords: 'struct enum service exception', end: /\{/,
        illegal: /\n/,
        contains: [
          hljs.inherit(hljs.TITLE_MODE, {
            starts: {endsWithParent: true, excludeEnd: true} // hack: eating everything after the first title
          })
        ]
      },
      {
        begin: '\\b(set|list|map)\\s*<', end: '>',
        keywords: BUILT_IN_TYPES,
        contains: ['self']
      }
    ]
  };
});

hljs.registerLanguage('tp', function(hljs) {
  var TPID = {
    className: 'number',
    begin: '[1-9][0-9]*', /* no leading zeros */
    relevance: 0
  };
  var TPLABEL = {
    className: 'comment',
    begin: ':[^\\]]+'
  };
  var TPDATA = {
    className: 'built_in',
    begin: '(AR|P|PAYLOAD|PR|R|SR|RSR|LBL|VR|UALM|MESSAGE|UTOOL|UFRAME|TIMER|\
    TIMER_OVERFLOW|JOINT_MAX_SPEED|RESUME_PROG|DIAG_REC)\\[', end: '\\]',
    contains: [
      'self',
      TPID,
      TPLABEL
    ]
  };
  var TPIO = {
    className: 'built_in',
    begin: '(AI|AO|DI|DO|F|RI|RO|UI|UO|GI|GO|SI|SO)\\[', end: '\\]',
    contains: [
      'self',
      TPID,
      hljs.QUOTE_STRING_MODE, /* for pos section at bottom */
      TPLABEL
    ]
  };

  return {
    keywords: {
      keyword:
        'ABORT ACC ADJUST AND AP_LD BREAK CALL CNT COL CONDITION CONFIG DA DB ' +
        'DIV DETECT ELSE END ENDFOR ERR_NUM ERROR_PROG FINE FOR GP GUARD INC ' +
        'IF JMP LINEAR_MAX_SPEED LOCK MOD MONITOR OFFSET Offset OR OVERRIDE ' +
        'PAUSE PREG PTH RT_LD RUN SELECT SKIP Skip TA TB TO TOOL_OFFSET ' +
        'Tool_Offset UF UT UFRAME_NUM UTOOL_NUM UNLOCK WAIT X Y Z W P R STRLEN ' +
        'SUBSTR FINDSTR VOFFSET',
      constant:
        'ON OFF max_speed LPOS JPOS ENABLE DISABLE START STOP RESET'
    },
    contains: [
      TPDATA,
      TPIO,
      {
        className: 'keyword',
        begin: '/(PROG|ATTR|MN|POS|END)\\b'
      },
      {
        /* this is for cases like ,CALL */
        className: 'keyword',
        begin: '(CALL|RUN|POINT_LOGIC|LBL)\\b'
      },
      {
        /* this is for cases like CNT100 where the default lexemes do not
         * separate the keyword and the number */
        className: 'keyword',
        begin: '\\b(ACC|CNT|Skip|Offset|PSPD|RT_LD|AP_LD|Tool_Offset)'
      },
      {
        /* to catch numbers that do not have a word boundary on the left */
        className: 'number',
        begin: '\\d+(sec|msec|mm/sec|cm/min|inch/min|deg/sec|mm|in|cm)?\\b',
        relevance: 0
      },
      hljs.COMMENT('//', '[;$]'),
      hljs.COMMENT('!', '[;$]'),
      hljs.COMMENT('--eg:', '$'),
      hljs.QUOTE_STRING_MODE,
      {
        className: 'string',
        begin: '\'', end: '\''
      },
      hljs.C_NUMBER_MODE,
      {
        className: 'variable',
        begin: '\\$[A-Za-z0-9_]+'
      }
    ]
  };
});

hljs.registerLanguage('twig', function(hljs) {
  var PARAMS = {
    className: 'params',
    begin: '\\(', end: '\\)'
  };

  var FUNCTION_NAMES = 'attribute block constant cycle date dump include ' +
                  'max min parent random range source template_from_string';

  var FUNCTIONS = {
    className: 'function',
    beginKeywords: FUNCTION_NAMES,
    relevance: 0,
    contains: [
      PARAMS
    ]
  };

  var FILTER = {
    className: 'filter',
    begin: /\|[A-Za-z_]+:?/,
    keywords:
      'abs batch capitalize convert_encoding date date_modify default ' +
      'escape first format join json_encode keys last length lower ' +
      'merge nl2br number_format raw replace reverse round slice sort split ' +
      'striptags title trim upper url_encode',
    contains: [
      FUNCTIONS
    ]
  };

  var TAGS = 'autoescape block do embed extends filter flush for ' +
    'if import include macro sandbox set spaceless use verbatim';

  TAGS = TAGS + ' ' + TAGS.split(' ').map(function(t){return 'end' + t}).join(' ');

  return {
    aliases: ['craftcms'],
    case_insensitive: true,
    subLanguage: 'xml',
    contains: [
      hljs.COMMENT(/\{#/, /#}/),
      {
        className: 'template_tag',
        begin: /\{%/, end: /%}/,
        keywords: TAGS,
        contains: [FILTER, FUNCTIONS]
      },
      {
        className: 'variable',
        begin: /\{\{/, end: /}}/,
        contains: [FILTER, FUNCTIONS]
      }
    ]
  };
});

hljs.registerLanguage('typescript', function(hljs) {
  var KEYWORDS = {
    keyword:
      'in if for while finally var new function|0 do return void else break catch ' +
      'instanceof with throw case default try this switch continue typeof delete ' +
      'let yield const class public private protected get set super ' +
      'static implements enum export import declare type namespace abstract',
    literal:
      'true false null undefined NaN Infinity',
    built_in:
      'eval isFinite isNaN parseFloat parseInt decodeURI decodeURIComponent ' +
      'encodeURI encodeURIComponent escape unescape Object Function Boolean Error ' +
      'EvalError InternalError RangeError ReferenceError StopIteration SyntaxError ' +
      'TypeError URIError Number Math Date String RegExp Array Float32Array ' +
      'Float64Array Int16Array Int32Array Int8Array Uint16Array Uint32Array ' +
      'Uint8Array Uint8ClampedArray ArrayBuffer DataView JSON Intl arguments require ' +
      'module console window document any number boolean string void'
  };

  return {
    aliases: ['ts'],
    keywords: KEYWORDS,
    contains: [
      {
        className: 'pi',
        begin: /^\s*['"]use strict['"]/,
        relevance: 0
      },
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      {
        className: 'number',
        variants: [
          { begin: '\\b(0[bB][01]+)' },
          { begin: '\\b(0[oO][0-7]+)' },
          { begin: hljs.C_NUMBER_RE }
        ],
        relevance: 0
      },
      { // "value" container
        begin: '(' + hljs.RE_STARTERS_RE + '|\\b(case|return|throw)\\b)\\s*',
        keywords: 'return throw case',
        contains: [
          hljs.C_LINE_COMMENT_MODE,
          hljs.C_BLOCK_COMMENT_MODE,
          hljs.REGEXP_MODE
        ],
        relevance: 0
      },
      {
        className: 'function',
        begin: 'function', end: /[\{;]/, excludeEnd: true,
        keywords: KEYWORDS,
        contains: [
          'self',
          hljs.inherit(hljs.TITLE_MODE, {begin: /[A-Za-z$_][0-9A-Za-z$_]*/}),
          {
            className: 'params',
            begin: /\(/, end: /\)/,
            excludeBegin: true,
            excludeEnd: true,
            keywords: KEYWORDS,
            contains: [
              hljs.C_LINE_COMMENT_MODE,
              hljs.C_BLOCK_COMMENT_MODE
            ],
            illegal: /["'\(]/
          }
        ],
        illegal: /\[|%/,
        relevance: 0 // () => {} is more typical in TypeScript
      },
      {
        className: 'constructor',
        beginKeywords: 'constructor', end: /\{/, excludeEnd: true,
        relevance: 10
      },
      {
        className: 'module',
        beginKeywords: 'module', end: /\{/, excludeEnd: true
      },
      {
        className: 'interface',
        beginKeywords: 'interface', end: /\{/, excludeEnd: true,
        keywords: 'interface extends'
      },
      {
        begin: /\$[(.]/ // relevance booster for a pattern common to JS libs: `$(something)` and `$.something`
      },
      {
        begin: '\\.' + hljs.IDENT_RE, relevance: 0 // hack: prevents detection of keywords after dots
      }
    ]
  };
});

hljs.registerLanguage('vala', function(hljs) {
  return {
    keywords: {
      keyword:
        // Value types
        'char uchar unichar int uint long ulong short ushort int8 int16 int32 int64 uint8 ' +
        'uint16 uint32 uint64 float double bool struct enum string void ' +
        // Reference types
        'weak unowned owned ' +
        // Modifiers
        'async signal static abstract interface override ' +
        // Control Structures
        'while do for foreach else switch case break default return try catch ' +
        // Visibility
        'public private protected internal ' +
        // Other
        'using new this get set const stdout stdin stderr var',
      built_in:
        'DBus GLib CCode Gee Object',
      literal:
        'false true null'
    },
    contains: [
      {
        className: 'class',
        beginKeywords: 'class interface delegate namespace', end: '{', excludeEnd: true,
        illegal: '[^,:\\n\\s\\.]',
        contains: [
          hljs.UNDERSCORE_TITLE_MODE
        ]
      },
      hljs.C_LINE_COMMENT_MODE,
      hljs.C_BLOCK_COMMENT_MODE,
      {
        className: 'string',
        begin: '"""', end: '"""',
        relevance: 5
      },
      hljs.APOS_STRING_MODE,
      hljs.QUOTE_STRING_MODE,
      hljs.C_NUMBER_MODE,
      {
        className: 'preprocessor',
        begin: '^#', end: '$',
        relevance: 2
      },
      {
        className: 'constant',
        begin: ' [A-Z_]+ ',
        relevance: 0
      }
    ]
  };
});

hljs.registerLanguage('vbnet', function(hljs) {
  return {
    aliases: ['vb'],
    case_insensitive: true,
    keywords: {
      keyword:
        'addhandler addressof alias and andalso aggregate ansi as assembly auto binary by byref byval ' + /* a-b */
        'call case catch class compare const continue custom declare default delegate dim distinct do ' + /* c-d */
        'each equals else elseif end enum erase error event exit explicit finally for friend from function ' + /* e-f */
        'get global goto group handles if implements imports in inherits interface into is isfalse isnot istrue ' + /* g-i */
        'join key let lib like loop me mid mod module mustinherit mustoverride mybase myclass ' + /* j-m */
        'namespace narrowing new next not notinheritable notoverridable ' + /* n */
        'of off on operator option optional or order orelse overloads overridable overrides ' + /* o */
        'paramarray partial preserve private property protected public ' + /* p */
        'raiseevent readonly redim rem removehandler resume return ' + /* r */
        'select set shadows shared skip static step stop structure strict sub synclock ' + /* s */
        'take text then throw to try unicode until using when where while widening with withevents writeonly xor', /* t-x */
      built_in:
        'boolean byte cbool cbyte cchar cdate cdec cdbl char cint clng cobj csbyte cshort csng cstr ctype ' +  /* b-c */
        'date decimal directcast double gettype getxmlnamespace iif integer long object ' + /* d-o */
        'sbyte short single string trycast typeof uinteger ulong ushort', /* s-u */
      literal:
        'true false nothing'
    },
    illegal: '//|{|}|endif|gosub|variant|wend', /* reserved deprecated keywords */
    contains: [
      hljs.inherit(hljs.QUOTE_STRING_MODE, {contains: [{begin: '""'}]}),
      hljs.COMMENT(
        '\'',
        '$',
        {
          returnBegin: true,
          contains: [
            {
              className: 'xmlDocTag',
              begin: '\'\'\'|<!--|-->',
              contains: [hljs.PHRASAL_WORDS_MODE]
            },
            {
              className: 'xmlDocTag',
              begin: '</?', end: '>',
              contains: [hljs.PHRASAL_WORDS_MODE]
            }
          ]
        }
      ),
      hljs.C_NUMBER_MODE,
      {
        className: 'preprocessor',
        begin: '#', end: '$',
        keywords: 'if else elseif end region externalsource'
      }
    ]
  };
});

hljs.registerLanguage('vbscript', function(hljs) {
  return {
    aliases: ['vbs'],
    case_insensitive: true,
    keywords: {
      keyword:
        'call class const dim do loop erase execute executeglobal exit for each next function ' +
        'if then else on error option explicit new private property let get public randomize ' +
        'redim rem select case set stop sub while wend with end to elseif is or xor and not ' +
        'class_initialize class_terminate default preserve in me byval byref step resume goto',
      built_in:
        'lcase month vartype instrrev ubound setlocale getobject rgb getref string ' +
        'weekdayname rnd dateadd monthname now day minute isarray cbool round formatcurrency ' +
        'conversions csng timevalue second year space abs clng timeserial fixs len asc ' +
        'isempty maths dateserial atn timer isobject filter weekday datevalue ccur isdate ' +
        'instr datediff formatdatetime replace isnull right sgn array snumeric log cdbl hex ' +
        'chr lbound msgbox ucase getlocale cos cdate cbyte rtrim join hour oct typename trim ' +
        'strcomp int createobject loadpicture tan formatnumber mid scriptenginebuildversion ' +
        'scriptengine split scriptengineminorversion cint sin datepart ltrim sqr ' +
        'scriptenginemajorversion time derived eval date formatpercent exp inputbox left ascw ' +
        'chrw regexp server response request cstr err',
      literal:
        'true false null nothing empty'
    },
    illegal: '//',
    contains: [
      hljs.inherit(hljs.QUOTE_STRING_MODE, {contains: [{begin: '""'}]}),
      hljs.COMMENT(
        /'/,
        /$/,
        {
          relevance: 0
        }
      ),
      hljs.C_NUMBER_MODE
    ]
  };
});

hljs.registerLanguage('vbscript-html', function(hljs) {
  return {
    subLanguage: 'xml',
    contains: [
      {
        begin: '<%', end: '%>',
        subLanguage: 'vbscript'
      }
    ]
  };
});

hljs.registerLanguage('verilog', function(hljs) {
  return {
    aliases: ['v'],
    case_insensitive: true,
    keywords: {
      keyword:
        'always and assign begin buf bufif0 bufif1 case casex casez cmos deassign ' +
        'default defparam disable edge else end endcase endfunction endmodule ' +
        'endprimitive endspecify endtable endtask event for force forever fork ' +
        'function if ifnone initial inout input join macromodule module nand ' +
        'negedge nmos nor not notif0 notif1 or output parameter pmos posedge ' +
        'primitive pulldown pullup rcmos release repeat rnmos rpmos rtran ' +
        'rtranif0 rtranif1 specify specparam table task timescale tran ' +
        'tranif0 tranif1 wait while xnor xor',
      typename:
        'highz0 highz1 integer large medium pull0 pull1 real realtime reg ' +
        'scalared signed small strong0 strong1 supply0 supply0 supply1 supply1 ' +
        'time tri tri0 tri1 triand trior trireg vectored wand weak0 weak1 wire wor'
    },
    contains: [
      hljs.C_BLOCK_COMMENT_MODE,
      hljs.C_LINE_COMMENT_MODE,
      hljs.QUOTE_STRING_MODE,
      {
        className: 'number',
        begin: '\\b(\\d+\'(b|h|o|d|B|H|O|D))?[0-9xzXZ]+',
        contains: [hljs.BACKSLASH_ESCAPE],
        relevance: 0
      },
      /* ports in instances */
      {
        className: 'typename',
        begin: '\\.\\w+',
        relevance: 0
      },
      /* parameters to instances */
      {
        className: 'value',
        begin: '#\\((?!parameter).+\\)'
      },
      /* operators */
      {
        className: 'keyword',
        begin: '\\+|-|\\*|/|%|<|>|=|#|`|\\!|&|\\||@|:|\\^|~|\\{|\\}',
        relevance: 0
      }
    ]
  }; // return
});

hljs.registerLanguage('vhdl', function(hljs) {
  // Regular expression for VHDL numeric literals.

  // Decimal literal:
  var INTEGER_RE = '\\d(_|\\d)*';
  var EXPONENT_RE = '[eE][-+]?' + INTEGER_RE;
  var DECIMAL_LITERAL_RE = INTEGER_RE + '(\\.' + INTEGER_RE + ')?' + '(' + EXPONENT_RE + ')?';
  // Based literal:
  var BASED_INTEGER_RE = '\\w+';
  var BASED_LITERAL_RE = INTEGER_RE + '#' + BASED_INTEGER_RE + '(\\.' + BASED_INTEGER_RE + ')?' + '#' + '(' + EXPONENT_RE + ')?';

  var NUMBER_RE = '\\b(' + BASED_LITERAL_RE + '|' + DECIMAL_LITERAL_RE + ')';

  return {
    case_insensitive: true,
    keywords: {
      keyword:
        'abs access after alias all and architecture array assert attribute begin block ' +
        'body buffer bus case component configuration constant context cover disconnect ' +
        'downto default else elsif end entity exit fairness file for force function generate ' +
        'generic group guarded if impure in inertial inout is label library linkage literal ' +
        'loop map mod nand new next nor not null of on open or others out package port ' +
        'postponed procedure process property protected pure range record register reject ' +
        'release rem report restrict restrict_guarantee return rol ror select sequence ' +
        'severity shared signal sla sll sra srl strong subtype then to transport type ' +
        'unaffected units until use variable vmode vprop vunit wait when while with xnor xor',
      typename:
        'boolean bit character severity_level integer time delay_length natural positive ' +
        'string bit_vector file_open_kind file_open_status std_ulogic std_ulogic_vector ' +
        'std_logic std_logic_vector unsigned signed boolean_vector integer_vector ' +
        'real_vector time_vector'
    },
    illegal: '{',
    contains: [
      hljs.C_BLOCK_COMMENT_MODE,        // VHDL-2008 block commenting.
      hljs.COMMENT('--', '$'),
      hljs.QUOTE_STRING_MODE,
      {
        className: 'number',
        begin: NUMBER_RE,
        relevance: 0
      },
      {
        className: 'literal',
        begin: '\'(U|X|0|1|Z|W|L|H|-)\'',
        contains: [hljs.BACKSLASH_ESCAPE]
      },
      {
        className: 'attribute',
        begin: '\'[A-Za-z](_?[A-Za-z0-9])*',
        contains: [hljs.BACKSLASH_ESCAPE]
      }
    ]
  };
});

hljs.registerLanguage('vim', function(hljs) {
  return {
    lexemes: /[!#@\w]+/,
    keywords: {
      keyword: //ex command
        // express version except: ! & * < = > !! # @ @@
        'N|0 P|0 X|0 a|0 ab abc abo al am an|0 ar arga argd arge argdo argg argl argu as au aug aun b|0 bN ba bad bd be bel bf bl bm bn bo bp br brea breaka breakd breakl bro bufdo buffers bun bw c|0 cN cNf ca cabc caddb cad caddf cal cat cb cc ccl cd ce cex cf cfir cgetb cgete cg changes chd che checkt cl cla clo cm cmapc cme cn cnew cnf cno cnorea cnoreme co col colo com comc comp con conf cope '+
        'cp cpf cq cr cs cst cu cuna cunme cw d|0 delm deb debugg delc delf dif diffg diffo diffp diffpu diffs diffthis dig di dl dell dj dli do doautoa dp dr ds dsp e|0 ea ec echoe echoh echom echon el elsei em en endfo endf endt endw ene ex exe exi exu f|0 files filet fin fina fini fir fix fo foldc foldd folddoc foldo for fu g|0 go gr grepa gu gv ha h|0 helpf helpg helpt hi hid his i|0 ia iabc if ij il im imapc '+
        'ime ino inorea inoreme int is isp iu iuna iunme j|0 ju k|0 keepa kee keepj lN lNf l|0 lad laddb laddf la lan lat lb lc lch lcl lcs le lefta let lex lf lfir lgetb lgete lg lgr lgrepa lh ll lla lli lmak lm lmapc lne lnew lnf ln loadk lo loc lockv lol lope lp lpf lr ls lt lu lua luad luaf lv lvimgrepa lw m|0 ma mak map mapc marks mat me menut mes mk mks mksp mkv mkvie mod mz mzf nbc nb nbs n|0 new nm nmapc nme nn nnoreme noa no noh norea noreme norm nu nun nunme ol o|0 om omapc ome on ono onoreme opt ou ounme ow p|0 '+
        'profd prof pro promptr pc ped pe perld po popu pp pre prev ps pt ptN ptf ptj ptl ptn ptp ptr pts pu pw py3 python3 py3d py3f py pyd pyf q|0 quita qa r|0 rec red redi redr redraws reg res ret retu rew ri rightb rub rubyd rubyf rund ru rv s|0 sN san sa sal sav sb sbN sba sbf sbl sbm sbn sbp sbr scrip scripte scs se setf setg setl sf sfir sh sim sig sil sl sla sm smap smapc sme sn sni sno snor snoreme sor '+
        'so spelld spe spelli spellr spellu spellw sp spr sre st sta startg startr star stopi stj sts sun sunm sunme sus sv sw sy synti sync t|0 tN tabN tabc tabdo tabe tabf tabfir tabl tabm tabnew '+
        'tabn tabo tabp tabr tabs tab ta tags tc tcld tclf te tf th tj tl tm tn to tp tr try ts tu u|0 undoj undol una unh unl unlo unm unme uns up v|0 ve verb vert vim vimgrepa vi viu vie vm vmapc vme vne vn vnoreme vs vu vunme windo w|0 wN wa wh wi winc winp wn wp wq wqa ws wu wv x|0 xa xmapc xm xme xn xnoreme xu xunme y|0 z|0 ~ '+
        // full version
        'Next Print append abbreviate abclear aboveleft all amenu anoremenu args argadd argdelete argedit argglobal arglocal argument ascii autocmd augroup aunmenu buffer bNext ball badd bdelete behave belowright bfirst blast bmodified bnext botright bprevious brewind break breakadd breakdel breaklist browse bunload '+
        'bwipeout change cNext cNfile cabbrev cabclear caddbuffer caddexpr caddfile call catch cbuffer cclose center cexpr cfile cfirst cgetbuffer cgetexpr cgetfile chdir checkpath checktime clist clast close cmap cmapclear cmenu cnext cnewer cnfile cnoremap cnoreabbrev cnoremenu copy colder colorscheme command comclear compiler continue confirm copen cprevious cpfile cquit crewind cscope cstag cunmap '+
        'cunabbrev cunmenu cwindow delete delmarks debug debuggreedy delcommand delfunction diffupdate diffget diffoff diffpatch diffput diffsplit digraphs display deletel djump dlist doautocmd doautoall deletep drop dsearch dsplit edit earlier echo echoerr echohl echomsg else elseif emenu endif endfor '+
        'endfunction endtry endwhile enew execute exit exusage file filetype find finally finish first fixdel fold foldclose folddoopen folddoclosed foldopen function global goto grep grepadd gui gvim hardcopy help helpfind helpgrep helptags highlight hide history insert iabbrev iabclear ijump ilist imap '+
        'imapclear imenu inoremap inoreabbrev inoremenu intro isearch isplit iunmap iunabbrev iunmenu join jumps keepalt keepmarks keepjumps lNext lNfile list laddexpr laddbuffer laddfile last language later lbuffer lcd lchdir lclose lcscope left leftabove lexpr lfile lfirst lgetbuffer lgetexpr lgetfile lgrep lgrepadd lhelpgrep llast llist lmake lmap lmapclear lnext lnewer lnfile lnoremap loadkeymap loadview '+
        'lockmarks lockvar lolder lopen lprevious lpfile lrewind ltag lunmap luado luafile lvimgrep lvimgrepadd lwindow move mark make mapclear match menu menutranslate messages mkexrc mksession mkspell mkvimrc mkview mode mzscheme mzfile nbclose nbkey nbsart next nmap nmapclear nmenu nnoremap '+
        'nnoremenu noautocmd noremap nohlsearch noreabbrev noremenu normal number nunmap nunmenu oldfiles open omap omapclear omenu only onoremap onoremenu options ounmap ounmenu ownsyntax print profdel profile promptfind promptrepl pclose pedit perl perldo pop popup ppop preserve previous psearch ptag ptNext '+
        'ptfirst ptjump ptlast ptnext ptprevious ptrewind ptselect put pwd py3do py3file python pydo pyfile quit quitall qall read recover redo redir redraw redrawstatus registers resize retab return rewind right rightbelow ruby rubydo rubyfile rundo runtime rviminfo substitute sNext sandbox sargument sall saveas sbuffer sbNext sball sbfirst sblast sbmodified sbnext sbprevious sbrewind scriptnames scriptencoding '+
        'scscope set setfiletype setglobal setlocal sfind sfirst shell simalt sign silent sleep slast smagic smapclear smenu snext sniff snomagic snoremap snoremenu sort source spelldump spellgood spellinfo spellrepall spellundo spellwrong split sprevious srewind stop stag startgreplace startreplace '+
        'startinsert stopinsert stjump stselect sunhide sunmap sunmenu suspend sview swapname syntax syntime syncbind tNext tabNext tabclose tabedit tabfind tabfirst tablast tabmove tabnext tabonly tabprevious tabrewind tag tcl tcldo tclfile tearoff tfirst throw tjump tlast tmenu tnext topleft tprevious '+'trewind tselect tunmenu undo undojoin undolist unabbreviate unhide unlet unlockvar unmap unmenu unsilent update vglobal version verbose vertical vimgrep vimgrepadd visual viusage view vmap vmapclear vmenu vnew '+
        'vnoremap vnoremenu vsplit vunmap vunmenu write wNext wall while winsize wincmd winpos wnext wprevious wqall wsverb wundo wviminfo xit xall xmapclear xmap xmenu xnoremap xnoremenu xunmap xunmenu yank',
      built_in: //built in func
        'abs acos add and append argc argidx argv asin atan atan2 browse browsedir bufexists buflisted bufloaded bufname bufnr bufwinnr byte2line byteidx call ceil changenr char2nr cindent clearmatches col complete complete_add complete_check confirm copy cos cosh count cscope_connection cursor '+
        'deepcopy delete did_filetype diff_filler diff_hlID empty escape eval eventhandler executable exists exp expand extend feedkeys filereadable filewritable filter finddir findfile float2nr floor fmod fnameescape fnamemodify foldclosed foldclosedend foldlevel foldtext foldtextresult foreground function '+
        'garbagecollect get getbufline getbufvar getchar getcharmod getcmdline getcmdpos getcmdtype getcwd getfontname getfperm getfsize getftime getftype getline getloclist getmatches getpid getpos getqflist getreg getregtype gettabvar gettabwinvar getwinposx getwinposy getwinvar glob globpath has has_key '+
        'haslocaldir hasmapto histadd histdel histget histnr hlexists hlID hostname iconv indent index input inputdialog inputlist inputrestore inputsave inputsecret insert invert isdirectory islocked items join keys len libcall libcallnr line line2byte lispindent localtime log log10 luaeval map maparg mapcheck '+
        'match matchadd matcharg matchdelete matchend matchlist matchstr max min mkdir mode mzeval nextnonblank nr2char or pathshorten pow prevnonblank printf pumvisible py3eval pyeval range readfile reltime reltimestr remote_expr remote_foreground remote_peek remote_read remote_send remove rename repeat '+
        'resolve reverse round screenattr screenchar screencol screenrow search searchdecl searchpair searchpairpos searchpos server2client serverlist setbufvar setcmdpos setline setloclist setmatches setpos setqflist setreg settabvar settabwinvar setwinvar sha256 shellescape shiftwidth simplify sin '+
        'sinh sort soundfold spellbadword spellsuggest split sqrt str2float str2nr strchars strdisplaywidth strftime stridx string strlen strpart strridx strtrans strwidth submatch substitute synconcealed synID synIDattr '+
        'synIDtrans synstack system tabpagebuflist tabpagenr tabpagewinnr tagfiles taglist tan tanh tempname tolower toupper tr trunc type undofile undotree values virtcol visualmode wildmenumode winbufnr wincol winheight winline winnr winrestcmd winrestview winsaveview winwidth writefile xor'
    },
    illegal: /[{:]/,
    contains: [
      hljs.NUMBER_MODE,
      hljs.APOS_STRING_MODE,
      {
        className: 'string',
        // quote with escape, comment as quote
        begin: /"((\\")|[^"\n])*("|\n)/
      },
      {
        className: 'variable',
        begin: /[bwtglsav]:[\w\d_]*/
      },
      {
        className: 'function',
        beginKeywords: 'function function!', end: '$',
        relevance: 0,
        contains: [
          hljs.TITLE_MODE,
          {
            className: 'params',
            begin: '\\(', end: '\\)'
          }
        ]
      }
    ]
  };
});

hljs.registerLanguage('x86asm', function(hljs) {
  return {
    case_insensitive: true,
    lexemes: '\\.?' + hljs.IDENT_RE,
    keywords: {
      keyword:
        'lock rep repe repz repne repnz xaquire xrelease bnd nobnd ' +
        'aaa aad aam aas adc add and arpl bb0_reset bb1_reset bound bsf bsr bswap bt btc btr bts call cbw cdq cdqe clc cld cli clts cmc cmp cmpsb cmpsd cmpsq cmpsw cmpxchg cmpxchg486 cmpxchg8b cmpxchg16b cpuid cpu_read cpu_write cqo cwd cwde daa das dec div dmint emms enter equ f2xm1 fabs fadd faddp fbld fbstp fchs fclex fcmovb fcmovbe fcmove fcmovnb fcmovnbe fcmovne fcmovnu fcmovu fcom fcomi fcomip fcomp fcompp fcos fdecstp fdisi fdiv fdivp fdivr fdivrp femms feni ffree ffreep fiadd ficom ficomp fidiv fidivr fild fimul fincstp finit fist fistp fisttp fisub fisubr fld fld1 fldcw fldenv fldl2e fldl2t fldlg2 fldln2 fldpi fldz fmul fmulp fnclex fndisi fneni fninit fnop fnsave fnstcw fnstenv fnstsw fpatan fprem fprem1 fptan frndint frstor fsave fscale fsetpm fsin fsincos fsqrt fst fstcw fstenv fstp fstsw fsub fsubp fsubr fsubrp ftst fucom fucomi fucomip fucomp fucompp fxam fxch fxtract fyl2x fyl2xp1 hlt ibts icebp idiv imul in inc incbin insb insd insw int int01 int1 int03 int3 into invd invpcid invlpg invlpga iret iretd iretq iretw jcxz jecxz jrcxz jmp jmpe lahf lar lds lea leave les lfence lfs lgdt lgs lidt lldt lmsw loadall loadall286 lodsb lodsd lodsq lodsw loop loope loopne loopnz loopz lsl lss ltr mfence monitor mov movd movq movsb movsd movsq movsw movsx movsxd movzx mul mwait neg nop not or out outsb outsd outsw packssdw packsswb packuswb paddb paddd paddsb paddsiw paddsw paddusb paddusw paddw pand pandn pause paveb pavgusb pcmpeqb pcmpeqd pcmpeqw pcmpgtb pcmpgtd pcmpgtw pdistib pf2id pfacc pfadd pfcmpeq pfcmpge pfcmpgt pfmax pfmin pfmul pfrcp pfrcpit1 pfrcpit2 pfrsqit1 pfrsqrt pfsub pfsubr pi2fd pmachriw pmaddwd pmagw pmulhriw pmulhrwa pmulhrwc pmulhw pmullw pmvgezb pmvlzb pmvnzb pmvzb pop popa popad popaw popf popfd popfq popfw por prefetch prefetchw pslld psllq psllw psrad psraw psrld psrlq psrlw psubb psubd psubsb psubsiw psubsw psubusb psubusw psubw punpckhbw punpckhdq punpckhwd punpcklbw punpckldq punpcklwd push pusha pushad pushaw pushf pushfd pushfq pushfw pxor rcl rcr rdshr rdmsr rdpmc rdtsc rdtscp ret retf retn rol ror rdm rsdc rsldt rsm rsts sahf sal salc sar sbb scasb scasd scasq scasw sfence sgdt shl shld shr shrd sidt sldt skinit smi smint smintold smsw stc std sti stosb stosd stosq stosw str sub svdc svldt svts swapgs syscall sysenter sysexit sysret test ud0 ud1 ud2b ud2 ud2a umov verr verw fwait wbinvd wrshr wrmsr xadd xbts xchg xlatb xlat xor cmove cmovz cmovne cmovnz cmova cmovnbe cmovae cmovnb cmovb cmovnae cmovbe cmovna cmovg cmovnle cmovge cmovnl cmovl cmovnge cmovle cmovng cmovc cmovnc cmovo cmovno cmovs cmovns cmovp cmovpe cmovnp cmovpo je jz jne jnz ja jnbe jae jnb jb jnae jbe jna jg jnle jge jnl jl jnge jle jng jc jnc jo jno js jns jpo jnp jpe jp sete setz setne setnz seta setnbe setae setnb setnc setb setnae setcset setbe setna setg setnle setge setnl setl setnge setle setng sets setns seto setno setpe setp setpo setnp addps addss andnps andps cmpeqps cmpeqss cmpleps cmpless cmpltps cmpltss cmpneqps cmpneqss cmpnleps cmpnless cmpnltps cmpnltss cmpordps cmpordss cmpunordps cmpunordss cmpps cmpss comiss cvtpi2ps cvtps2pi cvtsi2ss cvtss2si cvttps2pi cvttss2si divps divss ldmxcsr maxps maxss minps minss movaps movhps movlhps movlps movhlps movmskps movntps movss movups mulps mulss orps rcpps rcpss rsqrtps rsqrtss shufps sqrtps sqrtss stmxcsr subps subss ucomiss unpckhps unpcklps xorps fxrstor fxrstor64 fxsave fxsave64 xgetbv xsetbv xsave xsave64 xsaveopt xsaveopt64 xrstor xrstor64 prefetchnta prefetcht0 prefetcht1 prefetcht2 maskmovq movntq pavgb pavgw pextrw pinsrw pmaxsw pmaxub pminsw pminub pmovmskb pmulhuw psadbw pshufw pf2iw pfnacc pfpnacc pi2fw pswapd maskmovdqu clflush movntdq movnti movntpd movdqa movdqu movdq2q movq2dq paddq pmuludq pshufd pshufhw pshuflw pslldq psrldq psubq punpckhqdq punpcklqdq addpd addsd andnpd andpd cmpeqpd cmpeqsd cmplepd cmplesd cmpltpd cmpltsd cmpneqpd cmpneqsd cmpnlepd cmpnlesd cmpnltpd cmpnltsd cmpordpd cmpordsd cmpunordpd cmpunordsd cmppd comisd cvtdq2pd cvtdq2ps cvtpd2dq cvtpd2pi cvtpd2ps cvtpi2pd cvtps2dq cvtps2pd cvtsd2si cvtsd2ss cvtsi2sd cvtss2sd cvttpd2pi cvttpd2dq cvttps2dq cvttsd2si divpd divsd maxpd maxsd minpd minsd movapd movhpd movlpd movmskpd movupd mulpd mulsd orpd shufpd sqrtpd sqrtsd subpd subsd ucomisd unpckhpd unpcklpd xorpd addsubpd addsubps haddpd haddps hsubpd hsubps lddqu movddup movshdup movsldup clgi stgi vmcall vmclear vmfunc vmlaunch vmload vmmcall vmptrld vmptrst vmread vmresume vmrun vmsave vmwrite vmxoff vmxon invept invvpid pabsb pabsw pabsd palignr phaddw phaddd phaddsw phsubw phsubd phsubsw pmaddubsw pmulhrsw pshufb psignb psignw psignd extrq insertq movntsd movntss lzcnt blendpd blendps blendvpd blendvps dppd dpps extractps insertps movntdqa mpsadbw packusdw pblendvb pblendw pcmpeqq pextrb pextrd pextrq phminposuw pinsrb pinsrd pinsrq pmaxsb pmaxsd pmaxud pmaxuw pminsb pminsd pminud pminuw pmovsxbw pmovsxbd pmovsxbq pmovsxwd pmovsxwq pmovsxdq pmovzxbw pmovzxbd pmovzxbq pmovzxwd pmovzxwq pmovzxdq pmuldq pmulld ptest roundpd roundps roundsd roundss crc32 pcmpestri pcmpestrm pcmpistri pcmpistrm pcmpgtq popcnt getsec pfrcpv pfrsqrtv movbe aesenc aesenclast aesdec aesdeclast aesimc aeskeygenassist vaesenc vaesenclast vaesdec vaesdeclast vaesimc vaeskeygenassist vaddpd vaddps vaddsd vaddss vaddsubpd vaddsubps vandpd vandps vandnpd vandnps vblendpd vblendps vblendvpd vblendvps vbroadcastss vbroadcastsd vbroadcastf128 vcmpeq_ospd vcmpeqpd vcmplt_ospd vcmpltpd vcmple_ospd vcmplepd vcmpunord_qpd vcmpunordpd vcmpneq_uqpd vcmpneqpd vcmpnlt_uspd vcmpnltpd vcmpnle_uspd vcmpnlepd vcmpord_qpd vcmpordpd vcmpeq_uqpd vcmpnge_uspd vcmpngepd vcmpngt_uspd vcmpngtpd vcmpfalse_oqpd vcmpfalsepd vcmpneq_oqpd vcmpge_ospd vcmpgepd vcmpgt_ospd vcmpgtpd vcmptrue_uqpd vcmptruepd vcmplt_oqpd vcmple_oqpd vcmpunord_spd vcmpneq_uspd vcmpnlt_uqpd vcmpnle_uqpd vcmpord_spd vcmpeq_uspd vcmpnge_uqpd vcmpngt_uqpd vcmpfalse_ospd vcmpneq_ospd vcmpge_oqpd vcmpgt_oqpd vcmptrue_uspd vcmppd vcmpeq_osps vcmpeqps vcmplt_osps vcmpltps vcmple_osps vcmpleps vcmpunord_qps vcmpunordps vcmpneq_uqps vcmpneqps vcmpnlt_usps vcmpnltps vcmpnle_usps vcmpnleps vcmpord_qps vcmpordps vcmpeq_uqps vcmpnge_usps vcmpngeps vcmpngt_usps vcmpngtps vcmpfalse_oqps vcmpfalseps vcmpneq_oqps vcmpge_osps vcmpgeps vcmpgt_osps vcmpgtps vcmptrue_uqps vcmptrueps vcmplt_oqps vcmple_oqps vcmpunord_sps vcmpneq_usps vcmpnlt_uqps vcmpnle_uqps vcmpord_sps vcmpeq_usps vcmpnge_uqps vcmpngt_uqps vcmpfalse_osps vcmpneq_osps vcmpge_oqps vcmpgt_oqps vcmptrue_usps vcmpps vcmpeq_ossd vcmpeqsd vcmplt_ossd vcmpltsd vcmple_ossd vcmplesd vcmpunord_qsd vcmpunordsd vcmpneq_uqsd vcmpneqsd vcmpnlt_ussd vcmpnltsd vcmpnle_ussd vcmpnlesd vcmpord_qsd vcmpordsd vcmpeq_uqsd vcmpnge_ussd vcmpngesd vcmpngt_ussd vcmpngtsd vcmpfalse_oqsd vcmpfalsesd vcmpneq_oqsd vcmpge_ossd vcmpgesd vcmpgt_ossd vcmpgtsd vcmptrue_uqsd vcmptruesd vcmplt_oqsd vcmple_oqsd vcmpunord_ssd vcmpneq_ussd vcmpnlt_uqsd vcmpnle_uqsd vcmpord_ssd vcmpeq_ussd vcmpnge_uqsd vcmpngt_uqsd vcmpfalse_ossd vcmpneq_ossd vcmpge_oqsd vcmpgt_oqsd vcmptrue_ussd vcmpsd vcmpeq_osss vcmpeqss vcmplt_osss vcmpltss vcmple_osss vcmpless vcmpunord_qss vcmpunordss vcmpneq_uqss vcmpneqss vcmpnlt_usss vcmpnltss vcmpnle_usss vcmpnless vcmpord_qss vcmpordss vcmpeq_uqss vcmpnge_usss vcmpngess vcmpngt_usss vcmpngtss vcmpfalse_oqss vcmpfalsess vcmpneq_oqss vcmpge_osss vcmpgess vcmpgt_osss vcmpgtss vcmptrue_uqss vcmptruess vcmplt_oqss vcmple_oqss vcmpunord_sss vcmpneq_usss vcmpnlt_uqss vcmpnle_uqss vcmpord_sss vcmpeq_usss vcmpnge_uqss vcmpngt_uqss vcmpfalse_osss vcmpneq_osss vcmpge_oqss vcmpgt_oqss vcmptrue_usss vcmpss vcomisd vcomiss vcvtdq2pd vcvtdq2ps vcvtpd2dq vcvtpd2ps vcvtps2dq vcvtps2pd vcvtsd2si vcvtsd2ss vcvtsi2sd vcvtsi2ss vcvtss2sd vcvtss2si vcvttpd2dq vcvttps2dq vcvttsd2si vcvttss2si vdivpd vdivps vdivsd vdivss vdppd vdpps vextractf128 vextractps vhaddpd vhaddps vhsubpd vhsubps vinsertf128 vinsertps vlddqu vldqqu vldmxcsr vmaskmovdqu vmaskmovps vmaskmovpd vmaxpd vmaxps vmaxsd vmaxss vminpd vminps vminsd vminss vmovapd vmovaps vmovd vmovq vmovddup vmovdqa vmovqqa vmovdqu vmovqqu vmovhlps vmovhpd vmovhps vmovlhps vmovlpd vmovlps vmovmskpd vmovmskps vmovntdq vmovntqq vmovntdqa vmovntpd vmovntps vmovsd vmovshdup vmovsldup vmovss vmovupd vmovups vmpsadbw vmulpd vmulps vmulsd vmulss vorpd vorps vpabsb vpabsw vpabsd vpacksswb vpackssdw vpackuswb vpackusdw vpaddb vpaddw vpaddd vpaddq vpaddsb vpaddsw vpaddusb vpaddusw vpalignr vpand vpandn vpavgb vpavgw vpblendvb vpblendw vpcmpestri vpcmpestrm vpcmpistri vpcmpistrm vpcmpeqb vpcmpeqw vpcmpeqd vpcmpeqq vpcmpgtb vpcmpgtw vpcmpgtd vpcmpgtq vpermilpd vpermilps vperm2f128 vpextrb vpextrw vpextrd vpextrq vphaddw vphaddd vphaddsw vphminposuw vphsubw vphsubd vphsubsw vpinsrb vpinsrw vpinsrd vpinsrq vpmaddwd vpmaddubsw vpmaxsb vpmaxsw vpmaxsd vpmaxub vpmaxuw vpmaxud vpminsb vpminsw vpminsd vpminub vpminuw vpminud vpmovmskb vpmovsxbw vpmovsxbd vpmovsxbq vpmovsxwd vpmovsxwq vpmovsxdq vpmovzxbw vpmovzxbd vpmovzxbq vpmovzxwd vpmovzxwq vpmovzxdq vpmulhuw vpmulhrsw vpmulhw vpmullw vpmulld vpmuludq vpmuldq vpor vpsadbw vpshufb vpshufd vpshufhw vpshuflw vpsignb vpsignw vpsignd vpslldq vpsrldq vpsllw vpslld vpsllq vpsraw vpsrad vpsrlw vpsrld vpsrlq vptest vpsubb vpsubw vpsubd vpsubq vpsubsb vpsubsw vpsubusb vpsubusw vpunpckhbw vpunpckhwd vpunpckhdq vpunpckhqdq vpunpcklbw vpunpcklwd vpunpckldq vpunpcklqdq vpxor vrcpps vrcpss vrsqrtps vrsqrtss vroundpd vroundps vroundsd vroundss vshufpd vshufps vsqrtpd vsqrtps vsqrtsd vsqrtss vstmxcsr vsubpd vsubps vsubsd vsubss vtestps vtestpd vucomisd vucomiss vunpckhpd vunpckhps vunpcklpd vunpcklps vxorpd vxorps vzeroall vzeroupper pclmullqlqdq pclmulhqlqdq pclmullqhqdq pclmulhqhqdq pclmulqdq vpclmullqlqdq vpclmulhqlqdq vpclmullqhqdq vpclmulhqhqdq vpclmulqdq vfmadd132ps vfmadd132pd vfmadd312ps vfmadd312pd vfmadd213ps vfmadd213pd vfmadd123ps vfmadd123pd vfmadd231ps vfmadd231pd vfmadd321ps vfmadd321pd vfmaddsub132ps vfmaddsub132pd vfmaddsub312ps vfmaddsub312pd vfmaddsub213ps vfmaddsub213pd vfmaddsub123ps vfmaddsub123pd vfmaddsub231ps vfmaddsub231pd vfmaddsub321ps vfmaddsub321pd vfmsub132ps vfmsub132pd vfmsub312ps vfmsub312pd vfmsub213ps vfmsub213pd vfmsub123ps vfmsub123pd vfmsub231ps vfmsub231pd vfmsub321ps vfmsub321pd vfmsubadd132ps vfmsubadd132pd vfmsubadd312ps vfmsubadd312pd vfmsubadd213ps vfmsubadd213pd vfmsubadd123ps vfmsubadd123pd vfmsubadd231ps vfmsubadd231pd vfmsubadd321ps vfmsubadd321pd vfnmadd132ps vfnmadd132pd vfnmadd312ps vfnmadd312pd vfnmadd213ps vfnmadd213pd vfnmadd123ps vfnmadd123pd vfnmadd231ps vfnmadd231pd vfnmadd321ps vfnmadd321pd vfnmsub132ps vfnmsub132pd vfnmsub312ps vfnmsub312pd vfnmsub213ps vfnmsub213pd vfnmsub123ps vfnmsub123pd vfnmsub231ps vfnmsub231pd vfnmsub321ps vfnmsub321pd vfmadd132ss vfmadd132sd vfmadd312ss vfmadd312sd vfmadd213ss vfmadd213sd vfmadd123ss vfmadd123sd vfmadd231ss vfmadd231sd vfmadd321ss vfmadd321sd vfmsub132ss vfmsub132sd vfmsub312ss vfmsub312sd vfmsub213ss vfmsub213sd vfmsub123ss vfmsub123sd vfmsub231ss vfmsub231sd vfmsub321ss vfmsub321sd vfnmadd132ss vfnmadd132sd vfnmadd312ss vfnmadd312sd vfnmadd213ss vfnmadd213sd vfnmadd123ss vfnmadd123sd vfnmadd231ss vfnmadd231sd vfnmadd321ss vfnmadd321sd vfnmsub132ss vfnmsub132sd vfnmsub312ss vfnmsub312sd vfnmsub213ss vfnmsub213sd vfnmsub123ss vfnmsub123sd vfnmsub231ss vfnmsub231sd vfnmsub321ss vfnmsub321sd rdfsbase rdgsbase rdrand wrfsbase wrgsbase vcvtph2ps vcvtps2ph adcx adox rdseed clac stac xstore xcryptecb xcryptcbc xcryptctr xcryptcfb xcryptofb montmul xsha1 xsha256 llwpcb slwpcb lwpval lwpins vfmaddpd vfmaddps vfmaddsd vfmaddss vfmaddsubpd vfmaddsubps vfmsubaddpd vfmsubaddps vfmsubpd vfmsubps vfmsubsd vfmsubss vfnmaddpd vfnmaddps vfnmaddsd vfnmaddss vfnmsubpd vfnmsubps vfnmsubsd vfnmsubss vfrczpd vfrczps vfrczsd vfrczss vpcmov vpcomb vpcomd vpcomq vpcomub vpcomud vpcomuq vpcomuw vpcomw vphaddbd vphaddbq vphaddbw vphadddq vphaddubd vphaddubq vphaddubw vphaddudq vphadduwd vphadduwq vphaddwd vphaddwq vphsubbw vphsubdq vphsubwd vpmacsdd vpmacsdqh vpmacsdql vpmacssdd vpmacssdqh vpmacssdql vpmacsswd vpmacssww vpmacswd vpmacsww vpmadcsswd vpmadcswd vpperm vprotb vprotd vprotq vprotw vpshab vpshad vpshaq vpshaw vpshlb vpshld vpshlq vpshlw vbroadcasti128 vpblendd vpbroadcastb vpbroadcastw vpbroadcastd vpbroadcastq vpermd vpermpd vpermps vpermq vperm2i128 vextracti128 vinserti128 vpmaskmovd vpmaskmovq vpsllvd vpsllvq vpsravd vpsrlvd vpsrlvq vgatherdpd vgatherqpd vgatherdps vgatherqps vpgatherdd vpgatherqd vpgatherdq vpgatherqq xabort xbegin xend xtest andn bextr blci blcic blsi blsic blcfill blsfill blcmsk blsmsk blsr blcs bzhi mulx pdep pext rorx sarx shlx shrx tzcnt tzmsk t1mskc valignd valignq vblendmpd vblendmps vbroadcastf32x4 vbroadcastf64x4 vbroadcasti32x4 vbroadcasti64x4 vcompresspd vcompressps vcvtpd2udq vcvtps2udq vcvtsd2usi vcvtss2usi vcvttpd2udq vcvttps2udq vcvttsd2usi vcvttss2usi vcvtudq2pd vcvtudq2ps vcvtusi2sd vcvtusi2ss vexpandpd vexpandps vextractf32x4 vextractf64x4 vextracti32x4 vextracti64x4 vfixupimmpd vfixupimmps vfixupimmsd vfixupimmss vgetexppd vgetexpps vgetexpsd vgetexpss vgetmantpd vgetmantps vgetmantsd vgetmantss vinsertf32x4 vinsertf64x4 vinserti32x4 vinserti64x4 vmovdqa32 vmovdqa64 vmovdqu32 vmovdqu64 vpabsq vpandd vpandnd vpandnq vpandq vpblendmd vpblendmq vpcmpltd vpcmpled vpcmpneqd vpcmpnltd vpcmpnled vpcmpd vpcmpltq vpcmpleq vpcmpneqq vpcmpnltq vpcmpnleq vpcmpq vpcmpequd vpcmpltud vpcmpleud vpcmpnequd vpcmpnltud vpcmpnleud vpcmpud vpcmpequq vpcmpltuq vpcmpleuq vpcmpnequq vpcmpnltuq vpcmpnleuq vpcmpuq vpcompressd vpcompressq vpermi2d vpermi2pd vpermi2ps vpermi2q vpermt2d vpermt2pd vpermt2ps vpermt2q vpexpandd vpexpandq vpmaxsq vpmaxuq vpminsq vpminuq vpmovdb vpmovdw vpmovqb vpmovqd vpmovqw vpmovsdb vpmovsdw vpmovsqb vpmovsqd vpmovsqw vpmovusdb vpmovusdw vpmovusqb vpmovusqd vpmovusqw vpord vporq vprold vprolq vprolvd vprolvq vprord vprorq vprorvd vprorvq vpscatterdd vpscatterdq vpscatterqd vpscatterqq vpsraq vpsravq vpternlogd vpternlogq vptestmd vptestmq vptestnmd vptestnmq vpxord vpxorq vrcp14pd vrcp14ps vrcp14sd vrcp14ss vrndscalepd vrndscaleps vrndscalesd vrndscaless vrsqrt14pd vrsqrt14ps vrsqrt14sd vrsqrt14ss vscalefpd vscalefps vscalefsd vscalefss vscatterdpd vscatterdps vscatterqpd vscatterqps vshuff32x4 vshuff64x2 vshufi32x4 vshufi64x2 kandnw kandw kmovw knotw kortestw korw kshiftlw kshiftrw kunpckbw kxnorw kxorw vpbroadcastmb2q vpbroadcastmw2d vpconflictd vpconflictq vplzcntd vplzcntq vexp2pd vexp2ps vrcp28pd vrcp28ps vrcp28sd vrcp28ss vrsqrt28pd vrsqrt28ps vrsqrt28sd vrsqrt28ss vgatherpf0dpd vgatherpf0dps vgatherpf0qpd vgatherpf0qps vgatherpf1dpd vgatherpf1dps vgatherpf1qpd vgatherpf1qps vscatterpf0dpd vscatterpf0dps vscatterpf0qpd vscatterpf0qps vscatterpf1dpd vscatterpf1dps vscatterpf1qpd vscatterpf1qps prefetchwt1 bndmk bndcl bndcu bndcn bndmov bndldx bndstx sha1rnds4 sha1nexte sha1msg1 sha1msg2 sha256rnds2 sha256msg1 sha256msg2 hint_nop0 hint_nop1 hint_nop2 hint_nop3 hint_nop4 hint_nop5 hint_nop6 hint_nop7 hint_nop8 hint_nop9 hint_nop10 hint_nop11 hint_nop12 hint_nop13 hint_nop14 hint_nop15 hint_nop16 hint_nop17 hint_nop18 hint_nop19 hint_nop20 hint_nop21 hint_nop22 hint_nop23 hint_nop24 hint_nop25 hint_nop26 hint_nop27 hint_nop28 hint_nop29 hint_nop30 hint_nop31 hint_nop32 hint_nop33 hint_nop34 hint_nop35 hint_nop36 hint_nop37 hint_nop38 hint_nop39 hint_nop40 hint_nop41 hint_nop42 hint_nop43 hint_nop44 hint_nop45 hint_nop46 hint_nop47 hint_nop48 hint_nop49 hint_nop50 hint_nop51 hint_nop52 hint_nop53 hint_nop54 hint_nop55 hint_nop56 hint_nop57 hint_nop58 hint_nop59 hint_nop60 hint_nop61 hint_nop62 hint_nop63',
      literal:
        // Instruction pointer
        'ip eip rip ' +
        // 8-bit registers
        'al ah bl bh cl ch dl dh sil dil bpl spl r8b r9b r10b r11b r12b r13b r14b r15b ' +
        // 16-bit registers
        'ax bx cx dx si di bp sp r8w r9w r10w r11w r12w r13w r14w r15w ' +
        // 32-bit registers
        'eax ebx ecx edx esi edi ebp esp eip r8d r9d r10d r11d r12d r13d r14d r15d ' +
        // 64-bit registers
        'rax rbx rcx rdx rsi rdi rbp rsp r8 r9 r10 r11 r12 r13 r14 r15 ' +
        // Segment registers
        'cs ds es fs gs ss ' +
        // Floating point stack registers
        'st st0 st1 st2 st3 st4 st5 st6 st7 ' +
        // MMX Registers
        'mm0 mm1 mm2 mm3 mm4 mm5 mm6 mm7 ' +
        // SSE registers
        'xmm0  xmm1  xmm2  xmm3  xmm4  xmm5  xmm6  xmm7  xmm8  xmm9 xmm10  xmm11 xmm12 xmm13 xmm14 xmm15 ' +
        'xmm16 xmm17 xmm18 xmm19 xmm20 xmm21 xmm22 xmm23 xmm24 xmm25 xmm26 xmm27 xmm28 xmm29 xmm30 xmm31 ' +
        // AVX registers
        'ymm0  ymm1  ymm2  ymm3  ymm4  ymm5  ymm6  ymm7  ymm8  ymm9 ymm10  ymm11 ymm12 ymm13 ymm14 ymm15 ' +
        'ymm16 ymm17 ymm18 ymm19 ymm20 ymm21 ymm22 ymm23 ymm24 ymm25 ymm26 ymm27 ymm28 ymm29 ymm30 ymm31 ' +
        // AVX-512F registers
        'zmm0  zmm1  zmm2  zmm3  zmm4  zmm5  zmm6  zmm7  zmm8  zmm9 zmm10  zmm11 zmm12 zmm13 zmm14 zmm15 ' +
        'zmm16 zmm17 zmm18 zmm19 zmm20 zmm21 zmm22 zmm23 zmm24 zmm25 zmm26 zmm27 zmm28 zmm29 zmm30 zmm31 ' +
        // AVX-512F mask registers
        'k0 k1 k2 k3 k4 k5 k6 k7 ' +
        // Bound (MPX) register
        'bnd0 bnd1 bnd2 bnd3 ' +
        // Special register
        'cr0 cr1 cr2 cr3 cr4 cr8 dr0 dr1 dr2 dr3 dr8 tr3 tr4 tr5 tr6 tr7 ' +
        // NASM altreg package
        'r0 r1 r2 r3 r4 r5 r6 r7 r0b r1b r2b r3b r4b r5b r6b r7b ' +
        'r0w r1w r2w r3w r4w r5w r6w r7w r0d r1d r2d r3d r4d r5d r6d r7d ' +
        'r0h r1h r2h r3h ' +
        'r0l r1l r2l r3l r4l r5l r6l r7l r8l r9l r10l r11l r12l r13l r14l r15l',

      pseudo:
        'db dw dd dq dt ddq do dy dz ' +
        'resb resw resd resq rest resdq reso resy resz ' +
        'incbin equ times',

      preprocessor:
        '%define %xdefine %+ %undef %defstr %deftok %assign %strcat %strlen %substr %rotate %elif %else %endif ' +
        '%ifmacro %ifctx %ifidn %ifidni %ifid %ifnum %ifstr %iftoken %ifempty %ifenv %error %warning %fatal %rep ' +
        '%endrep %include %push %pop %repl %pathsearch %depend %use %arg %stacksize %local %line %comment %endcomment ' +
        '.nolist ' +
        'byte word dword qword nosplit rel abs seg wrt strict near far a32 ptr ' +
        '__FILE__ __LINE__ __SECT__  __BITS__ __OUTPUT_FORMAT__ __DATE__ __TIME__ __DATE_NUM__ __TIME_NUM__ ' +
        '__UTC_DATE__ __UTC_TIME__ __UTC_DATE_NUM__ __UTC_TIME_NUM__  __PASS__ struc endstruc istruc at iend ' +
        'align alignb sectalign daz nodaz up down zero default option assume public ',

      built_in:
        'bits use16 use32 use64 default section segment absolute extern global common cpu float ' +
        '__utf16__ __utf16le__ __utf16be__ __utf32__ __utf32le__ __utf32be__ ' +
        '__float8__ __float16__ __float32__ __float64__ __float80m__ __float80e__ __float128l__ __float128h__ ' +
        '__Infinity__ __QNaN__ __SNaN__ Inf NaN QNaN SNaN float8 float16 float32 float64 float80m float80e ' +
        'float128l float128h __FLOAT_DAZ__ __FLOAT_ROUND__ __FLOAT__'
    },
    contains: [
      hljs.COMMENT(
        ';',
        '$',
        {
          relevance: 0
        }
      ),
      {
        className: 'number',
        variants: [
          // Float number and x87 BCD
          {
            begin: '\\b(?:([0-9][0-9_]*)?\\.[0-9_]*(?:[eE][+-]?[0-9_]+)?|' +
                   '(0[Xx])?[0-9][0-9_]*\\.?[0-9_]*(?:[pP](?:[+-]?[0-9_]+)?)?)\\b',
            relevance: 0
          },

          // Hex number in $
          { begin: '\\$[0-9][0-9A-Fa-f]*', relevance: 0 },

          // Number in H,D,T,Q,O,B,Y suffix
          { begin: '\\b(?:[0-9A-Fa-f][0-9A-Fa-f_]*[Hh]|[0-9][0-9_]*[DdTt]?|[0-7][0-7_]*[QqOo]|[0-1][0-1_]*[BbYy])\\b' },

          // Number in X,D,T,Q,O,B,Y prefix
          { begin: '\\b(?:0[Xx][0-9A-Fa-f_]+|0[DdTt][0-9_]+|0[QqOo][0-7_]+|0[BbYy][0-1_]+)\\b'}
        ]
      },
      // Double quote string
      hljs.QUOTE_STRING_MODE,
      {
        className: 'string',
        variants: [
          // Single-quoted string
          { begin: '\'', end: '[^\\\\]\'' },
          // Backquoted string
          { begin: '`', end: '[^\\\\]`' },
          // Section name
          { begin: '\\.[A-Za-z0-9]+' }
        ],
        relevance: 0
      },
      {
        className: 'label',
        variants: [
          // Global label and local label
          { begin: '^\\s*[A-Za-z._?][A-Za-z0-9_$#@~.?]*(:|\\s+label)' },
          // Macro-local label
          { begin: '^\\s*%%[A-Za-z0-9_$#@~.?]*:' }
        ],
        relevance: 0
      },
      // Macro parameter
      {
        className: 'argument',
        begin: '%[0-9]+',
        relevance: 0
      },
      // Macro parameter
      {
        className: 'built_in',
        begin: '%!\S+',
        relevance: 0
      }
    ]
  };
});

hljs.registerLanguage('xl', function(hljs) {
  var BUILTIN_MODULES =
    'ObjectLoader Animate MovieCredits Slides Filters Shading Materials LensFlare Mapping VLCAudioVideo ' +
    'StereoDecoder PointCloud NetworkAccess RemoteControl RegExp ChromaKey Snowfall NodeJS Speech Charts';

  var XL_KEYWORDS = {
    keyword: 'if then else do while until for loop import with is as where when by data constant',
    literal: 'true false nil',
    type: 'integer real text name boolean symbol infix prefix postfix block tree',
    built_in: 'in mod rem and or xor not abs sign floor ceil sqrt sin cos tan asin acos atan exp expm1 log log2 log10 log1p pi at',
    module: BUILTIN_MODULES,
    id:
      'text_length text_range text_find text_replace contains page slide basic_slide title_slide title subtitle ' +
      'fade_in fade_out fade_at clear_color color line_color line_width texture_wrap texture_transform texture ' +
      'scale_?x scale_?y scale_?z? translate_?x translate_?y translate_?z? rotate_?x rotate_?y rotate_?z? rectangle ' +
      'circle ellipse sphere path line_to move_to quad_to curve_to theme background contents locally time mouse_?x ' +
      'mouse_?y mouse_buttons'
  };

  var XL_CONSTANT = {
    className: 'constant',
    begin: '[A-Z][A-Z_0-9]+',
    relevance: 0
  };
  var XL_VARIABLE = {
    className: 'variable',
    begin: '([A-Z][a-z_0-9]+)+',
    relevance: 0
  };
  var XL_ID = {
    className: 'id',
    begin: '[a-z][a-z_0-9]+',
    relevance: 0
  };

  var DOUBLE_QUOTE_TEXT = {
    className: 'string',
    begin: '"', end: '"', illegal: '\\n'
  };
  var SINGLE_QUOTE_TEXT = {
    className: 'string',
    begin: '\'', end: '\'', illegal: '\\n'
  };
  var LONG_TEXT = {
    className: 'string',
    begin: '<<', end: '>>'
  };
  var BASED_NUMBER = {
    className: 'number',
    begin: '[0-9]+#[0-9A-Z_]+(\\.[0-9-A-Z_]+)?#?([Ee][+-]?[0-9]+)?',
    relevance: 10
  };
  var IMPORT = {
    className: 'import',
    beginKeywords: 'import', end: '$',
    keywords: {
      keyword: 'import',
      module: BUILTIN_MODULES
    },
    relevance: 0,
    contains: [DOUBLE_QUOTE_TEXT]
  };
  var FUNCTION_DEFINITION = {
    className: 'function',
    begin: '[a-z].*->'
  };
  return {
    aliases: ['tao'],
    lexemes: /[a-zA-Z][a-zA-Z0-9_?]*/,
    keywords: XL_KEYWORDS,
    contains: [
    hljs.C_LINE_COMMENT_MODE,
    hljs.C_BLOCK_COMMENT_MODE,
    DOUBLE_QUOTE_TEXT,
    SINGLE_QUOTE_TEXT,
    LONG_TEXT,
    FUNCTION_DEFINITION,
    IMPORT,
    XL_CONSTANT,
    XL_VARIABLE,
    XL_ID,
    BASED_NUMBER,
    hljs.NUMBER_MODE
    ]
  };
});

hljs.registerLanguage('xquery', function(hljs) {
  var KEYWORDS = 'for let if while then else return where group by xquery encoding version' +
    'module namespace boundary-space preserve strip default collation base-uri ordering' +
    'copy-namespaces order declare import schema namespace function option in allowing empty' +
    'at tumbling window sliding window start when only end when previous next stable ascending' +
    'descending empty greatest least some every satisfies switch case typeswitch try catch and' +
    'or to union intersect instance of treat as castable cast map array delete insert into' +
    'replace value rename copy modify update';
  var LITERAL = 'false true xs:string xs:integer element item xs:date xs:datetime xs:float xs:double xs:decimal QName xs:anyURI xs:long xs:int xs:short xs:byte attribute';
  var VAR = {
    className: 'variable',
    begin: /\$[a-zA-Z0-9\-]+/,
    relevance: 5
  };

  var NUMBER = {
    className: 'number',
    begin: '(\\b0[0-7_]+)|(\\b0x[0-9a-fA-F_]+)|(\\b[1-9][0-9_]*(\\.[0-9_]+)?)|[0_]\\b',
    relevance: 0
  };

  var STRING = {
    className: 'string',
    variants: [
      {begin: /"/, end: /"/, contains: [{begin: /""/, relevance: 0}]},
      {begin: /'/, end: /'/, contains: [{begin: /''/, relevance: 0}]}
    ]
  };

  var ANNOTATION = {
    className: 'decorator',
    begin: '%\\w+'
  };

  var COMMENT = {
    className: 'comment',
    begin: '\\(:', end: ':\\)',
    relevance: 10,
    contains: [
      {
        className: 'doc', begin: '@\\w+'
      }
    ]
  };

  var METHOD = {
    begin: '{', end: '}'
  };

  var CONTAINS = [
    VAR,
    STRING,
    NUMBER,
    COMMENT,
    ANNOTATION,
    METHOD
  ];
  METHOD.contains = CONTAINS;


  return {
    aliases: ['xpath', 'xq'],
    case_insensitive: false,
    lexemes: /[a-zA-Z\$][a-zA-Z0-9_:\-]*/,
    illegal: /(proc)|(abstract)|(extends)|(until)|(#)/,
    keywords: {
      keyword: KEYWORDS,
      literal: LITERAL
    },
    contains: CONTAINS
  };
});

hljs.registerLanguage('zephir', function(hljs) {
  var STRING = {
    className: 'string',
    contains: [hljs.BACKSLASH_ESCAPE],
    variants: [
      {
        begin: 'b"', end: '"'
      },
      {
        begin: 'b\'', end: '\''
      },
      hljs.inherit(hljs.APOS_STRING_MODE, {illegal: null}),
      hljs.inherit(hljs.QUOTE_STRING_MODE, {illegal: null})
    ]
  };
  var NUMBER = {variants: [hljs.BINARY_NUMBER_MODE, hljs.C_NUMBER_MODE]};
  return {
    aliases: ['zep'],
    case_insensitive: true,
    keywords:
    'and include_once list abstract global private echo interface as static endswitch ' +
    'array null if endwhile or const for endforeach self var let while isset public ' +
    'protected exit foreach throw elseif include __FILE__ empty require_once do xor ' +
    'return parent clone use __CLASS__ __LINE__ else break print eval new ' +
    'catch __METHOD__ case exception default die require __FUNCTION__ ' +
    'enddeclare final try switch continue endfor endif declare unset true false ' +
    'trait goto instanceof insteadof __DIR__ __NAMESPACE__ ' +
    'yield finally int uint long ulong char uchar double float bool boolean string' +
    'likely unlikely',
    contains: [
      hljs.C_LINE_COMMENT_MODE,
      hljs.HASH_COMMENT_MODE,
      hljs.COMMENT(
        '/\\*',
        '\\*/',
        {
          contains: [
            {
              className: 'doctag',
              begin: '@[A-Za-z]+'
            }
          ]
        }
      ),
      hljs.COMMENT(
        '__halt_compiler.+?;',
        false,
        {
          endsWithParent: true,
          keywords: '__halt_compiler',
          lexemes: hljs.UNDERSCORE_IDENT_RE
        }
      ),
      {
        className: 'string',
        begin: '<<<[\'"]?\\w+[\'"]?$', end: '^\\w+;',
        contains: [hljs.BACKSLASH_ESCAPE]
      },
      {
        // swallow composed identifiers to avoid parsing them as keywords
        begin: /(::|->)+[a-zA-Z_\x7f-\xff][a-zA-Z0-9_\x7f-\xff]*/
      },
      {
        className: 'function',
        beginKeywords: 'function', end: /[;{]/, excludeEnd: true,
        illegal: '\\$|\\[|%',
        contains: [
          hljs.UNDERSCORE_TITLE_MODE,
          {
            className: 'params',
            begin: '\\(', end: '\\)',
            contains: [
              'self',
              hljs.C_BLOCK_COMMENT_MODE,
              STRING,
              NUMBER
            ]
          }
        ]
      },
      {
        className: 'class',
        beginKeywords: 'class interface', end: '{', excludeEnd: true,
        illegal: /[:\(\$"]/,
        contains: [
          {beginKeywords: 'extends implements'},
          hljs.UNDERSCORE_TITLE_MODE
        ]
      },
      {
        beginKeywords: 'namespace', end: ';',
        illegal: /[\.']/,
        contains: [hljs.UNDERSCORE_TITLE_MODE]
      },
      {
        beginKeywords: 'use', end: ';',
        contains: [hljs.UNDERSCORE_TITLE_MODE]
      },
      {
        begin: '=>' // No markup, just a relevance booster
      },
      STRING,
      NUMBER
    ]
  };
});

  return hljs;
}));

/**
* vkBeautify - javascript plugin to pretty-print or minify text in XML, JSON, CSS and SQL formats.
*  
* Version - 0.99.00.beta 
* Copyright (c) 2012 Vadim Kiryukhin
* vkiryukhin @ gmail.com
* http://www.eslinstructor.net/vkbeautify/
* 
* Dual licensed under the MIT and GPL licenses:
*   http://www.opensource.org/licenses/mit-license.php
*   http://www.gnu.org/licenses/gpl.html
*
*   Pretty print
*
*        vkbeautify.xml(text [,indent_pattern]);
*        vkbeautify.json(text [,indent_pattern]);
*        vkbeautify.css(text [,indent_pattern]);
*        vkbeautify.sql(text [,indent_pattern]);
*
*        @text - String; text to beatufy;
*        @indent_pattern - Integer | String;
*                Integer:  number of white spaces;
*                String:   character string to visualize indentation ( can also be a set of white spaces )
*   Minify
*
*        vkbeautify.xmlmin(text [,preserve_comments]);
*        vkbeautify.jsonmin(text);
*        vkbeautify.cssmin(text [,preserve_comments]);
*        vkbeautify.sqlmin(text);
*
*        @text - String; text to minify;
*        @preserve_comments - Bool; [optional];
*                Set this flag to true to prevent removing comments from @text ( minxml and mincss functions only. )
*
*   Examples:
*        vkbeautify.xml(text); // pretty print XML
*        vkbeautify.json(text, 4 ); // pretty print JSON
*        vkbeautify.css(text, '. . . .'); // pretty print CSS
*        vkbeautify.sql(text, '----'); // pretty print SQL
*
*        vkbeautify.xmlmin(text, true);// minify XML, preserve comments
*        vkbeautify.jsonmin(text);// minify JSON
*        vkbeautify.cssmin(text);// minify CSS, remove comments ( default )
*        vkbeautify.sqlmin(text);// minify SQL
*
*/

(function() {

function createShiftArr(step) {

	var space = '    ';
	
	if ( isNaN(parseInt(step)) ) {  // argument is string
		space = step;
	} else { // argument is integer
		switch(step) {
			case 1: space = ' '; break;
			case 2: space = '  '; break;
			case 3: space = '   '; break;
			case 4: space = '    '; break;
			case 5: space = '     '; break;
			case 6: space = '      '; break;
			case 7: space = '       '; break;
			case 8: space = '        '; break;
			case 9: space = '         '; break;
			case 10: space = '          '; break;
			case 11: space = '           '; break;
			case 12: space = '            '; break;
		}
	}

	var shift = ['\n']; // array of shifts
	for(ix=0;ix<100;ix++){
		shift.push(shift[ix]+space); 
	}
	return shift;
}

function vkbeautify(){
	this.step = '    '; // 4 spaces
	this.shift = createShiftArr(this.step);
};

vkbeautify.prototype.xml = function(text,step) {

	var ar = text.replace(/>\s{0,}</g,"><")
				 .replace(/</g,"~::~<")
				 .replace(/\s*xmlns\:/g,"~::~xmlns:")
				 .replace(/\s*xmlns\=/g,"~::~xmlns=")
				 .split('~::~'),
		len = ar.length,
		inComment = false,
		deep = 0,
		str = '',
		ix = 0,
		shift = step ? createShiftArr(step) : this.shift;

		for(ix=0;ix<len;ix++) {
			// start comment or <![CDATA[...]]> or <!DOCTYPE //
			if(ar[ix].search(/<!/) > -1) { 
				str += shift[deep]+ar[ix];
				inComment = true; 
				// end comment  or <![CDATA[...]]> //
				if(ar[ix].search(/-->/) > -1 || ar[ix].search(/\]>/) > -1 || ar[ix].search(/!DOCTYPE/) > -1 ) { 
					inComment = false; 
				}
			} else 
			// end comment  or <![CDATA[...]]> //
			if(ar[ix].search(/-->/) > -1 || ar[ix].search(/\]>/) > -1) { 
				str += ar[ix];
				inComment = false; 
			} else 
			// <elm></elm> //
			if( /^<\w/.exec(ar[ix-1]) && /^<\/\w/.exec(ar[ix]) &&
				/^<[\w:\-\.\,]+/.exec(ar[ix-1]) == /^<\/[\w:\-\.\,]+/.exec(ar[ix])[0].replace('/','')) { 
				str += ar[ix];
				if(!inComment) deep--;
			} else
			 // <elm> //
			if(ar[ix].search(/<\w/) > -1 && ar[ix].search(/<\//) == -1 && ar[ix].search(/\/>/) == -1 ) {
				str = !inComment ? str += shift[deep++]+ar[ix] : str += ar[ix];
			} else 
			 // <elm>...</elm> //
			if(ar[ix].search(/<\w/) > -1 && ar[ix].search(/<\//) > -1) {
				str = !inComment ? str += shift[deep]+ar[ix] : str += ar[ix];
			} else 
			// </elm> //
			if(ar[ix].search(/<\//) > -1) { 
				str = !inComment ? str += shift[--deep]+ar[ix] : str += ar[ix];
			} else 
			// <elm/> //
			if(ar[ix].search(/\/>/) > -1 ) { 
				str = !inComment ? str += shift[deep]+ar[ix] : str += ar[ix];
			} else 
			// <? xml ... ?> //
			if(ar[ix].search(/<\?/) > -1) { 
				str += shift[deep]+ar[ix];
			} else 
			// xmlns //
			if( ar[ix].search(/xmlns\:/) > -1  || ar[ix].search(/xmlns\=/) > -1) { 
				str += shift[deep]+ar[ix];
			} 
			
			else {
				str += ar[ix];
			}
		}
		
	return  (str[0] == '\n') ? str.slice(1) : str;
}

vkbeautify.prototype.json = function(text,step) {

	var step = step ? step : this.step;
	
	if (typeof JSON === 'undefined' ) return text; 
	
	if ( typeof text === "string" ) return JSON.stringify(JSON.parse(text), null, step);
	if ( typeof text === "object" ) return JSON.stringify(text, null, step);
		
	return text; // text is not string nor object
}

vkbeautify.prototype.css = function(text, step) {

	var ar = text.replace(/\s{1,}/g,' ')
				.replace(/\{/g,"{~::~")
				.replace(/\}/g,"~::~}~::~")
				.replace(/\;/g,";~::~")
				.replace(/\/\*/g,"~::~/*")
				.replace(/\*\//g,"*/~::~")
				.replace(/~::~\s{0,}~::~/g,"~::~")
				.split('~::~'),
		len = ar.length,
		deep = 0,
		str = '',
		ix = 0,
		shift = step ? createShiftArr(step) : this.shift;
		
		for(ix=0;ix<len;ix++) {

			if( /\{/.exec(ar[ix]))  { 
				str += shift[deep++]+ar[ix];
			} else 
			if( /\}/.exec(ar[ix]))  { 
				str += shift[--deep]+ar[ix];
			} else
			if( /\*\\/.exec(ar[ix]))  { 
				str += shift[deep]+ar[ix];
			}
			else {
				str += shift[deep]+ar[ix];
			}
		}
		return str.replace(/^\n{1,}/,'');
}

//----------------------------------------------------------------------------

function isSubquery(str, parenthesisLevel) {
	return  parenthesisLevel - (str.replace(/\(/g,'').length - str.replace(/\)/g,'').length )
}

function split_sql(str, tab) {

	return str.replace(/\s{1,}/g," ")

				.replace(/ AND /ig,"~::~"+tab+tab+"AND ")
				.replace(/ BETWEEN /ig,"~::~"+tab+"BETWEEN ")
				.replace(/ CASE /ig,"~::~"+tab+"CASE ")
				.replace(/ ELSE /ig,"~::~"+tab+"ELSE ")
				.replace(/ END /ig,"~::~"+tab+"END ")
				.replace(/ FROM /ig,"~::~FROM ")
				.replace(/ GROUP\s{1,}BY/ig,"~::~GROUP BY ")
				.replace(/ HAVING /ig,"~::~HAVING ")
				//.replace(/ SET /ig," SET~::~")
				.replace(/ IN /ig," IN ")
				
				.replace(/ JOIN /ig,"~::~JOIN ")
				.replace(/ CROSS~::~{1,}JOIN /ig,"~::~CROSS JOIN ")
				.replace(/ INNER~::~{1,}JOIN /ig,"~::~INNER JOIN ")
				.replace(/ LEFT~::~{1,}JOIN /ig,"~::~LEFT JOIN ")
				.replace(/ RIGHT~::~{1,}JOIN /ig,"~::~RIGHT JOIN ")
				
				.replace(/ ON /ig,"~::~"+tab+"ON ")
				.replace(/ OR /ig,"~::~"+tab+tab+"OR ")
				.replace(/ ORDER\s{1,}BY/ig,"~::~ORDER BY ")
				.replace(/ OVER /ig,"~::~"+tab+"OVER ")

				.replace(/\(\s{0,}SELECT /ig,"~::~(SELECT ")
				.replace(/\)\s{0,}SELECT /ig,")~::~SELECT ")
				
				.replace(/ THEN /ig," THEN~::~"+tab+"")
				.replace(/ UNION /ig,"~::~UNION~::~")
				.replace(/ USING /ig,"~::~USING ")
				.replace(/ WHEN /ig,"~::~"+tab+"WHEN ")
				.replace(/ WHERE /ig,"~::~WHERE ")
				.replace(/ WITH /ig,"~::~WITH ")
				
				//.replace(/\,\s{0,}\(/ig,",~::~( ")
				//.replace(/\,/ig,",~::~"+tab+tab+"")

				.replace(/ ALL /ig," ALL ")
				.replace(/ AS /ig," AS ")
				.replace(/ ASC /ig," ASC ")	
				.replace(/ DESC /ig," DESC ")	
				.replace(/ DISTINCT /ig," DISTINCT ")
				.replace(/ EXISTS /ig," EXISTS ")
				.replace(/ NOT /ig," NOT ")
				.replace(/ NULL /ig," NULL ")
				.replace(/ LIKE /ig," LIKE ")
				.replace(/\s{0,}SELECT /ig,"SELECT ")
				.replace(/\s{0,}UPDATE /ig,"UPDATE ")
				.replace(/ SET /ig," SET ")
							
				.replace(/~::~{1,}/g,"~::~")
				.split('~::~');
}

vkbeautify.prototype.sql = function(text,step) {

	var ar_by_quote = text.replace(/\s{1,}/g," ")
							.replace(/\'/ig,"~::~\'")
							.split('~::~'),
		len = ar_by_quote.length,
		ar = [],
		deep = 0,
		tab = this.step,//+this.step,
		inComment = true,
		inQuote = false,
		parenthesisLevel = 0,
		str = '',
		ix = 0,
		shift = step ? createShiftArr(step) : this.shift;;

		for(ix=0;ix<len;ix++) {
			if(ix%2) {
				ar = ar.concat(ar_by_quote[ix]);
			} else {
				ar = ar.concat(split_sql(ar_by_quote[ix], tab) );
			}
		}
		
		len = ar.length;
		for(ix=0;ix<len;ix++) {
			
			parenthesisLevel = isSubquery(ar[ix], parenthesisLevel);
			
			if( /\s{0,}\s{0,}SELECT\s{0,}/.exec(ar[ix]))  { 
				ar[ix] = ar[ix].replace(/\,/g,",\n"+tab+tab+"")
			} 
			
			if( /\s{0,}\s{0,}SET\s{0,}/.exec(ar[ix]))  { 
				ar[ix] = ar[ix].replace(/\,/g,",\n"+tab+tab+"")
			} 
			
			if( /\s{0,}\(\s{0,}SELECT\s{0,}/.exec(ar[ix]))  { 
				deep++;
				str += shift[deep]+ar[ix];
			} else 
			if( /\'/.exec(ar[ix]) )  { 
				if(parenthesisLevel<1 && deep) {
					deep--;
				}
				str += ar[ix];
			}
			else  { 
				str += shift[deep]+ar[ix];
				if(parenthesisLevel<1 && deep) {
					deep--;
				}
			} 
			var junk = 0;
		}

		str = str.replace(/^\n{1,}/,'').replace(/\n{1,}/g,"\n");
		return str;
}


vkbeautify.prototype.xmlmin = function(text, preserveComments) {

	var str = preserveComments ? text
							   : text.replace(/\<![ \r\n\t]*(--([^\-]|[\r\n]|-[^\-])*--[ \r\n\t]*)\>/g,"")
									 .replace(/[ \r\n\t]{1,}xmlns/g, ' xmlns');
	return  str.replace(/>\s{0,}</g,"><"); 
}

vkbeautify.prototype.jsonmin = function(text) {

	if (typeof JSON === 'undefined' ) return text; 
	
	return JSON.stringify(JSON.parse(text), null, 0); 
				
}

vkbeautify.prototype.cssmin = function(text, preserveComments) {
	
	var str = preserveComments ? text
							   : text.replace(/\/\*([^*]|[\r\n]|(\*+([^*/]|[\r\n])))*\*+\//g,"") ;

	return str.replace(/\s{1,}/g,' ')
			  .replace(/\{\s{1,}/g,"{")
			  .replace(/\}\s{1,}/g,"}")
			  .replace(/\;\s{1,}/g,";")
			  .replace(/\/\*\s{1,}/g,"/*")
			  .replace(/\*\/\s{1,}/g,"*/");
}

vkbeautify.prototype.sqlmin = function(text) {
	return text.replace(/\s{1,}/g," ").replace(/\s{1,}\(/,"(").replace(/\s{1,}\)/,")");
}

window.vkbeautify = new vkbeautify();

})();


/*
CryptoJS v3.1.2
code.google.com/p/crypto-js
(c) 2009-2013 by Jeff Mott. All rights reserved.
code.google.com/p/crypto-js/wiki/License
*/
var CryptoJS=CryptoJS||function(g,l){var e={},d=e.lib={},m=function(){},k=d.Base={extend:function(a){m.prototype=this;var c=new m;a&&c.mixIn(a);c.hasOwnProperty("init")||(c.init=function(){c.$super.init.apply(this,arguments)});c.init.prototype=c;c.$super=this;return c},create:function(){var a=this.extend();a.init.apply(a,arguments);return a},init:function(){},mixIn:function(a){for(var c in a)a.hasOwnProperty(c)&&(this[c]=a[c]);a.hasOwnProperty("toString")&&(this.toString=a.toString)},clone:function(){return this.init.prototype.extend(this)}},
p=d.WordArray=k.extend({init:function(a,c){a=this.words=a||[];this.sigBytes=c!=l?c:4*a.length},toString:function(a){return(a||n).stringify(this)},concat:function(a){var c=this.words,q=a.words,f=this.sigBytes;a=a.sigBytes;this.clamp();if(f%4)for(var b=0;b<a;b++)c[f+b>>>2]|=(q[b>>>2]>>>24-8*(b%4)&255)<<24-8*((f+b)%4);else if(65535<q.length)for(b=0;b<a;b+=4)c[f+b>>>2]=q[b>>>2];else c.push.apply(c,q);this.sigBytes+=a;return this},clamp:function(){var a=this.words,c=this.sigBytes;a[c>>>2]&=4294967295<<
32-8*(c%4);a.length=g.ceil(c/4)},clone:function(){var a=k.clone.call(this);a.words=this.words.slice(0);return a},random:function(a){for(var c=[],b=0;b<a;b+=4)c.push(4294967296*g.random()|0);return new p.init(c,a)}}),b=e.enc={},n=b.Hex={stringify:function(a){var c=a.words;a=a.sigBytes;for(var b=[],f=0;f<a;f++){var d=c[f>>>2]>>>24-8*(f%4)&255;b.push((d>>>4).toString(16));b.push((d&15).toString(16))}return b.join("")},parse:function(a){for(var c=a.length,b=[],f=0;f<c;f+=2)b[f>>>3]|=parseInt(a.substr(f,
2),16)<<24-4*(f%8);return new p.init(b,c/2)}},j=b.Latin1={stringify:function(a){var c=a.words;a=a.sigBytes;for(var b=[],f=0;f<a;f++)b.push(String.fromCharCode(c[f>>>2]>>>24-8*(f%4)&255));return b.join("")},parse:function(a){for(var c=a.length,b=[],f=0;f<c;f++)b[f>>>2]|=(a.charCodeAt(f)&255)<<24-8*(f%4);return new p.init(b,c)}},h=b.Utf8={stringify:function(a){try{return decodeURIComponent(escape(j.stringify(a)))}catch(c){throw Error("Malformed UTF-8 data");}},parse:function(a){return j.parse(unescape(encodeURIComponent(a)))}},
r=d.BufferedBlockAlgorithm=k.extend({reset:function(){this._data=new p.init;this._nDataBytes=0},_append:function(a){"string"==typeof a&&(a=h.parse(a));this._data.concat(a);this._nDataBytes+=a.sigBytes},_process:function(a){var c=this._data,b=c.words,f=c.sigBytes,d=this.blockSize,e=f/(4*d),e=a?g.ceil(e):g.max((e|0)-this._minBufferSize,0);a=e*d;f=g.min(4*a,f);if(a){for(var k=0;k<a;k+=d)this._doProcessBlock(b,k);k=b.splice(0,a);c.sigBytes-=f}return new p.init(k,f)},clone:function(){var a=k.clone.call(this);
a._data=this._data.clone();return a},_minBufferSize:0});d.Hasher=r.extend({cfg:k.extend(),init:function(a){this.cfg=this.cfg.extend(a);this.reset()},reset:function(){r.reset.call(this);this._doReset()},update:function(a){this._append(a);this._process();return this},finalize:function(a){a&&this._append(a);return this._doFinalize()},blockSize:16,_createHelper:function(a){return function(b,d){return(new a.init(d)).finalize(b)}},_createHmacHelper:function(a){return function(b,d){return(new s.HMAC.init(a,
d)).finalize(b)}}});var s=e.algo={};return e}(Math);
(function(){var g=CryptoJS,l=g.lib,e=l.WordArray,d=l.Hasher,m=[],l=g.algo.SHA1=d.extend({_doReset:function(){this._hash=new e.init([1732584193,4023233417,2562383102,271733878,3285377520])},_doProcessBlock:function(d,e){for(var b=this._hash.words,n=b[0],j=b[1],h=b[2],g=b[3],l=b[4],a=0;80>a;a++){if(16>a)m[a]=d[e+a]|0;else{var c=m[a-3]^m[a-8]^m[a-14]^m[a-16];m[a]=c<<1|c>>>31}c=(n<<5|n>>>27)+l+m[a];c=20>a?c+((j&h|~j&g)+1518500249):40>a?c+((j^h^g)+1859775393):60>a?c+((j&h|j&g|h&g)-1894007588):c+((j^h^
g)-899497514);l=g;g=h;h=j<<30|j>>>2;j=n;n=c}b[0]=b[0]+n|0;b[1]=b[1]+j|0;b[2]=b[2]+h|0;b[3]=b[3]+g|0;b[4]=b[4]+l|0},_doFinalize:function(){var d=this._data,e=d.words,b=8*this._nDataBytes,g=8*d.sigBytes;e[g>>>5]|=128<<24-g%32;e[(g+64>>>9<<4)+14]=Math.floor(b/4294967296);e[(g+64>>>9<<4)+15]=b;d.sigBytes=4*e.length;this._process();return this._hash},clone:function(){var e=d.clone.call(this);e._hash=this._hash.clone();return e}});g.SHA1=d._createHelper(l);g.HmacSHA1=d._createHmacHelper(l)})();
(function(){var g=CryptoJS,l=g.enc.Utf8;g.algo.HMAC=g.lib.Base.extend({init:function(e,d){e=this._hasher=new e.init;"string"==typeof d&&(d=l.parse(d));var g=e.blockSize,k=4*g;d.sigBytes>k&&(d=e.finalize(d));d.clamp();for(var p=this._oKey=d.clone(),b=this._iKey=d.clone(),n=p.words,j=b.words,h=0;h<g;h++)n[h]^=1549556828,j[h]^=909522486;p.sigBytes=b.sigBytes=k;this.reset()},reset:function(){var e=this._hasher;e.reset();e.update(this._iKey)},update:function(e){this._hasher.update(e);return this},finalize:function(e){var d=
this._hasher;e=d.finalize(e);d.reset();return d.finalize(this._oKey.clone().concat(e))}})})();

/*
CryptoJS v3.1.2
code.google.com/p/crypto-js
(c) 2009-2013 by Jeff Mott. All rights reserved.
code.google.com/p/crypto-js/wiki/License
*/
(function () {
    // Shortcuts
    var C = CryptoJS;
    var C_lib = C.lib;
    var WordArray = C_lib.WordArray;
    var C_enc = C.enc;

    /**
     * Base64 encoding strategy.
     */
    var Base64 = C_enc.Base64 = {
        /**
         * Converts a word array to a Base64 string.
         *
         * @param {WordArray} wordArray The word array.
         *
         * @return {string} The Base64 string.
         *
         * @static
         *
         * @example
         *
         *     var base64String = CryptoJS.enc.Base64.stringify(wordArray);
         */
        stringify: function (wordArray) {
            // Shortcuts
            var words = wordArray.words;
            var sigBytes = wordArray.sigBytes;
            var map = this._map;

            // Clamp excess bits
            wordArray.clamp();

            // Convert
            var base64Chars = [];
            for (var i = 0; i < sigBytes; i += 3) {
                var byte1 = (words[i >>> 2]       >>> (24 - (i % 4) * 8))       & 0xff;
                var byte2 = (words[(i + 1) >>> 2] >>> (24 - ((i + 1) % 4) * 8)) & 0xff;
                var byte3 = (words[(i + 2) >>> 2] >>> (24 - ((i + 2) % 4) * 8)) & 0xff;

                var triplet = (byte1 << 16) | (byte2 << 8) | byte3;

                for (var j = 0; (j < 4) && (i + j * 0.75 < sigBytes); j++) {
                    base64Chars.push(map.charAt((triplet >>> (6 * (3 - j))) & 0x3f));
                }
            }

            // Add padding
            var paddingChar = map.charAt(64);
            if (paddingChar) {
                while (base64Chars.length % 4) {
                    base64Chars.push(paddingChar);
                }
            }

            return base64Chars.join('');
        },

        /**
         * Converts a Base64 string to a word array.
         *
         * @param {string} base64Str The Base64 string.
         *
         * @return {WordArray} The word array.
         *
         * @static
         *
         * @example
         *
         *     var wordArray = CryptoJS.enc.Base64.parse(base64String);
         */
        parse: function (base64Str) {
            // Shortcuts
            var base64StrLength = base64Str.length;
            var map = this._map;

            // Ignore padding
            var paddingChar = map.charAt(64);
            if (paddingChar) {
                var paddingIndex = base64Str.indexOf(paddingChar);
                if (paddingIndex != -1) {
                    base64StrLength = paddingIndex;
                }
            }

            // Convert
            var words = [];
            var nBytes = 0;
            for (var i = 0; i < base64StrLength; i++) {
                if (i % 4) {
                    var bits1 = map.indexOf(base64Str.charAt(i - 1)) << ((i % 4) * 2);
                    var bits2 = map.indexOf(base64Str.charAt(i)) >>> (6 - (i % 4) * 2);
                    words[nBytes >>> 2] |= (bits1 | bits2) << (24 - (nBytes % 4) * 8);
                    nBytes++;
                }
            }

            return WordArray.create(words, nBytes);
        },

        _map: 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/='
    };
}());

// CodeMirror is the only global var we claim
window.CodeMirror = (function() {
  "use strict";

  // BROWSER SNIFFING

  // Crude, but necessary to handle a number of hard-to-feature-detect
  // bugs and behavior differences.
  var gecko = /gecko\/\d/i.test(navigator.userAgent);
  var ie = /MSIE \d/.test(navigator.userAgent);
  var ie_lt8 = ie && (document.documentMode == null || document.documentMode < 8);
  var ie_lt9 = ie && (document.documentMode == null || document.documentMode < 9);
  var webkit = /WebKit\//.test(navigator.userAgent);
  var qtwebkit = webkit && /Qt\/\d+\.\d+/.test(navigator.userAgent);
  var chrome = /Chrome\//.test(navigator.userAgent);
  var opera = /Opera\//.test(navigator.userAgent);
  var safari = /Apple Computer/.test(navigator.vendor);
  var khtml = /KHTML\//.test(navigator.userAgent);
  var mac_geLion = /Mac OS X 1\d\D([7-9]|\d\d)\D/.test(navigator.userAgent);
  var mac_geMountainLion = /Mac OS X 1\d\D([8-9]|\d\d)\D/.test(navigator.userAgent);
  var phantom = /PhantomJS/.test(navigator.userAgent);

  var ios = /AppleWebKit/.test(navigator.userAgent) && /Mobile\/\w+/.test(navigator.userAgent);
  // This is woefully incomplete. Suggestions for alternative methods welcome.
  var mobile = ios || /Android|webOS|BlackBerry|Opera Mini|Opera Mobi|IEMobile/i.test(navigator.userAgent);
  var mac = ios || /Mac/.test(navigator.platform);
  var windows = /windows/i.test(navigator.platform);

  var opera_version = opera && navigator.userAgent.match(/Version\/(\d*\.\d*)/);
  if (opera_version) opera_version = Number(opera_version[1]);
  if (opera_version && opera_version >= 15) { opera = false; webkit = true; }
  // Some browsers use the wrong event properties to signal cmd/ctrl on OS X
  var flipCtrlCmd = mac && (qtwebkit || opera && (opera_version == null || opera_version < 12.11));
  var captureMiddleClick = gecko || (ie && !ie_lt9);

  // Optimize some code when these features are not used
  var sawReadOnlySpans = false, sawCollapsedSpans = false;

  // CONSTRUCTOR

  function CodeMirror(place, options) {
    if (!(this instanceof CodeMirror)) return new CodeMirror(place, options);

    this.options = options = options || {};
    // Determine effective options based on given values and defaults.
    for (var opt in defaults) if (!options.hasOwnProperty(opt) && defaults.hasOwnProperty(opt))
      options[opt] = defaults[opt];
    setGuttersForLineNumbers(options);

    var docStart = typeof options.value == "string" ? 0 : options.value.first;
    var display = this.display = makeDisplay(place, docStart);
    display.wrapper.CodeMirror = this;
    updateGutters(this);
    if (options.autofocus && !mobile) focusInput(this);

    this.state = {keyMaps: [],
                  overlays: [],
                  modeGen: 0,
                  overwrite: false, focused: false,
                  suppressEdits: false, pasteIncoming: false,
                  draggingText: false,
                  highlight: new Delayed()};

    themeChanged(this);
    if (options.lineWrapping)
      this.display.wrapper.className += " CodeMirror-wrap";

    var doc = options.value;
    if (typeof doc == "string") doc = new Doc(options.value, options.mode);
    operation(this, attachDoc)(this, doc);

    // Override magic textarea content restore that IE sometimes does
    // on our hidden textarea on reload
    if (ie) setTimeout(bind(resetInput, this, true), 20);

    registerEventHandlers(this);
    // IE throws unspecified error in certain cases, when
    // trying to access activeElement before onload
    var hasFocus; try { hasFocus = (document.activeElement == display.input); } catch(e) { }
    if (hasFocus || (options.autofocus && !mobile)) setTimeout(bind(onFocus, this), 20);
    else onBlur(this);

    operation(this, function() {
      for (var opt in optionHandlers)
        if (optionHandlers.propertyIsEnumerable(opt))
          optionHandlers[opt](this, options[opt], Init);
      for (var i = 0; i < initHooks.length; ++i) initHooks[i](this);
    })();
  }

  // DISPLAY CONSTRUCTOR

  function makeDisplay(place, docStart) {
    var d = {};

    var input = d.input = elt("textarea", null, null, "position: absolute; padding: 0; width: 1px; height: 1em; outline: none; font-size: 4px;");
    if (webkit) input.style.width = "1000px";
    else input.setAttribute("wrap", "off");
    // if border: 0; -- iOS fails to open keyboard (issue #1287)
    if (ios) input.style.border = "1px solid black";
    input.setAttribute("autocorrect", "off"); input.setAttribute("autocapitalize", "off"); input.setAttribute("spellcheck", "false");

    // Wraps and hides input textarea
    d.inputDiv = elt("div", [input], null, "overflow: hidden; position: relative; width: 3px; height: 0px;");
    // The actual fake scrollbars.
    d.scrollbarH = elt("div", [elt("div", null, null, "height: 1px")], "CodeMirror-hscrollbar");
    d.scrollbarV = elt("div", [elt("div", null, null, "width: 1px")], "CodeMirror-vscrollbar");
    d.scrollbarFiller = elt("div", null, "CodeMirror-scrollbar-filler");
    d.gutterFiller = elt("div", null, "CodeMirror-gutter-filler");
    // DIVs containing the selection and the actual code
    d.lineDiv = elt("div", null, "CodeMirror-code");
    d.selectionDiv = elt("div", null, null, "position: relative; z-index: 1");
    // Blinky cursor, and element used to ensure cursor fits at the end of a line
    d.cursor = elt("div", "\u00a0", "CodeMirror-cursor");
    // Secondary cursor, shown when on a 'jump' in bi-directional text
    d.otherCursor = elt("div", "\u00a0", "CodeMirror-cursor CodeMirror-secondarycursor");
    // Used to measure text size
    d.measure = elt("div", null, "CodeMirror-measure");
    // Wraps everything that needs to exist inside the vertically-padded coordinate system
    d.lineSpace = elt("div", [d.measure, d.selectionDiv, d.lineDiv, d.cursor, d.otherCursor],
                         null, "position: relative; outline: none");
    // Moved around its parent to cover visible view
    d.mover = elt("div", [elt("div", [d.lineSpace], "CodeMirror-lines")], null, "position: relative");
    // Set to the height of the text, causes scrolling
    d.sizer = elt("div", [d.mover], "CodeMirror-sizer");
    // D is needed because behavior of elts with overflow: auto and padding is inconsistent across browsers
    d.heightForcer = elt("div", null, null, "position: absolute; height: " + scrollerCutOff + "px; width: 1px;");
    // Will contain the gutters, if any
    d.gutters = elt("div", null, "CodeMirror-gutters");
    d.lineGutter = null;
    // Provides scrolling
    d.scroller = elt("div", [d.sizer, d.heightForcer, d.gutters], "CodeMirror-scroll");
    d.scroller.setAttribute("tabIndex", "-1");
    // The element in which the editor lives.
    d.wrapper = elt("div", [d.inputDiv, d.scrollbarH, d.scrollbarV,
                            d.scrollbarFiller, d.gutterFiller, d.scroller], "CodeMirror");
    // Work around IE7 z-index bug
    if (ie_lt8) { d.gutters.style.zIndex = -1; d.scroller.style.paddingRight = 0; }
    if (place.appendChild) place.appendChild(d.wrapper); else place(d.wrapper);

    // Needed to hide big blue blinking cursor on Mobile Safari
    if (ios) input.style.width = "0px";
    if (!webkit) d.scroller.draggable = true;
    // Needed to handle Tab key in KHTML
    if (khtml) { d.inputDiv.style.height = "1px"; d.inputDiv.style.position = "absolute"; }
    // Need to set a minimum width to see the scrollbar on IE7 (but must not set it on IE8).
    else if (ie_lt8) d.scrollbarH.style.minWidth = d.scrollbarV.style.minWidth = "18px";

    // Current visible range (may be bigger than the view window).
    d.viewOffset = d.lastSizeC = 0;
    d.showingFrom = d.showingTo = docStart;

    // Used to only resize the line number gutter when necessary (when
    // the amount of lines crosses a boundary that makes its width change)
    d.lineNumWidth = d.lineNumInnerWidth = d.lineNumChars = null;
    // See readInput and resetInput
    d.prevInput = "";
    // Set to true when a non-horizontal-scrolling widget is added. As
    // an optimization, widget aligning is skipped when d is false.
    d.alignWidgets = false;
    // Flag that indicates whether we currently expect input to appear
    // (after some event like 'keypress' or 'input') and are polling
    // intensively.
    d.pollingFast = false;
    // Self-resetting timeout for the poller
    d.poll = new Delayed();

    d.cachedCharWidth = d.cachedTextHeight = null;
    d.measureLineCache = [];
    d.measureLineCachePos = 0;

    // Tracks when resetInput has punted to just putting a short
    // string instead of the (large) selection.
    d.inaccurateSelection = false;

    // Tracks the maximum line length so that the horizontal scrollbar
    // can be kept static when scrolling.
    d.maxLine = null;
    d.maxLineLength = 0;
    d.maxLineChanged = false;

    // Used for measuring wheel scrolling granularity
    d.wheelDX = d.wheelDY = d.wheelStartX = d.wheelStartY = null;

    return d;
  }

  // STATE UPDATES

  // Used to get the editor into a consistent state again when options change.

  function loadMode(cm) {
    cm.doc.mode = CodeMirror.getMode(cm.options, cm.doc.modeOption);
    cm.doc.iter(function(line) {
      if (line.stateAfter) line.stateAfter = null;
      if (line.styles) line.styles = null;
    });
    cm.doc.frontier = cm.doc.first;
    startWorker(cm, 100);
    cm.state.modeGen++;
    if (cm.curOp) regChange(cm);
  }

  function wrappingChanged(cm) {
    if (cm.options.lineWrapping) {
      cm.display.wrapper.className += " CodeMirror-wrap";
      cm.display.sizer.style.minWidth = "";
    } else {
      cm.display.wrapper.className = cm.display.wrapper.className.replace(" CodeMirror-wrap", "");
      computeMaxLength(cm);
    }
    estimateLineHeights(cm);
    regChange(cm);
    clearCaches(cm);
    setTimeout(function(){updateScrollbars(cm);}, 100);
  }

  function estimateHeight(cm) {
    var th = textHeight(cm.display), wrapping = cm.options.lineWrapping;
    var perLine = wrapping && Math.max(5, cm.display.scroller.clientWidth / charWidth(cm.display) - 3);
    return function(line) {
      if (lineIsHidden(cm.doc, line))
        return 0;
      else if (wrapping)
        return (Math.ceil(line.text.length / perLine) || 1) * th;
      else
        return th;
    };
  }

  function estimateLineHeights(cm) {
    var doc = cm.doc, est = estimateHeight(cm);
    doc.iter(function(line) {
      var estHeight = est(line);
      if (estHeight != line.height) updateLineHeight(line, estHeight);
    });
  }

  function keyMapChanged(cm) {
    var map = keyMap[cm.options.keyMap], style = map.style;
    cm.display.wrapper.className = cm.display.wrapper.className.replace(/\s*cm-keymap-\S+/g, "") +
      (style ? " cm-keymap-" + style : "");
    cm.state.disableInput = map.disableInput;
  }

  function themeChanged(cm) {
    cm.display.wrapper.className = cm.display.wrapper.className.replace(/\s*cm-s-\S+/g, "") +
      cm.options.theme.replace(/(^|\s)\s*/g, " cm-s-");
    clearCaches(cm);
  }

  function guttersChanged(cm) {
    updateGutters(cm);
    regChange(cm);
    setTimeout(function(){alignHorizontally(cm);}, 20);
  }

  function updateGutters(cm) {
    var gutters = cm.display.gutters, specs = cm.options.gutters;
    removeChildren(gutters);
    for (var i = 0; i < specs.length; ++i) {
      var gutterClass = specs[i];
      var gElt = gutters.appendChild(elt("div", null, "CodeMirror-gutter " + gutterClass));
      if (gutterClass == "CodeMirror-linenumbers") {
        cm.display.lineGutter = gElt;
        gElt.style.width = (cm.display.lineNumWidth || 1) + "px";
      }
    }
    gutters.style.display = i ? "" : "none";
  }

  function lineLength(doc, line) {
    if (line.height == 0) return 0;
    var len = line.text.length, merged, cur = line;
    while (merged = collapsedSpanAtStart(cur)) {
      var found = merged.find();
      cur = getLine(doc, found.from.line);
      len += found.from.ch - found.to.ch;
    }
    cur = line;
    while (merged = collapsedSpanAtEnd(cur)) {
      var found = merged.find();
      len -= cur.text.length - found.from.ch;
      cur = getLine(doc, found.to.line);
      len += cur.text.length - found.to.ch;
    }
    return len;
  }

  function computeMaxLength(cm) {
    var d = cm.display, doc = cm.doc;
    d.maxLine = getLine(doc, doc.first);
    d.maxLineLength = lineLength(doc, d.maxLine);
    d.maxLineChanged = true;
    doc.iter(function(line) {
      var len = lineLength(doc, line);
      if (len > d.maxLineLength) {
        d.maxLineLength = len;
        d.maxLine = line;
      }
    });
  }

  // Make sure the gutters options contains the element
  // "CodeMirror-linenumbers" when the lineNumbers option is true.
  function setGuttersForLineNumbers(options) {
    var found = false;
    for (var i = 0; i < options.gutters.length; ++i) {
      if (options.gutters[i] == "CodeMirror-linenumbers") {
        if (options.lineNumbers) found = true;
        else options.gutters.splice(i--, 1);
      }
    }
    if (!found && options.lineNumbers)
      options.gutters.push("CodeMirror-linenumbers");
  }

  // SCROLLBARS

  // Re-synchronize the fake scrollbars with the actual size of the
  // content. Optionally force a scrollTop.
  function updateScrollbars(cm) {
    var d = cm.display, docHeight = cm.doc.height;
    var totalHeight = docHeight + paddingVert(d);
    d.sizer.style.minHeight = d.heightForcer.style.top = totalHeight + "px";
    d.gutters.style.height = Math.max(totalHeight, d.scroller.clientHeight - scrollerCutOff) + "px";
    var scrollHeight = Math.max(totalHeight, d.scroller.scrollHeight);
    var needsH = d.scroller.scrollWidth > (d.scroller.clientWidth + 1);
    var needsV = scrollHeight > (d.scroller.clientHeight + 1);
    if (needsV) {
      d.scrollbarV.style.display = "block";
      d.scrollbarV.style.bottom = needsH ? scrollbarWidth(d.measure) + "px" : "0";
      d.scrollbarV.firstChild.style.height =
        (scrollHeight - d.scroller.clientHeight + d.scrollbarV.clientHeight) + "px";
    } else d.scrollbarV.style.display = "";
    if (needsH) {
      d.scrollbarH.style.display = "block";
      d.scrollbarH.style.right = needsV ? scrollbarWidth(d.measure) + "px" : "0";
      d.scrollbarH.firstChild.style.width =
        (d.scroller.scrollWidth - d.scroller.clientWidth + d.scrollbarH.clientWidth) + "px";
    } else d.scrollbarH.style.display = "";
    if (needsH && needsV) {
      d.scrollbarFiller.style.display = "block";
      d.scrollbarFiller.style.height = d.scrollbarFiller.style.width = scrollbarWidth(d.measure) + "px";
    } else d.scrollbarFiller.style.display = "";
    if (needsH && cm.options.coverGutterNextToScrollbar && cm.options.fixedGutter) {
      d.gutterFiller.style.display = "block";
      d.gutterFiller.style.height = scrollbarWidth(d.measure) + "px";
      d.gutterFiller.style.width = d.gutters.offsetWidth + "px";
    } else d.gutterFiller.style.display = "";

    if (mac_geLion && scrollbarWidth(d.measure) === 0)
      d.scrollbarV.style.minWidth = d.scrollbarH.style.minHeight = mac_geMountainLion ? "18px" : "12px";
  }

  function visibleLines(display, doc, viewPort) {
    var top = display.scroller.scrollTop, height = display.wrapper.clientHeight;
    if (typeof viewPort == "number") top = viewPort;
    else if (viewPort) {top = viewPort.top; height = viewPort.bottom - viewPort.top;}
    top = Math.floor(top - paddingTop(display));
    var bottom = Math.ceil(top + height);
    return {from: lineAtHeight(doc, top), to: lineAtHeight(doc, bottom)};
  }

  // LINE NUMBERS

  function alignHorizontally(cm) {
    var display = cm.display;
    if (!display.alignWidgets && (!display.gutters.firstChild || !cm.options.fixedGutter)) return;
    var comp = compensateForHScroll(display) - display.scroller.scrollLeft + cm.doc.scrollLeft;
    var gutterW = display.gutters.offsetWidth, l = comp + "px";
    for (var n = display.lineDiv.firstChild; n; n = n.nextSibling) if (n.alignable) {
      for (var i = 0, a = n.alignable; i < a.length; ++i) a[i].style.left = l;
    }
    if (cm.options.fixedGutter)
      display.gutters.style.left = (comp + gutterW) + "px";
  }

  function maybeUpdateLineNumberWidth(cm) {
    if (!cm.options.lineNumbers) return false;
    var doc = cm.doc, last = lineNumberFor(cm.options, doc.first + doc.size - 1), display = cm.display;
    if (last.length != display.lineNumChars) {
      var test = display.measure.appendChild(elt("div", [elt("div", last)],
                                                 "CodeMirror-linenumber CodeMirror-gutter-elt"));
      var innerW = test.firstChild.offsetWidth, padding = test.offsetWidth - innerW;
      display.lineGutter.style.width = "";
      display.lineNumInnerWidth = Math.max(innerW, display.lineGutter.offsetWidth - padding);
      display.lineNumWidth = display.lineNumInnerWidth + padding;
      display.lineNumChars = display.lineNumInnerWidth ? last.length : -1;
      display.lineGutter.style.width = display.lineNumWidth + "px";
      return true;
    }
    return false;
  }

  function lineNumberFor(options, i) {
    return String(options.lineNumberFormatter(i + options.firstLineNumber));
  }
  function compensateForHScroll(display) {
    return getRect(display.scroller).left - getRect(display.sizer).left;
  }

  // DISPLAY DRAWING

  function updateDisplay(cm, changes, viewPort, forced) {
    var oldFrom = cm.display.showingFrom, oldTo = cm.display.showingTo, updated;
    var visible = visibleLines(cm.display, cm.doc, viewPort);
    for (;;) {
      if (!updateDisplayInner(cm, changes, visible, forced)) break;
      forced = false;
      updated = true;
      updateSelection(cm);
      updateScrollbars(cm);

      // Clip forced viewport to actual scrollable area
      if (viewPort)
        viewPort = Math.min(cm.display.scroller.scrollHeight - cm.display.scroller.clientHeight,
                            typeof viewPort == "number" ? viewPort : viewPort.top);
      visible = visibleLines(cm.display, cm.doc, viewPort);
      if (visible.from >= cm.display.showingFrom && visible.to <= cm.display.showingTo)
        break;
      changes = [];
    }

    if (updated) {
      signalLater(cm, "update", cm);
      if (cm.display.showingFrom != oldFrom || cm.display.showingTo != oldTo)
        signalLater(cm, "viewportChange", cm, cm.display.showingFrom, cm.display.showingTo);
    }
    return updated;
  }

  // Uses a set of changes plus the current scroll position to
  // determine which DOM updates have to be made, and makes the
  // updates.
  function updateDisplayInner(cm, changes, visible, forced) {
    var display = cm.display, doc = cm.doc;
    if (!display.wrapper.clientWidth) {
      display.showingFrom = display.showingTo = doc.first;
      display.viewOffset = 0;
      return;
    }

    // Bail out if the visible area is already rendered and nothing changed.
    if (!forced && changes.length == 0 &&
        visible.from > display.showingFrom && visible.to < display.showingTo)
      return;

    if (maybeUpdateLineNumberWidth(cm))
      changes = [{from: doc.first, to: doc.first + doc.size}];
    var gutterW = display.sizer.style.marginLeft = display.gutters.offsetWidth + "px";
    display.scrollbarH.style.left = cm.options.fixedGutter ? gutterW : "0";

    // Used to determine which lines need their line numbers updated
    var positionsChangedFrom = Infinity;
    if (cm.options.lineNumbers)
      for (var i = 0; i < changes.length; ++i)
        if (changes[i].diff) { positionsChangedFrom = changes[i].from; break; }

    var end = doc.first + doc.size;
    var from = Math.max(visible.from - cm.options.viewportMargin, doc.first);
    var to = Math.min(end, visible.to + cm.options.viewportMargin);
    if (display.showingFrom < from && from - display.showingFrom < 20) from = Math.max(doc.first, display.showingFrom);
    if (display.showingTo > to && display.showingTo - to < 20) to = Math.min(end, display.showingTo);
    if (sawCollapsedSpans) {
      from = lineNo(visualLine(doc, getLine(doc, from)));
      while (to < end && lineIsHidden(doc, getLine(doc, to))) ++to;
    }

    // Create a range of theoretically intact lines, and punch holes
    // in that using the change info.
    var intact = [{from: Math.max(display.showingFrom, doc.first),
                   to: Math.min(display.showingTo, end)}];
    if (intact[0].from >= intact[0].to) intact = [];
    else intact = computeIntact(intact, changes);
    // When merged lines are present, we might have to reduce the
    // intact ranges because changes in continued fragments of the
    // intact lines do require the lines to be redrawn.
    if (sawCollapsedSpans)
      for (var i = 0; i < intact.length; ++i) {
        var range = intact[i], merged;
        while (merged = collapsedSpanAtEnd(getLine(doc, range.to - 1))) {
          var newTo = merged.find().from.line;
          if (newTo > range.from) range.to = newTo;
          else { intact.splice(i--, 1); break; }
        }
      }

    // Clip off the parts that won't be visible
    var intactLines = 0;
    for (var i = 0; i < intact.length; ++i) {
      var range = intact[i];
      if (range.from < from) range.from = from;
      if (range.to > to) range.to = to;
      if (range.from >= range.to) intact.splice(i--, 1);
      else intactLines += range.to - range.from;
    }
    if (!forced && intactLines == to - from && from == display.showingFrom && to == display.showingTo) {
      updateViewOffset(cm);
      return;
    }
    intact.sort(function(a, b) {return a.from - b.from;});

    // Avoid crashing on IE's "unspecified error" when in iframes
    try {
      var focused = document.activeElement;
    } catch(e) {}
    if (intactLines < (to - from) * .7) display.lineDiv.style.display = "none";
    patchDisplay(cm, from, to, intact, positionsChangedFrom);
    display.lineDiv.style.display = "";
    if (focused && document.activeElement != focused && focused.offsetHeight) focused.focus();

    var different = from != display.showingFrom || to != display.showingTo ||
      display.lastSizeC != display.wrapper.clientHeight;
    // This is just a bogus formula that detects when the editor is
    // resized or the font size changes.
    if (different) {
      display.lastSizeC = display.wrapper.clientHeight;
      startWorker(cm, 400);
    }
    display.showingFrom = from; display.showingTo = to;

    updateHeightsInViewport(cm);
    updateViewOffset(cm);

    return true;
  }

  function updateHeightsInViewport(cm) {
    var display = cm.display;
    var prevBottom = display.lineDiv.offsetTop;
    for (var node = display.lineDiv.firstChild, height; node; node = node.nextSibling) if (node.lineObj) {
      if (ie_lt8) {
        var bot = node.offsetTop + node.offsetHeight;
        height = bot - prevBottom;
        prevBottom = bot;
      } else {
        var box = getRect(node);
        height = box.bottom - box.top;
      }
      var diff = node.lineObj.height - height;
      if (height < 2) height = textHeight(display);
      if (diff > .001 || diff < -.001) {
        updateLineHeight(node.lineObj, height);
        var widgets = node.lineObj.widgets;
        if (widgets) for (var i = 0; i < widgets.length; ++i)
          widgets[i].height = widgets[i].node.offsetHeight;
      }
    }
  }

  function updateViewOffset(cm) {
    var off = cm.display.viewOffset = heightAtLine(cm, getLine(cm.doc, cm.display.showingFrom));
    // Position the mover div to align with the current virtual scroll position
    cm.display.mover.style.top = off + "px";
  }

  function computeIntact(intact, changes) {
    for (var i = 0, l = changes.length || 0; i < l; ++i) {
      var change = changes[i], intact2 = [], diff = change.diff || 0;
      for (var j = 0, l2 = intact.length; j < l2; ++j) {
        var range = intact[j];
        if (change.to <= range.from && change.diff) {
          intact2.push({from: range.from + diff, to: range.to + diff});
        } else if (change.to <= range.from || change.from >= range.to) {
          intact2.push(range);
        } else {
          if (change.from > range.from)
            intact2.push({from: range.from, to: change.from});
          if (change.to < range.to)
            intact2.push({from: change.to + diff, to: range.to + diff});
        }
      }
      intact = intact2;
    }
    return intact;
  }

  function getDimensions(cm) {
    var d = cm.display, left = {}, width = {};
    for (var n = d.gutters.firstChild, i = 0; n; n = n.nextSibling, ++i) {
      left[cm.options.gutters[i]] = n.offsetLeft;
      width[cm.options.gutters[i]] = n.offsetWidth;
    }
    return {fixedPos: compensateForHScroll(d),
            gutterTotalWidth: d.gutters.offsetWidth,
            gutterLeft: left,
            gutterWidth: width,
            wrapperWidth: d.wrapper.clientWidth};
  }

  function patchDisplay(cm, from, to, intact, updateNumbersFrom) {
    var dims = getDimensions(cm);
    var display = cm.display, lineNumbers = cm.options.lineNumbers;
    if (!intact.length && (!webkit || !cm.display.currentWheelTarget))
      removeChildren(display.lineDiv);
    var container = display.lineDiv, cur = container.firstChild;

    function rm(node) {
      var next = node.nextSibling;
      if (webkit && mac && cm.display.currentWheelTarget == node) {
        node.style.display = "none";
        node.lineObj = null;
      } else {
        node.parentNode.removeChild(node);
      }
      return next;
    }

    var nextIntact = intact.shift(), lineN = from;
    cm.doc.iter(from, to, function(line) {
      if (nextIntact && nextIntact.to == lineN) nextIntact = intact.shift();
      if (lineIsHidden(cm.doc, line)) {
        if (line.height != 0) updateLineHeight(line, 0);
        if (line.widgets && cur.previousSibling) for (var i = 0; i < line.widgets.length; ++i) {
          var w = line.widgets[i];
          if (w.showIfHidden) {
            var prev = cur.previousSibling;
            if (/pre/i.test(prev.nodeName)) {
              var wrap = elt("div", null, null, "position: relative");
              prev.parentNode.replaceChild(wrap, prev);
              wrap.appendChild(prev);
              prev = wrap;
            }
            var wnode = prev.appendChild(elt("div", [w.node], "CodeMirror-linewidget"));
            if (!w.handleMouseEvents) wnode.ignoreEvents = true;
            positionLineWidget(w, wnode, prev, dims);
          }
        }
      } else if (nextIntact && nextIntact.from <= lineN && nextIntact.to > lineN) {
        // This line is intact. Skip to the actual node. Update its
        // line number if needed.
        while (cur.lineObj != line) cur = rm(cur);
        if (lineNumbers && updateNumbersFrom <= lineN && cur.lineNumber)
          setTextContent(cur.lineNumber, lineNumberFor(cm.options, lineN));
        cur = cur.nextSibling;
      } else {
        // For lines with widgets, make an attempt to find and reuse
        // the existing element, so that widgets aren't needlessly
        // removed and re-inserted into the dom
        if (line.widgets) for (var j = 0, search = cur, reuse; search && j < 20; ++j, search = search.nextSibling)
          if (search.lineObj == line && /div/i.test(search.nodeName)) { reuse = search; break; }
        // This line needs to be generated.
        var lineNode = buildLineElement(cm, line, lineN, dims, reuse);
        if (lineNode != reuse) {
          container.insertBefore(lineNode, cur);
        } else {
          while (cur != reuse) cur = rm(cur);
          cur = cur.nextSibling;
        }

        lineNode.lineObj = line;
      }
      ++lineN;
    });
    while (cur) cur = rm(cur);
  }

  function buildLineElement(cm, line, lineNo, dims, reuse) {
    var lineElement = lineContent(cm, line);
    var markers = line.gutterMarkers, display = cm.display, wrap;

    if (!cm.options.lineNumbers && !markers && !line.bgClass && !line.wrapClass && !line.widgets)
      return lineElement;

    // Lines with gutter elements, widgets or a background class need
    // to be wrapped again, and have the extra elements added to the
    // wrapper div

    if (reuse) {
      reuse.alignable = null;
      var isOk = true, widgetsSeen = 0, insertBefore = null;
      for (var n = reuse.firstChild, next; n; n = next) {
        next = n.nextSibling;
        if (!/\bCodeMirror-linewidget\b/.test(n.className)) {
          reuse.removeChild(n);
        } else {
          for (var i = 0; i < line.widgets.length; ++i) {
            var widget = line.widgets[i];
            if (widget.node == n.firstChild) {
              if (!widget.above && !insertBefore) insertBefore = n;
              positionLineWidget(widget, n, reuse, dims);
              ++widgetsSeen;
              break;
            }
          }
          if (i == line.widgets.length) { isOk = false; break; }
        }
      }
      reuse.insertBefore(lineElement, insertBefore);
      if (isOk && widgetsSeen == line.widgets.length) {
        wrap = reuse;
        reuse.className = line.wrapClass || "";
      }
    }
    if (!wrap) {
      wrap = elt("div", null, line.wrapClass, "position: relative");
      wrap.appendChild(lineElement);
    }
    // Kludge to make sure the styled element lies behind the selection (by z-index)
    if (line.bgClass)
      wrap.insertBefore(elt("div", null, line.bgClass + " CodeMirror-linebackground"), wrap.firstChild);
    if (cm.options.lineNumbers || markers) {
      var gutterWrap = wrap.insertBefore(elt("div", null, null, "position: absolute; left: " +
                                             (cm.options.fixedGutter ? dims.fixedPos : -dims.gutterTotalWidth) + "px"),
                                         wrap.firstChild);
      if (cm.options.fixedGutter) (wrap.alignable || (wrap.alignable = [])).push(gutterWrap);
      if (cm.options.lineNumbers && (!markers || !markers["CodeMirror-linenumbers"]))
        wrap.lineNumber = gutterWrap.appendChild(
          elt("div", lineNumberFor(cm.options, lineNo),
              "CodeMirror-linenumber CodeMirror-gutter-elt",
              "left: " + dims.gutterLeft["CodeMirror-linenumbers"] + "px; width: "
              + display.lineNumInnerWidth + "px"));
      if (markers)
        for (var k = 0; k < cm.options.gutters.length; ++k) {
          var id = cm.options.gutters[k], found = markers.hasOwnProperty(id) && markers[id];
          if (found)
            gutterWrap.appendChild(elt("div", [found], "CodeMirror-gutter-elt", "left: " +
                                       dims.gutterLeft[id] + "px; width: " + dims.gutterWidth[id] + "px"));
        }
    }
    if (ie_lt8) wrap.style.zIndex = 2;
    if (line.widgets && wrap != reuse) for (var i = 0, ws = line.widgets; i < ws.length; ++i) {
      var widget = ws[i], node = elt("div", [widget.node], "CodeMirror-linewidget");
      if (!widget.handleMouseEvents) node.ignoreEvents = true;
      positionLineWidget(widget, node, wrap, dims);
      if (widget.above)
        wrap.insertBefore(node, cm.options.lineNumbers && line.height != 0 ? gutterWrap : lineElement);
      else
        wrap.appendChild(node);
      signalLater(widget, "redraw");
    }
    return wrap;
  }

  function positionLineWidget(widget, node, wrap, dims) {
    if (widget.noHScroll) {
      (wrap.alignable || (wrap.alignable = [])).push(node);
      var width = dims.wrapperWidth;
      node.style.left = dims.fixedPos + "px";
      if (!widget.coverGutter) {
        width -= dims.gutterTotalWidth;
        node.style.paddingLeft = dims.gutterTotalWidth + "px";
      }
      node.style.width = width + "px";
    }
    if (widget.coverGutter) {
      node.style.zIndex = 5;
      node.style.position = "relative";
      if (!widget.noHScroll) node.style.marginLeft = -dims.gutterTotalWidth + "px";
    }
  }

  // SELECTION / CURSOR

  function updateSelection(cm) {
    var display = cm.display;
    var collapsed = posEq(cm.doc.sel.from, cm.doc.sel.to);
    if (collapsed || cm.options.showCursorWhenSelecting)
      updateSelectionCursor(cm);
    else
      display.cursor.style.display = display.otherCursor.style.display = "none";
    if (!collapsed)
      updateSelectionRange(cm);
    else
      display.selectionDiv.style.display = "none";

    // Move the hidden textarea near the cursor to prevent scrolling artifacts
    if (cm.options.moveInputWithCursor) {
      var headPos = cursorCoords(cm, cm.doc.sel.head, "div");
      var wrapOff = getRect(display.wrapper), lineOff = getRect(display.lineDiv);
      display.inputDiv.style.top = Math.max(0, Math.min(display.wrapper.clientHeight - 10,
                                                        headPos.top + lineOff.top - wrapOff.top)) + "px";
      display.inputDiv.style.left = Math.max(0, Math.min(display.wrapper.clientWidth - 10,
                                                         headPos.left + lineOff.left - wrapOff.left)) + "px";
    }
  }

  // No selection, plain cursor
  function updateSelectionCursor(cm) {
    var display = cm.display, pos = cursorCoords(cm, cm.doc.sel.head, "div");
    display.cursor.style.left = pos.left + "px";
    display.cursor.style.top = pos.top + "px";
    display.cursor.style.height = Math.max(0, pos.bottom - pos.top) * cm.options.cursorHeight + "px";
    display.cursor.style.display = "";

    if (pos.other) {
      display.otherCursor.style.display = "";
      display.otherCursor.style.left = pos.other.left + "px";
      display.otherCursor.style.top = pos.other.top + "px";
      display.otherCursor.style.height = (pos.other.bottom - pos.other.top) * .85 + "px";
    } else { display.otherCursor.style.display = "none"; }
  }

  // Highlight selection
  function updateSelectionRange(cm) {
    var display = cm.display, doc = cm.doc, sel = cm.doc.sel;
    var fragment = document.createDocumentFragment();
    var clientWidth = display.lineSpace.offsetWidth, pl = paddingLeft(cm.display);

    function add(left, top, width, bottom) {
      if (top < 0) top = 0;
      fragment.appendChild(elt("div", null, "CodeMirror-selected", "position: absolute; left: " + left +
                               "px; top: " + top + "px; width: " + (width == null ? clientWidth - left : width) +
                               "px; height: " + (bottom - top) + "px"));
    }

    function drawForLine(line, fromArg, toArg) {
      var lineObj = getLine(doc, line);
      var lineLen = lineObj.text.length;
      var start, end;
      function coords(ch, bias) {
        return charCoords(cm, Pos(line, ch), "div", lineObj, bias);
      }

      iterateBidiSections(getOrder(lineObj), fromArg || 0, toArg == null ? lineLen : toArg, function(from, to, dir) {
        var leftPos = coords(from, "left"), rightPos, left, right;
        if (from == to) {
          rightPos = leftPos;
          left = right = leftPos.left;
        } else {
          rightPos = coords(to - 1, "right");
          if (dir == "rtl") { var tmp = leftPos; leftPos = rightPos; rightPos = tmp; }
          left = leftPos.left;
          right = rightPos.right;
        }
        if (fromArg == null && from == 0) left = pl;
        if (rightPos.top - leftPos.top > 3) { // Different lines, draw top part
          add(left, leftPos.top, null, leftPos.bottom);
          left = pl;
          if (leftPos.bottom < rightPos.top) add(left, leftPos.bottom, null, rightPos.top);
        }
        if (toArg == null && to == lineLen) right = clientWidth;
        if (!start || leftPos.top < start.top || leftPos.top == start.top && leftPos.left < start.left)
          start = leftPos;
        if (!end || rightPos.bottom > end.bottom || rightPos.bottom == end.bottom && rightPos.right > end.right)
          end = rightPos;
        if (left < pl + 1) left = pl;
        add(left, rightPos.top, right - left, rightPos.bottom);
      });
      return {start: start, end: end};
    }

    if (sel.from.line == sel.to.line) {
      drawForLine(sel.from.line, sel.from.ch, sel.to.ch);
    } else {
      var fromLine = getLine(doc, sel.from.line), toLine = getLine(doc, sel.to.line);
      var singleVLine = visualLine(doc, fromLine) == visualLine(doc, toLine);
      var leftEnd = drawForLine(sel.from.line, sel.from.ch, singleVLine ? fromLine.text.length : null).end;
      var rightStart = drawForLine(sel.to.line, singleVLine ? 0 : null, sel.to.ch).start;
      if (singleVLine) {
        if (leftEnd.top < rightStart.top - 2) {
          add(leftEnd.right, leftEnd.top, null, leftEnd.bottom);
          add(pl, rightStart.top, rightStart.left, rightStart.bottom);
        } else {
          add(leftEnd.right, leftEnd.top, rightStart.left - leftEnd.right, leftEnd.bottom);
        }
      }
      if (leftEnd.bottom < rightStart.top)
        add(pl, leftEnd.bottom, null, rightStart.top);
    }

    removeChildrenAndAdd(display.selectionDiv, fragment);
    display.selectionDiv.style.display = "";
  }

  // Cursor-blinking
  function restartBlink(cm) {
    if (!cm.state.focused) return;
    var display = cm.display;
    clearInterval(display.blinker);
    var on = true;
    display.cursor.style.visibility = display.otherCursor.style.visibility = "";
    display.blinker = setInterval(function() {
      display.cursor.style.visibility = display.otherCursor.style.visibility = (on = !on) ? "" : "hidden";
    }, cm.options.cursorBlinkRate);
  }

  // HIGHLIGHT WORKER

  function startWorker(cm, time) {
    if (cm.doc.mode.startState && cm.doc.frontier < cm.display.showingTo)
      cm.state.highlight.set(time, bind(highlightWorker, cm));
  }

  function highlightWorker(cm) {
    var doc = cm.doc;
    if (doc.frontier < doc.first) doc.frontier = doc.first;
    if (doc.frontier >= cm.display.showingTo) return;
    var end = +new Date + cm.options.workTime;
    var state = copyState(doc.mode, getStateBefore(cm, doc.frontier));
    var changed = [], prevChange;
    doc.iter(doc.frontier, Math.min(doc.first + doc.size, cm.display.showingTo + 500), function(line) {
      if (doc.frontier >= cm.display.showingFrom) { // Visible
        var oldStyles = line.styles;
        line.styles = highlightLine(cm, line, state);
        var ischange = !oldStyles || oldStyles.length != line.styles.length;
        for (var i = 0; !ischange && i < oldStyles.length; ++i) ischange = oldStyles[i] != line.styles[i];
        if (ischange) {
          if (prevChange && prevChange.end == doc.frontier) prevChange.end++;
          else changed.push(prevChange = {start: doc.frontier, end: doc.frontier + 1});
        }
        line.stateAfter = copyState(doc.mode, state);
      } else {
        processLine(cm, line, state);
        line.stateAfter = doc.frontier % 5 == 0 ? copyState(doc.mode, state) : null;
      }
      ++doc.frontier;
      if (+new Date > end) {
        startWorker(cm, cm.options.workDelay);
        return true;
      }
    });
    if (changed.length)
      operation(cm, function() {
        for (var i = 0; i < changed.length; ++i)
          regChange(this, changed[i].start, changed[i].end);
      })();
  }

  // Finds the line to start with when starting a parse. Tries to
  // find a line with a stateAfter, so that it can start with a
  // valid state. If that fails, it returns the line with the
  // smallest indentation, which tends to need the least context to
  // parse correctly.
  function findStartLine(cm, n, precise) {
    var minindent, minline, doc = cm.doc;
    for (var search = n, lim = n - 100; search > lim; --search) {
      if (search <= doc.first) return doc.first;
      var line = getLine(doc, search - 1);
      if (line.stateAfter && (!precise || search <= doc.frontier)) return search;
      var indented = countColumn(line.text, null, cm.options.tabSize);
      if (minline == null || minindent > indented) {
        minline = search - 1;
        minindent = indented;
      }
    }
    return minline;
  }

  function getStateBefore(cm, n, precise) {
    var doc = cm.doc, display = cm.display;
      if (!doc.mode.startState) return true;
    var pos = findStartLine(cm, n, precise), state = pos > doc.first && getLine(doc, pos-1).stateAfter;
    if (!state) state = startState(doc.mode);
    else state = copyState(doc.mode, state);
    doc.iter(pos, n, function(line) {
      processLine(cm, line, state);
      var save = pos == n - 1 || pos % 5 == 0 || pos >= display.showingFrom && pos < display.showingTo;
      line.stateAfter = save ? copyState(doc.mode, state) : null;
      ++pos;
    });
    return state;
  }

  // POSITION MEASUREMENT

  function paddingTop(display) {return display.lineSpace.offsetTop;}
  function paddingVert(display) {return display.mover.offsetHeight - display.lineSpace.offsetHeight;}
  function paddingLeft(display) {
    var e = removeChildrenAndAdd(display.measure, elt("pre", null, null, "text-align: left")).appendChild(elt("span", "x"));
    return e.offsetLeft;
  }

  function measureChar(cm, line, ch, data, bias) {
    var dir = -1;
    data = data || measureLine(cm, line);

    for (var pos = ch;; pos += dir) {
      var r = data[pos];
      if (r) break;
      if (dir < 0 && pos == 0) dir = 1;
    }
    bias = pos > ch ? "left" : pos < ch ? "right" : bias;
    if (bias == "left" && r.leftSide) r = r.leftSide;
    else if (bias == "right" && r.rightSide) r = r.rightSide;
    return {left: pos < ch ? r.right : r.left,
            right: pos > ch ? r.left : r.right,
            top: r.top,
            bottom: r.bottom};
  }

  function findCachedMeasurement(cm, line) {
    var cache = cm.display.measureLineCache;
    for (var i = 0; i < cache.length; ++i) {
      var memo = cache[i];
      if (memo.text == line.text && memo.markedSpans == line.markedSpans &&
          cm.display.scroller.clientWidth == memo.width &&
          memo.classes == line.textClass + "|" + line.bgClass + "|" + line.wrapClass)
        return memo;
    }
  }

  function clearCachedMeasurement(cm, line) {
    var exists = findCachedMeasurement(cm, line);
    if (exists) exists.text = exists.measure = exists.markedSpans = null;
  }

  function measureLine(cm, line) {
    // First look in the cache
    var cached = findCachedMeasurement(cm, line);
    if (cached) return cached.measure;

    // Failing that, recompute and store result in cache
    var measure = measureLineInner(cm, line);
    var cache = cm.display.measureLineCache;
    var memo = {text: line.text, width: cm.display.scroller.clientWidth,
                markedSpans: line.markedSpans, measure: measure,
                classes: line.textClass + "|" + line.bgClass + "|" + line.wrapClass};
    if (cache.length == 16) cache[++cm.display.measureLineCachePos % 16] = memo;
    else cache.push(memo);
    return measure;
  }

  function measureLineInner(cm, line) {
    var display = cm.display, measure = emptyArray(line.text.length);
    var pre = lineContent(cm, line, measure, true);

    // IE does not cache element positions of inline elements between
    // calls to getBoundingClientRect. This makes the loop below,
    // which gathers the positions of all the characters on the line,
    // do an amount of layout work quadratic to the number of
    // characters. When line wrapping is off, we try to improve things
    // by first subdividing the line into a bunch of inline blocks, so
    // that IE can reuse most of the layout information from caches
    // for those blocks. This does interfere with line wrapping, so it
    // doesn't work when wrapping is on, but in that case the
    // situation is slightly better, since IE does cache line-wrapping
    // information and only recomputes per-line.
    if (ie && !ie_lt8 && !cm.options.lineWrapping && pre.childNodes.length > 100) {
      var fragment = document.createDocumentFragment();
      var chunk = 10, n = pre.childNodes.length;
      for (var i = 0, chunks = Math.ceil(n / chunk); i < chunks; ++i) {
        var wrap = elt("div", null, null, "display: inline-block");
        for (var j = 0; j < chunk && n; ++j) {
          wrap.appendChild(pre.firstChild);
          --n;
        }
        fragment.appendChild(wrap);
      }
      pre.appendChild(fragment);
    }

    removeChildrenAndAdd(display.measure, pre);

    var outer = getRect(display.lineDiv);
    var vranges = [], data = emptyArray(line.text.length), maxBot = pre.offsetHeight;
    // Work around an IE7/8 bug where it will sometimes have randomly
    // replaced our pre with a clone at this point.
    if (ie_lt9 && display.measure.first != pre)
      removeChildrenAndAdd(display.measure, pre);

    function measureRect(rect) {
      var top = rect.top - outer.top, bot = rect.bottom - outer.top;
      if (bot > maxBot) bot = maxBot;
      if (top < 0) top = 0;
      for (var i = vranges.length - 2; i >= 0; i -= 2) {
        var rtop = vranges[i], rbot = vranges[i+1];
        if (rtop > bot || rbot < top) continue;
        if (rtop <= top && rbot >= bot ||
            top <= rtop && bot >= rbot ||
            Math.min(bot, rbot) - Math.max(top, rtop) >= (bot - top) >> 1) {
          vranges[i] = Math.min(top, rtop);
          vranges[i+1] = Math.max(bot, rbot);
          break;
        }
      }
      if (i < 0) { i = vranges.length; vranges.push(top, bot); }
      return {left: rect.left - outer.left,
              right: rect.right - outer.left,
              top: i, bottom: null};
    }
    function finishRect(rect) {
      rect.bottom = vranges[rect.top+1];
      rect.top = vranges[rect.top];
    }

    for (var i = 0, cur; i < measure.length; ++i) if (cur = measure[i]) {
      var node = cur, rect = null;
      // A widget might wrap, needs special care
      if (/\bCodeMirror-widget\b/.test(cur.className) && cur.getClientRects) {
        if (cur.firstChild.nodeType == 1) node = cur.firstChild;
        var rects = node.getClientRects();
        if (rects.length > 1) {
          rect = data[i] = measureRect(rects[0]);
          rect.rightSide = measureRect(rects[rects.length - 1]);
        }
      }
      if (!rect) rect = data[i] = measureRect(getRect(node));
      if (cur.measureRight) rect.right = getRect(cur.measureRight).left;
      if (cur.leftSide) rect.leftSide = measureRect(getRect(cur.leftSide));
    }
    for (var i = 0, cur; i < data.length; ++i) if (cur = data[i]) {
      finishRect(cur);
      if (cur.leftSide) finishRect(cur.leftSide);
      if (cur.rightSide) finishRect(cur.rightSide);
    }
    return data;
  }

  function measureLineWidth(cm, line) {
    var hasBadSpan = false;
    if (line.markedSpans) for (var i = 0; i < line.markedSpans; ++i) {
      var sp = line.markedSpans[i];
      if (sp.collapsed && (sp.to == null || sp.to == line.text.length)) hasBadSpan = true;
    }
    var cached = !hasBadSpan && findCachedMeasurement(cm, line);
    if (cached) return measureChar(cm, line, line.text.length, cached.measure, "right").right;

    var pre = lineContent(cm, line, null, true);
    var end = pre.appendChild(zeroWidthElement(cm.display.measure));
    removeChildrenAndAdd(cm.display.measure, pre);
    return getRect(end).right - getRect(cm.display.lineDiv).left;
  }

  function clearCaches(cm) {
    cm.display.measureLineCache.length = cm.display.measureLineCachePos = 0;
    cm.display.cachedCharWidth = cm.display.cachedTextHeight = null;
    if (!cm.options.lineWrapping) cm.display.maxLineChanged = true;
    cm.display.lineNumChars = null;
  }

  function pageScrollX() { return window.pageXOffset || (document.documentElement || document.body).scrollLeft; }
  function pageScrollY() { return window.pageYOffset || (document.documentElement || document.body).scrollTop; }

  // Context is one of "line", "div" (display.lineDiv), "local"/null (editor), or "page"
  function intoCoordSystem(cm, lineObj, rect, context) {
    if (lineObj.widgets) for (var i = 0; i < lineObj.widgets.length; ++i) if (lineObj.widgets[i].above) {
      var size = widgetHeight(lineObj.widgets[i]);
      rect.top += size; rect.bottom += size;
    }
    if (context == "line") return rect;
    if (!context) context = "local";
    var yOff = heightAtLine(cm, lineObj);
    if (context == "local") yOff += paddingTop(cm.display);
    else yOff -= cm.display.viewOffset;
    if (context == "page" || context == "window") {
      var lOff = getRect(cm.display.lineSpace);
      yOff += lOff.top + (context == "window" ? 0 : pageScrollY());
      var xOff = lOff.left + (context == "window" ? 0 : pageScrollX());
      rect.left += xOff; rect.right += xOff;
    }
    rect.top += yOff; rect.bottom += yOff;
    return rect;
  }

  // Context may be "window", "page", "div", or "local"/null
  // Result is in "div" coords
  function fromCoordSystem(cm, coords, context) {
    if (context == "div") return coords;
    var left = coords.left, top = coords.top;
    // First move into "page" coordinate system
    if (context == "page") {
      left -= pageScrollX();
      top -= pageScrollY();
    } else if (context == "local" || !context) {
      var localBox = getRect(cm.display.sizer);
      left += localBox.left;
      top += localBox.top;
    }

    var lineSpaceBox = getRect(cm.display.lineSpace);
    return {left: left - lineSpaceBox.left, top: top - lineSpaceBox.top};
  }

  function charCoords(cm, pos, context, lineObj, bias) {
    if (!lineObj) lineObj = getLine(cm.doc, pos.line);
    return intoCoordSystem(cm, lineObj, measureChar(cm, lineObj, pos.ch, null, bias), context);
  }

  function cursorCoords(cm, pos, context, lineObj, measurement) {
    lineObj = lineObj || getLine(cm.doc, pos.line);
    if (!measurement) measurement = measureLine(cm, lineObj);
    function get(ch, right) {
      var m = measureChar(cm, lineObj, ch, measurement, right ? "right" : "left");
      if (right) m.left = m.right; else m.right = m.left;
      return intoCoordSystem(cm, lineObj, m, context);
    }
    function getBidi(ch, partPos) {
      var part = order[partPos], right = part.level % 2;
      if (ch == bidiLeft(part) && partPos && part.level < order[partPos - 1].level) {
        part = order[--partPos];
        ch = bidiRight(part) - (part.level % 2 ? 0 : 1);
        right = true;
      } else if (ch == bidiRight(part) && partPos < order.length - 1 && part.level < order[partPos + 1].level) {
        part = order[++partPos];
        ch = bidiLeft(part) - part.level % 2;
        right = false;
      }
      if (right && ch == part.to && ch > part.from) return get(ch - 1);
      return get(ch, right);
    }
    var order = getOrder(lineObj), ch = pos.ch;
    if (!order) return get(ch);
    var partPos = getBidiPartAt(order, ch);
    var val = getBidi(ch, partPos);
    if (bidiOther != null) val.other = getBidi(ch, bidiOther);
    return val;
  }

  function PosWithInfo(line, ch, outside, xRel) {
    var pos = new Pos(line, ch);
    pos.xRel = xRel;
    if (outside) pos.outside = true;
    return pos;
  }

  // Coords must be lineSpace-local
  function coordsChar(cm, x, y) {
    var doc = cm.doc;
    y += cm.display.viewOffset;
    if (y < 0) return PosWithInfo(doc.first, 0, true, -1);
    var lineNo = lineAtHeight(doc, y), last = doc.first + doc.size - 1;
    if (lineNo > last)
      return PosWithInfo(doc.first + doc.size - 1, getLine(doc, last).text.length, true, 1);
    if (x < 0) x = 0;

    for (;;) {
      var lineObj = getLine(doc, lineNo);
      var found = coordsCharInner(cm, lineObj, lineNo, x, y);
      var merged = collapsedSpanAtEnd(lineObj);
      var mergedPos = merged && merged.find();
      if (merged && (found.ch > mergedPos.from.ch || found.ch == mergedPos.from.ch && found.xRel > 0))
        lineNo = mergedPos.to.line;
      else
        return found;
    }
  }

  function coordsCharInner(cm, lineObj, lineNo, x, y) {
    var innerOff = y - heightAtLine(cm, lineObj);
    var wrongLine = false, adjust = 2 * cm.display.wrapper.clientWidth;
    var measurement = measureLine(cm, lineObj);

    function getX(ch) {
      var sp = cursorCoords(cm, Pos(lineNo, ch), "line",
                            lineObj, measurement);
      wrongLine = true;
      if (innerOff > sp.bottom) return sp.left - adjust;
      else if (innerOff < sp.top) return sp.left + adjust;
      else wrongLine = false;
      return sp.left;
    }

    var bidi = getOrder(lineObj), dist = lineObj.text.length;
    var from = lineLeft(lineObj), to = lineRight(lineObj);
    var fromX = getX(from), fromOutside = wrongLine, toX = getX(to), toOutside = wrongLine;

    if (x > toX) return PosWithInfo(lineNo, to, toOutside, 1);
    // Do a binary search between these bounds.
    for (;;) {
      if (bidi ? to == from || to == moveVisually(lineObj, from, 1) : to - from <= 1) {
        var ch = x < fromX || x - fromX <= toX - x ? from : to;
        var xDiff = x - (ch == from ? fromX : toX);
        while (isExtendingChar.test(lineObj.text.charAt(ch))) ++ch;
        var pos = PosWithInfo(lineNo, ch, ch == from ? fromOutside : toOutside,
                              xDiff < 0 ? -1 : xDiff ? 1 : 0);
        return pos;
      }
      var step = Math.ceil(dist / 2), middle = from + step;
      if (bidi) {
        middle = from;
        for (var i = 0; i < step; ++i) middle = moveVisually(lineObj, middle, 1);
      }
      var middleX = getX(middle);
      if (middleX > x) {to = middle; toX = middleX; if (toOutside = wrongLine) toX += 1000; dist = step;}
      else {from = middle; fromX = middleX; fromOutside = wrongLine; dist -= step;}
    }
  }

  var measureText;
  function textHeight(display) {
    if (display.cachedTextHeight != null) return display.cachedTextHeight;
    if (measureText == null) {
      measureText = elt("pre");
      // Measure a bunch of lines, for browsers that compute
      // fractional heights.
      for (var i = 0; i < 49; ++i) {
        measureText.appendChild(document.createTextNode("x"));
        measureText.appendChild(elt("br"));
      }
      measureText.appendChild(document.createTextNode("x"));
    }
    removeChildrenAndAdd(display.measure, measureText);
    var height = measureText.offsetHeight / 50;
    if (height > 3) display.cachedTextHeight = height;
    removeChildren(display.measure);
    return height || 1;
  }

  function charWidth(display) {
    if (display.cachedCharWidth != null) return display.cachedCharWidth;
    var anchor = elt("span", "x");
    var pre = elt("pre", [anchor]);
    removeChildrenAndAdd(display.measure, pre);
    var width = anchor.offsetWidth;
    if (width > 2) display.cachedCharWidth = width;
    return width || 10;
  }

  // OPERATIONS

  // Operations are used to wrap changes in such a way that each
  // change won't have to update the cursor and display (which would
  // be awkward, slow, and error-prone), but instead updates are
  // batched and then all combined and executed at once.

  var nextOpId = 0;
  function startOperation(cm) {
    cm.curOp = {
      // An array of ranges of lines that have to be updated. See
      // updateDisplay.
      changes: [],
      forceUpdate: false,
      updateInput: null,
      userSelChange: null,
      textChanged: null,
      selectionChanged: false,
      cursorActivity: false,
      updateMaxLine: false,
      updateScrollPos: false,
      id: ++nextOpId
    };
    if (!delayedCallbackDepth++) delayedCallbacks = [];
  }

  function endOperation(cm) {
    var op = cm.curOp, doc = cm.doc, display = cm.display;
    cm.curOp = null;

    if (op.updateMaxLine) computeMaxLength(cm);
    if (display.maxLineChanged && !cm.options.lineWrapping && display.maxLine) {
      var width = measureLineWidth(cm, display.maxLine);
      display.sizer.style.minWidth = Math.max(0, width + 3 + scrollerCutOff) + "px";
      display.maxLineChanged = false;
      var maxScrollLeft = Math.max(0, display.sizer.offsetLeft + display.sizer.offsetWidth - display.scroller.clientWidth);
      if (maxScrollLeft < doc.scrollLeft && !op.updateScrollPos)
        setScrollLeft(cm, Math.min(display.scroller.scrollLeft, maxScrollLeft), true);
    }
    var newScrollPos, updated;
    if (op.updateScrollPos) {
      newScrollPos = op.updateScrollPos;
    } else if (op.selectionChanged && display.scroller.clientHeight) { // don't rescroll if not visible
      var coords = cursorCoords(cm, doc.sel.head);
      newScrollPos = calculateScrollPos(cm, coords.left, coords.top, coords.left, coords.bottom);
    }
    if (op.changes.length || op.forceUpdate || newScrollPos && newScrollPos.scrollTop != null) {
      updated = updateDisplay(cm, op.changes, newScrollPos && newScrollPos.scrollTop, op.forceUpdate);
      if (cm.display.scroller.offsetHeight) cm.doc.scrollTop = cm.display.scroller.scrollTop;
    }
    if (!updated && op.selectionChanged) updateSelection(cm);
    if (op.updateScrollPos) {
      display.scroller.scrollTop = display.scrollbarV.scrollTop = doc.scrollTop = newScrollPos.scrollTop;
      display.scroller.scrollLeft = display.scrollbarH.scrollLeft = doc.scrollLeft = newScrollPos.scrollLeft;
      alignHorizontally(cm);
      if (op.scrollToPos)
        scrollPosIntoView(cm, clipPos(cm.doc, op.scrollToPos), op.scrollToPosMargin);
    } else if (newScrollPos) {
      scrollCursorIntoView(cm);
    }
    if (op.selectionChanged) restartBlink(cm);

    if (cm.state.focused && op.updateInput)
      resetInput(cm, op.userSelChange);

    var hidden = op.maybeHiddenMarkers, unhidden = op.maybeUnhiddenMarkers;
    if (hidden) for (var i = 0; i < hidden.length; ++i)
      if (!hidden[i].lines.length) signal(hidden[i], "hide");
    if (unhidden) for (var i = 0; i < unhidden.length; ++i)
      if (unhidden[i].lines.length) signal(unhidden[i], "unhide");

    var delayed;
    if (!--delayedCallbackDepth) {
      delayed = delayedCallbacks;
      delayedCallbacks = null;
    }
    if (op.textChanged)
      signal(cm, "change", cm, op.textChanged);
    if (op.cursorActivity) signal(cm, "cursorActivity", cm);
    if (delayed) for (var i = 0; i < delayed.length; ++i) delayed[i]();
  }

  // Wraps a function in an operation. Returns the wrapped function.
  function operation(cm1, f) {
    return function() {
      var cm = cm1 || this, withOp = !cm.curOp;
      if (withOp) startOperation(cm);
      try { var result = f.apply(cm, arguments); }
      finally { if (withOp) endOperation(cm); }
      return result;
    };
  }
  function docOperation(f) {
    return function() {
      var withOp = this.cm && !this.cm.curOp, result;
      if (withOp) startOperation(this.cm);
      try { result = f.apply(this, arguments); }
      finally { if (withOp) endOperation(this.cm); }
      return result;
    };
  }
  function runInOp(cm, f) {
    var withOp = !cm.curOp, result;
    if (withOp) startOperation(cm);
    try { result = f(); }
    finally { if (withOp) endOperation(cm); }
    return result;
  }

  function regChange(cm, from, to, lendiff) {
    if (from == null) from = cm.doc.first;
    if (to == null) to = cm.doc.first + cm.doc.size;
    cm.curOp.changes.push({from: from, to: to, diff: lendiff});
  }

  // INPUT HANDLING

  function slowPoll(cm) {
    if (cm.display.pollingFast) return;
    cm.display.poll.set(cm.options.pollInterval, function() {
      readInput(cm);
      if (cm.state.focused) slowPoll(cm);
    });
  }

  function fastPoll(cm) {
    var missed = false;
    cm.display.pollingFast = true;
    function p() {
      var changed = readInput(cm);
      if (!changed && !missed) {missed = true; cm.display.poll.set(60, p);}
      else {cm.display.pollingFast = false; slowPoll(cm);}
    }
    cm.display.poll.set(20, p);
  }

  // prevInput is a hack to work with IME. If we reset the textarea
  // on every change, that breaks IME. So we look for changes
  // compared to the previous content instead. (Modern browsers have
  // events that indicate IME taking place, but these are not widely
  // supported or compatible enough yet to rely on.)
  function readInput(cm) {
    var input = cm.display.input, prevInput = cm.display.prevInput, doc = cm.doc, sel = doc.sel;
    if (!cm.state.focused || hasSelection(input) || isReadOnly(cm) || cm.state.disableInput) return false;
    var text = input.value;
    if (text == prevInput && posEq(sel.from, sel.to)) return false;
    if (ie && !ie_lt9 && cm.display.inputHasSelection === text) {
      resetInput(cm, true);
      return false;
    }

    var withOp = !cm.curOp;
    if (withOp) startOperation(cm);
    sel.shift = false;
    var same = 0, l = Math.min(prevInput.length, text.length);
    while (same < l && prevInput.charCodeAt(same) == text.charCodeAt(same)) ++same;
    var from = sel.from, to = sel.to;
    if (same < prevInput.length)
      from = Pos(from.line, from.ch - (prevInput.length - same));
    else if (cm.state.overwrite && posEq(from, to) && !cm.state.pasteIncoming)
      to = Pos(to.line, Math.min(getLine(doc, to.line).text.length, to.ch + (text.length - same)));

    var updateInput = cm.curOp.updateInput;
    var changeEvent = {from: from, to: to, text: splitLines(text.slice(same)),
                       origin: cm.state.pasteIncoming ? "paste" : "+input"};
    makeChange(cm.doc, changeEvent, "end");
    cm.curOp.updateInput = updateInput;
    signalLater(cm, "inputRead", cm, changeEvent);

    if (text.length > 1000 || text.indexOf("\n") > -1) input.value = cm.display.prevInput = "";
    else cm.display.prevInput = text;
    if (withOp) endOperation(cm);
    cm.state.pasteIncoming = false;
    return true;
  }

  function resetInput(cm, user) {
    var minimal, selected, doc = cm.doc;
    if (!posEq(doc.sel.from, doc.sel.to)) {
      cm.display.prevInput = "";
      minimal = hasCopyEvent &&
        (doc.sel.to.line - doc.sel.from.line > 100 || (selected = cm.getSelection()).length > 1000);
      var content = minimal ? "-" : selected || cm.getSelection();
      cm.display.input.value = content;
      if (cm.state.focused) selectInput(cm.display.input);
      if (ie && !ie_lt9) cm.display.inputHasSelection = content;
    } else if (user) {
      cm.display.prevInput = cm.display.input.value = "";
      if (ie && !ie_lt9) cm.display.inputHasSelection = null;
    }
    cm.display.inaccurateSelection = minimal;
  }

  function focusInput(cm) {
    if (cm.options.readOnly != "nocursor" && (!mobile || document.activeElement != cm.display.input))
      cm.display.input.focus();
  }

  function isReadOnly(cm) {
    return cm.options.readOnly || cm.doc.cantEdit;
  }

  // EVENT HANDLERS

  function registerEventHandlers(cm) {
    var d = cm.display;
    on(d.scroller, "mousedown", operation(cm, onMouseDown));
    if (ie)
      on(d.scroller, "dblclick", operation(cm, function(e) {
        if (signalDOMEvent(cm, e)) return;
        var pos = posFromMouse(cm, e);
        if (!pos || clickInGutter(cm, e) || eventInWidget(cm.display, e)) return;
        e_preventDefault(e);
        var word = findWordAt(getLine(cm.doc, pos.line).text, pos);
        extendSelection(cm.doc, word.from, word.to);
      }));
    else
      on(d.scroller, "dblclick", function(e) { signalDOMEvent(cm, e) || e_preventDefault(e); });
    on(d.lineSpace, "selectstart", function(e) {
      if (!eventInWidget(d, e)) e_preventDefault(e);
    });
    // Gecko browsers fire contextmenu *after* opening the menu, at
    // which point we can't mess with it anymore. Context menu is
    // handled in onMouseDown for Gecko.
    if (!captureMiddleClick) on(d.scroller, "contextmenu", function(e) {onContextMenu(cm, e);});

    on(d.scroller, "scroll", function() {
      if (d.scroller.clientHeight) {
        setScrollTop(cm, d.scroller.scrollTop);
        setScrollLeft(cm, d.scroller.scrollLeft, true);
        signal(cm, "scroll", cm);
      }
    });
    on(d.scrollbarV, "scroll", function() {
      if (d.scroller.clientHeight) setScrollTop(cm, d.scrollbarV.scrollTop);
    });
    on(d.scrollbarH, "scroll", function() {
      if (d.scroller.clientHeight) setScrollLeft(cm, d.scrollbarH.scrollLeft);
    });

    on(d.scroller, "mousewheel", function(e){onScrollWheel(cm, e);});
    on(d.scroller, "DOMMouseScroll", function(e){onScrollWheel(cm, e);});

    function reFocus() { if (cm.state.focused) setTimeout(bind(focusInput, cm), 0); }
    on(d.scrollbarH, "mousedown", reFocus);
    on(d.scrollbarV, "mousedown", reFocus);
    // Prevent wrapper from ever scrolling
    on(d.wrapper, "scroll", function() { d.wrapper.scrollTop = d.wrapper.scrollLeft = 0; });

    var resizeTimer;
    function onResize() {
      if (resizeTimer == null) resizeTimer = setTimeout(function() {
        resizeTimer = null;
        // Might be a text scaling operation, clear size caches.
        d.cachedCharWidth = d.cachedTextHeight = knownScrollbarWidth = null;
        clearCaches(cm);
        runInOp(cm, bind(regChange, cm));
      }, 100);
    }
    on(window, "resize", onResize);
    // Above handler holds on to the editor and its data structures.
    // Here we poll to unregister it when the editor is no longer in
    // the document, so that it can be garbage-collected.
    function unregister() {
      for (var p = d.wrapper.parentNode; p && p != document.body; p = p.parentNode) {}
      if (p) setTimeout(unregister, 5000);
      else off(window, "resize", onResize);
    }
    setTimeout(unregister, 5000);

    on(d.input, "keyup", operation(cm, function(e) {
      if (signalDOMEvent(cm, e) || cm.options.onKeyEvent && cm.options.onKeyEvent(cm, addStop(e))) return;
      if (e.keyCode == 16) cm.doc.sel.shift = false;
    }));
    on(d.input, "input", bind(fastPoll, cm));
    on(d.input, "keydown", operation(cm, onKeyDown));
    on(d.input, "keypress", operation(cm, onKeyPress));
    on(d.input, "focus", bind(onFocus, cm));
    on(d.input, "blur", bind(onBlur, cm));

    function drag_(e) {
      if (signalDOMEvent(cm, e) || cm.options.onDragEvent && cm.options.onDragEvent(cm, addStop(e))) return;
      e_stop(e);
    }
    if (cm.options.dragDrop) {
      on(d.scroller, "dragstart", function(e){onDragStart(cm, e);});
      on(d.scroller, "dragenter", drag_);
      on(d.scroller, "dragover", drag_);
      on(d.scroller, "drop", operation(cm, onDrop));
    }
    on(d.scroller, "paste", function(e){
      if (eventInWidget(d, e)) return;
      focusInput(cm);
      fastPoll(cm);
    });
    on(d.input, "paste", function() {
      cm.state.pasteIncoming = true;
      fastPoll(cm);
    });

    function prepareCopy() {
      if (d.inaccurateSelection) {
        d.prevInput = "";
        d.inaccurateSelection = false;
        d.input.value = cm.getSelection();
        selectInput(d.input);
      }
    }
    on(d.input, "cut", prepareCopy);
    on(d.input, "copy", prepareCopy);

    // Needed to handle Tab key in KHTML
    if (khtml) on(d.sizer, "mouseup", function() {
        if (document.activeElement == d.input) d.input.blur();
        focusInput(cm);
    });
  }

  function eventInWidget(display, e) {
    for (var n = e_target(e); n != display.wrapper; n = n.parentNode) {
      if (!n || n.ignoreEvents || n.parentNode == display.sizer && n != display.mover) return true;
    }
  }

  function posFromMouse(cm, e, liberal) {
    var display = cm.display;
    if (!liberal) {
      var target = e_target(e);
      if (target == display.scrollbarH || target == display.scrollbarH.firstChild ||
          target == display.scrollbarV || target == display.scrollbarV.firstChild ||
          target == display.scrollbarFiller || target == display.gutterFiller) return null;
    }
    var x, y, space = getRect(display.lineSpace);
    // Fails unpredictably on IE[67] when mouse is dragged around quickly.
    try { x = e.clientX; y = e.clientY; } catch (e) { return null; }
    return coordsChar(cm, x - space.left, y - space.top);
  }

  var lastClick, lastDoubleClick;
  function onMouseDown(e) {
    if (signalDOMEvent(this, e)) return;
    var cm = this, display = cm.display, doc = cm.doc, sel = doc.sel;
    sel.shift = e.shiftKey;

    if (eventInWidget(display, e)) {
      if (!webkit) {
        display.scroller.draggable = false;
        setTimeout(function(){display.scroller.draggable = true;}, 100);
      }
      return;
    }
    if (clickInGutter(cm, e)) return;
    var start = posFromMouse(cm, e);

    switch (e_button(e)) {
    case 3:
      if (captureMiddleClick) onContextMenu.call(cm, cm, e);
      return;
    case 2:
      if (start) extendSelection(cm.doc, start);
      setTimeout(bind(focusInput, cm), 20);
      e_preventDefault(e);
      return;
    }
    // For button 1, if it was clicked inside the editor
    // (posFromMouse returning non-null), we have to adjust the
    // selection.
    if (!start) {if (e_target(e) == display.scroller) e_preventDefault(e); return;}

    if (!cm.state.focused) onFocus(cm);

    var now = +new Date, type = "single";
    if (lastDoubleClick && lastDoubleClick.time > now - 400 && posEq(lastDoubleClick.pos, start)) {
      type = "triple";
      e_preventDefault(e);
      setTimeout(bind(focusInput, cm), 20);
      selectLine(cm, start.line);
    } else if (lastClick && lastClick.time > now - 400 && posEq(lastClick.pos, start)) {
      type = "double";
      lastDoubleClick = {time: now, pos: start};
      e_preventDefault(e);
      var word = findWordAt(getLine(doc, start.line).text, start);
      extendSelection(cm.doc, word.from, word.to);
    } else { lastClick = {time: now, pos: start}; }

    var last = start;
    if (cm.options.dragDrop && dragAndDrop && !isReadOnly(cm) && !posEq(sel.from, sel.to) &&
        !posLess(start, sel.from) && !posLess(sel.to, start) && type == "single") {
      var dragEnd = operation(cm, function(e2) {
        if (webkit) display.scroller.draggable = false;
        cm.state.draggingText = false;
        off(document, "mouseup", dragEnd);
        off(display.scroller, "drop", dragEnd);
        if (Math.abs(e.clientX - e2.clientX) + Math.abs(e.clientY - e2.clientY) < 10) {
          e_preventDefault(e2);
          extendSelection(cm.doc, start);
          focusInput(cm);
        }
      });
      // Let the drag handler handle this.
      if (webkit) display.scroller.draggable = true;
      cm.state.draggingText = dragEnd;
      // IE's approach to draggable
      if (display.scroller.dragDrop) display.scroller.dragDrop();
      on(document, "mouseup", dragEnd);
      on(display.scroller, "drop", dragEnd);
      return;
    }
    e_preventDefault(e);
    if (type == "single") extendSelection(cm.doc, clipPos(doc, start));

    var startstart = sel.from, startend = sel.to, lastPos = start;

    function doSelect(cur) {
      if (posEq(lastPos, cur)) return;
      lastPos = cur;

      if (type == "single") {
        extendSelection(cm.doc, clipPos(doc, start), cur);
        return;
      }

      startstart = clipPos(doc, startstart);
      startend = clipPos(doc, startend);
      if (type == "double") {
        var word = findWordAt(getLine(doc, cur.line).text, cur);
        if (posLess(cur, startstart)) extendSelection(cm.doc, word.from, startend);
        else extendSelection(cm.doc, startstart, word.to);
      } else if (type == "triple") {
        if (posLess(cur, startstart)) extendSelection(cm.doc, startend, clipPos(doc, Pos(cur.line, 0)));
        else extendSelection(cm.doc, startstart, clipPos(doc, Pos(cur.line + 1, 0)));
      }
    }

    var editorSize = getRect(display.wrapper);
    // Used to ensure timeout re-tries don't fire when another extend
    // happened in the meantime (clearTimeout isn't reliable -- at
    // least on Chrome, the timeouts still happen even when cleared,
    // if the clear happens after their scheduled firing time).
    var counter = 0;

    function extend(e) {
      var curCount = ++counter;
      var cur = posFromMouse(cm, e, true);
      if (!cur) return;
      if (!posEq(cur, last)) {
        if (!cm.state.focused) onFocus(cm);
        last = cur;
        doSelect(cur);
        var visible = visibleLines(display, doc);
        if (cur.line >= visible.to || cur.line < visible.from)
          setTimeout(operation(cm, function(){if (counter == curCount) extend(e);}), 150);
      } else {
        var outside = e.clientY < editorSize.top ? -20 : e.clientY > editorSize.bottom ? 20 : 0;
        if (outside) setTimeout(operation(cm, function() {
          if (counter != curCount) return;
          display.scroller.scrollTop += outside;
          extend(e);
        }), 50);
      }
    }

    function done(e) {
      counter = Infinity;
      e_preventDefault(e);
      focusInput(cm);
      off(document, "mousemove", move);
      off(document, "mouseup", up);
    }

    var move = operation(cm, function(e) {
      if (!ie && !e_button(e)) done(e);
      else extend(e);
    });
    var up = operation(cm, done);
    on(document, "mousemove", move);
    on(document, "mouseup", up);
  }

  function clickInGutter(cm, e) {
    var display = cm.display;
    try { var mX = e.clientX, mY = e.clientY; }
    catch(e) { return false; }

    if (mX >= Math.floor(getRect(display.gutters).right)) return false;
    e_preventDefault(e);
    if (!hasHandler(cm, "gutterClick")) return true;

    var lineBox = getRect(display.lineDiv);
    if (mY > lineBox.bottom) return true;
    mY -= lineBox.top - display.viewOffset;

    for (var i = 0; i < cm.options.gutters.length; ++i) {
      var g = display.gutters.childNodes[i];
      if (g && getRect(g).right >= mX) {
        var line = lineAtHeight(cm.doc, mY);
        var gutter = cm.options.gutters[i];
        signalLater(cm, "gutterClick", cm, line, gutter, e);
        break;
      }
    }
    return true;
  }

  // Kludge to work around strange IE behavior where it'll sometimes
  // re-fire a series of drag-related events right after the drop (#1551)
  var lastDrop = 0;

  function onDrop(e) {
    var cm = this;
    if (signalDOMEvent(cm, e) || eventInWidget(cm.display, e) || (cm.options.onDragEvent && cm.options.onDragEvent(cm, addStop(e))))
      return;
    e_preventDefault(e);
    if (ie) lastDrop = +new Date;
    var pos = posFromMouse(cm, e, true), files = e.dataTransfer.files;
    if (!pos || isReadOnly(cm)) return;
    if (files && files.length && window.FileReader && window.File) {
      var n = files.length, text = Array(n), read = 0;
      var loadFile = function(file, i) {
        var reader = new FileReader;
        reader.onload = function() {
          text[i] = reader.result;
          if (++read == n) {
            pos = clipPos(cm.doc, pos);
            makeChange(cm.doc, {from: pos, to: pos, text: splitLines(text.join("\n")), origin: "paste"}, "around");
          }
        };
        reader.readAsText(file);
      };
      for (var i = 0; i < n; ++i) loadFile(files[i], i);
    } else {
      // Don't do a replace if the drop happened inside of the selected text.
      if (cm.state.draggingText && !(posLess(pos, cm.doc.sel.from) || posLess(cm.doc.sel.to, pos))) {
        cm.state.draggingText(e);
        // Ensure the editor is re-focused
        setTimeout(bind(focusInput, cm), 20);
        return;
      }
      try {
        var text = e.dataTransfer.getData("Text");
        if (text) {
          var curFrom = cm.doc.sel.from, curTo = cm.doc.sel.to;
          setSelection(cm.doc, pos, pos);
          if (cm.state.draggingText) replaceRange(cm.doc, "", curFrom, curTo, "paste");
          cm.replaceSelection(text, null, "paste");
          focusInput(cm);
          onFocus(cm);
        }
      }
      catch(e){}
    }
  }

  function onDragStart(cm, e) {
    if (ie && (!cm.state.draggingText || +new Date - lastDrop < 100)) { e_stop(e); return; }
    if (signalDOMEvent(cm, e) || eventInWidget(cm.display, e)) return;

    var txt = cm.getSelection();
    e.dataTransfer.setData("Text", txt);

    // Use dummy image instead of default browsers image.
    // Recent Safari (~6.0.2) have a tendency to segfault when this happens, so we don't do it there.
    if (e.dataTransfer.setDragImage && !safari) {
      var img = elt("img", null, null, "position: fixed; left: 0; top: 0;");
      if (opera) {
        img.width = img.height = 1;
        cm.display.wrapper.appendChild(img);
        // Force a relayout, or Opera won't use our image for some obscure reason
        img._top = img.offsetTop;
      }
      e.dataTransfer.setDragImage(img, 0, 0);
      if (opera) img.parentNode.removeChild(img);
    }
  }

  function setScrollTop(cm, val) {
    if (Math.abs(cm.doc.scrollTop - val) < 2) return;
    cm.doc.scrollTop = val;
    if (!gecko) updateDisplay(cm, [], val);
    if (cm.display.scroller.scrollTop != val) cm.display.scroller.scrollTop = val;
    if (cm.display.scrollbarV.scrollTop != val) cm.display.scrollbarV.scrollTop = val;
    if (gecko) updateDisplay(cm, []);
    startWorker(cm, 100);
  }
  function setScrollLeft(cm, val, isScroller) {
    if (isScroller ? val == cm.doc.scrollLeft : Math.abs(cm.doc.scrollLeft - val) < 2) return;
    val = Math.min(val, cm.display.scroller.scrollWidth - cm.display.scroller.clientWidth);
    cm.doc.scrollLeft = val;
    alignHorizontally(cm);
    if (cm.display.scroller.scrollLeft != val) cm.display.scroller.scrollLeft = val;
    if (cm.display.scrollbarH.scrollLeft != val) cm.display.scrollbarH.scrollLeft = val;
  }

  // Since the delta values reported on mouse wheel events are
  // unstandardized between browsers and even browser versions, and
  // generally horribly unpredictable, this code starts by measuring
  // the scroll effect that the first few mouse wheel events have,
  // and, from that, detects the way it can convert deltas to pixel
  // offsets afterwards.
  //
  // The reason we want to know the amount a wheel event will scroll
  // is that it gives us a chance to update the display before the
  // actual scrolling happens, reducing flickering.

  var wheelSamples = 0, wheelPixelsPerUnit = null;
  // Fill in a browser-detected starting value on browsers where we
  // know one. These don't have to be accurate -- the result of them
  // being wrong would just be a slight flicker on the first wheel
  // scroll (if it is large enough).
  if (ie) wheelPixelsPerUnit = -.53;
  else if (gecko) wheelPixelsPerUnit = 15;
  else if (chrome) wheelPixelsPerUnit = -.7;
  else if (safari) wheelPixelsPerUnit = -1/3;

  function onScrollWheel(cm, e) {
    var dx = e.wheelDeltaX, dy = e.wheelDeltaY;
    if (dx == null && e.detail && e.axis == e.HORIZONTAL_AXIS) dx = e.detail;
    if (dy == null && e.detail && e.axis == e.VERTICAL_AXIS) dy = e.detail;
    else if (dy == null) dy = e.wheelDelta;

    var display = cm.display, scroll = display.scroller;
    // Quit if there's nothing to scroll here
    if (!(dx && scroll.scrollWidth > scroll.clientWidth ||
          dy && scroll.scrollHeight > scroll.clientHeight)) return;

    // Webkit browsers on OS X abort momentum scrolls when the target
    // of the scroll event is removed from the scrollable element.
    // This hack (see related code in patchDisplay) makes sure the
    // element is kept around.
    if (dy && mac && webkit) {
      for (var cur = e.target; cur != scroll; cur = cur.parentNode) {
        if (cur.lineObj) {
          cm.display.currentWheelTarget = cur;
          break;
        }
      }
    }

    // On some browsers, horizontal scrolling will cause redraws to
    // happen before the gutter has been realigned, causing it to
    // wriggle around in a most unseemly way. When we have an
    // estimated pixels/delta value, we just handle horizontal
    // scrolling entirely here. It'll be slightly off from native, but
    // better than glitching out.
    if (dx && !gecko && !opera && wheelPixelsPerUnit != null) {
      if (dy)
        setScrollTop(cm, Math.max(0, Math.min(scroll.scrollTop + dy * wheelPixelsPerUnit, scroll.scrollHeight - scroll.clientHeight)));
      setScrollLeft(cm, Math.max(0, Math.min(scroll.scrollLeft + dx * wheelPixelsPerUnit, scroll.scrollWidth - scroll.clientWidth)));
      e_preventDefault(e);
      display.wheelStartX = null; // Abort measurement, if in progress
      return;
    }

    if (dy && wheelPixelsPerUnit != null) {
      var pixels = dy * wheelPixelsPerUnit;
      var top = cm.doc.scrollTop, bot = top + display.wrapper.clientHeight;
      if (pixels < 0) top = Math.max(0, top + pixels - 50);
      else bot = Math.min(cm.doc.height, bot + pixels + 50);
      updateDisplay(cm, [], {top: top, bottom: bot});
    }

    if (wheelSamples < 20) {
      if (display.wheelStartX == null) {
        display.wheelStartX = scroll.scrollLeft; display.wheelStartY = scroll.scrollTop;
        display.wheelDX = dx; display.wheelDY = dy;
        setTimeout(function() {
          if (display.wheelStartX == null) return;
          var movedX = scroll.scrollLeft - display.wheelStartX;
          var movedY = scroll.scrollTop - display.wheelStartY;
          var sample = (movedY && display.wheelDY && movedY / display.wheelDY) ||
            (movedX && display.wheelDX && movedX / display.wheelDX);
          display.wheelStartX = display.wheelStartY = null;
          if (!sample) return;
          wheelPixelsPerUnit = (wheelPixelsPerUnit * wheelSamples + sample) / (wheelSamples + 1);
          ++wheelSamples;
        }, 200);
      } else {
        display.wheelDX += dx; display.wheelDY += dy;
      }
    }
  }

  function doHandleBinding(cm, bound, dropShift) {
    if (typeof bound == "string") {
      bound = commands[bound];
      if (!bound) return false;
    }
    // Ensure previous input has been read, so that the handler sees a
    // consistent view of the document
    if (cm.display.pollingFast && readInput(cm)) cm.display.pollingFast = false;
    var doc = cm.doc, prevShift = doc.sel.shift, done = false;
    try {
      if (isReadOnly(cm)) cm.state.suppressEdits = true;
      if (dropShift) doc.sel.shift = false;
      done = bound(cm) != Pass;
    } finally {
      doc.sel.shift = prevShift;
      cm.state.suppressEdits = false;
    }
    return done;
  }

  function allKeyMaps(cm) {
    var maps = cm.state.keyMaps.slice(0);
    if (cm.options.extraKeys) maps.push(cm.options.extraKeys);
    maps.push(cm.options.keyMap);
    return maps;
  }

  var maybeTransition;
  function handleKeyBinding(cm, e) {
    // Handle auto keymap transitions
    var startMap = getKeyMap(cm.options.keyMap), next = startMap.auto;
    clearTimeout(maybeTransition);
    if (next && !isModifierKey(e)) maybeTransition = setTimeout(function() {
      if (getKeyMap(cm.options.keyMap) == startMap) {
        cm.options.keyMap = (next.call ? next.call(null, cm) : next);
        keyMapChanged(cm);
      }
    }, 50);

    var name = keyName(e, true), handled = false;
    if (!name) return false;
    var keymaps = allKeyMaps(cm);

    if (e.shiftKey) {
      // First try to resolve full name (including 'Shift-'). Failing
      // that, see if there is a cursor-motion command (starting with
      // 'go') bound to the keyname without 'Shift-'.
      handled = lookupKey("Shift-" + name, keymaps, function(b) {return doHandleBinding(cm, b, true);})
             || lookupKey(name, keymaps, function(b) {
                  if (typeof b == "string" ? /^go[A-Z]/.test(b) : b.motion)
                    return doHandleBinding(cm, b);
                });
    } else {
      handled = lookupKey(name, keymaps, function(b) { return doHandleBinding(cm, b); });
    }

    if (handled) {
      e_preventDefault(e);
      restartBlink(cm);
      if (ie_lt9) { e.oldKeyCode = e.keyCode; e.keyCode = 0; }
      signalLater(cm, "keyHandled", cm, name, e);
    }
    return handled;
  }

  function handleCharBinding(cm, e, ch) {
    var handled = lookupKey("'" + ch + "'", allKeyMaps(cm),
                            function(b) { return doHandleBinding(cm, b, true); });
    if (handled) {
      e_preventDefault(e);
      restartBlink(cm);
      signalLater(cm, "keyHandled", cm, "'" + ch + "'", e);
    }
    return handled;
  }

  var lastStoppedKey = null;
  function onKeyDown(e) {
    var cm = this;
    if (!cm.state.focused) onFocus(cm);
    if (ie && e.keyCode == 27) { e.returnValue = false; }
    if (signalDOMEvent(cm, e) || cm.options.onKeyEvent && cm.options.onKeyEvent(cm, addStop(e))) return;
    var code = e.keyCode;
    // IE does strange things with escape.
    cm.doc.sel.shift = code == 16 || e.shiftKey;
    // First give onKeyEvent option a chance to handle this.
    var handled = handleKeyBinding(cm, e);
    if (opera) {
      lastStoppedKey = handled ? code : null;
      // Opera has no cut event... we try to at least catch the key combo
      if (!handled && code == 88 && !hasCopyEvent && (mac ? e.metaKey : e.ctrlKey))
        cm.replaceSelection("");
    }
  }

  function onKeyPress(e) {
    var cm = this;
    if (signalDOMEvent(cm, e) || cm.options.onKeyEvent && cm.options.onKeyEvent(cm, addStop(e))) return;
    var keyCode = e.keyCode, charCode = e.charCode;
    if (opera && keyCode == lastStoppedKey) {lastStoppedKey = null; e_preventDefault(e); return;}
    if (((opera && (!e.which || e.which < 10)) || khtml) && handleKeyBinding(cm, e)) return;
    var ch = String.fromCharCode(charCode == null ? keyCode : charCode);
    if (this.options.electricChars && this.doc.mode.electricChars &&
        this.options.smartIndent && !isReadOnly(this) &&
        this.doc.mode.electricChars.indexOf(ch) > -1)
      setTimeout(operation(cm, function() {indentLine(cm, cm.doc.sel.to.line, "smart");}), 75);
    if (handleCharBinding(cm, e, ch)) return;
    if (ie && !ie_lt9) cm.display.inputHasSelection = null;
    fastPoll(cm);
  }

  function onFocus(cm) {
    if (cm.options.readOnly == "nocursor") return;
    if (!cm.state.focused) {
      signal(cm, "focus", cm);
      cm.state.focused = true;
      if (cm.display.wrapper.className.search(/\bCodeMirror-focused\b/) == -1)
        cm.display.wrapper.className += " CodeMirror-focused";
      resetInput(cm, true);
    }
    slowPoll(cm);
    restartBlink(cm);
  }
  function onBlur(cm) {
    if (cm.state.focused) {
      signal(cm, "blur", cm);
      cm.state.focused = false;
      cm.display.wrapper.className = cm.display.wrapper.className.replace(" CodeMirror-focused", "");
    }
    clearInterval(cm.display.blinker);
    setTimeout(function() {if (!cm.state.focused) cm.doc.sel.shift = false;}, 150);
  }

  var detectingSelectAll;
  function onContextMenu(cm, e) {
    if (signalDOMEvent(cm, e, "contextmenu")) return;
    var display = cm.display, sel = cm.doc.sel;
    if (eventInWidget(display, e)) return;

    var pos = posFromMouse(cm, e), scrollPos = display.scroller.scrollTop;
    if (!pos || opera) return; // Opera is difficult.
    if (posEq(sel.from, sel.to) || posLess(pos, sel.from) || !posLess(pos, sel.to))
      operation(cm, setSelection)(cm.doc, pos, pos);

    var oldCSS = display.input.style.cssText;
    display.inputDiv.style.position = "absolute";
    display.input.style.cssText = "position: fixed; width: 30px; height: 30px; top: " + (e.clientY - 5) +
      "px; left: " + (e.clientX - 5) + "px; z-index: 1000; background: white; outline: none;" +
      "border-width: 0; outline: none; overflow: hidden; opacity: .05; -ms-opacity: .05; filter: alpha(opacity=5);";
    focusInput(cm);
    resetInput(cm, true);
    // Adds "Select all" to context menu in FF
    if (posEq(sel.from, sel.to)) display.input.value = display.prevInput = " ";

    function prepareSelectAllHack() {
      if (display.input.selectionStart != null) {
        var extval = display.input.value = " " + (posEq(sel.from, sel.to) ? "" : display.input.value);
        display.prevInput = " ";
        display.input.selectionStart = 1; display.input.selectionEnd = extval.length;
      }
    }
    function rehide() {
      display.inputDiv.style.position = "relative";
      display.input.style.cssText = oldCSS;
      if (ie_lt9) display.scrollbarV.scrollTop = display.scroller.scrollTop = scrollPos;
      slowPoll(cm);

      // Try to detect the user choosing select-all
      if (display.input.selectionStart != null) {
        if (!ie || ie_lt9) prepareSelectAllHack();
        clearTimeout(detectingSelectAll);
        var i = 0, poll = function(){
          if (display.prevInput == " " && display.input.selectionStart == 0)
            operation(cm, commands.selectAll)(cm);
          else if (i++ < 10) detectingSelectAll = setTimeout(poll, 500);
          else resetInput(cm);
        };
        detectingSelectAll = setTimeout(poll, 200);
      }
    }

    if (ie && !ie_lt9) prepareSelectAllHack();
    if (captureMiddleClick) {
      e_stop(e);
      var mouseup = function() {
        off(window, "mouseup", mouseup);
        setTimeout(rehide, 20);
      };
      on(window, "mouseup", mouseup);
    } else {
      setTimeout(rehide, 50);
    }
  }

  // UPDATING

  var changeEnd = CodeMirror.changeEnd = function(change) {
    if (!change.text) return change.to;
    return Pos(change.from.line + change.text.length - 1,
               lst(change.text).length + (change.text.length == 1 ? change.from.ch : 0));
  };

  // Make sure a position will be valid after the given change.
  function clipPostChange(doc, change, pos) {
    if (!posLess(change.from, pos)) return clipPos(doc, pos);
    var diff = (change.text.length - 1) - (change.to.line - change.from.line);
    if (pos.line > change.to.line + diff) {
      var preLine = pos.line - diff, lastLine = doc.first + doc.size - 1;
      if (preLine > lastLine) return Pos(lastLine, getLine(doc, lastLine).text.length);
      return clipToLen(pos, getLine(doc, preLine).text.length);
    }
    if (pos.line == change.to.line + diff)
      return clipToLen(pos, lst(change.text).length + (change.text.length == 1 ? change.from.ch : 0) +
                       getLine(doc, change.to.line).text.length - change.to.ch);
    var inside = pos.line - change.from.line;
    return clipToLen(pos, change.text[inside].length + (inside ? 0 : change.from.ch));
  }

  // Hint can be null|"end"|"start"|"around"|{anchor,head}
  function computeSelAfterChange(doc, change, hint) {
    if (hint && typeof hint == "object") // Assumed to be {anchor, head} object
      return {anchor: clipPostChange(doc, change, hint.anchor),
              head: clipPostChange(doc, change, hint.head)};

    if (hint == "start") return {anchor: change.from, head: change.from};

    var end = changeEnd(change);
    if (hint == "around") return {anchor: change.from, head: end};
    if (hint == "end") return {anchor: end, head: end};

    // hint is null, leave the selection alone as much as possible
    var adjustPos = function(pos) {
      if (posLess(pos, change.from)) return pos;
      if (!posLess(change.to, pos)) return end;

      var line = pos.line + change.text.length - (change.to.line - change.from.line) - 1, ch = pos.ch;
      if (pos.line == change.to.line) ch += end.ch - change.to.ch;
      return Pos(line, ch);
    };
    return {anchor: adjustPos(doc.sel.anchor), head: adjustPos(doc.sel.head)};
  }

  function filterChange(doc, change, update) {
    var obj = {
      canceled: false,
      from: change.from,
      to: change.to,
      text: change.text,
      origin: change.origin,
      cancel: function() { this.canceled = true; }
    };
    if (update) obj.update = function(from, to, text, origin) {
      if (from) this.from = clipPos(doc, from);
      if (to) this.to = clipPos(doc, to);
      if (text) this.text = text;
      if (origin !== undefined) this.origin = origin;
    };
    signal(doc, "beforeChange", doc, obj);
    if (doc.cm) signal(doc.cm, "beforeChange", doc.cm, obj);

    if (obj.canceled) return null;
    return {from: obj.from, to: obj.to, text: obj.text, origin: obj.origin};
  }

  // Replace the range from from to to by the strings in replacement.
  // change is a {from, to, text [, origin]} object
  function makeChange(doc, change, selUpdate, ignoreReadOnly) {
    if (doc.cm) {
      if (!doc.cm.curOp) return operation(doc.cm, makeChange)(doc, change, selUpdate, ignoreReadOnly);
      if (doc.cm.state.suppressEdits) return;
    }

    if (hasHandler(doc, "beforeChange") || doc.cm && hasHandler(doc.cm, "beforeChange")) {
      change = filterChange(doc, change, true);
      if (!change) return;
    }

    // Possibly split or suppress the update based on the presence
    // of read-only spans in its range.
    var split = sawReadOnlySpans && !ignoreReadOnly && removeReadOnlyRanges(doc, change.from, change.to);
    if (split) {
      for (var i = split.length - 1; i >= 1; --i)
        makeChangeNoReadonly(doc, {from: split[i].from, to: split[i].to, text: [""]});
      if (split.length)
        makeChangeNoReadonly(doc, {from: split[0].from, to: split[0].to, text: change.text}, selUpdate);
    } else {
      makeChangeNoReadonly(doc, change, selUpdate);
    }
  }

  function makeChangeNoReadonly(doc, change, selUpdate) {
    var selAfter = computeSelAfterChange(doc, change, selUpdate);
    addToHistory(doc, change, selAfter, doc.cm ? doc.cm.curOp.id : NaN);

    makeChangeSingleDoc(doc, change, selAfter, stretchSpansOverChange(doc, change));
    var rebased = [];

    linkedDocs(doc, function(doc, sharedHist) {
      if (!sharedHist && indexOf(rebased, doc.history) == -1) {
        rebaseHist(doc.history, change);
        rebased.push(doc.history);
      }
      makeChangeSingleDoc(doc, change, null, stretchSpansOverChange(doc, change));
    });
  }

  function makeChangeFromHistory(doc, type) {
    if (doc.cm && doc.cm.state.suppressEdits) return;

    var hist = doc.history;
    var event = (type == "undo" ? hist.done : hist.undone).pop();
    if (!event) return;

    var anti = {changes: [], anchorBefore: event.anchorAfter, headBefore: event.headAfter,
                anchorAfter: event.anchorBefore, headAfter: event.headBefore,
                generation: hist.generation};
    (type == "undo" ? hist.undone : hist.done).push(anti);
    hist.generation = event.generation || ++hist.maxGeneration;

    var filter = hasHandler(doc, "beforeChange") || doc.cm && hasHandler(doc.cm, "beforeChange");

    for (var i = event.changes.length - 1; i >= 0; --i) {
      var change = event.changes[i];
      change.origin = type;
      if (filter && !filterChange(doc, change, false)) {
        (type == "undo" ? hist.done : hist.undone).length = 0;
        return;
      }

      anti.changes.push(historyChangeFromChange(doc, change));

      var after = i ? computeSelAfterChange(doc, change, null)
                    : {anchor: event.anchorBefore, head: event.headBefore};
      makeChangeSingleDoc(doc, change, after, mergeOldSpans(doc, change));
      var rebased = [];

      linkedDocs(doc, function(doc, sharedHist) {
        if (!sharedHist && indexOf(rebased, doc.history) == -1) {
          rebaseHist(doc.history, change);
          rebased.push(doc.history);
        }
        makeChangeSingleDoc(doc, change, null, mergeOldSpans(doc, change));
      });
    }
  }

  function shiftDoc(doc, distance) {
    function shiftPos(pos) {return Pos(pos.line + distance, pos.ch);}
    doc.first += distance;
    if (doc.cm) regChange(doc.cm, doc.first, doc.first, distance);
    doc.sel.head = shiftPos(doc.sel.head); doc.sel.anchor = shiftPos(doc.sel.anchor);
    doc.sel.from = shiftPos(doc.sel.from); doc.sel.to = shiftPos(doc.sel.to);
  }

  function makeChangeSingleDoc(doc, change, selAfter, spans) {
    if (doc.cm && !doc.cm.curOp)
      return operation(doc.cm, makeChangeSingleDoc)(doc, change, selAfter, spans);

    if (change.to.line < doc.first) {
      shiftDoc(doc, change.text.length - 1 - (change.to.line - change.from.line));
      return;
    }
    if (change.from.line > doc.lastLine()) return;

    // Clip the change to the size of this doc
    if (change.from.line < doc.first) {
      var shift = change.text.length - 1 - (doc.first - change.from.line);
      shiftDoc(doc, shift);
      change = {from: Pos(doc.first, 0), to: Pos(change.to.line + shift, change.to.ch),
                text: [lst(change.text)], origin: change.origin};
    }
    var last = doc.lastLine();
    if (change.to.line > last) {
      change = {from: change.from, to: Pos(last, getLine(doc, last).text.length),
                text: [change.text[0]], origin: change.origin};
    }

    change.removed = getBetween(doc, change.from, change.to);

    if (!selAfter) selAfter = computeSelAfterChange(doc, change, null);
    if (doc.cm) makeChangeSingleDocInEditor(doc.cm, change, spans, selAfter);
    else updateDoc(doc, change, spans, selAfter);
  }

  function makeChangeSingleDocInEditor(cm, change, spans, selAfter) {
    var doc = cm.doc, display = cm.display, from = change.from, to = change.to;

    var recomputeMaxLength = false, checkWidthStart = from.line;
    if (!cm.options.lineWrapping) {
      checkWidthStart = lineNo(visualLine(doc, getLine(doc, from.line)));
      doc.iter(checkWidthStart, to.line + 1, function(line) {
        if (line == display.maxLine) {
          recomputeMaxLength = true;
          return true;
        }
      });
    }

    if (!posLess(doc.sel.head, change.from) && !posLess(change.to, doc.sel.head))
      cm.curOp.cursorActivity = true;

    updateDoc(doc, change, spans, selAfter, estimateHeight(cm));

    if (!cm.options.lineWrapping) {
      doc.iter(checkWidthStart, from.line + change.text.length, function(line) {
        var len = lineLength(doc, line);
        if (len > display.maxLineLength) {
          display.maxLine = line;
          display.maxLineLength = len;
          display.maxLineChanged = true;
          recomputeMaxLength = false;
        }
      });
      if (recomputeMaxLength) cm.curOp.updateMaxLine = true;
    }

    // Adjust frontier, schedule worker
    doc.frontier = Math.min(doc.frontier, from.line);
    startWorker(cm, 400);

    var lendiff = change.text.length - (to.line - from.line) - 1;
    // Remember that these lines changed, for updating the display
    regChange(cm, from.line, to.line + 1, lendiff);

    if (hasHandler(cm, "change")) {
      var changeObj = {from: from, to: to,
                       text: change.text,
                       removed: change.removed,
                       origin: change.origin};
      if (cm.curOp.textChanged) {
        for (var cur = cm.curOp.textChanged; cur.next; cur = cur.next) {}
        cur.next = changeObj;
      } else cm.curOp.textChanged = changeObj;
    }
  }

  function replaceRange(doc, code, from, to, origin) {
    if (!to) to = from;
    if (posLess(to, from)) { var tmp = to; to = from; from = tmp; }
    if (typeof code == "string") code = splitLines(code);
    makeChange(doc, {from: from, to: to, text: code, origin: origin}, null);
  }

  // POSITION OBJECT

  function Pos(line, ch) {
    if (!(this instanceof Pos)) return new Pos(line, ch);
    this.line = line; this.ch = ch;
  }
  CodeMirror.Pos = Pos;

  function posEq(a, b) {return a.line == b.line && a.ch == b.ch;}
  function posLess(a, b) {return a.line < b.line || (a.line == b.line && a.ch < b.ch);}
  function copyPos(x) {return Pos(x.line, x.ch);}

  // SELECTION

  function clipLine(doc, n) {return Math.max(doc.first, Math.min(n, doc.first + doc.size - 1));}
  function clipPos(doc, pos) {
    if (pos.line < doc.first) return Pos(doc.first, 0);
    var last = doc.first + doc.size - 1;
    if (pos.line > last) return Pos(last, getLine(doc, last).text.length);
    return clipToLen(pos, getLine(doc, pos.line).text.length);
  }
  function clipToLen(pos, linelen) {
    var ch = pos.ch;
    if (ch == null || ch > linelen) return Pos(pos.line, linelen);
    else if (ch < 0) return Pos(pos.line, 0);
    else return pos;
  }
  function isLine(doc, l) {return l >= doc.first && l < doc.first + doc.size;}

  // If shift is held, this will move the selection anchor. Otherwise,
  // it'll set the whole selection.
  function extendSelection(doc, pos, other, bias) {
    if (doc.sel.shift || doc.sel.extend) {
      var anchor = doc.sel.anchor;
      if (other) {
        var posBefore = posLess(pos, anchor);
        if (posBefore != posLess(other, anchor)) {
          anchor = pos;
          pos = other;
        } else if (posBefore != posLess(pos, other)) {
          pos = other;
        }
      }
      setSelection(doc, anchor, pos, bias);
    } else {
      setSelection(doc, pos, other || pos, bias);
    }
    if (doc.cm) doc.cm.curOp.userSelChange = true;
  }

  function filterSelectionChange(doc, anchor, head) {
    var obj = {anchor: anchor, head: head};
    signal(doc, "beforeSelectionChange", doc, obj);
    if (doc.cm) signal(doc.cm, "beforeSelectionChange", doc.cm, obj);
    obj.anchor = clipPos(doc, obj.anchor); obj.head = clipPos(doc, obj.head);
    return obj;
  }

  // Update the selection. Last two args are only used by
  // updateDoc, since they have to be expressed in the line
  // numbers before the update.
  function setSelection(doc, anchor, head, bias, checkAtomic) {
    if (!checkAtomic && hasHandler(doc, "beforeSelectionChange") || doc.cm && hasHandler(doc.cm, "beforeSelectionChange")) {
      var filtered = filterSelectionChange(doc, anchor, head);
      head = filtered.head;
      anchor = filtered.anchor;
    }

    var sel = doc.sel;
    sel.goalColumn = null;
    // Skip over atomic spans.
    if (checkAtomic || !posEq(anchor, sel.anchor))
      anchor = skipAtomic(doc, anchor, bias, checkAtomic != "push");
    if (checkAtomic || !posEq(head, sel.head))
      head = skipAtomic(doc, head, bias, checkAtomic != "push");

    if (posEq(sel.anchor, anchor) && posEq(sel.head, head)) return;

    sel.anchor = anchor; sel.head = head;
    var inv = posLess(head, anchor);
    sel.from = inv ? head : anchor;
    sel.to = inv ? anchor : head;

    if (doc.cm)
      doc.cm.curOp.updateInput = doc.cm.curOp.selectionChanged =
        doc.cm.curOp.cursorActivity = true;

    signalLater(doc, "cursorActivity", doc);
  }

  function reCheckSelection(cm) {
    setSelection(cm.doc, cm.doc.sel.from, cm.doc.sel.to, null, "push");
  }

  function skipAtomic(doc, pos, bias, mayClear) {
    var flipped = false, curPos = pos;
    var dir = bias || 1;
    doc.cantEdit = false;
    search: for (;;) {
      var line = getLine(doc, curPos.line);
      if (line.markedSpans) {
        for (var i = 0; i < line.markedSpans.length; ++i) {
          var sp = line.markedSpans[i], m = sp.marker;
          if ((sp.from == null || (m.inclusiveLeft ? sp.from <= curPos.ch : sp.from < curPos.ch)) &&
              (sp.to == null || (m.inclusiveRight ? sp.to >= curPos.ch : sp.to > curPos.ch))) {
            if (mayClear) {
              signal(m, "beforeCursorEnter");
              if (m.explicitlyCleared) {
                if (!line.markedSpans) break;
                else {--i; continue;}
              }
            }
            if (!m.atomic) continue;
            var newPos = m.find()[dir < 0 ? "from" : "to"];
            if (posEq(newPos, curPos)) {
              newPos.ch += dir;
              if (newPos.ch < 0) {
                if (newPos.line > doc.first) newPos = clipPos(doc, Pos(newPos.line - 1));
                else newPos = null;
              } else if (newPos.ch > line.text.length) {
                if (newPos.line < doc.first + doc.size - 1) newPos = Pos(newPos.line + 1, 0);
                else newPos = null;
              }
              if (!newPos) {
                if (flipped) {
                  // Driven in a corner -- no valid cursor position found at all
                  // -- try again *with* clearing, if we didn't already
                  if (!mayClear) return skipAtomic(doc, pos, bias, true);
                  // Otherwise, turn off editing until further notice, and return the start of the doc
                  doc.cantEdit = true;
                  return Pos(doc.first, 0);
                }
                flipped = true; newPos = pos; dir = -dir;
              }
            }
            curPos = newPos;
            continue search;
          }
        }
      }
      return curPos;
    }
  }

  // SCROLLING

  function scrollCursorIntoView(cm) {
    var coords = scrollPosIntoView(cm, cm.doc.sel.head, cm.options.cursorScrollMargin);
    if (!cm.state.focused) return;
    var display = cm.display, box = getRect(display.sizer), doScroll = null;
    if (coords.top + box.top < 0) doScroll = true;
    else if (coords.bottom + box.top > (window.innerHeight || document.documentElement.clientHeight)) doScroll = false;
    if (doScroll != null && !phantom) {
      var hidden = display.cursor.style.display == "none";
      if (hidden) {
        display.cursor.style.display = "";
        display.cursor.style.left = coords.left + "px";
        display.cursor.style.top = (coords.top - display.viewOffset) + "px";
      }
      display.cursor.scrollIntoView(doScroll);
      if (hidden) display.cursor.style.display = "none";
    }
  }

  function scrollPosIntoView(cm, pos, margin) {
    if (margin == null) margin = 0;
    for (;;) {
      var changed = false, coords = cursorCoords(cm, pos);
      var scrollPos = calculateScrollPos(cm, coords.left, coords.top - margin, coords.left, coords.bottom + margin);
      var startTop = cm.doc.scrollTop, startLeft = cm.doc.scrollLeft;
      if (scrollPos.scrollTop != null) {
        setScrollTop(cm, scrollPos.scrollTop);
        if (Math.abs(cm.doc.scrollTop - startTop) > 1) changed = true;
      }
      if (scrollPos.scrollLeft != null) {
        setScrollLeft(cm, scrollPos.scrollLeft);
        if (Math.abs(cm.doc.scrollLeft - startLeft) > 1) changed = true;
      }
      if (!changed) return coords;
    }
  }

  function scrollIntoView(cm, x1, y1, x2, y2) {
    var scrollPos = calculateScrollPos(cm, x1, y1, x2, y2);
    if (scrollPos.scrollTop != null) setScrollTop(cm, scrollPos.scrollTop);
    if (scrollPos.scrollLeft != null) setScrollLeft(cm, scrollPos.scrollLeft);
  }

  function calculateScrollPos(cm, x1, y1, x2, y2) {
    var display = cm.display, snapMargin = textHeight(cm.display);
    if (y1 < 0) y1 = 0;
    var screen = display.scroller.clientHeight - scrollerCutOff, screentop = display.scroller.scrollTop, result = {};
    var docBottom = cm.doc.height + paddingVert(display);
    var atTop = y1 < snapMargin, atBottom = y2 > docBottom - snapMargin;
    if (y1 < screentop) {
      result.scrollTop = atTop ? 0 : y1;
    } else if (y2 > screentop + screen) {
      var newTop = Math.min(y1, (atBottom ? docBottom : y2) - screen);
      if (newTop != screentop) result.scrollTop = newTop;
    }

    var screenw = display.scroller.clientWidth - scrollerCutOff, screenleft = display.scroller.scrollLeft;
    x1 += display.gutters.offsetWidth; x2 += display.gutters.offsetWidth;
    var gutterw = display.gutters.offsetWidth;
    var atLeft = x1 < gutterw + 10;
    if (x1 < screenleft + gutterw || atLeft) {
      if (atLeft) x1 = 0;
      result.scrollLeft = Math.max(0, x1 - 10 - gutterw);
    } else if (x2 > screenw + screenleft - 3) {
      result.scrollLeft = x2 + 10 - screenw;
    }
    return result;
  }

  function updateScrollPos(cm, left, top) {
    cm.curOp.updateScrollPos = {scrollLeft: left == null ? cm.doc.scrollLeft : left,
                                scrollTop: top == null ? cm.doc.scrollTop : top};
  }

  function addToScrollPos(cm, left, top) {
    var pos = cm.curOp.updateScrollPos || (cm.curOp.updateScrollPos = {scrollLeft: cm.doc.scrollLeft, scrollTop: cm.doc.scrollTop});
    var scroll = cm.display.scroller;
    pos.scrollTop = Math.max(0, Math.min(scroll.scrollHeight - scroll.clientHeight, pos.scrollTop + top));
    pos.scrollLeft = Math.max(0, Math.min(scroll.scrollWidth - scroll.clientWidth, pos.scrollLeft + left));
  }

  // API UTILITIES

  function indentLine(cm, n, how, aggressive) {
    var doc = cm.doc;
    if (how == null) how = "add";
    if (how == "smart") {
      if (!cm.doc.mode.indent) how = "prev";
      else var state = getStateBefore(cm, n);
    }

    var tabSize = cm.options.tabSize;
    var line = getLine(doc, n), curSpace = countColumn(line.text, null, tabSize);
    var curSpaceString = line.text.match(/^\s*/)[0], indentation;
    if (how == "smart") {
      indentation = cm.doc.mode.indent(state, line.text.slice(curSpaceString.length), line.text);
      if (indentation == Pass) {
        if (!aggressive) return;
        how = "prev";
      }
    }
    if (how == "prev") {
      if (n > doc.first) indentation = countColumn(getLine(doc, n-1).text, null, tabSize);
      else indentation = 0;
    } else if (how == "add") {
      indentation = curSpace + cm.options.indentUnit;
    } else if (how == "subtract") {
      indentation = curSpace - cm.options.indentUnit;
    } else if (typeof how == "number") {
      indentation = curSpace + how;
    }
    indentation = Math.max(0, indentation);

    var indentString = "", pos = 0;
    if (cm.options.indentWithTabs)
      for (var i = Math.floor(indentation / tabSize); i; --i) {pos += tabSize; indentString += "\t";}
    if (pos < indentation) indentString += spaceStr(indentation - pos);

    if (indentString != curSpaceString)
      replaceRange(cm.doc, indentString, Pos(n, 0), Pos(n, curSpaceString.length), "+input");
    line.stateAfter = null;
  }

  function changeLine(cm, handle, op) {
    var no = handle, line = handle, doc = cm.doc;
    if (typeof handle == "number") line = getLine(doc, clipLine(doc, handle));
    else no = lineNo(handle);
    if (no == null) return null;
    if (op(line, no)) regChange(cm, no, no + 1);
    else return null;
    return line;
  }

  function findPosH(doc, pos, dir, unit, visually) {
    var line = pos.line, ch = pos.ch, origDir = dir;
    var lineObj = getLine(doc, line);
    var possible = true;
    function findNextLine() {
      var l = line + dir;
      if (l < doc.first || l >= doc.first + doc.size) return (possible = false);
      line = l;
      return lineObj = getLine(doc, l);
    }
    function moveOnce(boundToLine) {
      var next = (visually ? moveVisually : moveLogically)(lineObj, ch, dir, true);
      if (next == null) {
        if (!boundToLine && findNextLine()) {
          if (visually) ch = (dir < 0 ? lineRight : lineLeft)(lineObj);
          else ch = dir < 0 ? lineObj.text.length : 0;
        } else return (possible = false);
      } else ch = next;
      return true;
    }

    if (unit == "char") moveOnce();
    else if (unit == "column") moveOnce(true);
    else if (unit == "word" || unit == "group") {
      var sawType = null, group = unit == "group";
      for (var first = true;; first = false) {
        if (dir < 0 && !moveOnce(!first)) break;
        var cur = lineObj.text.charAt(ch) || "\n";
        var type = isWordChar(cur) ? "w"
          : !group ? null
          : /\s/.test(cur) ? null
          : "p";
        if (sawType && sawType != type) {
          if (dir < 0) {dir = 1; moveOnce();}
          break;
        }
        if (type) sawType = type;
        if (dir > 0 && !moveOnce(!first)) break;
      }
    }
    var result = skipAtomic(doc, Pos(line, ch), origDir, true);
    if (!possible) result.hitSide = true;
    return result;
  }

  function findPosV(cm, pos, dir, unit) {
    var doc = cm.doc, x = pos.left, y;
    if (unit == "page") {
      var pageSize = Math.min(cm.display.wrapper.clientHeight, window.innerHeight || document.documentElement.clientHeight);
      y = pos.top + dir * (pageSize - (dir < 0 ? 1.5 : .5) * textHeight(cm.display));
    } else if (unit == "line") {
      y = dir > 0 ? pos.bottom + 3 : pos.top - 3;
    }
    for (;;) {
      var target = coordsChar(cm, x, y);
      if (!target.outside) break;
      if (dir < 0 ? y <= 0 : y >= doc.height) { target.hitSide = true; break; }
      y += dir * 5;
    }
    return target;
  }

  function findWordAt(line, pos) {
    var start = pos.ch, end = pos.ch;
    if (line) {
      if ((pos.xRel < 0 || end == line.length) && start) --start; else ++end;
      var startChar = line.charAt(start);
      var check = isWordChar(startChar) ? isWordChar
        : /\s/.test(startChar) ? function(ch) {return /\s/.test(ch);}
        : function(ch) {return !/\s/.test(ch) && !isWordChar(ch);};
      while (start > 0 && check(line.charAt(start - 1))) --start;
      while (end < line.length && check(line.charAt(end))) ++end;
    }
    return {from: Pos(pos.line, start), to: Pos(pos.line, end)};
  }

  function selectLine(cm, line) {
    extendSelection(cm.doc, Pos(line, 0), clipPos(cm.doc, Pos(line + 1, 0)));
  }

  // PROTOTYPE

  // The publicly visible API. Note that operation(null, f) means
  // 'wrap f in an operation, performed on its `this` parameter'

  CodeMirror.prototype = {
    constructor: CodeMirror,
    focus: function(){window.focus(); focusInput(this); onFocus(this); fastPoll(this);},

    setOption: function(option, value) {
      var options = this.options, old = options[option];
      if (options[option] == value && option != "mode") return;
      options[option] = value;
      if (optionHandlers.hasOwnProperty(option))
        operation(this, optionHandlers[option])(this, value, old);
    },

    getOption: function(option) {return this.options[option];},
    getDoc: function() {return this.doc;},

    addKeyMap: function(map, bottom) {
      this.state.keyMaps[bottom ? "push" : "unshift"](map);
    },
    removeKeyMap: function(map) {
      var maps = this.state.keyMaps;
      for (var i = 0; i < maps.length; ++i)
        if (maps[i] == map || (typeof maps[i] != "string" && maps[i].name == map)) {
          maps.splice(i, 1);
          return true;
        }
    },

    addOverlay: operation(null, function(spec, options) {
      var mode = spec.token ? spec : CodeMirror.getMode(this.options, spec);
      if (mode.startState) throw new Error("Overlays may not be stateful.");
      this.state.overlays.push({mode: mode, modeSpec: spec, opaque: options && options.opaque});
      this.state.modeGen++;
      regChange(this);
    }),
    removeOverlay: operation(null, function(spec) {
      var overlays = this.state.overlays;
      for (var i = 0; i < overlays.length; ++i) {
        var cur = overlays[i].modeSpec;
        if (cur == spec || typeof spec == "string" && cur.name == spec) {
          overlays.splice(i, 1);
          this.state.modeGen++;
          regChange(this);
          return;
        }
      }
    }),

    indentLine: operation(null, function(n, dir, aggressive) {
      if (typeof dir != "string" && typeof dir != "number") {
        if (dir == null) dir = this.options.smartIndent ? "smart" : "prev";
        else dir = dir ? "add" : "subtract";
      }
      if (isLine(this.doc, n)) indentLine(this, n, dir, aggressive);
    }),
    indentSelection: operation(null, function(how) {
      var sel = this.doc.sel;
      if (posEq(sel.from, sel.to)) return indentLine(this, sel.from.line, how);
      var e = sel.to.line - (sel.to.ch ? 0 : 1);
      for (var i = sel.from.line; i <= e; ++i) indentLine(this, i, how);
    }),

    // Fetch the parser token for a given character. Useful for hacks
    // that want to inspect the mode state (say, for completion).
    getTokenAt: function(pos, precise) {
      var doc = this.doc;
      pos = clipPos(doc, pos);
      var state = getStateBefore(this, pos.line, precise), mode = this.doc.mode;
      var line = getLine(doc, pos.line);
      var stream = new StringStream(line.text, this.options.tabSize);
      while (stream.pos < pos.ch && !stream.eol()) {
        stream.start = stream.pos;
        var style = mode.token(stream, state);
      }
      return {start: stream.start,
              end: stream.pos,
              string: stream.current(),
              className: style || null, // Deprecated, use 'type' instead
              type: style || null,
              state: state};
    },

    getTokenTypeAt: function(pos) {
      pos = clipPos(this.doc, pos);
      var styles = getLineStyles(this, getLine(this.doc, pos.line));
      var before = 0, after = (styles.length - 1) / 2, ch = pos.ch;
      if (ch == 0) return styles[2];
      for (;;) {
        var mid = (before + after) >> 1;
        if ((mid ? styles[mid * 2 - 1] : 0) >= ch) after = mid;
        else if (styles[mid * 2 + 1] < ch) before = mid + 1;
        else return styles[mid * 2 + 2];
      }
    },

    getModeAt: function(pos) {
      var mode = this.doc.mode;
      if (!mode.innerMode) return mode;
      return CodeMirror.innerMode(mode, this.getTokenAt(pos).state).mode;
    },

    getHelper: function(pos, type) {
      if (!helpers.hasOwnProperty(type)) return;
      var help = helpers[type], mode = this.getModeAt(pos);
      return mode[type] && help[mode[type]] ||
        mode.helperType && help[mode.helperType] ||
        help[mode.name];
    },

    getStateAfter: function(line, precise) {
      var doc = this.doc;
      line = clipLine(doc, line == null ? doc.first + doc.size - 1: line);
      return getStateBefore(this, line + 1, precise);
    },

    cursorCoords: function(start, mode) {
      var pos, sel = this.doc.sel;
      if (start == null) pos = sel.head;
      else if (typeof start == "object") pos = clipPos(this.doc, start);
      else pos = start ? sel.from : sel.to;
      return cursorCoords(this, pos, mode || "page");
    },

    charCoords: function(pos, mode) {
      return charCoords(this, clipPos(this.doc, pos), mode || "page");
    },

    coordsChar: function(coords, mode) {
      coords = fromCoordSystem(this, coords, mode || "page");
      return coordsChar(this, coords.left, coords.top);
    },

    lineAtHeight: function(height, mode) {
      height = fromCoordSystem(this, {top: height, left: 0}, mode || "page").top;
      return lineAtHeight(this.doc, height + this.display.viewOffset);
    },
    heightAtLine: function(line, mode) {
      var end = false, last = this.doc.first + this.doc.size - 1;
      if (line < this.doc.first) line = this.doc.first;
      else if (line > last) { line = last; end = true; }
      var lineObj = getLine(this.doc, line);
      return intoCoordSystem(this, getLine(this.doc, line), {top: 0, left: 0}, mode || "page").top +
        (end ? lineObj.height : 0);
    },

    defaultTextHeight: function() { return textHeight(this.display); },
    defaultCharWidth: function() { return charWidth(this.display); },

    setGutterMarker: operation(null, function(line, gutterID, value) {
      return changeLine(this, line, function(line) {
        var markers = line.gutterMarkers || (line.gutterMarkers = {});
        markers[gutterID] = value;
        if (!value && isEmpty(markers)) line.gutterMarkers = null;
        return true;
      });
    }),

    clearGutter: operation(null, function(gutterID) {
      var cm = this, doc = cm.doc, i = doc.first;
      doc.iter(function(line) {
        if (line.gutterMarkers && line.gutterMarkers[gutterID]) {
          line.gutterMarkers[gutterID] = null;
          regChange(cm, i, i + 1);
          if (isEmpty(line.gutterMarkers)) line.gutterMarkers = null;
        }
        ++i;
      });
    }),

    addLineClass: operation(null, function(handle, where, cls) {
      return changeLine(this, handle, function(line) {
        var prop = where == "text" ? "textClass" : where == "background" ? "bgClass" : "wrapClass";
        if (!line[prop]) line[prop] = cls;
        else if (new RegExp("(?:^|\\s)" + cls + "(?:$|\\s)").test(line[prop])) return false;
        else line[prop] += " " + cls;
        return true;
      });
    }),

    removeLineClass: operation(null, function(handle, where, cls) {
      return changeLine(this, handle, function(line) {
        var prop = where == "text" ? "textClass" : where == "background" ? "bgClass" : "wrapClass";
        var cur = line[prop];
        if (!cur) return false;
        else if (cls == null) line[prop] = null;
        else {
          var found = cur.match(new RegExp("(?:^|\\s+)" + cls + "(?:$|\\s+)"));
          if (!found) return false;
          var end = found.index + found[0].length;
          line[prop] = cur.slice(0, found.index) + (!found.index || end == cur.length ? "" : " ") + cur.slice(end) || null;
        }
        return true;
      });
    }),

    addLineWidget: operation(null, function(handle, node, options) {
      return addLineWidget(this, handle, node, options);
    }),

    removeLineWidget: function(widget) { widget.clear(); },

    lineInfo: function(line) {
      if (typeof line == "number") {
        if (!isLine(this.doc, line)) return null;
        var n = line;
        line = getLine(this.doc, line);
        if (!line) return null;
      } else {
        var n = lineNo(line);
        if (n == null) return null;
      }
      return {line: n, handle: line, text: line.text, gutterMarkers: line.gutterMarkers,
              textClass: line.textClass, bgClass: line.bgClass, wrapClass: line.wrapClass,
              widgets: line.widgets};
    },

    getViewport: function() { return {from: this.display.showingFrom, to: this.display.showingTo};},

    addWidget: function(pos, node, scroll, vert, horiz) {
      var display = this.display;
      pos = cursorCoords(this, clipPos(this.doc, pos));
      var top = pos.bottom, left = pos.left;
      node.style.position = "absolute";
      display.sizer.appendChild(node);
      if (vert == "over") {
        top = pos.top;
      } else if (vert == "above" || vert == "near") {
        var vspace = Math.max(display.wrapper.clientHeight, this.doc.height),
        hspace = Math.max(display.sizer.clientWidth, display.lineSpace.clientWidth);
        // Default to positioning above (if specified and possible); otherwise default to positioning below
        if ((vert == 'above' || pos.bottom + node.offsetHeight > vspace) && pos.top > node.offsetHeight)
          top = pos.top - node.offsetHeight;
        else if (pos.bottom + node.offsetHeight <= vspace)
          top = pos.bottom;
        if (left + node.offsetWidth > hspace)
          left = hspace - node.offsetWidth;
      }
      node.style.top = top + "px";
      node.style.left = node.style.right = "";
      if (horiz == "right") {
        left = display.sizer.clientWidth - node.offsetWidth;
        node.style.right = "0px";
      } else {
        if (horiz == "left") left = 0;
        else if (horiz == "middle") left = (display.sizer.clientWidth - node.offsetWidth) / 2;
        node.style.left = left + "px";
      }
      if (scroll)
        scrollIntoView(this, left, top, left + node.offsetWidth, top + node.offsetHeight);
    },

    triggerOnKeyDown: operation(null, onKeyDown),

    execCommand: function(cmd) {return commands[cmd](this);},

    findPosH: function(from, amount, unit, visually) {
      var dir = 1;
      if (amount < 0) { dir = -1; amount = -amount; }
      for (var i = 0, cur = clipPos(this.doc, from); i < amount; ++i) {
        cur = findPosH(this.doc, cur, dir, unit, visually);
        if (cur.hitSide) break;
      }
      return cur;
    },

    moveH: operation(null, function(dir, unit) {
      var sel = this.doc.sel, pos;
      if (sel.shift || sel.extend || posEq(sel.from, sel.to))
        pos = findPosH(this.doc, sel.head, dir, unit, this.options.rtlMoveVisually);
      else
        pos = dir < 0 ? sel.from : sel.to;
      extendSelection(this.doc, pos, pos, dir);
    }),

    deleteH: operation(null, function(dir, unit) {
      var sel = this.doc.sel;
      if (!posEq(sel.from, sel.to)) replaceRange(this.doc, "", sel.from, sel.to, "+delete");
      else replaceRange(this.doc, "", sel.from, findPosH(this.doc, sel.head, dir, unit, false), "+delete");
      this.curOp.userSelChange = true;
    }),

    findPosV: function(from, amount, unit, goalColumn) {
      var dir = 1, x = goalColumn;
      if (amount < 0) { dir = -1; amount = -amount; }
      for (var i = 0, cur = clipPos(this.doc, from); i < amount; ++i) {
        var coords = cursorCoords(this, cur, "div");
        if (x == null) x = coords.left;
        else coords.left = x;
        cur = findPosV(this, coords, dir, unit);
        if (cur.hitSide) break;
      }
      return cur;
    },

    moveV: operation(null, function(dir, unit) {
      var sel = this.doc.sel;
      var pos = cursorCoords(this, sel.head, "div");
      if (sel.goalColumn != null) pos.left = sel.goalColumn;
      var target = findPosV(this, pos, dir, unit);

      if (unit == "page") addToScrollPos(this, 0, charCoords(this, target, "div").top - pos.top);
      extendSelection(this.doc, target, target, dir);
      sel.goalColumn = pos.left;
    }),

    toggleOverwrite: function(value) {
      if (value != null && value == this.state.overwrite) return;
      if (this.state.overwrite = !this.state.overwrite)
        this.display.cursor.className += " CodeMirror-overwrite";
      else
        this.display.cursor.className = this.display.cursor.className.replace(" CodeMirror-overwrite", "");
    },
    hasFocus: function() { return this.state.focused; },

    scrollTo: operation(null, function(x, y) {
      updateScrollPos(this, x, y);
    }),
    getScrollInfo: function() {
      var scroller = this.display.scroller, co = scrollerCutOff;
      return {left: scroller.scrollLeft, top: scroller.scrollTop,
              height: scroller.scrollHeight - co, width: scroller.scrollWidth - co,
              clientHeight: scroller.clientHeight - co, clientWidth: scroller.clientWidth - co};
    },

    scrollIntoView: operation(null, function(pos, margin) {
      if (typeof pos == "number") pos = Pos(pos, 0);
      if (!margin) margin = 0;
      var coords = pos;

      if (!pos || pos.line != null) {
        this.curOp.scrollToPos = pos ? clipPos(this.doc, pos) : this.doc.sel.head;
        this.curOp.scrollToPosMargin = margin;
        coords = cursorCoords(this, this.curOp.scrollToPos);
      }
      var sPos = calculateScrollPos(this, coords.left, coords.top - margin, coords.right, coords.bottom + margin);
      updateScrollPos(this, sPos.scrollLeft, sPos.scrollTop);
    }),

    setSize: operation(null, function(width, height) {
      function interpret(val) {
        return typeof val == "number" || /^\d+$/.test(String(val)) ? val + "px" : val;
      }
      if (width != null) this.display.wrapper.style.width = interpret(width);
      if (height != null) this.display.wrapper.style.height = interpret(height);
      if (this.options.lineWrapping)
        this.display.measureLineCache.length = this.display.measureLineCachePos = 0;
      this.curOp.forceUpdate = true;
    }),

    operation: function(f){return runInOp(this, f);},

    refresh: operation(null, function() {
      clearCaches(this);
      updateScrollPos(this, this.doc.scrollLeft, this.doc.scrollTop);
      regChange(this);
    }),

    swapDoc: operation(null, function(doc) {
      var old = this.doc;
      old.cm = null;
      attachDoc(this, doc);
      clearCaches(this);
      resetInput(this, true);
      updateScrollPos(this, doc.scrollLeft, doc.scrollTop);
      return old;
    }),

    getInputField: function(){return this.display.input;},
    getWrapperElement: function(){return this.display.wrapper;},
    getScrollerElement: function(){return this.display.scroller;},
    getGutterElement: function(){return this.display.gutters;}
  };
  eventMixin(CodeMirror);

  // OPTION DEFAULTS

  var optionHandlers = CodeMirror.optionHandlers = {};

  // The default configuration options.
  var defaults = CodeMirror.defaults = {};

  function option(name, deflt, handle, notOnInit) {
    CodeMirror.defaults[name] = deflt;
    if (handle) optionHandlers[name] =
      notOnInit ? function(cm, val, old) {if (old != Init) handle(cm, val, old);} : handle;
  }

  var Init = CodeMirror.Init = {toString: function(){return "CodeMirror.Init";}};

  // These two are, on init, called from the constructor because they
  // have to be initialized before the editor can start at all.
  option("value", "", function(cm, val) {
    cm.setValue(val);
  }, true);
  option("mode", null, function(cm, val) {
    cm.doc.modeOption = val;
    loadMode(cm);
  }, true);

  option("indentUnit", 2, loadMode, true);
  option("indentWithTabs", false);
  option("smartIndent", true);
  option("tabSize", 4, function(cm) {
    loadMode(cm);
    clearCaches(cm);
    regChange(cm);
  }, true);
  option("electricChars", true);
  option("rtlMoveVisually", !windows);

  option("theme", "default", function(cm) {
    themeChanged(cm);
    guttersChanged(cm);
  }, true);
  option("keyMap", "default", keyMapChanged);
  option("extraKeys", null);

  option("onKeyEvent", null);
  option("onDragEvent", null);

  option("lineWrapping", false, wrappingChanged, true);
  option("gutters", [], function(cm) {
    setGuttersForLineNumbers(cm.options);
    guttersChanged(cm);
  }, true);
  option("fixedGutter", true, function(cm, val) {
    cm.display.gutters.style.left = val ? compensateForHScroll(cm.display) + "px" : "0";
    cm.refresh();
  }, true);
  option("coverGutterNextToScrollbar", false, updateScrollbars, true);
  option("lineNumbers", false, function(cm) {
    setGuttersForLineNumbers(cm.options);
    guttersChanged(cm);
  }, true);
  option("firstLineNumber", 1, guttersChanged, true);
  option("lineNumberFormatter", function(integer) {return integer;}, guttersChanged, true);
  option("showCursorWhenSelecting", false, updateSelection, true);

  option("readOnly", false, function(cm, val) {
    if (val == "nocursor") {onBlur(cm); cm.display.input.blur();}
    else if (!val) resetInput(cm, true);
  });
  option("dragDrop", true);

  option("cursorBlinkRate", 530);
  option("cursorScrollMargin", 0);
  option("cursorHeight", 1);
  option("workTime", 100);
  option("workDelay", 100);
  option("flattenSpans", true);
  option("pollInterval", 100);
  option("undoDepth", 40, function(cm, val){cm.doc.history.undoDepth = val;});
  option("historyEventDelay", 500);
  option("viewportMargin", 10, function(cm){cm.refresh();}, true);
  option("maxHighlightLength", 10000, function(cm){loadMode(cm); cm.refresh();}, true);
  option("moveInputWithCursor", true, function(cm, val) {
    if (!val) cm.display.inputDiv.style.top = cm.display.inputDiv.style.left = 0;
  });

  option("tabindex", null, function(cm, val) {
    cm.display.input.tabIndex = val || "";
  });
  option("autofocus", null);

  // MODE DEFINITION AND QUERYING

  // Known modes, by name and by MIME
  var modes = CodeMirror.modes = {}, mimeModes = CodeMirror.mimeModes = {};

  CodeMirror.defineMode = function(name, mode) {
    if (!CodeMirror.defaults.mode && name != "null") CodeMirror.defaults.mode = name;
    if (arguments.length > 2) {
      mode.dependencies = [];
      for (var i = 2; i < arguments.length; ++i) mode.dependencies.push(arguments[i]);
    }
    modes[name] = mode;
  };

  CodeMirror.defineMIME = function(mime, spec) {
    mimeModes[mime] = spec;
  };

  CodeMirror.resolveMode = function(spec) {
    if (typeof spec == "string" && mimeModes.hasOwnProperty(spec)) {
      spec = mimeModes[spec];
    } else if (spec && typeof spec.name == "string" && mimeModes.hasOwnProperty(spec.name)) {
      var found = mimeModes[spec.name];
      spec = createObj(found, spec);
      spec.name = found.name;
    } else if (typeof spec == "string" && /^[\w\-]+\/[\w\-]+\+xml$/.test(spec)) {
      return CodeMirror.resolveMode("application/xml");
    }
    if (typeof spec == "string") return {name: spec};
    else return spec || {name: "null"};
  };

  CodeMirror.getMode = function(options, spec) {
    var spec = CodeMirror.resolveMode(spec);
    var mfactory = modes[spec.name];
    if (!mfactory) return CodeMirror.getMode(options, "text/plain");
    var modeObj = mfactory(options, spec);
    if (modeExtensions.hasOwnProperty(spec.name)) {
      var exts = modeExtensions[spec.name];
      for (var prop in exts) {
        if (!exts.hasOwnProperty(prop)) continue;
        if (modeObj.hasOwnProperty(prop)) modeObj["_" + prop] = modeObj[prop];
        modeObj[prop] = exts[prop];
      }
    }
    modeObj.name = spec.name;

    return modeObj;
  };

  CodeMirror.defineMode("null", function() {
    return {token: function(stream) {stream.skipToEnd();}};
  });
  CodeMirror.defineMIME("text/plain", "null");

  var modeExtensions = CodeMirror.modeExtensions = {};
  CodeMirror.extendMode = function(mode, properties) {
    var exts = modeExtensions.hasOwnProperty(mode) ? modeExtensions[mode] : (modeExtensions[mode] = {});
    copyObj(properties, exts);
  };

  // EXTENSIONS

  CodeMirror.defineExtension = function(name, func) {
    CodeMirror.prototype[name] = func;
  };
  CodeMirror.defineDocExtension = function(name, func) {
    Doc.prototype[name] = func;
  };
  CodeMirror.defineOption = option;

  var initHooks = [];
  CodeMirror.defineInitHook = function(f) {initHooks.push(f);};

  var helpers = CodeMirror.helpers = {};
  CodeMirror.registerHelper = function(type, name, value) {
    if (!helpers.hasOwnProperty(type)) helpers[type] = CodeMirror[type] = {};
    helpers[type][name] = value;
  };

  // UTILITIES

  CodeMirror.isWordChar = isWordChar;

  // MODE STATE HANDLING

  // Utility functions for working with state. Exported because modes
  // sometimes need to do this.
  function copyState(mode, state) {
    if (state === true) return state;
    if (mode.copyState) return mode.copyState(state);
    var nstate = {};
    for (var n in state) {
      var val = state[n];
      if (val instanceof Array) val = val.concat([]);
      nstate[n] = val;
    }
    return nstate;
  }
  CodeMirror.copyState = copyState;

  function startState(mode, a1, a2) {
    return mode.startState ? mode.startState(a1, a2) : true;
  }
  CodeMirror.startState = startState;

  CodeMirror.innerMode = function(mode, state) {
    while (mode.innerMode) {
      var info = mode.innerMode(state);
      if (!info || info.mode == mode) break;
      state = info.state;
      mode = info.mode;
    }
    return info || {mode: mode, state: state};
  };

  // STANDARD COMMANDS

  var commands = CodeMirror.commands = {
    selectAll: function(cm) {cm.setSelection(Pos(cm.firstLine(), 0), Pos(cm.lastLine()));},
    killLine: function(cm) {
      var from = cm.getCursor(true), to = cm.getCursor(false), sel = !posEq(from, to);
      if (!sel && cm.getLine(from.line).length == from.ch)
        cm.replaceRange("", from, Pos(from.line + 1, 0), "+delete");
      else cm.replaceRange("", from, sel ? to : Pos(from.line), "+delete");
    },
    deleteLine: function(cm) {
      var l = cm.getCursor().line;
      cm.replaceRange("", Pos(l, 0), Pos(l), "+delete");
    },
    delLineLeft: function(cm) {
      var cur = cm.getCursor();
      cm.replaceRange("", Pos(cur.line, 0), cur, "+delete");
    },
    undo: function(cm) {cm.undo();},
    redo: function(cm) {cm.redo();},
    goDocStart: function(cm) {cm.extendSelection(Pos(cm.firstLine(), 0));},
    goDocEnd: function(cm) {cm.extendSelection(Pos(cm.lastLine()));},
    goLineStart: function(cm) {
      cm.extendSelection(lineStart(cm, cm.getCursor().line));
    },
    goLineStartSmart: function(cm) {
      var cur = cm.getCursor(), start = lineStart(cm, cur.line);
      var line = cm.getLineHandle(start.line);
      var order = getOrder(line);
      if (!order || order[0].level == 0) {
        var firstNonWS = Math.max(0, line.text.search(/\S/));
        var inWS = cur.line == start.line && cur.ch <= firstNonWS && cur.ch;
        cm.extendSelection(Pos(start.line, inWS ? 0 : firstNonWS));
      } else cm.extendSelection(start);
    },
    goLineEnd: function(cm) {
      cm.extendSelection(lineEnd(cm, cm.getCursor().line));
    },
    goLineRight: function(cm) {
      var top = cm.charCoords(cm.getCursor(), "div").top + 5;
      cm.extendSelection(cm.coordsChar({left: cm.display.lineDiv.offsetWidth + 100, top: top}, "div"));
    },
    goLineLeft: function(cm) {
      var top = cm.charCoords(cm.getCursor(), "div").top + 5;
      cm.extendSelection(cm.coordsChar({left: 0, top: top}, "div"));
    },
    goLineUp: function(cm) {cm.moveV(-1, "line");},
    goLineDown: function(cm) {cm.moveV(1, "line");},
    goPageUp: function(cm) {cm.moveV(-1, "page");},
    goPageDown: function(cm) {cm.moveV(1, "page");},
    goCharLeft: function(cm) {cm.moveH(-1, "char");},
    goCharRight: function(cm) {cm.moveH(1, "char");},
    goColumnLeft: function(cm) {cm.moveH(-1, "column");},
    goColumnRight: function(cm) {cm.moveH(1, "column");},
    goWordLeft: function(cm) {cm.moveH(-1, "word");},
    goGroupRight: function(cm) {cm.moveH(1, "group");},
    goGroupLeft: function(cm) {cm.moveH(-1, "group");},
    goWordRight: function(cm) {cm.moveH(1, "word");},
    delCharBefore: function(cm) {cm.deleteH(-1, "char");},
    delCharAfter: function(cm) {cm.deleteH(1, "char");},
    delWordBefore: function(cm) {cm.deleteH(-1, "word");},
    delWordAfter: function(cm) {cm.deleteH(1, "word");},
    delGroupBefore: function(cm) {cm.deleteH(-1, "group");},
    delGroupAfter: function(cm) {cm.deleteH(1, "group");},
    indentAuto: function(cm) {cm.indentSelection("smart");},
    indentMore: function(cm) {cm.indentSelection("add");},
    indentLess: function(cm) {cm.indentSelection("subtract");},
    insertTab: function(cm) {cm.replaceSelection("\t", "end", "+input");},
    defaultTab: function(cm) {
      if (cm.somethingSelected()) cm.indentSelection("add");
      else cm.replaceSelection("\t", "end", "+input");
    },
    transposeChars: function(cm) {
      var cur = cm.getCursor(), line = cm.getLine(cur.line);
      if (cur.ch > 0 && cur.ch < line.length - 1)
        cm.replaceRange(line.charAt(cur.ch) + line.charAt(cur.ch - 1),
                        Pos(cur.line, cur.ch - 1), Pos(cur.line, cur.ch + 1));
    },
    newlineAndIndent: function(cm) {
      operation(cm, function() {
        cm.replaceSelection("\n", "end", "+input");
        cm.indentLine(cm.getCursor().line, null, true);
      })();
    },
    toggleOverwrite: function(cm) {cm.toggleOverwrite();}
  };

  // STANDARD KEYMAPS

  var keyMap = CodeMirror.keyMap = {};
  keyMap.basic = {
    "Left": "goCharLeft", "Right": "goCharRight", "Up": "goLineUp", "Down": "goLineDown",
    "End": "goLineEnd", "Home": "goLineStartSmart", "PageUp": "goPageUp", "PageDown": "goPageDown",
    "Delete": "delCharAfter", "Backspace": "delCharBefore", "Tab": "defaultTab", "Shift-Tab": "indentAuto",
    "Enter": "newlineAndIndent", "Insert": "toggleOverwrite"
  };
  // Note that the save and find-related commands aren't defined by
  // default. Unknown commands are simply ignored.
  keyMap.pcDefault = {
    "Ctrl-A": "selectAll", "Ctrl-D": "deleteLine", "Ctrl-Z": "undo", "Shift-Ctrl-Z": "redo", "Ctrl-Y": "redo",
    "Ctrl-Home": "goDocStart", "Alt-Up": "goDocStart", "Ctrl-End": "goDocEnd", "Ctrl-Down": "goDocEnd",
    "Ctrl-Left": "goGroupLeft", "Ctrl-Right": "goGroupRight", "Alt-Left": "goLineStart", "Alt-Right": "goLineEnd",
    "Ctrl-Backspace": "delGroupBefore", "Ctrl-Delete": "delGroupAfter", "Ctrl-S": "save", "Ctrl-F": "find",
    "Ctrl-G": "findNext", "Shift-Ctrl-G": "findPrev", "Shift-Ctrl-F": "replace", "Shift-Ctrl-R": "replaceAll",
    "Ctrl-[": "indentLess", "Ctrl-]": "indentMore",
    fallthrough: "basic"
  };
  keyMap.macDefault = {
    "Cmd-A": "selectAll", "Cmd-D": "deleteLine", "Cmd-Z": "undo", "Shift-Cmd-Z": "redo", "Cmd-Y": "redo",
    "Cmd-Up": "goDocStart", "Cmd-End": "goDocEnd", "Cmd-Down": "goDocEnd", "Alt-Left": "goGroupLeft",
    "Alt-Right": "goGroupRight", "Cmd-Left": "goLineStart", "Cmd-Right": "goLineEnd", "Alt-Backspace": "delGroupBefore",
    "Ctrl-Alt-Backspace": "delGroupAfter", "Alt-Delete": "delGroupAfter", "Cmd-S": "save", "Cmd-F": "find",
    "Cmd-G": "findNext", "Shift-Cmd-G": "findPrev", "Cmd-Alt-F": "replace", "Shift-Cmd-Alt-F": "replaceAll",
    "Cmd-[": "indentLess", "Cmd-]": "indentMore", "Cmd-Backspace": "delLineLeft",
    fallthrough: ["basic", "emacsy"]
  };
  keyMap["default"] = mac ? keyMap.macDefault : keyMap.pcDefault;
  keyMap.emacsy = {
    "Ctrl-F": "goCharRight", "Ctrl-B": "goCharLeft", "Ctrl-P": "goLineUp", "Ctrl-N": "goLineDown",
    "Alt-F": "goWordRight", "Alt-B": "goWordLeft", "Ctrl-A": "goLineStart", "Ctrl-E": "goLineEnd",
    "Ctrl-V": "goPageDown", "Shift-Ctrl-V": "goPageUp", "Ctrl-D": "delCharAfter", "Ctrl-H": "delCharBefore",
    "Alt-D": "delWordAfter", "Alt-Backspace": "delWordBefore", "Ctrl-K": "killLine", "Ctrl-T": "transposeChars"
  };

  // KEYMAP DISPATCH

  function getKeyMap(val) {
    if (typeof val == "string") return keyMap[val];
    else return val;
  }

  function lookupKey(name, maps, handle) {
    function lookup(map) {
      map = getKeyMap(map);
      var found = map[name];
      if (found === false) return "stop";
      if (found != null && handle(found)) return true;
      if (map.nofallthrough) return "stop";

      var fallthrough = map.fallthrough;
      if (fallthrough == null) return false;
      if (Object.prototype.toString.call(fallthrough) != "[object Array]")
        return lookup(fallthrough);
      for (var i = 0, e = fallthrough.length; i < e; ++i) {
        var done = lookup(fallthrough[i]);
        if (done) return done;
      }
      return false;
    }

    for (var i = 0; i < maps.length; ++i) {
      var done = lookup(maps[i]);
      if (done) return done != "stop";
    }
  }
  function isModifierKey(event) {
    var name = keyNames[event.keyCode];
    return name == "Ctrl" || name == "Alt" || name == "Shift" || name == "Mod";
  }
  function keyName(event, noShift) {
    if (opera && event.keyCode == 34 && event["char"]) return false;
    var name = keyNames[event.keyCode];
    if (name == null || event.altGraphKey) return false;
    if (event.altKey) name = "Alt-" + name;
    if (flipCtrlCmd ? event.metaKey : event.ctrlKey) name = "Ctrl-" + name;
    if (flipCtrlCmd ? event.ctrlKey : event.metaKey) name = "Cmd-" + name;
    if (!noShift && event.shiftKey) name = "Shift-" + name;
    return name;
  }
  CodeMirror.lookupKey = lookupKey;
  CodeMirror.isModifierKey = isModifierKey;
  CodeMirror.keyName = keyName;

  // FROMTEXTAREA

  CodeMirror.fromTextArea = function(textarea, options) {
    if (!options) options = {};
    options.value = textarea.value;
    if (!options.tabindex && textarea.tabindex)
      options.tabindex = textarea.tabindex;
    if (!options.placeholder && textarea.placeholder)
      options.placeholder = textarea.placeholder;
    // Set autofocus to true if this textarea is focused, or if it has
    // autofocus and no other element is focused.
    if (options.autofocus == null) {
      var hasFocus = document.body;
      // doc.activeElement occasionally throws on IE
      try { hasFocus = document.activeElement; } catch(e) {}
      options.autofocus = hasFocus == textarea ||
        textarea.getAttribute("autofocus") != null && hasFocus == document.body;
    }

    function save() {textarea.value = cm.getValue();}
    if (textarea.form) {
      on(textarea.form, "submit", save);
      // Deplorable hack to make the submit method do the right thing.
      if (!options.leaveSubmitMethodAlone) {
        var form = textarea.form, realSubmit = form.submit;
        try {
          var wrappedSubmit = form.submit = function() {
            save();
            form.submit = realSubmit;
            form.submit();
            form.submit = wrappedSubmit;
          };
        } catch(e) {}
      }
    }

    textarea.style.display = "none";
    var cm = CodeMirror(function(node) {
      textarea.parentNode.insertBefore(node, textarea.nextSibling);
    }, options);
    cm.save = save;
    cm.getTextArea = function() { return textarea; };
    cm.toTextArea = function() {
      save();
      textarea.parentNode.removeChild(cm.getWrapperElement());
      textarea.style.display = "";
      if (textarea.form) {
        off(textarea.form, "submit", save);
        if (typeof textarea.form.submit == "function")
          textarea.form.submit = realSubmit;
      }
    };
    return cm;
  };

  // STRING STREAM

  // Fed to the mode parsers, provides helper functions to make
  // parsers more succinct.

  // The character stream used by a mode's parser.
  function StringStream(string, tabSize) {
    this.pos = this.start = 0;
    this.string = string;
    this.tabSize = tabSize || 8;
    this.lastColumnPos = this.lastColumnValue = 0;
  }

  StringStream.prototype = {
    eol: function() {return this.pos >= this.string.length;},
    sol: function() {return this.pos == 0;},
    peek: function() {return this.string.charAt(this.pos) || undefined;},
    next: function() {
      if (this.pos < this.string.length)
        return this.string.charAt(this.pos++);
    },
    eat: function(match) {
      var ch = this.string.charAt(this.pos);
      if (typeof match == "string") var ok = ch == match;
      else var ok = ch && (match.test ? match.test(ch) : match(ch));
      if (ok) {++this.pos; return ch;}
    },
    eatWhile: function(match) {
      var start = this.pos;
      while (this.eat(match)){}
      return this.pos > start;
    },
    eatSpace: function() {
      var start = this.pos;
      while (/[\s\u00a0]/.test(this.string.charAt(this.pos))) ++this.pos;
      return this.pos > start;
    },
    skipToEnd: function() {this.pos = this.string.length;},
    skipTo: function(ch) {
      var found = this.string.indexOf(ch, this.pos);
      if (found > -1) {this.pos = found; return true;}
    },
    backUp: function(n) {this.pos -= n;},
    column: function() {
      if (this.lastColumnPos < this.start) {
        this.lastColumnValue = countColumn(this.string, this.start, this.tabSize, this.lastColumnPos, this.lastColumnValue);
        this.lastColumnPos = this.start;
      }
      return this.lastColumnValue;
    },
    indentation: function() {return countColumn(this.string, null, this.tabSize);},
    match: function(pattern, consume, caseInsensitive) {
      if (typeof pattern == "string") {
        var cased = function(str) {return caseInsensitive ? str.toLowerCase() : str;};
        var substr = this.string.substr(this.pos, pattern.length);
        if (cased(substr) == cased(pattern)) {
          if (consume !== false) this.pos += pattern.length;
          return true;
        }
      } else {
        var match = this.string.slice(this.pos).match(pattern);
        if (match && match.index > 0) return null;
        if (match && consume !== false) this.pos += match[0].length;
        return match;
      }
    },
    current: function(){return this.string.slice(this.start, this.pos);}
  };
  CodeMirror.StringStream = StringStream;

  // TEXTMARKERS

  function TextMarker(doc, type) {
    this.lines = [];
    this.type = type;
    this.doc = doc;
  }
  CodeMirror.TextMarker = TextMarker;
  eventMixin(TextMarker);

  TextMarker.prototype.clear = function() {
    if (this.explicitlyCleared) return;
    var cm = this.doc.cm, withOp = cm && !cm.curOp;
    if (withOp) startOperation(cm);
    if (hasHandler(this, "clear")) {
      var found = this.find();
      if (found) signalLater(this, "clear", found.from, found.to);
    }
    var min = null, max = null;
    for (var i = 0; i < this.lines.length; ++i) {
      var line = this.lines[i];
      var span = getMarkedSpanFor(line.markedSpans, this);
      if (span.to != null) max = lineNo(line);
      line.markedSpans = removeMarkedSpan(line.markedSpans, span);
      if (span.from != null)
        min = lineNo(line);
      else if (this.collapsed && !lineIsHidden(this.doc, line) && cm)
        updateLineHeight(line, textHeight(cm.display));
    }
    if (cm && this.collapsed && !cm.options.lineWrapping) for (var i = 0; i < this.lines.length; ++i) {
      var visual = visualLine(cm.doc, this.lines[i]), len = lineLength(cm.doc, visual);
      if (len > cm.display.maxLineLength) {
        cm.display.maxLine = visual;
        cm.display.maxLineLength = len;
        cm.display.maxLineChanged = true;
      }
    }

    if (min != null && cm) regChange(cm, min, max + 1);
    this.lines.length = 0;
    this.explicitlyCleared = true;
    if (this.atomic && this.doc.cantEdit) {
      this.doc.cantEdit = false;
      if (cm) reCheckSelection(cm);
    }
    if (withOp) endOperation(cm);
  };

  TextMarker.prototype.find = function() {
    var from, to;
    for (var i = 0; i < this.lines.length; ++i) {
      var line = this.lines[i];
      var span = getMarkedSpanFor(line.markedSpans, this);
      if (span.from != null || span.to != null) {
        var found = lineNo(line);
        if (span.from != null) from = Pos(found, span.from);
        if (span.to != null) to = Pos(found, span.to);
      }
    }
    if (this.type == "bookmark") return from;
    return from && {from: from, to: to};
  };

  TextMarker.prototype.changed = function() {
    var pos = this.find(), cm = this.doc.cm;
    if (!pos || !cm) return;
    var line = getLine(this.doc, pos.from.line);
    clearCachedMeasurement(cm, line);
    if (pos.from.line >= cm.display.showingFrom && pos.from.line < cm.display.showingTo) {
      for (var node = cm.display.lineDiv.firstChild; node; node = node.nextSibling) if (node.lineObj == line) {
        if (node.offsetHeight != line.height) updateLineHeight(line, node.offsetHeight);
        break;
      }
      runInOp(cm, function() {
        cm.curOp.selectionChanged = cm.curOp.forceUpdate = cm.curOp.updateMaxLine = true;
      });
    }
  };

  TextMarker.prototype.attachLine = function(line) {
    if (!this.lines.length && this.doc.cm) {
      var op = this.doc.cm.curOp;
      if (!op.maybeHiddenMarkers || indexOf(op.maybeHiddenMarkers, this) == -1)
        (op.maybeUnhiddenMarkers || (op.maybeUnhiddenMarkers = [])).push(this);
    }
    this.lines.push(line);
  };
  TextMarker.prototype.detachLine = function(line) {
    this.lines.splice(indexOf(this.lines, line), 1);
    if (!this.lines.length && this.doc.cm) {
      var op = this.doc.cm.curOp;
      (op.maybeHiddenMarkers || (op.maybeHiddenMarkers = [])).push(this);
    }
  };

  function markText(doc, from, to, options, type) {
    if (options && options.shared) return markTextShared(doc, from, to, options, type);
    if (doc.cm && !doc.cm.curOp) return operation(doc.cm, markText)(doc, from, to, options, type);

    var marker = new TextMarker(doc, type);
    if (type == "range" && !posLess(from, to)) return marker;
    if (options) copyObj(options, marker);
    if (marker.replacedWith) {
      marker.collapsed = true;
      marker.replacedWith = elt("span", [marker.replacedWith], "CodeMirror-widget");
      if (!options.handleMouseEvents) marker.replacedWith.ignoreEvents = true;
    }
    if (marker.collapsed) sawCollapsedSpans = true;

    if (marker.addToHistory)
      addToHistory(doc, {from: from, to: to, origin: "markText"},
                   {head: doc.sel.head, anchor: doc.sel.anchor}, NaN);

    var curLine = from.line, size = 0, collapsedAtStart, collapsedAtEnd, cm = doc.cm, updateMaxLine;
    doc.iter(curLine, to.line + 1, function(line) {
      if (cm && marker.collapsed && !cm.options.lineWrapping && visualLine(doc, line) == cm.display.maxLine)
        updateMaxLine = true;
      var span = {from: null, to: null, marker: marker};
      size += line.text.length;
      if (curLine == from.line) {span.from = from.ch; size -= from.ch;}
      if (curLine == to.line) {span.to = to.ch; size -= line.text.length - to.ch;}
      if (marker.collapsed) {
        if (curLine == to.line) collapsedAtEnd = collapsedSpanAt(line, to.ch);
        if (curLine == from.line) collapsedAtStart = collapsedSpanAt(line, from.ch);
        else updateLineHeight(line, 0);
      }
      addMarkedSpan(line, span);
      ++curLine;
    });
    if (marker.collapsed) doc.iter(from.line, to.line + 1, function(line) {
      if (lineIsHidden(doc, line)) updateLineHeight(line, 0);
    });

    if (marker.clearOnEnter) on(marker, "beforeCursorEnter", function() { marker.clear(); });

    if (marker.readOnly) {
      sawReadOnlySpans = true;
      if (doc.history.done.length || doc.history.undone.length)
        doc.clearHistory();
    }
    if (marker.collapsed) {
      if (collapsedAtStart != collapsedAtEnd)
        throw new Error("Inserting collapsed marker overlapping an existing one");
      marker.size = size;
      marker.atomic = true;
    }
    if (cm) {
      if (updateMaxLine) cm.curOp.updateMaxLine = true;
      if (marker.className || marker.title || marker.startStyle || marker.endStyle || marker.collapsed)
        regChange(cm, from.line, to.line + 1);
      if (marker.atomic) reCheckSelection(cm);
    }
    return marker;
  }

  // SHARED TEXTMARKERS

  function SharedTextMarker(markers, primary) {
    this.markers = markers;
    this.primary = primary;
    for (var i = 0, me = this; i < markers.length; ++i) {
      markers[i].parent = this;
      on(markers[i], "clear", function(){me.clear();});
    }
  }
  CodeMirror.SharedTextMarker = SharedTextMarker;
  eventMixin(SharedTextMarker);

  SharedTextMarker.prototype.clear = function() {
    if (this.explicitlyCleared) return;
    this.explicitlyCleared = true;
    for (var i = 0; i < this.markers.length; ++i)
      this.markers[i].clear();
    signalLater(this, "clear");
  };
  SharedTextMarker.prototype.find = function() {
    return this.primary.find();
  };

  function markTextShared(doc, from, to, options, type) {
    options = copyObj(options);
    options.shared = false;
    var markers = [markText(doc, from, to, options, type)], primary = markers[0];
    var widget = options.replacedWith;
    linkedDocs(doc, function(doc) {
      if (widget) options.replacedWith = widget.cloneNode(true);
      markers.push(markText(doc, clipPos(doc, from), clipPos(doc, to), options, type));
      for (var i = 0; i < doc.linked.length; ++i)
        if (doc.linked[i].isParent) return;
      primary = lst(markers);
    });
    return new SharedTextMarker(markers, primary);
  }

  // TEXTMARKER SPANS

  function getMarkedSpanFor(spans, marker) {
    if (spans) for (var i = 0; i < spans.length; ++i) {
      var span = spans[i];
      if (span.marker == marker) return span;
    }
  }
  function removeMarkedSpan(spans, span) {
    for (var r, i = 0; i < spans.length; ++i)
      if (spans[i] != span) (r || (r = [])).push(spans[i]);
    return r;
  }
  function addMarkedSpan(line, span) {
    line.markedSpans = line.markedSpans ? line.markedSpans.concat([span]) : [span];
    span.marker.attachLine(line);
  }

  function markedSpansBefore(old, startCh, isInsert) {
    if (old) for (var i = 0, nw; i < old.length; ++i) {
      var span = old[i], marker = span.marker;
      var startsBefore = span.from == null || (marker.inclusiveLeft ? span.from <= startCh : span.from < startCh);
      if (startsBefore || marker.type == "bookmark" && span.from == startCh && (!isInsert || !span.marker.insertLeft)) {
        var endsAfter = span.to == null || (marker.inclusiveRight ? span.to >= startCh : span.to > startCh);
        (nw || (nw = [])).push({from: span.from,
                                to: endsAfter ? null : span.to,
                                marker: marker});
      }
    }
    return nw;
  }

  function markedSpansAfter(old, endCh, isInsert) {
    if (old) for (var i = 0, nw; i < old.length; ++i) {
      var span = old[i], marker = span.marker;
      var endsAfter = span.to == null || (marker.inclusiveRight ? span.to >= endCh : span.to > endCh);
      if (endsAfter || marker.type == "bookmark" && span.from == endCh && (!isInsert || span.marker.insertLeft)) {
        var startsBefore = span.from == null || (marker.inclusiveLeft ? span.from <= endCh : span.from < endCh);
        (nw || (nw = [])).push({from: startsBefore ? null : span.from - endCh,
                                to: span.to == null ? null : span.to - endCh,
                                marker: marker});
      }
    }
    return nw;
  }

  function stretchSpansOverChange(doc, change) {
    var oldFirst = isLine(doc, change.from.line) && getLine(doc, change.from.line).markedSpans;
    var oldLast = isLine(doc, change.to.line) && getLine(doc, change.to.line).markedSpans;
    if (!oldFirst && !oldLast) return null;

    var startCh = change.from.ch, endCh = change.to.ch, isInsert = posEq(change.from, change.to);
    // Get the spans that 'stick out' on both sides
    var first = markedSpansBefore(oldFirst, startCh, isInsert);
    var last = markedSpansAfter(oldLast, endCh, isInsert);

    // Next, merge those two ends
    var sameLine = change.text.length == 1, offset = lst(change.text).length + (sameLine ? startCh : 0);
    if (first) {
      // Fix up .to properties of first
      for (var i = 0; i < first.length; ++i) {
        var span = first[i];
        if (span.to == null) {
          var found = getMarkedSpanFor(last, span.marker);
          if (!found) span.to = startCh;
          else if (sameLine) span.to = found.to == null ? null : found.to + offset;
        }
      }
    }
    if (last) {
      // Fix up .from in last (or move them into first in case of sameLine)
      for (var i = 0; i < last.length; ++i) {
        var span = last[i];
        if (span.to != null) span.to += offset;
        if (span.from == null) {
          var found = getMarkedSpanFor(first, span.marker);
          if (!found) {
            span.from = offset;
            if (sameLine) (first || (first = [])).push(span);
          }
        } else {
          span.from += offset;
          if (sameLine) (first || (first = [])).push(span);
        }
      }
    }
    if (sameLine && first) {
      // Make sure we didn't create any zero-length spans
      for (var i = 0; i < first.length; ++i)
        if (first[i].from != null && first[i].from == first[i].to && first[i].marker.type != "bookmark")
          first.splice(i--, 1);
      if (!first.length) first = null;
    }

    var newMarkers = [first];
    if (!sameLine) {
      // Fill gap with whole-line-spans
      var gap = change.text.length - 2, gapMarkers;
      if (gap > 0 && first)
        for (var i = 0; i < first.length; ++i)
          if (first[i].to == null)
            (gapMarkers || (gapMarkers = [])).push({from: null, to: null, marker: first[i].marker});
      for (var i = 0; i < gap; ++i)
        newMarkers.push(gapMarkers);
      newMarkers.push(last);
    }
    return newMarkers;
  }

  function mergeOldSpans(doc, change) {
    var old = getOldSpans(doc, change);
    var stretched = stretchSpansOverChange(doc, change);
    if (!old) return stretched;
    if (!stretched) return old;

    for (var i = 0; i < old.length; ++i) {
      var oldCur = old[i], stretchCur = stretched[i];
      if (oldCur && stretchCur) {
        spans: for (var j = 0; j < stretchCur.length; ++j) {
          var span = stretchCur[j];
          for (var k = 0; k < oldCur.length; ++k)
            if (oldCur[k].marker == span.marker) continue spans;
          oldCur.push(span);
        }
      } else if (stretchCur) {
        old[i] = stretchCur;
      }
    }
    return old;
  }

  function removeReadOnlyRanges(doc, from, to) {
    var markers = null;
    doc.iter(from.line, to.line + 1, function(line) {
      if (line.markedSpans) for (var i = 0; i < line.markedSpans.length; ++i) {
        var mark = line.markedSpans[i].marker;
        if (mark.readOnly && (!markers || indexOf(markers, mark) == -1))
          (markers || (markers = [])).push(mark);
      }
    });
    if (!markers) return null;
    var parts = [{from: from, to: to}];
    for (var i = 0; i < markers.length; ++i) {
      var mk = markers[i], m = mk.find();
      for (var j = 0; j < parts.length; ++j) {
        var p = parts[j];
        if (posLess(p.to, m.from) || posLess(m.to, p.from)) continue;
        var newParts = [j, 1];
        if (posLess(p.from, m.from) || !mk.inclusiveLeft && posEq(p.from, m.from))
          newParts.push({from: p.from, to: m.from});
        if (posLess(m.to, p.to) || !mk.inclusiveRight && posEq(p.to, m.to))
          newParts.push({from: m.to, to: p.to});
        parts.splice.apply(parts, newParts);
        j += newParts.length - 1;
      }
    }
    return parts;
  }

  function collapsedSpanAt(line, ch) {
    var sps = sawCollapsedSpans && line.markedSpans, found;
    if (sps) for (var sp, i = 0; i < sps.length; ++i) {
      sp = sps[i];
      if (!sp.marker.collapsed) continue;
      if ((sp.from == null || sp.from < ch) &&
          (sp.to == null || sp.to > ch) &&
          (!found || found.width < sp.marker.width))
        found = sp.marker;
    }
    return found;
  }
  function collapsedSpanAtStart(line) { return collapsedSpanAt(line, -1); }
  function collapsedSpanAtEnd(line) { return collapsedSpanAt(line, line.text.length + 1); }

  function visualLine(doc, line) {
    var merged;
    while (merged = collapsedSpanAtStart(line))
      line = getLine(doc, merged.find().from.line);
    return line;
  }

  function lineIsHidden(doc, line) {
    var sps = sawCollapsedSpans && line.markedSpans;
    if (sps) for (var sp, i = 0; i < sps.length; ++i) {
      sp = sps[i];
      if (!sp.marker.collapsed) continue;
      if (sp.from == null) return true;
      if (sp.marker.replacedWith) continue;
      if (sp.from == 0 && sp.marker.inclusiveLeft && lineIsHiddenInner(doc, line, sp))
        return true;
    }
  }
  function lineIsHiddenInner(doc, line, span) {
    if (span.to == null) {
      var end = span.marker.find().to, endLine = getLine(doc, end.line);
      return lineIsHiddenInner(doc, endLine, getMarkedSpanFor(endLine.markedSpans, span.marker));
    }
    if (span.marker.inclusiveRight && span.to == line.text.length)
      return true;
    for (var sp, i = 0; i < line.markedSpans.length; ++i) {
      sp = line.markedSpans[i];
      if (sp.marker.collapsed && !sp.marker.replacedWith && sp.from == span.to &&
          (sp.marker.inclusiveLeft || span.marker.inclusiveRight) &&
          lineIsHiddenInner(doc, line, sp)) return true;
    }
  }

  function detachMarkedSpans(line) {
    var spans = line.markedSpans;
    if (!spans) return;
    for (var i = 0; i < spans.length; ++i)
      spans[i].marker.detachLine(line);
    line.markedSpans = null;
  }

  function attachMarkedSpans(line, spans) {
    if (!spans) return;
    for (var i = 0; i < spans.length; ++i)
      spans[i].marker.attachLine(line);
    line.markedSpans = spans;
  }

  // LINE WIDGETS

  var LineWidget = CodeMirror.LineWidget = function(cm, node, options) {
    if (options) for (var opt in options) if (options.hasOwnProperty(opt))
      this[opt] = options[opt];
    this.cm = cm;
    this.node = node;
  };
  eventMixin(LineWidget);
  function widgetOperation(f) {
    return function() {
      var withOp = !this.cm.curOp;
      if (withOp) startOperation(this.cm);
      try {var result = f.apply(this, arguments);}
      finally {if (withOp) endOperation(this.cm);}
      return result;
    };
  }
  LineWidget.prototype.clear = widgetOperation(function() {
    var ws = this.line.widgets, no = lineNo(this.line);
    if (no == null || !ws) return;
    for (var i = 0; i < ws.length; ++i) if (ws[i] == this) ws.splice(i--, 1);
    if (!ws.length) this.line.widgets = null;
    var aboveVisible = heightAtLine(this.cm, this.line) < this.cm.doc.scrollTop;
    updateLineHeight(this.line, Math.max(0, this.line.height - widgetHeight(this)));
    if (aboveVisible) addToScrollPos(this.cm, 0, -this.height);
    regChange(this.cm, no, no + 1);
  });
  LineWidget.prototype.changed = widgetOperation(function() {
    var oldH = this.height;
    this.height = null;
    var diff = widgetHeight(this) - oldH;
    if (!diff) return;
    updateLineHeight(this.line, this.line.height + diff);
    var no = lineNo(this.line);
    regChange(this.cm, no, no + 1);
  });

  function widgetHeight(widget) {
    if (widget.height != null) return widget.height;
    if (!widget.node.parentNode || widget.node.parentNode.nodeType != 1)
      removeChildrenAndAdd(widget.cm.display.measure, elt("div", [widget.node], null, "position: relative"));
    return widget.height = widget.node.offsetHeight;
  }

  function addLineWidget(cm, handle, node, options) {
    var widget = new LineWidget(cm, node, options);
    if (widget.noHScroll) cm.display.alignWidgets = true;
    changeLine(cm, handle, function(line) {
      var widgets = line.widgets || (line.widgets = []);
      if (widget.insertAt == null) widgets.push(widget);
      else widgets.splice(Math.min(widgets.length - 1, Math.max(0, widget.insertAt)), 0, widget);
      widget.line = line;
      if (!lineIsHidden(cm.doc, line) || widget.showIfHidden) {
        var aboveVisible = heightAtLine(cm, line) < cm.doc.scrollTop;
        updateLineHeight(line, line.height + widgetHeight(widget));
        if (aboveVisible) addToScrollPos(cm, 0, widget.height);
      }
      return true;
    });
    return widget;
  }

  // LINE DATA STRUCTURE

  // Line objects. These hold state related to a line, including
  // highlighting info (the styles array).
  var Line = CodeMirror.Line = function(text, markedSpans, estimateHeight) {
    this.text = text;
    attachMarkedSpans(this, markedSpans);
    this.height = estimateHeight ? estimateHeight(this) : 1;
  };
  eventMixin(Line);

  function updateLine(line, text, markedSpans, estimateHeight) {
    line.text = text;
    if (line.stateAfter) line.stateAfter = null;
    if (line.styles) line.styles = null;
    if (line.order != null) line.order = null;
    detachMarkedSpans(line);
    attachMarkedSpans(line, markedSpans);
    var estHeight = estimateHeight ? estimateHeight(line) : 1;
    if (estHeight != line.height) updateLineHeight(line, estHeight);
  }

  function cleanUpLine(line) {
    line.parent = null;
    detachMarkedSpans(line);
  }

  // Run the given mode's parser over a line, update the styles
  // array, which contains alternating fragments of text and CSS
  // classes.
  function runMode(cm, text, mode, state, f) {
    var flattenSpans = mode.flattenSpans;
    if (flattenSpans == null) flattenSpans = cm.options.flattenSpans;
    var curStart = 0, curStyle = null;
    var stream = new StringStream(text, cm.options.tabSize), style;
    if (text == "" && mode.blankLine) mode.blankLine(state);
    while (!stream.eol()) {
      if (stream.pos > cm.options.maxHighlightLength) {
        flattenSpans = false;
        // Webkit seems to refuse to render text nodes longer than 57444 characters
        stream.pos = Math.min(text.length, stream.start + 50000);
        style = null;
      } else {
        style = mode.token(stream, state);
      }
      if (!flattenSpans || curStyle != style) {
        if (curStart < stream.start) f(stream.start, curStyle);
        curStart = stream.start; curStyle = style;
      }
      stream.start = stream.pos;
    }
    if (curStart < stream.pos) f(stream.pos, curStyle);
  }

  function highlightLine(cm, line, state) {
    // A styles array always starts with a number identifying the
    // mode/overlays that it is based on (for easy invalidation).
    var st = [cm.state.modeGen];
    // Compute the base array of styles
    runMode(cm, line.text, cm.doc.mode, state, function(end, style) {st.push(end, style);});

    // Run overlays, adjust style array.
    for (var o = 0; o < cm.state.overlays.length; ++o) {
      var overlay = cm.state.overlays[o], i = 1, at = 0;
      runMode(cm, line.text, overlay.mode, true, function(end, style) {
        var start = i;
        // Ensure there's a token end at the current position, and that i points at it
        while (at < end) {
          var i_end = st[i];
          if (i_end > end)
            st.splice(i, 1, end, st[i+1], i_end);
          i += 2;
          at = Math.min(end, i_end);
        }
        if (!style) return;
        if (overlay.opaque) {
          st.splice(start, i - start, end, style);
          i = start + 2;
        } else {
          for (; start < i; start += 2) {
            var cur = st[start+1];
            st[start+1] = cur ? cur + " " + style : style;
          }
        }
      });
    }

    return st;
  }

  function getLineStyles(cm, line) {
    if (!line.styles || line.styles[0] != cm.state.modeGen)
      line.styles = highlightLine(cm, line, line.stateAfter = getStateBefore(cm, lineNo(line)));
    return line.styles;
  }

  // Lightweight form of highlight -- proceed over this line and
  // update state, but don't save a style array.
  function processLine(cm, line, state) {
    var mode = cm.doc.mode;
    var stream = new StringStream(line.text, cm.options.tabSize);
    if (line.text == "" && mode.blankLine) mode.blankLine(state);
    while (!stream.eol() && stream.pos <= cm.options.maxHighlightLength) {
      mode.token(stream, state);
      stream.start = stream.pos;
    }
  }

  var styleToClassCache = {};
  function styleToClass(style) {
    if (!style) return null;
    return styleToClassCache[style] ||
      (styleToClassCache[style] = "cm-" + style.replace(/ +/g, " cm-"));
  }

  function lineContent(cm, realLine, measure, copyWidgets) {
    var merged, line = realLine, empty = true;
    while (merged = collapsedSpanAtStart(line))
      line = getLine(cm.doc, merged.find().from.line);

    var builder = {pre: elt("pre"), col: 0, pos: 0,
                   measure: null, measuredSomething: false, cm: cm,
                   copyWidgets: copyWidgets};
    if (line.textClass) builder.pre.className = line.textClass;

    do {
      if (line.text) empty = false;
      builder.measure = line == realLine && measure;
      builder.pos = 0;
      builder.addToken = builder.measure ? buildTokenMeasure : buildToken;
      if ((ie || webkit) && cm.getOption("lineWrapping"))
        builder.addToken = buildTokenSplitSpaces(builder.addToken);
      var next = insertLineContent(line, builder, getLineStyles(cm, line));
      if (measure && line == realLine && !builder.measuredSomething) {
        measure[0] = builder.pre.appendChild(zeroWidthElement(cm.display.measure));
        builder.measuredSomething = true;
      }
      if (next) line = getLine(cm.doc, next.to.line);
    } while (next);

    if (measure && !builder.measuredSomething && !measure[0])
      measure[0] = builder.pre.appendChild(empty ? elt("span", "\u00a0") : zeroWidthElement(cm.display.measure));
    if (!builder.pre.firstChild && !lineIsHidden(cm.doc, realLine))
      builder.pre.appendChild(document.createTextNode("\u00a0"));

    var order;
    // Work around problem with the reported dimensions of single-char
    // direction spans on IE (issue #1129). See also the comment in
    // cursorCoords.
    if (measure && ie && (order = getOrder(line))) {
      var l = order.length - 1;
      if (order[l].from == order[l].to) --l;
      var last = order[l], prev = order[l - 1];
      if (last.from + 1 == last.to && prev && last.level < prev.level) {
        var span = measure[builder.pos - 1];
        if (span) span.parentNode.insertBefore(span.measureRight = zeroWidthElement(cm.display.measure),
                                               span.nextSibling);
      }
    }

    signal(cm, "renderLine", cm, realLine, builder.pre);
    return builder.pre;
  }

  var tokenSpecialChars = /[\t\u0000-\u0019\u00ad\u200b\u2028\u2029\uFEFF]/g;
  function buildToken(builder, text, style, startStyle, endStyle, title) {
    if (!text) return;
    if (!tokenSpecialChars.test(text)) {
      builder.col += text.length;
      var content = document.createTextNode(text);
    } else {
      var content = document.createDocumentFragment(), pos = 0;
      while (true) {
        tokenSpecialChars.lastIndex = pos;
        var m = tokenSpecialChars.exec(text);
        var skipped = m ? m.index - pos : text.length - pos;
        if (skipped) {
          content.appendChild(document.createTextNode(text.slice(pos, pos + skipped)));
          builder.col += skipped;
        }
        if (!m) break;
        pos += skipped + 1;
        if (m[0] == "\t") {
          var tabSize = builder.cm.options.tabSize, tabWidth = tabSize - builder.col % tabSize;
          content.appendChild(elt("span", spaceStr(tabWidth), "cm-tab"));
          builder.col += tabWidth;
        } else {
          var token = elt("span", "\u2022", "cm-invalidchar");
          token.title = "\\u" + m[0].charCodeAt(0).toString(16);
          content.appendChild(token);
          builder.col += 1;
        }
      }
    }
    if (style || startStyle || endStyle || builder.measure) {
      var fullStyle = style || "";
      if (startStyle) fullStyle += startStyle;
      if (endStyle) fullStyle += endStyle;
      var token = elt("span", [content], fullStyle);
      if (title) token.title = title;
      return builder.pre.appendChild(token);
    }
    builder.pre.appendChild(content);
  }

  function buildTokenMeasure(builder, text, style, startStyle, endStyle) {
    var wrapping = builder.cm.options.lineWrapping;
    for (var i = 0; i < text.length; ++i) {
      var ch = text.charAt(i), start = i == 0;
      if (ch >= "\ud800" && ch < "\udbff" && i < text.length - 1) {
        ch = text.slice(i, i + 2);
        ++i;
      } else if (i && wrapping && spanAffectsWrapping(text, i)) {
        builder.pre.appendChild(elt("wbr"));
      }
      var old = builder.measure[builder.pos];
      var span = builder.measure[builder.pos] =
        buildToken(builder, ch, style,
                   start && startStyle, i == text.length - 1 && endStyle);
      if (old) span.leftSide = old.leftSide || old;
      // In IE single-space nodes wrap differently than spaces
      // embedded in larger text nodes, except when set to
      // white-space: normal (issue #1268).
      if (ie && wrapping && ch == " " && i && !/\s/.test(text.charAt(i - 1)) &&
          i < text.length - 1 && !/\s/.test(text.charAt(i + 1)))
        span.style.whiteSpace = "normal";
      builder.pos += ch.length;
    }
    if (text.length) builder.measuredSomething = true;
  }

  function buildTokenSplitSpaces(inner) {
    function split(old) {
      var out = " ";
      for (var i = 0; i < old.length - 2; ++i) out += i % 2 ? " " : "\u00a0";
      out += " ";
      return out;
    }
    return function(builder, text, style, startStyle, endStyle, title) {
      return inner(builder, text.replace(/ {3,}/, split), style, startStyle, endStyle, title);
    };
  }

  function buildCollapsedSpan(builder, size, marker, ignoreWidget) {
    var widget = !ignoreWidget && marker.replacedWith;
    if (widget) {
      if (builder.copyWidgets) widget = widget.cloneNode(true);
      builder.pre.appendChild(widget);
      if (builder.measure) {
        if (size) {
          builder.measure[builder.pos] = widget;
        } else {
          var elt = builder.measure[builder.pos] = zeroWidthElement(builder.cm.display.measure);
          if (marker.type != "bookmark" || marker.insertLeft)
            builder.pre.insertBefore(elt, widget);
          else
            builder.pre.appendChild(elt);
        }
        builder.measuredSomething = true;
      }
    }
    builder.pos += size;
  }

  // Outputs a number of spans to make up a line, taking highlighting
  // and marked text into account.
  function insertLineContent(line, builder, styles) {
    var spans = line.markedSpans, allText = line.text, at = 0;
    if (!spans) {
      for (var i = 1; i < styles.length; i+=2)
        builder.addToken(builder, allText.slice(at, at = styles[i]), styleToClass(styles[i+1]));
      return;
    }

    var len = allText.length, pos = 0, i = 1, text = "", style;
    var nextChange = 0, spanStyle, spanEndStyle, spanStartStyle, title, collapsed;
    for (;;) {
      if (nextChange == pos) { // Update current marker set
        spanStyle = spanEndStyle = spanStartStyle = title = "";
        collapsed = null; nextChange = Infinity;
        var foundBookmark = null;
        for (var j = 0; j < spans.length; ++j) {
          var sp = spans[j], m = sp.marker;
          if (sp.from <= pos && (sp.to == null || sp.to > pos)) {
            if (sp.to != null && nextChange > sp.to) { nextChange = sp.to; spanEndStyle = ""; }
            if (m.className) spanStyle += " " + m.className;
            if (m.startStyle && sp.from == pos) spanStartStyle += " " + m.startStyle;
            if (m.endStyle && sp.to == nextChange) spanEndStyle += " " + m.endStyle;
            if (m.title && !title) title = m.title;
            if (m.collapsed && (!collapsed || collapsed.marker.size < m.size))
              collapsed = sp;
          } else if (sp.from > pos && nextChange > sp.from) {
            nextChange = sp.from;
          }
          if (m.type == "bookmark" && sp.from == pos && m.replacedWith) foundBookmark = m;
        }
        if (collapsed && (collapsed.from || 0) == pos) {
          buildCollapsedSpan(builder, (collapsed.to == null ? len : collapsed.to) - pos,
                             collapsed.marker, collapsed.from == null);
          if (collapsed.to == null) return collapsed.marker.find();
        }
        if (foundBookmark && !collapsed) buildCollapsedSpan(builder, 0, foundBookmark);
      }
      if (pos >= len) break;

      var upto = Math.min(len, nextChange);
      while (true) {
        if (text) {
          var end = pos + text.length;
          if (!collapsed) {
            var tokenText = end > upto ? text.slice(0, upto - pos) : text;
            builder.addToken(builder, tokenText, style ? style + spanStyle : spanStyle,
                             spanStartStyle, pos + tokenText.length == nextChange ? spanEndStyle : "", title);
          }
          if (end >= upto) {text = text.slice(upto - pos); pos = upto; break;}
          pos = end;
          spanStartStyle = "";
        }
        text = allText.slice(at, at = styles[i++]);
        style = styleToClass(styles[i++]);
      }
    }
  }

  // DOCUMENT DATA STRUCTURE

  function updateDoc(doc, change, markedSpans, selAfter, estimateHeight) {
    function spansFor(n) {return markedSpans ? markedSpans[n] : null;}
    function update(line, text, spans) {
      updateLine(line, text, spans, estimateHeight);
      signalLater(line, "change", line, change);
    }

    var from = change.from, to = change.to, text = change.text;
    var firstLine = getLine(doc, from.line), lastLine = getLine(doc, to.line);
    var lastText = lst(text), lastSpans = spansFor(text.length - 1), nlines = to.line - from.line;

    // First adjust the line structure
    if (from.ch == 0 && to.ch == 0 && lastText == "") {
      // This is a whole-line replace. Treated specially to make
      // sure line objects move the way they are supposed to.
      for (var i = 0, e = text.length - 1, added = []; i < e; ++i)
        added.push(new Line(text[i], spansFor(i), estimateHeight));
      update(lastLine, lastLine.text, lastSpans);
      if (nlines) doc.remove(from.line, nlines);
      if (added.length) doc.insert(from.line, added);
    } else if (firstLine == lastLine) {
      if (text.length == 1) {
        update(firstLine, firstLine.text.slice(0, from.ch) + lastText + firstLine.text.slice(to.ch), lastSpans);
      } else {
        for (var added = [], i = 1, e = text.length - 1; i < e; ++i)
          added.push(new Line(text[i], spansFor(i), estimateHeight));
        added.push(new Line(lastText + firstLine.text.slice(to.ch), lastSpans, estimateHeight));
        update(firstLine, firstLine.text.slice(0, from.ch) + text[0], spansFor(0));
        doc.insert(from.line + 1, added);
      }
    } else if (text.length == 1) {
      update(firstLine, firstLine.text.slice(0, from.ch) + text[0] + lastLine.text.slice(to.ch), spansFor(0));
      doc.remove(from.line + 1, nlines);
    } else {
      update(firstLine, firstLine.text.slice(0, from.ch) + text[0], spansFor(0));
      update(lastLine, lastText + lastLine.text.slice(to.ch), lastSpans);
      for (var i = 1, e = text.length - 1, added = []; i < e; ++i)
        added.push(new Line(text[i], spansFor(i), estimateHeight));
      if (nlines > 1) doc.remove(from.line + 1, nlines - 1);
      doc.insert(from.line + 1, added);
    }

    signalLater(doc, "change", doc, change);
    setSelection(doc, selAfter.anchor, selAfter.head, null, true);
  }

  function LeafChunk(lines) {
    this.lines = lines;
    this.parent = null;
    for (var i = 0, e = lines.length, height = 0; i < e; ++i) {
      lines[i].parent = this;
      height += lines[i].height;
    }
    this.height = height;
  }

  LeafChunk.prototype = {
    chunkSize: function() { return this.lines.length; },
    removeInner: function(at, n) {
      for (var i = at, e = at + n; i < e; ++i) {
        var line = this.lines[i];
        this.height -= line.height;
        cleanUpLine(line);
        signalLater(line, "delete");
      }
      this.lines.splice(at, n);
    },
    collapse: function(lines) {
      lines.splice.apply(lines, [lines.length, 0].concat(this.lines));
    },
    insertInner: function(at, lines, height) {
      this.height += height;
      this.lines = this.lines.slice(0, at).concat(lines).concat(this.lines.slice(at));
      for (var i = 0, e = lines.length; i < e; ++i) lines[i].parent = this;
    },
    iterN: function(at, n, op) {
      for (var e = at + n; at < e; ++at)
        if (op(this.lines[at])) return true;
    }
  };

  function BranchChunk(children) {
    this.children = children;
    var size = 0, height = 0;
    for (var i = 0, e = children.length; i < e; ++i) {
      var ch = children[i];
      size += ch.chunkSize(); height += ch.height;
      ch.parent = this;
    }
    this.size = size;
    this.height = height;
    this.parent = null;
  }

  BranchChunk.prototype = {
    chunkSize: function() { return this.size; },
    removeInner: function(at, n) {
      this.size -= n;
      for (var i = 0; i < this.children.length; ++i) {
        var child = this.children[i], sz = child.chunkSize();
        if (at < sz) {
          var rm = Math.min(n, sz - at), oldHeight = child.height;
          child.removeInner(at, rm);
          this.height -= oldHeight - child.height;
          if (sz == rm) { this.children.splice(i--, 1); child.parent = null; }
          if ((n -= rm) == 0) break;
          at = 0;
        } else at -= sz;
      }
      if (this.size - n < 25) {
        var lines = [];
        this.collapse(lines);
        this.children = [new LeafChunk(lines)];
        this.children[0].parent = this;
      }
    },
    collapse: function(lines) {
      for (var i = 0, e = this.children.length; i < e; ++i) this.children[i].collapse(lines);
    },
    insertInner: function(at, lines, height) {
      this.size += lines.length;
      this.height += height;
      for (var i = 0, e = this.children.length; i < e; ++i) {
        var child = this.children[i], sz = child.chunkSize();
        if (at <= sz) {
          child.insertInner(at, lines, height);
          if (child.lines && child.lines.length > 50) {
            while (child.lines.length > 50) {
              var spilled = child.lines.splice(child.lines.length - 25, 25);
              var newleaf = new LeafChunk(spilled);
              child.height -= newleaf.height;
              this.children.splice(i + 1, 0, newleaf);
              newleaf.parent = this;
            }
            this.maybeSpill();
          }
          break;
        }
        at -= sz;
      }
    },
    maybeSpill: function() {
      if (this.children.length <= 10) return;
      var me = this;
      do {
        var spilled = me.children.splice(me.children.length - 5, 5);
        var sibling = new BranchChunk(spilled);
        if (!me.parent) { // Become the parent node
          var copy = new BranchChunk(me.children);
          copy.parent = me;
          me.children = [copy, sibling];
          me = copy;
        } else {
          me.size -= sibling.size;
          me.height -= sibling.height;
          var myIndex = indexOf(me.parent.children, me);
          me.parent.children.splice(myIndex + 1, 0, sibling);
        }
        sibling.parent = me.parent;
      } while (me.children.length > 10);
      me.parent.maybeSpill();
    },
    iterN: function(at, n, op) {
      for (var i = 0, e = this.children.length; i < e; ++i) {
        var child = this.children[i], sz = child.chunkSize();
        if (at < sz) {
          var used = Math.min(n, sz - at);
          if (child.iterN(at, used, op)) return true;
          if ((n -= used) == 0) break;
          at = 0;
        } else at -= sz;
      }
    }
  };

  var nextDocId = 0;
  var Doc = CodeMirror.Doc = function(text, mode, firstLine) {
    if (!(this instanceof Doc)) return new Doc(text, mode, firstLine);
    if (firstLine == null) firstLine = 0;

    BranchChunk.call(this, [new LeafChunk([new Line("", null)])]);
    this.first = firstLine;
    this.scrollTop = this.scrollLeft = 0;
    this.cantEdit = false;
    this.history = makeHistory();
    this.cleanGeneration = 1;
    this.frontier = firstLine;
    var start = Pos(firstLine, 0);
    this.sel = {from: start, to: start, head: start, anchor: start, shift: false, extend: false, goalColumn: null};
    this.id = ++nextDocId;
    this.modeOption = mode;

    if (typeof text == "string") text = splitLines(text);
    updateDoc(this, {from: start, to: start, text: text}, null, {head: start, anchor: start});
  };

  Doc.prototype = createObj(BranchChunk.prototype, {
    constructor: Doc,
    iter: function(from, to, op) {
      if (op) this.iterN(from - this.first, to - from, op);
      else this.iterN(this.first, this.first + this.size, from);
    },

    insert: function(at, lines) {
      var height = 0;
      for (var i = 0, e = lines.length; i < e; ++i) height += lines[i].height;
      this.insertInner(at - this.first, lines, height);
    },
    remove: function(at, n) { this.removeInner(at - this.first, n); },

    getValue: function(lineSep) {
      var lines = getLines(this, this.first, this.first + this.size);
      if (lineSep === false) return lines;
      return lines.join(lineSep || "\n");
    },
    setValue: function(code) {
      var top = Pos(this.first, 0), last = this.first + this.size - 1;
      makeChange(this, {from: top, to: Pos(last, getLine(this, last).text.length),
                        text: splitLines(code), origin: "setValue"},
                 {head: top, anchor: top}, true);
    },
    replaceRange: function(code, from, to, origin) {
      from = clipPos(this, from);
      to = to ? clipPos(this, to) : from;
      replaceRange(this, code, from, to, origin);
    },
    getRange: function(from, to, lineSep) {
      var lines = getBetween(this, clipPos(this, from), clipPos(this, to));
      if (lineSep === false) return lines;
      return lines.join(lineSep || "\n");
    },

    getLine: function(line) {var l = this.getLineHandle(line); return l && l.text;},
    setLine: function(line, text) {
      if (isLine(this, line))
        replaceRange(this, text, Pos(line, 0), clipPos(this, Pos(line)));
    },
    removeLine: function(line) {
      if (line) replaceRange(this, "", clipPos(this, Pos(line - 1)), clipPos(this, Pos(line)));
      else replaceRange(this, "", Pos(0, 0), clipPos(this, Pos(1, 0)));
    },

    getLineHandle: function(line) {if (isLine(this, line)) return getLine(this, line);},
    getLineNumber: function(line) {return lineNo(line);},

    getLineHandleVisualStart: function(line) {
      if (typeof line == "number") line = getLine(this, line);
      return visualLine(this, line);
    },

    lineCount: function() {return this.size;},
    firstLine: function() {return this.first;},
    lastLine: function() {return this.first + this.size - 1;},

    clipPos: function(pos) {return clipPos(this, pos);},

    getCursor: function(start) {
      var sel = this.sel, pos;
      if (start == null || start == "head") pos = sel.head;
      else if (start == "anchor") pos = sel.anchor;
      else if (start == "end" || start === false) pos = sel.to;
      else pos = sel.from;
      return copyPos(pos);
    },
    somethingSelected: function() {return !posEq(this.sel.head, this.sel.anchor);},

    setCursor: docOperation(function(line, ch, extend) {
      var pos = clipPos(this, typeof line == "number" ? Pos(line, ch || 0) : line);
      if (extend) extendSelection(this, pos);
      else setSelection(this, pos, pos);
    }),
    setSelection: docOperation(function(anchor, head) {
      setSelection(this, clipPos(this, anchor), clipPos(this, head || anchor));
    }),
    extendSelection: docOperation(function(from, to) {
      extendSelection(this, clipPos(this, from), to && clipPos(this, to));
    }),

    getSelection: function(lineSep) {return this.getRange(this.sel.from, this.sel.to, lineSep);},
    replaceSelection: function(code, collapse, origin) {
      makeChange(this, {from: this.sel.from, to: this.sel.to, text: splitLines(code), origin: origin}, collapse || "around");
    },
    undo: docOperation(function() {makeChangeFromHistory(this, "undo");}),
    redo: docOperation(function() {makeChangeFromHistory(this, "redo");}),

    setExtending: function(val) {this.sel.extend = val;},

    historySize: function() {
      var hist = this.history;
      return {undo: hist.done.length, redo: hist.undone.length};
    },
    clearHistory: function() {this.history = makeHistory(this.history.maxGeneration);},

    markClean: function() {
      this.cleanGeneration = this.changeGeneration();
    },
    changeGeneration: function() {
      this.history.lastOp = this.history.lastOrigin = null;
      return this.history.generation;
    },
    isClean: function (gen) {
      return this.history.generation == (gen || this.cleanGeneration);
    },

    getHistory: function() {
      return {done: copyHistoryArray(this.history.done),
              undone: copyHistoryArray(this.history.undone)};
    },
    setHistory: function(histData) {
      var hist = this.history = makeHistory(this.history.maxGeneration);
      hist.done = histData.done.slice(0);
      hist.undone = histData.undone.slice(0);
    },

    markText: function(from, to, options) {
      return markText(this, clipPos(this, from), clipPos(this, to), options, "range");
    },
    setBookmark: function(pos, options) {
      var realOpts = {replacedWith: options && (options.nodeType == null ? options.widget : options),
                      insertLeft: options && options.insertLeft};
      pos = clipPos(this, pos);
      return markText(this, pos, pos, realOpts, "bookmark");
    },
    findMarksAt: function(pos) {
      pos = clipPos(this, pos);
      var markers = [], spans = getLine(this, pos.line).markedSpans;
      if (spans) for (var i = 0; i < spans.length; ++i) {
        var span = spans[i];
        if ((span.from == null || span.from <= pos.ch) &&
            (span.to == null || span.to >= pos.ch))
          markers.push(span.marker.parent || span.marker);
      }
      return markers;
    },
    getAllMarks: function() {
      var markers = [];
      this.iter(function(line) {
        var sps = line.markedSpans;
        if (sps) for (var i = 0; i < sps.length; ++i)
          if (sps[i].from != null) markers.push(sps[i].marker);
      });
      return markers;
    },

    posFromIndex: function(off) {
      var ch, lineNo = this.first;
      this.iter(function(line) {
        var sz = line.text.length + 1;
        if (sz > off) { ch = off; return true; }
        off -= sz;
        ++lineNo;
      });
      return clipPos(this, Pos(lineNo, ch));
    },
    indexFromPos: function (coords) {
      coords = clipPos(this, coords);
      var index = coords.ch;
      if (coords.line < this.first || coords.ch < 0) return 0;
      this.iter(this.first, coords.line, function (line) {
        index += line.text.length + 1;
      });
      return index;
    },

    copy: function(copyHistory) {
      var doc = new Doc(getLines(this, this.first, this.first + this.size), this.modeOption, this.first);
      doc.scrollTop = this.scrollTop; doc.scrollLeft = this.scrollLeft;
      doc.sel = {from: this.sel.from, to: this.sel.to, head: this.sel.head, anchor: this.sel.anchor,
                 shift: this.sel.shift, extend: false, goalColumn: this.sel.goalColumn};
      if (copyHistory) {
        doc.history.undoDepth = this.history.undoDepth;
        doc.setHistory(this.getHistory());
      }
      return doc;
    },

    linkedDoc: function(options) {
      if (!options) options = {};
      var from = this.first, to = this.first + this.size;
      if (options.from != null && options.from > from) from = options.from;
      if (options.to != null && options.to < to) to = options.to;
      var copy = new Doc(getLines(this, from, to), options.mode || this.modeOption, from);
      if (options.sharedHist) copy.history = this.history;
      (this.linked || (this.linked = [])).push({doc: copy, sharedHist: options.sharedHist});
      copy.linked = [{doc: this, isParent: true, sharedHist: options.sharedHist}];
      return copy;
    },
    unlinkDoc: function(other) {
      if (other instanceof CodeMirror) other = other.doc;
      if (this.linked) for (var i = 0; i < this.linked.length; ++i) {
        var link = this.linked[i];
        if (link.doc != other) continue;
        this.linked.splice(i, 1);
        other.unlinkDoc(this);
        break;
      }
      // If the histories were shared, split them again
      if (other.history == this.history) {
        var splitIds = [other.id];
        linkedDocs(other, function(doc) {splitIds.push(doc.id);}, true);
        other.history = makeHistory();
        other.history.done = copyHistoryArray(this.history.done, splitIds);
        other.history.undone = copyHistoryArray(this.history.undone, splitIds);
      }
    },
    iterLinkedDocs: function(f) {linkedDocs(this, f);},

    getMode: function() {return this.mode;},
    getEditor: function() {return this.cm;}
  });

  Doc.prototype.eachLine = Doc.prototype.iter;

  // The Doc methods that should be available on CodeMirror instances
  var dontDelegate = "iter insert remove copy getEditor".split(" ");
  for (var prop in Doc.prototype) if (Doc.prototype.hasOwnProperty(prop) && indexOf(dontDelegate, prop) < 0)
    CodeMirror.prototype[prop] = (function(method) {
      return function() {return method.apply(this.doc, arguments);};
    })(Doc.prototype[prop]);

  eventMixin(Doc);

  function linkedDocs(doc, f, sharedHistOnly) {
    function propagate(doc, skip, sharedHist) {
      if (doc.linked) for (var i = 0; i < doc.linked.length; ++i) {
        var rel = doc.linked[i];
        if (rel.doc == skip) continue;
        var shared = sharedHist && rel.sharedHist;
        if (sharedHistOnly && !shared) continue;
        f(rel.doc, shared);
        propagate(rel.doc, doc, shared);
      }
    }
    propagate(doc, null, true);
  }

  function attachDoc(cm, doc) {
    if (doc.cm) throw new Error("This document is already in use.");
    cm.doc = doc;
    doc.cm = cm;
    estimateLineHeights(cm);
    loadMode(cm);
    if (!cm.options.lineWrapping) computeMaxLength(cm);
    cm.options.mode = doc.modeOption;
    regChange(cm);
  }

  // LINE UTILITIES

  function getLine(chunk, n) {
    n -= chunk.first;
    while (!chunk.lines) {
      for (var i = 0;; ++i) {
        var child = chunk.children[i], sz = child.chunkSize();
        if (n < sz) { chunk = child; break; }
        n -= sz;
      }
    }
    return chunk.lines[n];
  }

  function getBetween(doc, start, end) {
    var out = [], n = start.line;
    doc.iter(start.line, end.line + 1, function(line) {
      var text = line.text;
      if (n == end.line) text = text.slice(0, end.ch);
      if (n == start.line) text = text.slice(start.ch);
      out.push(text);
      ++n;
    });
    return out;
  }
  function getLines(doc, from, to) {
    var out = [];
    doc.iter(from, to, function(line) { out.push(line.text); });
    return out;
  }

  function updateLineHeight(line, height) {
    var diff = height - line.height;
    for (var n = line; n; n = n.parent) n.height += diff;
  }

  function lineNo(line) {
    if (line.parent == null) return null;
    var cur = line.parent, no = indexOf(cur.lines, line);
    for (var chunk = cur.parent; chunk; cur = chunk, chunk = chunk.parent) {
      for (var i = 0;; ++i) {
        if (chunk.children[i] == cur) break;
        no += chunk.children[i].chunkSize();
      }
    }
    return no + cur.first;
  }

  function lineAtHeight(chunk, h) {
    var n = chunk.first;
    outer: do {
      for (var i = 0, e = chunk.children.length; i < e; ++i) {
        var child = chunk.children[i], ch = child.height;
        if (h < ch) { chunk = child; continue outer; }
        h -= ch;
        n += child.chunkSize();
      }
      return n;
    } while (!chunk.lines);
    for (var i = 0, e = chunk.lines.length; i < e; ++i) {
      var line = chunk.lines[i], lh = line.height;
      if (h < lh) break;
      h -= lh;
    }
    return n + i;
  }

  function heightAtLine(cm, lineObj) {
    lineObj = visualLine(cm.doc, lineObj);

    var h = 0, chunk = lineObj.parent;
    for (var i = 0; i < chunk.lines.length; ++i) {
      var line = chunk.lines[i];
      if (line == lineObj) break;
      else h += line.height;
    }
    for (var p = chunk.parent; p; chunk = p, p = chunk.parent) {
      for (var i = 0; i < p.children.length; ++i) {
        var cur = p.children[i];
        if (cur == chunk) break;
        else h += cur.height;
      }
    }
    return h;
  }

  function getOrder(line) {
    var order = line.order;
    if (order == null) order = line.order = bidiOrdering(line.text);
    return order;
  }

  // HISTORY

  function makeHistory(startGen) {
    return {
      // Arrays of history events. Doing something adds an event to
      // done and clears undo. Undoing moves events from done to
      // undone, redoing moves them in the other direction.
      done: [], undone: [], undoDepth: Infinity,
      // Used to track when changes can be merged into a single undo
      // event
      lastTime: 0, lastOp: null, lastOrigin: null,
      // Used by the isClean() method
      generation: startGen || 1, maxGeneration: startGen || 1
    };
  }

  function attachLocalSpans(doc, change, from, to) {
    var existing = change["spans_" + doc.id], n = 0;
    doc.iter(Math.max(doc.first, from), Math.min(doc.first + doc.size, to), function(line) {
      if (line.markedSpans)
        (existing || (existing = change["spans_" + doc.id] = {}))[n] = line.markedSpans;
      ++n;
    });
  }

  function historyChangeFromChange(doc, change) {
    var from = { line: change.from.line, ch: change.from.ch };
    var histChange = {from: from, to: changeEnd(change), text: getBetween(doc, change.from, change.to)};
    attachLocalSpans(doc, histChange, change.from.line, change.to.line + 1);
    linkedDocs(doc, function(doc) {attachLocalSpans(doc, histChange, change.from.line, change.to.line + 1);}, true);
    return histChange;
  }

  function addToHistory(doc, change, selAfter, opId) {
    var hist = doc.history;
    hist.undone.length = 0;
    var time = +new Date, cur = lst(hist.done);

    if (cur &&
        (hist.lastOp == opId ||
         hist.lastOrigin == change.origin && change.origin &&
         ((change.origin.charAt(0) == "+" && doc.cm && hist.lastTime > time - doc.cm.options.historyEventDelay) ||
          change.origin.charAt(0) == "*"))) {
      // Merge this change into the last event
      var last = lst(cur.changes);
      if (posEq(change.from, change.to) && posEq(change.from, last.to)) {
        // Optimized case for simple insertion -- don't want to add
        // new changesets for every character typed
        last.to = changeEnd(change);
      } else {
        // Add new sub-event
        cur.changes.push(historyChangeFromChange(doc, change));
      }
      cur.anchorAfter = selAfter.anchor; cur.headAfter = selAfter.head;
    } else {
      // Can not be merged, start a new event.
      cur = {changes: [historyChangeFromChange(doc, change)],
             generation: hist.generation,
             anchorBefore: doc.sel.anchor, headBefore: doc.sel.head,
             anchorAfter: selAfter.anchor, headAfter: selAfter.head};
      hist.done.push(cur);
      hist.generation = ++hist.maxGeneration;
      while (hist.done.length > hist.undoDepth)
        hist.done.shift();
    }
    hist.lastTime = time;
    hist.lastOp = opId;
    hist.lastOrigin = change.origin;
  }

  function removeClearedSpans(spans) {
    if (!spans) return null;
    for (var i = 0, out; i < spans.length; ++i) {
      if (spans[i].marker.explicitlyCleared) { if (!out) out = spans.slice(0, i); }
      else if (out) out.push(spans[i]);
    }
    return !out ? spans : out.length ? out : null;
  }

  function getOldSpans(doc, change) {
    var found = change["spans_" + doc.id];
    if (!found) return null;
    for (var i = 0, nw = []; i < change.text.length; ++i)
      nw.push(removeClearedSpans(found[i]));
    return nw;
  }

  // Used both to provide a JSON-safe object in .getHistory, and, when
  // detaching a document, to split the history in two
  function copyHistoryArray(events, newGroup) {
    for (var i = 0, copy = []; i < events.length; ++i) {
      var event = events[i], changes = event.changes, newChanges = [];
      copy.push({changes: newChanges, anchorBefore: event.anchorBefore, headBefore: event.headBefore,
                 anchorAfter: event.anchorAfter, headAfter: event.headAfter});
      for (var j = 0; j < changes.length; ++j) {
        var change = changes[j], m;
        newChanges.push({from: change.from, to: change.to, text: change.text});
        if (newGroup) for (var prop in change) if (m = prop.match(/^spans_(\d+)$/)) {
          if (indexOf(newGroup, Number(m[1])) > -1) {
            lst(newChanges)[prop] = change[prop];
            delete change[prop];
          }
        }
      }
    }
    return copy;
  }

  // Rebasing/resetting history to deal with externally-sourced changes

  function rebaseHistSel(pos, from, to, diff) {
    if (to < pos.line) {
      pos.line += diff;
    } else if (from < pos.line) {
      pos.line = from;
      pos.ch = 0;
    }
  }

  // Tries to rebase an array of history events given a change in the
  // document. If the change touches the same lines as the event, the
  // event, and everything 'behind' it, is discarded. If the change is
  // before the event, the event's positions are updated. Uses a
  // copy-on-write scheme for the positions, to avoid having to
  // reallocate them all on every rebase, but also avoid problems with
  // shared position objects being unsafely updated.
  function rebaseHistArray(array, from, to, diff) {
    for (var i = 0; i < array.length; ++i) {
      var sub = array[i], ok = true;
      for (var j = 0; j < sub.changes.length; ++j) {
        var cur = sub.changes[j];
        if (!sub.copied) { cur.from = copyPos(cur.from); cur.to = copyPos(cur.to); }
        if (to < cur.from.line) {
          cur.from.line += diff;
          cur.to.line += diff;
        } else if (from <= cur.to.line) {
          ok = false;
          break;
        }
      }
      if (!sub.copied) {
        sub.anchorBefore = copyPos(sub.anchorBefore); sub.headBefore = copyPos(sub.headBefore);
        sub.anchorAfter = copyPos(sub.anchorAfter); sub.readAfter = copyPos(sub.headAfter);
        sub.copied = true;
      }
      if (!ok) {
        array.splice(0, i + 1);
        i = 0;
      } else {
        rebaseHistSel(sub.anchorBefore); rebaseHistSel(sub.headBefore);
        rebaseHistSel(sub.anchorAfter); rebaseHistSel(sub.headAfter);
      }
    }
  }

  function rebaseHist(hist, change) {
    var from = change.from.line, to = change.to.line, diff = change.text.length - (to - from) - 1;
    rebaseHistArray(hist.done, from, to, diff);
    rebaseHistArray(hist.undone, from, to, diff);
  }

  // EVENT OPERATORS

  function stopMethod() {e_stop(this);}
  // Ensure an event has a stop method.
  function addStop(event) {
    if (!event.stop) event.stop = stopMethod;
    return event;
  }

  function e_preventDefault(e) {
    if (e.preventDefault) e.preventDefault();
    else e.returnValue = false;
  }
  function e_stopPropagation(e) {
    if (e.stopPropagation) e.stopPropagation();
    else e.cancelBubble = true;
  }
  function e_defaultPrevented(e) {
    return e.defaultPrevented != null ? e.defaultPrevented : e.returnValue == false;
  }
  function e_stop(e) {e_preventDefault(e); e_stopPropagation(e);}
  CodeMirror.e_stop = e_stop;
  CodeMirror.e_preventDefault = e_preventDefault;
  CodeMirror.e_stopPropagation = e_stopPropagation;

  function e_target(e) {return e.target || e.srcElement;}
  function e_button(e) {
    var b = e.which;
    if (b == null) {
      if (e.button & 1) b = 1;
      else if (e.button & 2) b = 3;
      else if (e.button & 4) b = 2;
    }
    if (mac && e.ctrlKey && b == 1) b = 3;
    return b;
  }

  // EVENT HANDLING

  function on(emitter, type, f) {
    if (emitter.addEventListener)
      emitter.addEventListener(type, f, false);
    else if (emitter.attachEvent)
      emitter.attachEvent("on" + type, f);
    else {
      var map = emitter._handlers || (emitter._handlers = {});
      var arr = map[type] || (map[type] = []);
      arr.push(f);
    }
  }

  function off(emitter, type, f) {
    if (emitter.removeEventListener)
      emitter.removeEventListener(type, f, false);
    else if (emitter.detachEvent)
      emitter.detachEvent("on" + type, f);
    else {
      var arr = emitter._handlers && emitter._handlers[type];
      if (!arr) return;
      for (var i = 0; i < arr.length; ++i)
        if (arr[i] == f) { arr.splice(i, 1); break; }
    }
  }

  function signal(emitter, type /*, values...*/) {
    var arr = emitter._handlers && emitter._handlers[type];
    if (!arr) return;
    var args = Array.prototype.slice.call(arguments, 2);
    for (var i = 0; i < arr.length; ++i) arr[i].apply(null, args);
  }

  var delayedCallbacks, delayedCallbackDepth = 0;
  function signalLater(emitter, type /*, values...*/) {
    var arr = emitter._handlers && emitter._handlers[type];
    if (!arr) return;
    var args = Array.prototype.slice.call(arguments, 2);
    if (!delayedCallbacks) {
      ++delayedCallbackDepth;
      delayedCallbacks = [];
      setTimeout(fireDelayed, 0);
    }
    function bnd(f) {return function(){f.apply(null, args);};};
    for (var i = 0; i < arr.length; ++i)
      delayedCallbacks.push(bnd(arr[i]));
  }

  function signalDOMEvent(cm, e, override) {
    signal(cm, override || e.type, cm, e);
    return e_defaultPrevented(e) || e.codemirrorIgnore;
  }

  function fireDelayed() {
    --delayedCallbackDepth;
    var delayed = delayedCallbacks;
    delayedCallbacks = null;
    for (var i = 0; i < delayed.length; ++i) delayed[i]();
  }

  function hasHandler(emitter, type) {
    var arr = emitter._handlers && emitter._handlers[type];
    return arr && arr.length > 0;
  }

  CodeMirror.on = on; CodeMirror.off = off; CodeMirror.signal = signal;

  function eventMixin(ctor) {
    ctor.prototype.on = function(type, f) {on(this, type, f);};
    ctor.prototype.off = function(type, f) {off(this, type, f);};
  }

  // MISC UTILITIES

  // Number of pixels added to scroller and sizer to hide scrollbar
  var scrollerCutOff = 30;

  // Returned or thrown by various protocols to signal 'I'm not
  // handling this'.
  var Pass = CodeMirror.Pass = {toString: function(){return "CodeMirror.Pass";}};

  function Delayed() {this.id = null;}
  Delayed.prototype = {set: function(ms, f) {clearTimeout(this.id); this.id = setTimeout(f, ms);}};

  // Counts the column offset in a string, taking tabs into account.
  // Used mostly to find indentation.
  function countColumn(string, end, tabSize, startIndex, startValue) {
    if (end == null) {
      end = string.search(/[^\s\u00a0]/);
      if (end == -1) end = string.length;
    }
    for (var i = startIndex || 0, n = startValue || 0; i < end; ++i) {
      if (string.charAt(i) == "\t") n += tabSize - (n % tabSize);
      else ++n;
    }
    return n;
  }
  CodeMirror.countColumn = countColumn;

  var spaceStrs = [""];
  function spaceStr(n) {
    while (spaceStrs.length <= n)
      spaceStrs.push(lst(spaceStrs) + " ");
    return spaceStrs[n];
  }

  function lst(arr) { return arr[arr.length-1]; }

  function selectInput(node) {
    if (ios) { // Mobile Safari apparently has a bug where select() is broken.
      node.selectionStart = 0;
      node.selectionEnd = node.value.length;
    } else {
      // Suppress mysterious IE10 errors
      try { node.select(); }
      catch(_e) {}
    }
  }

  function indexOf(collection, elt) {
    if (collection.indexOf) return collection.indexOf(elt);
    for (var i = 0, e = collection.length; i < e; ++i)
      if (collection[i] == elt) return i;
    return -1;
  }

  function createObj(base, props) {
    function Obj() {}
    Obj.prototype = base;
    var inst = new Obj();
    if (props) copyObj(props, inst);
    return inst;
  }

  function copyObj(obj, target) {
    if (!target) target = {};
    for (var prop in obj) if (obj.hasOwnProperty(prop)) target[prop] = obj[prop];
    return target;
  }

  function emptyArray(size) {
    for (var a = [], i = 0; i < size; ++i) a.push(undefined);
    return a;
  }

  function bind(f) {
    var args = Array.prototype.slice.call(arguments, 1);
    return function(){return f.apply(null, args);};
  }

  var nonASCIISingleCaseWordChar = /[\u3040-\u309f\u30a0-\u30ff\u3400-\u4db5\u4e00-\u9fcc\uac00-\ud7af]/;
  function isWordChar(ch) {
    return /\w/.test(ch) || ch > "\x80" &&
      (ch.toUpperCase() != ch.toLowerCase() || nonASCIISingleCaseWordChar.test(ch));
  }

  function isEmpty(obj) {
    for (var n in obj) if (obj.hasOwnProperty(n) && obj[n]) return false;
    return true;
  }

  var isExtendingChar = /[\u0300-\u036F\u0483-\u0487\u0488-\u0489\u0591-\u05BD\u05BF\u05C1-\u05C2\u05C4-\u05C5\u05C7\u0610-\u061A\u064B-\u065F\u0670\u06D6-\u06DC\u06DF-\u06E4\u06E7-\u06E8\u06EA-\u06ED\uA66F\uA670-\uA672\uA674-\uA67D\uA69F\udc00-\udfff]/;

  // DOM UTILITIES

  function elt(tag, content, className, style) {
    var e = document.createElement(tag);
    if (className) e.className = className;
    if (style) e.style.cssText = style;
    if (typeof content == "string") setTextContent(e, content);
    else if (content) for (var i = 0; i < content.length; ++i) e.appendChild(content[i]);
    return e;
  }

  function removeChildren(e) {
    for (var count = e.childNodes.length; count > 0; --count)
      e.removeChild(e.firstChild);
    return e;
  }

  function removeChildrenAndAdd(parent, e) {
    return removeChildren(parent).appendChild(e);
  }

  function setTextContent(e, str) {
    if (ie_lt9) {
      e.innerHTML = "";
      e.appendChild(document.createTextNode(str));
    } else e.textContent = str;
  }

  function getRect(node) {
    return node.getBoundingClientRect();
  }
  CodeMirror.replaceGetRect = function(f) { getRect = f; };

  // FEATURE DETECTION

  // Detect drag-and-drop
  var dragAndDrop = function() {
    // There is *some* kind of drag-and-drop support in IE6-8, but I
    // couldn't get it to work yet.
    if (ie_lt9) return false;
    var div = elt('div');
    return "draggable" in div || "dragDrop" in div;
  }();

  // For a reason I have yet to figure out, some browsers disallow
  // word wrapping between certain characters *only* if a new inline
  // element is started between them. This makes it hard to reliably
  // measure the position of things, since that requires inserting an
  // extra span. This terribly fragile set of tests matches the
  // character combinations that suffer from this phenomenon on the
  // various browsers.
  function spanAffectsWrapping() { return false; }
  if (gecko) // Only for "$'"
    spanAffectsWrapping = function(str, i) {
      return str.charCodeAt(i - 1) == 36 && str.charCodeAt(i) == 39;
    };
  else if (safari && !/Version\/([6-9]|\d\d)\b/.test(navigator.userAgent))
    spanAffectsWrapping = function(str, i) {
      return /\-[^ \-?]|\?[^ !\'\"\),.\-\/:;\?\]\}]/.test(str.slice(i - 1, i + 1));
    };
  else if (webkit && !/Chrome\/(?:29|[3-9]\d|\d\d\d)\./.test(navigator.userAgent))
    spanAffectsWrapping = function(str, i) {
      if (i > 1 && str.charCodeAt(i - 1) == 45) {
        if (/\w/.test(str.charAt(i - 2)) && /[^\-?\.]/.test(str.charAt(i))) return true;
        if (i > 2 && /[\d\.,]/.test(str.charAt(i - 2)) && /[\d\.,]/.test(str.charAt(i))) return false;
      }
      return /[~!#%&*)=+}\]|\"\.>,:;][({[<]|-[^\-?\.\u2010-\u201f\u2026]|\?[\w~`@#$%\^&*(_=+{[|><]|…[\w~`@#$%\^&*(_=+{[><]/.test(str.slice(i - 1, i + 1));
    };

  var knownScrollbarWidth;
  function scrollbarWidth(measure) {
    if (knownScrollbarWidth != null) return knownScrollbarWidth;
    var test = elt("div", null, null, "width: 50px; height: 50px; overflow-x: scroll");
    removeChildrenAndAdd(measure, test);
    if (test.offsetWidth)
      knownScrollbarWidth = test.offsetHeight - test.clientHeight;
    return knownScrollbarWidth || 0;
  }

  var zwspSupported;
  function zeroWidthElement(measure) {
    if (zwspSupported == null) {
      var test = elt("span", "\u200b");
      removeChildrenAndAdd(measure, elt("span", [test, document.createTextNode("x")]));
      if (measure.firstChild.offsetHeight != 0)
        zwspSupported = test.offsetWidth <= 1 && test.offsetHeight > 2 && !ie_lt8;
    }
    if (zwspSupported) return elt("span", "\u200b");
    else return elt("span", "\u00a0", null, "display: inline-block; width: 1px; margin-right: -1px");
  }

  // See if "".split is the broken IE version, if so, provide an
  // alternative way to split lines.
  var splitLines = "\n\nb".split(/\n/).length != 3 ? function(string) {
    var pos = 0, result = [], l = string.length;
    while (pos <= l) {
      var nl = string.indexOf("\n", pos);
      if (nl == -1) nl = string.length;
      var line = string.slice(pos, string.charAt(nl - 1) == "\r" ? nl - 1 : nl);
      var rt = line.indexOf("\r");
      if (rt != -1) {
        result.push(line.slice(0, rt));
        pos += rt + 1;
      } else {
        result.push(line);
        pos = nl + 1;
      }
    }
    return result;
  } : function(string){return string.split(/\r\n?|\n/);};
  CodeMirror.splitLines = splitLines;

  var hasSelection = window.getSelection ? function(te) {
    try { return te.selectionStart != te.selectionEnd; }
    catch(e) { return false; }
  } : function(te) {
    try {var range = te.ownerDocument.selection.createRange();}
    catch(e) {}
    if (!range || range.parentElement() != te) return false;
    return range.compareEndPoints("StartToEnd", range) != 0;
  };

  var hasCopyEvent = (function() {
    var e = elt("div");
    if ("oncopy" in e) return true;
    e.setAttribute("oncopy", "return;");
    return typeof e.oncopy == 'function';
  })();

  // KEY NAMING

  var keyNames = {3: "Enter", 8: "Backspace", 9: "Tab", 13: "Enter", 16: "Shift", 17: "Ctrl", 18: "Alt",
                  19: "Pause", 20: "CapsLock", 27: "Esc", 32: "Space", 33: "PageUp", 34: "PageDown", 35: "End",
                  36: "Home", 37: "Left", 38: "Up", 39: "Right", 40: "Down", 44: "PrintScrn", 45: "Insert",
                  46: "Delete", 59: ";", 91: "Mod", 92: "Mod", 93: "Mod", 109: "-", 107: "=", 127: "Delete",
                  186: ";", 187: "=", 188: ",", 189: "-", 190: ".", 191: "/", 192: "`", 219: "[", 220: "\\",
                  221: "]", 222: "'", 63276: "PageUp", 63277: "PageDown", 63275: "End", 63273: "Home",
                  63234: "Left", 63232: "Up", 63235: "Right", 63233: "Down", 63302: "Insert", 63272: "Delete"};
  CodeMirror.keyNames = keyNames;
  (function() {
    // Number keys
    for (var i = 0; i < 10; i++) keyNames[i + 48] = String(i);
    // Alphabetic keys
    for (var i = 65; i <= 90; i++) keyNames[i] = String.fromCharCode(i);
    // Function keys
    for (var i = 1; i <= 12; i++) keyNames[i + 111] = keyNames[i + 63235] = "F" + i;
  })();

  // BIDI HELPERS

  function iterateBidiSections(order, from, to, f) {
    if (!order) return f(from, to, "ltr");
    var found = false;
    for (var i = 0; i < order.length; ++i) {
      var part = order[i];
      if (part.from < to && part.to > from || from == to && part.to == from) {
        f(Math.max(part.from, from), Math.min(part.to, to), part.level == 1 ? "rtl" : "ltr");
        found = true;
      }
    }
    if (!found) f(from, to, "ltr");
  }

  function bidiLeft(part) { return part.level % 2 ? part.to : part.from; }
  function bidiRight(part) { return part.level % 2 ? part.from : part.to; }

  function lineLeft(line) { var order = getOrder(line); return order ? bidiLeft(order[0]) : 0; }
  function lineRight(line) {
    var order = getOrder(line);
    if (!order) return line.text.length;
    return bidiRight(lst(order));
  }

  function lineStart(cm, lineN) {
    var line = getLine(cm.doc, lineN);
    var visual = visualLine(cm.doc, line);
    if (visual != line) lineN = lineNo(visual);
    var order = getOrder(visual);
    var ch = !order ? 0 : order[0].level % 2 ? lineRight(visual) : lineLeft(visual);
    return Pos(lineN, ch);
  }
  function lineEnd(cm, lineN) {
    var merged, line;
    while (merged = collapsedSpanAtEnd(line = getLine(cm.doc, lineN)))
      lineN = merged.find().to.line;
    var order = getOrder(line);
    var ch = !order ? line.text.length : order[0].level % 2 ? lineLeft(line) : lineRight(line);
    return Pos(lineN, ch);
  }

  function compareBidiLevel(order, a, b) {
    var linedir = order[0].level;
    if (a == linedir) return true;
    if (b == linedir) return false;
    return a < b;
  }
  var bidiOther;
  function getBidiPartAt(order, pos) {
    for (var i = 0, found; i < order.length; ++i) {
      var cur = order[i];
      if (cur.from < pos && cur.to > pos) { bidiOther = null; return i; }
      if (cur.from == pos || cur.to == pos) {
        if (found == null) {
          found = i;
        } else if (compareBidiLevel(order, cur.level, order[found].level)) {
          bidiOther = found;
          return i;
        } else {
          bidiOther = i;
          return found;
        }
      }
    }
    bidiOther = null;
    return found;
  }

  function moveInLine(line, pos, dir, byUnit) {
    if (!byUnit) return pos + dir;
    do pos += dir;
    while (pos > 0 && isExtendingChar.test(line.text.charAt(pos)));
    return pos;
  }

  // This is somewhat involved. It is needed in order to move
  // 'visually' through bi-directional text -- i.e., pressing left
  // should make the cursor go left, even when in RTL text. The
  // tricky part is the 'jumps', where RTL and LTR text touch each
  // other. This often requires the cursor offset to move more than
  // one unit, in order to visually move one unit.
  function moveVisually(line, start, dir, byUnit) {
    var bidi = getOrder(line);
    if (!bidi) return moveLogically(line, start, dir, byUnit);
    var pos = getBidiPartAt(bidi, start), part = bidi[pos];
    var target = moveInLine(line, start, part.level % 2 ? -dir : dir, byUnit);

    for (;;) {
      if (target > part.from && target < part.to) return target;
      if (target == part.from || target == part.to) {
        if (getBidiPartAt(bidi, target) == pos) return target;
        part = bidi[pos += dir];
        return (dir > 0) == part.level % 2 ? part.to : part.from;
      } else {
        part = bidi[pos += dir];
        if (!part) return null;
        if ((dir > 0) == part.level % 2)
          target = moveInLine(line, part.to, -1, byUnit);
        else
          target = moveInLine(line, part.from, 1, byUnit);
      }
    }
  }

  function moveLogically(line, start, dir, byUnit) {
    var target = start + dir;
    if (byUnit) while (target > 0 && isExtendingChar.test(line.text.charAt(target))) target += dir;
    return target < 0 || target > line.text.length ? null : target;
  }

  // Bidirectional ordering algorithm
  // See http://unicode.org/reports/tr9/tr9-13.html for the algorithm
  // that this (partially) implements.

  // One-char codes used for character types:
  // L (L):   Left-to-Right
  // R (R):   Right-to-Left
  // r (AL):  Right-to-Left Arabic
  // 1 (EN):  European Number
  // + (ES):  European Number Separator
  // % (ET):  European Number Terminator
  // n (AN):  Arabic Number
  // , (CS):  Common Number Separator
  // m (NSM): Non-Spacing Mark
  // b (BN):  Boundary Neutral
  // s (B):   Paragraph Separator
  // t (S):   Segment Separator
  // w (WS):  Whitespace
  // N (ON):  Other Neutrals

  // Returns null if characters are ordered as they appear
  // (left-to-right), or an array of sections ({from, to, level}
  // objects) in the order in which they occur visually.
  var bidiOrdering = (function() {
    // Character types for codepoints 0 to 0xff
    var lowTypes = "bbbbbbbbbtstwsbbbbbbbbbbbbbbssstwNN%%%NNNNNN,N,N1111111111NNNNNNNLLLLLLLLLLLLLLLLLLLLLLLLLLNNNNNNLLLLLLLLLLLLLLLLLLLLLLLLLLNNNNbbbbbbsbbbbbbbbbbbbbbbbbbbbbbbbbb,N%%%%NNNNLNNNNN%%11NLNNN1LNNNNNLLLLLLLLLLLLLLLLLLLLLLLNLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLLNLLLLLLLL";
    // Character types for codepoints 0x600 to 0x6ff
    var arabicTypes = "rrrrrrrrrrrr,rNNmmmmmmrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrmmmmmmmmmmmmmmrrrrrrrnnnnnnnnnn%nnrrrmrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrrmmmmmmmmmmmmmmmmmmmNmmmmrrrrrrrrrrrrrrrrrr";
    function charType(code) {
      if (code <= 0xff) return lowTypes.charAt(code);
      else if (0x590 <= code && code <= 0x5f4) return "R";
      else if (0x600 <= code && code <= 0x6ff) return arabicTypes.charAt(code - 0x600);
      else if (0x700 <= code && code <= 0x8ac) return "r";
      else return "L";
    }

    var bidiRE = /[\u0590-\u05f4\u0600-\u06ff\u0700-\u08ac]/;
    var isNeutral = /[stwN]/, isStrong = /[LRr]/, countsAsLeft = /[Lb1n]/, countsAsNum = /[1n]/;
    // Browsers seem to always treat the boundaries of block elements as being L.
    var outerType = "L";

    return function(str) {
      if (!bidiRE.test(str)) return false;
      var len = str.length, types = [];
      for (var i = 0, type; i < len; ++i)
        types.push(type = charType(str.charCodeAt(i)));

      // W1. Examine each non-spacing mark (NSM) in the level run, and
      // change the type of the NSM to the type of the previous
      // character. If the NSM is at the start of the level run, it will
      // get the type of sor.
      for (var i = 0, prev = outerType; i < len; ++i) {
        var type = types[i];
        if (type == "m") types[i] = prev;
        else prev = type;
      }

      // W2. Search backwards from each instance of a European number
      // until the first strong type (R, L, AL, or sor) is found. If an
      // AL is found, change the type of the European number to Arabic
      // number.
      // W3. Change all ALs to R.
      for (var i = 0, cur = outerType; i < len; ++i) {
        var type = types[i];
        if (type == "1" && cur == "r") types[i] = "n";
        else if (isStrong.test(type)) { cur = type; if (type == "r") types[i] = "R"; }
      }

      // W4. A single European separator between two European numbers
      // changes to a European number. A single common separator between
      // two numbers of the same type changes to that type.
      for (var i = 1, prev = types[0]; i < len - 1; ++i) {
        var type = types[i];
        if (type == "+" && prev == "1" && types[i+1] == "1") types[i] = "1";
        else if (type == "," && prev == types[i+1] &&
                 (prev == "1" || prev == "n")) types[i] = prev;
        prev = type;
      }

      // W5. A sequence of European terminators adjacent to European
      // numbers changes to all European numbers.
      // W6. Otherwise, separators and terminators change to Other
      // Neutral.
      for (var i = 0; i < len; ++i) {
        var type = types[i];
        if (type == ",") types[i] = "N";
        else if (type == "%") {
          for (var end = i + 1; end < len && types[end] == "%"; ++end) {}
          var replace = (i && types[i-1] == "!") || (end < len - 1 && types[end] == "1") ? "1" : "N";
          for (var j = i; j < end; ++j) types[j] = replace;
          i = end - 1;
        }
      }

      // W7. Search backwards from each instance of a European number
      // until the first strong type (R, L, or sor) is found. If an L is
      // found, then change the type of the European number to L.
      for (var i = 0, cur = outerType; i < len; ++i) {
        var type = types[i];
        if (cur == "L" && type == "1") types[i] = "L";
        else if (isStrong.test(type)) cur = type;
      }

      // N1. A sequence of neutrals takes the direction of the
      // surrounding strong text if the text on both sides has the same
      // direction. European and Arabic numbers act as if they were R in
      // terms of their influence on neutrals. Start-of-level-run (sor)
      // and end-of-level-run (eor) are used at level run boundaries.
      // N2. Any remaining neutrals take the embedding direction.
      for (var i = 0; i < len; ++i) {
        if (isNeutral.test(types[i])) {
          for (var end = i + 1; end < len && isNeutral.test(types[end]); ++end) {}
          var before = (i ? types[i-1] : outerType) == "L";
          var after = (end < len - 1 ? types[end] : outerType) == "L";
          var replace = before || after ? "L" : "R";
          for (var j = i; j < end; ++j) types[j] = replace;
          i = end - 1;
        }
      }

      // Here we depart from the documented algorithm, in order to avoid
      // building up an actual levels array. Since there are only three
      // levels (0, 1, 2) in an implementation that doesn't take
      // explicit embedding into account, we can build up the order on
      // the fly, without following the level-based algorithm.
      var order = [], m;
      for (var i = 0; i < len;) {
        if (countsAsLeft.test(types[i])) {
          var start = i;
          for (++i; i < len && countsAsLeft.test(types[i]); ++i) {}
          order.push({from: start, to: i, level: 0});
        } else {
          var pos = i, at = order.length;
          for (++i; i < len && types[i] != "L"; ++i) {}
          for (var j = pos; j < i;) {
            if (countsAsNum.test(types[j])) {
              if (pos < j) order.splice(at, 0, {from: pos, to: j, level: 1});
              var nstart = j;
              for (++j; j < i && countsAsNum.test(types[j]); ++j) {}
              order.splice(at, 0, {from: nstart, to: j, level: 2});
              pos = j;
            } else ++j;
          }
          if (pos < i) order.splice(at, 0, {from: pos, to: i, level: 1});
        }
      }
      if (order[0].level == 1 && (m = str.match(/^\s+/))) {
        order[0].from = m[0].length;
        order.unshift({from: 0, to: m[0].length, level: 0});
      }
      if (lst(order).level == 1 && (m = str.match(/\s+$/))) {
        lst(order).to -= m[0].length;
        order.push({from: len - m[0].length, to: len, level: 0});
      }
      if (order[0].level != lst(order).level)
        order.push({from: len, to: len, level: order[0].level});

      return order;
    };
  })();

  // THE END

  CodeMirror.version = "3.15.0";

  return CodeMirror;
})();

// TODO actually recognize syntax of TypeScript constructs

CodeMirror.defineMode("javascript", function(config, parserConfig) {
  var indentUnit = config.indentUnit;
  var statementIndent = parserConfig.statementIndent;
  var jsonMode = parserConfig.json;
  var isTS = parserConfig.typescript;

  // Tokenizer

  var keywords = function(){
    function kw(type) {return {type: type, style: "keyword"};}
    var A = kw("keyword a"), B = kw("keyword b"), C = kw("keyword c");
    var operator = kw("operator"), atom = {type: "atom", style: "atom"};

    var jsKeywords = {
      "if": kw("if"), "while": A, "with": A, "else": B, "do": B, "try": B, "finally": B,
      "return": C, "break": C, "continue": C, "new": C, "delete": C, "throw": C,
      "var": kw("var"), "const": kw("var"), "let": kw("var"),
      "function": kw("function"), "catch": kw("catch"),
      "for": kw("for"), "switch": kw("switch"), "case": kw("case"), "default": kw("default"),
      "in": operator, "typeof": operator, "instanceof": operator,
      "true": atom, "false": atom, "null": atom, "undefined": atom, "NaN": atom, "Infinity": atom,
      "this": kw("this")
    };

    // Extend the 'normal' keywords with the TypeScript language extensions
    if (isTS) {
      var type = {type: "variable", style: "variable-3"};
      var tsKeywords = {
        // object-like things
        "interface": kw("interface"),
        "class": kw("class"),
        "extends": kw("extends"),
        "constructor": kw("constructor"),

        // scope modifiers
        "public": kw("public"),
        "private": kw("private"),
        "protected": kw("protected"),
        "static": kw("static"),

        "super": kw("super"),

        // types
        "string": type, "number": type, "bool": type, "any": type
      };

      for (var attr in tsKeywords) {
        jsKeywords[attr] = tsKeywords[attr];
      }
    }

    return jsKeywords;
  }();

  var isOperatorChar = /[+\-*&%=<>!?|~^]/;

  function chain(stream, state, f) {
    state.tokenize = f;
    return f(stream, state);
  }

  function nextUntilUnescaped(stream, end) {
    var escaped = false, next;
    while ((next = stream.next()) != null) {
      if (next == end && !escaped)
        return false;
      escaped = !escaped && next == "\\";
    }
    return escaped;
  }

  // Used as scratch variables to communicate multiple values without
  // consing up tons of objects.
  var type, content;
  function ret(tp, style, cont) {
    type = tp; content = cont;
    return style;
  }

  function jsTokenBase(stream, state) {
    var ch = stream.next();
    if (ch == '"' || ch == "'")
      return chain(stream, state, jsTokenString(ch));
    else if (/[\[\]{}\(\),;\:\.]/.test(ch))
      return ret(ch);
    else if (ch == "0" && stream.eat(/x/i)) {
      stream.eatWhile(/[\da-f]/i);
      return ret("number", "number");
    }
    else if (/\d/.test(ch) || ch == "-" && stream.eat(/\d/)) {
      stream.match(/^\d*(?:\.\d*)?(?:[eE][+\-]?\d+)?/);
      return ret("number", "number");
    }
    else if (ch == "/") {
      if (stream.eat("*")) {
        return chain(stream, state, jsTokenComment);
      }
      else if (stream.eat("/")) {
        stream.skipToEnd();
        return ret("comment", "comment");
      }
      else if (state.lastType == "operator" || state.lastType == "keyword c" ||
               /^[\[{}\(,;:]$/.test(state.lastType)) {
        nextUntilUnescaped(stream, "/");
        stream.eatWhile(/[gimy]/); // 'y' is "sticky" option in Mozilla
        return ret("regexp", "string-2");
      }
      else {
        stream.eatWhile(isOperatorChar);
        return ret("operator", null, stream.current());
      }
    }
    else if (ch == "#") {
      stream.skipToEnd();
      return ret("error", "error");
    }
    else if (isOperatorChar.test(ch)) {
      stream.eatWhile(isOperatorChar);
      return ret("operator", null, stream.current());
    }
    else {
      stream.eatWhile(/[\w\$_]/);
      var word = stream.current(), known = keywords.propertyIsEnumerable(word) && keywords[word];
      return (known && state.lastType != ".") ? ret(known.type, known.style, word) :
                     ret("variable", "variable", word);
    }
  }

  function jsTokenString(quote) {
    return function(stream, state) {
      if (!nextUntilUnescaped(stream, quote))
        state.tokenize = jsTokenBase;
      return ret("string", "string");
    };
  }

  function jsTokenComment(stream, state) {
    var maybeEnd = false, ch;
    while (ch = stream.next()) {
      if (ch == "/" && maybeEnd) {
        state.tokenize = jsTokenBase;
        break;
      }
      maybeEnd = (ch == "*");
    }
    return ret("comment", "comment");
  }

  // Parser

  var atomicTypes = {"atom": true, "number": true, "variable": true, "string": true, "regexp": true, "this": true};

  function JSLexical(indented, column, type, align, prev, info) {
    this.indented = indented;
    this.column = column;
    this.type = type;
    this.prev = prev;
    this.info = info;
    if (align != null) this.align = align;
  }

  function inScope(state, varname) {
    for (var v = state.localVars; v; v = v.next)
      if (v.name == varname) return true;
  }

  function parseJS(state, style, type, content, stream) {
    var cc = state.cc;
    // Communicate our context to the combinators.
    // (Less wasteful than consing up a hundred closures on every call.)
    cx.state = state; cx.stream = stream; cx.marked = null, cx.cc = cc;

    if (!state.lexical.hasOwnProperty("align"))
      state.lexical.align = true;

    while(true) {
      var combinator = cc.length ? cc.pop() : jsonMode ? expression : statement;
      if (combinator(type, content)) {
        while(cc.length && cc[cc.length - 1].lex)
          cc.pop()();
        if (cx.marked) return cx.marked;
        if (type == "variable" && inScope(state, content)) return "variable-2";
        return style;
      }
    }
  }

  // Combinator utils

  var cx = {state: null, column: null, marked: null, cc: null};
  function pass() {
    for (var i = arguments.length - 1; i >= 0; i--) cx.cc.push(arguments[i]);
  }
  function cont() {
    pass.apply(null, arguments);
    return true;
  }
  function register(varname) {
    function inList(list) {
      for (var v = list; v; v = v.next)
        if (v.name == varname) return true;
      return false;
    }
    var state = cx.state;
    if (state.context) {
      cx.marked = "def";
      if (inList(state.localVars)) return;
      state.localVars = {name: varname, next: state.localVars};
    } else {
      if (inList(state.globalVars)) return;
      state.globalVars = {name: varname, next: state.globalVars};
    }
  }

  // Combinators

  var defaultVars = {name: "this", next: {name: "arguments"}};
  function pushcontext() {
    cx.state.context = {prev: cx.state.context, vars: cx.state.localVars};
    cx.state.localVars = defaultVars;
  }
  function popcontext() {
    cx.state.localVars = cx.state.context.vars;
    cx.state.context = cx.state.context.prev;
  }
  function pushlex(type, info) {
    var result = function() {
      var state = cx.state, indent = state.indented;
      if (state.lexical.type == "stat") indent = state.lexical.indented;
      state.lexical = new JSLexical(indent, cx.stream.column(), type, null, state.lexical, info);
    };
    result.lex = true;
    return result;
  }
  function poplex() {
    var state = cx.state;
    if (state.lexical.prev) {
      if (state.lexical.type == ")")
        state.indented = state.lexical.indented;
      state.lexical = state.lexical.prev;
    }
  }
  poplex.lex = true;

  function expect(wanted) {
    return function(type) {
      if (type == wanted) return cont();
      else if (wanted == ";") return pass();
      else return cont(arguments.callee);
    };
  }

  function statement(type) {
    if (type == "var") return cont(pushlex("vardef"), vardef1, expect(";"), poplex);
    if (type == "keyword a") return cont(pushlex("form"), expression, statement, poplex);
    if (type == "keyword b") return cont(pushlex("form"), statement, poplex);
    if (type == "{") return cont(pushlex("}"), block, poplex);
    if (type == ";") return cont();
    if (type == "if") return cont(pushlex("form"), expression, statement, poplex, maybeelse);
    if (type == "function") return cont(functiondef);
    if (type == "for") return cont(pushlex("form"), expect("("), pushlex(")"), forspec1, expect(")"),
                                   poplex, statement, poplex);
    if (type == "variable") return cont(pushlex("stat"), maybelabel);
    if (type == "switch") return cont(pushlex("form"), expression, pushlex("}", "switch"), expect("{"),
                                      block, poplex, poplex);
    if (type == "case") return cont(expression, expect(":"));
    if (type == "default") return cont(expect(":"));
    if (type == "catch") return cont(pushlex("form"), pushcontext, expect("("), funarg, expect(")"),
                                     statement, poplex, popcontext);
    return pass(pushlex("stat"), expression, expect(";"), poplex);
  }
  function expression(type) {
    return expressionInner(type, false);
  }
  function expressionNoComma(type) {
    return expressionInner(type, true);
  }
  function expressionInner(type, noComma) {
    var maybeop = noComma ? maybeoperatorNoComma : maybeoperatorComma;
    if (atomicTypes.hasOwnProperty(type)) return cont(maybeop);
    if (type == "function") return cont(functiondef);
    if (type == "keyword c") return cont(noComma ? maybeexpressionNoComma : maybeexpression);
    if (type == "(") return cont(pushlex(")"), maybeexpression, expect(")"), poplex, maybeop);
    if (type == "operator") return cont(noComma ? expressionNoComma : expression);
    if (type == "[") return cont(pushlex("]"), commasep(expressionNoComma, "]"), poplex, maybeop);
    if (type == "{") return cont(pushlex("}"), commasep(objprop, "}"), poplex, maybeop);
    return cont();
  }
  function maybeexpression(type) {
    if (type.match(/[;\}\)\],]/)) return pass();
    return pass(expression);
  }
  function maybeexpressionNoComma(type) {
    if (type.match(/[;\}\)\],]/)) return pass();
    return pass(expressionNoComma);
  }

  function maybeoperatorComma(type, value) {
    if (type == ",") return cont(expression);
    return maybeoperatorNoComma(type, value, false);
  }
  function maybeoperatorNoComma(type, value, noComma) {
    var me = noComma == false ? maybeoperatorComma : maybeoperatorNoComma;
    var expr = noComma == false ? expression : expressionNoComma;
    if (type == "operator") {
      if (/\+\+|--/.test(value)) return cont(me);
      if (value == "?") return cont(expression, expect(":"), expr);
      return cont(expr);
    }
    if (type == ";") return;
    if (type == "(") return cont(pushlex(")", "call"), commasep(expressionNoComma, ")"), poplex, me);
    if (type == ".") return cont(property, me);
    if (type == "[") return cont(pushlex("]"), maybeexpression, expect("]"), poplex, me);
  }
  function maybelabel(type) {
    if (type == ":") return cont(poplex, statement);
    return pass(maybeoperatorComma, expect(";"), poplex);
  }
  function property(type) {
    if (type == "variable") {cx.marked = "property"; return cont();}
  }
  function objprop(type, value) {
    if (type == "variable") {
      cx.marked = "property";
      if (value == "get" || value == "set") return cont(getterSetter);
    } else if (type == "number" || type == "string") {
      cx.marked = type + " property";
    }
    if (atomicTypes.hasOwnProperty(type)) return cont(expect(":"), expressionNoComma);
  }
  function getterSetter(type) {
    if (type == ":") return cont(expression);
    if (type != "variable") return cont(expect(":"), expression);
    cx.marked = "property";
    return cont(functiondef);
  }
  function commasep(what, end) {
    function proceed(type) {
      if (type == ",") {
        var lex = cx.state.lexical;
        if (lex.info == "call") lex.pos = (lex.pos || 0) + 1;
        return cont(what, proceed);
      }
      if (type == end) return cont();
      return cont(expect(end));
    }
    return function(type) {
      if (type == end) return cont();
      else return pass(what, proceed);
    };
  }
  function block(type) {
    if (type == "}") return cont();
    return pass(statement, block);
  }
  function maybetype(type) {
    if (type == ":") return cont(typedef);
    return pass();
  }
  function typedef(type) {
    if (type == "variable"){cx.marked = "variable-3"; return cont();}
    return pass();
  }
  function vardef1(type, value) {
    if (type == "variable") {
      register(value);
      return isTS ? cont(maybetype, vardef2) : cont(vardef2);
    }
    return pass();
  }
  function vardef2(type, value) {
    if (value == "=") return cont(expressionNoComma, vardef2);
    if (type == ",") return cont(vardef1);
  }
  function maybeelse(type, value) {
    if (type == "keyword b" && value == "else") return cont(pushlex("form"), statement, poplex);
  }
  function forspec1(type) {
    if (type == "var") return cont(vardef1, expect(";"), forspec2);
    if (type == ";") return cont(forspec2);
    if (type == "variable") return cont(formaybein);
    return pass(expression, expect(";"), forspec2);
  }
  function formaybein(_type, value) {
    if (value == "in") return cont(expression);
    return cont(maybeoperatorComma, forspec2);
  }
  function forspec2(type, value) {
    if (type == ";") return cont(forspec3);
    if (value == "in") return cont(expression);
    return pass(expression, expect(";"), forspec3);
  }
  function forspec3(type) {
    if (type != ")") cont(expression);
  }
  function functiondef(type, value) {
    if (type == "variable") {register(value); return cont(functiondef);}
    if (type == "(") return cont(pushlex(")"), pushcontext, commasep(funarg, ")"), poplex, statement, popcontext);
  }
  function funarg(type, value) {
    if (type == "variable") {register(value); return isTS ? cont(maybetype) : cont();}
  }

  // Interface

  return {
    startState: function(basecolumn) {
      return {
        tokenize: jsTokenBase,
        lastType: null,
        cc: [],
        lexical: new JSLexical((basecolumn || 0) - indentUnit, 0, "block", false),
        localVars: parserConfig.localVars,
        globalVars: parserConfig.globalVars,
        context: parserConfig.localVars && {vars: parserConfig.localVars},
        indented: 0
      };
    },

    token: function(stream, state) {
      if (stream.sol()) {
        if (!state.lexical.hasOwnProperty("align"))
          state.lexical.align = false;
        state.indented = stream.indentation();
      }
      if (state.tokenize != jsTokenComment && stream.eatSpace()) return null;
      var style = state.tokenize(stream, state);
      if (type == "comment") return style;
      state.lastType = type == "operator" && (content == "++" || content == "--") ? "incdec" : type;
      return parseJS(state, style, type, content, stream);
    },

    indent: function(state, textAfter) {
      if (state.tokenize == jsTokenComment) return CodeMirror.Pass;
      if (state.tokenize != jsTokenBase) return 0;
      var firstChar = textAfter && textAfter.charAt(0), lexical = state.lexical;
      // Kludge to prevent 'maybelse' from blocking lexical scope pops
      for (var i = state.cc.length - 1; i >= 0; --i) {
        var c = state.cc[i];
        if (c == poplex) lexical = lexical.prev;
        else if (c != maybeelse || /^else\b/.test(textAfter)) break;
      }
      if (lexical.type == "stat" && firstChar == "}") lexical = lexical.prev;
      if (statementIndent && lexical.type == ")" && lexical.prev.type == "stat")
        lexical = lexical.prev;
      var type = lexical.type, closing = firstChar == type;

      if (type == "vardef") return lexical.indented + (state.lastType == "operator" || state.lastType == "," ? 4 : 0);
      else if (type == "form" && firstChar == "{") return lexical.indented;
      else if (type == "form") return lexical.indented + indentUnit;
      else if (type == "stat")
        return lexical.indented + (state.lastType == "operator" || state.lastType == "," ? statementIndent || indentUnit : 0);
      else if (lexical.info == "switch" && !closing && parserConfig.doubleIndentSwitch != false)
        return lexical.indented + (/^(?:case|default)\b/.test(textAfter) ? indentUnit : 2 * indentUnit);
      else if (lexical.align) return lexical.column + (closing ? 0 : 1);
      else return lexical.indented + (closing ? 0 : indentUnit);
    },

    electricChars: ":{}",
    blockCommentStart: jsonMode ? null : "/*",
    blockCommentEnd: jsonMode ? null : "*/",
    lineComment: jsonMode ? null : "//",
    fold: "brace",

    helperType: jsonMode ? "json" : "javascript",
    jsonMode: jsonMode
  };
});

CodeMirror.defineMIME("text/javascript", "javascript");
CodeMirror.defineMIME("text/ecmascript", "javascript");
CodeMirror.defineMIME("application/javascript", "javascript");
CodeMirror.defineMIME("application/ecmascript", "javascript");
CodeMirror.defineMIME("application/json", {name: "javascript", json: true});
CodeMirror.defineMIME("application/x-json", {name: "javascript", json: true});
CodeMirror.defineMIME("text/typescript", { name: "javascript", typescript: true });
CodeMirror.defineMIME("application/typescript", { name: "javascript", typescript: true });

CodeMirror.defineMode("xml", function(config, parserConfig) {
  var indentUnit = config.indentUnit;
  var multilineTagIndentFactor = parserConfig.multilineTagIndentFactor || 1;
  var multilineTagIndentPastTag = parserConfig.multilineTagIndentPastTag || true;

  var Kludges = parserConfig.htmlMode ? {
    autoSelfClosers: {'area': true, 'base': true, 'br': true, 'col': true, 'command': true,
                      'embed': true, 'frame': true, 'hr': true, 'img': true, 'input': true,
                      'keygen': true, 'link': true, 'meta': true, 'param': true, 'source': true,
                      'track': true, 'wbr': true},
    implicitlyClosed: {'dd': true, 'li': true, 'optgroup': true, 'option': true, 'p': true,
                       'rp': true, 'rt': true, 'tbody': true, 'td': true, 'tfoot': true,
                       'th': true, 'tr': true},
    contextGrabbers: {
      'dd': {'dd': true, 'dt': true},
      'dt': {'dd': true, 'dt': true},
      'li': {'li': true},
      'option': {'option': true, 'optgroup': true},
      'optgroup': {'optgroup': true},
      'p': {'address': true, 'article': true, 'aside': true, 'blockquote': true, 'dir': true,
            'div': true, 'dl': true, 'fieldset': true, 'footer': true, 'form': true,
            'h1': true, 'h2': true, 'h3': true, 'h4': true, 'h5': true, 'h6': true,
            'header': true, 'hgroup': true, 'hr': true, 'menu': true, 'nav': true, 'ol': true,
            'p': true, 'pre': true, 'section': true, 'table': true, 'ul': true},
      'rp': {'rp': true, 'rt': true},
      'rt': {'rp': true, 'rt': true},
      'tbody': {'tbody': true, 'tfoot': true},
      'td': {'td': true, 'th': true},
      'tfoot': {'tbody': true},
      'th': {'td': true, 'th': true},
      'thead': {'tbody': true, 'tfoot': true},
      'tr': {'tr': true}
    },
    doNotIndent: {"pre": true},
    allowUnquoted: true,
    allowMissing: true
  } : {
    autoSelfClosers: {},
    implicitlyClosed: {},
    contextGrabbers: {},
    doNotIndent: {},
    allowUnquoted: false,
    allowMissing: false
  };
  var alignCDATA = parserConfig.alignCDATA;

  // Return variables for tokenizers
  var tagName, type;

  function inText(stream, state) {
    function chain(parser) {
      state.tokenize = parser;
      return parser(stream, state);
    }

    var ch = stream.next();
    if (ch == "<") {
      if (stream.eat("!")) {
        if (stream.eat("[")) {
          if (stream.match("CDATA[")) return chain(inBlock("atom", "]]>"));
          else return null;
        } else if (stream.match("--")) {
          return chain(inBlock("comment", "-->"));
        } else if (stream.match("DOCTYPE", true, true)) {
          stream.eatWhile(/[\w\._\-]/);
          return chain(doctype(1));
        } else {
          return null;
        }
      } else if (stream.eat("?")) {
        stream.eatWhile(/[\w\._\-]/);
        state.tokenize = inBlock("meta", "?>");
        return "meta";
      } else {
        var isClose = stream.eat("/");
        tagName = "";
        var c;
        while ((c = stream.eat(/[^\s\u00a0=<>\"\'\/?]/))) tagName += c;
        if (!tagName) return "error";
        type = isClose ? "closeTag" : "openTag";
        state.tokenize = inTag;
        return "tag";
      }
    } else if (ch == "&") {
      var ok;
      if (stream.eat("#")) {
        if (stream.eat("x")) {
          ok = stream.eatWhile(/[a-fA-F\d]/) && stream.eat(";");
        } else {
          ok = stream.eatWhile(/[\d]/) && stream.eat(";");
        }
      } else {
        ok = stream.eatWhile(/[\w\.\-:]/) && stream.eat(";");
      }
      return ok ? "atom" : "error";
    } else {
      stream.eatWhile(/[^&<]/);
      return null;
    }
  }

  function inTag(stream, state) {
    var ch = stream.next();
    if (ch == ">" || (ch == "/" && stream.eat(">"))) {
      state.tokenize = inText;
      type = ch == ">" ? "endTag" : "selfcloseTag";
      return "tag";
    } else if (ch == "=") {
      type = "equals";
      return null;
    } else if (ch == "<") {
      return "error";
    } else if (/[\'\"]/.test(ch)) {
      state.tokenize = inAttribute(ch);
      state.stringStartCol = stream.column();
      return state.tokenize(stream, state);
    } else {
      stream.eatWhile(/[^\s\u00a0=<>\"\']/);
      return "word";
    }
  }

  function inAttribute(quote) {
    var closure = function(stream, state) {
      while (!stream.eol()) {
        if (stream.next() == quote) {
          state.tokenize = inTag;
          break;
        }
      }
      return "string";
    };
    closure.isInAttribute = true;
    return closure;
  }

  function inBlock(style, terminator) {
    return function(stream, state) {
      while (!stream.eol()) {
        if (stream.match(terminator)) {
          state.tokenize = inText;
          break;
        }
        stream.next();
      }
      return style;
    };
  }
  function doctype(depth) {
    return function(stream, state) {
      var ch;
      while ((ch = stream.next()) != null) {
        if (ch == "<") {
          state.tokenize = doctype(depth + 1);
          return state.tokenize(stream, state);
        } else if (ch == ">") {
          if (depth == 1) {
            state.tokenize = inText;
            break;
          } else {
            state.tokenize = doctype(depth - 1);
            return state.tokenize(stream, state);
          }
        }
      }
      return "meta";
    };
  }

  var curState, curStream, setStyle;
  function pass() {
    for (var i = arguments.length - 1; i >= 0; i--) curState.cc.push(arguments[i]);
  }
  function cont() {
    pass.apply(null, arguments);
    return true;
  }

  function pushContext(tagName, startOfLine) {
    var noIndent = Kludges.doNotIndent.hasOwnProperty(tagName) || (curState.context && curState.context.noIndent);
    curState.context = {
      prev: curState.context,
      tagName: tagName,
      indent: curState.indented,
      startOfLine: startOfLine,
      noIndent: noIndent
    };
  }
  function popContext() {
    if (curState.context) curState.context = curState.context.prev;
  }

  function element(type) {
    if (type == "openTag") {
      curState.tagName = tagName;
      curState.tagStart = curStream.column();
      return cont(attributes, endtag(curState.startOfLine));
    } else if (type == "closeTag") {
      var err = false;
      if (curState.context) {
        if (curState.context.tagName != tagName) {
          if (Kludges.implicitlyClosed.hasOwnProperty(curState.context.tagName.toLowerCase())) {
            popContext();
          }
          err = !curState.context || curState.context.tagName != tagName;
        }
      } else {
        err = true;
      }
      if (err) setStyle = "error";
      return cont(endclosetag(err));
    }
    return cont();
  }
  function endtag(startOfLine) {
    return function(type) {
      var tagName = curState.tagName;
      curState.tagName = curState.tagStart = null;
      if (type == "selfcloseTag" ||
          (type == "endTag" && Kludges.autoSelfClosers.hasOwnProperty(tagName.toLowerCase()))) {
        maybePopContext(tagName.toLowerCase());
        return cont();
      }
      if (type == "endTag") {
        maybePopContext(tagName.toLowerCase());
        pushContext(tagName, startOfLine);
        return cont();
      }
      return cont();
    };
  }
  function endclosetag(err) {
    return function(type) {
      if (err) setStyle = "error";
      if (type == "endTag") { popContext(); return cont(); }
      setStyle = "error";
      return cont(arguments.callee);
    };
  }
  function maybePopContext(nextTagName) {
    var parentTagName;
    while (true) {
      if (!curState.context) {
        return;
      }
      parentTagName = curState.context.tagName.toLowerCase();
      if (!Kludges.contextGrabbers.hasOwnProperty(parentTagName) ||
          !Kludges.contextGrabbers[parentTagName].hasOwnProperty(nextTagName)) {
        return;
      }
      popContext();
    }
  }

  function attributes(type) {
    if (type == "word") {setStyle = "attribute"; return cont(attribute, attributes);}
    if (type == "endTag" || type == "selfcloseTag") return pass();
    setStyle = "error";
    return cont(attributes);
  }
  function attribute(type) {
    if (type == "equals") return cont(attvalue, attributes);
    if (!Kludges.allowMissing) setStyle = "error";
    else if (type == "word") setStyle = "attribute";
    return (type == "endTag" || type == "selfcloseTag") ? pass() : cont();
  }
  function attvalue(type) {
    if (type == "string") return cont(attvaluemaybe);
    if (type == "word" && Kludges.allowUnquoted) {setStyle = "string"; return cont();}
    setStyle = "error";
    return (type == "endTag" || type == "selfCloseTag") ? pass() : cont();
  }
  function attvaluemaybe(type) {
    if (type == "string") return cont(attvaluemaybe);
    else return pass();
  }

  return {
    startState: function() {
      return {tokenize: inText, cc: [], indented: 0, startOfLine: true, tagName: null, tagStart: null, context: null};
    },

    token: function(stream, state) {
      if (!state.tagName && stream.sol()) {
        state.startOfLine = true;
        state.indented = stream.indentation();
      }
      if (stream.eatSpace()) return null;

      setStyle = type = tagName = null;
      var style = state.tokenize(stream, state);
      state.type = type;
      if ((style || type) && style != "comment") {
        curState = state; curStream = stream;
        while (true) {
          var comb = state.cc.pop() || element;
          if (comb(type || style)) break;
        }
      }
      state.startOfLine = false;
      return setStyle || style;
    },

    indent: function(state, textAfter, fullLine) {
      var context = state.context;
      // Indent multi-line strings (e.g. css).
      if (state.tokenize.isInAttribute) {
        return state.stringStartCol + 1;
      }
      if ((state.tokenize != inTag && state.tokenize != inText) ||
          context && context.noIndent)
        return fullLine ? fullLine.match(/^(\s*)/)[0].length : 0;
      // Indent the starts of attribute names.
      if (state.tagName) {
        if (multilineTagIndentPastTag)
          return state.tagStart + state.tagName.length + 2;
        else
          return state.tagStart + indentUnit * multilineTagIndentFactor;
      }
      if (alignCDATA && /<!\[CDATA\[/.test(textAfter)) return 0;
      if (context && /^<\//.test(textAfter))
        context = context.prev;
      while (context && !context.startOfLine)
        context = context.prev;
      if (context) return context.indent + indentUnit;
      else return 0;
    },

    electricChars: "/",
    blockCommentStart: "<!--",
    blockCommentEnd: "-->",

    configuration: parserConfig.htmlMode ? "html" : "xml",
    helperType: parserConfig.htmlMode ? "html" : "xml"
  };
});

CodeMirror.defineMIME("text/xml", "xml");
CodeMirror.defineMIME("application/xml", "xml");
if (!CodeMirror.mimeModes.hasOwnProperty("text/html"))
  CodeMirror.defineMIME("text/html", {name: "xml", htmlMode: true});

CodeMirror.defineMode("yaml", function() {

  var cons = ['true', 'false', 'on', 'off', 'yes', 'no'];
  var keywordRegex = new RegExp("\\b(("+cons.join(")|(")+"))$", 'i');

  return {
    token: function(stream, state) {
      var ch = stream.peek();
      var esc = state.escaped;
      state.escaped = false;
      /* comments */
      if (ch == "#" && (stream.pos == 0 || /\s/.test(stream.string.charAt(stream.pos - 1)))) {
        stream.skipToEnd(); return "comment";
      }
      if (state.literal && stream.indentation() > state.keyCol) {
        stream.skipToEnd(); return "string";
      } else if (state.literal) { state.literal = false; }
      if (stream.sol()) {
        state.keyCol = 0;
        state.pair = false;
        state.pairStart = false;
        /* document start */
        if(stream.match(/---/)) { return "def"; }
        /* document end */
        if (stream.match(/\.\.\./)) { return "def"; }
        /* array list item */
        if (stream.match(/\s*-\s+/)) { return 'meta'; }
      }
      /* pairs (associative arrays) -> key */
      if (!state.pair && stream.match(/^\s*([a-z0-9\._-])+(?=\s*:)/i)) {
        state.pair = true;
        state.keyCol = stream.indentation();
        return "atom";
      }
      if (state.pair && stream.match(/^:\s*/)) { state.pairStart = true; return 'meta'; }

      /* inline pairs/lists */
      if (stream.match(/^(\{|\}|\[|\])/)) {
        if (ch == '{')
          state.inlinePairs++;
        else if (ch == '}')
          state.inlinePairs--;
        else if (ch == '[')
          state.inlineList++;
        else
          state.inlineList--;
        return 'meta';
      }

      /* list seperator */
      if (state.inlineList > 0 && !esc && ch == ',') {
        stream.next();
        return 'meta';
      }
      /* pairs seperator */
      if (state.inlinePairs > 0 && !esc && ch == ',') {
        state.keyCol = 0;
        state.pair = false;
        state.pairStart = false;
        stream.next();
        return 'meta';
      }

      /* start of value of a pair */
      if (state.pairStart) {
        /* block literals */
        if (stream.match(/^\s*(\||\>)\s*/)) { state.literal = true; return 'meta'; };
        /* references */
        if (stream.match(/^\s*(\&|\*)[a-z0-9\._-]+\b/i)) { return 'variable-2'; }
        /* numbers */
        if (state.inlinePairs == 0 && stream.match(/^\s*-?[0-9\.\,]+\s?$/)) { return 'number'; }
        if (state.inlinePairs > 0 && stream.match(/^\s*-?[0-9\.\,]+\s?(?=(,|}))/)) { return 'number'; }
        /* keywords */
        if (stream.match(keywordRegex)) { return 'keyword'; }
      }

      /* nothing found, continue */
      state.pairStart = false;
      state.escaped = (ch == '\\');
      stream.next();
      return null;
    },
    startState: function() {
      return {
        pair: false,
        pairStart: false,
        keyCol: 0,
        inlinePairs: 0,
        inlineList: 0,
        literal: false,
        escaped: false
      };
    }
  };
});

CodeMirror.defineMIME("text/x-yaml", "yaml");

// Open simple dialogs on top of an editor. Relies on dialog.css.

(function() {
  function dialogDiv(cm, template, bottom) {
    var wrap = cm.getWrapperElement();
    var dialog;
    dialog = wrap.appendChild(document.createElement("div"));
    if (bottom) {
      dialog.className = "CodeMirror-dialog CodeMirror-dialog-bottom";
    } else {
      dialog.className = "CodeMirror-dialog CodeMirror-dialog-top";
    }
    dialog.innerHTML = template;
    return dialog;
  }

  CodeMirror.defineExtension("openDialog", function(template, callback, options) {
    var dialog = dialogDiv(this, template, options && options.bottom);
    var closed = false, me = this;
    function close() {
      if (closed) return;
      closed = true;
      dialog.parentNode.removeChild(dialog);
    }
    var inp = dialog.getElementsByTagName("input")[0], button;
    if (inp) {
      CodeMirror.on(inp, "keydown", function(e) {
        if (options && options.onKeyDown && options.onKeyDown(e, inp.value, close)) { return; }
        if (e.keyCode == 13 || e.keyCode == 27) {
          CodeMirror.e_stop(e);
          close();
          me.focus();
          if (e.keyCode == 13) callback(inp.value);
        }
      });
      if (options && options.onKeyUp) {
        CodeMirror.on(inp, "keyup", function(e) {options.onKeyUp(e, inp.value, close);});
      }
      if (options && options.value) inp.value = options.value;
      inp.focus();
      CodeMirror.on(inp, "blur", close);
    } else if (button = dialog.getElementsByTagName("button")[0]) {
      CodeMirror.on(button, "click", function() {
        close();
        me.focus();
      });
      button.focus();
      CodeMirror.on(button, "blur", close);
    }
    return close;
  });

  CodeMirror.defineExtension("openConfirm", function(template, callbacks, options) {
    var dialog = dialogDiv(this, template, options && options.bottom);
    var buttons = dialog.getElementsByTagName("button");
    var closed = false, me = this, blurring = 1;
    function close() {
      if (closed) return;
      closed = true;
      dialog.parentNode.removeChild(dialog);
      me.focus();
    }
    buttons[0].focus();
    for (var i = 0; i < buttons.length; ++i) {
      var b = buttons[i];
      (function(callback) {
        CodeMirror.on(b, "click", function(e) {
          CodeMirror.e_preventDefault(e);
          close();
          if (callback) callback(me);
        });
      })(callbacks[i]);
      CodeMirror.on(b, "blur", function() {
        --blurring;
        setTimeout(function() { if (blurring <= 0) close(); }, 200);
      });
      CodeMirror.on(b, "focus", function() { ++blurring; });
    }
  });
})();

// Define search commands. Depends on dialog.js or another
// implementation of the openDialog method.

// Replace works a little oddly -- it will do the replace on the next
// Ctrl-G (or whatever is bound to findNext) press. You prevent a
// replace by making sure the match is no longer selected when hitting
// Ctrl-G.

(function() {
  function searchOverlay(query) {
    if (typeof query == "string") return {token: function(stream) {
      if (stream.match(query)) return "searching";
      stream.next();
      stream.skipTo(query.charAt(0)) || stream.skipToEnd();
    }};
    return {token: function(stream) {
      if (stream.match(query)) return "searching";
      while (!stream.eol()) {
        stream.next();
        if (stream.match(query, false)) break;
      }
    }};
  }

  function SearchState() {
    this.posFrom = this.posTo = this.query = null;
    this.overlay = null;
  }
  function getSearchState(cm) {
    return cm.state.search || (cm.state.search = new SearchState());
  }
  function getSearchCursor(cm, query, pos) {
    // Heuristic: if the query string is all lowercase, do a case insensitive search.
    return cm.getSearchCursor(query, pos, typeof query == "string" && query == query.toLowerCase());
  }
  function dialog(cm, text, shortText, f) {
    if (cm.openDialog) cm.openDialog(text, f);
    else f(prompt(shortText, ""));
  }
  function confirmDialog(cm, text, shortText, fs) {
    if (cm.openConfirm) cm.openConfirm(text, fs);
    else if (confirm(shortText)) fs[0]();
  }
  function parseQuery(query) {
    var isRE = query.match(/^\/(.*)\/([a-z]*)$/);
    return isRE ? new RegExp(isRE[1], isRE[2].indexOf("i") == -1 ? "" : "i") : query;
  }
  var queryDialog =
    'Search: <input type="text" style="width: 10em"/> <span style="color: #888">(Use /re/ syntax for regexp search)</span>';
  function doSearch(cm, rev) {
    var state = getSearchState(cm);
    if (state.query) return findNext(cm, rev);
    dialog(cm, queryDialog, "Search for:", function(query) {
      cm.operation(function() {
        if (!query || state.query) return;
        state.query = parseQuery(query);
        cm.removeOverlay(state.overlay);
        state.overlay = searchOverlay(state.query);
        cm.addOverlay(state.overlay);
        state.posFrom = state.posTo = cm.getCursor();
        findNext(cm, rev);
      });
    });
  }
  function findNext(cm, rev) {cm.operation(function() {
    var state = getSearchState(cm);
    var cursor = getSearchCursor(cm, state.query, rev ? state.posFrom : state.posTo);
    if (!cursor.find(rev)) {
      cursor = getSearchCursor(cm, state.query, rev ? CodeMirror.Pos(cm.lastLine()) : CodeMirror.Pos(cm.firstLine(), 0));
      if (!cursor.find(rev)) return;
    }
    cm.setSelection(cursor.from(), cursor.to());
    state.posFrom = cursor.from(); state.posTo = cursor.to();
  });}
  function clearSearch(cm) {cm.operation(function() {
    var state = getSearchState(cm);
    if (!state.query) return;
    state.query = null;
    cm.removeOverlay(state.overlay);
  });}

  var replaceQueryDialog =
    'Replace: <input type="text" style="width: 10em"/> <span style="color: #888">(Use /re/ syntax for regexp search)</span>';
  var replacementQueryDialog = 'With: <input type="text" style="width: 10em"/>';
  var doReplaceConfirm = "Replace? <button>Yes</button> <button>No</button> <button>Stop</button>";
  function replace(cm, all) {
    dialog(cm, replaceQueryDialog, "Replace:", function(query) {
      if (!query) return;
      query = parseQuery(query);
      dialog(cm, replacementQueryDialog, "Replace with:", function(text) {
        if (all) {
          cm.operation(function() {
            for (var cursor = getSearchCursor(cm, query); cursor.findNext();) {
              if (typeof query != "string") {
                var match = cm.getRange(cursor.from(), cursor.to()).match(query);
                cursor.replace(text.replace(/\$(\d)/, function(_, i) {return match[i];}));
              } else cursor.replace(text);
            }
          });
        } else {
          clearSearch(cm);
          var cursor = getSearchCursor(cm, query, cm.getCursor());
          var advance = function() {
            var start = cursor.from(), match;
            if (!(match = cursor.findNext())) {
              cursor = getSearchCursor(cm, query);
              if (!(match = cursor.findNext()) ||
                  (start && cursor.from().line == start.line && cursor.from().ch == start.ch)) return;
            }
            cm.setSelection(cursor.from(), cursor.to());
            confirmDialog(cm, doReplaceConfirm, "Replace?",
                          [function() {doReplace(match);}, advance]);
          };
          var doReplace = function(match) {
            cursor.replace(typeof query == "string" ? text :
                           text.replace(/\$(\d)/, function(_, i) {return match[i];}));
            advance();
          };
          advance();
        }
      });
    });
  }

  CodeMirror.commands.find = function(cm) {clearSearch(cm); doSearch(cm);};
  CodeMirror.commands.findNext = doSearch;
  CodeMirror.commands.findPrev = function(cm) {doSearch(cm, true);};
  CodeMirror.commands.clearSearch = clearSearch;
  CodeMirror.commands.replace = replace;
  CodeMirror.commands.replaceAll = function(cm) {replace(cm, true);};
})();

(function(){
  var Pos = CodeMirror.Pos;

  function SearchCursor(doc, query, pos, caseFold) {
    this.atOccurrence = false; this.doc = doc;
    if (caseFold == null && typeof query == "string") caseFold = false;

    pos = pos ? doc.clipPos(pos) : Pos(0, 0);
    this.pos = {from: pos, to: pos};

    // The matches method is filled in based on the type of query.
    // It takes a position and a direction, and returns an object
    // describing the next occurrence of the query, or null if no
    // more matches were found.
    if (typeof query != "string") { // Regexp match
      if (!query.global) query = new RegExp(query.source, query.ignoreCase ? "ig" : "g");
      this.matches = function(reverse, pos) {
        if (reverse) {
          query.lastIndex = 0;
          var line = doc.getLine(pos.line).slice(0, pos.ch), cutOff = 0, match, start;
          for (;;) {
            query.lastIndex = cutOff;
            var newMatch = query.exec(line);
            if (!newMatch) break;
            match = newMatch;
            start = match.index;
            cutOff = match.index + (match[0].length || 1);
            if (cutOff == line.length) break;
          }
          var matchLen = (match && match[0].length) || 0;
          if (!matchLen) {
            if (start == 0 && line.length == 0) {match = undefined;}
            else if (start != doc.getLine(pos.line).length) {
              matchLen++;
            }
          }
        } else {
          query.lastIndex = pos.ch;
          var line = doc.getLine(pos.line), match = query.exec(line);
          var matchLen = (match && match[0].length) || 0;
          var start = match && match.index;
          if (start + matchLen != line.length && !matchLen) matchLen = 1;
        }
        if (match && matchLen)
          return {from: Pos(pos.line, start),
                  to: Pos(pos.line, start + matchLen),
                  match: match};
      };
    } else { // String query
      if (caseFold) query = query.toLowerCase();
      var fold = caseFold ? function(str){return str.toLowerCase();} : function(str){return str;};
      var target = query.split("\n");
      // Different methods for single-line and multi-line queries
      if (target.length == 1) {
        if (!query.length) {
          // Empty string would match anything and never progress, so
          // we define it to match nothing instead.
          this.matches = function() {};
        } else {
          this.matches = function(reverse, pos) {
            var line = fold(doc.getLine(pos.line)), len = query.length, match;
            if (reverse ? (pos.ch >= len && (match = line.lastIndexOf(query, pos.ch - len)) != -1)
                        : (match = line.indexOf(query, pos.ch)) != -1)
              return {from: Pos(pos.line, match),
                      to: Pos(pos.line, match + len)};
          };
        }
      } else {
        this.matches = function(reverse, pos) {
          var ln = pos.line, idx = (reverse ? target.length - 1 : 0), match = target[idx], line = fold(doc.getLine(ln));
          var offsetA = (reverse ? line.indexOf(match) + match.length : line.lastIndexOf(match));
          if (reverse ? offsetA >= pos.ch || offsetA != match.length
              : offsetA <= pos.ch || offsetA != line.length - match.length)
            return;
          for (;;) {
            if (reverse ? !ln : ln == doc.lineCount() - 1) return;
            line = fold(doc.getLine(ln += reverse ? -1 : 1));
            match = target[reverse ? --idx : ++idx];
            if (idx > 0 && idx < target.length - 1) {
              if (line != match) return;
              else continue;
            }
            var offsetB = (reverse ? line.lastIndexOf(match) : line.indexOf(match) + match.length);
            if (reverse ? offsetB != line.length - match.length : offsetB != match.length)
              return;
            var start = Pos(pos.line, offsetA), end = Pos(ln, offsetB);
            return {from: reverse ? end : start, to: reverse ? start : end};
          }
        };
      }
    }
  }

  SearchCursor.prototype = {
    findNext: function() {return this.find(false);},
    findPrevious: function() {return this.find(true);},

    find: function(reverse) {
      var self = this, pos = this.doc.clipPos(reverse ? this.pos.from : this.pos.to);
      function savePosAndFail(line) {
        var pos = Pos(line, 0);
        self.pos = {from: pos, to: pos};
        self.atOccurrence = false;
        return false;
      }

      for (;;) {
        if (this.pos = this.matches(reverse, pos)) {
          if (!this.pos.from || !this.pos.to) { console.log(this.matches, this.pos); }
          this.atOccurrence = true;
          return this.pos.match || true;
        }
        if (reverse) {
          if (!pos.line) return savePosAndFail(0);
          pos = Pos(pos.line-1, this.doc.getLine(pos.line-1).length);
        }
        else {
          var maxLine = this.doc.lineCount();
          if (pos.line == maxLine - 1) return savePosAndFail(maxLine);
          pos = Pos(pos.line + 1, 0);
        }
      }
    },

    from: function() {if (this.atOccurrence) return this.pos.from;},
    to: function() {if (this.atOccurrence) return this.pos.to;},

    replace: function(newText) {
      if (!this.atOccurrence) return;
      var lines = CodeMirror.splitLines(newText);
      this.doc.replaceRange(lines, this.pos.from, this.pos.to);
      this.pos.to = Pos(this.pos.from.line + lines.length - 1,
                        lines[lines.length - 1].length + (lines.length == 1 ? this.pos.from.ch : 0));
    }
  };

  CodeMirror.defineExtension("getSearchCursor", function(query, pos, caseFold) {
    return new SearchCursor(this.doc, query, pos, caseFold);
  });
  CodeMirror.defineDocExtension("getSearchCursor", function(query, pos, caseFold) {
    return new SearchCursor(this, query, pos, caseFold);
  });
})();

(function() {
  "use strict";
  var GUTTER_ID = "CodeMirror-lint-markers";
  var SEVERITIES = /^(?:error|warning)$/;

  function showTooltip(e, content) {
    var tt = document.createElement("div");
    tt.className = "CodeMirror-lint-tooltip";
    tt.appendChild(content.cloneNode(true));
    document.body.appendChild(tt);

    function position(e) {
      if (!tt.parentNode) return CodeMirror.off(document, "mousemove", position);
      tt.style.top = Math.max(0, e.clientY - tt.offsetHeight - 5) + "px";
      tt.style.left = (e.clientX + 5) + "px";
    }
    CodeMirror.on(document, "mousemove", position);
    position(e);
    if (tt.style.opacity != null) tt.style.opacity = 1;
    return tt;
  }
  function rm(elt) {
    if (elt.parentNode) elt.parentNode.removeChild(elt);
  }
  function hideTooltip(tt) {
    if (!tt.parentNode) return;
    if (tt.style.opacity == null) rm(tt);
    tt.style.opacity = 0;
    setTimeout(function() { rm(tt); }, 600);
  }

  function showTooltipFor(e, content, node) {
    var tooltip = showTooltip(e, content);
    function hide() {
      CodeMirror.off(node, "mouseout", hide);
      if (tooltip) { hideTooltip(tooltip); tooltip = null; }
    }
    var poll = setInterval(function() {
      if (tooltip) for (var n = node;; n = n.parentNode) {
        if (n == document.body) return;
        if (!n) { hide(); break; }
      }
      if (!tooltip) return clearInterval(poll);
    }, 400);
    CodeMirror.on(node, "mouseout", hide);
  }

  function LintState(cm, options, hasGutter) {
    this.marked = [];
    this.options = options;
    this.timeout = null;
    this.hasGutter = hasGutter;
    this.onMouseOver = function(e) { onMouseOver(cm, e); };
  }

  function parseOptions(cm, options) {
    if (options instanceof Function) return {getAnnotations: options};
    if (!options || options === true) options = {};
    if (!options.getAnnotations) options.getAnnotations = cm.getHelper(CodeMirror.Pos(0, 0), "lint");
    if (!options.getAnnotations) throw new Error("Required option 'getAnnotations' missing (lint addon)");
    return options;
  }

  function clearMarks(cm) {
    var state = cm.state.lint;
    if (state.hasGutter) cm.clearGutter(GUTTER_ID);
    for (var i = 0; i < state.marked.length; ++i)
      state.marked[i].clear();
    state.marked.length = 0;
  }

  function makeMarker(labels, severity, multiple, tooltips) {
    var marker = document.createElement("div"), inner = marker;
    marker.className = "CodeMirror-lint-marker-" + severity;
    if (multiple) {
      inner = marker.appendChild(document.createElement("div"));
      inner.className = "CodeMirror-lint-marker-multiple";
    }

    if (tooltips != false) CodeMirror.on(inner, "mouseover", function(e) {
      showTooltipFor(e, labels, inner);
    });

    return marker;
  }

  function getMaxSeverity(a, b) {
    if (a == "error") return a;
    else return b;
  }

  function groupByLine(annotations) {
    var lines = [];
    for (var i = 0; i < annotations.length; ++i) {
      var ann = annotations[i], line = ann.from.line;
      (lines[line] || (lines[line] = [])).push(ann);
    }
    return lines;
  }

  function annotationTooltip(ann) {
    var severity = ann.severity;
    if (!SEVERITIES.test(severity)) severity = "error";
    var tip = document.createElement("div");
    tip.className = "CodeMirror-lint-message-" + severity;
    tip.appendChild(document.createTextNode(ann.message));
    return tip;
  }

  function startLinting(cm) {
    var state = cm.state.lint, options = state.options;
    if (options.async)
      options.getAnnotations(cm, updateLinting, options);
    else
      updateLinting(cm, options.getAnnotations(cm.getValue()));
  }

  function updateLinting(cm, annotationsNotSorted) {
    clearMarks(cm);
    var state = cm.state.lint, options = state.options;

    var annotations = groupByLine(annotationsNotSorted);

    for (var line = 0; line < annotations.length; ++line) {
      var anns = annotations[line];
      if (!anns) continue;

      var maxSeverity = null;
      var tipLabel = state.hasGutter && document.createDocumentFragment();

      for (var i = 0; i < anns.length; ++i) {
        var ann = anns[i];
        var severity = ann.severity;
        if (!SEVERITIES.test(severity)) severity = "error";
        maxSeverity = getMaxSeverity(maxSeverity, severity);

        if (options.formatAnnotation) ann = options.formatAnnotation(ann);
        if (state.hasGutter) tipLabel.appendChild(annotationTooltip(ann));

        if (ann.to) state.marked.push(cm.markText(ann.from, ann.to, {
          className: "CodeMirror-lint-mark-" + severity,
          __annotation: ann
        }));
      }

      if (state.hasGutter)
        cm.setGutterMarker(line, GUTTER_ID, makeMarker(tipLabel, maxSeverity, anns.length > 1,
                                                       state.options.tooltips));
    }
    if (options.onUpdateLinting) options.onUpdateLinting(annotationsNotSorted, annotations, cm);
  }

  function onChange(cm) {
    var state = cm.state.lint;
    clearTimeout(state.timeout);
    state.timeout = setTimeout(function(){startLinting(cm);}, state.options.delay || 500);
  }

  function popupSpanTooltip(ann, e) {
    var target = e.target || e.srcElement;
    showTooltipFor(e, annotationTooltip(ann), target);
  }

  // When the mouseover fires, the cursor might not actually be over
  // the character itself yet. These pairs of x,y offsets are used to
  // probe a few nearby points when no suitable marked range is found.
  var nearby = [0, 0, 0, 5, 0, -5, 5, 0, -5, 0];

  function onMouseOver(cm, e) {
    if (!/\bCodeMirror-lint-mark-/.test((e.target || e.srcElement).className)) return;
    for (var i = 0; i < nearby.length; i += 2) {
      var spans = cm.findMarksAt(cm.coordsChar({left: e.clientX + nearby[i],
                                                top: e.clientY + nearby[i + 1]}));
      for (var j = 0; j < spans.length; ++j) {
        var span = spans[j], ann = span.__annotation;
        if (ann) return popupSpanTooltip(ann, e);
      }
    }
  }

  function optionHandler(cm, val, old) {
    if (old && old != CodeMirror.Init) {
      clearMarks(cm);
      cm.off("change", onChange);
      CodeMirror.off(cm.getWrapperElement(), "mouseover", cm.state.lint.onMouseOver);
      delete cm.state.lint;
    }

    if (val) {
      var gutters = cm.getOption("gutters"), hasLintGutter = false;
      for (var i = 0; i < gutters.length; ++i) if (gutters[i] == GUTTER_ID) hasLintGutter = true;
      var state = cm.state.lint = new LintState(cm, parseOptions(cm, val), hasLintGutter);
      cm.on("change", onChange);
      if (state.options.tooltips != false)
        CodeMirror.on(cm.getWrapperElement(), "mouseover", state.onMouseOver);

      startLinting(cm);
    }
  }

  CodeMirror.defineOption("lintWith", false, optionHandler); // deprecated
  CodeMirror.defineOption("lint", false, optionHandler); // deprecated
})();

'use strict';
/**
 * Binds a CodeMirror widget to a <textarea> element.
 */
angular.module('ui.codemirror', []).constant('uiCodemirrorConfig', {}).directive('uiCodemirror', [
  'uiCodemirrorConfig',
  function (uiCodemirrorConfig) {
    return {
      restrict: 'EA',
      require: '?ngModel',
      priority: 1,
      compile: function compile() {
        // Require CodeMirror
        if (angular.isUndefined(window.CodeMirror)) {
          throw new Error('ui-codemirror need CodeMirror to work... (o rly?)');
        }
        return function postLink(scope, iElement, iAttrs, ngModel) {
          var options, opts, codeMirror, initialTextValue;
          initialTextValue = iElement.text();
          options = uiCodemirrorConfig.codemirror || {};
          opts = angular.extend({ value: initialTextValue }, options, scope.$eval(iAttrs.uiCodemirror), scope.$eval(iAttrs.uiCodemirrorOpts));
          if (iElement[0].tagName === 'TEXTAREA') {
            // Might bug but still ...
            codeMirror = window.CodeMirror.fromTextArea(iElement[0], opts);
          } else {
            iElement.html('');
            codeMirror = new window.CodeMirror(function (cm_el) {
              iElement.append(cm_el);
            }, opts);
          }
          if (iAttrs.uiCodemirror || iAttrs.uiCodemirrorOpts) {
            var codemirrorDefaultsKeys = Object.keys(window.CodeMirror.defaults);
            scope.$watch(iAttrs.uiCodemirror || iAttrs.uiCodemirrorOpts, function updateOptions(newValues, oldValue) {
              if (!angular.isObject(newValues)) {
                return;
              }
              codemirrorDefaultsKeys.forEach(function (key) {
                if (newValues.hasOwnProperty(key)) {
                  if (oldValue && newValues[key] === oldValue[key]) {
                    return;
                  }
                  codeMirror.setOption(key, newValues[key]);
                }
              });
            }, true);
          }
          if (ngModel) {
            // CodeMirror expects a string, so make sure it gets one.
            // This does not change the model.
            ngModel.$formatters.push(function (value) {
              if (angular.isUndefined(value) || value === null) {
                return '';
              } else if (angular.isObject(value) || angular.isArray(value)) {
                throw new Error('ui-codemirror cannot use an object or an array as a model');
              }
              return value;
            });
            // Override the ngModelController $render method, which is what gets called when the model is updated.
            // This takes care of the synchronizing the codeMirror element with the underlying model, in the case that it is changed by something else.
            ngModel.$render = function () {
              //Code mirror expects a string so make sure it gets one
              //Although the formatter have already done this, it can be possible that another formatter returns undefined (for example the required directive)
              var safeViewValue = ngModel.$viewValue || '';
              codeMirror.setValue(safeViewValue);
            };
            // Keep the ngModel in sync with changes from CodeMirror
            codeMirror.on('change', function (instance) {
              var newValue = instance.getValue();
              if (newValue !== ngModel.$viewValue) {
                // Changes to the model from a callback need to be wrapped in $apply or angular will not notice them
                scope.$apply(function () {
                  ngModel.$setViewValue(newValue);
                });
              }
            });
          }
          // Watch ui-refresh and refresh the directive
          if (iAttrs.uiRefresh) {
            scope.$watch(iAttrs.uiRefresh, function (newVal, oldVal) {
              // Skip the initial watch firing
              if (newVal !== oldVal) {
                codeMirror.refresh();
              }
            });
          }
          // Allow access to the CodeMirror instance through a broadcasted event
          // eg: $broadcast('CodeMirror', function(cm){...});
          scope.$on('CodeMirror', function (event, callback) {
            if (angular.isFunction(callback)) {
              callback(codeMirror);
            } else {
              throw new Error('the CodeMirror event requires a callback function');
            }
          });
          // onLoad callback
          if (angular.isFunction(opts.onLoad)) {
            opts.onLoad(codeMirror);
          }
        };
      }
    };
  }
]);
/*
 * angular-marked
 * (c) 2014 J. Harshbarger
 * Licensed MIT
 */

/* jshint undef: true, unused: true */
/* global angular:true */
/* global marked:true */
/* global module */
/* global require */

(function () {
  'use strict';

  /**
   * @ngdoc overview
   * @name index
   *
   * @description
   * AngularJS Markdown using [marked](https://github.com/chjj/marked).
   *
   * ## Why?
   *
   * I wanted to use [marked](https://github.com/chjj/marked) instead of [showdown](https://github.com/coreyti/showdown) as used in [angular-markdown-directive](https://github.com/btford/angular-markdown-directive) as well as expose the option to globally set defaults.
   *
   * ## How?
   *
   * - {@link hc.marked.directive:marked As a directive}
   * - {@link hc.marked.service:marked As a service}
   * - {@link hc.marked.service:markedProvider Set default options}
   *
   * @example

      Convert markdown to html at run time.  For example:

      <example module="hc.marked">
        <file name=".html">
          <form ng-controller="MainController">
            Markdown:<br />
            <textarea ng-model="my_markdown" cols="60" rows="5" class="span8" /><br />
            Output:<br />
            <div marked="my_markdown" />
          </form>
        </file>
        <file  name=".js">
          function MainController($scope) {
            $scope.my_markdown = "*This* **is** [markdown](https://daringfireball.net/projects/markdown/)";
          }
        </file>
      </example>

    *
    */

    /**
     * @ngdoc overview
     * @name hc.marked
     * @description # angular-marked (core module)
       # Installation
      First include angular-marked.js in your HTML:

      ```js
        <script src="angular-marked.js">
      ```

      Then load the module in your application by adding it as a dependency:

      ```js
      angular.module('yourApp', ['hc.marked']);
      ```

      With that you're ready to get started!
     */

  if (typeof module !== 'undefined' && typeof exports === 'object') {
    module.exports = 'hc.marked';
  }

  angular.module('hc.marked', [])

    /**
    * @ngdoc service
    * @name hc.marked.service:marked
    * @requires $window
    * @description
    * A reference to the [marked](https://github.com/chjj/marked) parser.
    *
    * @example
    <example module="hc.marked">
      <file name=".html">
        <div ng-controller="MainController">
          html: {{html}}
        </div>
      </file>
      <file  name=".js">
        function MainController($scope, marked) {
          $scope.html = marked('#TEST');
        }
      </file>
    </example>
   **/

   /**
   * @ngdoc service
   * @name hc.marked.service:markedProvider
   * @description
   * Use `markedProvider` to change the default behavior of the {@link hc.marked.service:marked marked} service.
   *
   * @example

    ## Example using [google-code-prettify syntax highlighter](https://code.google.com/p/google-code-prettify/) (must include google-code-prettify.js script).  Also works with [highlight.js Javascript syntax highlighter](http://highlightjs.org/).

    <example module="myApp">
    <file name=".js">
    angular.module('myApp', ['hc.marked'])
      .config(['markedProvider', function(markedProvider) {
        markedProvider.setOptions({
          gfm: true,
          tables: true,
          highlight: function (code) {
            return prettyPrintOne(code);
          }
        });
      }]);
    </file>
    <file name=".html">
      <marked>
      ```js
      angular.module('myApp', ['hc.marked'])
        .config(['markedProvider', function(markedProvider) {
          markedProvider.setOptions({
            gfm: true,
            tables: true,
            highlight: function (code) {
              return prettyPrintOne(code);
            }
          });
        }]);
      ```
      </marked>
    </file>
    </example>
  **/

  .provider('marked', function () {

    var self = this;

    /**
     * @ngdoc method
     * @name markedProvider#setOptions
     * @methodOf hc.marked.service:markedProvider
     *
     * @param {object} opts Default options for [marked](https://github.com/chjj/marked#options-1).
     */

    self.setRenderer = function (opts) {
      this.renderer = opts;
    };

    self.setOptions = function(opts) {  // Store options for later
      this.defaults = opts;
    };

    self.$get = ['$window', '$log', function ($window, $log) {

      var m =  (function() {

        if (typeof module !== 'undefined' && typeof exports === 'object') {
          return require('marked');
        } else {
          return $window.marked || marked;
        }

      })();

      if (angular.isUndefined(m)) {
        $log.error('angular-marked Error: marked not loaded.  See installation instructions.');
        return;
      }

      // override rendered markdown html
      // with custom definitions if defined
      if (self.renderer) {
        var r = new m.Renderer();
        var o = Object.keys(self.renderer),
            l = o.length;

        while (l--) {
          r[o[l]] = self.renderer[o[l]];
        }

        // add the new renderer to the options if need be
        self.defaults = self.defaults || {};
        self.defaults.renderer = r;
      }

      m.setOptions(self.defaults);

      return m;
    }];

  })

  // TODO: filter tests */
  //app.filter('marked', ['marked', function(marked) {
  //  return marked;
  //}]);

  /**
   * @ngdoc directive
   * @name hc.marked.directive:marked
   * @restrict AE
   * @element any
   *
   * @description
   * Compiles source test into HTML.
   *
   * @param {expression} marked The source text to be compiled.  If blank uses content as the source.
   * @param {expression=} opts Hash of options that override defaults.
   *
   * @example

     ## A simple block of text

      <example module="hc.marked">
        <file name="exampleA.html">
         * <marked>
         * ### Markdown directive
         *
         * *It works!*
         *
         * *This* **is** [markdown](https://daringfireball.net/projects/markdown/) in the view.
         * </marked>
        </file>
      </example>

     ## Bind to a scope variable

      <example module="hc.marked">
        <file name="exampleB.html">
          <form ng-controller="MainController">
            Markdown:<br />
            <textarea ng-model="my_markdown" class="span8" cols="60" rows="5"></textarea><br />
            Output:<br />
            <blockquote marked="my_markdown"></blockquote>
          </form>
        </file>
        <file  name="exampleB.js">
          * function MainController($scope) {
          *   $scope.my_markdown = '*This* **is** [markdown](https://daringfireball.net/projects/markdown/)';
          *   $scope.my_markdown += ' in a scope variable';
          * }
        </file>
      </example>

      ## Include a markdown file:

       <example module="hc.marked">
         <file name="exampleC.html">
           <div marked ng-include="'include.html'" />
         </file>
         * <file name="include.html">
         * *This* **is** [markdown](https://daringfireball.net/projects/markdown/) in a include file.
         * </file>
       </example>
   */

  .directive('marked', ['marked', function (marked) {
    return {
      restrict: 'AE',
      replace: true,
      scope: {
        opts: '=',
        marked: '='
      },
      link: function (scope, element, attrs) {
        set(scope.marked || element.text() || '');

        function unindent(text) {
          if (!text) return text;

          var lines  = text
            .replace(/\t/g, '  ')
            .split(/\r?\n/);

          var i, l, min = null, line, len = lines.length;
          for (i = 0; i < len; i++) {
            line = lines[i];
            l = line.match(/^(\s*)/)[0].length;
            if (l === line.length) { continue; }
            min = (l < min || min === null) ? l : min;
          }

          if (min !== null && min > 0) {
            for (i = 0; i < len; i++) {
              lines[i] = lines[i].substr(min);
            }
          }
          return lines.join('\n');
        }

        function set(text) {
          text = unindent(text || '');
          element.html(marked(text, scope.opts || null));
        }

        if (attrs.marked) {
          scope.$watch('marked', set);
        }

      }
    };
  }]);

}());

/*global angular*/
(function (module) {

var dirHljs, dirLanguageFactory, dirSourceFactory, dirIncludeFactory;

function shouldHighlightStatics(attrs) {
  var should = true;
  angular.forEach([
    'source', 'include'
  ], function (name) {
    if (attrs[name]) {
      should = false;
    }
  });
  return should;
}

module

/**
 * hljsService service
 */
.provider('hljsService', function () {
  var _hljsOptions = {};

  return {
    setOptions: function (options) {
      angular.extend(_hljsOptions, options);
    },
    getOptions: function () {
      return angular.copy(_hljsOptions);
    },
    $get: ['$window', function ($window) {
      ($window.hljs.configure || angular.noop)(_hljsOptions);
      return $window.hljs;
    }]
  };
})

/**
 * hljsCache service
 */
.factory('hljsCache', [
         '$cacheFactory',
function ($cacheFactory) {
  return $cacheFactory('hljsCache');
}])

/**
 * HljsCtrl controller
 */
.controller('HljsCtrl', [
                  'hljsCache', 'hljsService',
function HljsCtrl (hljsCache,   hljsService) {
  var ctrl = this;

  var _elm = null,
      _lang = null,
      _code = null,
      _hlCb = null;

  ctrl.init = function (codeElm) {
    _elm = codeElm;
  };

  ctrl.setLanguage = function (lang) {
    _lang = lang;

    if (_code) {
      ctrl.highlight(_code);
    }
  };

  ctrl.highlightCallback = function (cb) {
    _hlCb = cb;
  };

  ctrl.highlight = function (code) {
    if (!_elm) {
      return;
    }

    var res, cacheKey;

    _code = code;

    if (_lang) {
      // language specified
      cacheKey = ctrl._cacheKey(_lang, _code);
      res = hljsCache.get(cacheKey);

      if (!res) {
        res = hljsService.highlight(_lang, hljsService.fixMarkup(_code), true);
        hljsCache.put(cacheKey, res);
      }
    }
    else {
      // language auto-detect
      cacheKey = ctrl._cacheKey(_code);
      res = hljsCache.get(cacheKey);

      if (!res) {
        res = hljsService.highlightAuto(hljsService.fixMarkup(_code));
        hljsCache.put(cacheKey, res);
      }
    }

    _elm.html(res.value);
    // language as class on the <code> tag
    _elm.addClass(res.language);

    if (_hlCb !== null && angular.isFunction(_hlCb)) {
      _hlCb();
    }
  };

  ctrl.clear = function () {
    if (!_elm) {
      return;
    }
    _code = null;
    _elm.text('');
  };

  ctrl.release = function () {
    _elm = null;
  };

  ctrl._cacheKey = function () {
    var args = Array.prototype.slice.call(arguments),
        glue = "!angular-highlightjs!";
    return args.join(glue);
  };
}]);

/**
 * hljs directive
 */
dirHljs = ['$compile', '$parse', function ($compile, $parse) {
  return {
    restrict: 'EA',
    controller: 'HljsCtrl',
    compile: function(tElm, tAttrs, transclude) {
      // get static code
      // strip the starting "new line" character
      var staticHTML = tElm[0].innerHTML.replace(/^(\r\n|\r|\n)/m, ''),
          staticText = tElm[0].textContent.replace(/^(\r\n|\r|\n)/m, '');

      // put template
      tElm.html('<pre><code class="hljs"></code></pre>');

      return function postLink(scope, iElm, iAttrs, ctrl) {
        var compileCheck, escapeCheck;

        if (angular.isDefined(iAttrs.compile)) {
          compileCheck = $parse(iAttrs.compile);
        }

        if (angular.isDefined(iAttrs.escape)) {
          escapeCheck = $parse(iAttrs.escape);
        } else if (angular.isDefined(iAttrs.noEscape)) {
          escapeCheck = $parse('false');
        }

        ctrl.init(iElm.find('code'));

        if (iAttrs.onhighlight) {
          ctrl.highlightCallback(function () {
            scope.$eval(iAttrs.onhighlight);
          });
        }

        if ((staticHTML || staticText) && shouldHighlightStatics(iAttrs)) {

          var code;

          // Auto-escape check
          // default to "true"
          if (escapeCheck && !escapeCheck(scope)) {
            code = staticText;
          }
          else {
            code = staticHTML;
          }

          ctrl.highlight(code);

          // Check if the highlight result needs to be compiled
          if (compileCheck && compileCheck(scope)) {
            // compile the new DOM and link it to the current scope.
            // NOTE: we only compile .childNodes so that
            // we don't get into infinite loop compiling ourselves
            $compile(iElm.find('code').contents())(scope);
          }
        }

        scope.$on('$destroy', function () {
          ctrl.release();
        });
      };
    }
  };
}];

/**
 * language directive
 */
dirLanguageFactory = function (dirName) {
  return [function () {
    return {
      require: '?hljs',
      restrict: 'A',
      link: function (scope, iElm, iAttrs, ctrl) {
        if (!ctrl) {
          return;
        }      
        iAttrs.$observe(dirName, function (lang) {
          if (angular.isDefined(lang)) {
            ctrl.setLanguage(lang);
          }
        });
      }
    };
  }];
};

/**
 * source directive
 */
dirSourceFactory = function (dirName) {
  return ['$compile', '$parse', function ($compile, $parse) {
    return {
      require: '?hljs',
      restrict: 'A',
      link: function(scope, iElm, iAttrs, ctrl) {
        var compileCheck;

        if (!ctrl) {
          return;
        }

        if (angular.isDefined(iAttrs.compile)) {
          compileCheck = $parse(iAttrs.compile);
        }

        scope.$watch(iAttrs[dirName], function (newCode, oldCode) {
          if (newCode) {
            ctrl.highlight(newCode);

            // Check if the highlight result needs to be compiled
            if (compileCheck && compileCheck(scope)) {
              // compile the new DOM and link it to the current scope.
              // NOTE: we only compile .childNodes so that
              // we don't get into infinite loop compiling ourselves
              $compile(iElm.find('code').contents())(scope);
            }
          }
          else {
            ctrl.clear();
          }
        });
      }
    };
  }];
};

/**
 * include directive
 */
dirIncludeFactory = function (dirName) {
  return [
             '$http', '$templateCache', '$q', '$compile', '$parse',
    function ($http,   $templateCache,   $q,   $compile,   $parse) {
      return {
        require: '?hljs',
        restrict: 'A',
        compile: function(tElm, tAttrs, transclude) {
          var srcExpr = tAttrs[dirName];

          return function postLink(scope, iElm, iAttrs, ctrl) {
            var changeCounter = 0, compileCheck;

            if (!ctrl) {
              return;
            }

            if (angular.isDefined(iAttrs.compile)) {
              compileCheck = $parse(iAttrs.compile);
            }

            scope.$watch(srcExpr, function (src) {
              var thisChangeId = ++changeCounter;

              if (src && angular.isString(src)) {
                var templateCachePromise, dfd;

                templateCachePromise = $templateCache.get(src);
                if (!templateCachePromise) {
                  dfd = $q.defer();
                  $http.get(src, {
                    cache: $templateCache,
                    transformResponse: function(data, headersGetter) {
                      // Return the raw string, so $http doesn't parse it
                      // if it's json.
                      return data;
                    }
                  }).success(function (code) {
                    if (thisChangeId !== changeCounter) {
                      return;
                    }
                    dfd.resolve(code);
                  }).error(function() {
                    if (thisChangeId === changeCounter) {
                      ctrl.clear();
                    }
                    dfd.resolve();
                  });
                  templateCachePromise = dfd.promise;
                }

                $q.when(templateCachePromise)
                .then(function (code) {
                  if (!code) {
                    return;
                  }

                  // $templateCache from $http
                  if (angular.isArray(code)) {
                    // 1.1.5
                    code = code[1];
                  }
                  else if (angular.isObject(code)) {
                    // 1.0.7
                    code = code.data;
                  }

                  code = code.replace(/^(\r\n|\r|\n)/m, '');
                  ctrl.highlight(code);

                  // Check if the highlight result needs to be compiled
                  if (compileCheck && compileCheck(scope)) {
                    // compile the new DOM and link it to the current scope.
                    // NOTE: we only compile .childNodes so that
                    // we don't get into infinite loop compiling ourselves
                    $compile(iElm.find('code').contents())(scope);
                  }
                });
              }
              else {
                ctrl.clear();
              }
            });
          };
        }
      };
  }];
};

module
.directive('hljs', dirHljs)
.directive('language', dirLanguageFactory('language'))
.directive('source', dirSourceFactory('source'))
.directive('include', dirIncludeFactory('include'));

})(angular.module('hljs', []));
(function (root) {
// lazy require symbols table
var _symbols, removelist;
function symbols(code) {
    if (_symbols) return _symbols[code];
    _symbols = require('unicode/category/So');
    removelist = ['sign','cross','of','symbol','staff','hand','black','white']
        .map(function (word) {return new RegExp(word, 'gi')});
    return _symbols[code];
}

function slug(string, opts) {
    opts = opts || {};
    string = string.toString();
    if ('string' === typeof opts)
        opts = {replacement:opts};
    opts.mode = opts.mode || slug.defaults.mode;
    var defaults = slug.defaults.modes[opts.mode];
    ['replacement','multicharmap','charmap','remove'].forEach(function (key) {
        opts[key] = opts[key] || defaults[key];
    });
    if ('undefined' === typeof opts.symbols)
        opts.symbols = defaults.symbols;
    var lengths = [];
    Object.keys(opts.multicharmap).forEach(function (key) {
        var len = key.length;
        if (lengths.indexOf(len) === -1)
            lengths.push(len);
    });
    var code, unicode, result = "";
    for (var char, i = 0, l = string.length; i < l; i++) { char = string[i];
        if (!lengths.some(function (len) {
            var str = string.substr(i, len);
            if (opts.multicharmap[str]) {
                i += len - 1;
                char = opts.multicharmap[str];
                return true;
            } else return false;
        })) {
            if (opts.charmap[char]) {
                char = opts.charmap[char];
                code = char.charCodeAt(0);
            } else {
                code = string.charCodeAt(i);
            }
            if (opts.symbols && (unicode = symbols(code))) {
                char = unicode.name.toLowerCase();
                for(var j = 0, rl = removelist.length; j < rl; j++) {
                    char = char.replace(removelist[j], '');
                }
                char = char.replace(/^\s+|\s+$/g, '');
            }
        }
        char = char.replace(/[^\w\s\-\.\_~]/g, ''); // allowed
        if (opts.remove) char = char.replace(opts.remove, ''); // add flavour
        result += char;
    }
    result = result.replace(/^\s+|\s+$/g, ''); // trim leading/trailing spaces
    result = result.replace(/[-\s]+/g, opts.replacement); // convert spaces
    return result.replace(opts.replacement+"$",''); // remove trailing separator
};

slug.defaults = {
    mode: 'pretty',
};

slug.multicharmap = slug.defaults.multicharmap = {
    '<3': 'love', '&&': 'and', '||': 'or', 'w/': 'with',
};

// https://code.djangoproject.com/browser/django/trunk/django/contrib/admin/media/js/urlify.js
slug.charmap  = slug.defaults.charmap = {
    // latin
    'À': 'A', 'Á': 'A', 'Â': 'A', 'Ã': 'A', 'Ä': 'A', 'Å': 'A', 'Æ': 'AE',
    'Ç': 'C', 'È': 'E', 'É': 'E', 'Ê': 'E', 'Ë': 'E', 'Ì': 'I', 'Í': 'I',
    'Î': 'I', 'Ï': 'I', 'Ð': 'D', 'Ñ': 'N', 'Ò': 'O', 'Ó': 'O', 'Ô': 'O',
    'Õ': 'O', 'Ö': 'O', 'Ő': 'O', 'Ø': 'O', 'Ù': 'U', 'Ú': 'U', 'Û': 'U',
    'Ü': 'U', 'Ű': 'U', 'Ý': 'Y', 'Þ': 'TH', 'ß': 'ss', 'à':'a', 'á':'a',
    'â': 'a', 'ã': 'a', 'ä': 'a', 'å': 'a', 'æ': 'ae', 'ç': 'c', 'è': 'e',
    'é': 'e', 'ê': 'e', 'ë': 'e', 'ì': 'i', 'í': 'i', 'î': 'i', 'ï': 'i',
    'ð': 'd', 'ñ': 'n', 'ò': 'o', 'ó': 'o', 'ô': 'o', 'õ': 'o', 'ö': 'o',
    'ő': 'o', 'ø': 'o', 'ù': 'u', 'ú': 'u', 'û': 'u', 'ü': 'u', 'ű': 'u',
    'ý': 'y', 'þ': 'th', 'ÿ': 'y', 'ẞ': 'SS',
    // greek
    'α':'a', 'β':'b', 'γ':'g', 'δ':'d', 'ε':'e', 'ζ':'z', 'η':'h', 'θ':'8',
    'ι':'i', 'κ':'k', 'λ':'l', 'μ':'m', 'ν':'n', 'ξ':'3', 'ο':'o', 'π':'p',
    'ρ':'r', 'σ':'s', 'τ':'t', 'υ':'y', 'φ':'f', 'χ':'x', 'ψ':'ps', 'ω':'w',
    'ά':'a', 'έ':'e', 'ί':'i', 'ό':'o', 'ύ':'y', 'ή':'h', 'ώ':'w', 'ς':'s',
    'ϊ':'i', 'ΰ':'y', 'ϋ':'y', 'ΐ':'i',
    'Α':'A', 'Β':'B', 'Γ':'G', 'Δ':'D', 'Ε':'E', 'Ζ':'Z', 'Η':'H', 'Θ':'8',
    'Ι':'I', 'Κ':'K', 'Λ':'L', 'Μ':'M', 'Ν':'N', 'Ξ':'3', 'Ο':'O', 'Π':'P',
    'Ρ':'R', 'Σ':'S', 'Τ':'T', 'Υ':'Y', 'Φ':'F', 'Χ':'X', 'Ψ':'PS', 'Ω':'W',
    'Ά':'A', 'Έ':'E', 'Ί':'I', 'Ό':'O', 'Ύ':'Y', 'Ή':'H', 'Ώ':'W', 'Ϊ':'I',
    'Ϋ':'Y',
    // turkish
    'ş':'s', 'Ş':'S', 'ı':'i', 'İ':'I',
    'ğ':'g', 'Ğ':'G',
    // russian
    'а':'a', 'б':'b', 'в':'v', 'г':'g', 'д':'d', 'е':'e', 'ё':'yo', 'ж':'zh',
    'з':'z', 'и':'i', 'й':'j', 'к':'k', 'л':'l', 'м':'m', 'н':'n', 'о':'o',
    'п':'p', 'р':'r', 'с':'s', 'т':'t', 'у':'u', 'ф':'f', 'х':'h', 'ц':'c',
    'ч':'ch', 'ш':'sh', 'щ':'sh', 'ъ':'u', 'ы':'y', 'ь':'', 'э':'e', 'ю':'yu',
    'я':'ya',
    'А':'A', 'Б':'B', 'В':'V', 'Г':'G', 'Д':'D', 'Е':'E', 'Ё':'Yo', 'Ж':'Zh',
    'З':'Z', 'И':'I', 'Й':'J', 'К':'K', 'Л':'L', 'М':'M', 'Н':'N', 'О':'O',
    'П':'P', 'Р':'R', 'С':'S', 'Т':'T', 'У':'U', 'Ф':'F', 'Х':'H', 'Ц':'C',
    'Ч':'Ch', 'Ш':'Sh', 'Щ':'Sh', 'Ъ':'U', 'Ы':'Y', 'Ь':'', 'Э':'E', 'Ю':'Yu',
    'Я':'Ya',
    // ukranian
    'Є':'Ye', 'І':'I', 'Ї':'Yi', 'Ґ':'G', 'є':'ye', 'і':'i', 'ї':'yi', 'ґ':'g',
    // czech
    'č':'c', 'ď':'d', 'ě':'e', 'ň': 'n', 'ř':'r', 'š':'s', 'ť':'t', 'ů':'u',
    'ž':'z', 'Č':'C', 'Ď':'D', 'Ě':'E', 'Ň': 'N', 'Ř':'R', 'Š':'S', 'Ť':'T',
    'Ů':'U', 'Ž':'Z',
    // polish
    'ą':'a', 'ć':'c', 'ę':'e', 'ł':'l', 'ń':'n', 'ś':'s', 'ź':'z',
    'ż':'z', 'Ą':'A', 'Ć':'C', 'Ę':'E', 'Ł':'L', 'Ń':'N', 'Ś':'S',
    'Ź':'Z', 'Ż':'Z',
    // latvian
    'ā':'a', 'ē':'e', 'ģ':'g', 'ī':'i', 'ķ':'k', 'ļ':'l', 'ņ':'n',
    'ū':'u', 'Ā':'A', 'Ē':'E', 'Ģ':'G', 'Ī':'I',
    'Ķ':'K', 'Ļ':'L', 'Ņ':'N', 'Ū':'U',
    // lithuanian
    'ė':'e', 'į':'i', 'ų':'u', 'Ė': 'E', 'Į': 'I', 'Ų':'U',
    // romanian
    'ț':'t', 'Ț':'T', 'ţ':'t', 'Ţ':'T', 'ș':'s', 'Ș':'S', 'ă':'a', 'Ă':'A',
    // currency
    '€': 'euro', '₢': 'cruzeiro', '₣': 'french franc', '£': 'pound',
    '₤': 'lira', '₥': 'mill', '₦': 'naira', '₧': 'peseta', '₨': 'rupee',
    '₩': 'won', '₪': 'new shequel', '₫': 'dong', '₭': 'kip', '₮': 'tugrik',
    '₯': 'drachma', '₰': 'penny', '₱': 'peso', '₲': 'guarani', '₳': 'austral',
    '₴': 'hryvnia', '₵': 'cedi', '¢': 'cent', '¥': 'yen', '元': 'yuan',
    '円': 'yen', '﷼': 'rial', '₠': 'ecu', '¤': 'currency', '฿': 'baht',
    "$": 'dollar', '₹': 'indian rupee',
    // symbols
    '©':'(c)', 'œ': 'oe', 'Œ': 'OE', '∑': 'sum', '®': '(r)', '†': '+',
    '“': '"', '”': '"', '‘': "'", '’': "'", '∂': 'd', 'ƒ': 'f', '™': 'tm',
    '℠': 'sm', '…': '...', '˚': 'o', 'º': 'o', 'ª': 'a', '•': '*',
    '∆': 'delta', '∞': 'infinity', '♥': 'love', '&': 'and', '|': 'or',
    '<': 'less', '>': 'greater',
};

slug.defaults.modes = {
    rfc3986: {
        replacement: '-',
        symbols: true,
        remove: null,
        charmap: slug.defaults.charmap,
        multicharmap: slug.defaults.multicharmap,
    },
    pretty: {
        replacement: '-',
        symbols: true,
        remove: /[.]/g,
        charmap: slug.defaults.charmap,
        multicharmap: slug.defaults.multicharmap,
    },
};

// Be compatible with different module systems

if (typeof define !== 'undefined' && define.amd) { // AMD
    // dont load symbols table in the browser
    Object.keys(slug.defaults.modes).forEach(function (key) {
        slug.defaults.modes[key].symbols = false;
    });
    define([], function () {return slug});
} else if (typeof module !== 'undefined' && module.exports) { // CommonJS
    symbols(); // preload symbols table
    module.exports = slug;
} else { // Script tag
    // dont load symbols table in the browser
    Object.keys(slug.defaults.modes).forEach(function (key) {
        slug.defaults.modes[key].symbols = false;
    });
    root.slug = slug;
}

}(this));

/* FileSaver.js
 * A saveAs() FileSaver implementation.
 * 1.1.20160328
 *
 * By Eli Grey, http://eligrey.com
 * License: MIT
 *   See https://github.com/eligrey/FileSaver.js/blob/master/LICENSE.md
 */

/*global self */
/*jslint bitwise: true, indent: 4, laxbreak: true, laxcomma: true, smarttabs: true, plusplus: true */

/*! @source http://purl.eligrey.com/github/FileSaver.js/blob/master/FileSaver.js */

var saveAs = saveAs || (function(view) {
	"use strict";
	// IE <10 is explicitly unsupported
	if (typeof navigator !== "undefined" && /MSIE [1-9]\./.test(navigator.userAgent)) {
		return;
	}
	var
		  doc = view.document
		  // only get URL when necessary in case Blob.js hasn't overridden it yet
		, get_URL = function() {
			return view.URL || view.webkitURL || view;
		}
		, save_link = doc.createElementNS("http://www.w3.org/1999/xhtml", "a")
		, can_use_save_link = "download" in save_link
		, click = function(node) {
			var event = new MouseEvent("click");
			node.dispatchEvent(event);
		}
		, is_safari = /Version\/[\d\.]+.*Safari/.test(navigator.userAgent)
		, webkit_req_fs = view.webkitRequestFileSystem
		, req_fs = view.requestFileSystem || webkit_req_fs || view.mozRequestFileSystem
		, throw_outside = function(ex) {
			(view.setImmediate || view.setTimeout)(function() {
				throw ex;
			}, 0);
		}
		, force_saveable_type = "application/octet-stream"
		, fs_min_size = 0
		// the Blob API is fundamentally broken as there is no "downloadfinished" event to subscribe to
		, arbitrary_revoke_timeout = 1000 * 40 // in ms
		, revoke = function(file) {
			var revoker = function() {
				if (typeof file === "string") { // file is an object URL
					get_URL().revokeObjectURL(file);
				} else { // file is a File
					file.remove();
				}
			};
			/* // Take note W3C:
			var
			  uri = typeof file === "string" ? file : file.toURL()
			, revoker = function(evt) {
				// idealy DownloadFinishedEvent.data would be the URL requested
				if (evt.data === uri) {
					if (typeof file === "string") { // file is an object URL
						get_URL().revokeObjectURL(file);
					} else { // file is a File
						file.remove();
					}
				}
			}
			;
			view.addEventListener("downloadfinished", revoker);
			*/
			setTimeout(revoker, arbitrary_revoke_timeout);
		}
		, dispatch = function(filesaver, event_types, event) {
			event_types = [].concat(event_types);
			var i = event_types.length;
			while (i--) {
				var listener = filesaver["on" + event_types[i]];
				if (typeof listener === "function") {
					try {
						listener.call(filesaver, event || filesaver);
					} catch (ex) {
						throw_outside(ex);
					}
				}
			}
		}
		, auto_bom = function(blob) {
			// prepend BOM for UTF-8 XML and text/* types (including HTML)
			if (/^\s*(?:text\/\S*|application\/xml|\S*\/\S*\+xml)\s*;.*charset\s*=\s*utf-8/i.test(blob.type)) {
				return new Blob(["\ufeff", blob], {type: blob.type});
			}
			return blob;
		}
		, FileSaver = function(blob, name, no_auto_bom) {
			if (!no_auto_bom) {
				blob = auto_bom(blob);
			}
			// First try a.download, then web filesystem, then object URLs
			var
				  filesaver = this
				, type = blob.type
				, blob_changed = false
				, object_url
				, target_view
				, dispatch_all = function() {
					dispatch(filesaver, "writestart progress write writeend".split(" "));
				}
				// on any filesys errors revert to saving with object URLs
				, fs_error = function() {
					if (target_view && is_safari && typeof FileReader !== "undefined") {
						// Safari doesn't allow downloading of blob urls
						var reader = new FileReader();
						reader.onloadend = function() {
							var base64Data = reader.result;
							target_view.location.href = "data:attachment/file" + base64Data.slice(base64Data.search(/[,;]/));
							filesaver.readyState = filesaver.DONE;
							dispatch_all();
						};
						reader.readAsDataURL(blob);
						filesaver.readyState = filesaver.INIT;
						return;
					}
					// don't create more object URLs than needed
					if (blob_changed || !object_url) {
						object_url = get_URL().createObjectURL(blob);
					}
					if (target_view) {
						target_view.location.href = object_url;
					} else {
						var new_tab = view.open(object_url, "_blank");
						if (new_tab === undefined && is_safari) {
							//Apple do not allow window.open, see http://bit.ly/1kZffRI
							view.location.href = object_url
						}
					}
					filesaver.readyState = filesaver.DONE;
					dispatch_all();
					revoke(object_url);
				}
				, abortable = function(func) {
					return function() {
						if (filesaver.readyState !== filesaver.DONE) {
							return func.apply(this, arguments);
						}
					};
				}
				, create_if_not_found = {create: true, exclusive: false}
				, slice
			;
			filesaver.readyState = filesaver.INIT;
			if (!name) {
				name = "download";
			}
			if (can_use_save_link) {
				object_url = get_URL().createObjectURL(blob);
				setTimeout(function() {
					save_link.href = object_url;
					save_link.download = name;
					click(save_link);
					dispatch_all();
					revoke(object_url);
					filesaver.readyState = filesaver.DONE;
				});
				return;
			}
			// Object and web filesystem URLs have a problem saving in Google Chrome when
			// viewed in a tab, so I force save with application/octet-stream
			// http://code.google.com/p/chromium/issues/detail?id=91158
			// Update: Google errantly closed 91158, I submitted it again:
			// https://code.google.com/p/chromium/issues/detail?id=389642
			if (view.chrome && type && type !== force_saveable_type) {
				slice = blob.slice || blob.webkitSlice;
				blob = slice.call(blob, 0, blob.size, force_saveable_type);
				blob_changed = true;
			}
			// Since I can't be sure that the guessed media type will trigger a download
			// in WebKit, I append .download to the filename.
			// https://bugs.webkit.org/show_bug.cgi?id=65440
			if (webkit_req_fs && name !== "download") {
				name += ".download";
			}
			if (type === force_saveable_type || webkit_req_fs) {
				target_view = view;
			}
			if (!req_fs) {
				fs_error();
				return;
			}
			fs_min_size += blob.size;
			req_fs(view.TEMPORARY, fs_min_size, abortable(function(fs) {
				fs.root.getDirectory("saved", create_if_not_found, abortable(function(dir) {
					var save = function() {
						dir.getFile(name, create_if_not_found, abortable(function(file) {
							file.createWriter(abortable(function(writer) {
								writer.onwriteend = function(event) {
									target_view.location.href = file.toURL();
									filesaver.readyState = filesaver.DONE;
									dispatch(filesaver, "writeend", event);
									revoke(file);
								};
								writer.onerror = function() {
									var error = writer.error;
									if (error.code !== error.ABORT_ERR) {
										fs_error();
									}
								};
								"writestart progress write abort".split(" ").forEach(function(event) {
									writer["on" + event] = filesaver["on" + event];
								});
								writer.write(blob);
								filesaver.abort = function() {
									writer.abort();
									filesaver.readyState = filesaver.DONE;
								};
								filesaver.readyState = filesaver.WRITING;
							}), fs_error);
						}), fs_error);
					};
					dir.getFile(name, {create: false}, abortable(function(file) {
						// delete file if it already exists
						file.remove();
						save();
					}), abortable(function(ex) {
						if (ex.code === ex.NOT_FOUND_ERR) {
							save();
						} else {
							fs_error();
						}
					}));
				}), fs_error);
			}), fs_error);
		}
		, FS_proto = FileSaver.prototype
		, saveAs = function(blob, name, no_auto_bom) {
			return new FileSaver(blob, name, no_auto_bom);
		}
	;
	// IE 10+ (native saveAs)
	if (typeof navigator !== "undefined" && navigator.msSaveOrOpenBlob) {
		return function(blob, name, no_auto_bom) {
			if (!no_auto_bom) {
				blob = auto_bom(blob);
			}
			return navigator.msSaveOrOpenBlob(blob, name || "download");
		};
	}

	FS_proto.abort = function() {
		var filesaver = this;
		filesaver.readyState = filesaver.DONE;
		dispatch(filesaver, "abort");
	};
	FS_proto.readyState = FS_proto.INIT = 0;
	FS_proto.WRITING = 1;
	FS_proto.DONE = 2;

	FS_proto.error =
	FS_proto.onwritestart =
	FS_proto.onprogress =
	FS_proto.onwrite =
	FS_proto.onabort =
	FS_proto.onerror =
	FS_proto.onwriteend =
		null;

	return saveAs;
}(
	   typeof self !== "undefined" && self
	|| typeof window !== "undefined" && window
	|| this.content
));
// `self` is undefined in Firefox for Android content script context
// while `this` is nsIContentFrameMessageManager
// with an attribute `content` that corresponds to the window

if (typeof module !== "undefined" && module.exports) {
  module.exports.saveAs = saveAs;
} else if ((typeof define !== "undefined" && define !== null) && (define.amd !== null)) {
  define([], function() {
    return saveAs;
  });
}

!function(e){if("object"==typeof exports&&"undefined"!=typeof module)module.exports=e();else if("function"==typeof define&&define.amd)define([],e);else{var n;"undefined"!=typeof window?n=window:"undefined"!=typeof global?n=global:"undefined"!=typeof self&&(n=self),n.ramlClientGenerator=e()}}(function(){var define,module,exports;return (function e(t,n,r){function s(o,u){if(!n[o]){if(!t[o]){var a=typeof require=="function"&&require;if(!u&&a)return a(o,!0);if(i)return i(o,!0);var f=new Error("Cannot find module '"+o+"'");throw f.code="MODULE_NOT_FOUND",f}var l=n[o]={exports:{}};t[o][0].call(l.exports,function(e){var n=t[o][1][e];return s(n?n:e)},l,l.exports,e,t,n,r)}return n[o].exports}var i=typeof require=="function"&&require;for(var o=0;o<r.length;o++)s(r[o]);return s})({1:[function(require,module,exports){
/**
 * Map dependencies to their environment.
 *
 * @type {Object}
 */
var DEPS_MAP = {
  node: {
    popsicle:     'require(\'popsicle\')',
    ClientOAuth2: 'require(\'client-oauth2\')'
  },
  amd: {
    popsicle:     '\'popsicle\'',
    ClientOAuth2: '\'ClientOAuth2\''
  },
  browser: {
    popsicle:     'root.popsicle',
    ClientOAuth2: 'root.ClientOAuth2'
  }
};

/**
 * Map an array of dependency names to values.
 *
 * @param  {Array}  deps
 * @param  {String} env
 * @return {Array}
 */
function mapDeps (deps, env) {
  if (!env) {
    return deps;
  }

  return deps.map(function (dep) {
    return DEPS_MAP[env][dep];
  });
}

/**
 * Create a dependencies string.
 *
 * @param  {Object} context
 * @param  {String} env
 * @return {String}
 */
module.exports = function (context, env) {
  var deps = ['popsicle'];

  // OAuth 2.0 depends on ClientOAuth2 to work.
  if (context.security['OAuth 2.0']) {
    deps.push('ClientOAuth2');
  }

  // Returns an array of strings for AMD.
  if (env === 'amd') {
    return '[' + mapDeps(deps, env).join(', ') + ']';
  }

  return mapDeps(deps, env).join(', ');
};

},{}],2:[function(require,module,exports){
/**
 * Iterate over the parameters and turn into a string.
 *
 * @param  {Object} parameters
 * @return {String}
 */
module.exports = function (parameters) {
  return Object.keys(parameters).map(function (key) {
    var parameter = parameters[key];
    var title     = '* **' + parameter.displayName + '**';
    var options   = [];

    if (parameter.type) {
      options.push(parameter.type);
    }

    if (Array.isArray(parameter.enum) && parameter.enum.length) {
      options.push('one of (' + parameter.enum.join(', ') + ')');
    }

    if (parameter.default) {
      options.push('default: ' + parameter.default);
    }

    return title +
      (options.length ? ' _' + options.join(', ') + '_' : '') +
      (parameter.description ? '\n\n' + parameter.description : '');
  }).join('\n\n');
};

},{}],3:[function(require,module,exports){
/**
 * Pull out request parameters from the resource.
 *
 * @param  {Object} resource
 * @return {String}
 */
var params = function (resource) {
  return resource.uriParameters.map(function (param) {
    return param.displayName;
  }).join(', ');
};

/**
 * Stringify a resource into a request snippet.
 *
 * @param  {Object} resource
 * @return {String}
 */
module.exports = function (resource) {
  var parts = [];
  var part  = resource;

  while (part && part.parent) {
    var segment = part.key;

    // If uri parameters exist, push onto the stack.
    if (part.uriParameters.length) {
      segment += '(' + params(part) + ')';
    }

    parts.unshift(segment);

    part = part.parent;
  }

  return 'resources' + (parts.length ? '.' + parts.join('.') : '');
};

},{}],4:[function(require,module,exports){
var generator = require('../../lib/generator');

/**
 * Export a client generator instance.
 *
 * @type {Function}
 */
module.exports = generator({
  templates: {
    '.gitignore':   require('./templates/.gitignore.hbs'),
    'index.js':     require('./templates/index.js.hbs'),
    'README.md':    require('./templates/README.md.hbs'),
    'INSTALL.md':   require('./templates/INSTALL.md.hbs'),
    'package.json': require('./templates/package.json.hbs')
  },
  format: {
    variable: require('camel-case')
  },
  partials: {
    auth:      require('./partials/auth.js.hbs'),
    utils:     require('./partials/utils.js.hbs'),
    client:    require('./partials/client.js.hbs'),
    resources: require('./partials/resources.js.hbs')
  },
  helpers: {
    stringify:         require('javascript-stringify'),
    dependencies:      require('./helpers/dependencies'),
    requestSnippet:    require('./helpers/request-snippet'),
    parametersSnippet: require('./helpers/parameters-snippet')
  }
});

},{"../../lib/generator":20,"./helpers/dependencies":1,"./helpers/parameters-snippet":2,"./helpers/request-snippet":3,"./partials/auth.js.hbs":5,"./partials/client.js.hbs":6,"./partials/resources.js.hbs":7,"./partials/utils.js.hbs":8,"./templates/.gitignore.hbs":9,"./templates/INSTALL.md.hbs":10,"./templates/README.md.hbs":11,"./templates/index.js.hbs":12,"./templates/package.json.hbs":13,"camel-case":27,"javascript-stringify":45}],5:[function(require,module,exports){
// hbsfy compiled Handlebars template
var HandlebarsCompiler = require('hbsfy/runtime');
module.exports = HandlebarsCompiler.template({"1":function(depth0,helpers,partials,data) {
    var stack1;

  return "/**\n * @param {Object} options\n */\nfunction OAuth2 (options) {\n  ClientOAuth2.call(this, extend("
    + ((stack1 = (helpers.stringify || (depth0 && depth0.stringify) || helpers.helperMissing).call(depth0,((stack1 = ((stack1 = (depth0 != null ? depth0.security : depth0)) != null ? stack1['OAuth 2.0'] : stack1)) != null ? stack1.settings : stack1),{"name":"stringify","hash":{},"data":data})) != null ? stack1 : "")
    + ", options));\n}\n\nOAuth2.prototype = Object.create(ClientOAuth2.prototype);\nOAuth2.prototype.constructor = OAuth2;\nOAuth2.prototype.request = popsicle;\n\nClient.OAuth2 = OAuth2;\n";
},"compiler":[6,">= 2.0.0-beta.1"],"main":function(depth0,helpers,partials,data) {
    var stack1;

  return ((stack1 = helpers['if'].call(depth0,((stack1 = (depth0 != null ? depth0.security : depth0)) != null ? stack1['OAuth 2.0'] : stack1),{"name":"if","hash":{},"fn":this.program(1, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "");
},"useData":true});

},{"hbsfy/runtime":41}],6:[function(require,module,exports){
// hbsfy compiled Handlebars template
var HandlebarsCompiler = require('hbsfy/runtime');
module.exports = HandlebarsCompiler.template({"compiler":[6,">= 2.0.0-beta.1"],"main":function(depth0,helpers,partials,data) {
    var stack1, alias1=helpers.helperMissing;

  return "function Client (options) {\n  this.options = extend({\n    baseUri: "
    + ((stack1 = (helpers.stringify || (depth0 && depth0.stringify) || alias1).call(depth0,(depth0 != null ? depth0.baseUri : depth0),{"name":"stringify","hash":{},"data":data})) != null ? stack1 : "")
    + ",\n    baseUriParameters: "
    + ((stack1 = (helpers.stringify || (depth0 && depth0.stringify) || alias1).call(depth0,(helpers.object || (depth0 && depth0.object) || alias1).call(depth0,(helpers.keys || (depth0 && depth0.keys) || alias1).call(depth0,(depth0 != null ? depth0.baseUriParameters : depth0),{"name":"keys","hash":{},"data":data}),(helpers.pluck || (depth0 && depth0.pluck) || alias1).call(depth0,(depth0 != null ? depth0.baseUriParameters : depth0),"default",{"name":"pluck","hash":{},"data":data}),{"name":"object","hash":{},"data":data}),{"name":"stringify","hash":{},"data":data})) != null ? stack1 : "")
    + "\n  }, options);\n\n  this.resources = new "
    + this.escapeExpression((helpers.pascalCase || (depth0 && depth0.pascalCase) || alias1).call(depth0,((stack1 = (depth0 != null ? depth0.resources : depth0)) != null ? stack1.id : stack1),{"name":"pascalCase","hash":{},"data":data}))
    + "('', this);\n};\n\nClient.prototype.resource = function (route, parameters) {\n  var path = '/' + template(route, parameters).replace(/^\\//, '');\n\n  return new CustomResource(path, this);\n};\n\nClient.prototype.request = popsicle;\nClient.prototype.form = Client.form = popsicle.form;\nClient.prototype.version  = "
    + ((stack1 = (helpers.stringify || (depth0 && depth0.stringify) || alias1).call(depth0,(depth0 != null ? depth0.version : depth0),{"name":"stringify","hash":{},"data":data})) != null ? stack1 : "")
    + ";\n";
},"useData":true});

},{"hbsfy/runtime":41}],7:[function(require,module,exports){
// hbsfy compiled Handlebars template
var HandlebarsCompiler = require('hbsfy/runtime');
module.exports = HandlebarsCompiler.template({"1":function(depth0,helpers,partials,data,blockParams,depths) {
    var stack1;

  return "function "
    + this.escapeExpression((helpers.pascalCase || (depth0 && depth0.pascalCase) || helpers.helperMissing).call(depth0,(depth0 != null ? depth0.id : depth0),{"name":"pascalCase","hash":{},"data":data}))
    + " (uri, client) {\n  this._uri    = uri;\n  this._client = client;\n\n"
    + ((stack1 = helpers.each.call(depth0,(depth0 != null ? depth0.children : depth0),{"name":"each","hash":{},"fn":this.program(2, data, 0, blockParams, depths),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + "};\n\n"
    + ((stack1 = helpers.each.call(depth0,(depth0 != null ? depth0.children : depth0),{"name":"each","hash":{},"fn":this.program(5, data, 0, blockParams, depths),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + "\n"
    + ((stack1 = helpers.each.call(depth0,(depth0 != null ? depth0.methods : depth0),{"name":"each","hash":{},"fn":this.program(8, data, 0, blockParams, depths),"inverse":this.noop,"data":data})) != null ? stack1 : "");
},"2":function(depth0,helpers,partials,data) {
    var stack1;

  return ((stack1 = helpers.unless.call(depth0,(depth0 != null ? depth0.uriParameters : depth0),{"name":"unless","hash":{},"fn":this.program(3, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "");
},"3":function(depth0,helpers,partials,data) {
    var stack1, helper, alias1=helpers.helperMissing, alias2=this.escapeExpression;

  return "  this."
    + alias2(((helper = (helper = helpers.key || (data && data.key)) != null ? helper : alias1),(typeof helper === "function" ? helper.call(depth0,{"name":"key","hash":{},"data":data}) : helper)))
    + " = new "
    + alias2((helpers.pascalCase || (depth0 && depth0.pascalCase) || alias1).call(depth0,(depth0 != null ? depth0.id : depth0),{"name":"pascalCase","hash":{},"data":data}))
    + "(uri + "
    + ((stack1 = (helpers.stringify || (depth0 && depth0.stringify) || alias1).call(depth0,(depth0 != null ? depth0.relativeUri : depth0),{"name":"stringify","hash":{},"data":data})) != null ? stack1 : "")
    + ", client);\n";
},"5":function(depth0,helpers,partials,data,blockParams,depths) {
    var stack1;

  return ((stack1 = helpers['if'].call(depth0,(depth0 != null ? depth0.uriParameters : depth0),{"name":"if","hash":{},"fn":this.program(6, data, 0, blockParams, depths),"inverse":this.noop,"data":data})) != null ? stack1 : "");
},"6":function(depth0,helpers,partials,data,blockParams,depths) {
    var stack1, helper, alias1=helpers.helperMissing, alias2=this.escapeExpression;

  return alias2((helpers.pascalCase || (depth0 && depth0.pascalCase) || alias1).call(depth0,(depths[2] != null ? depths[2].id : depths[2]),{"name":"pascalCase","hash":{},"data":data}))
    + ".prototype."
    + alias2(((helper = (helper = helpers.key || (data && data.key)) != null ? helper : alias1),(typeof helper === "function" ? helper.call(depth0,{"name":"key","hash":{},"data":data}) : helper)))
    + " = function (/* ...args */) {\n  var uri = this._uri + template("
    + ((stack1 = (helpers.stringify || (depth0 && depth0.stringify) || alias1).call(depth0,(depth0 != null ? depth0.relativeUri : depth0),{"name":"stringify","hash":{},"data":data})) != null ? stack1 : "")
    + ", arguments, "
    + ((stack1 = (helpers.stringify || (depth0 && depth0.stringify) || alias1).call(depth0,(helpers.pluck || (depth0 && depth0.pluck) || alias1).call(depth0,(depth0 != null ? depth0.uriParameters : depth0),"default",{"name":"pluck","hash":{},"data":data}),{"name":"stringify","hash":{},"data":data})) != null ? stack1 : "")
    + ");\n\n  return new "
    + alias2((helpers.pascalCase || (depth0 && depth0.pascalCase) || alias1).call(depth0,(depth0 != null ? depth0.id : depth0),{"name":"pascalCase","hash":{},"data":data}))
    + "(uri, this._client);\n};\n";
},"8":function(depth0,helpers,partials,data,blockParams,depths) {
    var stack1, helper, alias1=helpers.helperMissing, alias2=this.escapeExpression;

  return alias2((helpers.pascalCase || (depth0 && depth0.pascalCase) || alias1).call(depth0,(depths[1] != null ? depths[1].id : depths[1]),{"name":"pascalCase","hash":{},"data":data}))
    + ".prototype."
    + alias2(((helper = (helper = helpers.key || (data && data.key)) != null ? helper : alias1),(typeof helper === "function" ? helper.call(depth0,{"name":"key","hash":{},"data":data}) : helper)))
    + " = function (body, options) {\n"
    + ((stack1 = helpers['if'].call(depth0,(helpers.keys || (depth0 && depth0.keys) || alias1).call(depth0,(depth0 != null ? depth0.headers : depth0),{"name":"keys","hash":{},"data":data}),{"name":"if","hash":{},"fn":this.program(9, data, 0, blockParams, depths),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + "  return handleRequest(this._client, this._uri, "
    + ((stack1 = (helpers.stringify || (depth0 && depth0.stringify) || alias1).call(depth0,(helpers.upperCase || (depth0 && depth0.upperCase) || alias1).call(depth0,(depth0 != null ? depth0.method : depth0),{"name":"upperCase","hash":{},"data":data}),{"name":"stringify","hash":{},"data":data})) != null ? stack1 : "")
    + ", body, options);\n};\n";
},"9":function(depth0,helpers,partials,data) {
    var stack1, alias1=helpers.helperMissing;

  return "  options = extend({}, options);\n  options.headers = extend("
    + ((stack1 = (helpers.stringify || (depth0 && depth0.stringify) || alias1).call(depth0,(helpers.object || (depth0 && depth0.object) || alias1).call(depth0,(helpers.keys || (depth0 && depth0.keys) || alias1).call(depth0,(depth0 != null ? depth0.headers : depth0),{"name":"keys","hash":{},"data":data}),(helpers.pluck || (depth0 && depth0.pluck) || alias1).call(depth0,(depth0 != null ? depth0.headers : depth0),"default",{"name":"pluck","hash":{},"data":data}),{"name":"object","hash":{},"data":data}),{"name":"stringify","hash":{},"data":data})) != null ? stack1 : "")
    + ", options.headers);\n\n";
},"11":function(depth0,helpers,partials,data) {
    var stack1, alias1=helpers.helperMissing;

  return "CustomResource.prototype."
    + this.escapeExpression((helpers.camelCase || (depth0 && depth0.camelCase) || alias1).call(depth0,depth0,{"name":"camelCase","hash":{},"data":data}))
    + " = function (body, options) {\n  return handleRequest(this._client, this._uri, "
    + ((stack1 = (helpers.stringify || (depth0 && depth0.stringify) || alias1).call(depth0,(helpers.upperCase || (depth0 && depth0.upperCase) || alias1).call(depth0,depth0,{"name":"upperCase","hash":{},"data":data}),{"name":"stringify","hash":{},"data":data})) != null ? stack1 : "")
    + ", body, options);\n};\n";
},"compiler":[6,">= 2.0.0-beta.1"],"main":function(depth0,helpers,partials,data,blockParams,depths) {
    var stack1;

  return "function handleRequest (client, path, method, body, options) {\n  options = extend({}, client.options, options);\n\n  var baseUri = template(options.baseUri, options.baseUriParameters);\n  var hasBody = method !== 'GET' && method !== 'HEAD';\n  var reqOpts = {};\n\n  var reqBody = hasBody && body != null ? body : options.body;\n  var reqQuery = !hasBody && body != null ? body : options.query;\n\n  var reqOpts = {\n    url: baseUri.replace(/\\/$/, '') + path,\n    method: method,\n    headers: extend({}, options.headers),\n    body: reqBody,\n    query: typeof reqQuery === 'object' ? extend({}, reqQuery) : reqQuery\n  };\n\n  if (options.user && typeof options.user.sign === 'function') {\n    options.user.sign(reqOpts);\n  }\n\n  return client.request(reqOpts);\n}\n\n"
    + ((stack1 = helpers.each.call(depth0,(depth0 != null ? depth0.allResources : depth0),{"name":"each","hash":{},"fn":this.program(1, data, 0, blockParams, depths),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + "\nfunction CustomResource (uri, client) {\n  this._uri    = uri;\n  this._client = client;\n}\n\n"
    + ((stack1 = helpers.each.call(depth0,(depth0 != null ? depth0.supportedMethods : depth0),{"name":"each","hash":{},"fn":this.program(11, data, 0, blockParams, depths),"inverse":this.noop,"data":data})) != null ? stack1 : "");
},"useData":true,"useDepths":true});

},{"hbsfy/runtime":41}],8:[function(require,module,exports){
// hbsfy compiled Handlebars template
var HandlebarsCompiler = require('hbsfy/runtime');
module.exports = HandlebarsCompiler.template({"compiler":[6,">= 2.0.0-beta.1"],"main":function(depth0,helpers,partials,data) {
    return "var TEMPLATE_REGEXP = /\\{([^\\{\\}]+)\\}/g;\n\n/**\n * @param  {String} string\n * @param  {Object} interpolate\n * @param  {Object} defaults\n * @return {String}\n */\nfunction template (string, interpolate, defaults) {\n  defaults    = defaults || {};\n  interpolate = interpolate || {};\n\n  return string.replace(TEMPLATE_REGEXP, function (match, key) {\n    if (interpolate[key] != null) {\n      return encodeURIComponent(interpolate[key]);\n    }\n\n    if (defaults[key] != null) {\n      return encodeURIComponent(defaults[key]);\n    }\n\n    return '';\n  });\n}\n\n/**\n * @param  {Object} dest\n * @param  {Object} ...source\n * @return {Object}\n */\nfunction extend (dest /*, ...source */) {\n  for (var i = 1; i < arguments.length; i++) {\n    for (var key in arguments[i]) {\n      dest[key] = arguments[i][key];\n    }\n  }\n\n  return dest;\n}\n";
},"useData":true});

},{"hbsfy/runtime":41}],9:[function(require,module,exports){
// hbsfy compiled Handlebars template
var HandlebarsCompiler = require('hbsfy/runtime');
module.exports = HandlebarsCompiler.template({"compiler":[6,">= 2.0.0-beta.1"],"main":function(depth0,helpers,partials,data) {
    return "node_modules\n";
},"useData":true});

},{"hbsfy/runtime":41}],10:[function(require,module,exports){
// hbsfy compiled Handlebars template
var HandlebarsCompiler = require('hbsfy/runtime');
module.exports = HandlebarsCompiler.template({"compiler":[6,">= 2.0.0-beta.1"],"main":function(depth0,helpers,partials,data) {
    var alias1=helpers.helperMissing, alias2=this.escapeExpression;

  return "# Installation\n\nFollow these instructions to publish and subsequently install the module in your project.\n\n## Git\n\n```\n# Initialize with git\ngit init\ngit add .\ngit commit -m \"initial commit\"\ngit push [git-url]\n\n# Install in project from git\nnpm install [git-url] --save\n```\n\n## Source Directory\n\n```\n# Link module globally\nnpm link\n\n# Link in project to local module\nnpm link "
    + alias2((helpers.paramCase || (depth0 && depth0.paramCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"paramCase","hash":{},"data":data}))
    + "\n```\n\n**Note:** You should publish it before you use it publicly.\n\n## NPM\n\n```\n# Publish to npm\nnpm publish\n\n# Install from npm\nnpm install "
    + alias2((helpers.paramCase || (depth0 && depth0.paramCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"paramCase","hash":{},"data":data}))
    + " --save\n```\n\n## Bower\n\n```\n# Register with bower\nbower register "
    + alias2((helpers.paramCase || (depth0 && depth0.paramCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"paramCase","hash":{},"data":data}))
    + " [git-url]\n\n# Install from bower\nbower install "
    + alias2((helpers.paramCase || (depth0 && depth0.paramCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"paramCase","hash":{},"data":data}))
    + " --save\n```\n";
},"useData":true});

},{"hbsfy/runtime":41}],11:[function(require,module,exports){
// hbsfy compiled Handlebars template
var HandlebarsCompiler = require('hbsfy/runtime');
module.exports = HandlebarsCompiler.template({"1":function(depth0,helpers,partials,data) {
    var stack1, alias1=helpers.helperMissing, alias2=this.escapeExpression;

  return "### Authentication\n\n#### OAuth 2.0\n\nThis API supports authentication with [OAuth 2.0](https://github.com/mulesoft/js-client-oauth2). Initialize the `OAuth2` instance with the application client id, client secret and a redirect uri to authenticate with users.\n\n```js\nvar auth = new "
    + alias2((helpers.pascalCase || (depth0 && depth0.pascalCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"pascalCase","hash":{},"data":data}))
    + ".OAuth2({\n  clientId:     '123',\n  clientSecret: 'abc',\n  redirectUri:  'http://example.com/auth/callback'\n});\n```\n\n**All `getToken()` calls are asynchronous and return promise objects which resolve to an access token instance.**\n\n"
    + ((stack1 = helpers['if'].call(depth0,(helpers.contains || (depth0 && depth0.contains) || alias1).call(depth0,((stack1 = ((stack1 = ((stack1 = (depth0 != null ? depth0.security : depth0)) != null ? stack1['OAuth 2.0'] : stack1)) != null ? stack1.settings : stack1)) != null ? stack1.authorizationGrants : stack1),"code",{"name":"contains","hash":{},"data":data}),{"name":"if","hash":{},"fn":this.program(2, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + ((stack1 = helpers['if'].call(depth0,(helpers.contains || (depth0 && depth0.contains) || alias1).call(depth0,((stack1 = ((stack1 = ((stack1 = (depth0 != null ? depth0.security : depth0)) != null ? stack1['OAuth 2.0'] : stack1)) != null ? stack1.settings : stack1)) != null ? stack1.authorizationGrants : stack1),"token",{"name":"contains","hash":{},"data":data}),{"name":"if","hash":{},"fn":this.program(4, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + ((stack1 = helpers['if'].call(depth0,(helpers.contains || (depth0 && depth0.contains) || alias1).call(depth0,((stack1 = ((stack1 = ((stack1 = (depth0 != null ? depth0.security : depth0)) != null ? stack1['OAuth 2.0'] : stack1)) != null ? stack1.settings : stack1)) != null ? stack1.authorizationGrants : stack1),"owner",{"name":"contains","hash":{},"data":data}),{"name":"if","hash":{},"fn":this.program(6, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + ((stack1 = helpers['if'].call(depth0,(helpers.contains || (depth0 && depth0.contains) || alias1).call(depth0,((stack1 = ((stack1 = ((stack1 = (depth0 != null ? depth0.security : depth0)) != null ? stack1['OAuth 2.0'] : stack1)) != null ? stack1.settings : stack1)) != null ? stack1.authorizationGrants : stack1),"credentials",{"name":"contains","hash":{},"data":data}),{"name":"if","hash":{},"fn":this.program(8, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + "##### Access Tokens\n\nAccess token instances can be manually re-created. This is critical for access token reuse, such as saving credentials to a database for reusing later in the codebase.\n\n```js\nvar token = auth.createToken('access token', 'refresh token');\n```\n\nAn access token instance (manually created or automatically generated by a `getToken()` method) can be passed into any API request. This will sign the API request with the current users access token credentials.\n\n```js\n// Existing API client instance.\nclient.resource('/').get(null, {\n  user: token\n});\n\n// New API client instance.\nvar client = new "
    + alias2((helpers.pascalCase || (depth0 && depth0.pascalCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"pascalCase","hash":{},"data":data}))
    + "({\n  user: token\n});\n```\n\n";
},"2":function(depth0,helpers,partials,data) {
    return "##### [Authorization Code Grant](https://github.com/mulesoft/js-client-oauth2#authorization-code-grant)\n\n1. Redirect user to `auth.code.getUri()`.\n2. Parse response uri and get an access token instance using `auth.code.getToken(uri)`.\n\n";
},"4":function(depth0,helpers,partials,data) {
    return "\n##### [Implicit Grant](https://github.com/mulesoft/js-client-oauth2#implicit-grant)\n\n1. Redirect user to `auth.token.getUri()` in a browser.\n2. Parse response uri and get an access token instance using `auth.token.getToken(uri)`.\n\n";
},"6":function(depth0,helpers,partials,data) {
    return "\n##### [Resource Owner Password Credentials Grant](https://github.com/mulesoft/js-client-oauth2#resource-owner-password-credentials-grant)\n\n1. Make a direct request for the access token on behalf of the user using `auth.owner.getToken(username, password)`.\n\n";
},"8":function(depth0,helpers,partials,data) {
    return "\n##### [Client Credentials Grant](https://github.com/mulesoft/js-client-oauth2#client-credentials-grant)\n\n1. Get the access token for the application by using `auth.credentials.getToken()`.\n\n";
},"10":function(depth0,helpers,partials,data) {
    var helper;

  return this.escapeExpression(((helper = (helper = helpers.version || (depth0 != null ? depth0.version : depth0)) != null ? helper : helpers.helperMissing),(typeof helper === "function" ? helper.call(depth0,{"name":"version","hash":{},"data":data}) : helper)));
},"12":function(depth0,helpers,partials,data) {
    return "v3";
},"14":function(depth0,helpers,partials,data) {
    var stack1;

  return ((stack1 = helpers['if'].call(depth0,(helpers.keys || (depth0 && depth0.keys) || helpers.helperMissing).call(depth0,(depth0 != null ? depth0.methods : depth0),{"name":"keys","hash":{},"data":data}),{"name":"if","hash":{},"fn":this.program(15, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "");
},"15":function(depth0,helpers,partials,data) {
    var stack1, alias1=helpers.helperMissing;

  return "#### "
    + ((stack1 = (helpers.requestSnippet || (depth0 && depth0.requestSnippet) || alias1).call(depth0,depth0,{"name":"requestSnippet","hash":{},"data":data})) != null ? stack1 : "")
    + "\n\n"
    + ((stack1 = helpers['if'].call(depth0,(depth0 != null ? depth0.uriParameters : depth0),{"name":"if","hash":{},"fn":this.program(16, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + ((stack1 = helpers['if'].call(depth0,(depth0 != null ? depth0.description : depth0),{"name":"if","hash":{},"fn":this.program(18, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + "```js\nvar resource = client."
    + ((stack1 = (helpers.requestSnippet || (depth0 && depth0.requestSnippet) || alias1).call(depth0,depth0,{"name":"requestSnippet","hash":{},"data":data})) != null ? stack1 : "")
    + ";\n```\n\n"
    + ((stack1 = helpers.each.call(depth0,(depth0 != null ? depth0.methods : depth0),{"name":"each","hash":{},"fn":this.program(20, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "");
},"16":function(depth0,helpers,partials,data) {
    var stack1;

  return ((stack1 = (helpers.parametersSnippet || (depth0 && depth0.parametersSnippet) || helpers.helperMissing).call(depth0,(depth0 != null ? depth0.uriParameters : depth0),{"name":"parametersSnippet","hash":{},"data":data})) != null ? stack1 : "")
    + "\n\n";
},"18":function(depth0,helpers,partials,data) {
    var stack1, helper;

  return ((stack1 = ((helper = (helper = helpers.description || (depth0 != null ? depth0.description : depth0)) != null ? helper : helpers.helperMissing),(typeof helper === "function" ? helper.call(depth0,{"name":"description","hash":{},"data":data}) : helper))) != null ? stack1 : "")
    + "\n\n";
},"20":function(depth0,helpers,partials,data) {
    var stack1, helper, alias1=helpers.helperMissing, alias2=this.escapeExpression;

  return "##### "
    + alias2((helpers.upperCase || (depth0 && depth0.upperCase) || alias1).call(depth0,(depth0 != null ? depth0.method : depth0),{"name":"upperCase","hash":{},"data":data}))
    + "\n\n"
    + ((stack1 = helpers['if'].call(depth0,(depth0 != null ? depth0.description : depth0),{"name":"if","hash":{},"fn":this.program(18, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + "```js\nresource."
    + alias2(((helper = (helper = helpers.key || (depth0 != null ? depth0.key : depth0)) != null ? helper : alias1),(typeof helper === "function" ? helper.call(depth0,{"name":"key","hash":{},"data":data}) : helper)))
    + "().then(function (res) { ... });\n```\n\n"
    + ((stack1 = helpers['if'].call(depth0,(helpers.keys || (depth0 && depth0.keys) || alias1).call(depth0,(depth0 != null ? depth0.queryParameters : depth0),{"name":"keys","hash":{},"data":data}),{"name":"if","hash":{},"fn":this.program(21, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + ((stack1 = helpers['if'].call(depth0,(helpers.keys || (depth0 && depth0.keys) || alias1).call(depth0,(depth0 != null ? depth0.headers : depth0),{"name":"keys","hash":{},"data":data}),{"name":"if","hash":{},"fn":this.program(26, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + ((stack1 = helpers['if'].call(depth0,(helpers.keys || (depth0 && depth0.keys) || alias1).call(depth0,(depth0 != null ? depth0.body : depth0),{"name":"keys","hash":{},"data":data}),{"name":"if","hash":{},"fn":this.program(28, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "");
},"21":function(depth0,helpers,partials,data) {
    var stack1, alias1=helpers.helperMissing;

  return "##### Query Parameters\n\n```javascript\n"
    + ((stack1 = helpers['if'].call(depth0,(helpers.equal || (depth0 && depth0.equal) || alias1).call(depth0,(depth0 != null ? depth0.method : depth0),"get",{"name":"equal","hash":{},"data":data}),{"name":"if","hash":{},"fn":this.program(22, data, 0),"inverse":this.program(24, data, 0),"data":data})) != null ? stack1 : "")
    + "```\n\n"
    + ((stack1 = (helpers.parametersSnippet || (depth0 && depth0.parametersSnippet) || alias1).call(depth0,(depth0 != null ? depth0.queryParameters : depth0),{"name":"parametersSnippet","hash":{},"data":data})) != null ? stack1 : "")
    + "\n\n";
},"22":function(depth0,helpers,partials,data) {
    var helper;

  return "resource."
    + this.escapeExpression(((helper = (helper = helpers.key || (depth0 != null ? depth0.key : depth0)) != null ? helper : helpers.helperMissing),(typeof helper === "function" ? helper.call(depth0,{"name":"key","hash":{},"data":data}) : helper)))
    + "({ ... });\n";
},"24":function(depth0,helpers,partials,data) {
    var helper;

  return "resource."
    + this.escapeExpression(((helper = (helper = helpers.key || (depth0 != null ? depth0.key : depth0)) != null ? helper : helpers.helperMissing),(typeof helper === "function" ? helper.call(depth0,{"name":"key","hash":{},"data":data}) : helper)))
    + "(null, { query: { ... } });\n";
},"26":function(depth0,helpers,partials,data) {
    var stack1, helper, alias1=helpers.helperMissing;

  return "##### Headers\n\n```javascript\nresource."
    + this.escapeExpression(((helper = (helper = helpers.key || (depth0 != null ? depth0.key : depth0)) != null ? helper : alias1),(typeof helper === "function" ? helper.call(depth0,{"name":"key","hash":{},"data":data}) : helper)))
    + "(null, {\n  headers: { ... }\n});\n```\n\n"
    + ((stack1 = (helpers.parametersSnippet || (depth0 && depth0.parametersSnippet) || alias1).call(depth0,(depth0 != null ? depth0.headers : depth0),{"name":"parametersSnippet","hash":{},"data":data})) != null ? stack1 : "")
    + "\n\n";
},"28":function(depth0,helpers,partials,data) {
    var stack1;

  return "##### Body\n\n"
    + ((stack1 = helpers.each.call(depth0,(depth0 != null ? depth0.body : depth0),{"name":"each","hash":{},"fn":this.program(29, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "");
},"29":function(depth0,helpers,partials,data) {
    var stack1, helper;

  return "**"
    + this.escapeExpression(((helper = (helper = helpers.key || (data && data.key)) != null ? helper : helpers.helperMissing),(typeof helper === "function" ? helper.call(depth0,{"name":"key","hash":{},"data":data}) : helper)))
    + "**\n\n"
    + ((stack1 = helpers['if'].call(depth0,(depth0 != null ? depth0.schema : depth0),{"name":"if","hash":{},"fn":this.program(30, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + ((stack1 = helpers['if'].call(depth0,(depth0 != null ? depth0.formParameters : depth0),{"name":"if","hash":{},"fn":this.program(32, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "");
},"30":function(depth0,helpers,partials,data) {
    var stack1, helper;

  return "```\n"
    + ((stack1 = ((helper = (helper = helpers.schema || (depth0 != null ? depth0.schema : depth0)) != null ? helper : helpers.helperMissing),(typeof helper === "function" ? helper.call(depth0,{"name":"schema","hash":{},"data":data}) : helper))) != null ? stack1 : "")
    + "\n```\n\n";
},"32":function(depth0,helpers,partials,data) {
    var stack1;

  return ((stack1 = (helpers.json || (depth0 && depth0.json) || helpers.helperMissing).call(depth0,(depth0 != null ? depth0.formParameters : depth0),2,{"name":"json","hash":{},"data":data})) != null ? stack1 : "")
    + "\n\n";
},"compiler":[6,">= 2.0.0-beta.1"],"main":function(depth0,helpers,partials,data) {
    var stack1, helper, alias1=helpers.helperMissing, alias2="function", alias3=this.escapeExpression;

  return "# "
    + alias3(((helper = (helper = helpers.title || (depth0 != null ? depth0.title : depth0)) != null ? helper : alias1),(typeof helper === alias2 ? helper.call(depth0,{"name":"title","hash":{},"data":data}) : helper)))
    + "\n\nBrowser and node module for making API requests against ["
    + alias3(((helper = (helper = helpers.title || (depth0 != null ? depth0.title : depth0)) != null ? helper : alias1),(typeof helper === alias2 ? helper.call(depth0,{"name":"title","hash":{},"data":data}) : helper)))
    + "]("
    + alias3(((helper = (helper = helpers.baseUri || (depth0 != null ? depth0.baseUri : depth0)) != null ? helper : alias1),(typeof helper === alias2 ? helper.call(depth0,{"name":"baseUri","hash":{},"data":data}) : helper)))
    + ").\n\n**Please note: This module uses [Popsicle](https://github.com/blakeembrey/popsicle) to make API requests. Promises must be supported or polyfilled on all target environments.**\n\n## Installation\n\n```\nnpm install "
    + alias3((helpers.paramCase || (depth0 && depth0.paramCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"paramCase","hash":{},"data":data}))
    + " --save\nbower install "
    + alias3((helpers.paramCase || (depth0 && depth0.paramCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"paramCase","hash":{},"data":data}))
    + " --save\n```\n\n## Usage\n\n### Node\n\n```javascript\nvar "
    + alias3((helpers.pascalCase || (depth0 && depth0.pascalCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"pascalCase","hash":{},"data":data}))
    + " = require('"
    + alias3((helpers.paramCase || (depth0 && depth0.paramCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"paramCase","hash":{},"data":data}))
    + "');\n\nvar client = new "
    + alias3((helpers.pascalCase || (depth0 && depth0.pascalCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"pascalCase","hash":{},"data":data}))
    + "();\n```\n\n### Browsers\n\n```html\n<script src=\""
    + alias3((helpers.paramCase || (depth0 && depth0.paramCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"paramCase","hash":{},"data":data}))
    + "/index.js\">\n\n<script>\n  var client = new window."
    + alias3((helpers.pascalCase || (depth0 && depth0.pascalCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"pascalCase","hash":{},"data":data}))
    + "();\n</script>\n```\n\n"
    + ((stack1 = helpers['if'].call(depth0,((stack1 = (depth0 != null ? depth0.security : depth0)) != null ? stack1['OAuth 2.0'] : stack1),{"name":"if","hash":{},"fn":this.program(1, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + "### Options\n\nYou can set options when you initialize a client or at any time with the `options` property. You may also override options for a single request by passing an object as the second argument of any request method. For example:\n\n```javascript\nvar client = new "
    + alias3((helpers.pascalCase || (depth0 && depth0.pascalCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"pascalCase","hash":{},"data":data}))
    + "({ ... });\n\nclient.options = { ... };\n\nclient.resource('/').get(null, {\n  baseUri: 'http://example.com',\n  headers: {\n    'Content-Type': 'application/json'\n  }\n});\n```\n\n#### Base URI\n\nYou can override the base URI by setting the `baseUri` property, or initializing a client with a base URI. For example:\n\n```javascript\nnew "
    + alias3((helpers.pascalCase || (depth0 && depth0.pascalCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"pascalCase","hash":{},"data":data}))
    + "({\n  baseUri: 'https://example.com'\n});\n```\n\n#### Base URI Parameters\n\nIf the base URI has parameters inline, you can set them by updating the `baseUriParameters` property. For example:\n\n```javascript\nclient.options.baseUriParameters.version = '"
    + ((stack1 = helpers['if'].call(depth0,(depth0 != null ? depth0.version : depth0),{"name":"if","hash":{},"fn":this.program(10, data, 0),"inverse":this.program(12, data, 0),"data":data})) != null ? stack1 : "")
    + "';\n```\n\n### Resources\n\nAll methods return a HTTP request instance of [Popsicle](https://github.com/blakeembrey/popsicle), which allows the use of promises (and streaming in node).\n\n"
    + ((stack1 = helpers.each.call(depth0,(depth0 != null ? depth0.allResources : depth0),{"name":"each","hash":{},"fn":this.program(14, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + "\n\n### Custom Resources\n\nYou can make requests to a custom path in the API using the `#resource(path)` method.\n\n```javascript\nclient.resource('/example/path').get();\n```\n\n## License\n\nApache 2.0\n";
},"useData":true});

},{"hbsfy/runtime":41}],12:[function(require,module,exports){
// hbsfy compiled Handlebars template
var HandlebarsCompiler = require('hbsfy/runtime');
module.exports = HandlebarsCompiler.template({"1":function(depth0,helpers,partials,data) {
    var stack1;

  return ((stack1 = this.invokePartial(partials.utils,depth0,{"name":"utils","data":data,"helpers":helpers,"partials":partials})) != null ? stack1 : "")
    + "\n"
    + ((stack1 = this.invokePartial(partials.resources,depth0,{"name":"resources","data":data,"helpers":helpers,"partials":partials})) != null ? stack1 : "")
    + "\n"
    + ((stack1 = this.invokePartial(partials.client,depth0,{"name":"client","data":data,"helpers":helpers,"partials":partials})) != null ? stack1 : "")
    + "\n"
    + ((stack1 = this.invokePartial(partials.auth,depth0,{"name":"auth","data":data,"helpers":helpers,"partials":partials})) != null ? stack1 : "")
    + "\nreturn Client;\n";
},"compiler":[6,">= 2.0.0-beta.1"],"main":function(depth0,helpers,partials,data) {
    var stack1, alias1=helpers.helperMissing;

  return "(function (root, client) {\n  if (typeof define === 'function' && define.amd) {\n    // AMD. Register as an anonymous module.\n    define("
    + ((stack1 = (helpers.dependencies || (depth0 && depth0.dependencies) || alias1).call(depth0,depth0,"amd",{"name":"dependencies","hash":{},"data":data})) != null ? stack1 : "")
    + ", client);\n  } else if (typeof exports === 'object') {\n    // Node. Does not work with strict CommonJS, but only CommonJS-like\n    // environments that support `module.exports`, like Node.\n    module.exports = client("
    + ((stack1 = (helpers.dependencies || (depth0 && depth0.dependencies) || alias1).call(depth0,depth0,"node",{"name":"dependencies","hash":{},"data":data})) != null ? stack1 : "")
    + ");\n  } else {\n    // Browser globals (root is window).\n    root."
    + this.escapeExpression((helpers.pascalCase || (depth0 && depth0.pascalCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"pascalCase","hash":{},"data":data}))
    + " = client("
    + ((stack1 = (helpers.dependencies || (depth0 && depth0.dependencies) || alias1).call(depth0,depth0,"browser",{"name":"dependencies","hash":{},"data":data})) != null ? stack1 : "")
    + ");\n  }\n})(this, function ("
    + ((stack1 = (helpers.dependencies || (depth0 && depth0.dependencies) || alias1).call(depth0,depth0,false,{"name":"dependencies","hash":{},"data":data})) != null ? stack1 : "")
    + ") {\n"
    + ((stack1 = (helpers.indent || (depth0 && depth0.indent) || alias1).call(depth0,2,{"name":"indent","hash":{},"fn":this.program(1, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + "});\n";
},"usePartial":true,"useData":true});

},{"hbsfy/runtime":41}],13:[function(require,module,exports){
// hbsfy compiled Handlebars template
var HandlebarsCompiler = require('hbsfy/runtime');
module.exports = HandlebarsCompiler.template({"1":function(depth0,helpers,partials,data) {
    return "\"client-oauth2\": \"^0.1.0\",\n    ";
},"compiler":[6,">= 2.0.0-beta.1"],"main":function(depth0,helpers,partials,data) {
    var stack1, helper, alias1=helpers.helperMissing, alias2=this.escapeExpression;

  return "{\n  \"name\": \""
    + alias2((helpers.paramCase || (depth0 && depth0.paramCase) || alias1).call(depth0,(depth0 != null ? depth0.title : depth0),{"name":"paramCase","hash":{},"data":data}))
    + "\",\n  \"version\": \"0.0.0\",\n  \"description\": \""
    + alias2(((helper = (helper = helpers.description || (depth0 != null ? depth0.description : depth0)) != null ? helper : alias1),(typeof helper === "function" ? helper.call(depth0,{"name":"description","hash":{},"data":data}) : helper)))
    + "\",\n  \"main\": \"index.js\",\n  \"files\": [\n    \"index.js\"\n  ],\n  \"repository\": {\n    \"type\": \"git\",\n    \"url\": \"git://github.com/mulesoft/raml-client-generator.git\"\n  },\n  \"keywords\": [\n    \"raml-api\"\n  ],\n  \"author\": \"MuleSoft, Inc.\",\n  \"license\": \"Apache 2.0\",\n  \"bugs\": {\n    \"url\": \"https://github.com/mulesoft/raml-client-generator/issues\"\n  },\n  \"homepage\": \"https://github.com/mulesoft/raml-client-generator\",\n  \"dependencies\": {\n    "
    + ((stack1 = helpers['if'].call(depth0,((stack1 = (depth0 != null ? depth0.security : depth0)) != null ? stack1['OAuth 2.0'] : stack1),{"name":"if","hash":{},"fn":this.program(1, data, 0),"inverse":this.noop,"data":data})) != null ? stack1 : "")
    + "\"popsicle\": \"^0.3.6\"\n  }\n}\n";
},"useData":true});

},{"hbsfy/runtime":41}],14:[function(require,module,exports){
var extend             = require('extend');
var sanitizeUri        = require('./uri');
var sanitizeSecurity   = require('./security');
var sanitizeResources  = require('./resources');
var sanitizeParameters = require('./parameters');

/**
 * Track indexes of each generated id.
 *
 * @type {Object}
 */
var PARAM_IDS;

/**
 * Default formatting options.
 *
 * @type {Object}
 */
var DEFAULT_FORMAT = {
  /**
   * Replace with your preferred uri templating language.
   *
   * @param  {String} uri
   * @return {String}
   */
  uri: function (uri) {
    return uri;
  },
  /**
   * Variable formatting support. By default, we'll just throw an error.
   */
  variable: function () {
    throw new Error('No variable format specified');
  },
  /**
   * Generate unique ids each spec iteration.
   */
  uniqueId: function (prefix) {
    var id = ++PARAM_IDS[prefix] || (PARAM_IDS[prefix] = 0);

    return prefix + id;
  }
};

/**
 * Validate (and sanitize) the passed in spec object.
 *
 * @param  {Obejct} spec
 * @return {Obejct}
 */
var validateSpec = function (spec) {
  // Reset the id generations.
  PARAM_IDS = {};

  spec.format = extend({}, DEFAULT_FORMAT, spec.format);

  return extend({}, spec);
};

/**
 * Flatten the resources object tree into an array.
 *
 * @param  {Object} resources
 * @return {Array}
 */
var flattenResources = function (resources) {
  var array = [];

  // Recursively push all resources into a single flattened array.
  (function recurse (resource) {
    array.push(resource);

    Object.keys(resource.children).forEach(function (key) {
      recurse(resource.children[key]);
    });
  })(resources);

  return array;
};

/**
 * Flatten the resources object into an array of methods.
 *
 * @param  {Object} resources
 * @return {Array}
 */
var flattenMethods = function (resources) {
  var array = [];

  // Recursively push all methods into a single flattened array.
  (function recurse (resource) {
    if (resource.methods) {
      Object.keys(resource.methods).forEach(function (key) {
        array.push(resource.methods[key]);
      });
    }

    Object.keys(resource.children).forEach(function (key) {
      recurse(resource.children[key]);
    });
  })(resources);

  return array;
};

/**
 * Create a context object for the templates to use during compilation.
 *
 * @param  {Object} ast
 * @param  {Object} spec
 * @return {Object}
 */
module.exports = function (ast, spec) {
  // Validate the spec before using.
  spec = validateSpec(spec);

  // Create an empty context object.
  var context = {
    id:                spec.format.uniqueId('client'),
    title:             ast.title || 'API Client',
    version:           ast.version,
    baseUri:           sanitizeUri(ast.baseUri, spec),
    security:          sanitizeSecurity(ast.securitySchemes, spec),
    resources:         sanitizeResources(ast.resources, spec),
    baseUriParameters: sanitizeParameters(ast.baseUriParameters, spec)
  };

  context.allMethods       = flattenMethods(context.resources);
  context.allResources     = flattenResources(context.resources);
  context.supportedMethods = require('methods');

  return context;
};

},{"./parameters":16,"./resources":17,"./security":18,"./uri":19,"extend":33,"methods":47}],15:[function(require,module,exports){
var pick               = require('object.pick');
var sanitizeParameters = require('./parameters');

/**
 * Sanitize a method into a flatter, more readable structure.
 *
 * @param  {Object} method
 * @param  {Object} resource
 * @param  {Object} spec
 * @return {Object}
 */
var sanitizeMethod = function (method, resource, spec) {
  // Pick only the usable properties.
  var obj = pick(method, [
    'method',
    'protocols',
    'responses',
    'body',
    'headers'
  ]);

  // Attach a unique id to every method.
  obj.id              = spec.format.uniqueId('method');
  obj.resource        = resource;
  obj.queryParameters = sanitizeParameters(method.queryParameters);
  obj.description     = (method.description || '').trim();

  // TODO: Add `securedBy` support.
  // TODO: Automatically infer content-type header from body.

  return obj;
};

/**
 * Sanitize a methods array into a more reusable object.
 *
 * @param  {Array}  methods
 * @param  {Object} resource
 * @param  {Object} spec
 * @return {Object}
 */
module.exports = function (methods, resource, spec) {
  var obj = {};

  if (!methods) {
    return obj;
  }

  methods.forEach(function (method) {
    var key             = spec.format.variable(method.method);
    var sanitizedMethod = sanitizeMethod(method, resource, spec);

    obj[key] = sanitizedMethod;
    sanitizedMethod.key = key;
  });

  return obj;
};

},{"./parameters":16,"object.pick":48}],16:[function(require,module,exports){
var pick = require('object.pick');

/**
 * Sanitize the parameter into a more reusable object.
 *
 * @param  {Object} parameter
 * @return {Object}
 */
var sanitizeParameter = function (parameter) {
  var obj = pick(parameter, [
    'displayName',
    'type',
    'enum',
    'pattern',
    'minLength',
    'maxLength',
    'minimum',
    'maximum',
    'example',
    'repeat',
    'required',
    'default'
  ]);

  obj.description = (parameter.description || '').trim();

  // Automatically set the default parameter from the enum value.
  if (obj.default == null && Array.isArray(obj.enum)) {
    obj.default = obj.enum[0];
  }

  return obj;
};

/**
 * Sanitize parameters into something more consumable.
 *
 * @param  {Object} parameters
 * @return {Object}
 */
module.exports = function (parameters) {
  var obj = {};

  if (!parameters) {
    return obj;
  }

  // Iterate over every parameter and generate a new parameters object.
  Object.keys(parameters).forEach(function (key) {
    obj[key] = sanitizeParameter(parameters[key]);
  });

  return obj;
};

},{"object.pick":48}],17:[function(require,module,exports){
var sanitizeUri        = require('./uri');
var sanitizeMethods    = require('./methods');
var sanitizeParameters = require('./parameters');

/**
 * Match template tags in a string.
 *
 * @type {RegExp}
 */
var TEMPLATE_REGEXP = /\{[^\{\}]+\}/g;

/**
 * Convert a URI parameter into a variable name.
 *
 * @param  {String} uri
 * @param  {Object} spec
 * @return {String}
 */
var toPropertyFormat = function (uri, spec) {
  // Replace the prefixed path segment.
  uri = uri.replace(/^[\.\/]/, '');

  // Handle a only a single parameter. E.g. "/{param}".
  if (/^\{[^\{\}]+\}$/.test(uri)) {
    return spec.format.variable(uri.slice(1, -1));
  }

  // Handle static text with trailing parameters. E.g. "/string{id}".
  if (/^[^\{\}]+(?:\{[^\{\}]+\})*$/.test(uri)) {
    return spec.format.variable(uri.replace(/\{.+\}$/, ''));
  }
};

/**
 * Convert the uri to the language replacement format.
 *
 * @param  {String} uri
 * @param  {Object} spec
 * @return {String}
 */
var toUriFormat = function (uri, spec) {
  var index = 0;

  // Index the template parameters instead of having unique names. This
  // saves a minor amount of space and makes processing *a lot* easier.
  var indexedUri = uri.replace(/\{[^\{\}]+\}/g, function () {
    return '{' + (index++) + '}';
  });

  return sanitizeUri(indexedUri, spec);
};

/**
 * Attach the current resource to the object structure.
 *
 * @param {Object} obj
 * @param {Object} resource
 * @param {Object} spec
 */
var attachResource = function (obj, resource, spec) {
  // Split the relative uri into the valid parts. This includes special-case
  // handling for the `mediaTypeExtension` parameter according to the spec.
  var uriParts = resource.relativeUri.split(
    /(?=\.|\/|\{mediaTypeExtension\}$)/
  );

  // Sanitize the uri parameters before extracting.
  var parameters = sanitizeParameters(resource.uriParameters);

  /**
   * Return the parameter from the parameters object based on the passed in tag.
   *
   * @param  {String} param
   * @return {Object}
   */
  var getParamTag = function (param) {
    return parameters[param.slice(1, -1)];
  };

  // Iterate over each of the uri parts and nest on the root object.
  (function recurse (obj, parts) {
    var part = parts[0];

    // Add a period to the beginning of the manual media type extension.
    if (part === '{mediaTypeExtension}' && parts.length === 1) {
      if (Array.isArray(parameters.mediaTypeExtension.enum)) {
        parameters.mediaTypeExtension.enum.forEach(function (extension) {
          extension = '.' + extension.replace(/^\./, '');

          return recurse(obj, [extension]);
        });
      }

      // Remove the media type enum from documentation purposes.
      delete parameters.mediaTypeExtension.enum;

      part = '.{mediaTypeExtension}';
    }

    // Recursively create (or select) the child resource. If the resource is
    // a single slash, it should be attached to the same object.
    if (part !== '/') {
      // Convert the uri part into a variable name.
      var key = toPropertyFormat(part, spec);

      // TODO: Handle duplicate variable names and missing variable names.
      if (!key || obj.children.hasOwnProperty(key)) {
        // Handle exact matching relative uris. If they don't match exactly,
        // it's impossible for us to handle generically.
        if (part === obj.children[key].relativeUri) {
          obj = obj.children[key];
        } else {
          return;
        }
      } else {
        var matches       = part.match(TEMPLATE_REGEXP) || [];
        var uriParameters = Array.prototype.map.call(matches, getParamTag);

        obj = obj.children[key] = {
          id:            spec.format.uniqueId('resource'),
          key:           key,
          parent:        obj,
          children:      {},
          relativeUri:   toUriFormat(part, spec),
          uriParameters: uriParameters
        };
      }
    }

    // Recursively append uri parts.
    if (parts.length > 1) {
      return recurse(obj, parts.slice(1));
    }

    obj.methods     = sanitizeMethods(resource.methods, obj, spec);
    obj.description = (resource.description || '').trim();

    if (resource.resources) {
      resource.resources.forEach(function (resource) {
        attachResource(obj, resource, spec);
      });
    }

    // TODO: Implement node backtracking when no methods are available.

    return obj;
  })(obj, uriParts);
};

/**
 * Sanitize resources into nested object form.
 *
 * @param  {Object} resources
 * @param  {Object} spec
 * @return {Object}
 */
module.exports = function (resources, spec) {
  // Create the root resource object for consistency of behaviour.
  var obj = {
    id:            spec.format.uniqueId('resource'),
    children:      {},
    relativeUri:   '',
    uriParameters: []
  };

  if (!resources) {
    return obj;
  }

  // Iterate over the resources array and attach each .
  resources.forEach(function (resource) {
    return attachResource(obj, resource, spec);
  });

  return obj;
};

},{"./methods":15,"./parameters":16,"./uri":19}],18:[function(require,module,exports){
/**
 * Sanitize resources into nested object form.
 *
 * @param  {Object} securitySchemes
 * @return {Object}
 */
module.exports = function (securitySchemes) {
  var obj = {};

  if (!Array.isArray(securitySchemes)) {
    return obj;
  }

  securitySchemes.forEach(function (schemes) {
    Object.keys(schemes).forEach(function (key) {
      var scheme = schemes[key];

      obj[scheme.type] = scheme;
    });
  });

  return obj;
};

},{}],19:[function(require,module,exports){
/**
 * Sanitize all uris.
 *
 * @param  {String} uri
 * @param  {Object} spec
 * @return {String}
 */
module.exports = function (uri, spec) {
  return spec.format.uri(uri || '').replace(/\/+$/, '');
};

},{}],20:[function(require,module,exports){
var extend        = require('extend');
var helpers       = require('./helpers');
var createContext = require('./context');

// Handlebars required in node to support `require('x.hbs')`.
require('handlebars');

/**
 * Compile an api client using a combination of the ast, spec and user data.
 *
 * @param  {Object} ast
 * @param  {Object} spec
 * @param  {Object} data
 * @return {Object}
 */
function generate (ast, spec, data) {
  // Handlebars compile options from the specification.
  var options = {
    data:     data,
    helpers:  extend({}, helpers, spec.helpers),
    partials: extend({}, spec.partials)
  };

  // Allow the language to override the file generator.
  var createFiles = spec.files || generateFiles;
  var context = createContext(ast, spec);
  var files = createFiles(spec.templates, context, options);

  // Create the compile object. We resolve this object instead of just the
  // files so that external utilities have access to the context object. For
  // example, the "API Notebook" project needs to add runtime documentation.
  return {
    files: files,
    context: context,
    options: options
  };
}

/**
 * Default file generator directly from templates.
 *
 * @param  {Object} templates
 * @param  {Object} context
 * @param  {Object} options
 * @return {Object}
 */
function generateFiles (templates, context, options) {
  var files = {};

  Object.keys(templates).forEach(function (key) {
    files[key] = templates[key](context, options);
  });

  return files;
}

/**
 * Generate a language specific client generator based on passed in spec.
 *
 * @param  {Object}   spec
 * @return {Function}
 */
module.exports = function (spec) {
  /**
   * Generate an API client by passed in an AST.
   *
   * @param  {Object} ast
   * @param  {Object} options
   * @return {Object}
   */
  return function (ast, options) {
    return generate(ast, spec, options);
  };
};

},{"./context":14,"./helpers":21,"extend":33,"handlebars":22}],21:[function(require,module,exports){
var indent = require('indent-string');
var trim   = String.prototype.trim;
var hasOwn = Object.prototype.hasOwnProperty;

/**
 * Case sanitization support.
 */
exports.camelCase    = require('camel-case');
exports.pascalCase   = require('pascal-case');
exports.constantCase = require('constant-case');
exports.paramCase    = require('param-case');
exports.lowerCase    = require('lower-case');
exports.upperCase    = require('upper-case');
exports.snakeCase    = require('snake-case');

/**
 * Formatting utilities.
 */
exports.indent = function (/* input, count, character, opts */) {
  var args      = Array.prototype.slice.call(arguments);
  var opts      = args.pop();
  var input     = (opts.fn ? opts.fn(this) : args[0]);
  var count     = (opts.fn ? args[0] : args[1]) || 2;
  var character = (opts.fn ? args[1] : args[2]) || ' ';

  return indent(input, character, count);
};

/**
 * The `||` conditional as a helper.
 *
 * @return {Boolean}
 */
exports.or = function (/* ...condition, opts */) {
  for (var i = 0; i < arguments.length - 1; i++) {
    if (arguments[i]) {
      return true;
    }
  }

  return false;
};

/**
 * The `&&` conditional as a helper.
 *
 * @return {Boolean}
 */
exports.and = function (/* ...condition, opts */) {
  for (var i = 0; i < arguments.length - 1; i++) {
    if (!arguments[i]) {
      return false;
    }
  }

  return true;
};

/**
 * The `!` conditional as a helper.
 *
 * @return {Boolean}
 */
exports.not = function (condition) {
  return !condition;
};

/**
 * Get the keys of an object.
 */
exports.keys = function (obj) {
  var keys = [];

  for (var prop in obj) {
    if (hasOwn.call(obj, prop)) {
      keys.push(prop);
    }
  }

  return keys;
};

/**
 * Return all the nested by the name.
 *
 * @param  {Object} obj
 * @param  {String} name
 * @return {Array}
 */
exports.pluck = function (obj, name) {
  return Object.keys(obj).map(function (key) {
    return obj[key] && obj[key][name];
  });
};

/**
 * Turn an array of keys into an object.
 *
 * @param  {Array}  keys
 * @param  {Array}  values
 * @return {Object}
 */
exports.object = function (keys, values) {
  var obj = {};

  for (var i = 0; i < keys.length; i++) {
    obj[keys[i]] = values[i];
  }

  return obj;
};

/**
 * Check whether a value is contained within an array.
 *
 * @param  {Array}   array
 * @param  {*}       value
 * @return {Boolean}
 */
exports.contains = function (array, value) {
  return array.indexOf(value) > -1;
};

/**
 * Debugging.
 */
exports.log = function () {
  var opts = arguments[arguments.length - 1];

  if (opts.fn) {
    console.log(opts.fn(this));
  } else {
    console.log.apply(console, Array.prototype.slice.call(arguments, 0, -1));
  }
};

/**
 * Trim a string.
 *
 * @return {String}
 */
exports.trim = function () {
  var opts = arguments[arguments.length - 1];

  if (arguments.length > 1) {
    return trim.call(arguments[0] == null ? '' : arguments[0]);
  }

  return trim.call(opts.fn(this));
};

/**
 * Check that a number of arguments are equal.
 *
 * @return {Boolean}
 */
exports.equal = function () {
  var args = Array.prototype.slice.call(arguments, 0, -1);
  var opts = arguments[arguments.length - 1];

  for (var i = 1; i < args.length; i++) {
    if (args[i - 1] !== args[i]) {
      return opts.fn ? opts.inverse(this) : false;
    }
  }

  return opts.fn ? opts.fn(this) : true;
};

/**
 * Serialize as a JSON string.
 *
 * @return {String}
 */
exports.json = function () {
  if (arguments.length > 2) {
    return JSON.stringify(arguments[0], null, arguments[1]);
  }

  if (arguments.length === 2) {
    return JSON.stringify(arguments[0]);
  }

  throw new Error('Unsupported usage of json helper');
};

/**
 * Join an array of values together.
 *
 * @param  {Array}  array
 * @param  {String} value
 * @return {String}
 */
exports.join = function (array, value) {
  return Array.isArray(array) ? array.join(value) : array;
};

},{"camel-case":27,"constant-case":32,"indent-string":42,"lower-case":46,"param-case":53,"pascal-case":55,"snake-case":60,"upper-case":61}],22:[function(require,module,exports){

},{}],23:[function(require,module,exports){
/*!
 * The buffer module from node.js, for the browser.
 *
 * @author   Feross Aboukhadijeh <feross@feross.org> <http://feross.org>
 * @license  MIT
 */

var base64 = require('base64-js')
var ieee754 = require('ieee754')
var isArray = require('is-array')

exports.Buffer = Buffer
exports.SlowBuffer = SlowBuffer
exports.INSPECT_MAX_BYTES = 50
Buffer.poolSize = 8192 // not used by this implementation

var kMaxLength = 0x3fffffff
var rootParent = {}

/**
 * If `Buffer.TYPED_ARRAY_SUPPORT`:
 *   === true    Use Uint8Array implementation (fastest)
 *   === false   Use Object implementation (most compatible, even IE6)
 *
 * Browsers that support typed arrays are IE 10+, Firefox 4+, Chrome 7+, Safari 5.1+,
 * Opera 11.6+, iOS 4.2+.
 *
 * Note:
 *
 * - Implementation must support adding new properties to `Uint8Array` instances.
 *   Firefox 4-29 lacked support, fixed in Firefox 30+.
 *   See: https://bugzilla.mozilla.org/show_bug.cgi?id=695438.
 *
 *  - Chrome 9-10 is missing the `TypedArray.prototype.subarray` function.
 *
 *  - IE10 has a broken `TypedArray.prototype.subarray` function which returns arrays of
 *    incorrect length in some situations.
 *
 * We detect these buggy browsers and set `Buffer.TYPED_ARRAY_SUPPORT` to `false` so they will
 * get the Object implementation, which is slower but will work correctly.
 */
Buffer.TYPED_ARRAY_SUPPORT = (function () {
  try {
    var buf = new ArrayBuffer(0)
    var arr = new Uint8Array(buf)
    arr.foo = function () { return 42 }
    return arr.foo() === 42 && // typed array instances can be augmented
        typeof arr.subarray === 'function' && // chrome 9-10 lack `subarray`
        new Uint8Array(1).subarray(1, 1).byteLength === 0 // ie10 has broken `subarray`
  } catch (e) {
    return false
  }
})()

/**
 * Class: Buffer
 * =============
 *
 * The Buffer constructor returns instances of `Uint8Array` that are augmented
 * with function properties for all the node `Buffer` API functions. We use
 * `Uint8Array` so that square bracket notation works as expected -- it returns
 * a single octet.
 *
 * By augmenting the instances, we can avoid modifying the `Uint8Array`
 * prototype.
 */
function Buffer (subject, encoding, noZero) {
  if (!(this instanceof Buffer))
    return new Buffer(subject, encoding, noZero)

  var type = typeof subject

  // Find the length
  var length
  if (type === 'number') {
    length = +subject
  } else if (type === 'string') {
    length = Buffer.byteLength(subject, encoding)
  } else if (type === 'object' && subject !== null) { // assume object is array-like
    if (subject.type === 'Buffer' && isArray(subject.data))
      subject = subject.data
    length = +subject.length
  } else {
    throw new TypeError('must start with number, buffer, array or string')
  }

  if (length > kMaxLength)
    throw new RangeError('Attempt to allocate Buffer larger than maximum ' +
      'size: 0x' + kMaxLength.toString(16) + ' bytes')

  if (length < 0)
    length = 0
  else
    length >>>= 0 // Coerce to uint32.

  var self = this
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    // Preferred: Return an augmented `Uint8Array` instance for best performance
    /*eslint-disable consistent-this */
    self = Buffer._augment(new Uint8Array(length))
    /*eslint-enable consistent-this */
  } else {
    // Fallback: Return THIS instance of Buffer (created by `new`)
    self.length = length
    self._isBuffer = true
  }

  var i
  if (Buffer.TYPED_ARRAY_SUPPORT && typeof subject.byteLength === 'number') {
    // Speed optimization -- use set if we're copying from a typed array
    self._set(subject)
  } else if (isArrayish(subject)) {
    // Treat array-ish objects as a byte array
    if (Buffer.isBuffer(subject)) {
      for (i = 0; i < length; i++)
        self[i] = subject.readUInt8(i)
    } else {
      for (i = 0; i < length; i++)
        self[i] = ((subject[i] % 256) + 256) % 256
    }
  } else if (type === 'string') {
    self.write(subject, 0, encoding)
  } else if (type === 'number' && !Buffer.TYPED_ARRAY_SUPPORT && !noZero) {
    for (i = 0; i < length; i++) {
      self[i] = 0
    }
  }

  if (length > 0 && length <= Buffer.poolSize)
    self.parent = rootParent

  return self
}

function SlowBuffer (subject, encoding, noZero) {
  if (!(this instanceof SlowBuffer))
    return new SlowBuffer(subject, encoding, noZero)

  var buf = new Buffer(subject, encoding, noZero)
  delete buf.parent
  return buf
}

Buffer.isBuffer = function (b) {
  return !!(b != null && b._isBuffer)
}

Buffer.compare = function (a, b) {
  if (!Buffer.isBuffer(a) || !Buffer.isBuffer(b))
    throw new TypeError('Arguments must be Buffers')

  if (a === b) return 0

  var x = a.length
  var y = b.length
  for (var i = 0, len = Math.min(x, y); i < len && a[i] === b[i]; i++) {}
  if (i !== len) {
    x = a[i]
    y = b[i]
  }
  if (x < y) return -1
  if (y < x) return 1
  return 0
}

Buffer.isEncoding = function (encoding) {
  switch (String(encoding).toLowerCase()) {
    case 'hex':
    case 'utf8':
    case 'utf-8':
    case 'ascii':
    case 'binary':
    case 'base64':
    case 'raw':
    case 'ucs2':
    case 'ucs-2':
    case 'utf16le':
    case 'utf-16le':
      return true
    default:
      return false
  }
}

Buffer.concat = function (list, totalLength) {
  if (!isArray(list)) throw new TypeError('Usage: Buffer.concat(list[, length])')

  if (list.length === 0) {
    return new Buffer(0)
  } else if (list.length === 1) {
    return list[0]
  }

  var i
  if (totalLength === undefined) {
    totalLength = 0
    for (i = 0; i < list.length; i++) {
      totalLength += list[i].length
    }
  }

  var buf = new Buffer(totalLength)
  var pos = 0
  for (i = 0; i < list.length; i++) {
    var item = list[i]
    item.copy(buf, pos)
    pos += item.length
  }
  return buf
}

Buffer.byteLength = function (str, encoding) {
  var ret
  str = str + ''
  switch (encoding || 'utf8') {
    case 'ascii':
    case 'binary':
    case 'raw':
      ret = str.length
      break
    case 'ucs2':
    case 'ucs-2':
    case 'utf16le':
    case 'utf-16le':
      ret = str.length * 2
      break
    case 'hex':
      ret = str.length >>> 1
      break
    case 'utf8':
    case 'utf-8':
      ret = utf8ToBytes(str).length
      break
    case 'base64':
      ret = base64ToBytes(str).length
      break
    default:
      ret = str.length
  }
  return ret
}

// pre-set for values that may exist in the future
Buffer.prototype.length = undefined
Buffer.prototype.parent = undefined

// toString(encoding, start=0, end=buffer.length)
Buffer.prototype.toString = function (encoding, start, end) {
  var loweredCase = false

  start = start >>> 0
  end = end === undefined || end === Infinity ? this.length : end >>> 0

  if (!encoding) encoding = 'utf8'
  if (start < 0) start = 0
  if (end > this.length) end = this.length
  if (end <= start) return ''

  while (true) {
    switch (encoding) {
      case 'hex':
        return hexSlice(this, start, end)

      case 'utf8':
      case 'utf-8':
        return utf8Slice(this, start, end)

      case 'ascii':
        return asciiSlice(this, start, end)

      case 'binary':
        return binarySlice(this, start, end)

      case 'base64':
        return base64Slice(this, start, end)

      case 'ucs2':
      case 'ucs-2':
      case 'utf16le':
      case 'utf-16le':
        return utf16leSlice(this, start, end)

      default:
        if (loweredCase)
          throw new TypeError('Unknown encoding: ' + encoding)
        encoding = (encoding + '').toLowerCase()
        loweredCase = true
    }
  }
}

Buffer.prototype.equals = function (b) {
  if (!Buffer.isBuffer(b)) throw new TypeError('Argument must be a Buffer')
  if (this === b) return true
  return Buffer.compare(this, b) === 0
}

Buffer.prototype.inspect = function () {
  var str = ''
  var max = exports.INSPECT_MAX_BYTES
  if (this.length > 0) {
    str = this.toString('hex', 0, max).match(/.{2}/g).join(' ')
    if (this.length > max)
      str += ' ... '
  }
  return '<Buffer ' + str + '>'
}

Buffer.prototype.compare = function (b) {
  if (!Buffer.isBuffer(b)) throw new TypeError('Argument must be a Buffer')
  if (this === b) return 0
  return Buffer.compare(this, b)
}

// `get` will be removed in Node 0.13+
Buffer.prototype.get = function (offset) {
  console.log('.get() is deprecated. Access using array indexes instead.')
  return this.readUInt8(offset)
}

// `set` will be removed in Node 0.13+
Buffer.prototype.set = function (v, offset) {
  console.log('.set() is deprecated. Access using array indexes instead.')
  return this.writeUInt8(v, offset)
}

function hexWrite (buf, string, offset, length) {
  offset = Number(offset) || 0
  var remaining = buf.length - offset
  if (!length) {
    length = remaining
  } else {
    length = Number(length)
    if (length > remaining) {
      length = remaining
    }
  }

  // must be an even number of digits
  var strLen = string.length
  if (strLen % 2 !== 0) throw new Error('Invalid hex string')

  if (length > strLen / 2) {
    length = strLen / 2
  }
  for (var i = 0; i < length; i++) {
    var byte = parseInt(string.substr(i * 2, 2), 16)
    if (isNaN(byte)) throw new Error('Invalid hex string')
    buf[offset + i] = byte
  }
  return i
}

function utf8Write (buf, string, offset, length) {
  var charsWritten = blitBuffer(utf8ToBytes(string, buf.length - offset), buf, offset, length)
  return charsWritten
}

function asciiWrite (buf, string, offset, length) {
  var charsWritten = blitBuffer(asciiToBytes(string), buf, offset, length)
  return charsWritten
}

function binaryWrite (buf, string, offset, length) {
  return asciiWrite(buf, string, offset, length)
}

function base64Write (buf, string, offset, length) {
  var charsWritten = blitBuffer(base64ToBytes(string), buf, offset, length)
  return charsWritten
}

function utf16leWrite (buf, string, offset, length) {
  var charsWritten = blitBuffer(utf16leToBytes(string, buf.length - offset), buf, offset, length)
  return charsWritten
}

Buffer.prototype.write = function (string, offset, length, encoding) {
  // Support both (string, offset, length, encoding)
  // and the legacy (string, encoding, offset, length)
  if (isFinite(offset)) {
    if (!isFinite(length)) {
      encoding = length
      length = undefined
    }
  } else {  // legacy
    var swap = encoding
    encoding = offset
    offset = length
    length = swap
  }

  offset = Number(offset) || 0

  if (length < 0 || offset < 0 || offset > this.length)
    throw new RangeError('attempt to write outside buffer bounds')

  var remaining = this.length - offset
  if (!length) {
    length = remaining
  } else {
    length = Number(length)
    if (length > remaining) {
      length = remaining
    }
  }
  encoding = String(encoding || 'utf8').toLowerCase()

  var ret
  switch (encoding) {
    case 'hex':
      ret = hexWrite(this, string, offset, length)
      break
    case 'utf8':
    case 'utf-8':
      ret = utf8Write(this, string, offset, length)
      break
    case 'ascii':
      ret = asciiWrite(this, string, offset, length)
      break
    case 'binary':
      ret = binaryWrite(this, string, offset, length)
      break
    case 'base64':
      ret = base64Write(this, string, offset, length)
      break
    case 'ucs2':
    case 'ucs-2':
    case 'utf16le':
    case 'utf-16le':
      ret = utf16leWrite(this, string, offset, length)
      break
    default:
      throw new TypeError('Unknown encoding: ' + encoding)
  }
  return ret
}

Buffer.prototype.toJSON = function () {
  return {
    type: 'Buffer',
    data: Array.prototype.slice.call(this._arr || this, 0)
  }
}

function base64Slice (buf, start, end) {
  if (start === 0 && end === buf.length) {
    return base64.fromByteArray(buf)
  } else {
    return base64.fromByteArray(buf.slice(start, end))
  }
}

function utf8Slice (buf, start, end) {
  var res = ''
  var tmp = ''
  end = Math.min(buf.length, end)

  for (var i = start; i < end; i++) {
    if (buf[i] <= 0x7F) {
      res += decodeUtf8Char(tmp) + String.fromCharCode(buf[i])
      tmp = ''
    } else {
      tmp += '%' + buf[i].toString(16)
    }
  }

  return res + decodeUtf8Char(tmp)
}

function asciiSlice (buf, start, end) {
  var ret = ''
  end = Math.min(buf.length, end)

  for (var i = start; i < end; i++) {
    ret += String.fromCharCode(buf[i] & 0x7F)
  }
  return ret
}

function binarySlice (buf, start, end) {
  var ret = ''
  end = Math.min(buf.length, end)

  for (var i = start; i < end; i++) {
    ret += String.fromCharCode(buf[i])
  }
  return ret
}

function hexSlice (buf, start, end) {
  var len = buf.length

  if (!start || start < 0) start = 0
  if (!end || end < 0 || end > len) end = len

  var out = ''
  for (var i = start; i < end; i++) {
    out += toHex(buf[i])
  }
  return out
}

function utf16leSlice (buf, start, end) {
  var bytes = buf.slice(start, end)
  var res = ''
  for (var i = 0; i < bytes.length; i += 2) {
    res += String.fromCharCode(bytes[i] + bytes[i + 1] * 256)
  }
  return res
}

Buffer.prototype.slice = function (start, end) {
  var len = this.length
  start = ~~start
  end = end === undefined ? len : ~~end

  if (start < 0) {
    start += len
    if (start < 0)
      start = 0
  } else if (start > len) {
    start = len
  }

  if (end < 0) {
    end += len
    if (end < 0)
      end = 0
  } else if (end > len) {
    end = len
  }

  if (end < start)
    end = start

  var newBuf
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    newBuf = Buffer._augment(this.subarray(start, end))
  } else {
    var sliceLen = end - start
    newBuf = new Buffer(sliceLen, undefined, true)
    for (var i = 0; i < sliceLen; i++) {
      newBuf[i] = this[i + start]
    }
  }

  if (newBuf.length)
    newBuf.parent = this.parent || this

  return newBuf
}

/*
 * Need to make sure that buffer isn't trying to write out of bounds.
 */
function checkOffset (offset, ext, length) {
  if ((offset % 1) !== 0 || offset < 0)
    throw new RangeError('offset is not uint')
  if (offset + ext > length)
    throw new RangeError('Trying to access beyond buffer length')
}

Buffer.prototype.readUIntLE = function (offset, byteLength, noAssert) {
  offset = offset >>> 0
  byteLength = byteLength >>> 0
  if (!noAssert)
    checkOffset(offset, byteLength, this.length)

  var val = this[offset]
  var mul = 1
  var i = 0
  while (++i < byteLength && (mul *= 0x100))
    val += this[offset + i] * mul

  return val
}

Buffer.prototype.readUIntBE = function (offset, byteLength, noAssert) {
  offset = offset >>> 0
  byteLength = byteLength >>> 0
  if (!noAssert)
    checkOffset(offset, byteLength, this.length)

  var val = this[offset + --byteLength]
  var mul = 1
  while (byteLength > 0 && (mul *= 0x100))
    val += this[offset + --byteLength] * mul

  return val
}

Buffer.prototype.readUInt8 = function (offset, noAssert) {
  if (!noAssert)
    checkOffset(offset, 1, this.length)
  return this[offset]
}

Buffer.prototype.readUInt16LE = function (offset, noAssert) {
  if (!noAssert)
    checkOffset(offset, 2, this.length)
  return this[offset] | (this[offset + 1] << 8)
}

Buffer.prototype.readUInt16BE = function (offset, noAssert) {
  if (!noAssert)
    checkOffset(offset, 2, this.length)
  return (this[offset] << 8) | this[offset + 1]
}

Buffer.prototype.readUInt32LE = function (offset, noAssert) {
  if (!noAssert)
    checkOffset(offset, 4, this.length)

  return ((this[offset]) |
      (this[offset + 1] << 8) |
      (this[offset + 2] << 16)) +
      (this[offset + 3] * 0x1000000)
}

Buffer.prototype.readUInt32BE = function (offset, noAssert) {
  if (!noAssert)
    checkOffset(offset, 4, this.length)

  return (this[offset] * 0x1000000) +
      ((this[offset + 1] << 16) |
      (this[offset + 2] << 8) |
      this[offset + 3])
}

Buffer.prototype.readIntLE = function (offset, byteLength, noAssert) {
  offset = offset >>> 0
  byteLength = byteLength >>> 0
  if (!noAssert)
    checkOffset(offset, byteLength, this.length)

  var val = this[offset]
  var mul = 1
  var i = 0
  while (++i < byteLength && (mul *= 0x100))
    val += this[offset + i] * mul
  mul *= 0x80

  if (val >= mul)
    val -= Math.pow(2, 8 * byteLength)

  return val
}

Buffer.prototype.readIntBE = function (offset, byteLength, noAssert) {
  offset = offset >>> 0
  byteLength = byteLength >>> 0
  if (!noAssert)
    checkOffset(offset, byteLength, this.length)

  var i = byteLength
  var mul = 1
  var val = this[offset + --i]
  while (i > 0 && (mul *= 0x100))
    val += this[offset + --i] * mul
  mul *= 0x80

  if (val >= mul)
    val -= Math.pow(2, 8 * byteLength)

  return val
}

Buffer.prototype.readInt8 = function (offset, noAssert) {
  if (!noAssert)
    checkOffset(offset, 1, this.length)
  if (!(this[offset] & 0x80))
    return (this[offset])
  return ((0xff - this[offset] + 1) * -1)
}

Buffer.prototype.readInt16LE = function (offset, noAssert) {
  if (!noAssert)
    checkOffset(offset, 2, this.length)
  var val = this[offset] | (this[offset + 1] << 8)
  return (val & 0x8000) ? val | 0xFFFF0000 : val
}

Buffer.prototype.readInt16BE = function (offset, noAssert) {
  if (!noAssert)
    checkOffset(offset, 2, this.length)
  var val = this[offset + 1] | (this[offset] << 8)
  return (val & 0x8000) ? val | 0xFFFF0000 : val
}

Buffer.prototype.readInt32LE = function (offset, noAssert) {
  if (!noAssert)
    checkOffset(offset, 4, this.length)

  return (this[offset]) |
      (this[offset + 1] << 8) |
      (this[offset + 2] << 16) |
      (this[offset + 3] << 24)
}

Buffer.prototype.readInt32BE = function (offset, noAssert) {
  if (!noAssert)
    checkOffset(offset, 4, this.length)

  return (this[offset] << 24) |
      (this[offset + 1] << 16) |
      (this[offset + 2] << 8) |
      (this[offset + 3])
}

Buffer.prototype.readFloatLE = function (offset, noAssert) {
  if (!noAssert)
    checkOffset(offset, 4, this.length)
  return ieee754.read(this, offset, true, 23, 4)
}

Buffer.prototype.readFloatBE = function (offset, noAssert) {
  if (!noAssert)
    checkOffset(offset, 4, this.length)
  return ieee754.read(this, offset, false, 23, 4)
}

Buffer.prototype.readDoubleLE = function (offset, noAssert) {
  if (!noAssert)
    checkOffset(offset, 8, this.length)
  return ieee754.read(this, offset, true, 52, 8)
}

Buffer.prototype.readDoubleBE = function (offset, noAssert) {
  if (!noAssert)
    checkOffset(offset, 8, this.length)
  return ieee754.read(this, offset, false, 52, 8)
}

function checkInt (buf, value, offset, ext, max, min) {
  if (!Buffer.isBuffer(buf)) throw new TypeError('buffer must be a Buffer instance')
  if (value > max || value < min) throw new RangeError('value is out of bounds')
  if (offset + ext > buf.length) throw new RangeError('index out of range')
}

Buffer.prototype.writeUIntLE = function (value, offset, byteLength, noAssert) {
  value = +value
  offset = offset >>> 0
  byteLength = byteLength >>> 0
  if (!noAssert)
    checkInt(this, value, offset, byteLength, Math.pow(2, 8 * byteLength), 0)

  var mul = 1
  var i = 0
  this[offset] = value & 0xFF
  while (++i < byteLength && (mul *= 0x100))
    this[offset + i] = (value / mul) >>> 0 & 0xFF

  return offset + byteLength
}

Buffer.prototype.writeUIntBE = function (value, offset, byteLength, noAssert) {
  value = +value
  offset = offset >>> 0
  byteLength = byteLength >>> 0
  if (!noAssert)
    checkInt(this, value, offset, byteLength, Math.pow(2, 8 * byteLength), 0)

  var i = byteLength - 1
  var mul = 1
  this[offset + i] = value & 0xFF
  while (--i >= 0 && (mul *= 0x100))
    this[offset + i] = (value / mul) >>> 0 & 0xFF

  return offset + byteLength
}

Buffer.prototype.writeUInt8 = function (value, offset, noAssert) {
  value = +value
  offset = offset >>> 0
  if (!noAssert)
    checkInt(this, value, offset, 1, 0xff, 0)
  if (!Buffer.TYPED_ARRAY_SUPPORT) value = Math.floor(value)
  this[offset] = value
  return offset + 1
}

function objectWriteUInt16 (buf, value, offset, littleEndian) {
  if (value < 0) value = 0xffff + value + 1
  for (var i = 0, j = Math.min(buf.length - offset, 2); i < j; i++) {
    buf[offset + i] = (value & (0xff << (8 * (littleEndian ? i : 1 - i)))) >>>
      (littleEndian ? i : 1 - i) * 8
  }
}

Buffer.prototype.writeUInt16LE = function (value, offset, noAssert) {
  value = +value
  offset = offset >>> 0
  if (!noAssert)
    checkInt(this, value, offset, 2, 0xffff, 0)
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = value
    this[offset + 1] = (value >>> 8)
  } else objectWriteUInt16(this, value, offset, true)
  return offset + 2
}

Buffer.prototype.writeUInt16BE = function (value, offset, noAssert) {
  value = +value
  offset = offset >>> 0
  if (!noAssert)
    checkInt(this, value, offset, 2, 0xffff, 0)
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = (value >>> 8)
    this[offset + 1] = value
  } else objectWriteUInt16(this, value, offset, false)
  return offset + 2
}

function objectWriteUInt32 (buf, value, offset, littleEndian) {
  if (value < 0) value = 0xffffffff + value + 1
  for (var i = 0, j = Math.min(buf.length - offset, 4); i < j; i++) {
    buf[offset + i] = (value >>> (littleEndian ? i : 3 - i) * 8) & 0xff
  }
}

Buffer.prototype.writeUInt32LE = function (value, offset, noAssert) {
  value = +value
  offset = offset >>> 0
  if (!noAssert)
    checkInt(this, value, offset, 4, 0xffffffff, 0)
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset + 3] = (value >>> 24)
    this[offset + 2] = (value >>> 16)
    this[offset + 1] = (value >>> 8)
    this[offset] = value
  } else objectWriteUInt32(this, value, offset, true)
  return offset + 4
}

Buffer.prototype.writeUInt32BE = function (value, offset, noAssert) {
  value = +value
  offset = offset >>> 0
  if (!noAssert)
    checkInt(this, value, offset, 4, 0xffffffff, 0)
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = (value >>> 24)
    this[offset + 1] = (value >>> 16)
    this[offset + 2] = (value >>> 8)
    this[offset + 3] = value
  } else objectWriteUInt32(this, value, offset, false)
  return offset + 4
}

Buffer.prototype.writeIntLE = function (value, offset, byteLength, noAssert) {
  value = +value
  offset = offset >>> 0
  if (!noAssert) {
    checkInt(this,
             value,
             offset,
             byteLength,
             Math.pow(2, 8 * byteLength - 1) - 1,
             -Math.pow(2, 8 * byteLength - 1))
  }

  var i = 0
  var mul = 1
  var sub = value < 0 ? 1 : 0
  this[offset] = value & 0xFF
  while (++i < byteLength && (mul *= 0x100))
    this[offset + i] = ((value / mul) >> 0) - sub & 0xFF

  return offset + byteLength
}

Buffer.prototype.writeIntBE = function (value, offset, byteLength, noAssert) {
  value = +value
  offset = offset >>> 0
  if (!noAssert) {
    checkInt(this,
             value,
             offset,
             byteLength,
             Math.pow(2, 8 * byteLength - 1) - 1,
             -Math.pow(2, 8 * byteLength - 1))
  }

  var i = byteLength - 1
  var mul = 1
  var sub = value < 0 ? 1 : 0
  this[offset + i] = value & 0xFF
  while (--i >= 0 && (mul *= 0x100))
    this[offset + i] = ((value / mul) >> 0) - sub & 0xFF

  return offset + byteLength
}

Buffer.prototype.writeInt8 = function (value, offset, noAssert) {
  value = +value
  offset = offset >>> 0
  if (!noAssert)
    checkInt(this, value, offset, 1, 0x7f, -0x80)
  if (!Buffer.TYPED_ARRAY_SUPPORT) value = Math.floor(value)
  if (value < 0) value = 0xff + value + 1
  this[offset] = value
  return offset + 1
}

Buffer.prototype.writeInt16LE = function (value, offset, noAssert) {
  value = +value
  offset = offset >>> 0
  if (!noAssert)
    checkInt(this, value, offset, 2, 0x7fff, -0x8000)
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = value
    this[offset + 1] = (value >>> 8)
  } else objectWriteUInt16(this, value, offset, true)
  return offset + 2
}

Buffer.prototype.writeInt16BE = function (value, offset, noAssert) {
  value = +value
  offset = offset >>> 0
  if (!noAssert)
    checkInt(this, value, offset, 2, 0x7fff, -0x8000)
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = (value >>> 8)
    this[offset + 1] = value
  } else objectWriteUInt16(this, value, offset, false)
  return offset + 2
}

Buffer.prototype.writeInt32LE = function (value, offset, noAssert) {
  value = +value
  offset = offset >>> 0
  if (!noAssert)
    checkInt(this, value, offset, 4, 0x7fffffff, -0x80000000)
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = value
    this[offset + 1] = (value >>> 8)
    this[offset + 2] = (value >>> 16)
    this[offset + 3] = (value >>> 24)
  } else objectWriteUInt32(this, value, offset, true)
  return offset + 4
}

Buffer.prototype.writeInt32BE = function (value, offset, noAssert) {
  value = +value
  offset = offset >>> 0
  if (!noAssert)
    checkInt(this, value, offset, 4, 0x7fffffff, -0x80000000)
  if (value < 0) value = 0xffffffff + value + 1
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = (value >>> 24)
    this[offset + 1] = (value >>> 16)
    this[offset + 2] = (value >>> 8)
    this[offset + 3] = value
  } else objectWriteUInt32(this, value, offset, false)
  return offset + 4
}

function checkIEEE754 (buf, value, offset, ext, max, min) {
  if (value > max || value < min) throw new RangeError('value is out of bounds')
  if (offset + ext > buf.length) throw new RangeError('index out of range')
  if (offset < 0) throw new RangeError('index out of range')
}

function writeFloat (buf, value, offset, littleEndian, noAssert) {
  if (!noAssert)
    checkIEEE754(buf, value, offset, 4, 3.4028234663852886e+38, -3.4028234663852886e+38)
  ieee754.write(buf, value, offset, littleEndian, 23, 4)
  return offset + 4
}

Buffer.prototype.writeFloatLE = function (value, offset, noAssert) {
  return writeFloat(this, value, offset, true, noAssert)
}

Buffer.prototype.writeFloatBE = function (value, offset, noAssert) {
  return writeFloat(this, value, offset, false, noAssert)
}

function writeDouble (buf, value, offset, littleEndian, noAssert) {
  if (!noAssert)
    checkIEEE754(buf, value, offset, 8, 1.7976931348623157E+308, -1.7976931348623157E+308)
  ieee754.write(buf, value, offset, littleEndian, 52, 8)
  return offset + 8
}

Buffer.prototype.writeDoubleLE = function (value, offset, noAssert) {
  return writeDouble(this, value, offset, true, noAssert)
}

Buffer.prototype.writeDoubleBE = function (value, offset, noAssert) {
  return writeDouble(this, value, offset, false, noAssert)
}

// copy(targetBuffer, targetStart=0, sourceStart=0, sourceEnd=buffer.length)
Buffer.prototype.copy = function (target, target_start, start, end) {
  var self = this // source

  if (!start) start = 0
  if (!end && end !== 0) end = this.length
  if (target_start >= target.length) target_start = target.length
  if (!target_start) target_start = 0
  if (end > 0 && end < start) end = start

  // Copy 0 bytes; we're done
  if (end === start) return 0
  if (target.length === 0 || self.length === 0) return 0

  // Fatal error conditions
  if (target_start < 0)
    throw new RangeError('targetStart out of bounds')
  if (start < 0 || start >= self.length) throw new RangeError('sourceStart out of bounds')
  if (end < 0) throw new RangeError('sourceEnd out of bounds')

  // Are we oob?
  if (end > this.length)
    end = this.length
  if (target.length - target_start < end - start)
    end = target.length - target_start + start

  var len = end - start

  if (len < 1000 || !Buffer.TYPED_ARRAY_SUPPORT) {
    for (var i = 0; i < len; i++) {
      target[i + target_start] = this[i + start]
    }
  } else {
    target._set(this.subarray(start, start + len), target_start)
  }

  return len
}

// fill(value, start=0, end=buffer.length)
Buffer.prototype.fill = function (value, start, end) {
  if (!value) value = 0
  if (!start) start = 0
  if (!end) end = this.length

  if (end < start) throw new RangeError('end < start')

  // Fill 0 bytes; we're done
  if (end === start) return
  if (this.length === 0) return

  if (start < 0 || start >= this.length) throw new RangeError('start out of bounds')
  if (end < 0 || end > this.length) throw new RangeError('end out of bounds')

  var i
  if (typeof value === 'number') {
    for (i = start; i < end; i++) {
      this[i] = value
    }
  } else {
    var bytes = utf8ToBytes(value.toString())
    var len = bytes.length
    for (i = start; i < end; i++) {
      this[i] = bytes[i % len]
    }
  }

  return this
}

/**
 * Creates a new `ArrayBuffer` with the *copied* memory of the buffer instance.
 * Added in Node 0.12. Only available in browsers that support ArrayBuffer.
 */
Buffer.prototype.toArrayBuffer = function () {
  if (typeof Uint8Array !== 'undefined') {
    if (Buffer.TYPED_ARRAY_SUPPORT) {
      return (new Buffer(this)).buffer
    } else {
      var buf = new Uint8Array(this.length)
      for (var i = 0, len = buf.length; i < len; i += 1) {
        buf[i] = this[i]
      }
      return buf.buffer
    }
  } else {
    throw new TypeError('Buffer.toArrayBuffer not supported in this browser')
  }
}

// HELPER FUNCTIONS
// ================

var BP = Buffer.prototype

/**
 * Augment a Uint8Array *instance* (not the Uint8Array class!) with Buffer methods
 */
Buffer._augment = function (arr) {
  arr.constructor = Buffer
  arr._isBuffer = true

  // save reference to original Uint8Array get/set methods before overwriting
  arr._get = arr.get
  arr._set = arr.set

  // deprecated, will be removed in node 0.13+
  arr.get = BP.get
  arr.set = BP.set

  arr.write = BP.write
  arr.toString = BP.toString
  arr.toLocaleString = BP.toString
  arr.toJSON = BP.toJSON
  arr.equals = BP.equals
  arr.compare = BP.compare
  arr.copy = BP.copy
  arr.slice = BP.slice
  arr.readUIntLE = BP.readUIntLE
  arr.readUIntBE = BP.readUIntBE
  arr.readUInt8 = BP.readUInt8
  arr.readUInt16LE = BP.readUInt16LE
  arr.readUInt16BE = BP.readUInt16BE
  arr.readUInt32LE = BP.readUInt32LE
  arr.readUInt32BE = BP.readUInt32BE
  arr.readIntLE = BP.readIntLE
  arr.readIntBE = BP.readIntBE
  arr.readInt8 = BP.readInt8
  arr.readInt16LE = BP.readInt16LE
  arr.readInt16BE = BP.readInt16BE
  arr.readInt32LE = BP.readInt32LE
  arr.readInt32BE = BP.readInt32BE
  arr.readFloatLE = BP.readFloatLE
  arr.readFloatBE = BP.readFloatBE
  arr.readDoubleLE = BP.readDoubleLE
  arr.readDoubleBE = BP.readDoubleBE
  arr.writeUInt8 = BP.writeUInt8
  arr.writeUIntLE = BP.writeUIntLE
  arr.writeUIntBE = BP.writeUIntBE
  arr.writeUInt16LE = BP.writeUInt16LE
  arr.writeUInt16BE = BP.writeUInt16BE
  arr.writeUInt32LE = BP.writeUInt32LE
  arr.writeUInt32BE = BP.writeUInt32BE
  arr.writeIntLE = BP.writeIntLE
  arr.writeIntBE = BP.writeIntBE
  arr.writeInt8 = BP.writeInt8
  arr.writeInt16LE = BP.writeInt16LE
  arr.writeInt16BE = BP.writeInt16BE
  arr.writeInt32LE = BP.writeInt32LE
  arr.writeInt32BE = BP.writeInt32BE
  arr.writeFloatLE = BP.writeFloatLE
  arr.writeFloatBE = BP.writeFloatBE
  arr.writeDoubleLE = BP.writeDoubleLE
  arr.writeDoubleBE = BP.writeDoubleBE
  arr.fill = BP.fill
  arr.inspect = BP.inspect
  arr.toArrayBuffer = BP.toArrayBuffer

  return arr
}

var INVALID_BASE64_RE = /[^+\/0-9A-z\-]/g

function base64clean (str) {
  // Node strips out invalid characters like \n and \t from the string, base64-js does not
  str = stringtrim(str).replace(INVALID_BASE64_RE, '')
  // Node converts strings with length < 2 to ''
  if (str.length < 2) return ''
  // Node allows for non-padded base64 strings (missing trailing ===), base64-js does not
  while (str.length % 4 !== 0) {
    str = str + '='
  }
  return str
}

function stringtrim (str) {
  if (str.trim) return str.trim()
  return str.replace(/^\s+|\s+$/g, '')
}

function isArrayish (subject) {
  return isArray(subject) || Buffer.isBuffer(subject) ||
      subject && typeof subject === 'object' &&
      typeof subject.length === 'number'
}

function toHex (n) {
  if (n < 16) return '0' + n.toString(16)
  return n.toString(16)
}

function utf8ToBytes (string, units) {
  units = units || Infinity
  var codePoint
  var length = string.length
  var leadSurrogate = null
  var bytes = []
  var i = 0

  for (; i < length; i++) {
    codePoint = string.charCodeAt(i)

    // is surrogate component
    if (codePoint > 0xD7FF && codePoint < 0xE000) {
      // last char was a lead
      if (leadSurrogate) {
        // 2 leads in a row
        if (codePoint < 0xDC00) {
          if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD)
          leadSurrogate = codePoint
          continue
        } else {
          // valid surrogate pair
          codePoint = leadSurrogate - 0xD800 << 10 | codePoint - 0xDC00 | 0x10000
          leadSurrogate = null
        }
      } else {
        // no lead yet

        if (codePoint > 0xDBFF) {
          // unexpected trail
          if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD)
          continue
        } else if (i + 1 === length) {
          // unpaired lead
          if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD)
          continue
        } else {
          // valid lead
          leadSurrogate = codePoint
          continue
        }
      }
    } else if (leadSurrogate) {
      // valid bmp char, but last char was a lead
      if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD)
      leadSurrogate = null
    }

    // encode utf8
    if (codePoint < 0x80) {
      if ((units -= 1) < 0) break
      bytes.push(codePoint)
    } else if (codePoint < 0x800) {
      if ((units -= 2) < 0) break
      bytes.push(
        codePoint >> 0x6 | 0xC0,
        codePoint & 0x3F | 0x80
      )
    } else if (codePoint < 0x10000) {
      if ((units -= 3) < 0) break
      bytes.push(
        codePoint >> 0xC | 0xE0,
        codePoint >> 0x6 & 0x3F | 0x80,
        codePoint & 0x3F | 0x80
      )
    } else if (codePoint < 0x200000) {
      if ((units -= 4) < 0) break
      bytes.push(
        codePoint >> 0x12 | 0xF0,
        codePoint >> 0xC & 0x3F | 0x80,
        codePoint >> 0x6 & 0x3F | 0x80,
        codePoint & 0x3F | 0x80
      )
    } else {
      throw new Error('Invalid code point')
    }
  }

  return bytes
}

function asciiToBytes (str) {
  var byteArray = []
  for (var i = 0; i < str.length; i++) {
    // Node's code seems to be doing this and not & 0x7F..
    byteArray.push(str.charCodeAt(i) & 0xFF)
  }
  return byteArray
}

function utf16leToBytes (str, units) {
  var c, hi, lo
  var byteArray = []
  for (var i = 0; i < str.length; i++) {
    if ((units -= 2) < 0) break

    c = str.charCodeAt(i)
    hi = c >> 8
    lo = c % 256
    byteArray.push(lo)
    byteArray.push(hi)
  }

  return byteArray
}

function base64ToBytes (str) {
  return base64.toByteArray(base64clean(str))
}

function blitBuffer (src, dst, offset, length) {
  for (var i = 0; i < length; i++) {
    if ((i + offset >= dst.length) || (i >= src.length))
      break
    dst[i + offset] = src[i]
  }
  return i
}

function decodeUtf8Char (str) {
  try {
    return decodeURIComponent(str)
  } catch (err) {
    return String.fromCharCode(0xFFFD) // UTF 8 invalid char
  }
}

},{"base64-js":24,"ieee754":25,"is-array":26}],24:[function(require,module,exports){
var lookup = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';

;(function (exports) {
	'use strict';

  var Arr = (typeof Uint8Array !== 'undefined')
    ? Uint8Array
    : Array

	var PLUS   = '+'.charCodeAt(0)
	var SLASH  = '/'.charCodeAt(0)
	var NUMBER = '0'.charCodeAt(0)
	var LOWER  = 'a'.charCodeAt(0)
	var UPPER  = 'A'.charCodeAt(0)
	var PLUS_URL_SAFE = '-'.charCodeAt(0)
	var SLASH_URL_SAFE = '_'.charCodeAt(0)

	function decode (elt) {
		var code = elt.charCodeAt(0)
		if (code === PLUS ||
		    code === PLUS_URL_SAFE)
			return 62 // '+'
		if (code === SLASH ||
		    code === SLASH_URL_SAFE)
			return 63 // '/'
		if (code < NUMBER)
			return -1 //no match
		if (code < NUMBER + 10)
			return code - NUMBER + 26 + 26
		if (code < UPPER + 26)
			return code - UPPER
		if (code < LOWER + 26)
			return code - LOWER + 26
	}

	function b64ToByteArray (b64) {
		var i, j, l, tmp, placeHolders, arr

		if (b64.length % 4 > 0) {
			throw new Error('Invalid string. Length must be a multiple of 4')
		}

		// the number of equal signs (place holders)
		// if there are two placeholders, than the two characters before it
		// represent one byte
		// if there is only one, then the three characters before it represent 2 bytes
		// this is just a cheap hack to not do indexOf twice
		var len = b64.length
		placeHolders = '=' === b64.charAt(len - 2) ? 2 : '=' === b64.charAt(len - 1) ? 1 : 0

		// base64 is 4/3 + up to two characters of the original data
		arr = new Arr(b64.length * 3 / 4 - placeHolders)

		// if there are placeholders, only get up to the last complete 4 chars
		l = placeHolders > 0 ? b64.length - 4 : b64.length

		var L = 0

		function push (v) {
			arr[L++] = v
		}

		for (i = 0, j = 0; i < l; i += 4, j += 3) {
			tmp = (decode(b64.charAt(i)) << 18) | (decode(b64.charAt(i + 1)) << 12) | (decode(b64.charAt(i + 2)) << 6) | decode(b64.charAt(i + 3))
			push((tmp & 0xFF0000) >> 16)
			push((tmp & 0xFF00) >> 8)
			push(tmp & 0xFF)
		}

		if (placeHolders === 2) {
			tmp = (decode(b64.charAt(i)) << 2) | (decode(b64.charAt(i + 1)) >> 4)
			push(tmp & 0xFF)
		} else if (placeHolders === 1) {
			tmp = (decode(b64.charAt(i)) << 10) | (decode(b64.charAt(i + 1)) << 4) | (decode(b64.charAt(i + 2)) >> 2)
			push((tmp >> 8) & 0xFF)
			push(tmp & 0xFF)
		}

		return arr
	}

	function uint8ToBase64 (uint8) {
		var i,
			extraBytes = uint8.length % 3, // if we have 1 byte left, pad 2 bytes
			output = "",
			temp, length

		function encode (num) {
			return lookup.charAt(num)
		}

		function tripletToBase64 (num) {
			return encode(num >> 18 & 0x3F) + encode(num >> 12 & 0x3F) + encode(num >> 6 & 0x3F) + encode(num & 0x3F)
		}

		// go through the array every three bytes, we'll deal with trailing stuff later
		for (i = 0, length = uint8.length - extraBytes; i < length; i += 3) {
			temp = (uint8[i] << 16) + (uint8[i + 1] << 8) + (uint8[i + 2])
			output += tripletToBase64(temp)
		}

		// pad the end with zeros, but make sure to not forget the extra bytes
		switch (extraBytes) {
			case 1:
				temp = uint8[uint8.length - 1]
				output += encode(temp >> 2)
				output += encode((temp << 4) & 0x3F)
				output += '=='
				break
			case 2:
				temp = (uint8[uint8.length - 2] << 8) + (uint8[uint8.length - 1])
				output += encode(temp >> 10)
				output += encode((temp >> 4) & 0x3F)
				output += encode((temp << 2) & 0x3F)
				output += '='
				break
		}

		return output
	}

	exports.toByteArray = b64ToByteArray
	exports.fromByteArray = uint8ToBase64
}(typeof exports === 'undefined' ? (this.base64js = {}) : exports))

},{}],25:[function(require,module,exports){
exports.read = function(buffer, offset, isLE, mLen, nBytes) {
  var e, m,
      eLen = nBytes * 8 - mLen - 1,
      eMax = (1 << eLen) - 1,
      eBias = eMax >> 1,
      nBits = -7,
      i = isLE ? (nBytes - 1) : 0,
      d = isLE ? -1 : 1,
      s = buffer[offset + i];

  i += d;

  e = s & ((1 << (-nBits)) - 1);
  s >>= (-nBits);
  nBits += eLen;
  for (; nBits > 0; e = e * 256 + buffer[offset + i], i += d, nBits -= 8);

  m = e & ((1 << (-nBits)) - 1);
  e >>= (-nBits);
  nBits += mLen;
  for (; nBits > 0; m = m * 256 + buffer[offset + i], i += d, nBits -= 8);

  if (e === 0) {
    e = 1 - eBias;
  } else if (e === eMax) {
    return m ? NaN : ((s ? -1 : 1) * Infinity);
  } else {
    m = m + Math.pow(2, mLen);
    e = e - eBias;
  }
  return (s ? -1 : 1) * m * Math.pow(2, e - mLen);
};

exports.write = function(buffer, value, offset, isLE, mLen, nBytes) {
  var e, m, c,
      eLen = nBytes * 8 - mLen - 1,
      eMax = (1 << eLen) - 1,
      eBias = eMax >> 1,
      rt = (mLen === 23 ? Math.pow(2, -24) - Math.pow(2, -77) : 0),
      i = isLE ? 0 : (nBytes - 1),
      d = isLE ? 1 : -1,
      s = value < 0 || (value === 0 && 1 / value < 0) ? 1 : 0;

  value = Math.abs(value);

  if (isNaN(value) || value === Infinity) {
    m = isNaN(value) ? 1 : 0;
    e = eMax;
  } else {
    e = Math.floor(Math.log(value) / Math.LN2);
    if (value * (c = Math.pow(2, -e)) < 1) {
      e--;
      c *= 2;
    }
    if (e + eBias >= 1) {
      value += rt / c;
    } else {
      value += rt * Math.pow(2, 1 - eBias);
    }
    if (value * c >= 2) {
      e++;
      c /= 2;
    }

    if (e + eBias >= eMax) {
      m = 0;
      e = eMax;
    } else if (e + eBias >= 1) {
      m = (value * c - 1) * Math.pow(2, mLen);
      e = e + eBias;
    } else {
      m = value * Math.pow(2, eBias - 1) * Math.pow(2, mLen);
      e = 0;
    }
  }

  for (; mLen >= 8; buffer[offset + i] = m & 0xff, i += d, m /= 256, mLen -= 8);

  e = (e << mLen) | m;
  eLen += mLen;
  for (; eLen > 0; buffer[offset + i] = e & 0xff, i += d, e /= 256, eLen -= 8);

  buffer[offset + i - d] |= s * 128;
};

},{}],26:[function(require,module,exports){

/**
 * isArray
 */

var isArray = Array.isArray;

/**
 * toString
 */

var str = Object.prototype.toString;

/**
 * Whether or not the given `val`
 * is an array.
 *
 * example:
 *
 *        isArray([]);
 *        // > true
 *        isArray(arguments);
 *        // > false
 *        isArray('');
 *        // > false
 *
 * @param {mixed} val
 * @return {bool}
 */

module.exports = isArray || function (val) {
  return !! val && '[object Array]' == str.call(val);
};

},{}],27:[function(require,module,exports){
var upperCase    = require('upper-case');
var sentenceCase = require('sentence-case');

/**
 * Camel case a string.
 *
 * @param  {String} string
 * @param  {String} [locale]
 * @return {String}
 */
module.exports = function (string, locale) {
  return sentenceCase(string, locale)
    // Replace periods between numeric entities with an underscore.
    .replace(/(\d) (?=\d)/g, '$1_')
    // Replace spaces between words with an upper cased character.
    .replace(/ (.)/g, function (m, $1) {
      return upperCase($1, locale);
    });
};

},{"sentence-case":28,"upper-case":61}],28:[function(require,module,exports){
var lowerCase = require('lower-case')

var NON_WORD_REGEXP = require('./vendor/non-word-regexp')
var CAMEL_CASE_REGEXP = require('./vendor/camel-case-regexp')
var TRAILING_DIGIT_REGEXP = require('./vendor/trailing-digit-regexp')

/**
 * Sentence case a string.
 *
 * @param  {String} str
 * @param  {String} locale
 * @param  {String} replacement
 * @return {String}
 */
module.exports = function (str, locale, replacement) {
  if (str == null) {
    return ''
  }

  replacement = replacement || ' '

  function replace (match, index, string) {
    if (index === 0 || index === (string.length - match.length)) {
      return ''
    }

    return replacement
  }

  str = String(str)
    // Support camel case ("camelCase" -> "camel Case").
    .replace(CAMEL_CASE_REGEXP, '$1 $2')
    // Support digit groups ("test2012" -> "test 2012").
    .replace(TRAILING_DIGIT_REGEXP, '$1 $2')
    // Remove all non-word characters and replace with a single space.
    .replace(NON_WORD_REGEXP, replace)

  // Lower case the entire string.
  return lowerCase(str, locale)
}

},{"./vendor/camel-case-regexp":29,"./vendor/non-word-regexp":30,"./vendor/trailing-digit-regexp":31,"lower-case":46}],29:[function(require,module,exports){
module.exports = /([\u0061-\u007A\u00B5\u00DF-\u00F6\u00F8-\u00FF\u0101\u0103\u0105\u0107\u0109\u010B\u010D\u010F\u0111\u0113\u0115\u0117\u0119\u011B\u011D\u011F\u0121\u0123\u0125\u0127\u0129\u012B\u012D\u012F\u0131\u0133\u0135\u0137\u0138\u013A\u013C\u013E\u0140\u0142\u0144\u0146\u0148\u0149\u014B\u014D\u014F\u0151\u0153\u0155\u0157\u0159\u015B\u015D\u015F\u0161\u0163\u0165\u0167\u0169\u016B\u016D\u016F\u0171\u0173\u0175\u0177\u017A\u017C\u017E-\u0180\u0183\u0185\u0188\u018C\u018D\u0192\u0195\u0199-\u019B\u019E\u01A1\u01A3\u01A5\u01A8\u01AA\u01AB\u01AD\u01B0\u01B4\u01B6\u01B9\u01BA\u01BD-\u01BF\u01C6\u01C9\u01CC\u01CE\u01D0\u01D2\u01D4\u01D6\u01D8\u01DA\u01DC\u01DD\u01DF\u01E1\u01E3\u01E5\u01E7\u01E9\u01EB\u01ED\u01EF\u01F0\u01F3\u01F5\u01F9\u01FB\u01FD\u01FF\u0201\u0203\u0205\u0207\u0209\u020B\u020D\u020F\u0211\u0213\u0215\u0217\u0219\u021B\u021D\u021F\u0221\u0223\u0225\u0227\u0229\u022B\u022D\u022F\u0231\u0233-\u0239\u023C\u023F\u0240\u0242\u0247\u0249\u024B\u024D\u024F-\u0293\u0295-\u02AF\u0371\u0373\u0377\u037B-\u037D\u0390\u03AC-\u03CE\u03D0\u03D1\u03D5-\u03D7\u03D9\u03DB\u03DD\u03DF\u03E1\u03E3\u03E5\u03E7\u03E9\u03EB\u03ED\u03EF-\u03F3\u03F5\u03F8\u03FB\u03FC\u0430-\u045F\u0461\u0463\u0465\u0467\u0469\u046B\u046D\u046F\u0471\u0473\u0475\u0477\u0479\u047B\u047D\u047F\u0481\u048B\u048D\u048F\u0491\u0493\u0495\u0497\u0499\u049B\u049D\u049F\u04A1\u04A3\u04A5\u04A7\u04A9\u04AB\u04AD\u04AF\u04B1\u04B3\u04B5\u04B7\u04B9\u04BB\u04BD\u04BF\u04C2\u04C4\u04C6\u04C8\u04CA\u04CC\u04CE\u04CF\u04D1\u04D3\u04D5\u04D7\u04D9\u04DB\u04DD\u04DF\u04E1\u04E3\u04E5\u04E7\u04E9\u04EB\u04ED\u04EF\u04F1\u04F3\u04F5\u04F7\u04F9\u04FB\u04FD\u04FF\u0501\u0503\u0505\u0507\u0509\u050B\u050D\u050F\u0511\u0513\u0515\u0517\u0519\u051B\u051D\u051F\u0521\u0523\u0525\u0527\u0561-\u0587\u1D00-\u1D2B\u1D6B-\u1D77\u1D79-\u1D9A\u1E01\u1E03\u1E05\u1E07\u1E09\u1E0B\u1E0D\u1E0F\u1E11\u1E13\u1E15\u1E17\u1E19\u1E1B\u1E1D\u1E1F\u1E21\u1E23\u1E25\u1E27\u1E29\u1E2B\u1E2D\u1E2F\u1E31\u1E33\u1E35\u1E37\u1E39\u1E3B\u1E3D\u1E3F\u1E41\u1E43\u1E45\u1E47\u1E49\u1E4B\u1E4D\u1E4F\u1E51\u1E53\u1E55\u1E57\u1E59\u1E5B\u1E5D\u1E5F\u1E61\u1E63\u1E65\u1E67\u1E69\u1E6B\u1E6D\u1E6F\u1E71\u1E73\u1E75\u1E77\u1E79\u1E7B\u1E7D\u1E7F\u1E81\u1E83\u1E85\u1E87\u1E89\u1E8B\u1E8D\u1E8F\u1E91\u1E93\u1E95-\u1E9D\u1E9F\u1EA1\u1EA3\u1EA5\u1EA7\u1EA9\u1EAB\u1EAD\u1EAF\u1EB1\u1EB3\u1EB5\u1EB7\u1EB9\u1EBB\u1EBD\u1EBF\u1EC1\u1EC3\u1EC5\u1EC7\u1EC9\u1ECB\u1ECD\u1ECF\u1ED1\u1ED3\u1ED5\u1ED7\u1ED9\u1EDB\u1EDD\u1EDF\u1EE1\u1EE3\u1EE5\u1EE7\u1EE9\u1EEB\u1EED\u1EEF\u1EF1\u1EF3\u1EF5\u1EF7\u1EF9\u1EFB\u1EFD\u1EFF-\u1F07\u1F10-\u1F15\u1F20-\u1F27\u1F30-\u1F37\u1F40-\u1F45\u1F50-\u1F57\u1F60-\u1F67\u1F70-\u1F7D\u1F80-\u1F87\u1F90-\u1F97\u1FA0-\u1FA7\u1FB0-\u1FB4\u1FB6\u1FB7\u1FBE\u1FC2-\u1FC4\u1FC6\u1FC7\u1FD0-\u1FD3\u1FD6\u1FD7\u1FE0-\u1FE7\u1FF2-\u1FF4\u1FF6\u1FF7\u210A\u210E\u210F\u2113\u212F\u2134\u2139\u213C\u213D\u2146-\u2149\u214E\u2184\u2C30-\u2C5E\u2C61\u2C65\u2C66\u2C68\u2C6A\u2C6C\u2C71\u2C73\u2C74\u2C76-\u2C7B\u2C81\u2C83\u2C85\u2C87\u2C89\u2C8B\u2C8D\u2C8F\u2C91\u2C93\u2C95\u2C97\u2C99\u2C9B\u2C9D\u2C9F\u2CA1\u2CA3\u2CA5\u2CA7\u2CA9\u2CAB\u2CAD\u2CAF\u2CB1\u2CB3\u2CB5\u2CB7\u2CB9\u2CBB\u2CBD\u2CBF\u2CC1\u2CC3\u2CC5\u2CC7\u2CC9\u2CCB\u2CCD\u2CCF\u2CD1\u2CD3\u2CD5\u2CD7\u2CD9\u2CDB\u2CDD\u2CDF\u2CE1\u2CE3\u2CE4\u2CEC\u2CEE\u2CF3\u2D00-\u2D25\u2D27\u2D2D\uA641\uA643\uA645\uA647\uA649\uA64B\uA64D\uA64F\uA651\uA653\uA655\uA657\uA659\uA65B\uA65D\uA65F\uA661\uA663\uA665\uA667\uA669\uA66B\uA66D\uA681\uA683\uA685\uA687\uA689\uA68B\uA68D\uA68F\uA691\uA693\uA695\uA697\uA723\uA725\uA727\uA729\uA72B\uA72D\uA72F-\uA731\uA733\uA735\uA737\uA739\uA73B\uA73D\uA73F\uA741\uA743\uA745\uA747\uA749\uA74B\uA74D\uA74F\uA751\uA753\uA755\uA757\uA759\uA75B\uA75D\uA75F\uA761\uA763\uA765\uA767\uA769\uA76B\uA76D\uA76F\uA771-\uA778\uA77A\uA77C\uA77F\uA781\uA783\uA785\uA787\uA78C\uA78E\uA791\uA793\uA7A1\uA7A3\uA7A5\uA7A7\uA7A9\uA7FA\uFB00-\uFB06\uFB13-\uFB17\uFF41-\uFF5A])([\u0041-\u005A\u00C0-\u00D6\u00D8-\u00DE\u0100\u0102\u0104\u0106\u0108\u010A\u010C\u010E\u0110\u0112\u0114\u0116\u0118\u011A\u011C\u011E\u0120\u0122\u0124\u0126\u0128\u012A\u012C\u012E\u0130\u0132\u0134\u0136\u0139\u013B\u013D\u013F\u0141\u0143\u0145\u0147\u014A\u014C\u014E\u0150\u0152\u0154\u0156\u0158\u015A\u015C\u015E\u0160\u0162\u0164\u0166\u0168\u016A\u016C\u016E\u0170\u0172\u0174\u0176\u0178\u0179\u017B\u017D\u0181\u0182\u0184\u0186\u0187\u0189-\u018B\u018E-\u0191\u0193\u0194\u0196-\u0198\u019C\u019D\u019F\u01A0\u01A2\u01A4\u01A6\u01A7\u01A9\u01AC\u01AE\u01AF\u01B1-\u01B3\u01B5\u01B7\u01B8\u01BC\u01C4\u01C7\u01CA\u01CD\u01CF\u01D1\u01D3\u01D5\u01D7\u01D9\u01DB\u01DE\u01E0\u01E2\u01E4\u01E6\u01E8\u01EA\u01EC\u01EE\u01F1\u01F4\u01F6-\u01F8\u01FA\u01FC\u01FE\u0200\u0202\u0204\u0206\u0208\u020A\u020C\u020E\u0210\u0212\u0214\u0216\u0218\u021A\u021C\u021E\u0220\u0222\u0224\u0226\u0228\u022A\u022C\u022E\u0230\u0232\u023A\u023B\u023D\u023E\u0241\u0243-\u0246\u0248\u024A\u024C\u024E\u0370\u0372\u0376\u0386\u0388-\u038A\u038C\u038E\u038F\u0391-\u03A1\u03A3-\u03AB\u03CF\u03D2-\u03D4\u03D8\u03DA\u03DC\u03DE\u03E0\u03E2\u03E4\u03E6\u03E8\u03EA\u03EC\u03EE\u03F4\u03F7\u03F9\u03FA\u03FD-\u042F\u0460\u0462\u0464\u0466\u0468\u046A\u046C\u046E\u0470\u0472\u0474\u0476\u0478\u047A\u047C\u047E\u0480\u048A\u048C\u048E\u0490\u0492\u0494\u0496\u0498\u049A\u049C\u049E\u04A0\u04A2\u04A4\u04A6\u04A8\u04AA\u04AC\u04AE\u04B0\u04B2\u04B4\u04B6\u04B8\u04BA\u04BC\u04BE\u04C0\u04C1\u04C3\u04C5\u04C7\u04C9\u04CB\u04CD\u04D0\u04D2\u04D4\u04D6\u04D8\u04DA\u04DC\u04DE\u04E0\u04E2\u04E4\u04E6\u04E8\u04EA\u04EC\u04EE\u04F0\u04F2\u04F4\u04F6\u04F8\u04FA\u04FC\u04FE\u0500\u0502\u0504\u0506\u0508\u050A\u050C\u050E\u0510\u0512\u0514\u0516\u0518\u051A\u051C\u051E\u0520\u0522\u0524\u0526\u0531-\u0556\u10A0-\u10C5\u10C7\u10CD\u1E00\u1E02\u1E04\u1E06\u1E08\u1E0A\u1E0C\u1E0E\u1E10\u1E12\u1E14\u1E16\u1E18\u1E1A\u1E1C\u1E1E\u1E20\u1E22\u1E24\u1E26\u1E28\u1E2A\u1E2C\u1E2E\u1E30\u1E32\u1E34\u1E36\u1E38\u1E3A\u1E3C\u1E3E\u1E40\u1E42\u1E44\u1E46\u1E48\u1E4A\u1E4C\u1E4E\u1E50\u1E52\u1E54\u1E56\u1E58\u1E5A\u1E5C\u1E5E\u1E60\u1E62\u1E64\u1E66\u1E68\u1E6A\u1E6C\u1E6E\u1E70\u1E72\u1E74\u1E76\u1E78\u1E7A\u1E7C\u1E7E\u1E80\u1E82\u1E84\u1E86\u1E88\u1E8A\u1E8C\u1E8E\u1E90\u1E92\u1E94\u1E9E\u1EA0\u1EA2\u1EA4\u1EA6\u1EA8\u1EAA\u1EAC\u1EAE\u1EB0\u1EB2\u1EB4\u1EB6\u1EB8\u1EBA\u1EBC\u1EBE\u1EC0\u1EC2\u1EC4\u1EC6\u1EC8\u1ECA\u1ECC\u1ECE\u1ED0\u1ED2\u1ED4\u1ED6\u1ED8\u1EDA\u1EDC\u1EDE\u1EE0\u1EE2\u1EE4\u1EE6\u1EE8\u1EEA\u1EEC\u1EEE\u1EF0\u1EF2\u1EF4\u1EF6\u1EF8\u1EFA\u1EFC\u1EFE\u1F08-\u1F0F\u1F18-\u1F1D\u1F28-\u1F2F\u1F38-\u1F3F\u1F48-\u1F4D\u1F59\u1F5B\u1F5D\u1F5F\u1F68-\u1F6F\u1FB8-\u1FBB\u1FC8-\u1FCB\u1FD8-\u1FDB\u1FE8-\u1FEC\u1FF8-\u1FFB\u2102\u2107\u210B-\u210D\u2110-\u2112\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u2130-\u2133\u213E\u213F\u2145\u2183\u2C00-\u2C2E\u2C60\u2C62-\u2C64\u2C67\u2C69\u2C6B\u2C6D-\u2C70\u2C72\u2C75\u2C7E-\u2C80\u2C82\u2C84\u2C86\u2C88\u2C8A\u2C8C\u2C8E\u2C90\u2C92\u2C94\u2C96\u2C98\u2C9A\u2C9C\u2C9E\u2CA0\u2CA2\u2CA4\u2CA6\u2CA8\u2CAA\u2CAC\u2CAE\u2CB0\u2CB2\u2CB4\u2CB6\u2CB8\u2CBA\u2CBC\u2CBE\u2CC0\u2CC2\u2CC4\u2CC6\u2CC8\u2CCA\u2CCC\u2CCE\u2CD0\u2CD2\u2CD4\u2CD6\u2CD8\u2CDA\u2CDC\u2CDE\u2CE0\u2CE2\u2CEB\u2CED\u2CF2\uA640\uA642\uA644\uA646\uA648\uA64A\uA64C\uA64E\uA650\uA652\uA654\uA656\uA658\uA65A\uA65C\uA65E\uA660\uA662\uA664\uA666\uA668\uA66A\uA66C\uA680\uA682\uA684\uA686\uA688\uA68A\uA68C\uA68E\uA690\uA692\uA694\uA696\uA722\uA724\uA726\uA728\uA72A\uA72C\uA72E\uA732\uA734\uA736\uA738\uA73A\uA73C\uA73E\uA740\uA742\uA744\uA746\uA748\uA74A\uA74C\uA74E\uA750\uA752\uA754\uA756\uA758\uA75A\uA75C\uA75E\uA760\uA762\uA764\uA766\uA768\uA76A\uA76C\uA76E\uA779\uA77B\uA77D\uA77E\uA780\uA782\uA784\uA786\uA78B\uA78D\uA790\uA792\uA7A0\uA7A2\uA7A4\uA7A6\uA7A8\uA7AA\uFF21-\uFF3A\u0030-\u0039\u00B2\u00B3\u00B9\u00BC-\u00BE\u0660-\u0669\u06F0-\u06F9\u07C0-\u07C9\u0966-\u096F\u09E6-\u09EF\u09F4-\u09F9\u0A66-\u0A6F\u0AE6-\u0AEF\u0B66-\u0B6F\u0B72-\u0B77\u0BE6-\u0BF2\u0C66-\u0C6F\u0C78-\u0C7E\u0CE6-\u0CEF\u0D66-\u0D75\u0E50-\u0E59\u0ED0-\u0ED9\u0F20-\u0F33\u1040-\u1049\u1090-\u1099\u1369-\u137C\u16EE-\u16F0\u17E0-\u17E9\u17F0-\u17F9\u1810-\u1819\u1946-\u194F\u19D0-\u19DA\u1A80-\u1A89\u1A90-\u1A99\u1B50-\u1B59\u1BB0-\u1BB9\u1C40-\u1C49\u1C50-\u1C59\u2070\u2074-\u2079\u2080-\u2089\u2150-\u2182\u2185-\u2189\u2460-\u249B\u24EA-\u24FF\u2776-\u2793\u2CFD\u3007\u3021-\u3029\u3038-\u303A\u3192-\u3195\u3220-\u3229\u3248-\u324F\u3251-\u325F\u3280-\u3289\u32B1-\u32BF\uA620-\uA629\uA6E6-\uA6EF\uA830-\uA835\uA8D0-\uA8D9\uA900-\uA909\uA9D0-\uA9D9\uAA50-\uAA59\uABF0-\uABF9\uFF10-\uFF19])/g

},{}],30:[function(require,module,exports){
module.exports = /[^\u0041-\u005A\u0061-\u007A\u00AA\u00B5\u00BA\u00C0-\u00D6\u00D8-\u00F6\u00F8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u0527\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u08A0\u08A2-\u08AC\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0977\u0979-\u097F\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C33\u0C35-\u0C39\u0C3D\u0C58\u0C59\u0C60\u0C61\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D60\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F4\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191C\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19C1-\u19C7\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2119-\u211D\u2124\u2126\u2128\u212A-\u212D\u212F-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2183\u2184\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2E2F\u3005\u3006\u3031-\u3035\u303B\u303C\u3041-\u3096\u309D-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FCC\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA697\uA6A0-\uA6E5\uA717-\uA71F\uA722-\uA788\uA78B-\uA78E\uA790-\uA793\uA7A0-\uA7AA\uA7F8-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA80-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uABC0-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC\u0030-\u0039\u00B2\u00B3\u00B9\u00BC-\u00BE\u0660-\u0669\u06F0-\u06F9\u07C0-\u07C9\u0966-\u096F\u09E6-\u09EF\u09F4-\u09F9\u0A66-\u0A6F\u0AE6-\u0AEF\u0B66-\u0B6F\u0B72-\u0B77\u0BE6-\u0BF2\u0C66-\u0C6F\u0C78-\u0C7E\u0CE6-\u0CEF\u0D66-\u0D75\u0E50-\u0E59\u0ED0-\u0ED9\u0F20-\u0F33\u1040-\u1049\u1090-\u1099\u1369-\u137C\u16EE-\u16F0\u17E0-\u17E9\u17F0-\u17F9\u1810-\u1819\u1946-\u194F\u19D0-\u19DA\u1A80-\u1A89\u1A90-\u1A99\u1B50-\u1B59\u1BB0-\u1BB9\u1C40-\u1C49\u1C50-\u1C59\u2070\u2074-\u2079\u2080-\u2089\u2150-\u2182\u2185-\u2189\u2460-\u249B\u24EA-\u24FF\u2776-\u2793\u2CFD\u3007\u3021-\u3029\u3038-\u303A\u3192-\u3195\u3220-\u3229\u3248-\u324F\u3251-\u325F\u3280-\u3289\u32B1-\u32BF\uA620-\uA629\uA6E6-\uA6EF\uA830-\uA835\uA8D0-\uA8D9\uA900-\uA909\uA9D0-\uA9D9\uAA50-\uAA59\uABF0-\uABF9\uFF10-\uFF19]+/g

},{}],31:[function(require,module,exports){
module.exports = /([\u0030-\u0039\u00B2\u00B3\u00B9\u00BC-\u00BE\u0660-\u0669\u06F0-\u06F9\u07C0-\u07C9\u0966-\u096F\u09E6-\u09EF\u09F4-\u09F9\u0A66-\u0A6F\u0AE6-\u0AEF\u0B66-\u0B6F\u0B72-\u0B77\u0BE6-\u0BF2\u0C66-\u0C6F\u0C78-\u0C7E\u0CE6-\u0CEF\u0D66-\u0D75\u0E50-\u0E59\u0ED0-\u0ED9\u0F20-\u0F33\u1040-\u1049\u1090-\u1099\u1369-\u137C\u16EE-\u16F0\u17E0-\u17E9\u17F0-\u17F9\u1810-\u1819\u1946-\u194F\u19D0-\u19DA\u1A80-\u1A89\u1A90-\u1A99\u1B50-\u1B59\u1BB0-\u1BB9\u1C40-\u1C49\u1C50-\u1C59\u2070\u2074-\u2079\u2080-\u2089\u2150-\u2182\u2185-\u2189\u2460-\u249B\u24EA-\u24FF\u2776-\u2793\u2CFD\u3007\u3021-\u3029\u3038-\u303A\u3192-\u3195\u3220-\u3229\u3248-\u324F\u3251-\u325F\u3280-\u3289\u32B1-\u32BF\uA620-\uA629\uA6E6-\uA6EF\uA830-\uA835\uA8D0-\uA8D9\uA900-\uA909\uA9D0-\uA9D9\uAA50-\uAA59\uABF0-\uABF9\uFF10-\uFF19])([^\u0030-\u0039\u00B2\u00B3\u00B9\u00BC-\u00BE\u0660-\u0669\u06F0-\u06F9\u07C0-\u07C9\u0966-\u096F\u09E6-\u09EF\u09F4-\u09F9\u0A66-\u0A6F\u0AE6-\u0AEF\u0B66-\u0B6F\u0B72-\u0B77\u0BE6-\u0BF2\u0C66-\u0C6F\u0C78-\u0C7E\u0CE6-\u0CEF\u0D66-\u0D75\u0E50-\u0E59\u0ED0-\u0ED9\u0F20-\u0F33\u1040-\u1049\u1090-\u1099\u1369-\u137C\u16EE-\u16F0\u17E0-\u17E9\u17F0-\u17F9\u1810-\u1819\u1946-\u194F\u19D0-\u19DA\u1A80-\u1A89\u1A90-\u1A99\u1B50-\u1B59\u1BB0-\u1BB9\u1C40-\u1C49\u1C50-\u1C59\u2070\u2074-\u2079\u2080-\u2089\u2150-\u2182\u2185-\u2189\u2460-\u249B\u24EA-\u24FF\u2776-\u2793\u2CFD\u3007\u3021-\u3029\u3038-\u303A\u3192-\u3195\u3220-\u3229\u3248-\u324F\u3251-\u325F\u3280-\u3289\u32B1-\u32BF\uA620-\uA629\uA6E6-\uA6EF\uA830-\uA835\uA8D0-\uA8D9\uA900-\uA909\uA9D0-\uA9D9\uAA50-\uAA59\uABF0-\uABF9\uFF10-\uFF19])/g

},{}],32:[function(require,module,exports){
var upperCase = require('upper-case');
var snakeCase = require('snake-case');

/**
 * Constant case a string.
 *
 * @param  {String} string
 * @param  {String} [locale]
 * @return {String}
 */
module.exports = function (string, locale) {
  return upperCase(snakeCase(string, locale), locale);
};

},{"snake-case":60,"upper-case":61}],33:[function(require,module,exports){
var hasOwn = Object.prototype.hasOwnProperty;
var toString = Object.prototype.toString;
var undefined;

var isPlainObject = function isPlainObject(obj) {
	'use strict';
	if (!obj || toString.call(obj) !== '[object Object]') {
		return false;
	}

	var has_own_constructor = hasOwn.call(obj, 'constructor');
	var has_is_property_of_method = obj.constructor && obj.constructor.prototype && hasOwn.call(obj.constructor.prototype, 'isPrototypeOf');
	// Not own constructor property must be Object
	if (obj.constructor && !has_own_constructor && !has_is_property_of_method) {
		return false;
	}

	// Own properties are enumerated firstly, so to speed up,
	// if last one is own, then all properties are own.
	var key;
	for (key in obj) {}

	return key === undefined || hasOwn.call(obj, key);
};

module.exports = function extend() {
	'use strict';
	var options, name, src, copy, copyIsArray, clone,
		target = arguments[0],
		i = 1,
		length = arguments.length,
		deep = false;

	// Handle a deep copy situation
	if (typeof target === 'boolean') {
		deep = target;
		target = arguments[1] || {};
		// skip the boolean and the target
		i = 2;
	} else if ((typeof target !== 'object' && typeof target !== 'function') || target == null) {
		target = {};
	}

	for (; i < length; ++i) {
		options = arguments[i];
		// Only deal with non-null/undefined values
		if (options != null) {
			// Extend the base object
			for (name in options) {
				src = target[name];
				copy = options[name];

				// Prevent never-ending loop
				if (target === copy) {
					continue;
				}

				// Recurse if we're merging plain objects or arrays
				if (deep && copy && (isPlainObject(copy) || (copyIsArray = Array.isArray(copy)))) {
					if (copyIsArray) {
						copyIsArray = false;
						clone = src && Array.isArray(src) ? src : [];
					} else {
						clone = src && isPlainObject(src) ? src : {};
					}

					// Never move original objects, clone them
					target[name] = extend(deep, clone, copy);

				// Don't bring in undefined values
				} else if (copy !== undefined) {
					target[name] = copy;
				}
			}
		}
	}

	// Return the modified object
	return target;
};


},{}],34:[function(require,module,exports){
(function (global){
"use strict";
/*globals Handlebars: true */
var base = require("./handlebars/base");

// Each of these augment the Handlebars object. No need to setup here.
// (This is done to easily share code between commonjs and browse envs)
var SafeString = require("./handlebars/safe-string")["default"];
var Exception = require("./handlebars/exception")["default"];
var Utils = require("./handlebars/utils");
var runtime = require("./handlebars/runtime");

// For compatibility and usage outside of module systems, make the Handlebars object a namespace
var create = function() {
  var hb = new base.HandlebarsEnvironment();

  Utils.extend(hb, base);
  hb.SafeString = SafeString;
  hb.Exception = Exception;
  hb.Utils = Utils;
  hb.escapeExpression = Utils.escapeExpression;

  hb.VM = runtime;
  hb.template = function(spec) {
    return runtime.template(spec, hb);
  };

  return hb;
};

var Handlebars = create();
Handlebars.create = create;

/*jshint -W040 */
/* istanbul ignore next */
var root = typeof global !== 'undefined' ? global : window,
    $Handlebars = root.Handlebars;
/* istanbul ignore next */
Handlebars.noConflict = function() {
  if (root.Handlebars === Handlebars) {
    root.Handlebars = $Handlebars;
  }
};

Handlebars['default'] = Handlebars;

exports["default"] = Handlebars;
}).call(this,typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {})
},{"./handlebars/base":35,"./handlebars/exception":36,"./handlebars/runtime":37,"./handlebars/safe-string":38,"./handlebars/utils":39}],35:[function(require,module,exports){
"use strict";
var Utils = require("./utils");
var Exception = require("./exception")["default"];

var VERSION = "3.0.0";
exports.VERSION = VERSION;var COMPILER_REVISION = 6;
exports.COMPILER_REVISION = COMPILER_REVISION;
var REVISION_CHANGES = {
  1: '<= 1.0.rc.2', // 1.0.rc.2 is actually rev2 but doesn't report it
  2: '== 1.0.0-rc.3',
  3: '== 1.0.0-rc.4',
  4: '== 1.x.x',
  5: '== 2.0.0-alpha.x',
  6: '>= 2.0.0-beta.1'
};
exports.REVISION_CHANGES = REVISION_CHANGES;
var isArray = Utils.isArray,
    isFunction = Utils.isFunction,
    toString = Utils.toString,
    objectType = '[object Object]';

function HandlebarsEnvironment(helpers, partials) {
  this.helpers = helpers || {};
  this.partials = partials || {};

  registerDefaultHelpers(this);
}

exports.HandlebarsEnvironment = HandlebarsEnvironment;HandlebarsEnvironment.prototype = {
  constructor: HandlebarsEnvironment,

  logger: logger,
  log: log,

  registerHelper: function(name, fn) {
    if (toString.call(name) === objectType) {
      if (fn) { throw new Exception('Arg not supported with multiple helpers'); }
      Utils.extend(this.helpers, name);
    } else {
      this.helpers[name] = fn;
    }
  },
  unregisterHelper: function(name) {
    delete this.helpers[name];
  },

  registerPartial: function(name, partial) {
    if (toString.call(name) === objectType) {
      Utils.extend(this.partials,  name);
    } else {
      if (typeof partial === 'undefined') {
        throw new Exception('Attempting to register a partial as undefined');
      }
      this.partials[name] = partial;
    }
  },
  unregisterPartial: function(name) {
    delete this.partials[name];
  }
};

function registerDefaultHelpers(instance) {
  instance.registerHelper('helperMissing', function(/* [args, ]options */) {
    if(arguments.length === 1) {
      // A missing field in a {{foo}} constuct.
      return undefined;
    } else {
      // Someone is actually trying to call something, blow up.
      throw new Exception("Missing helper: '" + arguments[arguments.length-1].name + "'");
    }
  });

  instance.registerHelper('blockHelperMissing', function(context, options) {
    var inverse = options.inverse,
        fn = options.fn;

    if(context === true) {
      return fn(this);
    } else if(context === false || context == null) {
      return inverse(this);
    } else if (isArray(context)) {
      if(context.length > 0) {
        if (options.ids) {
          options.ids = [options.name];
        }

        return instance.helpers.each(context, options);
      } else {
        return inverse(this);
      }
    } else {
      if (options.data && options.ids) {
        var data = createFrame(options.data);
        data.contextPath = Utils.appendContextPath(options.data.contextPath, options.name);
        options = {data: data};
      }

      return fn(context, options);
    }
  });

  instance.registerHelper('each', function(context, options) {
    if (!options) {
      throw new Exception('Must pass iterator to #each');
    }

    var fn = options.fn, inverse = options.inverse;
    var i = 0, ret = "", data;

    var contextPath;
    if (options.data && options.ids) {
      contextPath = Utils.appendContextPath(options.data.contextPath, options.ids[0]) + '.';
    }

    if (isFunction(context)) { context = context.call(this); }

    if (options.data) {
      data = createFrame(options.data);
    }

    function execIteration(key, i, last) {
      if (data) {
        data.key = key;
        data.index = i;
        data.first = i === 0;
        data.last  = !!last;

        if (contextPath) {
          data.contextPath = contextPath + key;
        }
      }

      ret = ret + fn(context[key], {
        data: data,
        blockParams: Utils.blockParams([context[key], key], [contextPath + key, null])
      });
    }

    if(context && typeof context === 'object') {
      if (isArray(context)) {
        for(var j = context.length; i<j; i++) {
          execIteration(i, i, i === context.length-1);
        }
      } else {
        var priorKey;

        for(var key in context) {
          if(context.hasOwnProperty(key)) {
            // We're running the iterations one step out of sync so we can detect
            // the last iteration without have to scan the object twice and create
            // an itermediate keys array. 
            if (priorKey) {
              execIteration(priorKey, i-1);
            }
            priorKey = key;
            i++;
          }
        }
        if (priorKey) {
          execIteration(priorKey, i-1, true);
        }
      }
    }

    if(i === 0){
      ret = inverse(this);
    }

    return ret;
  });

  instance.registerHelper('if', function(conditional, options) {
    if (isFunction(conditional)) { conditional = conditional.call(this); }

    // Default behavior is to render the positive path if the value is truthy and not empty.
    // The `includeZero` option may be set to treat the condtional as purely not empty based on the
    // behavior of isEmpty. Effectively this determines if 0 is handled by the positive path or negative.
    if ((!options.hash.includeZero && !conditional) || Utils.isEmpty(conditional)) {
      return options.inverse(this);
    } else {
      return options.fn(this);
    }
  });

  instance.registerHelper('unless', function(conditional, options) {
    return instance.helpers['if'].call(this, conditional, {fn: options.inverse, inverse: options.fn, hash: options.hash});
  });

  instance.registerHelper('with', function(context, options) {
    if (isFunction(context)) { context = context.call(this); }

    var fn = options.fn;

    if (!Utils.isEmpty(context)) {
      if (options.data && options.ids) {
        var data = createFrame(options.data);
        data.contextPath = Utils.appendContextPath(options.data.contextPath, options.ids[0]);
        options = {data:data};
      }

      return fn(context, options);
    } else {
      return options.inverse(this);
    }
  });

  instance.registerHelper('log', function(message, options) {
    var level = options.data && options.data.level != null ? parseInt(options.data.level, 10) : 1;
    instance.log(level, message);
  });

  instance.registerHelper('lookup', function(obj, field) {
    return obj && obj[field];
  });
}

var logger = {
  methodMap: { 0: 'debug', 1: 'info', 2: 'warn', 3: 'error' },

  // State enum
  DEBUG: 0,
  INFO: 1,
  WARN: 2,
  ERROR: 3,
  level: 1,

  // Can be overridden in the host environment
  log: function(level, message) {
    if (typeof console !== 'undefined' && logger.level <= level) {
      var method = logger.methodMap[level];
      (console[method] || console.log).call(console, message);
    }
  }
};
exports.logger = logger;
var log = logger.log;
exports.log = log;
var createFrame = function(object) {
  var frame = Utils.extend({}, object);
  frame._parent = object;
  return frame;
};
exports.createFrame = createFrame;
},{"./exception":36,"./utils":39}],36:[function(require,module,exports){
"use strict";

var errorProps = ['description', 'fileName', 'lineNumber', 'message', 'name', 'number', 'stack'];

function Exception(message, node) {
  var loc = node && node.loc,
      line,
      column;
  if (loc) {
    line = loc.start.line;
    column = loc.start.column;

    message += ' - ' + line + ':' + column;
  }

  var tmp = Error.prototype.constructor.call(this, message);

  // Unfortunately errors are not enumerable in Chrome (at least), so `for prop in tmp` doesn't work.
  for (var idx = 0; idx < errorProps.length; idx++) {
    this[errorProps[idx]] = tmp[errorProps[idx]];
  }

  if (loc) {
    this.lineNumber = line;
    this.column = column;
  }
}

Exception.prototype = new Error();

exports["default"] = Exception;
},{}],37:[function(require,module,exports){
"use strict";
var Utils = require("./utils");
var Exception = require("./exception")["default"];
var COMPILER_REVISION = require("./base").COMPILER_REVISION;
var REVISION_CHANGES = require("./base").REVISION_CHANGES;
var createFrame = require("./base").createFrame;

function checkRevision(compilerInfo) {
  var compilerRevision = compilerInfo && compilerInfo[0] || 1,
      currentRevision = COMPILER_REVISION;

  if (compilerRevision !== currentRevision) {
    if (compilerRevision < currentRevision) {
      var runtimeVersions = REVISION_CHANGES[currentRevision],
          compilerVersions = REVISION_CHANGES[compilerRevision];
      throw new Exception("Template was precompiled with an older version of Handlebars than the current runtime. "+
            "Please update your precompiler to a newer version ("+runtimeVersions+") or downgrade your runtime to an older version ("+compilerVersions+").");
    } else {
      // Use the embedded version info since the runtime doesn't know about this revision yet
      throw new Exception("Template was precompiled with a newer version of Handlebars than the current runtime. "+
            "Please update your runtime to a newer version ("+compilerInfo[1]+").");
    }
  }
}

exports.checkRevision = checkRevision;// TODO: Remove this line and break up compilePartial

function template(templateSpec, env) {
  /* istanbul ignore next */
  if (!env) {
    throw new Exception("No environment passed to template");
  }
  if (!templateSpec || !templateSpec.main) {
    throw new Exception('Unknown template object: ' + typeof templateSpec);
  }

  // Note: Using env.VM references rather than local var references throughout this section to allow
  // for external users to override these as psuedo-supported APIs.
  env.VM.checkRevision(templateSpec.compiler);

  var invokePartialWrapper = function(partial, context, options) {
    if (options.hash) {
      context = Utils.extend({}, context, options.hash);
    }

    partial = env.VM.resolvePartial.call(this, partial, context, options);
    var result = env.VM.invokePartial.call(this, partial, context, options);

    if (result == null && env.compile) {
      options.partials[options.name] = env.compile(partial, templateSpec.compilerOptions, env);
      result = options.partials[options.name](context, options);
    }
    if (result != null) {
      if (options.indent) {
        var lines = result.split('\n');
        for (var i = 0, l = lines.length; i < l; i++) {
          if (!lines[i] && i + 1 === l) {
            break;
          }

          lines[i] = options.indent + lines[i];
        }
        result = lines.join('\n');
      }
      return result;
    } else {
      throw new Exception("The partial " + options.name + " could not be compiled when running in runtime-only mode");
    }
  };

  // Just add water
  var container = {
    strict: function(obj, name) {
      if (!(name in obj)) {
        throw new Exception('"' + name + '" not defined in ' + obj);
      }
      return obj[name];
    },
    lookup: function(depths, name) {
      var len = depths.length;
      for (var i = 0; i < len; i++) {
        if (depths[i] && depths[i][name] != null) {
          return depths[i][name];
        }
      }
    },
    lambda: function(current, context) {
      return typeof current === 'function' ? current.call(context) : current;
    },

    escapeExpression: Utils.escapeExpression,
    invokePartial: invokePartialWrapper,

    fn: function(i) {
      return templateSpec[i];
    },

    programs: [],
    program: function(i, data, declaredBlockParams, blockParams, depths) {
      var programWrapper = this.programs[i],
          fn = this.fn(i);
      if (data || depths || blockParams || declaredBlockParams) {
        programWrapper = program(this, i, fn, data, declaredBlockParams, blockParams, depths);
      } else if (!programWrapper) {
        programWrapper = this.programs[i] = program(this, i, fn);
      }
      return programWrapper;
    },

    data: function(data, depth) {
      while (data && depth--) {
        data = data._parent;
      }
      return data;
    },
    merge: function(param, common) {
      var ret = param || common;

      if (param && common && (param !== common)) {
        ret = Utils.extend({}, common, param);
      }

      return ret;
    },

    noop: env.VM.noop,
    compilerInfo: templateSpec.compiler
  };

  var ret = function(context, options) {
    options = options || {};
    var data = options.data;

    ret._setup(options);
    if (!options.partial && templateSpec.useData) {
      data = initData(context, data);
    }
    var depths,
        blockParams = templateSpec.useBlockParams ? [] : undefined;
    if (templateSpec.useDepths) {
      depths = options.depths ? [context].concat(options.depths) : [context];
    }

    return templateSpec.main.call(container, context, container.helpers, container.partials, data, blockParams, depths);
  };
  ret.isTop = true;

  ret._setup = function(options) {
    if (!options.partial) {
      container.helpers = container.merge(options.helpers, env.helpers);

      if (templateSpec.usePartial) {
        container.partials = container.merge(options.partials, env.partials);
      }
    } else {
      container.helpers = options.helpers;
      container.partials = options.partials;
    }
  };

  ret._child = function(i, data, blockParams, depths) {
    if (templateSpec.useBlockParams && !blockParams) {
      throw new Exception('must pass block params');
    }
    if (templateSpec.useDepths && !depths) {
      throw new Exception('must pass parent depths');
    }

    return program(container, i, templateSpec[i], data, 0, blockParams, depths);
  };
  return ret;
}

exports.template = template;function program(container, i, fn, data, declaredBlockParams, blockParams, depths) {
  var prog = function(context, options) {
    options = options || {};

    return fn.call(container,
        context,
        container.helpers, container.partials,
        options.data || data,
        blockParams && [options.blockParams].concat(blockParams),
        depths && [context].concat(depths));
  };
  prog.program = i;
  prog.depth = depths ? depths.length : 0;
  prog.blockParams = declaredBlockParams || 0;
  return prog;
}

exports.program = program;function resolvePartial(partial, context, options) {
  if (!partial) {
    partial = options.partials[options.name];
  } else if (!partial.call && !options.name) {
    // This is a dynamic partial that returned a string
    options.name = partial;
    partial = options.partials[partial];
  }
  return partial;
}

exports.resolvePartial = resolvePartial;function invokePartial(partial, context, options) {
  options.partial = true;

  if(partial === undefined) {
    throw new Exception("The partial " + options.name + " could not be found");
  } else if(partial instanceof Function) {
    return partial(context, options);
  }
}

exports.invokePartial = invokePartial;function noop() { return ""; }

exports.noop = noop;function initData(context, data) {
  if (!data || !('root' in data)) {
    data = data ? createFrame(data) : {};
    data.root = context;
  }
  return data;
}
},{"./base":35,"./exception":36,"./utils":39}],38:[function(require,module,exports){
"use strict";
// Build out our basic SafeString type
function SafeString(string) {
  this.string = string;
}

SafeString.prototype.toString = SafeString.prototype.toHTML = function() {
  return "" + this.string;
};

exports["default"] = SafeString;
},{}],39:[function(require,module,exports){
"use strict";
/*jshint -W004 */
var escape = {
  "&": "&amp;",
  "<": "&lt;",
  ">": "&gt;",
  '"': "&quot;",
  "'": "&#x27;",
  "`": "&#x60;"
};

var badChars = /[&<>"'`]/g;
var possible = /[&<>"'`]/;

function escapeChar(chr) {
  return escape[chr];
}

function extend(obj /* , ...source */) {
  for (var i = 1; i < arguments.length; i++) {
    for (var key in arguments[i]) {
      if (Object.prototype.hasOwnProperty.call(arguments[i], key)) {
        obj[key] = arguments[i][key];
      }
    }
  }

  return obj;
}

exports.extend = extend;var toString = Object.prototype.toString;
exports.toString = toString;
// Sourced from lodash
// https://github.com/bestiejs/lodash/blob/master/LICENSE.txt
var isFunction = function(value) {
  return typeof value === 'function';
};
// fallback for older versions of Chrome and Safari
/* istanbul ignore next */
if (isFunction(/x/)) {
  isFunction = function(value) {
    return typeof value === 'function' && toString.call(value) === '[object Function]';
  };
}
var isFunction;
exports.isFunction = isFunction;
/* istanbul ignore next */
var isArray = Array.isArray || function(value) {
  return (value && typeof value === 'object') ? toString.call(value) === '[object Array]' : false;
};
exports.isArray = isArray;
// Older IE versions do not directly support indexOf so we must implement our own, sadly.
function indexOf(array, value) {
  for (var i = 0, len = array.length; i < len; i++) {
    if (array[i] === value) {
      return i;
    }
  }
  return -1;
}

exports.indexOf = indexOf;
function escapeExpression(string) {
  // don't escape SafeStrings, since they're already safe
  if (string && string.toHTML) {
    return string.toHTML();
  } else if (string == null) {
    return "";
  } else if (!string) {
    return string + '';
  }

  // Force a string conversion as this will be done by the append regardless and
  // the regex test will do this transparently behind the scenes, causing issues if
  // an object's to string has escaped characters in it.
  string = "" + string;

  if(!possible.test(string)) { return string; }
  return string.replace(badChars, escapeChar);
}

exports.escapeExpression = escapeExpression;function isEmpty(value) {
  if (!value && value !== 0) {
    return true;
  } else if (isArray(value) && value.length === 0) {
    return true;
  } else {
    return false;
  }
}

exports.isEmpty = isEmpty;function blockParams(params, ids) {
  params.path = ids;
  return params;
}

exports.blockParams = blockParams;function appendContextPath(contextPath, id) {
  return (contextPath ? contextPath + '.' : '') + id;
}

exports.appendContextPath = appendContextPath;
},{}],40:[function(require,module,exports){
// Create a simple path alias to allow browserify to resolve
// the runtime on a supported path.
module.exports = require('./dist/cjs/handlebars.runtime').default;

},{"./dist/cjs/handlebars.runtime":34}],41:[function(require,module,exports){
module.exports = require("handlebars/runtime")["default"];

},{"handlebars/runtime":40}],42:[function(require,module,exports){
'use strict';
var repeating = require('repeating');

module.exports = function (str, indent, count) {
	if (typeof str !== 'string' || typeof indent !== 'string') {
		throw new TypeError('`string` and `indent` should be strings');
	}

	if (count != null && typeof count !== 'number') {
		throw new TypeError('`count` should be a number');
	}

	indent = count > 1 ? repeating(indent, count) : indent;

	return str.replace(/^(?!\s*$)/mg, indent);
};

},{"repeating":43}],43:[function(require,module,exports){
'use strict';
var isFinite = require('is-finite');

module.exports = function (str, n) {
	if (typeof str !== 'string') {
		throw new TypeError('Expected a string as the first argument');
	}

	if (n < 0 || !isFinite(n)) {
		throw new TypeError('Expected a finite positive number');
	}

	var ret = '';

	do {
		if (n & 1) {
			ret += str;
		}

		str += str;
	} while (n = n >> 1);

	return ret;
};

},{"is-finite":44}],44:[function(require,module,exports){
'use strict';
module.exports = Number.isFinite || function (val) {
	// Number.isNaN() => val !== val
	if (typeof val !== 'number' || val !== val || val === Infinity || val === -Infinity) {
		return false;
	}

	return true;
};

},{}],45:[function(require,module,exports){
(function (Buffer){
(function (root, stringify) {
  /* istanbul ignore else */
  if (typeof require === 'function' && typeof exports === 'object' && typeof module === 'object') {
    // Node.
    module.exports = stringify();
  } else if (typeof define === 'function' && define.amd) {
    // AMD, registers as an anonymous module.
    define(function () {
      return stringify();
    });
  } else {
    // Browser global.
    root.javascriptStringify = stringify();
  }
})(this, function () {
  /**
   * Match all characters that need to be escaped in a string. Modified from
   * source to match single quotes instead of double.
   *
   * Source: https://github.com/douglascrockford/JSON-js/blob/master/json2.js
   *
   * @type {RegExp}
   */
  var ESCAPABLE = /[\\\'\x00-\x1f\x7f-\x9f\u00ad\u0600-\u0604\u070f\u17b4\u17b5\u200c-\u200f\u2028-\u202f\u2060-\u206f\ufeff\ufff0-\uffff]/g;

  /**
   * Map of characters to escape characters.
   *
   * @type {Object}
   */
  var META_CHARS = {
    '\b': '\\b',
    '\t': '\\t',
    '\n': '\\n',
    '\f': '\\f',
    '\r': '\\r',
    "'":  "\\'",
    '"':  '\\"',
    '\\': '\\\\'
  };

  /**
   * Escape any character into its literal JavaScript string.
   *
   * @param  {String} char
   * @return {String}
   */
  var escapeChar = function (char) {
    var meta = META_CHARS[char];

    return meta || '\\u' + ('0000' + char.charCodeAt(0).toString(16)).slice(-4);
  };

  /**
   * JavaScript reserved word list.
   */
  var RESERVED_WORDS = {};

  /**
   * Map reserved words to the object.
   */
  (
    'break else new var case finally return void catch for switch while ' +
    'continue function this with default if throw delete in try ' +
    'do instanceof typeof abstract enum int short boolean export ' +
    'interface static byte extends long super char final native synchronized ' +
    'class float package throws const goto private transient debugger ' +
    'implements protected volatile double import public let yield'
  ).split(' ').map(function (key) {
    RESERVED_WORDS[key] = true;
  });

  /**
   * Check if a variable name is valid.
   *
   * @param  {String}  name
   * @return {Boolean}
   */
  var isValidVariableName = function (name) {
    return !RESERVED_WORDS[name] && /^[a-zA-Z_$][0-9a-zA-Z_$]*$/.test(name);
  };

  /**
   * Return the global variable name.
   *
   * @return {String}
   */
  var getGlobalVariable = function (value, indent, stringify) {
    return 'Function(' + stringify('return this;') + ')()';
  };

  /**
   * Convert JavaScript objects into strings.
   *
   * @type {Object}
   */
  var OBJECT_TYPES = {
    '[object Array]': function (array, indent, stringify) {
      // Map array values to their stringified values with correct indentation.
      var values = array.map(function (value) {
        return indent + stringify(value).split('\n').join('\n' + indent);
      }).join(indent ? ',\n' : ',');

      // Wrap the array in newlines if we have indentation set.
      if (indent && values) {
        return '[\n' + values + '\n]';
      }

      return '[' + values + ']';
    },
    '[object Object]': function (object, indent, stringify) {
      if (typeof Buffer === 'function' && Buffer.isBuffer(object)) {
        return 'new Buffer(' + stringify(object.toString()) + ')';
      }

      // Iterate over object keys and concat string together.
      var values = Object.keys(object).reduce(function (values, key) {
        var value = stringify(object[key]);

        // Omit `undefined` object values.
        if (value === undefined) {
          return values;
        }

        // String format the key and value data.
        key   = isValidVariableName(key) ? key : stringify(key);
        value = String(value).split('\n').join('\n' + indent);

        // Push the current object key and value into the values array.
        values.push(indent + key + ':' + (indent ? ' ' : '') + value);

        return values;
      }, []).join(indent ? ',\n' : ',');

      // Wrap the object in newlines if we have indentation set.
      if (indent && values) {
        return '{\n' + values + '\n}';
      }

      return '{' + values + '}';
    },
    '[object Date]': function (date, indent, stringify) {
      return 'new Date(' + date.getTime() + ')';
    },
    '[object String]': function (string, indent, stringify) {
      return 'new String(' + stringify(string.toString()) + ')';
    },
    '[object Number]': function (number, indent, stringify) {
      return 'new Number(' + number + ')';
    },
    '[object Boolean]': function (boolean, indent, stringify) {
      return 'new Boolean(' + boolean + ')';
    },
    '[object RegExp]': String,
    '[object Function]': String,
    '[object global]': getGlobalVariable,
    '[object Window]': getGlobalVariable
  };

  /**
   * Convert JavaScript primitives into strings.
   *
   * @type {Object}
   */
  var PRIMITIVE_TYPES = {
    'string': function (string) {
      return "'" + string.replace(ESCAPABLE, escapeChar) + "'";
    },
    'number': String,
    'object': String,
    'boolean': String,
    'undefined': String
  };

  /**
   * Convert any value to a string.
   *
   * @param  {*}        value
   * @param  {String}   indent
   * @param  {Function} stringify
   * @return {String}
   */
  var stringify = function (value, indent, stringify) {
    // Convert primitives into strings.
    if (Object(value) !== value) {
      return PRIMITIVE_TYPES[typeof value](value, indent, stringify);
    }

    // Use the internal object string to select stringification method.
    var toString = OBJECT_TYPES[Object.prototype.toString.call(value)];

    // Convert objects into strings.
    return toString && toString(value, indent, stringify);
  };

  /**
   * Stringify an object into the literal string.
   *
   * @param  {Object}          value
   * @param  {Function}        [replacer]
   * @param  {(Number|String)} [space]
   * @return {String}
   */
  return function (value, replacer, space) {
    // Convert the spaces into a string.
    if (typeof space !== 'string') {
      space = new Array(Math.max(0, space|0) + 1).join(' ');
    }

    /**
     * Handle recursion by checking if we've visited this node every iteration.
     *
     * @param  {*}      value
     * @param  {Array}  cache
     * @return {String}
     */
    var recurse = function (value, cache, next) {
      // If we've already visited this node before, break the recursion.
      if (cache.indexOf(value) > -1) {
        return;
      }

      // Push the value into the values cache to avoid an infinite loop.
      cache.push(value);

      // Stringify the value and fallback to
      return next(value, space, function (value) {
        return recurse(value, cache.slice(), next);
      });
    };

    // If the user defined a replacer function, make the recursion function
    // a double step process - `replacer -> stringify -> replacer -> etc`.
    if (typeof replacer === 'function') {
      return recurse(value, [], function (value, space, next) {
        return replacer(value, space, function (value) {
          return stringify(value, space, next);
        });
      });
    }

    return recurse(value, [], stringify);
  };
});

}).call(this,require("buffer").Buffer)
},{"buffer":23}],46:[function(require,module,exports){
/**
 * Special language-specific overrides.
 *
 * Source: ftp://ftp.unicode.org/Public/UCD/latest/ucd/SpecialCasing.txt
 *
 * @type {Object}
 */
var LANGUAGES = {
  tr: {
    regexp: /\u0130|\u0049|\u0049\u0307/g,
    map: {
      '\u0130': '\u0069',
      '\u0049': '\u0131',
      '\u0049\u0307': '\u0069'
    }
  },
  az: {
    regexp: /[\u0130]/g,
    map: {
      '\u0130': '\u0069',
      '\u0049': '\u0131',
      '\u0049\u0307': '\u0069'
    }
  },
  lt: {
    regexp: /[\u0049\u004A\u012E\u00CC\u00CD\u0128]/g,
    map: {
      '\u0049': '\u0069\u0307',
      '\u004A': '\u006A\u0307',
      '\u012E': '\u012F\u0307',
      '\u00CC': '\u0069\u0307\u0300',
      '\u00CD': '\u0069\u0307\u0301',
      '\u0128': '\u0069\u0307\u0303'
    }
  }
}

/**
 * Lowercase a string.
 *
 * @param  {String} str
 * @return {String}
 */
module.exports = function (str, locale) {
  var lang = LANGUAGES[locale]

  str = str == null ? '' : String(str)

  if (lang) {
    str = str.replace(lang.regexp, function (m) { return lang.map[m] })
  }

  return str.toLowerCase()
}

},{}],47:[function(require,module,exports){

var http = require('http');

/* istanbul ignore next: implementation differs on version */
if (http.METHODS) {

  module.exports = http.METHODS.map(function(method){
    return method.toLowerCase();
  });

} else {

  module.exports = [
    'get',
    'post',
    'put',
    'head',
    'delete',
    'options',
    'trace',
    'copy',
    'lock',
    'mkcol',
    'move',
    'purge',
    'propfind',
    'proppatch',
    'unlock',
    'report',
    'mkactivity',
    'checkout',
    'merge',
    'm-search',
    'notify',
    'subscribe',
    'unsubscribe',
    'patch',
    'search',
    'connect'
  ];

}

},{"http":22}],48:[function(require,module,exports){
/*!
 * object.pick <https://github.com/jonschlinkert/object.pick>
 *
 * Copyright (c) 2014-2015 Jon Schlinkert, contributors.
 * Licensed under the MIT License
 */

'use strict';

module.exports = function pick(obj, keys) {
  var res = {};
  var i = 0;

  if (typeof obj !== 'object') {
    return res;
  }

  if (typeof keys === 'string') {
    if (keys in obj) {
      res[keys] = obj[keys];
    }
    return res;
  }

  var len = keys.length;

  while (len--) {
    var key = keys[i++];
    if (key in obj) {
      res[key] = obj[key];
    }
  }
  return res;
};

},{}],49:[function(require,module,exports){
arguments[4][28][0].apply(exports,arguments)
},{"./vendor/camel-case-regexp":50,"./vendor/non-word-regexp":51,"./vendor/trailing-digit-regexp":52,"dup":28,"lower-case":46}],50:[function(require,module,exports){
arguments[4][29][0].apply(exports,arguments)
},{"dup":29}],51:[function(require,module,exports){
arguments[4][30][0].apply(exports,arguments)
},{"dup":30}],52:[function(require,module,exports){
arguments[4][31][0].apply(exports,arguments)
},{"dup":31}],53:[function(require,module,exports){
var sentenceCase = require('sentence-case');

/**
 * Param case a string.
 *
 * @param  {String} string
 * @param  {String} [locale]
 * @return {String}
 */
module.exports = function (string, locale) {
  return sentenceCase(string, locale, '-');
};

},{"sentence-case":49}],54:[function(require,module,exports){
var upperCase = require('upper-case');

/**
 * Upper case the first character of a string.
 *
 * @param  {String} str
 * @return {String}
 */
module.exports = function (str, locale) {
  if (str == null) {
    return '';
  }

  str = String(str);

  return upperCase(str.charAt(0), locale) + str.substr(1);
};

},{"upper-case":61}],55:[function(require,module,exports){
var camelCase      = require('camel-case');
var upperCaseFirst = require('upper-case-first');

/**
 * Pascal case a string.
 *
 * @param  {String} string
 * @param  {String} [locale]
 * @return {String}
 */
module.exports = function (string, locale) {
  return upperCaseFirst(camelCase(string, locale), locale);
};

},{"camel-case":27,"upper-case-first":54}],56:[function(require,module,exports){
arguments[4][28][0].apply(exports,arguments)
},{"./vendor/camel-case-regexp":57,"./vendor/non-word-regexp":58,"./vendor/trailing-digit-regexp":59,"dup":28,"lower-case":46}],57:[function(require,module,exports){
arguments[4][29][0].apply(exports,arguments)
},{"dup":29}],58:[function(require,module,exports){
arguments[4][30][0].apply(exports,arguments)
},{"dup":30}],59:[function(require,module,exports){
arguments[4][31][0].apply(exports,arguments)
},{"dup":31}],60:[function(require,module,exports){
var sentenceCase = require('sentence-case');

/**
 * Snake case a string.
 *
 * @param  {String} str
 * @param  {String} [locale]
 * @return {String}
 */
module.exports = function (str, locale) {
  return sentenceCase(str, locale, '_');
};

},{"sentence-case":56}],61:[function(require,module,exports){
/**
 * Special language-specific overrides.
 *
 * Source: ftp://ftp.unicode.org/Public/UCD/latest/ucd/SpecialCasing.txt
 *
 * @type {Object}
 */
var LANGUAGES = {
  tr: {
    regexp: /[\u0069]/g,
    map: {
      '\u0069': '\u0130'
    }
  },
  az: {
    regexp: /[\u0069]/g,
    map: {
      '\u0069': '\u0130'
    }
  },
  lt: {
    regexp: /[\u0069\u006A\u012F]\u0307|\u0069\u0307[\u0300\u0301\u0303]/g,
    map: {
      '\u0069\u0307': '\u0049',
      '\u006A\u0307': '\u004A',
      '\u012F\u0307': '\u012E',
      '\u0069\u0307\u0300': '\u00CC',
      '\u0069\u0307\u0301': '\u00CD',
      '\u0069\u0307\u0303': '\u0128'
    }
  }
}

/**
 * Upper case a string.
 *
 * @param  {String} str
 * @return {String}
 */
module.exports = function (str, locale) {
  var lang = LANGUAGES[locale]

  str = str == null ? '' : String(str)

  if (lang) {
    str = str.replace(lang.regexp, function (m) { return lang.map[m] })
  }

  return str.toUpperCase()
}

},{}],62:[function(require,module,exports){
/**
 * Export all implemented languages.
 */
exports.javascript = require('./javascript');

},{"./javascript":4}]},{},[62])(62)
});
(function (window) {
  'use strict';

  // Namespaces
  RAML.Directives     = {};
  RAML.Services       = {};
  RAML.Filters        = {};
  RAML.Services.TryIt = {};
  RAML.Security       = {};
  RAML.Settings       = RAML.Settings || {};

  // Angular Modules
  angular.module('RAML.Directives', []);
  angular.module('RAML.Services', ['raml']);
  angular.module('RAML.Security', []);
  angular.module('ramlConsoleApp', [
    'RAML.Directives',
    'RAML.Services',
    'RAML.Security',
    'hc.marked',
    'ui.codemirror',
    'hljs',
    'ngSanitize'
  ]).config(['hljsServiceProvider', function (hljsServiceProvider) {
    hljsServiceProvider.setOptions({
      classPrefix: 'raml-console-hljs-'
    });
  }]);

  var loc = window.location;
  var uri = loc.protocol + '//' + loc.host + loc.pathname.replace(/\/$/, '');

  window.hljs.configure({
    classPrefix: 'raml-console-hljs-'
  });

  // Settings
  RAML.Settings.proxy             = RAML.Settings.proxy || false;
  RAML.Settings.oauth2RedirectUri = RAML.Settings.oauth2RedirectUri || uri + '/authentication/oauth2.html';
  RAML.Settings.oauth1RedirectUri = RAML.Settings.oauth1RedirectUri || uri + '/authentication/oauth1.html';
  RAML.Settings.marked            = {
    gfm: true,
    tables: true,
    breaks: true,
    pedantic: false,
    sanitize: false,
    smartLists: true,
    silent: false,
    langPrefix: 'lang-',
    smartypants: false,
    headerPrefix: '',
    renderer: new window.marked.Renderer(),
    xhtml: false,
    highlight: function (code, lang) {
      var result = [
        '<pre class="raml-console-resource-pre raml-console-hljs hljs">',
        lang ? window.hljs.highlightAuto(code).value : code,
        '</pre>'
      ];

      return result.join('');
    }
  };
})(window);

(function () {
  'use strict';

  RAML.Directives.clickOutside = function ($document) {
    return {
      restrict: 'A',
      link: function ($scope, $element, $attrs) {
        function onClick (e) {
          if ($element[0] === e.target || $element.has(e.target).length) {
            return;
          }

          $scope.$apply($attrs.clickOutside);
        }

        $document.on('click', onClick);

        $scope.$on('$destroy', function () {
          $document.off('click', onClick);
        });
      }
    };
  };

  angular.module('RAML.Directives')
    .directive('clickOutside', ['$document', RAML.Directives.clickOutside]);
})();

(function () {
  'use strict';

  RAML.Directives.closeButton = function() {
    return {
      restrict: 'E',
      templateUrl: 'directives/close-button.tpl.html',
      replace: true,
      controller: ['$scope', '$rootScope', function($scope, $rootScope) {
        $scope.close = function () {
          var $inactiveElements = jQuery('.raml-console-tab').add('.raml-console-resource').add('li');

          $rootScope.$broadcast('resetData');
          $inactiveElements.removeClass('raml-console-is-active');
          $scope.showPanel = false;
          $scope.traits = null;
          $scope.methodInfo = {};
        };
      }]
    };
  };

  angular.module('RAML.Directives')
    .directive('closeButton', RAML.Directives.closeButton);
})();

(function () {
  'use strict';

  RAML.Directives.documentation = function() {
    return {
      restrict: 'E',
      templateUrl: 'directives/documentation.tpl.html',
      replace: true,
      controller: ['$scope', function($scope) {
        var defaultSchemaKey = Object.keys($scope.securitySchemes).sort()[0];
        var defaultSchema    = $scope.securitySchemes[defaultSchemaKey];

        $scope.markedOptions = RAML.Settings.marked;
        $scope.documentationSchemeSelected = defaultSchema;

        $scope.isSchemeSelected = function isSchemeSelected(scheme) {
          return scheme.id === $scope.documentationSchemeSelected.id;
        };

        $scope.selectDocumentationScheme = function selectDocumentationScheme(scheme) {
          $scope.documentationSchemeSelected = scheme;
        };

        $scope.schemaSettingsDocumentation = function schemaSettingsDocumentation(settings) {
          var doc = settings;

          if (typeof settings === 'object') {
            doc = settings.join(', ');
          }

          return doc;
        };

        $scope.unique = function (arr) {
          return arr.filter (function (v, i, a) { return a.indexOf (v) === i; });
        };

        $scope.currentStatusCode = '200';

        if ($scope.methodInfo.responseCodes && $scope.methodInfo.responseCodes.length > 0) {
          $scope.currentStatusCode = $scope.methodInfo.responseCodes[0];
        }

        $scope.$on('resetData', function() {
          if ($scope.methodInfo.responseCodes && $scope.methodInfo.responseCodes.length > 0) {
            $scope.currentStatusCode = $scope.methodInfo.responseCodes[0];
          }
        });

        function beautify(body, contentType) {
          if(contentType.indexOf('json') !== -1) {
            body = vkbeautify.json(body, 2);
          }

          if(contentType.indexOf('xml') !== -1) {
            body = vkbeautify.xml(body, 2);
          }

          return body;
        }

        $scope.getBeatifiedExample = function (value) {
          var result = value;

          try {
            result = beautify(value, $scope.currentBodySelected);
          }
          catch (e) { }

          return result;
        };

        $scope.getColorCode = function (code) {
          return code[0] + 'xx';
        };

        $scope.showCodeDetails = function (code) {
          $scope.currentStatusCode = code;
        };

        $scope.isActiveCode = function (code) {
          return $scope.currentStatusCode === code;
        };

        $scope.showRequestDocumentation = true;
        $scope.toggleRequestDocumentation = function () {
          $scope.showRequestDocumentation = !$scope.showRequestDocumentation;
        };

        $scope.showResponseDocumentation = true;
        $scope.toggleResponseDocumentation = function () {
          $scope.showResponseDocumentation = !$scope.showResponseDocumentation;
        };

        $scope.parameterDocumentation = function (parameter) {
          var result = '';

          if (parameter) {
            if (parameter.required) {
              result += 'required, ';
            }

            if (parameter['enum']) {
              var enumValues = $scope.unique(parameter['enum']);

              if (enumValues.length > 1) {
                result += 'one of ';
              }

              result += '(' + enumValues.filter(function (value) { return value !== ''; }).join(', ') + ')';

            } else {
              result += parameter.type || '';
            }

            if (parameter.pattern) {
              result += ' matching ' + parameter.pattern;
            }

            if (parameter.minLength && parameter.maxLength) {
              result += ', ' + parameter.minLength + '-' + parameter.maxLength + ' characters';
            } else if (parameter.minLength && !parameter.maxLength) {
              result += ', at least ' + parameter.minLength + ' characters';
            } else if (parameter.maxLength && !parameter.minLength) {
              result += ', at most ' + parameter.maxLength + ' characters';
            }


            if (parameter.minimum && parameter.maximum) {
              result += ' between ' + parameter.minimum + '-' + parameter.maximum;
            } else if (parameter.minimum && !parameter.maximum) {
              result += ' ≥ ' + parameter.minimum;
            } else if (parameter.maximum && !parameter.minimum) {
              result += ' ≤ ' + parameter.maximum;
            }

            if (parameter.repeat) {
              result += ', repeatable';
            }

            if (parameter['default'] !== undefined) {
              result += ', default: ' + parameter['default'];
            }
          }

          return result;
        };

        $scope.toggleTab = function ($event) {
          var $this        = jQuery($event.currentTarget);
          var $eachTab     = $this.parent().children('.raml-console-toggle-tab');
          var $panel       = $this.closest('.raml-console-resource-panel');
          var $eachContent = $panel.find('.raml-console-resource-panel-content');

          if (!$this.hasClass('raml-console-is-active')) {
            $eachTab.toggleClass('raml-console-is-active');
            $eachContent.toggleClass('raml-console-is-active');
          }
        };

        $scope.changeType = function ($event, type, code) {
          var $this        = jQuery($event.currentTarget);
          var $panel       = $this.closest('.raml-console-resource-body-heading');
          var $eachContent = $panel.find('span');

          $eachContent.removeClass('raml-console-is-active');
          $this.addClass('raml-console-is-active');

          $scope.responseInfo[code].currentType = type;
        };

        $scope.changeResourceBodyType = function ($event, type) {
          var $this        = jQuery($event.currentTarget);
          var $panel       = $this.closest('.raml-console-request-body-heading');
          var $eachContent = $panel.find('span');

          $eachContent.removeClass('raml-console-is-active');
          $this.addClass('raml-console-is-active');

          $scope.currentBodySelected = type;
        };

        $scope.getBodyId = function (bodyType) {
          return jQuery.trim(bodyType.toString().replace(/\W/g, ' ')).replace(/\s+/g, '_');
        };

        $scope.bodySelected = function (value) {
          return value === $scope.currentBodySelected;
        };

        $scope.$watch('currentBodySelected', function (value) {
          var $container = jQuery('.raml-console-request-body-heading');
          var $elements  = $container.find('span');

          $elements.removeClass('raml-console-is-active');
          $container.find('.raml-console-body-' + $scope.getBodyId(value)).addClass('raml-console-is-active');
        });
      }]
    };
  };

  angular.module('RAML.Directives')
    .directive('documentation', RAML.Directives.documentation);
})();

(function () {
  'use strict';
  angular.module('RAML.Directives').directive('dynamicName', ['$parse', function($parse) {
    return {
      restrict: 'A',
      controller: ['$scope', '$element', '$attrs', function($scope, $element, $attrs){
        var name = $parse($attrs.dynamicName)($scope);

        delete($attrs.dynamicName);
        $element.removeAttr('data-dynamic-name');
        $element.removeAttr('dynamic-name');
        $attrs.$set('name', name);
      }]
    };
  }]);
})();

(function () {
  'use strict';

  RAML.Directives.examples = function() {
    return {
      restrict: 'E',
      templateUrl: 'directives/examples.tpl.html',
      scope: {
        exampleContainer: '=',
        getBeatifiedExampleRef: '&'
      },
      controller: ['$scope', function($scope) {
        $scope.getBeatifiedExample = $scope.getBeatifiedExampleRef();
        $scope.examples = transformExample($scope.exampleContainer);
        $scope.currentExample = 0;

        $scope.isXML = $scope.exampleContainer.name === 'application/xml';

        $scope.changeExample = function(example) {
          $scope.currentExample = example;
        };

        $scope.$watch('exampleContainer', function (value) {
          $scope.examples = transformExample(value);
        });
      }]
    };
  };

  function transformExample(exampleContainer) {
    if (exampleContainer.example) {
      return [{
        name: 'Example',
        content: (typeof exampleContainer.example === 'object') ?
            JSON.stringify(exampleContainer.example) : exampleContainer.example
      }];
    } else if (exampleContainer.examples) {
      if (Array.isArray(exampleContainer.examples)) {
        return exampleContainer.examples.map(function (example, index) {
          return {
            name: example.name || 'Example ' + index,
            content: JSON.stringify(example.value, null, 2)
          };
        });
      } else {
        return Object.keys(exampleContainer.examples).sort().map(function (key) {
          return {
            name: key,
            content: exampleContainer.examples[key].value
          };
        });
      }
    }
  }

  angular.module('RAML.Directives')
    .directive('examples', RAML.Directives.examples);
})();

(function () {
  'use strict';

  RAML.Directives.markdown = function() {
    return {
      restrict: 'A',
      scope: {
        markdown: '='
      },
      controller: ['$scope', '$sanitize', '$window', '$element', function($scope, $sanitize, $window, $element) {
        $scope.$watch('markdown', function (markdown) {
          var allowUnsafeMarkdown = $scope.$parent.allowUnsafeMarkdown;
          var html = $window.marked(markdown || '', RAML.Settings.marked);

          if (!allowUnsafeMarkdown) {
            html = $sanitize(html);
          }

          $element.html(html);
        });
      }]
    };
  };

  angular.module('RAML.Directives')
    .directive('markdown', RAML.Directives.markdown);
})();

(function () {
  'use strict';

  RAML.Directives.methodList = function() {
    return {
      restrict: 'E',
      templateUrl: 'directives/method-list.tpl.html',
      replace: true,
      controller: ['$scope', '$timeout', '$rootScope', function($scope, $timeout, $rootScope) {
        function loadExamples () {
          $scope.context.uriParameters.reset($scope.resource.uriParametersForDocumentation);
          $scope.context.queryParameters.reset($scope.methodInfo.queryParameters);
          $scope.context.headers.reset($scope.methodInfo.headers.plain);

          function beautify(body, contentType) {
            if(contentType.indexOf('json') !== -1) {
              body = vkbeautify.json(body, 2);
            }

            if(contentType.indexOf('xml') !== -1) {
              body = vkbeautify.xml(body, 2);
            }

            return body;
          }

          $scope.getBeatifiedExample = function (value) {
            var result = value;

            try {
              result = beautify(value, $scope.currentBodySelected);
            }
            catch (e) { }

            return result;
          };

          if ($scope.context.bodyContent) {
            var definitions = $scope.context.bodyContent.definitions;

            Object.keys(definitions).map(function (key) {
              if (typeof definitions[key].reset !== 'undefined') {
                definitions[key].reset($scope.methodInfo.body[key].formParameters);
              } else {
                definitions[key].fillWithExample();
                if (definitions[key].value) {
                  definitions[key].value = $scope.getBeatifiedExample(definitions[key].value);
                }
              }
            });
          }
        }

        function getResponseInfo() {
          var responseInfo = {};
          var responses    = $scope.methodInfo.responses;

          if (responses) {
            Object.keys(responses).map(function (key) {
              if(responses[key] && typeof responses[key].body !== 'undefined' && responses[key].body) {
                responseInfo[key] = {};

                Object.keys(responses[key].body).sort().reverse().map(function (type) {
                  responseInfo[key][type] = responses[key].body[type];
                  responseInfo[key].currentType = type;
                });
              }
            });
          }

          return responseInfo;
        }

        function toUIModel (collection) {
          if(collection) {
            Object.keys(collection).forEach(function (key) {
              collection[key][0].id = key;
              if (collection[key][0].properties) {
                toUIModel(collection[key][0].properties);
              }
            });
          }
        }

        function beautifyCustomSecuritySchemeName (name) {
          return (name.charAt(0).toUpperCase() + name.slice(1)).replace(/_/g, ' ');
        }

        $scope.readTraits = function (traits) {
          var list = [];
          var traitList = traits || [];

          traitList = traitList.concat($scope.resource.traits);

          traitList.map(function (trait) {
            if (trait) {
              if (typeof trait === 'object') {
              trait = Object.keys(trait).join(', ');
              }

              if (list.indexOf(trait) === -1) {
                list.push(trait);
              }
            }
          });

          return list.join(', ');
        };

        $scope.generateId = function (path) {
          return jQuery.trim(path.toString().replace(/\W/g, ' ')).replace(/\s+/g, '_');
        };

        var $inactiveElements = jQuery('.raml-console-tab').add('.raml-console-resource')
                                                           .add('li')
                                                           .add('.raml-console-tab');

        $scope.$on('openMethod', function(event, $currentScope) {
          if ($scope.$id !== $currentScope.$id) {
            $inactiveElements.removeClass('raml-console-is-active');
            $scope.showPanel = false;
          }
        });

        $scope.showResource = function ($event, $index) {
          var $this             = jQuery($event.currentTarget);
          var $resource         = $this.closest('.raml-console-resource');
          var methodInfo        = $scope.resource.methods[$index];
          var $inactiveElements = jQuery('.raml-console-tab').add('.raml-console-resource')
                                                             .add('li')
                                                             .add('.raml-console-tab');

          $scope.methodInfo               = methodInfo;
          $scope.responseInfo             = getResponseInfo();
          $scope.context                  = new RAML.Services.TryIt.Context($scope.raml.baseUriParameters, $scope.resource, $scope.methodInfo);
          $scope.requestUrl               = '';
          $scope.response                 = {};
          $scope.requestOptions           = {};
          $scope.requestEnd               = false;
          $scope.showRequestMetadata      = false;
          $scope.showMoreEnable           = true;
          $scope.showSpinner              = false;
          $scope.securitySchemes          = $scope.methodInfo.securitySchemes();
          $scope.traits                   = $scope.readTraits($scope.methodInfo.is);
          $scope.context.customParameters = { headers: [], queryParameters: [] };
          $scope.currentBodySelected      = methodInfo.body ? Object.keys(methodInfo.body)[0] : 'application/json';

          toUIModel($scope.methodInfo.queryParameters);
          toUIModel($scope.methodInfo.headers.plain);
          toUIModel($scope.resource.uriParametersForDocumentation);

          Object.keys($scope.securitySchemes).map(function (key) {
            var type = $scope.securitySchemes[key].type;

            $scope.securitySchemes[key].name = type;
            $scope.securitySchemes[key].id = type + '|' + key;

            if (type === 'x-custom') {
              $scope.securitySchemes[key].name = beautifyCustomSecuritySchemeName(key);
              $scope.securitySchemes[key].id = type + '|' + key;
            }
          });

          $rootScope.$broadcast('resetData');

          /*jshint camelcase: false */
          // Digest Authentication is not supported
          delete $scope.securitySchemes.digest_auth;
          /*jshint camelcase: true */

          loadExamples();

          // Hack for codemirror
          setTimeout(function () {
            var editors = jQuery('.raml-console-sidebar-content-wrapper #sidebar-body .raml-console-codemirror-body-editor .CodeMirror');

            editors.map(function (index) {
              var bodyEditor = editors[index].CodeMirror;

              if (bodyEditor && $scope.context.bodyContent) {
                bodyEditor.setOption('mode', $scope.context.bodyContent.selected);
                bodyEditor.refresh();
              }
            });
          }, 10);

          if (!$resource.hasClass('raml-console-is-active')) {
            var hash = $scope.generateId($scope.resource.pathSegments);

            $rootScope.$broadcast('openMethod', $scope);
            jQuery($this).addClass('raml-console-is-active');
            $scope.showPanel = true;

            $timeout(function () {
              jQuery('html, body').animate({
                scrollTop: jQuery('#'+hash).offset().top + 'px'
              }, 'fast');
            }, 10);

          } else if (jQuery($this).hasClass('raml-console-is-active')) {
            $scope.showPanel = false;
            $inactiveElements.removeClass('raml-console-is-active');
            $scope.traits = null;
            $scope.methodInfo = {};
          } else {
            jQuery($this).addClass('raml-console-is-active');
            jQuery($this).siblings('.raml-console-tab').removeClass('raml-console-is-active');
          }
        };
      }]
    };
  };

  angular.module('RAML.Directives')
    .directive('methodList', RAML.Directives.methodList);
})();

(function () {
  'use strict';

  RAML.Directives.namedParameters = function() {
    return {
      restrict: 'E',
      templateUrl: 'directives/named-parameters.tpl.html',
      replace: true,
      scope: {
        src: '=',
        context: '=',
        type: '@',
        title: '@'
      },
      controller: ['$scope', '$attrs', function ($scope, $attrs) {
        $scope.markedOptions = RAML.Settings.marked;

        if ($attrs.hasOwnProperty('enableCustomParameters')) {
          $scope.enableCustomParameters = true;
        }

        if ($attrs.hasOwnProperty('showBaseUrl')) {
          $scope.showBaseUrl = true;
        }

        $scope.segments = [];

        var baseUri = $scope.$parent.raml.baseUri;

        if (typeof baseUri !== 'undefined' && baseUri.templated) {
          var tokens = baseUri.tokens;

          for (var i = 0; i < tokens.length; i++) {
            $scope.segments.push({
              name: tokens[i],
              templated: typeof baseUri.parameters[tokens[i]] !== 'undefined' ? true : false
            });
          }
        }

        $scope.$parent.resource.pathSegments.map(function (element) {
          var tokens = element.tokens;

          for (var i = 0; i < tokens.length; i++) {
            $scope.segments.push({
              name: tokens[i],
              templated: element.templated && typeof element.parameters[tokens[i]] !== 'undefined' ? true : false
            });
          }
        });

        $scope.addCustomParameter = function () {
          $scope.context.customParameters[$scope.type].push({});
        };

        $scope.removeCutomParam = function (param) {
          $scope.context.customParameters[$scope.type] = $scope.context.customParameters[$scope.type].filter(function (el) {
            return el.name !== param.name;
          });
        };

        $scope.isValueProvided = function isValueProvided(value) {
          if (!value) {
            return false;
          }

          if (typeof value !== 'object') {
            return true;
          }

          return Object.keys(value).filter(function (k) {
            return $scope.isValueProvided(value[k]);
          }).length > 0;
        };

        $scope.cleanupValue = RAML.Inspector.Properties.cleanupPropertyValue;
      }]
    };
  };

  angular.module('RAML.Directives')
    .directive('namedParameters', RAML.Directives.namedParameters);
})();

(function () {
  'use strict';

  var PATTERN_PATTERN = /^\/[^\/]*\/$/;

  RAML.Directives.properties = function(RecursionHelper) {
    return {
      restrict: 'E',
      templateUrl: 'directives/properties.tpl.html',
      replace: true,
      scope: {
        list: '=',
        collapsible: '=',
        isNestedProperty: '=',
        hideTypeLinks: '=',
        hidePropertyDetails: '=',
        showExamples: '='
      },
      controller: function ($scope, $rootScope) {
        if (!Array.isArray($scope.list)) {
          $scope.listArray = Object.keys($scope.list).map(function (key) {
            return $scope.list[key];
          });

          $scope.listArray = RAML.Inspector.Properties.normalizeNamedParameters($scope.list);
        } else {
          $scope.listArray = $scope.list;
        }

        $scope.getType = function (type) {
          var newType = $scope.mergeType(type);
          newType.type = RAML.Inspector.Types.ensureArray(newType.type);

          if (newType.type[0] === 'array') {
            newType.type = newType.items.type.map(function (aType) {
              return aType + '[]';
            });
            newType.properties = newType.items.properties;
          }

          return newType;
        };

        $scope.mergeType = function (type) {
          var newType = angular.copy(type);

          if (!$scope.isNestedProperty && $rootScope.types) {
            return RAML.Inspector.Types.mergeType(newType, $rootScope.types);
          }
          return newType;
        };

        $scope.isNativeType = RAML.Inspector.Types.isNativeType;

        $scope.isPattern = function (propertyName) {
          return propertyName.match(PATTERN_PATTERN);
        };

        $scope.isSchema = RAML.Inspector.Types.isSchema;

        $scope.isCollapsible = function isCollapsible(property) {
          return $scope.collapsible && !!(property.description || property.properties || $scope.isSchema(property.type[0]));
        };

        $scope.parameterDocumentation = function (parameter) {
          var result = [];

          if (parameter) {
            if (parameter.required) {
              result.push('required');
            }

            if (parameter.discriminator) {
              result.push('discriminator');
            }

            if (parameter['enum']) {
              var enumValues = $scope.unique(parameter['enum']);
              var enumDescription = '';

              if (enumValues.length > 1) {
                enumDescription += 'one of ';
              }

              enumDescription += '(' + enumValues.filter(function (value) { return value !== ''; }).join(', ') + ')';

              result.push(enumDescription);
            }

            if (parameter.pattern) {
              result.push(' matching ' + parameter.pattern);
            }

            if (parameter.minLength && parameter.maxLength) {
              result.push(parameter.minLength + '-' + parameter.maxLength + ' characters');
            } else if (parameter.minLength && !parameter.maxLength) {
              result.push('at least ' + parameter.minLength + ' characters');
            } else if (parameter.maxLength && !parameter.minLength) {
              result.push('at most ' + parameter.maxLength + ' characters');
            }

            if (parameter.minimum && parameter.maximum) {
              result.push('between ' + parameter.minimum + '-' + parameter.maximum);
            } else if (parameter.minimum && !parameter.maximum) {
              result.push('≥ ' + parameter.minimum);
            } else if (parameter.maximum && !parameter.minimum) {
              result.push('≤ ' + parameter.maximum);
            }

            if (parameter.repeat) {
              result.push('repeatable');
            }

            if (parameter['default'] !== undefined) {
              result.push('default: ' + parameter['default']);
            }
          }

          return result.join(', ');
        };

        $scope.typeDocumentation = function (type) {
          var result = [];

          if (type.minItems) {
            result.push('minItems: ' + type.minItems);
          }

          if (type.maxItems) {
            result.push('maxItems: ' + type.maxItems);
          }

          if (type['enum']) {
            var enumValues = type['enum'];
            var enumDescription = '';

            if (enumValues.length > 1) {
              enumDescription += 'one of ';
            }

            enumDescription += '(' + enumValues.filter(function (value) { return value !== ''; }).join(', ') + ')';

            result.push(enumDescription);
          }

          if (type.pattern) {
            result.push('pattern: ' + type.pattern);
          }

          if (type.minLength) {
            result.push('minLength: ' + type.minLength);
          }

          if (type.maxLength) {
            result.push('maxLength: ' + type.maxLength);
          }

          if (type.minimum) {
            result.push('minimum: ' + type.minimum);
          }

          if (type.format) {
            result.push('format: ' + type.format);
          }

          if (type.multipleOf) {
            result.push('multipleOf: ' + type.multipleOf);
          }

          if (type.fileTypes) {
            result.push('fileTypes: ' + type.fileTypes.join(', '));
          }

          return result.join(', ');
        };

        $scope.unique = function (arr) {
          return arr.filter (function (v, i, a) { return a.indexOf (v) === i; });
        };
      },
      compile: function (element) {
        return RecursionHelper.compile(element);
      }
    };
  };

  angular.module('RAML.Directives')
    .directive('properties', RAML.Directives.properties);
})();

(function () {
  'use strict';

  RAML.Directives.ramlBody = function() {
    return {
      restrict: 'E',
      templateUrl: 'directives/raml-body.tpl.html',
      scope: {
        body: '=',
        getBeatifiedExampleRef: '&'
      },
      controller: ['$scope', '$rootScope', function($scope, $rootScope) {
        $scope.getBeatifiedExample = $scope.getBeatifiedExampleRef();

        $scope.$watch('body', function () {
          $scope.identifyBodyType();
        });

        $scope.getTopSchema = function (name) {
          return RAML.Inspector.Types.findSchema(name, $rootScope.schemas);
        };

        $scope.getTopType = function (name) {
          name = Array.isArray(name) ? name[0] : name;
          return RAML.Inspector.Types.findType(name, $rootScope.types);
        };

        $scope.identifyBodyType = function () {
          var node = angular.copy($scope.body);
          node.type = node.type || node.schema;
          $scope.isType = false;
          $scope.isSchema = false;

          if (node.type) {
            node.type = Array.isArray(node.type) ? node.type : [node.type];
            node.type.forEach(function (aType) {
              if (typeof aType !== 'object') {
                var isNative = RAML.Inspector.Types.isNativeType(aType);

                if (isNative) {
                  $scope.isType = true;
                } else {
                  var declaredType = RAML.Inspector.Types.findType(aType, $rootScope.types);
                  var declaredSchema = RAML.Inspector.Types.findSchema(aType, $rootScope.schemas);

                  if (declaredType) {
                    var typeParts = declaredType.type[0].split('|');
                    var firstType = RAML.Inspector.Types.cleanupTypeName(typeParts[0]);

                    if (RAML.Inspector.Types.isNativeType(firstType) ||
                        RAML.Inspector.Types.findType(firstType, $rootScope.types)) {
                      $scope.isType = true;
                    } else {
                      $scope.isSchema = true;
                      $scope.definition = declaredType.type[0];
                    }
                  } else {
                    $scope.isSchema = true;
                    if (declaredSchema) {
                      if (declaredSchema.type) {
                        $scope.definition = declaredSchema.type[0];
                      } else {
                        $scope.definition = declaredSchema;
                      }
                    } else {
                      if (aType.indexOf('|') !== -1) {
                        $scope.isSchema = false;
                        $scope.isType = true;
                      } else {
                        $scope.definition = aType;
                      }
                    }
                  }
                }
              } else {
                $scope.isSchema = true;
                $scope.definition = JSON.stringify(aType, null, 2);
              }
            });
          }
        };

        $scope.showSchema = function ($event) {
          var $this   = jQuery($event.currentTarget);
          var $panel  = $this.closest('.raml-console-schema-container');
          var $schema = $panel.find('.raml-console-resource-pre-toggle');

          $this.toggleClass('raml-console-is-active');

          if (!$schema.hasClass('raml-console-is-active')) {
            $this.text('Hide Schema');
            $schema
              .addClass('raml-console-is-active')
              .velocity('slideDown');
          } else {
            $this.text('Show Schema');
            $schema
              .removeClass('raml-console-is-active')
              .velocity('slideUp');
          }
        };

        $scope.identifyBodyType();
      }]
    };
  };

  angular.module('RAML.Directives')
    .directive('ramlBody', RAML.Directives.ramlBody);
})();

(function () {
  'use strict';

  var generator = window.ramlClientGenerator;

  function downloadClient (language, ast) {
    var zip    = new window.JSZip();
    var output = generator[language](ast);
    var title  = window.slug(output.context.title);

    Object.keys(output.files).forEach(function (key) {
      zip.file(key, output.files[key]);
    });

    var content  = zip.generate({ type: 'blob' });
    var filename = title + '-' + language + '.zip';

    // Download as a zip file with an appropriate language name.
    window.saveAs(content, filename);
  }

  RAML.Directives.ramlClientGenerator = function () {
    return {
      restrict: 'E',
      templateUrl: 'directives/raml-client-generator.tpl.html',
      controller: ['$scope', function ($scope) {
        $scope.downloadJavaScriptClient = function () {
          return downloadClient('javascript', $scope.rawRaml);
        };
      }]
    };
  };

  angular.module('RAML.Directives')
    .directive('ramlClientGenerator', RAML.Directives.ramlClientGenerator);
})();

(function () {
  'use strict';

  angular.module('RAML.Directives')
    .directive('ramlConsoleLoader', function ramlConsoleLoader() {
      return {
        restrict:    'E',
        templateUrl: 'directives/raml-console-loader.tpl.html',
        replace:     true,
        controller:  'RamlConsoleLoaderController',
        scope:       {
          src:     '@',
          options: '='
        }
      };
    })
    .controller('RamlConsoleLoaderController', function RamlConsoleLoaderController(
      $scope,
      $window,
      ramlParser
    ) {
      $scope.vm = {
        error:   void(0),
        loaded:  false,
        options: $scope.options,
        raml:    void(0),
        src:     $scope.src
      };

      // ---

      (function activate() {
        loadFromUrl($scope.vm.src);
      })();

      // ---

      function loadFromUrl(url) {
        $scope.vm.raml   = void(0);
        $scope.vm.loaded = false;
        $scope.vm.error  = void(0);

        return ramlParser.loadPath($window.resolveUrl(url), null, $scope.options)
          .then(function (raml) {
            $scope.vm.raml = raml;
          })
          .catch(function (error) {
            $scope.vm.error = angular.extend(error, {
              /*jshint camelcase: false */
              buffer: (error.context_mark || error.problem_mark).buffer
              /*jshint camelcase: true */
            });
          })
          .finally(function () {
            $scope.vm.loaded = true;
          })
        ;
      }
    })
  ;
})();

(function () {
  'use strict';

  angular.module('RAML.Directives')
    .directive('ramlConsoleSpinner', function ramlConsoleSpinner() {
      return {
        restrict:    'E',
        templateUrl: 'directives/raml-console-spinner.tpl.html',
        replace:     true
      };
    })
  ;
})();

(function () {
  'use strict';

  angular.module('RAML.Directives')
    .directive('ramlConsole', function ramlConsole() {
      return {
        restrict:    'E',
        templateUrl: 'directives/raml-console.tpl.html',
        replace:     true,
        controller:  'RamlConsoleController',
        scope:       {
          raml:    '=',
          options: '='
        }
      };
    })
    .controller('RamlConsoleController', function RamlConsoleController(
      $attrs,
      $scope,
      $rootScope,
      $timeout,
      $window
    ) {
      $scope.allowUnsafeMarkdown        = $attrs.hasOwnProperty('allowUnsafeMarkdown');
      $scope.collapseAll                = collapseAll;
      $scope.credentials                = {};
      $scope.disableRamlClientGenerator = $attrs.hasOwnProperty('disableRamlClientGenerator');
      $scope.disableThemeSwitcher       = $attrs.hasOwnProperty('disableThemeSwitcher');
      $scope.disableTitle               = $attrs.hasOwnProperty('disableTitle');
      $scope.disableTryIt               = $attrs.hasOwnProperty('disableTryIt');
      $scope.documentationCollapsed     = $attrs.hasOwnProperty('documentationCollapsed');
      $scope.proxy                      = $window.RAML.Settings.proxy;
      $scope.readResourceTraits         = readResourceTraits;
      $scope.resourcesCollapsed         = $attrs.hasOwnProperty('resourcesCollapsed');
      $scope.singleView                 = $attrs.hasOwnProperty('singleView');
      $scope.hasResourcesWithChilds     = hasResourcesWithChilds;
      $scope.toggle                     = toggle;
      $scope.updateProxyConfig          = updateProxyConfig;

      // ---

      (function activate() {
        $scope.options && [
          'allowUnsafeMarkdown',
          'disableRamlClientGenerator',
          'disableThemeSwitcher',
          'disableTitle',
          'disableTryIt',
          'documentationCollapsed',
          'resourcesCollapsed',
          'singleView'
        ].forEach(function (property) {
          if ($scope.options[property]) {
            $scope[property] = true;
          }
        });

        $scope.$watch('raml', function (raml) {
          if (!raml) {
            return;
          }
          delete $scope.types;
          delete $rootScope.types;

          $timeout(function () {
            var securitySchemes = raml.securitySchemes ? angular.copy(raml.securitySchemes) : [];
            var librarySecuritySchemes = getSecuritySchemes();

            if (securitySchemes || librarySecuritySchemes) {
              raml.securitySchemes = securitySchemes.concat(librarySecuritySchemes);
            }

            inspectRaml(raml);

            var types = raml.types ? angular.copy(raml.types) : [];
            var libraryTypes = getLibraryTypes();

            if (types.length || libraryTypes.length) {
              $scope.types = types.concat(libraryTypes);

              $rootScope.types = $scope.types.map(function (type) {
                var theType = type[Object.keys(type)[0]];
                theType.properties = RAML.Inspector.Properties.normalizeNamedParameters(theType.properties);
                return type;
              });
            }

            var schemas = raml.schemas ? angular.copy(raml.schemas) : [];
            var librarySchemas = getLibrarySchemas();

            if (schemas || librarySchemas) {
              $rootScope.schemas = schemas.concat(librarySchemas);
            }
          });

          function getLibraryTypes() {
            var result = [] ;
            if (raml.uses) {
              Object.keys(raml.uses).forEach(function (usesKey) {
                var usesTypes = raml.uses[usesKey].types;
                if (usesTypes) {
                  usesTypes.forEach(function (aType) {
                    Object.keys(aType).forEach(function (typeKey) {
                      var tempType = {};
                      convertType(aType[typeKey], usesKey);

                      tempType[usesKey + '.' + typeKey] = aType[typeKey];
                      tempType[usesKey + '.' + typeKey].displayName = usesKey + '.' + typeKey;
                      result.push(tempType);
                    });
                  });
                }
              });
            }

            return result;
          }

          function convertType(typeNode, usesKey) {
            typeNode.type = typeNode.type.map(function (typeName) {
              if (!RAML.Inspector.Types.isSchema(typeName)) {
                var typeInfo = RAML.Inspector.Types.getTypeInfo(typeName);

                typeInfo.parts = typeInfo.parts.map(function (theType) {
                  if (!RAML.Inspector.Types.isNativeType(theType)) {
                    return usesKey + '.' + RAML.Inspector.Types.cleanupTypeName(theType);
                  }
                  return theType;
                });

                return RAML.Inspector.Types.getTypeFromTypeInfo(typeInfo);
              }
              return typeName;
            });

            if (typeNode.properties) {
              Object.keys(typeNode.properties).forEach(function (propertiesKey) {
                convertType(typeNode.properties[propertiesKey], usesKey);
              });
            }
          }

          function getLibrarySchemas() {
            var result = [];
            if (raml.uses) {
              Object.keys(raml.uses).forEach(function (usesKey) {
                var usesSchemas = raml.uses[usesKey].schemas;
                if (usesSchemas) {
                  usesSchemas.forEach(function (aSchema) {
                    Object.keys(aSchema).forEach(function (schemaKey) {
                      var tempSchema = {};
                      tempSchema[usesKey + '.' + schemaKey] = aSchema[schemaKey];
                      result.push(tempSchema);
                    });
                  });
                }
              });
            }

            return result;
          }

          function getSecuritySchemes() {
            var result = [];
            if (raml.uses) {
              Object.keys(raml.uses).forEach(function (usesKey) {
                var usesSecuritySchemes = raml.uses[usesKey].securitySchemes;
                if (usesSecuritySchemes) {
                  usesSecuritySchemes.forEach(function (aScheme) {
                    Object.keys(aScheme).forEach(function (schemaKey) {
                      var tempSchema = {};
                      tempSchema[usesKey + '.' + schemaKey] = aScheme[schemaKey];
                      result.push(tempSchema);
                    });
                  });
                }
              });
            }

            return result;
          }
        });
      })();

      // ---

      function collapseAll($event, collection, flagKey) {
        var $this = jQuery($event.currentTarget);

        if ($this.hasClass('raml-console-resources-expanded')) {
          $scope[flagKey] = true;
        } else {
          if (flagKey === 'resourcesCollapsed') {
            jQuery('.raml-console-resource-description').removeClass('ng-hide');
          }
          $scope[flagKey] = false;
        }

        jQuery('.raml-console-resources-' + flagKey).find('ol.raml-console-resource-list').toggleClass('raml-console-is-collapsed');

        toggleCollapsed($scope[flagKey], collection);
      }

      function readResourceTraits(traits) {
        var list = [];

        if (traits) {
          traits.map(function (trait) {
            if (trait) {
              if (typeof trait === 'object') {
                list.push(Object.keys(trait).join(', '));
              } else {
                list.push(trait);
              }
            }
          });
        }

        return list.join(', ');
      }

      function toggle($event, index, collection, flagKey) {
        var $this    = jQuery($event.currentTarget);
        var $section = $this
          .closest('.raml-console-resource-list-item')
          .find('.raml-console-resource-list');

        collection[index] = !collection[index];

        $scope[flagKey] = checkItemStatus(false, collection) ? false : $scope[flagKey];
        $scope[flagKey] = checkItemStatus(true, collection) ? true : $scope[flagKey];

        $section.toggleClass('raml-console-is-collapsed');
      }

      function updateProxyConfig(status) {
        $window.RAML.Settings.disableProxy = status;
      }

      // ---

      function toggleCollapsed(status, collection) {
        for (var i = 0; i < collection.length; i++) {
          collection[i] = collection[i] !== null ? status : collection[i];
        }
      }

      function checkItemStatus(status, collection) {
        return collection.filter(function (el) { return el === status || el === null; }).length === collection.length;
      }

      function hasResourcesWithChilds() {
        return $scope.inspectedRaml && $scope.inspectedRaml.resourceGroups.filter(function (el) {
          return el.length > 1;
        }).length > 0;
      }

      function inspectRaml(raml) {
        $scope.inspectedRaml = RAML.Inspector.create(raml);
        $scope.resourceList  = [];
        $scope.documentList  = [];

        for (var i = 0; i < $scope.inspectedRaml.resourceGroups.length; i++) {
          var resources = $scope.inspectedRaml.resourceGroups[i];
          var status    = resources.length > 1 ? false : null;
          $scope.resourceList.push($scope.resourcesCollapsed ? true : status);
        }

        if ($scope.inspectedRaml.documentation) {
          for (var j = 0; j < $scope.inspectedRaml.documentation.length; j++) {
            $scope.documentList.push($scope.documentationCollapsed ? true : false);
          }
        }
      }
    })
  ;
})();

(function () {
  'use strict';

  RAML.Directives.ramlField = function(RecursionHelper) {
    return {
      restrict: 'E',
      templateUrl: 'directives/raml-field.tpl.html',
      replace: true,
      scope: {
        context: '=',
        type: '=',
        model: '=',
        param: '='
      },
      controller: ['$scope', function($scope) {
        var bodyContent = $scope.context.bodyContent;
        var context     = $scope.context[$scope.type];

        if (bodyContent) {
          context = context || bodyContent.definitions[bodyContent.selected];
        }

        Object.keys(context.plain).map(function (key) {
          var definition = context.plain[key].definitions[0];

          if (typeof definition['enum'] !== 'undefined') {
            context.values[definition.id][0] = definition['enum'][0];
          }
        });

        $scope.isArray = function (param) {
          return param.type[0].indexOf('[]') !== -1;
        };

        $scope.addArrayElement = function (model) {
          model.push([undefined]);
        };

        $scope.removeArrayElement = function (model, index) {
          model.splice(index, 1);
        };

        $scope.canOverride = function (definition) {
          return definition.type === 'boolean' ||  typeof definition['enum'] !== 'undefined';
        };

        $scope.overrideField = function ($event, definition) {
          var $this      = jQuery($event.currentTarget);
          var $container = $this.closest('p');
          var $el        = $container.find('#' + definition.id);
          var $checkbox  = $container.find('#checkbox_' + definition.id);
          var $select    = $container.find('#select_' + definition.id);

          $el.toggleClass('raml-console-sidebar-override-show');
          $checkbox.toggleClass('raml-console-sidebar-override-hide');
          $select.toggleClass('raml-console-sidebar-override-hide');

          $this.text('Override');

          if($el.hasClass('raml-console-sidebar-override-show')) {
            definition.overwritten = true;
            $this.text('Cancel override');
          } else {
            definition.overwritten = false;
            $scope.context[$scope.type].values[definition.id][0] = definition['enum'][0];
          }
        };

        $scope.onChange = function () {
          $scope.context.forceRequest = false;
        };

        $scope.isDefault = function (definition) {
          return typeof definition['enum'] === 'undefined' && definition.type !== 'boolean';
        };

        $scope.isEnum = function (definition) {
          return typeof definition['enum'] !== 'undefined';
        };

        $scope.isBoolean = function (definition) {
          return definition.type === 'boolean';
        };

        $scope.hasExampleValue = function (value) {
          return $scope.isEnum(value) ? false : value.type === 'boolean' ? false : typeof value['enum'] !== 'undefined' ? false : (typeof value.example !== 'undefined' || typeof value.examples !== 'undefined') ? true : false;
        };

        $scope.reset = function (param) {
          var type = $scope.type || 'bodyContent';
          var info = {};

          info[param.id] = [param];

          $scope.context[type].reset(info, param.id);
        };

        $scope.unique = function (arr) {
          return arr.filter (function (v, i, a) { return a.indexOf (v) === i; });
        };

        $scope.toString = function toString(value) {
          return Array.isArray(value) ? value.join(', ') : value;
        };
      }],
      compile: function (element) {
        return RecursionHelper.compile(element);
      }
    };
  };

  angular.module('RAML.Directives')
    .directive('ramlField', RAML.Directives.ramlField);
})();

(function () {
  'use strict';

  angular.module('RAML.Directives')
    .directive('ramlInitializer', function ramlInitializer() {
      return {
        restrict:    'E',
        templateUrl: 'directives/raml-initializer.tpl.html',
        replace:     true,
        controller:  'RamlInitializerController'
      };
    })
    .controller('RamlInitializerController', function RamlInitializerController(
      $scope,
      $window,
      ramlParser
    ) {
      $scope.vm = {
        codeMirror: {
          gutters:      ['CodeMirror-lint-markers'],
          lineNumbers:  true,
          lineWrapping: true,
          lint:         null,
          mode:         'yaml',
          tabSize:      2,
          theme:        'raml-console'
        },

        error:           null,
        isLoadedFromUrl: false,
        isLoading:       false,
        loadFromString:  loadFromString,
        loadFromUrl:     loadFromUrl,
        raml:            null
      };

      // ---

      (function activate() {
        if (document.location.search.indexOf('?raml=') !== -1) {
          loadFromUrl(document.location.search.replace('?raml=', ''));
        }
      })();

      // ---

      function loadFromUrl(url) {
        $scope.vm.ramlUrl = url;
        return loadFromPromise(ramlParser.loadPath($window.resolveUrl(url)), {isLoadingFromUrl: true});
      }

      function loadFromString(string) {
        $scope.vm.ramlString = string;
        return loadFromPromise(ramlParser.load(string));
      }

      // ---

      /**
       * @param {Promise} promise
       * @param {Boolean} options.isLoadingFromUrl
       */
      function loadFromPromise(promise, options) {
        options                   = options || {};
        $scope.vm.error           = null;
        $scope.vm.raml            = null;
        $scope.vm.isLoading       = true;
        $scope.vm.isLoadedFromUrl = false;
        $scope.vm.codeMirror.lint = null;

        return promise
          .then(function (raml) {
            $scope.vm.raml = raml;
          })
          .catch(function (error) {
            $scope.vm.error           = error;
            $scope.vm.codeMirror.lint = lintFromError(error);
          })
          .finally(function () {
            $scope.vm.isLoading       = false;
            $scope.vm.isLoadedFromUrl = options.isLoadingFromUrl;
          })
        ;
      }

      function lintFromError(error) {
        return function getAnnotations() {
          return (error.parserErrors || []).map(function (error) {
            return {
              message:  error.message,
              severity: error.isWarning ? 'warning' : 'error',
              from:     CodeMirror.Pos(error.line),
              to:       CodeMirror.Pos(error.line)
            };
          });
        };
      }
    })
  ;
})();

(function () {
  'use strict';

  RAML.Directives.resourcePanel = function() {
    return {
      restrict: 'E',
      templateUrl: 'directives/resource-panel.tpl.html',
      replace: true
    };
  };

  angular.module('RAML.Directives')
    .directive('resourcePanel', RAML.Directives.resourcePanel);
})();

(function () {
  'use strict';

  RAML.Directives.resourceType = function() {
    return {
      restrict: 'E',
      templateUrl: 'directives/resource-type.tpl.html',
      replace: true,
      controller: ['$scope', function ($scope) {
        var resourceType = $scope.resource.resourceType;

        if (typeof resourceType === 'object') {
          $scope.resource.resourceType = Object.keys(resourceType).join();
        }
      }]
    };
  };

  angular.module('RAML.Directives')
    .directive('resourceType', RAML.Directives.resourceType);
})();

(function () {
  'use strict';

  RAML.Directives.rootDocumentation = function() {
    return {
      restrict: 'E',
      templateUrl: 'directives/root-documentation.tpl.html',
      replace: true,
      controller: ['$scope', '$timeout', function($scope, $timeout) {
        $scope.markedOptions = RAML.Settings.marked;
        $scope.selectedSection = 'all';

        $scope.hasDocumentationWithIndex = function () {
          var regex = /(^#|^##)+\s(.*)$/gim;

          return $scope.raml.documentation.filter(function (el) {
            return regex.test(el.content);
          }).length > 0;
        };

        $scope.generateDocId = function (path) {
          return jQuery.trim(path.toString().replace(/\W/g, ' ')).replace(/\s+/g, '_').toLowerCase();
        };

        $scope.toggleSection = function ($event, key, section) {
          var $el = jQuery($event.currentTarget).closest('.raml-console-documentation');
          $scope.selectedDocumentSection = key;
          $scope.documentationEnabled = $el.hasClass('raml-console-documentation-active') ? false : true;

          jQuery('.raml-console-resource-list-item').removeClass('raml-console-documentation-active');

          $el[!$scope.documentationEnabled ? 'removeClass' : 'addClass']('raml-console-documentation-active');

          $timeout(function () {
            jQuery('html, body').animate({
              scrollTop: jQuery('#'+$scope.generateDocId(section)).offset().top + 'px'
            }, 'fast');
          }, 10);
        };

        $scope.closeDocumentation = function ($event) {
          var $container = jQuery($event.currentTarget).closest('.raml-console-documentation');
          $container.toggleClass('raml-console-documentation-active');
          $scope.documentationEnabled = false;
          jQuery('.raml-console-resource-list-item').removeClass('raml-console-documentation-active');
        };

        $scope.sectionChange = function (value) {
          $scope.selectedDocumentSection = value;
        };

        $scope.getDocumentationContent = function (content, selected) {
          var lines  = content.split('\n');
          var index  = lines.indexOf(selected);
          var result = [];
          var regex  = /(^#|^##)+\s(.*)$/gim;

          result.push(lines[index]);

          for (var i = index+1; i < lines.length; i++) {
            var line = lines[i];

            if (regex.test(line)) {
              break;
            }

            result.push(line);
          }

          return !selected || selected === 'all' ? content : result.join('\n');
        };

        $scope.filterHeaders = function (c) {
          return c.filter(function (el) {
            return el.heading <= 2;
          });
        };

        $scope.getMarkdownHeaders = function (content) {
          var headers = content.match(/^#+\s(.*)$/gim);
          var result  = [];
          var regex   = new RegExp(/(^#|^##)+\s(.*)$/gim);

          if (headers) {
            var key = headers[0];

            headers.map(function(el) {
              if(el.match(regex) !== null) {
                key = el;
              }

              result.push({
                value: key,
                heading: el.match(/#/g).length,
                label: el.replace(/#/ig, '').trim()
              });
            });
          }

          return result;
        };
      }]
    };
  };

  angular.module('RAML.Directives')
    .directive('rootDocumentation', RAML.Directives.rootDocumentation);
})();

(function () {
  'use strict';

  RAML.Directives.rootTypes = function() {
    return {
      restrict: 'E',
      templateUrl: 'directives/root-types.tpl.html',
      replace: true,
      scope: {
        types: '='
      },
      controller: function ($scope) {
        $scope.convertTypes = function () {
          var types = {};
          $scope.types.forEach(function (type) {
            types[Object.keys(type)[0]] = type[Object.keys(type)[0]];
          });
          $scope.theTypes = RAML.Inspector.Properties.normalizeNamedParameters(types);
        };

        $scope.$watch('types', function () {
          $scope.convertTypes();
        });
      }
    };
  };

  angular.module('RAML.Directives')
    .directive('rootTypes', RAML.Directives.rootTypes);
})();

(function () {
  'use strict';

  RAML.Directives.sidebar = function() {
    return {
      restrict: 'E',
      templateUrl: 'directives/sidebar.tpl.html',
      replace: true,
      controller: ['$scope', '$timeout', function ($scope, $timeout) {
        var defaultSchemaKey = Object.keys($scope.securitySchemes).sort()[0];
        var defaultSchema    = $scope.securitySchemes[defaultSchemaKey];
        var defaultAccept    = 'application/json';

        $scope.markedOptions     = RAML.Settings.marked;
        $scope.currentSchemeType = defaultSchema.type;
        $scope.currentScheme     = defaultSchema.id;
        $scope.responseDetails   = false;

        function readCustomSchemeInfo (name) {
          if (!$scope.methodInfo.headers.plain) {
            $scope.methodInfo.headers.plain = {};
          }

          if (!$scope.methodInfo.queryParameters) {
            $scope.methodInfo.queryParameters = {};
          }

          updateContextData('headers', name, $scope.methodInfo.headers.plain, $scope.context.headers);
          updateContextData('queryParameters', name, $scope.methodInfo.queryParameters, $scope.context.queryParameters);
        }

        if (defaultSchema.type === 'x-custom') {
          readCustomSchemeInfo(defaultSchema.id.split('|')[1]);
        }

        function completeAnimation (element) {
          jQuery(element).removeAttr('style');
        }

        function parseHeaders(headers) {
          var parsed = {}, key, val, i;

          if (!headers) {
            return parsed;
          }

          headers.split('\n').forEach(function(line) {
            i   = line.indexOf(':');
            key = line.substr(0, i).trim().toLowerCase();
            val = line.substr(i + 1).trim();

            if (key) {
              if (parsed[key]) {
                parsed[key] += ', ' + val;
              } else {
                parsed[key] = val;
              }
            }
          });

          return parsed;
        }

        function apply () {
          $scope.$apply.apply($scope, arguments);
        }

        function beautify(body, contentType) {
          if(contentType.indexOf('json')) {
            body = vkbeautify.json(body, 2);
          }

          if(contentType.indexOf('xml')) {
            body = vkbeautify.xml(body, 2);
          }

          return body;
        }

        function handleResponse(jqXhr, err) {
          $scope.response.status = jqXhr ? jqXhr.status : err ? (err.status ? err.status : err.message) : 0;

          if (jqXhr) {
            $scope.response.headers = parseHeaders(jqXhr.getAllResponseHeaders());

            if ($scope.response.headers['content-type']) {
              $scope.response.contentType = $scope.response.headers['content-type'].split(';')[0];
            }

            try {
              $scope.response.body = beautify(jqXhr.responseText, $scope.response.contentType);
            }
            catch (e) {
              $scope.response.body = jqXhr.responseText;
            }
          }

          $scope.requestEnd      = true;
          $scope.showMoreEnable  = true;
          $scope.showSpinner     = false;
          $scope.responseDetails = true;

          // If the response fails because of CORS, responseText is null
          var editorHeight = 50;

          if (jqXhr && jqXhr.responseText) {
            var lines = $scope.response.body.split('\n').length;
            editorHeight = lines > 100 ? 2000 : 25*lines;
          }

          $scope.editorStyle = {
            height: editorHeight + 'px'
          };

          apply();

          var hash = 'request_' + $scope.generateId($scope.resource.pathSegments);

          $timeout(function () {
            if (jqXhr) {
              var $editors = jQuery('.raml-console-sidebar-content-wrapper .CodeMirror').toArray();

              $editors.forEach(function (editor) {
                var cm = editor.CodeMirror;
                cm.setOption('mode', $scope.response.contentType);
                cm.refresh();
              });
            }

            jQuery('html, body').animate({
              scrollTop: jQuery('#'+hash).offset().top + 'px'
            }, 'fast');
          }, 10);
        }

        function resolveSegementContexts(pathSegments, uriParameters) {
          var segmentContexts = [];

          pathSegments.forEach(function (element) {
            if (element.templated) {
              var segment = {};
              Object.keys(element.parameters).map(function (key) {
                segment[key] = uriParameters[key];
              });
              segmentContexts.push(segment);
            } else {
              segmentContexts.push({});
            }
          });

          return segmentContexts;
        }

        function validateForm(form) {
          var keys = Object.keys(form.form).filter(function (key) { return key.indexOf('$') === -1;});

          keys.forEach(function (fieldName) {
            form.form[fieldName].$setDirty();
          });

          return form.form.$valid;
        }

        function getParameters (context, type) {
          var params           = {};
          var customParameters = context.customParameters[type];

          if (!RAML.Utils.isEmpty(context[type].data())) {
            params = angular.copy(context[type].data());
          }

          Object.keys(params).forEach(function (key) {
            if (Array.isArray(params[key][0])) {
              var input = angular.copy(params[key][0]);

              input.forEach(function (each, index) {
                params[key][index] = each[0];
              });
            }

            params[key].forEach(function (param, index) {
              if (typeof param === 'object') {
                params[key][index] = JSON.stringify(
                  RAML.Inspector.Properties.cleanupPropertyValue(params[key][index]));
              }
            });

            // Remove empty array property
            if (params[key][0] === '[null]') {
              delete params[key];
            }
          });

          if (customParameters.length > 0) {
            for(var i = 0; i < customParameters.length; i++) {
              var key = customParameters[i].name;

              params[key] = [];
              params[key].push(customParameters[i].value);
            }
          }

          return params;
        }

        function clearCustomFields (types) {
          types.map(function (type) {
            var custom = $scope.context.customParameters[type];

            for (var i = 0; i < custom.length; i++) {
              custom[i].value = '';
            }
          });
        }

        $scope.$watch('methodInfo', function () {
          $scope.protocols       = $scope.methodInfo.protocols || $scope.raml.protocols;
          $scope.currentProtocol = $scope.protocols && $scope.protocols.length ? $scope.protocols[0] : null;
        });

        $scope.$on('resetData', function() {
          var defaultSchemaKey = Object.keys($scope.securitySchemes).sort()[0];
          var defaultSchema    = $scope.securitySchemes[defaultSchemaKey];

          $scope.currentSchemeType           = defaultSchema.type;
          $scope.currentScheme               = defaultSchema.id;
          $scope.protocols                   = $scope.methodInfo.protocols || $scope.raml.protocols;
          $scope.currentProtocol             = $scope.protocols && $scope.protocols.length ? $scope.protocols[0] : null;
          $scope.documentationSchemeSelected = defaultSchema;
          $scope.responseDetails             = null;

          cleanSchemeMetadata($scope.methodInfo.headers.plain, $scope.context.headers);
          cleanSchemeMetadata($scope.methodInfo.queryParameters, $scope.context.queryParameters);
        });

        $scope.cancelRequest = function () {
          $scope.showSpinner = false;
        };

        $scope.prefillBody = function (current) {
          var definition   = $scope.context.bodyContent.definitions[current];
          definition.fillWithExample();

          if (definition.value) {
            definition.value = $scope.getBeatifiedExample(definition.value);
          }
        };

        $scope.clearFields = function () {
          $scope.context.uriParameters.clear($scope.resource.uriParametersForDocumentation);
          $scope.context.queryParameters.clear($scope.methodInfo.queryParameters);
          $scope.context.headers.clear($scope.methodInfo.headers.plain);
          if ($scope.context.bodyContent) {
            $scope.context.bodyContent.definitions[$scope.context.bodyContent.selected].value = '';
          }
          $scope.context.forceRequest = false;

          if ($scope.credentials) {
            Object.keys($scope.credentials).map(function (key) {
              $scope.credentials[key] = '';
            });
          }

          clearCustomFields(['headers', 'queryParameters']);

          if ($scope.context.bodyContent) {
            var current    = $scope.context.bodyContent.selected;
            var definition = $scope.context.bodyContent.definitions[current];

            if (typeof definition.clear !== 'undefined') {
              definition.clear($scope.methodInfo.body[current].formParameters);
            } else {
              definition.value = '';
            }
          }
        };

        $scope.resetFormParameter = function (param) {
          var current    = $scope.context.bodyContent.selected;
          var definition = $scope.context.bodyContent.definitions[current];

          definition.reset($scope.methodInfo.body[current].formParameters, param.id);
        };

        $scope.resetFields = function () {
          $scope.context.uriParameters.reset($scope.resource.uriParametersForDocumentation);
          $scope.context.queryParameters.reset($scope.methodInfo.queryParameters);
          $scope.context.headers.reset($scope.methodInfo.headers.plain);

          if ($scope.context.bodyContent) {
            var current    = $scope.context.bodyContent.selected;
            var definition = $scope.context.bodyContent.definitions[current];

            if (typeof definition.reset !== 'undefined') {
              definition.reset($scope.methodInfo.body[current].formParameters);
            } else {
              definition.value = definition.contentType.example;
            }
          }

          $scope.context.forceRequest = false;
        };

        $scope.requestBodySelectionChange = function (bodyType) {
          $scope.currentBodySelected = bodyType;
        };

        $scope.toggleBodyType = function ($event, bodyType) {
          var $this  = jQuery($event.currentTarget);
          var $panel = $this.closest('.raml-console-sidebar-toggle-type').find('button');

          $panel.removeClass('raml-console-is-active');
          $this.addClass('raml-console-is-active');

          $scope.context.bodyContent.selected = bodyType;
        };

        $scope.getHeaderValue = function (header) {
          if (typeof header === 'string') {
            return header;
          }

          return header[0];
        };

        $scope.hasExampleValue = function (value) {
          return typeof value !== 'undefined' ? true : false;
        };

        $scope.context.forceRequest = false;

        function cleanSchemeMetadata(collection, context) {
          if (collection) {
            Object.keys(collection).map(function (key) {
              if (collection[key][0].isFromSecurityScheme) {
                delete collection[key];
              }

              if (context.plain[key].definitions[0].isFromSecurityScheme) {
                delete context.plain[key];
              }
            });
          }
        }

        function updateContextData (type, scheme, collection, context) {
          var details         = jQuery.extend({}, $scope.securitySchemes[scheme].describedBy || {});
          var securityHeaders = details[type] || {};

          if (securityHeaders) {
            Object.keys(securityHeaders).map(function (key) {
              if (!securityHeaders[key]) {
                securityHeaders[key] = {
                  id: key,
                  type: 'string'
                };
              }

              securityHeaders[key].id                   = key;
              securityHeaders[key].displayName          = key;
              securityHeaders[key].isFromSecurityScheme = true;
              collection[key] = [securityHeaders[key]];

              context.plain[key] = {
                definitions: [securityHeaders[key]],
                selected: securityHeaders[key].type
              };
              context.values[key] = [undefined];
            });
          }
        }

        $scope.protocolChanged = function protocolChanged(protocol) {
          $scope.currentProtocol = protocol;
        };

        $scope.securitySchemeChanged = function securitySchemeChanged(scheme) {
          var info            = scheme.split('|');
          var type            = info[0];
          var name            = info[1];

          $scope.currentSchemeType = type;
          $scope.context.forceRequest = false;

          cleanSchemeMetadata($scope.methodInfo.headers.plain, $scope.context.headers);
          cleanSchemeMetadata($scope.methodInfo.queryParameters, $scope.context.queryParameters);

          $scope.documentationSchemeSelected = $scope.securitySchemes[name];

          if (type === 'x-custom') {
            readCustomSchemeInfo(name);
          }
        };

        $scope.setFormScope = function (form) {
          $scope.form = form;
        };

        $scope.tryIt = function ($event) {
          $scope.requestOptions  = null;
          $scope.responseDetails = false;
          $scope.response        = {};

          if (!$scope.context.forceRequest) {
            jQuery($event.currentTarget).closest('form').find('.ng-invalid').first().focus();
          }

          if($scope.context.forceRequest || validateForm($scope.form)) {
            var url;
            var context         = $scope.context;
            var segmentContexts = resolveSegementContexts($scope.resource.pathSegments, $scope.context.uriParameters.data());

            $scope.showSpinner = true;
            $scope.queryStringHasError = false;
            $scope.toggleRequestMetadata($event, true);

            try {
              var pathBuilder = context.pathBuilder;
              var client      = RAML.Client.create($scope.raml, function(client) {
                if ($scope.raml.baseUriParameters) {
                  Object.keys($scope.raml.baseUriParameters).map(function (key) {
                    var uriParameters = $scope.context.uriParameters.data();
                    pathBuilder.baseUriContext[key] = uriParameters[key][0];
                    delete uriParameters[key];
                  });
                }
                client.baseUriParameters(pathBuilder.baseUriContext);
              });

              client.baseUri = client.baseUri.replace(/(https)|(http)/, $scope.currentProtocol.toLocaleLowerCase());
              url = client.baseUri + pathBuilder(segmentContexts);
            } catch (e) {
              console.error(e);
              $scope.response = {};
              return;
            }
            var request = RAML.Client.Request.create(url, $scope.methodInfo.method);

            $scope.parameters = getParameters(context, 'queryParameters');

            if (context.queryString) {
              var parameters;
              try {
                parameters = JSON.parse(context.queryString);
              } catch (e) {
                $scope.queryStringHasError = true;
                $scope.response = {};

                $scope.showSpinner = false;
                return;
              }
              Object.keys(parameters).forEach(function (key) {
                if (!$scope.parameters[key]) {
                  $scope.parameters[key] = [];
                }
                var value = parameters[key];
                if (typeof value === 'object') {
                  value = JSON.stringify(value);
                }
                $scope.parameters[key].push(value);
              });
            }

            request.queryParams($scope.parameters);
            request.header('Accept', $scope.raml.mediaType || defaultAccept);
            request.headers(getParameters(context, 'headers'));

            if (context.bodyContent) {
              request.header('Content-Type', context.bodyContent.selected);
              request.data(context.bodyContent.data());
            }

            var authStrategy;

            try {
              var securitySchemes = $scope.methodInfo.securitySchemes();
              var scheme;

              Object.keys(securitySchemes).map(function(key) {
                if (securitySchemes[key].type === $scope.currentSchemeType) {
                  scheme = securitySchemes && securitySchemes[key];
                  return;
                }
              });

              //// TODO: Make a uniform interface
              if (scheme && scheme.type === 'OAuth 2.0') {
                authStrategy = new RAML.Client.AuthStrategies.Oauth2(scheme, $scope.credentials);
                authStrategy.authenticate(request.toOptions(), function (jqXhr, err) {
                  $scope.requestOptions = request.toOptions();
                  handleResponse(jqXhr, err);
                });
                return;
              }
              authStrategy = RAML.Client.AuthStrategies.forScheme(scheme, $scope.credentials);
              authStrategy.authenticate().then(function(token) {
                token.sign(request);
                $scope.requestOptions = request.toOptions();
                jQuery.ajax(request.toOptions()).then(
                  function(data, textStatus, jqXhr) { handleResponse(jqXhr); },
                  function(jqXhr) { handleResponse(jqXhr); }
                );
              });

              $scope.requestOptions = request.toOptions();
            } catch (e) {
              console.error(e);
              $scope.customStrategyError = true;
              $scope.response = {};

              $scope.showSpinner = false;
            }
          } else {
            $scope.context.forceRequest = true;
          }
        };

        $scope.documentationEnabled = true;

        $scope.closeSidebar = function ($event) {
          var $this         = jQuery($event.currentTarget);
          var $panel        = $this.closest('.raml-console-resource-panel');
          var $sidebar      = $panel.find('.raml-console-sidebar');
          var sidebarWidth  = 0;

          if (jQuery(window).width() > 960) {
            sidebarWidth = 430;
          }

          $scope.documentationEnabled = true;
          $sidebar.velocity(
            { width: 0 },
            {
              duration: 200,
              complete: function (element) {
                jQuery(element).removeAttr('style');
                $sidebar.removeClass('raml-console-is-fullscreen');
              }
            }
          );
          $sidebar.toggleClass('raml-console-is-collapsed');
          $sidebar.removeClass('raml-console-is-responsive');
          $panel.toggleClass('raml-console-has-sidebar-collapsed');
        };

        $scope.toggleSidebar = function ($event) {
          var $this        = jQuery($event.currentTarget);
          var $panel       = $this.closest('.raml-console-resource-panel');
          var $sidebar     = $panel.find('.raml-console-sidebar');
          var sidebarWidth = 0;

          if (jQuery(window).width() > 960) {
            sidebarWidth = 430;
          }

          if ($sidebar.hasClass('raml-console-is-fullscreen')) {
            $scope.documentationEnabled = true;
            $sidebar.velocity(
              { width: $scope.singleView ? 0 : sidebarWidth },
              {
                duration: 200,
                complete: function (element) {
                  jQuery(element).removeAttr('style');
                  $sidebar.removeClass('raml-console-is-fullscreen');
                }
              }
            );
            $sidebar.removeClass('raml-console-is-responsive');
            $panel.removeClass('raml-console-has-sidebar-fullscreen');
          } else {
            $sidebar.velocity(
              { width: '100%' },
              {
                duration: 200,
                complete: function (element) {
                  jQuery(element).removeAttr('style');
                  $scope.documentationEnabled = false;
                  apply();
                }
              }
            );

            $sidebar.addClass('raml-console-is-fullscreen');
            $sidebar.addClass('raml-console-is-responsive');
            $panel.addClass('raml-console-has-sidebar-fullscreen');
          }

          if ($scope.singleView) {
            $sidebar.toggleClass('raml-console-is-collapsed');
            $panel.toggleClass('raml-console-has-sidebar-collapsed');
          }
        };

        $scope.collapseSidebar = function ($event) {
          var $this         = jQuery($event.currentTarget);
          var $panel        = $this.closest('.raml-console-resource-panel');
          var $panelContent = $panel.find('.raml-console-resource-panel-primary');
          var $sidebar      = $panel.find('.raml-console-sidebar');
          var animation     = 430;
          var speed         = 200;

          if ((!$sidebar.hasClass('raml-console-is-fullscreen') && !$sidebar.hasClass('raml-console-is-collapsed')) || $sidebar.hasClass('raml-console-is-responsive')) {
            animation = 0;
          }

          if ($scope.singleView) {
            $panel.toggleClass('raml-console-has-sidebar-fullscreen');
            speed = 0;
          }

          $sidebar.velocity(
            { width: animation },
            {
              duration: speed,
              complete: function (element) {
                jQuery(element).removeAttr('style');
                if ($scope.singleView) {
                  $scope.documentationEnabled = false;
                }
                apply();
              }
            }
          );

          $panelContent.velocity(
            { 'padding-right': animation },
            {
              duration: speed,
              complete: completeAnimation
            }
          );

          $sidebar.toggleClass('raml-console-is-collapsed');
          $sidebar.removeClass('raml-console-is-responsive');
          $panel.toggleClass('raml-console-has-sidebar-collapsed');

          if ($sidebar.hasClass('raml-console-is-fullscreen') || $scope.singleView) {
            $sidebar.toggleClass('raml-console-is-fullscreen');
          }
        };

        $scope.toggleRequestMetadata = function (enabled) {
          if ($scope.showRequestMetadata && !enabled) {
            $scope.showRequestMetadata = false;
          } else {
            $scope.showRequestMetadata = true;
          }
        };

        $scope.showResponseMetadata = true;

        $scope.toggleResponseMetadata = function () {
          $scope.showResponseMetadata = !$scope.showResponseMetadata;
        };
      }]
    };
  };

  angular.module('RAML.Directives')
    .directive('sidebar', RAML.Directives.sidebar);
})();

(function () {
  'use strict';

  RAML.Directives.spinner = function() {
    return {
      restrict: 'E',
      templateUrl: 'directives/spinner.tpl.html',
      replace: true,
      link: function($scope, $element) {
        $scope.$on('loading-started', function() {
          $element.css({ 'display': ''});
        });

        $scope.$on('loading-complete', function() {
          $element.css({ 'display': 'none' });
        });
      }
    };
  };

  angular.module('RAML.Directives')
    .directive('spinner', RAML.Directives.spinner);
})();

(function () {
  'use strict';

  RAML.Directives.theme = function() {
    return {
      restrict: 'E',
      templateUrl: 'directives/theme-switcher.tpl.html',
      replace: true,
      link: function($scope, $element) {
        $element.on('click', function() {
          // var $link = jQuery('head link.theme');
          var $theme = jQuery('head').find('#raml-console-theme-dark');

          // $link.attr('href', 'styles/light-theme.css');
          // $element.removeClass('raml-console-theme-toggle-dark');

          if ($theme.length === 0) {
            jQuery.ajax({
              url: 'styles/api-console-dark-theme.css'
            }).done(function (data) {
              jQuery('head').append('<style id="raml-console-theme-dark">' + data + '</style>');
              jQuery('head').find('#raml-console-theme-light').remove();
            });
          } else {
            jQuery.ajax({
              url: 'styles/api-console-light-theme.css'
            }).done(function (data) {
              jQuery('head').append('<style id="raml-console-theme-light">' + data + '</style>');
              jQuery('head').find('#raml-console-theme-dark').remove();
            });
          }
        });
      }
    };
  };

  angular.module('RAML.Directives')
    .directive('themeSwitcher', RAML.Directives.theme);
})();

(function () {
  'use strict';

  RAML.Directives.typeProperties = function() {
    return {
      restrict: 'E',
      templateUrl: 'directives/type-properties.tpl.html',
      replace: true,
      scope: {
        type: '='
      },
      controller: function ($scope) {
        $scope.properties = {
          body: [$scope.type]
        };
      }
    };
  };

  angular.module('RAML.Directives')
    .directive('typeProperties', RAML.Directives.typeProperties);
})();

(function () {
  'use strict';

  RAML.Directives.type = function() {
    var TOGGLE_POPOVER = 'popover:toggle';
    return {
      restrict: 'E',
      templateUrl: 'directives/type.tpl.html',
      scope: {
        typeName: '=',
        hideTypeLinks: '=',
        items: '='
      },
      controller: function ($scope, $rootScope, $timeout) {
        $scope.typeInfo = RAML.Inspector.Types.getTypeInfo($scope.typeName, $scope.items);

        $scope.closePopover = function () {
          $scope.selectedType = null;
        };

        $rootScope.$on(TOGGLE_POPOVER, function () {
          $scope.closePopover();
        });

        $scope.showTypeLink = function (type) {
          return !$scope.hideTypeLinks && !RAML.Inspector.Types.isNativeType(type);
        };

        $scope.cleanupTypeName = RAML.Inspector.Types.cleanupTypeName;

        $scope.getSupertTypes = function (type) {
          return RAML.Inspector.Types.findType(type.type[0], $rootScope.types).type.map(function (aTypeName) {
            return aTypeName;
          });
        };

        $scope.selectType = function ($event, type) {
          jQuery(document).one('click', function () {
            $timeout(function () {
              $rootScope.$broadcast(TOGGLE_POPOVER);
            });
          });

          $rootScope.$broadcast(TOGGLE_POPOVER);

          $timeout(function () {
            $scope.selectedType = RAML.Inspector.Types.mergeType({
                displayName: type,
                type: [type]
              },
              $rootScope.types);
          });

          $event.stopPropagation();
        };
      }
    };
  };

  angular.module('RAML.Directives')
    .directive('type', RAML.Directives.type);
})();

(function () {
  'use strict';

  RAML.Directives.validate = function($parse) {
    return {
      require: 'ngModel',
      link: function ($scope, $element, $attrs, $ctrl) {
        function clear ($ctrl, rules) {
          Object.keys(rules).map(function (key) {
            $ctrl.$setValidity(key, true);
          });
        }

        function validate(value) {
          var sanitizer = (new RAMLSanitize())(sanitationRules);
          var validator = (new RAMLValidate())(validationRules);
          var current   = {};
          var errors;

          value = typeof value !== 'undefined' && value !== null && value.length === 0 ? undefined : value;
          current[validation.id] = value;

          errors = validator(sanitizer(current)).errors;

          if (errors.length > 0) {
            control.$setValidity(errors[0].rule, errors[0].valid);
            // Note: We want to allow invalid errors for testing purposes
            return value;
          } else {
            clear(control, validationRules[validation.id]);
            return value;
          }
        }

        var validation      = $parse($attrs.validate)($scope);
        var sanitationRules = {};
        var validationRules = {};
        var control         = $ctrl;

        sanitationRules[validation.id] = {
          type: validation.type || null,
          repeat: validation.repeat || null
        };

        sanitationRules[validation.id] = RAML.Utils.filterEmpty(sanitationRules[validation.id]);

        validationRules[validation.id] = {
          type: validation.type || null,
          minLength: validation.minLength || null,
          maxLength: validation.maxLength || null,
          required: validation.required || null,
          'enum': validation['enum'] || null,
          pattern: validation.pattern || null,
          minimum: validation.minimum || null,
          maximum: validation.maximum || null,
          repeat: validation.repeat || null
        };

        validationRules[validation.id] = RAML.Utils.filterEmpty(validationRules[validation.id]);

        $ctrl.$formatters.unshift(function(value) {
          return validate(value);
        });

        $ctrl.$parsers.unshift(function(value) {
          return validate(value);
        });
      }
    };
  };

  angular.module('RAML.Directives')
    .directive('validate', ['$parse', RAML.Directives.validate]);
})();

(function () {
  'use strict';

  angular.module('raml', [])
    .factory('ramlParser', function ramlParser(
      $http,
      $q,
      $window
    ) {
      return {
        load:     toQ(load),
        loadPath: toQ(loadPath)
      };

      // ---

      function load(text, contentAsyncFn, options) {
        var virtualPath = '/' + Date.now() + '.raml';
        return loadApi(virtualPath, function contentAsync(path) {
          return (path === virtualPath) ? $q.when(text) : (contentAsyncFn ? contentAsyncFn(path) : $q.reject(new Error('ramlParser: load: contentAsync: ' + path + ': no such path')));
        }, options);
      }

      function loadPath(path, contentAsyncFn, options) {
        return loadApi(path, function contentAsync(path) {
          return contentAsyncFn ? contentAsyncFn(path) : $q.reject(new Error('ramlParser: loadPath: contentAsync: ' + path + ': no such path'));
        }, options);
      }

      // ---

      function toQ(fn) {
        return function toQWrapper() {
          return $q.when(fn.apply(this, arguments));
        };
      }

      /**
       * @param  {String}   path
       * @param  {Function} contentAsyncFn
       * @param  {Object}   options
       * @param  {Boolean}  options.bypassProxy
       */
      function loadApi(path, contentAsyncFn, options) {
        options = options || {};
        return RAML.Parser.loadApi(path, {
          attributeDefaults: true,
          rejectOnErrors:    true,
          fsResolver:        {
            contentAsync: contentAsyncFn,
            content:      content
          },
          httpResolver:      {
            getResourceAsync: function getResourceAsync(url) {
              var settings = ($window.RAML || {}).Settings || {};
              var proxy    = (options.bypassProxy ? {} : settings).proxy || '';
              var req      = {
                method: 'GET',
                url: proxy + url,
                headers: {
                  'Accept': 'application/raml+yaml'
                },
                transformResponse: null
              };
              return $http(req)
                .then(function (res) {
                  return {content: res.data};
                })
              ;
            }
          }
        })
          .then(function (api) {
            var apiJSON;

            api = api.expand ? api.expand() : api;
            apiJSON = api.toJSON();
            if (api.uses && api.uses()) {
              apiJSON.uses = {};
              api.uses().forEach(function (usesItem) {
                var libraryAST = usesItem.ast();
                libraryAST = libraryAST.expand ? libraryAST.expand() : libraryAST;
                apiJSON.uses[usesItem.key()] = libraryAST.toJSON();
              });
            }

            return apiJSON;
          })
        ;

        // ---

        function content(path) {
          throw new Error('ramlParser: loadPath: loadApi: content: ' + path + ': no such path');
        }
      }
    })
  ;
})();

(function () {
  'use strict';

  RAML.Security.basicAuth = function() {
    return {
      restrict: 'E',
      templateUrl: 'security/basic_auth.tpl.html',
      replace: true,
      scope: {
        credentials: '='
      },
      controller: ['$scope', function ($scope) {
        $scope.onChange = function () {
          $scope.$parent.context.forceRequest = false;
        };
      }]
    };
  };

  angular.module('RAML.Security')
    .directive('basicAuth', RAML.Security.basicAuth);
})();

(function () {
  'use strict';

  RAML.Security.oauth1 = function() {
    return {
      restrict: 'E',
      templateUrl: 'security/oauth1.tpl.html',
      replace: true,
      scope: {
        credentials: '='
      },
      controller: ['$scope', function ($scope) {
        $scope.onChange = function () {
          $scope.$parent.context.forceRequest = false;
        };
      }]
    };
  };

  angular.module('RAML.Security')
    .directive('oauth1', RAML.Security.oauth1);
})();

(function () {
  'use strict';

  RAML.Security.oauth2 = function() {
    return {
      restrict: 'E',
      templateUrl: 'security/oauth2.tpl.html',
      replace: true,
      controller: ['$scope', function ($scope) {
        $scope.onChange = function () {
          $scope.$parent.context.forceRequest = false;
        };

        $scope.ownerOptionsEnabled = function () {
          return $scope.credentials.grant === 'owner';
        };

        $scope.isImplicitEnabled = function () {
          return $scope.credentials.grant === 'token';
        };

        $scope.grants = [
          {
            label: 'Implicit',
            value: 'token'
          },
          {
            label: 'Implicit',
            value: 'implicit'
          },
          {
            label: 'Authorization Code',
            value: 'code'
          },
          {
            label: 'Authorization Code',
            value: 'authorization_code'
          },
          {
            label: 'Resource Owner Password Credentials',
            value: 'owner'
          },
          {
            label: 'Resource Owner Password Credentials',
            value: 'password'
          },
          {
            label: 'Client Credentials',
            value: 'credentials'
          },
          {
            label: 'Client Credentials',
            value: 'client_credentials'
          }
        ];

        /* jshint camelcase: false */
        $scope.getOAuth2Settings = function () {
          var result;
          for (var securitySchemesKey in $scope.$parent.securitySchemes) {
            if ($scope.$parent.securitySchemes.hasOwnProperty(securitySchemesKey)) {
              if ($scope.$parent.securitySchemes[securitySchemesKey].type === 'OAuth 2.0') {
                result = $scope.$parent.securitySchemes[securitySchemesKey].settings;
                break;
              }
            }
          }
          return result;
        };

        var oauth2Settings = $scope.getOAuth2Settings();
        var authorizationGrants = oauth2Settings.authorizationGrants;

        $scope.scopes = oauth2Settings.scopes;
        $scope.credentials.scopes = {};

        if (authorizationGrants) {
          $scope.grants = $scope.grants.filter(function (el) {
            return authorizationGrants.indexOf(el.value) > -1;
          });
        }
        /* jshint camelcase: true */

        $scope.credentials.grant = $scope.grants[0].value;
      }]
    };
  };


  angular.module('RAML.Security')
    .directive('oauth2', RAML.Security.oauth2);
})();

(function () {
  'use strict';
  angular.module('RAML.Services').factory('RecursionHelper', ['$compile', function ($compile) {
    return {
      /**
      * Manually compiles the element, fixing the recursion loop.
      * @param element
      * @param [link] A post-link function, or an object with function(s) registered via pre and post properties.
      * @returns An object containing the linking functions.
      */
      compile: function (element, link) {
        // Normalize the link parameter
        if (angular.isFunction(link)) {
          link = { post: link };
        }

        // Break the recursion loop by removing the contents
        var contents = element.contents().remove();
        var compiledContents;
        return {
          pre: (link && link.pre) ? link.pre : null,
          /**
          * Compiles and re-adds the contents
          */
          post: function (scope, element) {
            // Compile the contents
            if (!compiledContents) {
              compiledContents = $compile(contents);
            }
            // Re-add the compiled contents to the element
            compiledContents(scope, function (clone) {
              element.append(clone);
            });

            // Call the post-linking function, if any
            if (link && link.post) {
              link.post.apply(null, arguments);
            }
          }
        };
      }
    };
  }]);
})();

'use strict';

(function() {
  var Client = function(configuration) {
    this.baseUri = configuration.getBaseUri();
  };

  function createConfiguration(parsed) {
    var config = {
      baseUriParameters: {}
    };

    return {
      baseUriParameters: function(baseUriParameters) {
        config.baseUriParameters = baseUriParameters || {};
      },

      getBaseUri: function() {
        var template = RAML.Client.createBaseUri(parsed);
        config.baseUriParameters.version = parsed.version;

        return template.render(config.baseUriParameters);
      }
    };
  }

  RAML.Client = {
    create: function(parsed, configure) {
      var configuration = createConfiguration(parsed);

      if (configure) {
        configure(configuration);
      }

      return new Client(configuration);
    },

    createBaseUri: function(rootRAML) {
      var baseUri = rootRAML.baseUri.toString().replace(/\/+$/, '');

      return new RAML.Client.ParameterizedString(baseUri, rootRAML.baseUriParameters, { parameterValues: {version: rootRAML.version}, encodeURIComponent: true });
    },

    createPathSegment: function(resourceRAML) {
      return new RAML.Client.ParameterizedString(resourceRAML.relativeUri, resourceRAML.uriParameters, { encodeURIComponent: true });
    }
  };
})();

(function() {
  'use strict';

  RAML.Client.AuthStrategies = {
    forScheme: function(scheme, credentials) {
      if (!scheme) {
        return RAML.Client.AuthStrategies.anonymous();
      }

      switch(scheme.type) {
      case 'Basic Authentication':
        return new RAML.Client.AuthStrategies.Basic(scheme, credentials);
      case 'OAuth 2.0':
        return new RAML.Client.AuthStrategies.Oauth2(scheme, credentials);
      case 'OAuth 1.0':
        return new RAML.Client.AuthStrategies.Oauth1(scheme, credentials);
      case 'x-custom':
        return RAML.Client.AuthStrategies.anonymous();
      case 'Anonymous':
        return RAML.Client.AuthStrategies.anonymous();
      default:
        throw new Error('Unknown authentication strategy: ' + scheme.type);
      }
    }
  };
})();

'use strict';

(function() {
  var NO_OP_TOKEN = {
    sign: function() {}
  };

  var Anonymous = function() {};

  Anonymous.prototype.authenticate = function() {
    return {
      then: function(success) { success(NO_OP_TOKEN); }
    };
  };

  var anonymous = new Anonymous();

  RAML.Client.AuthStrategies.Anonymous = Anonymous;
  RAML.Client.AuthStrategies.anonymous = function() {
    return anonymous;
  };
})();

'use strict';

(function() {
  var Basic = function(scheme, credentials) {
    this.token = new Basic.Token(credentials);
  };

  Basic.prototype.authenticate = function() {
    var token = this.token;

    return {
      then: function(success) { success(token); }
    };
  };

  Basic.Token = function(credentials) {
    var words = CryptoJS.enc.Utf8.parse((credentials.username || '') + ':' + (credentials.password || ''));
    this.encoded = CryptoJS.enc.Base64.stringify(words);
  };

  Basic.Token.prototype.sign = function(request) {
    request.header('Authorization', 'Basic ' + this.encoded);
  };

  RAML.Client.AuthStrategies.Basic = Basic;
})();

(function() {
  'use strict';

  var Oauth1 = function(scheme, credentials) {
    var signerFactory = RAML.Client.AuthStrategies.Oauth1.Signer.createFactory(scheme.settings, credentials);
    this.requestTemporaryCredentials = RAML.Client.AuthStrategies.Oauth1.requestTemporaryCredentials(scheme.settings, signerFactory);
    this.requestAuthorization = RAML.Client.AuthStrategies.Oauth1.requestAuthorization(scheme.settings);
    this.requestTokenCredentials = RAML.Client.AuthStrategies.Oauth1.requestTokenCredentials(scheme.settings, signerFactory);
  };

  Oauth1.parseUrlEncodedData = function(data) {
    var result = {};

    data.split('&').forEach(function(param) {
      var keyAndValue = param.split('=');
      result[keyAndValue[0]] = keyAndValue[1];
    });

    return result;
  };

  Oauth1.prototype.authenticate = function() {
    return this.requestTemporaryCredentials().then(this.requestAuthorization).then(this.requestTokenCredentials);
  };

  RAML.Client.AuthStrategies.Oauth1 = Oauth1;
})();

(function() {
  /* jshint camelcase: false */
  'use strict';

  var WINDOW_NAME = 'raml-console-oauth1';

  RAML.Client.AuthStrategies.Oauth1.requestAuthorization = function(settings) {
    return function requestAuthorization(temporaryCredentials) {
      var authorizationUrl = settings.authorizationUri + '?oauth_token=' + temporaryCredentials.token,
      deferred = jQuery.Deferred();

      window.RAML.authorizationSuccess = function(authResult) {
        temporaryCredentials.verifier = authResult.verifier;
        deferred.resolve(temporaryCredentials);
      };
      window.open(authorizationUrl, WINDOW_NAME);
      return deferred.promise();
    };
  };
})();

(function() {
  /* jshint camelcase: false */
  'use strict';

  RAML.Client.AuthStrategies.Oauth1.requestTemporaryCredentials = function(settings, signerFactory) {
    return function requestTemporaryCredentials() {
      var request = RAML.Client.Request.create(settings.requestTokenUri, 'post');

      signerFactory().sign(request);

      return jQuery.ajax(request.toOptions()).then(function(rawFormData) {
        var data = RAML.Client.AuthStrategies.Oauth1.parseUrlEncodedData(rawFormData);

        return {
          token: data.oauth_token,
          tokenSecret: data.oauth_token_secret
        };
      });
    };
  };

})();

(function() {
  /* jshint camelcase: false */
  'use strict';

  RAML.Client.AuthStrategies.Oauth1.requestTokenCredentials = function(settings, signerFactory) {
    return function requestTokenCredentials(temporaryCredentials) {
      var request = RAML.Client.Request.create(settings.tokenCredentialsUri, 'post');

      signerFactory(temporaryCredentials).sign(request);

      return jQuery.ajax(request.toOptions()).then(function(rawFormData) {
        var credentials = RAML.Client.AuthStrategies.Oauth1.parseUrlEncodedData(rawFormData);

        return signerFactory({
          token: credentials.oauth_token,
          tokenSecret: credentials.oauth_token_secret
        });
      });
    };
  };
})();

(function() {
  /* jshint camelcase: false */
  'use strict';

  var Signer = RAML.Client.AuthStrategies.Oauth1.Signer = {};

  Signer.createFactory = function(settings, consumerCredentials) {
    settings = settings || {};

    return function createSigner(tokenCredentials) {
      var type = settings.signatureMethod === 'PLAINTEXT' ? 'Plaintext' : 'Hmac';
      var mode = tokenCredentials === undefined ? 'Temporary' : 'Token';

      return new Signer[type][mode](consumerCredentials, tokenCredentials);
    };
  };

  function baseParameters(consumerCredentials) {
    return {
      oauth_consumer_key: consumerCredentials.consumerKey,
      oauth_version: '1.0'
    };
  }

  Signer.generateTemporaryCredentialParameters = function(consumerCredentials) {
    var result = baseParameters(consumerCredentials);
    result.oauth_callback = RAML.Settings.oauth1RedirectUri;

    return result;
  };

  Signer.generateTokenCredentialParameters = function(consumerCredentials, tokenCredentials) {
    var result = baseParameters(consumerCredentials);

    result.oauth_token = tokenCredentials.token;
    if (tokenCredentials.verifier) {
      result.oauth_verifier = tokenCredentials.verifier;
    }

    return result;
  };

  // https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/encodeURIComponent
  Signer.rfc3986Encode = function(str) {
    return encodeURIComponent(str).replace(/[!'()]/g, window.escape).replace(/\*/g, '%2A');
  };

  Signer.setRequestHeader = function(params, request) {
    var header = Object.keys(params).map(function(key) {
      return key + '="' + Signer.rfc3986Encode(params[key]) + '"';
    }).join(', ');

    request.header('Authorization', 'OAuth ' + header);
  };
})();

(function() {
  /* jshint camelcase: false */
  'use strict';

  var generateTemporaryCredentialParameters = RAML.Client.AuthStrategies.Oauth1.Signer.generateTemporaryCredentialParameters,
      generateTokenCredentialParameters = RAML.Client.AuthStrategies.Oauth1.Signer.generateTokenCredentialParameters,
      rfc3986Encode = RAML.Client.AuthStrategies.Oauth1.Signer.rfc3986Encode,
      setRequestHeader = RAML.Client.AuthStrategies.Oauth1.Signer.setRequestHeader;

  function generateSignature(params, request, key) {
    params.oauth_signature_method = 'HMAC-SHA1';
    params.oauth_timestamp = Math.floor(Date.now() / 1000);
    params.oauth_nonce = CryptoJS.lib.WordArray.random(16).toString();

    var data = Hmac.constructHmacText(request, params);
    var hash = CryptoJS.HmacSHA1(data, key);
    params.oauth_signature = hash.toString(CryptoJS.enc.Base64);
  }

  var Hmac = {
    constructHmacText: function(request, oauthParams) {
      var options = request.toOptions();

      return [
        options.method.toUpperCase(),
        this.encodeURI(options.url),
        rfc3986Encode(this.encodeParameters(request, oauthParams))
      ].join('&');
    },

    encodeURI: function(uri) {
      var parser = document.createElement('a');
      parser.href = uri;

      var hostname = '';
      if (parser.protocol === 'https:' && parser.port === 443 || parser.protocol === 'http:' && parser.port === 80) {
        hostname = parser.hostname.toLowerCase();
      } else {
        hostname = parser.host.toLowerCase();
      }

      return rfc3986Encode(parser.protocol + '//' + hostname + parser.pathname);
    },

    encodeParameters: function(request, oauthParameters) {
      var params = request.queryParams();
      var formParams = {};
      if (request.toOptions().contentType === 'application/x-www-form-urlencoded') {
        formParams = request.data();
      }

      var result = [];
      for (var key in params) {
        result.push([rfc3986Encode(key), rfc3986Encode(params[key])]);
      }

      for (var formKey in formParams) {
        result.push([rfc3986Encode(formKey), rfc3986Encode(formParams[formKey])]);
      }

      for (var oauthKey in oauthParameters) {
        result.push([rfc3986Encode(oauthKey), rfc3986Encode(oauthParameters[oauthKey])]);
      }

      result.sort(function(a, b) {
        return (a[0] === b[0] ? a[1].localeCompare(b[1]) : a[0].localeCompare(b[0]));
      });

      return result.map(function(tuple) { return tuple.join('='); }).join('&');
    }
  };

  Hmac.Temporary = function(consumerCredentials) {
    this.consumerCredentials = consumerCredentials;
  };

  Hmac.Temporary.prototype.sign = function(request) {
    var params = generateTemporaryCredentialParameters(this.consumerCredentials);
    var key = rfc3986Encode(this.consumerCredentials.consumerSecret) + '&';

    generateSignature(params, request, key);
    setRequestHeader(params, request);
  };

  Hmac.Token = function(consumerCredentials, tokenCredentials) {
    this.consumerCredentials = consumerCredentials;
    this.tokenCredentials = tokenCredentials;
  };

  Hmac.Token.prototype.sign = function(request) {
    var params = generateTokenCredentialParameters(this.consumerCredentials, this.tokenCredentials);
    var key = rfc3986Encode(this.consumerCredentials.consumerSecret) + '&' + rfc3986Encode(this.tokenCredentials.tokenSecret);

    generateSignature(params, request, key);
    setRequestHeader(params, request);
  };

  RAML.Client.AuthStrategies.Oauth1.Signer.Hmac = Hmac;
})();

(function() {
  /* jshint camelcase: false */
  'use strict';

  var generateTemporaryCredentialParameters = RAML.Client.AuthStrategies.Oauth1.Signer.generateTemporaryCredentialParameters,
      generateTokenCredentialParameters = RAML.Client.AuthStrategies.Oauth1.Signer.generateTokenCredentialParameters,
      rfc3986Encode = RAML.Client.AuthStrategies.Oauth1.Signer.rfc3986Encode,
      setRequestHeader = RAML.Client.AuthStrategies.Oauth1.Signer.setRequestHeader;

  var Plaintext = {};

  Plaintext.Temporary = function(consumerCredentials) {
    this.consumerCredentials = consumerCredentials;
  };

  Plaintext.Temporary.prototype.sign = function(request) {
    var params = generateTemporaryCredentialParameters(this.consumerCredentials);
    params.oauth_signature = rfc3986Encode(this.consumerCredentials.consumerSecret) + '&';
    params.oauth_signature_method = 'PLAINTEXT';

    setRequestHeader(params, request);
  };

  Plaintext.Token = function(consumerCredentials, tokenCredentials) {
    this.consumerCredentials = consumerCredentials;
    this.tokenCredentials = tokenCredentials;
  };

  Plaintext.Token.prototype.sign = function(request) {
    var params = generateTokenCredentialParameters(this.consumerCredentials, this.tokenCredentials);
    params.oauth_signature = rfc3986Encode(this.consumerCredentials.consumerSecret) + '&' + rfc3986Encode(this.tokenCredentials.tokenSecret);
    params.oauth_signature_method = 'PLAINTEXT';

    setRequestHeader(params, request);
  };

  RAML.Client.AuthStrategies.Oauth1.Signer.Plaintext = Plaintext;
})();

(function() {
  'use strict';

  var Oauth2 = function(scheme, credentials) {
    this.scheme = scheme;
    this.credentials = credentials;
  };

  function getScopes(credentials) {
    var scopes = [];

    if (credentials.scopes) {
      scopes = Object.keys(credentials.scopes).filter(function (scope) {
        return credentials.scopes[scope] === true;
      });
    }

    return scopes;
  }

  function popup(location) {
    var w    = 640;
    var h    = 480;
    var left = (screen.width / 2) - (w / 2);
    var top  = (screen.height / 2) - (h / 2);
    return window.open(location, 'Authentication', 'toolbar=no, location=no, directories=no, status=no, menubar=no, scrollbars=no, resizable=no, copyhistory=no, width=' + w + ', height=' + h + ', top=' + top + ', left=' + left);
  }

  Oauth2.prototype.authenticate = function(options, done) {
    var auth = new ClientOAuth2({
      clientId:         this.credentials.clientId,
      clientSecret:     this.credentials.clientSecret,
      accessTokenUri:   this.scheme.settings.accessTokenUri,
      authorizationUri: this.scheme.settings.authorizationUri,
      redirectUri:      RAML.Settings.oauth2RedirectUri,
      scopes:           getScopes(this.credentials)
    });
    var grantType = this.credentials.grant;

    if (grantType === 'token' || grantType === 'code' || grantType === 'authorization_code' || grantType === 'implicit') {
      window.oauth2Callback = function (uri) {
        auth[grantType].getToken(uri, function (err, user, raw) {
          if (err) {
            done(raw, err);
          }

          if (user && user.accessToken) {
            user.request(options, function (err, res) {
              done(res.raw, err);
            });
          }
        });
      };
      //// TODO: Find a way to handle 404
      popup(auth[grantType].getUri());
    }

    if (grantType === 'owner' || grantType === 'password') {
      auth.owner.getToken(this.credentials.username, this.credentials.password, function (err, user, raw) {
        if (err) {
          done(raw, err);
        }

        if (user && user.accessToken) {
          user.request(options, function (err, res) {
            done(res.raw, err);
          });
        }
      });
    }

    if (grantType === 'credentials'|| grantType === 'client_credentials') {
      auth.credentials.getToken(function (err, user, raw) {
        if (err) {
          done(raw, err);
        }

        if (user && user.accessToken) {
          user.request(options, function (err, res) {
            done(res.raw, err);
          });
        }
      });
    }
  };

  RAML.Client.AuthStrategies.Oauth2 = Oauth2;
})();

(function() {
  'use strict';

  var templateMatcher = /\{([^}]*)\}/g;

  function tokenize(template) {
    var tokens = template.split(templateMatcher);

    return tokens.filter(function(token) {
      return token.length > 0;
    });
  }

  function rendererFor(template, uriParameters, options) {
    return function renderer(context) {
      context = context || {};

      // Enforce request without URI parameters
      // requiredParameters.forEach(function(name) {
      //   if (!context[name]) {
      //     throw new Error('Missing required uri parameter: ' + name);
      //   }
      // });

      var templated = template.replace(templateMatcher, function(match, parameterName) {
        if (context[parameterName]) {
          if (typeof context[parameterName][0] !== 'object') {
            return context[parameterName];
          }
          var tempValue = JSON.stringify(
            RAML.Inspector.Properties.cleanupPropertyValue(context[parameterName][0]));

          if (options.encodeURIComponent) {
            tempValue = encodeURIComponent(tempValue);
          }

          return tempValue;
        }
        return '';
      });

      return templated;
    };
  }

  RAML.Client.ParameterizedString = function(template, uriParameters, options) {
    options = angular.extend({ parameterValues: {} }, options);
    template = template.replace(templateMatcher, function(match, parameterName) {
      if (options.parameterValues[parameterName]) {
        return options.parameterValues[parameterName];
      }
      return '{' + parameterName + '}';
    });

    this.parameters = uriParameters;
    this.templated = Object.keys(this.parameters || {}).length > 0;
    this.tokens = tokenize(template);
    this.render = rendererFor(template, uriParameters, options);
    this.toString = function() { return template; };
  };
})();

(function() {
  'use strict';

  RAML.Client.PathBuilder = {
    create: function(pathSegments) {
      return function pathBuilder(contexts) {
        contexts = contexts || [];

        return pathSegments.map(function(pathSegment, index) {
          return pathSegment.render(contexts[index]);
        }).join('');
      };
    }
  };
})();

(function() {
  'use strict';

  var CONTENT_TYPE = 'content-type';
  var FORM_DATA = 'multipart/form-data';

  var RequestDsl = function(options) {
    var rawData;
    var queryParams;
    var isMultipartRequest;

    this.data = function(data) {
      if (data === undefined) {
        return RAML.Utils.clone(rawData);
      } else {
        rawData = data;
      }
    };

    this.queryParams = function(parameters) {
      if (parameters === undefined) {
        return RAML.Utils.clone(queryParams);
      } else {
        queryParams = parameters;
      }
    };

    this.queryParam = function(name, value) {
      queryParams = queryParams || {};
      queryParams[name] = value;
    };

    this.header = function(name, value) {
      options.headers = options.headers || {};

      if (name.toLowerCase() === CONTENT_TYPE) {
        if (value === FORM_DATA) {
          isMultipartRequest = true;
          options.contentType = false;
          return;
        } else {
          isMultipartRequest = false;
          options.contentType = value;
        }
      }

      options.headers[name] = value;
    };

    this.headers = function(headers) {
      options.headers = {};
      isMultipartRequest = false;

      for (var name in headers) {
        this.header(name, headers[name]);
      }

      if (Object.keys(options.headers).length === 0) {
        options.headers = null;
      }
    };

    this.toOptions = function() {
      var o = RAML.Utils.copy(options);
      o.traditional = true;

      if (rawData) {
        if (isMultipartRequest) {
          var data = new FormData();

          var appendValueForKey = function(key) {
            return function(value) {
              data.append(key, value);
            };
          };

          for (var key in rawData) {
            rawData[key].forEach(appendValueForKey(key));
          }

          o.processData = false;
          o.data = data;
        } else {
          o.processData = true;
          o.data = rawData;
        }
      }

      o.baseUrl = options.url;

      if (!RAML.Utils.isEmpty(queryParams)) {
        var separator = (options.url.match('\\?') ? '&' : '?');

        o.baseUrl = options.url + separator;
        o.url = options.url + separator + jQuery.param(queryParams, true);
      }

      if (!RAML.Settings.disableProxy && RAML.Settings.proxy) {
        o.url = RAML.Settings.proxy + o.url;
      }

      return o;
    };
  };

  RAML.Client.Request = {
    create: function(url, method) {
      return new RequestDsl({ url: url, method: method });
    }
  };
})();

(function() {
  'use strict';

  // number regular expressions from http://yaml.org/spec/1.2/spec.html#id2804092

  var RFC1123 = /^(Mon|Tue|Wed|Thu|Fri|Sat|Sun), \d{2} (Jan|Feb|Mar|Apr|May|Jun|Jul|Aug|Sep|Oct|Nov|Dec) \d{4} \d{2}:\d{2}:\d{2} GMT$/;

  function isEmpty(value) {
    return value == null || value === '';
  }

  var VALIDATIONS = {
    required: function(value) {
      return !isEmpty(value);
    },
    'boolean': function(value) {
      return isEmpty(value) || value === 'true' || value === 'false';
    },
    'enum': function(enumeration) {
      return function(value) {
        return isEmpty(value) || enumeration.indexOf(value) > -1;
      };
    },
    integer: function(value) {
      return isEmpty(value) || /^-?(0|[1-9][0-9]*)$/.test(value);
    },
    number: function(value) {
      return isEmpty(value) || /^-?(0|[1-9][0-9]*)(\.[0-9]*)?([eE][-+]?[0-9]+)?$/.test(value);
    },
    minimum: function(minimum) {
      return function(value) {
        return isEmpty(value) || value >= minimum;
      };
    },
    maximum: function(maximum) {
      return function(value) {
        return isEmpty(value) || value <= maximum;
      };
    },
    minLength: function(minimum) {
      return function(value) {
        return isEmpty(value) || value.length >= minimum;
      };
    },
    maxLength: function(maximum) {
      return function(value) {
        return isEmpty(value) || value.length <= maximum;
      };
    },
    pattern: function(pattern) {
      var regex = new RegExp(pattern);

      return function(value) {
        return isEmpty(value) || regex.test(value);
      };
    },
    date: function(value) {
      return isEmpty(value) || RFC1123.test(value);
    }
  };

  function baseValidations(definition) {
    var validations = {};

    if (definition.required) {
      validations.required = VALIDATIONS.required;
    }

    return validations;
  }

  function numberValidations(validations, definition) {
    if (definition.minimum != null) {
      validations.minimum = VALIDATIONS.minimum(definition.minimum);
    }

    if (definition.maximum != null) {
      validations.maximum = VALIDATIONS.maximum(definition.maximum);
    }
  }

  // function copyValidations(validations, types) {
  //   Object.keys(types).forEach(function(type) {
  //     validations[type] = VALIDATIONS[type](types[type]);
  //   });
  // }

  var VALIDATIONS_FOR_TYPE = {
    string: function(definition) {
      var validations = baseValidations(definition);

      if (Array.isArray(definition['enum'])) {
        validations['enum'] = VALIDATIONS['enum'](definition['enum']);
      }

      if (definition.minLength != null) {
        validations.minLength = VALIDATIONS.minLength(definition.minLength);
      }

      if (definition.maxLength != null) {
        validations.maxLength = VALIDATIONS.maxLength(definition.maxLength);
      }

      if (definition.pattern) {
        validations.pattern = VALIDATIONS.pattern(definition.pattern);
      }

      return validations;
    },

    integer: function(definition) {
      var validations = baseValidations(definition);
      validations.integer = VALIDATIONS.integer;
      numberValidations(validations, definition);
      return validations;
    },

    number: function(definition) {
      var validations = baseValidations(definition);
      validations.number = VALIDATIONS.number;
      numberValidations(validations, definition);
      return validations;
    },

    'boolean': function(definition) {
      var validations = baseValidations(definition);
      // Ignore better written in dot notation rule
      /*jshint -W069 */
      validations['boolean'] = VALIDATIONS['boolean'];
      /*jshint +W069 */
      return validations;
    },

    date: function(definition) {
      var validations = baseValidations(definition);
      validations.date = VALIDATIONS.date;
      return validations;
    }
  };

  function Validator(validations) {
    this.validations = validations;
  }

  Validator.prototype.validate = function(value) {
    var errors;

    for (var validation in this.validations) {
      if (!this.validations[validation](value)) {
        errors = errors || [];
        errors.push(validation);
      }
    }

    return errors;
  };

  Validator.from = function(definition) {
    if (!definition) {
      throw new Error('definition is required!');
    }

    var validations;

    if (VALIDATIONS_FOR_TYPE[definition.type]) {
      validations = VALIDATIONS_FOR_TYPE[definition.type](definition);
    } else {
      validations = {};
    }

    return new Validator(validations);
  };

  RAML.Client.Validator = Validator;
})();

(function() {
  'use strict';

  RAML.Filters.nameFromParameterizable = function() {
    return function(input) {
      if (typeof input === 'object' && input !== null) {
        return Object.keys(input)[0];
      } else if (input) {
        return input;
      } else {
        return undefined;
      }
    };
  };
})();

RAML.Inspector = (function() {
  'use strict';

  var exports = {};

  var METHOD_ORDERING = ['GET', 'POST', 'PUT', 'PATCH', 'DELETE', 'HEAD', 'OPTIONS', 'TRACE', 'CONNECT'];

  function extractResources(basePathSegments, api, securitySchemes) {
    var resources = [], apiResources = api.resources || [];

    apiResources.forEach(function(resource) {
      var resourcePathSegments = basePathSegments.concat(RAML.Client.createPathSegment(resource));
      var overview = exports.resourceOverviewSource(resourcePathSegments, resource);

      overview.methods = overview.methods.map(function(method) {
        return RAML.Inspector.Method.create(method, securitySchemes);
      });


      resources.push(overview);

      if (resource.resources) {
        var extracted = extractResources(resourcePathSegments, resource, securitySchemes);
        extracted.forEach(function(resource) {
          resources.push(resource);
        });
      }
    });

    return resources;
  }

  function groupResources(resources) {
    var currentPrefix, resourceGroups = [];

    (resources || []).forEach(function(resource) {
      var prefix = resource.pathSegments[0].toString();
      if (prefix === currentPrefix || prefix.indexOf(currentPrefix + '/') === 0) {
        resourceGroups[resourceGroups.length-1].push(resource);
      } else {
        currentPrefix = resource.pathSegments[0].toString();
        resourceGroups.push([resource]);
      }
    });

    return resourceGroups;
  }

  exports.resourceOverviewSource = function(pathSegments, resource) {
    var clone = RAML.Utils.clone(resource);

    clone.traits = resource.is;
    clone.resourceType = resource.type;
    clone.type = clone.is = undefined;
    clone.pathSegments = pathSegments;

    clone.methods = (resource.methods || []);

    clone.methods.sort(function(a, b) {
      var aOrder = METHOD_ORDERING.indexOf(a.method.toUpperCase());
      var bOrder = METHOD_ORDERING.indexOf(b.method.toUpperCase());

      return aOrder > bOrder ? 1 : -1;
    });

    clone.uriParametersForDocumentation = RAML.Inspector.Properties.normalizeNamedParameters(pathSegments
      .map(function(segment) { return segment.parameters; })
      .filter(function(params) { return !!params; })
      .reduce(function(accum, parameters) {
        for (var key in parameters) {
          accum[key] = parameters[key];
        }
        return accum;
      }, {}));

    if (Object.keys(clone.uriParametersForDocumentation).length === 0) {
      clone.uriParametersForDocumentation = null;
    }

    clone.toString = function() {
      return this.pathSegments.map(function(segment) { return segment.toString(); }).join('');
    };

    return clone;
  };

  exports.create = function(api) {
    // Perform deep copy to avoid mutating object.
    // TODO: Audit code and only use parts of object that are required.
    api = jQuery.extend(true, {}, api);

    if (api.baseUri) {
      api.baseUri = RAML.Client.createBaseUri(api);
    }

    api.resources = extractResources([], api, api.securitySchemes);
    api.resourceGroups = groupResources(api.resources);

    return api;
  };

  return exports;
})();

(function() {
  'use strict';

  var PARAMETER = /\{\*\}/;

  function wrapWithParameterizedHeader(name, definitions) {
    return definitions.map(function(definition) {
      return RAML.Inspector.ParameterizedHeader.fromRAML(name, definition);
    });
  }

  function filterHeaders(headers) {
    var filtered = {
      plain: {},
      parameterized: {}
    };

    Object.keys(headers || {}).forEach(function(key) {
      if (key.match(PARAMETER)) {
        filtered.parameterized[key] = wrapWithParameterizedHeader(key, headers[key]);
      } else {
        filtered.plain[key] = headers[key];
      }
    });

    if(Object.keys(filtered.plain).length === 0) {
      filtered.plain = null;
    }

    return filtered;
  }

  function processBody(body) {
    var content = body['application/x-www-form-urlencoded'];
    if (content) {
      RAML.Inspector.Properties.normalizeNamedParameters(content.formParameters);
    }

    content = body['multipart/form-data'];
    if (content) {
      RAML.Inspector.Properties.normalizeNamedParameters(content.formParameters);
    }
  }

  function processResponses(responses) {
    Object.keys(responses).forEach(function(status) {
      var response = responses[status];
      if (response) {
        RAML.Inspector.Properties.normalizeNamedParameters(response.headers);
      }
    });
  }

  function securitySchemesExtractor(securitySchemes) {
    securitySchemes = securitySchemes || [];

    return function() {
      var securedBy = this.securedBy || [],
          selectedSchemes = {};

      var overwrittenSchemes = {};

      securedBy.map(function(el) {
        if (el === null) {
          securitySchemes.push({
            anonymous: {
              type: 'Anonymous'
            }
          });
          securedBy.push('anonymous');
        }

        if (typeof el === 'object' && el) {
          var key = Object.keys(el)[0];

          overwrittenSchemes[key] = el[key];
          securedBy.push(key);
        }
      });

      securedBy = securedBy.filter(function(name) {
        return name !== null && typeof name !== 'object';
      });

      securitySchemes.forEach(function(scheme) {
        securedBy.forEach(function(name) {
          if (scheme[name]) {
            selectedSchemes[name] = jQuery.extend(true, {}, scheme[name]);
          }
        });
      });

      Object.keys(overwrittenSchemes).map(function (key) {
        Object.keys(overwrittenSchemes[key]).map(function (prop) {
          if (selectedSchemes[key].settings) {
            selectedSchemes[key].settings[prop] = overwrittenSchemes[key][prop];
          }
        });
      });

      if(Object.keys(selectedSchemes).length === 0) {
        selectedSchemes.anonymous = {
          type: 'Anonymous'
        };
      }

      return selectedSchemes;
    };
  }

  function allowsAnonymousAccess() {
    /*jshint validthis: true */
    var securedBy = this.securedBy || [null];
    return securedBy.some(function(name) { return name === null; });
  }

  RAML.Inspector.Method = {
    create: function(raml, securitySchemes) {
      var method = RAML.Utils.clone(raml);

      method.responseCodes = Object.keys(method.responses || {});
      method.securitySchemes = securitySchemesExtractor(securitySchemes);
      method.allowsAnonymousAccess = allowsAnonymousAccess;
      RAML.Inspector.Properties.normalizeNamedParameters(method.headers);
      RAML.Inspector.Properties.normalizeNamedParameters(method.queryParameters);

      method.headers = filterHeaders(method.headers);
      processBody(method.body || {});
      processResponses(method.responses || {});

      method.plainAndParameterizedHeaders = RAML.Utils.copy(method.headers.plain);
      Object.keys(method.headers.parameterized).forEach(function(parameterizedHeader) {
        method.plainAndParameterizedHeaders[parameterizedHeader] = method.headers.parameterized[parameterizedHeader].map(function(parameterized) {
          return parameterized.definition();
        });
      });

      return method;
    }
  };
})();

(function () {
  'use strict';

  function validate(value) {
    value = value ? value.trim() : '';

    if (value === '') {
      throw new Error();
    }

    return value;
  }

  function fromRAML(name, definition) {
    var parameterizedString = new RAML.Client.ParameterizedString(name, definition);

    return {
      create: function(value) {
        value = validate(value);

        var header = RAML.Utils.clone(definition);
        header.displayName = parameterizedString.render({'*': value});

        return header;
      },
      definition: function() {
        return definition;
      }
    };
  }

  RAML.Inspector.ParameterizedHeader = {
    fromRAML: fromRAML
  };
})();

(function() {
  'use strict';

  function ensureArray(value) {
    if (value === undefined || value === null) {
      return;
    }

    return (value instanceof Array) ? value : [ value ];
  }

  function normalizeNamedParameters(parameters) {
    Object.keys(parameters || {}).forEach(function(key) {
      if (parameters[key].properties) {
        normalizeNamedParameters(parameters[key].properties);
      }

      parameters[key] = ensureArray(parameters[key]);
    });

    return parameters;
  }

  function cleanupPropertyValue(value) {
    if (typeof value !== 'object') {
      return value;
    }
    var cleanedValue = {};

    if (Array.isArray(value)) {
      cleanedValue = value.map(function (arrayItem) {
        return cleanupPropertyValue(arrayItem[0]);
      });
    } else {
      Object.keys(value).forEach(function (key) {
        cleanedValue[key] = cleanupPropertyValue(value[key] ? value[key][0] : value[key]);

        // Remove empty array property
        if (!cleanedValue[key][0]) {
          delete cleanedValue[key];
        }
      });
    }

    return cleanedValue;
  }

  RAML.Inspector.Properties = {
    normalizeNamedParameters: normalizeNamedParameters,
    cleanupPropertyValue: cleanupPropertyValue
  };
})();

(function() {
  'use strict';

  var UNION_ARRAY_REGEXP = /^\([^\)]*\)\[\]$/;

  function cleanupTypeName(typeName) {
    return typeName.replace('[]', '').replace('(', '').replace(')', '').trim();
  }

  function isNativeType(typeName) {
    typeName = cleanupTypeName(typeName);
    var nativeTypes = [
      'object',
      'string',
      'number',
      'integer',
      'boolean',
      'date-only',
      'time-only',
      'datetime-only',
      'datetime',
      'file',
      'array'
    ];
    return nativeTypes.indexOf(typeName) !== -1;
  }

  function isSchema(typeName) {
    try {
      JSON.parse(typeName);
      return true;
    } catch (error) {
      return false;
    }
  }

  function find(name, collection) {
    var found;
    var length = collection.length;
    for (var i = 0; i < length; i++) {
      if (collection[i][name]) {
        found = collection[i][name];
        break;
      }
    }
    return found;
  }

  function findType(typeName, types) {
    if (types) {
      typeName = cleanupTypeName(typeName);
      var existingType = find(typeName, types);
      return existingType;
    }
  }

  function findSchema(schemaName, schemas) {
    if (schemas) {
      var existingSchema = find(schemaName, schemas);
      return existingSchema;
    }
  }

  function getSuperTypesProperties(properties, typeName, types) {
    if (!isNativeType(typeName)) {
      var superType = findType(typeName, types);

      if (superType) {
        var superTypeProperties = convertProperties(superType);
        properties = angular.extend({}, superTypeProperties, properties);
        return getSuperTypesProperties(properties, superType.type[0], types);
      }
    }
    return properties;
  }

  function convertProperties(type) {
    if (type.properties) {
      Object.keys(type.properties).forEach(function (propertyKey) {
        var aProperty = type.properties[propertyKey];
        if (type.discriminator && type.discriminator === aProperty[0].name) {
          aProperty[0].discriminator = true;
        }
      });
    }
    return type.properties;
  }

  function mergeType(type, types) {
    var resultingType = angular.copy(type);
    resultingType.type = resultingType.type || resultingType.schema;
    var properties = angular.copy(resultingType.properties || {});
    var currentType = Array.isArray(resultingType.type) ?
        resultingType.type[0] : resultingType.type;

    properties = convertProperties(resultingType);

    if (!isNativeType(currentType)) {
      resultingType.type.forEach(function (superType) {
        properties = getSuperTypesProperties(properties, superType, types);
      });
    }
    if (properties) {
      var propertiesKeys = Object.keys(properties).sort();

      if (propertiesKeys.length > 0) {
        resultingType.properties = propertiesKeys.map(function (key) {
          return ensureArray(properties[key]);
        });
      }
    }

    return resultingType;
  }

  function getTypeInfo(typeName) {
    var types = typeName.split('|');
    var typeInfo = {};

    if (types.length > 1) {
      typeInfo.type = 'union';
      typeInfo.isArray = UNION_ARRAY_REGEXP.test(typeName);
      typeInfo.parts = types.map(function (type) {
        return cleanupTypeName(type);
      });
    } else if (typeName.indexOf('[]') !== -1) {
      typeInfo.type = 'array';
      typeInfo.parts = [typeName.replace('[]', '').trim()];
    } else {
      typeInfo.type = 'custom';
      typeInfo.parts = [typeName.trim()];
    }

    return typeInfo;
  }

  function getTypeFromTypeInfo(typeInfo) {
    var type;
    if (typeInfo.type === 'union') {
      type = typeInfo.parts.join('|');
      if (typeInfo.isArray) {
        type = '(' + type + ')[]';
      }

      return type;
    } else if (typeInfo.type === 'array') {
      return typeInfo.parts.join('') + '[]';
    } else {
      return typeInfo.parts.join('');
    }
  }

  function ensureArray(type) {
    return Array.isArray(type) ? type : [type];
  }

  RAML.Inspector.Types = {
    mergeType:           mergeType,
    isNativeType:        isNativeType,
    isSchema:            isSchema,
    findType:            findType,
    findSchema:          findSchema,
    getTypeInfo:         getTypeInfo,
    getTypeFromTypeInfo: getTypeFromTypeInfo,
    ensureArray:         ensureArray,
    cleanupTypeName:     cleanupTypeName
  };
})();

(function() {
  'use strict';

  window.ramlErrors = {};

  CodeMirror.registerHelper('lint', 'yaml', function () {
    var found = [];

    found.push({
      message: window.ramlErrors.message,
      severity: 'error',
      from: CodeMirror.Pos(window.ramlErrors.line),
      to: CodeMirror.Pos(window.ramlErrors.line)
    });

    return found;
  });
})();

(function() {
  'use strict';

  var FORM_URLENCODED = 'application/x-www-form-urlencoded';
  var FORM_DATA = 'multipart/form-data';

  var BodyContent = function(contentTypes) {
    this.contentTypes = Object.keys(contentTypes).sort();
    this.selected = this.contentTypes[0];

    var definitions = this.definitions = {};
    this.contentTypes.forEach(function(contentType) {
      var definition = contentTypes[contentType] || {};

      if (definition.formParameters) {
        Object.keys(definition.formParameters).map(function (key) {
          definition.formParameters[key][0].id = key;
        });
      }

      switch (contentType) {
      case FORM_URLENCODED:
      case FORM_DATA:
        definitions[contentType] = new RAML.Services.TryIt.NamedParameters(definition.formParameters);
        break;
      default:
        definitions[contentType] = new RAML.Services.TryIt.BodyType(definition);
      }
    });
  };

  BodyContent.prototype.isForm = function(contentType) {
    return contentType === FORM_URLENCODED || contentType === FORM_DATA;
  };

  BodyContent.prototype.isSelected = function(contentType) {
    return contentType === this.selected;
  };

  BodyContent.prototype.fillWithExample = function($event) {
    $event.preventDefault();
    this.definitions[this.selected].fillWithExample();
  };

  BodyContent.prototype.hasExample = function(contentType) {
    return this.definitions[contentType].hasExample();
  };

  BodyContent.prototype.data = function() {
    if (this.selected) {
      return this.definitions[this.selected].data();
    }
  };

  BodyContent.prototype.copyFrom = function(oldContent) {
    var content = this;

    oldContent.contentTypes.forEach(function(contentType) {
      if (content.definitions[contentType]) {
        content.definitions[contentType].copyFrom(oldContent.definitions[contentType]);
      }
    });

    if (this.contentTypes.some(function(contentType) { return contentType === oldContent.selected; })) {
      this.selected = oldContent.selected;
    }
  };

  BodyContent.prototype.clear = function (info) {
    var that = this.definitions[this.selected];
    Object.keys(this.values).map(function (key) {
      if (typeof info[key][0]['enum'] === 'undefined' || info[key][0].overwritten === true) {
        that.values[key] = [''];
      }
    });
  };

  BodyContent.prototype.reset = function (info, field) {
    var that = this.definitions[this.selected];
    if (info) {
      Object.keys(info).map(function (key) {
        if (typeof field === 'undefined' || field === key) {
          if (typeof info[key][0]['enum'] === 'undefined') {
            that.values[key][0] = info[key][0].example;
          }
        }
      });
    }
  };

  RAML.Services.TryIt.BodyContent = BodyContent;
})();

(function() {
  'use strict';

  var BodyType = function(contentType) {
    this.contentType = contentType || {};
    this.value = undefined;
  };

  BodyType.prototype.fillWithExample = function() {
    var example;
    if (this.contentType.examples) {
      example = this.contentType.examples[0].value;
    } else {
      example = this.contentType.example;
    }

    if (typeof example === 'object') {
      this.value = JSON.stringify(example);
    } else {
      this.value = example;
    }

  };

  BodyType.prototype.hasExample = function() {
    return !!this.contentType.example || !!this.contentType.examples;
  };

  BodyType.prototype.data = function() {
    return this.value;
  };

  BodyType.prototype.copyFrom = function(oldBodyType) {
    this.value = oldBodyType.value;
  };

  RAML.Services.TryIt.BodyType = BodyType;
})();

(function() {
  'use strict';

  var Context = function(baseUriParameters, resource, method) {
    this.headers = new RAML.Services.TryIt.NamedParameters(method.headers.plain, method.headers.parameterized);
    this.queryParameters = new RAML.Services.TryIt.NamedParameters(method.queryParameters);

    resource.uriParametersForDocumentation = resource.uriParametersForDocumentation || {};

    if (baseUriParameters) {
      Object.keys(baseUriParameters).map(function (key) {
        resource.uriParametersForDocumentation[key] = [baseUriParameters[key]];
      });
    }

    if (Object.keys(resource.uriParametersForDocumentation).length === 0) {
      resource.uriParametersForDocumentation = null;
    }

    this.uriParameters = new RAML.Services.TryIt.NamedParameters(resource.uriParametersForDocumentation);

    if (method.body) {
      this.bodyContent = new RAML.Services.TryIt.BodyContent(method.body);
    }

    this.pathBuilder = new RAML.Client.PathBuilder.create(resource.pathSegments);
    this.pathBuilder.baseUriContext = {};
    this.pathBuilder.segmentContexts = resource.pathSegments.map(function() {
      return {};
    });
  };

  Context.prototype.merge = function(oldContext) {
    this.headers.copyFrom(oldContext.headers);
    this.queryParameters.copyFrom(oldContext.queryParameters);
    this.uriParameters.copyFrom(oldContext.uriParameters);
    if (this.bodyContent && oldContext.bodyContent) {
      this.bodyContent.copyFrom(oldContext.bodyContent);
    }

    this.pathBuilder.baseUriContext = oldContext.pathBuilder.baseUriContext;
    this.pathBuilder.segmentContexts = oldContext.pathBuilder.segmentContexts;
  };

  RAML.Services.TryIt.Context = Context;
})();

(function() {
  'use strict';

  var NamedParameter = function(definitions) {
    this.definitions = definitions;
    this.selected = definitions[0].type;
  };

  NamedParameter.prototype.hasMultipleTypes = function() {
    return this.definitions.length > 1;
  };

  NamedParameter.prototype.isSelected = function(definition) {
    return this.selected === definition.type;
  };

  RAML.Services.TryIt.NamedParameter = NamedParameter;
})();

(function() {
  'use strict';

  function copy(object) {
    var shallow = {};
    Object.keys(object || {}).forEach(function(key) {
      shallow[key] = new RAML.Services.TryIt.NamedParameter(object[key]);
    });

    return shallow;
  }

  function filterEmpty(object) {
    var copy = {};

    Object.keys(object).forEach(function(key) {
      var values = object[key].filter(function(value) {
        return value !== undefined && value !== null && (typeof value !== 'string' || value.trim().length > 0);
      });

      if (values.length > 0) {
        copy[key] = values;
      }
    });

    return copy;
  }

  var NamedParameters = function(plain, parameterized) {
    this.plain = copy(plain);
    this.parameterized = parameterized;
    Object.keys(this.plain).forEach(function (key) {
      var data = this.plain[key].definitions[0];

      if (typeof data['enum'] !== 'undefined') {
        if (!data.required) {
          var temp = [''];
          data['enum'] = temp.concat(data['enum']);
        }
      }

      if (key.charAt(0) === '$') {
        var tempKey = '&#36;' + key.substring(1);
        this.plain[tempKey] = this.plain[key];
      }
    }.bind(this));

    Object.keys(parameterized || {}).forEach(function(key) {
      parameterized[key].created = [];
    });

    this.values = {};
    Object.keys(this.plain).forEach(function(key) {
      this.values[key] = [undefined];
    }.bind(this));
  };

  NamedParameters.prototype.clear = function (info) {
    var that = this;
    Object.keys(this.values).map(function (key) {
      if (typeof info[key][0]['enum'] === 'undefined' || info[key][0].overwritten === true) {
        that.values[key] = [''];
      }
    });
  };

  NamedParameters.prototype.reset = function (info, field) {
    var that = this;
    if (info) {
      Object.keys(info).map(function (key) {
        if (typeof field === 'undefined' || field === key) {
          if (typeof info[key][0]['enum'] === 'undefined') {
            if (info[key][0].type === 'date' && typeof info[key][0].example === 'object') {
              info[key][0].example = info[key][0].example.toUTCString();
            }

            if (info[key][0].example) {
              that.values[key][0] = info[key][0].example;
            } else if (info[key][0].examples && info[key][0].examples[0] && info[key][0].examples[0].value) {
              that.values[key][0] = info[key][0].examples[0].value;
            }
          }
        }
      });
    }
  };

  NamedParameters.prototype.create = function(name, value) {
    var parameters = this.parameterized[name];

    var definition = parameters.map(function(parameterizedHeader) {
      return parameterizedHeader.create(value);
    });

    var parameterizedName = definition[0].displayName;

    parameters.created.push(parameterizedName);
    this.plain[parameterizedName] = new RAML.Services.TryIt.NamedParameter(definition);
    this.values[parameterizedName] = [undefined];
  };

  NamedParameters.prototype.remove = function(name) {
    delete this.plain[name];
    delete this.values[name];
    return;
  };

  NamedParameters.prototype.data = function() {
    return filterEmpty(this.values);
  };

  NamedParameters.prototype.copyFrom = function(oldParameters) {
    var parameters = this;

    Object.keys(oldParameters.parameterized || {}).forEach(function(key) {
      if (parameters.parameterized[key]) {
        oldParameters.parameterized[key].created.forEach(function(createdParam) {
          parameters.plain[createdParam] = oldParameters.plain[createdParam];
        });
      }
    });

    var keys = Object.keys(oldParameters.plain || {}).filter(function(key) {
      return parameters.plain[key];
    });

    keys.forEach(function(key) {
      parameters.values[key] = oldParameters.values[key];
    });
  };

  RAML.Services.TryIt.NamedParameters = NamedParameters;
})();

(function() {
  'use strict';

  function Clone() {}

  RAML.Utils = {
    clone: function(object) {
      Clone.prototype = object;
      return new Clone();
    },

    copy: function(object) {
      var copiedObject = {};
      for (var key in object) {
        copiedObject[key] = object[key];
      }
      return copiedObject;
    },

    isEmpty: function(object) {
      if (object) {
        return Object.keys(object).length === 0;
      } else {
        return true;
      }
    },

    filterEmpty: function (object) {
      var copy = {};

      Object.keys(object).forEach(function(key) {
        var value = object[key];
        var flag = value !== undefined && value !== null && (typeof value !== 'string' || value.trim().length > 0);

        if (flag) {
          copy[key] = value;
        }
      });

      return copy;
    }
  };
})();

(function (root) {
  var _hasOwnProperty = Object.prototype.hasOwnProperty;
  var btoa            = typeof Buffer === 'function' ? bufferBtoa : root.btoa;

  /**
   * Format error response types to regular strings for displaying to clients.
   *
   * Reference: http://tools.ietf.org/html/rfc6749#section-4.1.2.1
   *
   * @type {Object}
   */
  var ERROR_RESPONSES = {
    'invalid_request': [
      'The request is missing a required parameter, includes an',
      'invalid parameter value, includes a parameter more than',
      'once, or is otherwise malformed.'
    ].join(' '),
    'invalid_client': [
      'Client authentication failed (e.g., unknown client, no',
      'client authentication included, or unsupported',
      'authentication method).'
    ].join(' '),
    'invalid_grant': [
      'The provided authorization grant (e.g., authorization',
      'code, resource owner credentials) or refresh token is',
      'invalid, expired, revoked, does not match the redirection',
      'URI used in the authorization request, or was issued to',
      'another client.'
    ].join(' '),
    'unauthorized_client': [
      'The client is not authorized to request an authorization',
      'code using this method.'
    ].join(' '),
    'unsupported_grant_type': [
      'The authorization grant type is not supported by the',
      'authorization server.'
    ].join(' '),
    'access_denied': [
      'The resource owner or authorization server denied the request.'
    ].join(' '),
    'unsupported_response_type': [
      'The authorization server does not support obtaining',
      'an authorization code using this method.'
    ].join(' '),
    'invalid_scope': [
      'The requested scope is invalid, unknown, or malformed.'
    ].join(' '),
    'server_error': [
      'The authorization server encountered an unexpected',
      'condition that prevented it from fulfilling the request.',
      '(This error code is needed because a 500 Internal Server',
      'Error HTTP status code cannot be returned to the client',
      'via an HTTP redirect.)'
    ].join(' '),
    'temporarily_unavailable': [
      'The authorization server is currently unable to handle',
      'the request due to a temporary overloading or maintenance',
      'of the server.'
    ].join(' ')
  };

  /**
   * Iterate over a source object and copy properties to the destination object.
   *
   * @param  {Object} dest
   * @param  {Object} source
   * @return {Object}
   */
  function assign (dest /*, ...source */) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (_hasOwnProperty.call(source, key)) {
          dest[key] = source[key];
        }
      }
    }

    return dest;
  }

  /**
   * Support base64 in node like how it works in the browser.
   *
   * @param  {String} string
   * @return {String}
   */
  function bufferBtoa (string) {
    return new Buffer(string).toString('base64');
  }

  /**
   * Check if properties exist on an object and throw when they aren't.
   *
   * @throws {TypeError} If an expected property is missing.
   *
   * @param {Object} obj
   * @param {Array}  props
   */
  function expects (obj, props) {
    for (var i = 0; i < props.length; i++) {
      var prop = props[i];
    }
  }

  /**
   * Create a new object based on a source object with keys omitted.
   *
   * @param  {Object} source
   * @param  {Array}  keys
   * @return {Object}
   */
  function omit (source, keys) {
    var obj = {};

    // Iterate over the source object and set properties on a new object.
    Object.keys(source || {}).forEach(function (key) {
      if (keys.indexOf(key) === -1) {
        obj[key] = source[key];
      }
    });

    return obj;
  }

  /**
   * Attempt (and fix) URI component encoding.
   *
   * @param  {String} str
   * @return {String}
   */
  function encodeComponent (str) {
    return encodeURIComponent(str)
      .replace(/[!'()]/g, root.escape)
      .replace(/\*/g, '%2A');
  }

  /**
   * Attempt URI component decoding.
   *
   * @param  {String} str
   * @return {String}
   */
  function decodeComponent (str) {
    return decodeURIComponent(str);
  }

  /**
   * Convert an object into a query string.
   *
   * @param  {Object} obj
   * @param  {String} sep
   * @param  {String} eq
   * @return {String}
   */
  function uriEncode (obj, sep, eq) {
    var params = [];

    eq  = eq  || '=';
    sep = sep || '&';

    Object.keys(obj).forEach(function (key) {
      var value  = obj[key];
      var keyStr = encodeComponent(key) + eq;

      if (Array.isArray(value)) {
        for (var i = 0; i < value.length; i++) {
          params.push(keyStr + encodeComponent(value[i]));
        }
      } else if (value != null) {
        params.push(keyStr + encodeComponent(value));
      }
    });

    return params.join(sep);
  }

  /**
   * Convert a query string into an object.
   *
   * @param  {String} qs
   * @param  {String} sep
   * @param  {String} eq
   * @return {Object}
   */
  function uriDecode (qs, sep, eq) {
    eq  = eq  || '=';
    sep = sep || '&';
    qs  = qs.split(sep);

    var obj     = {};
    var maxKeys = 1000;
    var len     = qs.length > maxKeys ? maxKeys : qs.length;

    for (var i = 0; i < len; i++) {
      var key   = qs[i].replace(/\+/g, '%20');
      var value = '';
      var index = key.indexOf(eq);

      if (index !== -1) {
        value = key.substr(index + 1);
        key   = key.substr(0, index);
      }

      key   = decodeComponent(key);
      value = decodeComponent(value);

      if (!_hasOwnProperty.call(obj, key)) {
        obj[key] = value;
      } else if (Array.isArray(obj[key])) {
        obj[key].push(value);
      } else {
        obj[key] = [obj[key], value];
      }
    }

    return obj;
  }

  /**
   * Pull an authentication error from the response data.
   *
   * @param  {Object} data
   * @return {String}
   */
  function getAuthError (data) {
    var message = ERROR_RESPONSES[data.error] ||
      data.error ||
      data.error_message;

    // Return an error instance with the message if it exists.
    return message && new Error(message);
  }

  /**
   * Retrieve all the HTTP response headers for an XMLHttpRequest instance.
   *
   * @param  {XMLHttpRequest} xhr
   * @return {Object}
   */
  function getAllReponseHeaders (xhr) {
    var headers = {};

    // Split all header lines and iterate.
    xhr.getAllResponseHeaders().split('\n').forEach(function (header) {
      var index = header.indexOf(':');

      if (index === -1) {
        return;
      }

      var name  = header.substr(0, index).toLowerCase();
      var value = header.substr(index + 1).trim();

      headers[name] = value;
    });

    return headers;
  }

  /**
   * Retrieve body request with valid format depending content type
   *
   * @param {Mixed} data
   * @param {String} contentType
   * @return {Mixed}
   */
  function getBodyRequest(data, contentType) {
    if (contentType === 'application/x-www-form-urlencoded' && typeof data === 'object') {
      return uriEncode(data);
    }
    return data;
  }

  /**
   * Sanitize the scopes option to be a string.
   *
   * @param  {Array}  scopes
   * @return {String}
   */
  function sanitizeScope (scopes) {
    if (!Array.isArray(scopes)) {
      return scopes == null ? null : String(scopes);
    }

    return scopes.join(' ');
  }

  /**
   * Construct an object that can handle the multiple OAuth 2.0 flows.
   *
   * @param {Object} options
   */
  function ClientOAuth2 (options) {
    this.options = options;

    this.code        = this['authorization_code'] = new CodeFlow(this);
    this.token       = this.implicit              = new TokenFlow(this);
    this.owner       = this.password              = new OwnerFlow(this);
    this.credentials = this['client_credentials'] = new CredentialsFlow(this);
  }

  /**
   * Alias the token constructor.
   *
   * @type {Function}
   */
  ClientOAuth2.Token = ClientOAuth2Token;

  /**
   * Create a new token from existing data.
   *
   * @param  {String} access
   * @param  {String} [refresh]
   * @param  {String} [type]
   * @param  {Object} [data]
   * @return {Object}
   */
  ClientOAuth2.prototype.createToken = function (access, refresh, type, data) {
    return new ClientOAuth2Token(this, assign({}, data, {
      access_token:  access,
      refresh_token: refresh,
      token_type:    type
    }));
  };

  /**
   * Using the built-in request method, we'll automatically attempt to parse
   * the response.
   *
   * @param {Object}   options
   * @param {Function} done
   */
  ClientOAuth2.prototype._request = function (options, done) {
    return this.request(options, function (err, res) {
      if (err) {
        return done(err);
      }

      // Check the response status and fail.
      if (res.status && Math.floor(res.status / 100) !== 2) {
        err = new Error('HTTP Status ' + res.status);
        err.status = res.status;

        return done(err);
      }

      // Support already parsed responses in case of custom body parsing.
      if (typeof res.body !== 'string') {
        return done(null, res.body);
      }

      // Attempt to parse as JSON, falling back to parsing as a query string.
      try {
        done(null, JSON.parse(res.body), res.raw);
      } catch (e) {
        done(null, uriDecode(res.body), res.raw);
      }
    });
  };

  if (typeof window !== 'undefined') {
    /**
     * Make a HTTP request using XMLHttpRequest.
     *
     * @param {Object}   options
     * @param {Function} done
     */
    ClientOAuth2.prototype.request = function (options, done) {
      var xhr     = new root.XMLHttpRequest();
      var headers = options.headers || {};
      var body = getBodyRequest(options.data, options.contentType);

      // Open the request to the url and method.
      xhr.open(options.method, options.url);

      // When the request has loaded, attempt to automatically parse the body.
      xhr.onload = function () {
        return done(null, {
          raw:     xhr,
          status:  xhr.status,
          headers: getAllReponseHeaders(xhr),
          body:    xhr.responseText
        });
      };

      // Catch request errors.
      xhr.onerror = xhr.onabort = function () {
        return done(new Error(xhr.statusText || 'XHR aborted'));
      };

      // Set all request headers.
      Object.keys(headers).forEach(function (header) {
        xhr.setRequestHeader(header, headers[header]);
      });

      // Make the request with the body.
      xhr.send(body);
    };
  } else {
    var url   = require('url');
    var http  = require('http');
    var https = require('https');

    /**
     * Make a request using the built-in node http library.
     *
     * @param {Object}   options
     * @param {Function} done
     */
    ClientOAuth2.prototype.request = function (options, done) {
      var lib        = http;
      var reqOptions = url.parse(options.url);

      // If the protocol is over https, switch request library.
      if (reqOptions.protocol === 'https:') {
        lib = https;
      }

      // Alias request options.
      reqOptions.method  = options.method;
      reqOptions.headers = options.headers;

      // Send the http request and listen for the response to finish.
      var req = lib.request(reqOptions, function (res) {
        var data = '';

        // Callback to `done` if a response error occurs.
        res.on('error', done);

        // Concat all the data chunks into a string.
        res.on('data', function (chunk) {
          data += chunk;
        });

        // When the response is finished, attempt to parse the data string.
        res.on('end', function () {
          return done(null, {
            raw:     res,
            status:  res.statusCode,
            headers: res.headers,
            body:    data
          });
        });
      });

      // Callback to `done` if a request error occurs.
      req.on('error', done);

      // Send the body and make the request.
      req.write(options.body);
      req.end();
    };
  }

  /**
   * General purpose client token generator.
   *
   * @param {Object} client
   * @param {Object} data
   */
  function ClientOAuth2Token (client, data) {
    this.client = client;

    this.data = omit(data, [
      'access_token', 'refresh_token', 'token_type', 'expires_in', 'scope',
      'state', 'error', 'error_description', 'error_uri'
    ]);

    this.tokenType    = (data.token_type || 'bearer').toLowerCase();
    this.accessToken  = data.access_token;
    this.refreshToken = data.refresh_token;

    // Set the expiration date.
    if (data.expires_in) {
      this.expires = new Date();

      this.expires.setSeconds(this.expires.getSeconds() + data.expires_in);
    }
  }

  /**
   * Sign a standardised request object with user authentication information.
   *
   * @param  {Object} options
   * @return {Object}
   */
  ClientOAuth2Token.prototype.sign = function (options) {
    if (!this.accessToken) {
      throw new Error('Unable to sign without access token');
    }

    options.headers = options.headers || {};

    if (this.tokenType === 'bearer') {
      options.headers.Authorization = 'Bearer ' + this.accessToken;
    } else {
      var parts    = options.url.split('#');
      var token    = 'access_token=' + this.accessToken;
      var url      = parts[0].replace(/[?&]access_token=[^&#]/, '');
      var fragment = parts[1] ? '#' + parts[1] : '';

      // Prepend the correct query string parameter to the url.
      options.url = url + (url.indexOf('?') > -1 ? '&' : '?') + token + fragment;

      // Attempt to avoid storing the url in proxies, since the access token
      // is exposed in the query parameters.
      options.headers.Pragma           = 'no-store';
      options.headers['Cache-Control'] = 'no-store';
    }

    return options;
  };

  /**
   * Make a HTTP request as the user.
   *
   * @param {Object}   options
   * @param {Function} done
   */
  ClientOAuth2Token.prototype.request = function (options, done) {
    return this.client.client.request(this.sign(options), done);
  };

  /**
   * Refresh a user access token with the supplied token.
   *
   * @param {Function} done
   */
  ClientOAuth2Token.prototype.refresh = function (done) {
    var self    = this;
    var options = this.client.options;

    if (!this.refreshToken) {
      return done(new Error('No refresh token set'));
    }

    var authorization = btoa(options.clientId + ':' + options.clientSecret);

    return this.client._request({
      url: options.accessTokenUri,
      method: 'POST',
      headers: {
        'Accept':        'application/json, application/x-www-form-urlencoded',
        'Content-Type':  'application/x-www-form-urlencoded',
        'Authorization': 'Basic ' + authorization
      },
      data: uriEncode({
        refresh_token: this.refreshToken,
        grant_type:    'refresh_token'
      })
    }, function (err, data) {
      // If an error exists or the data contains an error, return `done`.
      if (err || (err = getAuthError(data))) {
        return done(err);
      }

      // Update stored tokens on the current instance.
      self.accessToken  = data.access_token;
      self.refreshToken = data.refresh_token;

      return done(null, self);
    });
  };

  /**
   * Check whether the token has expired.
   *
   * @return {Boolean}
   */
  ClientOAuth2Token.prototype.expired = function () {
    if (this.expires) {
      return Date.now() < this.expires.getTime();
    }

    return false;
  };

  /**
   * Support resource owner password credentials OAuth 2.0 grant.
   *
   * Reference: http://tools.ietf.org/html/rfc6749#section-4.3
   *
   * @param {ClientOAuth2} client
   */
  function OwnerFlow (client) {
    this.client = client;
  }

  /**
   * Make a request on behalf of the user credentials to get an acces token.
   *
   * @param {String}   username
   * @param {String}   password
   * @param {Function} done
   */
  OwnerFlow.prototype.getToken = function (username, password, done) {
    var self          = this;
    var options       = this.client.options;
    var authorization = btoa(options.clientId + ':' + options.clientSecret);

    return this.client._request({
      url: options.accessTokenUri,
      method: 'POST',
      headers: {
        'Accept':        'application/json, application/x-www-form-urlencoded',
        'Content-Type':  'application/x-www-form-urlencoded',
        'Authorization': 'Basic ' + authorization
      },
      data: uriEncode({
        scope:      sanitizeScope(options.scopes),
        username:   username,
        password:   password,
        grant_type: 'password'
      })
    }, function (err, data) {
      // If an error exists or the data contains an error, return `done`.
      if (err || (err = getAuthError(data))) {
        return done(err);
      }

      return done(null, new ClientOAuth2Token(self, data));
    });
  };

  /**
   * Support implicit OAuth 2.0 grant.
   *
   * Reference: http://tools.ietf.org/html/rfc6749#section-4.2
   *
   * @param {ClientOAuth2} client
   */
  function TokenFlow (client) {
    this.client = client;
  }

  /**
   * Get the uri to redirect the user to for implicit authentication.
   *
   * @param  {Object} options
   * @return {String}
   */
  TokenFlow.prototype.getUri = function (options) {
    options = assign({}, this.client.options, options);

    // Check the parameters have been set.
    expects(options, [
      'clientId',
      'redirectUri',
      'authorizationUri'
    ]);

    return options.authorizationUri + '?' + uriEncode({
      state:         options.state,
      scope:         sanitizeScope(options.scopes),
      client_id:     options.clientId,
      redirect_uri:  options.redirectUri,
      response_type: 'token'
    });
  };

  /**
   * Get the user access token from the url.
   *
   * @param {String}   url
   * @param {String}   [state]
   * @param {Function} done
   */
  TokenFlow.prototype.getToken = function (url, state, done) {
    var options = this.client.options;
    var err;

    // State is an optional pass in.
    if (typeof state === 'function') {
      done  = state;
      state = null;
    }

    // Make sure the url matches our expected redirect url.
    if (url.substr(0, options.redirectUri.length) !== options.redirectUri) {
      return done(new Error('Invalid url (should to match redirect): ' + url));
    }

    var queryString    = url.replace(/^[^\?]*|\#.*$/g, '').substr(1);
    var fragmentString = url.replace(/^[^\#]*/, '').substr(1);

    // Check whether a query string is present in the url.
    if (!queryString && !fragmentString) {
      return done(new Error('Unable to process url: ' + url));
    }

    // Merge the fragment with the the query string. This is because, at least,
    // Instagram has a bug where the OAuth 2.0 state is being passed back as
    // part of the query string instead of the fragment. For example:
    // "?state=123#access_token=abc"
    var data = assign(
      queryString ? uriDecode(queryString) : {},
      fragmentString ? uriDecode(fragmentString) : {}
    );

    // Check if the query string was populated with a known error.
    if (err = getAuthError(data)) {
      return done(err);
    }

    // Check whether the state is correct.
    if (state && data.state !== state) {
      return done(new Error('Invalid state:' + data.state));
    }

    // Initalize a new token and return.
    return done(null, new ClientOAuth2Token(this, data));
  };

  /**
   * Support client credentials OAuth 2.0 grant.
   *
   * Reference: http://tools.ietf.org/html/rfc6749#section-4.4
   *
   * @param {ClientOAuth2} client
   */
  function CredentialsFlow (client) {
    this.client = client;
  }

  /**
   * Request an access token using the client credentials.
   *
   * @param {Object}   [options]
   * @param {Function} done
   */
  CredentialsFlow.prototype.getToken = function (options, done) {
    var self = this;

    // Allow the options argument to be omitted.
    if (typeof options === 'function') {
      done = options;
      options = null;
    }

    options = assign({}, this.client.options, options);

    expects(options, [
      'clientId',
      'clientSecret',
      'accessTokenUri'
    ]);

    // Base64 encode the client id and secret for the Authorization header.
    var authorization = btoa(options.clientId + ':' + options.clientSecret);

    return this.client._request({
      url: options.accessTokenUri,
      method: 'POST',
      headers: {
        'Accept':        'application/json, application/x-www-form-urlencoded',
        'Content-Type':  'application/x-www-form-urlencoded',
        'Authorization': 'Basic ' + authorization
      },
      data: uriEncode({
        scope:      sanitizeScope(options.scopes),
        grant_type: 'client_credentials'
      })
    }, function (err, data) {
      // If an error exists or the data contains an error, return `done`.
      if (err || (err = getAuthError(data))) {
        return done(err);
      }

      return done(null, new ClientOAuth2Token(self, data));
    });
  };

  /**
   * Support authorization code OAuth 2.0 grant.
   *
   * Reference: http://tools.ietf.org/html/rfc6749#section-4.1
   *
   * @param {ClientOAuth2} client
   */
  function CodeFlow (client) {
    this.client = client;
  }

  /**
   * Generate the uri for doing the first redirect.
   *
   * @return {String}
   */
  CodeFlow.prototype.getUri = function (options) {
    options = assign({}, this.client.options, options);

    // Check the parameters have been set.
    expects(options, [
      'clientId',
      'redirectUri',
      'authorizationUri'
    ]);

    return options.authorizationUri + '?' + uriEncode({
      state:         options.state,
      scope:         sanitizeScope(options.scopes),
      client_id:     options.clientId,
      redirect_uri:  options.redirectUri,
      response_type: 'code'
    });
  };

  /**
   * Get the code token from the redirected uri and make another request for
   * the user access token.
   *
   * @param {String}   url
   * @param {String}   [state]
   * @param {Function} done
   */
  CodeFlow.prototype.getToken = function (url, state, done) {
    var self    = this;
    var options = this.client.options;
    var err;

    // State is an optional pass in.
    if (typeof state === 'function') {
      done  = state;
      state = null;
    }

    expects(options, [
      'clientId',
      'clientSecret',
      'redirectUri',
      'accessTokenUri'
    ]);

    // Make sure the url matches our expected redirect url.
    if (url.substr(0, options.redirectUri.length) !== options.redirectUri) {
      return done(new Error('Invalid url (should to match redirect): ' + url));
    }

    // Extract the query string from the url.
    var queryString = url.replace(/^[^\?]*|\#.*$/g, '').substr(1);

    // Check whether a query string is present in the url.
    if (!queryString) {
      return done(new Error('Unable to process url: ' + url));
    }

    var query = uriDecode(queryString);

    // Check if the query string was populated with a known error.
    if (err = getAuthError(query)) {
      return done(err);
    }

    // Check whether the state is correct.
    if (state && query.state !== state) {
      return done(new Error('Invalid state:' + query.state));
    }

    // Check whether the response code is set.
    if (!query.code) {
      return done(new Error('Missing code, unable to request token'));
    }

    return this.client._request({
      url: options.accessTokenUri,
      method: 'POST',
      headers: {
        'Accept':       'application/json, application/x-www-form-urlencoded',
        'Content-Type': 'application/x-www-form-urlencoded'
      },
      data: uriEncode({
        code:          query.code,
        grant_type:    'authorization_code',
        redirect_uri:  options.redirectUri,
        client_id:     options.clientId,
        client_secret: options.clientSecret
      })
    }, function (err, data, raw) {
      // If an error exists or the data contains an error, return `done`.
      if (err || (err = getAuthError(data))) {
        return done(err, null, raw);
      }

      return done(null, new ClientOAuth2Token(self, data), raw);
    });
  };

  /**
   * Export the OAuth2 client for multiple environments.
   */
  if (typeof define === 'function' && define.amd) {
    define([], function () {
      return ClientOAuth2;
    });
  } else if (typeof exports === 'object') {
    module.exports = ClientOAuth2;
  } else {
    root.ClientOAuth2 = ClientOAuth2;
  }
})(this);

(function (root) {
  /**
   * Check if a value is empty.
   *
   * @param  {*}       value
   * @return {Boolean}
   */
  var isEmpty = function (value) {
    return value == null;
  };

  /**
   * Convert a value into a boolean.
   *
   * @param  {String}  value
   * @return {Boolean}
   */
  var toBoolean = function (value) {
    return [0, false, '', '0', 'false'].indexOf(value) === -1;
  };

  /**
   * Convert a value into a number. Non-number strings and infinite values will
   * sanitize into `NaN`.
   *
   * @param  {String} value
   * @return {Number}
   */
  var toNumber = function (value) {
    return isFinite(value) ? Number(value) : null;
  };

  /**
   * Convert a value into an integer. Use strict sanitization - if something is
   * not an integer, return `NaN`.
   *
   * @param  {String} value
   * @return {Number}
   */
  var toInteger = function (value) {
    return value % 1 === 0 ? Number(value) : null;
  };

  /**
   * Convert a value into a date.
   *
   * @param  {String} value
   * @return {Date}
   */
  var toDate = function (value) {
    return !isNaN(Date.parse(value)) ? new Date(value) : null;
  };

  /**
   * Returns the passed value unchanged.
   */
  var returnValue = function (value) {
    return value;
  }

  var toUnion = function (value, key, object, configs) {
    var any = null;
    configs.forEach(function (config) {
      config.unionTypes.forEach(function (type) {
        any = any || TYPES[type](value, key, object, configs);
      });
    });

    return any;
  }

  function isNativeType(typeName) {
    typeName = typeName.replace('[]', '');
    var nativeTypes = [
      'object',
      'string',
      'number',
      'integer',
      'boolean',
      'date-only',
      'time-only',
      'datetime-only',
      'datetime',
      'file',
      'array'
    ];
    return nativeTypes.indexOf(typeName) !== -1;
  }

  function convertType(config) {
    var newConfig = {};
    // Clone config object.
    Object.keys(config).forEach(function (key) {
      newConfig[key] = config[key];
    });

    if (Array.isArray(newConfig.type)) {
      newConfig.type = newConfig.type.map(function (aType) {
        var newType = aType.replace('[]', '');
        var parts = aType.split('|');
        if (parts.length > 1) {
          newType = 'union';
          newConfig.unionTypes = parts.map(function (part) {
            part = part.trim();
            return !isNativeType(part) ? 'object' : part;
          });
        } else {
          newType = !isNativeType(newType) ? 'object' : newType;
        }
        return newType;
      });
    }
    return newConfig;
  }

  /**
   * Convert the schema config into a single sanitization function.
   *
   * @param  {Object}   configs
   * @param  {Object}   rules
   * @param  {Object}   types
   * @return {Function}
   */
  var toSanitization = function (configs, rules, types) {
    configs = Array.isArray(configs) ? configs : [configs];

    // Map configurations into function sanitization chains.
    var sanitizations = configs.map(function (config) {
      var fns = [];

      // Push type sanitization first.
      if (typeof types[config.type] === 'function') {
        fns.push(types[config.type]);
      }

      // Iterate over the schema configuration and push sanitization functions
      // into the sanitization array.
      Object.keys(config).filter(function (rule) {
        return rule !== 'type' && rule !== 'repeat' && rule !== 'default';
      }).forEach(function (rule) {
        if (typeof rules[rule] === 'function') {
          fns.push(rules[rule](config[rule], rule, config));
        }
      });

      /**
       * Sanitize a single value using the function chain. Breaks when any value
       * returns an empty value (`null` or `undefined`).
       *
       * @param  {*}      value
       * @param  {String} key
       * @param  {Object} object
       * @return {*}
       */
      var sanitize = function (value, key, object) {
        // Iterate over each sanitization function and return a single value.
        fns.every(function (fn) {
          value = fn(value, key, object, configs);

          // Break when the value returns `null`.
          return value != null;
        });

        return value;
      };

      /**
       * Do the entire sanitization flow using the current config.
       *
       * @param  {*}      value
       * @param  {String} key
       * @param  {Object} object
       * @return {*}
       */
      return function sanitization (value, key, object) {
        // Immediately return empty values with attempting to sanitize.
        if (isEmpty(value)) {
          // Fallback to providing the default value instead.
          if (config["default"] != null) {
            return sanitization(config["default"], key, object);
          }

          // Return an empty array for repeatable values.
          return config.repeat && !config.required ? [] : value;
        }

        // Support repeated parameters as arrays.
        if (config.repeat) {
          // Turn the result into an array
          if (!Array.isArray(value)) {
            value = [value];
          }

          // Map every value to be sanitized into a new array.
          value = value.map(function (value) {
            return sanitize(value, key, object);
          });

          // If any of the values are empty, refuse the sanitization.
          return value.some(isEmpty) ? null : value;
        }

        return sanitize(value, key, object);
      };
    });

    /**
     * Pass in a value to be sanitized.
     *
     * @param  {*}      value
     * @param  {String} key
     * @param  {Object} object
     * @return {*}
     */
    return function (value, key, object) {
      var result = value;

      // Iterate over each sanitization until one is not empty.
      sanitizations.some(function (sanitization) {
        var sanitized = sanitization(value, key, object);

        // If the value was accepted and sanitized, return it.
        if (sanitized != null) {
          // Assign the sanitized value to the result.
          result = sanitized;

          return true;
        }

        return false;
      });

      return result;
    };
  };

  var TYPES = {
    string:          String,
    number:          toNumber,
    integer:         toInteger,
    'boolean':       toBoolean,
    date:            toDate,
    'date-only':     toDate,
    'time-only':     toDate,
    'datetime-only': toDate,
    'datetime':      toDate,
    object:          returnValue,
    union:           toUnion
  };

  /**
   * Every time the module is exported and executed, we return a new instance.
   *
   * @return {Function}
   */
  RAMLSanitize = function () {
    /**
     * Return a sanitization function based on the passed in schema.
     *
     * @param  {Object}   schema
     * @return {Function}
     */
    var sanitize = function (schema) {
      var sanitizations = {};

      // Map each parameter in the schema to a validation function.
      Object.keys(schema).forEach(function (param) {
        var config = convertType(schema[param]);
        var types  = sanitize.TYPES;
        var rules  = sanitize.RULES;

        sanitizations[param] = toSanitization(config, rules, types);
      });

      /**
       * Execute the returned function with a model to return a sanitized object.
       *
       * @param  {Object} model
       * @return {Object}
       */
      return function (model) {
        model = model || {};

        // Create a new model instance to be sanitized without any additional
        // properties or overrides occuring.
        var sanitized = {};

        // Iterate only the sanitized parameters to get a clean model.
        Object.keys(sanitizations).forEach(function (param) {
          var value    = model[param];
          var sanitize = sanitizations[param];

          // Ensure the value is a direct property on the model object before
          // sanitizing. The keeps model handling in sync with expectations.
          if (Object.prototype.hasOwnProperty.call(model, param)) {
            sanitized[param] = sanitize(value, param, model);
          }
        });

        return sanitized;
      };
    };

    /**
     * Provide sanitization based on types.
     *
     * @type {Object}
     */
    sanitize.TYPES = TYPES;

    /**
     * Provide sanitization based on rules.
     *
     * @type {Object}
     */
    sanitize.RULES = {};

    return sanitize;
  };

  /**
   * Export the raml-sanitize for multiple environments.
   */
  if (typeof define === 'function' && define.amd) {
    define([], function () {
      return RAMLSanitize;
    });
  } else if (typeof exports === 'object') {
    module.exports = RAMLSanitize;
  } else {
    root.RAMLSanitize = RAMLSanitize;
  }
})(this);

(function (root) {
  /**
   * `Object.prototype.toString` as a function.
   *
   * @type {Function}
   */
  var toString = Function.prototype.call.bind(Object.prototype.toString);

  /**
   * Check the value is a valid date.
   *
   * @param  {Date}    check
   * @return {Boolean}
   */
  var isDate = function (check) {
    return toString(check) === '[object Date]' && !isNaN(check.getTime());
  };

  /**
   * Check if the value is a boolean.
   *
   * @param  {Boolean}  check
   * @return {Boolean}
   */
  var isBoolean = function (check) {
    return typeof check === 'boolean';
  };

  /**
   * Check the value is a string.
   *
   * @param  {String}  check
   * @return {Boolean}
   */
  var isString = function (check) {
    return typeof check === 'string';
  };

  /**
   * Check if the value is an integer.
   *
   * @param  {Number}  check
   * @return {Boolean}
   */
  var isInteger = function (check) {
    return typeof check === 'number' && check % 1 === 0;
  };

  /**
   * Check if the value is a number.
   *
   * @param  {Number}  check
   * @return {Boolean}
   */
  var isNumber = function (check) {
    return typeof check === 'number' && isFinite(check);
  };

  /**
   * Check if the value is a JSON string.
   *
   * @param  {String}  check
   * @return {Boolean}
   */
  var isJSON = function (check) {
    try {
      JSON.parse(check);
      return true;
    } catch(e) {
      return false;
    }
  };

  var isUnion = function (check, key, object, configs) {
    var any = false;
    configs.forEach(function (config) {
      config.unionTypes.forEach(function (type) {
        any = any || TYPES[type](check, key, object, configs);
      });
    });

    return any;
  };

  /**
   * Check a number is not smaller than the minimum.
   *
   * @param  {Number}   min
   * @return {Function}
   */
  var isMinimum = function (min) {
    return function (check) {
      return check >= min;
    };
  };

  /**
   * Check a number doesn't exceed the maximum.
   *
   * @param  {Number}  max
   * @return {Boolean}
   */
  var isMaximum = function (max) {
    return function (check) {
      return check <= max;
    };
  };

  /**
   * Check a string is not smaller than a minimum length.
   *
   * @param  {Number}  min
   * @return {Boolean}
   */
  var isMinimumLength = function (min) {
    return function (check) {
      return check.length >= min;
    };
  };

  /**
   * Check a string does not exceed a maximum length.
   *
   * @param  {Number}  max
   * @return {Boolean}
   */
  var isMaximumLength = function (max) {
    return function (check) {
      return check.length <= max;
    };
  };

  /**
   * Check a value is equal to anything in an array.
   *
   * @param  {Array}    values
   * @return {Function}
   */
  var isEnum = function (values) {
    return function (check) {
      return values.indexOf(check) > -1;
    };
  };

  /**
   * Check if a pattern matches the value.
   *
   * @param  {(String|RegExp)} pattern
   * @return {Function}
   */
  var isPattern = function (pattern) {
    if (toString(pattern) !== '[object RegExp]') {
      pattern = new RegExp(pattern);
    }

    return pattern.test.bind(pattern);
  };

  /**
   * Convert arguments into an object.
   *
   * @param  {Boolean} valid
   * @param  {String}  rule
   * @param  {*}       value
   * @param  {String}  key
   * @return {Object}
   */
  var toValidationObject = function (valid, rule, value, key) {
    return { valid: valid, rule: rule, value: value, key: key };
  };

  /**
   * Convert a single config into a function.
   *
   * @param  {Object}   config
   * @param  {Object}   rules
   * @return {Function}
   */
  var toValidationFunction = function (config, rules) {
    var fns = [];

    // Iterate over all of the keys and dynamically push validation rules.
    Object.keys(config).forEach(function (rule) {
      if (rules.hasOwnProperty(rule)) {
        fns.push([rule, rules[rule](config[rule], rule)]);
      }
    });

    /**
     * Run every validation that has been attached.
     *
     * @param  {String} value
     * @param  {String} value
     * @param  {Object} object
     * @return {Object}
     */
    return function (value, key, object) {
      // Run each of the validations returning early when something fails.
      for (var i = 0; i < fns.length; i++) {
        var valid = fns[i][1](value, key, object);

        if (!valid) {
          return toValidationObject(false, fns[i][0], value, key);
        }
      }

      return toValidationObject(true, null, value, key);
    };
  };

  /**
   * Convert a rules object into a simple validation function.
   *
   * @param  {Object}   configs
   * @param  {Object}   rules
   * @param  {Object}   types
   * @return {Function}
   */
  var toValidation = function (configs, rules, types) {
    // Initialize the configs to an array if they aren't already.
    configs = Array.isArray(configs) ? configs : [configs];

    var isOptional        = !configs.length;
    var simpleValidations = [];
    var repeatValidations = [];

    // Support multiple type validations.
    configs.forEach(function (config) {
      var validation = [config.type, toValidationFunction(config, rules)];

      // Allow short-circuiting of non-required values.
      if (!config.required) {
        isOptional = true;
      }

      // Push validations into each stack depending on the "repeat".
      if (config.repeat) {
        repeatValidations.push(validation);
      } else {
        simpleValidations.push(validation);
      }
    });

    /**
     * Validate a value based on "type" and "repeat".
     *
     * @param  {*}      value
     * @param  {String} key
     * @param  {Object} object
     * @return {Object}
     */
    return function (value, key, object) {
      // Short-circuit validation if the value is `null`.
      if (value == null) {
        return toValidationObject(isOptional, 'required', value, key);
      }

      // Switch validation type depending on if the value is an array or not.
      var isArray = Array.isArray(value);

      // Select the validation stack to use based on the (repeated) value.
      var values      = isArray ? value : [value];
      var validations = isArray ? repeatValidations : simpleValidations;

      // Set the initial response to be an error.
      var response = toValidationObject(
        false, validations.length ? 'type' : 'repeat', value, key
      );

      // Iterate over each value and test using type validation.
      validations.some(function (validation) {
        // Non-existant types should always be invalid.
        if (!types.hasOwnProperty(validation[0])) {
          return false;
        }

        // Check all the types match. If they don't, attempt another validation.
        var isType = values.every(function (value) {
          return types[validation[0]](value, key, object, configs);
        });

        // Skip to the next check if not all types match.
        if (!isType) {
          return false;
        }

        // When every value is the correct type, run the validation on each value
        // and break the loop if we get a failure.
        values.every(function (value) {
          return (response = validation[1](value, key, object)).valid;
        });

        // Always break the loop when the type was successful. If anything has
        // failed, `response` will have been set to the invalid object.
        return true;
      });

      return response;
    };
  };

  function isNativeType(typeName) {
    typeName = typeName.replace('[]', '');
    var nativeTypes = [
      'object',
      'string',
      'number',
      'integer',
      'boolean',
      'date-only',
      'time-only',
      'datetime-only',
      'datetime',
      'file',
      'array'
    ];
    return nativeTypes.indexOf(typeName) !== -1;
  }

  function convertType(config) {
    var newConfig = {};
    // Clone config object.
    Object.keys(config).forEach(function (key) {
      newConfig[key] = config[key];
    });

    if (Array.isArray(newConfig.type)) {
      newConfig.type = newConfig.type.map(function (aType) {
        var newType = aType.replace('[]', '');
        var parts = aType.split('|');
        if (parts.length > 1) {
          newType = 'union';
          newConfig.unionTypes = parts.map(function (part) {
            part = part.trim();
            return !isNativeType(part) ? 'object' : part;
          });
        } else {
          newType = !isNativeType(newType) ? 'object' : newType;
        }
        return newType;
      });
    }
    return newConfig;
  }

  var TYPES = {
    date:            isDate,
    'date-only':     isDate,
    'time-only':     isDate,
    'datetime-only': isDate,
    datetime:        isDate,
    number:          isNumber,
    integer:         isInteger,
    'boolean':       isBoolean,
    string:          isString,
    object:          isJSON,
    union:           isUnion
  };

  /**
   * Every time you require the module you're expected to call it as a function
   * to create a new instance. This is to ensure two modules can't make competing
   * changes with their own validation rules.
   *
   * @return {Function}
   */
  RAMLValidate = function () {
    /**
     * Return a validation function that validates a model based on the schema.
     *
     * @param  {Object}   schema
     * @return {Function}
     */
    var validate = function (schema) {
      var validations = {};

      // Convert all parameters into validation functions.
      Object.keys(schema).forEach(function (param) {
        var config = convertType(schema[param]);
        var rules  = validate.RULES;
        var types  = validate.TYPES;

        validations[param] = toValidation(config, rules, types);
      });

      /**
       * The function accepts an object to be validated. All rules are already
       * precompiled.
       *
       * @param  {Object}  model
       * @return {Boolean}
       */
      return function (model) {
        model = model || {};

        // Map all validations to their object and filter for failures.
        var errors = Object.keys(validations).map(function (param) {
          var value      = model[param];
          var validation = validations[param];

          // Return the validation result.
          return validation(value, param, model);
        }).filter(function (validation) {
          return !validation.valid;
        });

        return {
          valid:  errors.length === 0,
          errors: errors
        };
      };
    };

    /**
     * Provide validation of types.
     *
     * @type {Object}
     */
    validate.TYPES = TYPES;

    /**
     * Provide overridable validation of parameters.
     *
     * @type {Object}
     */
    validate.RULES = {
      minimum:   isMinimum,
      maximum:   isMaximum,
      minLength: isMinimumLength,
      maxLength: isMaximumLength,
      'enum':    isEnum,
      pattern:   isPattern
    };

    /**
     * Return the validate function.
     */
    return validate;
  };

  /**
   * Export the raml-validate for multiple environments.
   */
  if (typeof define === 'function' && define.amd) {
    define([], function () {
      return RAMLValidate;
    });
  } else if (typeof exports === 'object') {
    module.exports = RAMLValidate;
  } else {
    root.RAMLValidate = RAMLValidate;
  }
})(this);

angular.module('ramlConsoleApp').run(['$templateCache', function($templateCache) {
  'use strict';

  $templateCache.put('directives/close-button.tpl.html',
    "<button class=\"raml-console-resource-close-btn\" ng-click=\"close($event)\">\n" +
    "  Close\n" +
    "</button>\n"
  );


  $templateCache.put('directives/documentation.tpl.html',
    "<div class=\"raml-console-resource-panel-primary\" ng-if=\"documentationEnabled\">\n" +
    "  <!-- Request -->\n" +
    "  <header class=\"raml-console-resource-header\">\n" +
    "    <h3 class=\"raml-console-resource-head\">\n" +
    "      Request\n" +
    "    </h3>\n" +
    "  </header>\n" +
    "  <div id=\"request-documentation\" class=\"raml-console-resource-panel-primary-row raml-console-resource-panel-content raml-console-is-active\" ng-class=\"{'raml-console-is-active':showRequestDocumentation}\">\n" +
    "    <h3 class=\"raml-console-resource-heading-a\">Description</h3>\n" +
    "\n" +
    "    <p markdown=\"methodInfo.description\" class=\"raml-console-marked-content\"></p>\n" +
    "\n" +
    "    <section class=\"raml-console-resource-section\" id=\"docs-uri-parameters\" ng-if=\"resource.uriParametersForDocumentation\">\n" +
    "      <h3 class=\"raml-console-resource-heading-a\">URI Parameters</h3>\n" +
    "      <properties list=\"resource.uriParametersForDocumentation\" show-examples=\"true\"></properties>\n" +
    "    </section>\n" +
    "\n" +
    "    <section class=\"raml-console-resource-section\" id=\"docs-headers\" ng-if=\"methodInfo.headers.plain\">\n" +
    "      <h3 class=\"raml-console-resource-heading-a\">Headers</h3>\n" +
    "      <properties list=\"methodInfo.headers.plain\" show-examples=\"true\"></properties>\n" +
    "    </section>\n" +
    "\n" +
    "    <section class=\"raml-console-resource-section\" id=\"docs-query-parameters\" ng-if=\"methodInfo.queryParameters\">\n" +
    "      <h3 class=\"raml-console-resource-heading-a\">Query Parameters</h3>\n" +
    "      <properties list=\"methodInfo.queryParameters\" show-examples=\"true\"></properties>\n" +
    "    </section>\n" +
    "\n" +
    "    <section class=\"raml-console-resource-section\" id=\"docs-query-string\" ng-if=\"methodInfo.queryString\">\n" +
    "      <h3 class=\"raml-console-resource-heading-a\">Query String</h3>\n" +
    "      <type-properties type=\"methodInfo.queryString\"></type-properties>\n" +
    "    </section>\n" +
    "\n" +
    "    <section class=\"raml-console-resource-section raml-console-documentation-schemes\">\n" +
    "      <h3 class=\"raml-console-resource-heading-a\">Security Schemes</h3>\n" +
    "      <ol class=\"raml-console-documentation-security-scheme\">\n" +
    "        <li class=\"raml-console-documentation-scheme\" ng-class=\"{'raml-console-is-active':isSchemeSelected(value)}\" ng-click=\"selectDocumentationScheme(value)\" ng-repeat=\"(key, value) in securitySchemes\">{{value.name}}</li>\n" +
    "      </ol>\n" +
    "\n" +
    "      <p ng-if\"documentationSchemeSelected.description\" markdown=\"documentationSchemeSelected.description\" class=\"raml-console-marked-content\"></p>\n" +
    "\n" +
    "      <section class=\"raml-console-resource-section raml-console-scheme-headers\" ng-if=\"documentationSchemeSelected.describedBy.headers\">\n" +
    "        <h4 class=\"raml-console-resource-heading-a\">Headers</h4>\n" +
    "        <properties list=\"documentationSchemeSelected.describedBy.headers\" show-examples=\"true\"></properties>\n" +
    "      </section>\n" +
    "\n" +
    "      <section class=\"raml-console-resource-section raml-console-scheme-query-parameters\" ng-if=\"documentationSchemeSelected.describedBy.queryParameters\">\n" +
    "        <h4 class=\"raml-console-resource-heading-a\">Query Parameters</h4>\n" +
    "        <properties list=\"documentationSchemeSelected.describedBy.queryParameters\" show-examples=\"true\"></properties>\n" +
    "      </section>\n" +
    "\n" +
    "      <section class=\"raml-console-resource-section raml-console-scheme-responses\" ng-if=\"documentationSchemeSelected.describedBy.responses\">\n" +
    "        <h4 class=\"raml-console-resource-heading-a\">Responses</h4>\n" +
    "\n" +
    "        <div class=\"raml-console-resource-param\" ng-repeat=\"(code, info) in documentationSchemeSelected.describedBy.responses\">\n" +
    "          <h4 class=\"raml-console-resource-param-heading\">{{info.code}}</h4>\n" +
    "          <p markdown=\"info.description\" class=\"raml-console-marked-content\"></p>\n" +
    "        </div>\n" +
    "      </section>\n" +
    "\n" +
    "      <section class=\"raml-console-resource-section raml-console-scheme-settings\" ng-if=\"documentationSchemeSelected.settings\">\n" +
    "        <h4 class=\"raml-console-resource-heading-a\">Settings</h4>\n" +
    "\n" +
    "        <div class=\"raml-console-resource-param\" ng-repeat=\"(key, config) in documentationSchemeSelected.settings\">\n" +
    "          <h4 class=\"raml-console-resource-param-heading\">{{key}}</h4>\n" +
    "          <p>{{schemaSettingsDocumentation(config)}}</p>\n" +
    "        </div>\n" +
    "      </section>\n" +
    "    </section>\n" +
    "\n" +
    "\n" +
    "    <section class=\"raml-console-resource-section\" ng-if=\"methodInfo.body\">\n" +
    "      <h3 class=\"raml-console-resource-heading-a\">\n" +
    "        Body\n" +
    "      </h3>\n" +
    "\n" +
    "      <h4 class=\"raml-console-request-body-heading\">\n" +
    "        <span ng-click=\"changeResourceBodyType($event, key)\" ng-class=\"{ 'raml-console-is-active' : bodySelected(key)}\" class=\"raml-console-flag raml-console-body-{{getBodyId(key)}}\" ng-repeat=\"(key, value) in methodInfo.body\">{{key}}</span>\n" +
    "      </h4>\n" +
    "\n" +
    "      <div ng-repeat=\"(key, value) in methodInfo.body\">\n" +
    "        <div ng-if=\"key === currentBodySelected\">\n" +
    "          <section ng-if=\"value.formParameters\">\n" +
    "             <div class=\"raml-console-resource-param\" ng-repeat=\"formParam in value.formParameters\">\n" +
    "              <h4 class=\"raml-console-resource-param-heading\">{{formParam[0].displayName}}<span class=\"raml-console-resource-param-instructional\">{{parameterDocumentation(formParam[0])}}</span></h4>\n" +
    "\n" +
    "              <p markdown=\"formParam[0].description\" class=\"raml-console-marked-content\"></p>\n" +
    "\n" +
    "              <p ng-if=\"formParam[0].example !== undefined\">\n" +
    "                <span class=\"raml-console-resource-param-example\"><b>Example:</b> {{formParam[0].example}}</span>\n" +
    "              </p>\n" +
    "            </div>\n" +
    "          </section>\n" +
    "\n" +
    "          <examples\n" +
    "            ng-if=\"value\"\n" +
    "            example-container=\"value\"\n" +
    "            get-beatified-example-ref=\"getBeatifiedExample\">\n" +
    "          </examples>\n" +
    "\n" +
    "          <raml-body\n" +
    "            ng-if=\"value\"\n" +
    "            body=\"value\"\n" +
    "            get-beatified-example-ref=\"getBeatifiedExample\">\n" +
    "          </raml-body>\n" +
    "        </div>\n" +
    "      </div>\n" +
    "    </section>\n" +
    "  </div>\n" +
    "\n" +
    "  <!-- Response -->\n" +
    "  <div ng-if=\"methodInfo.responseCodes\">\n" +
    "    <header class=\"raml-console-resource-header\">\n" +
    "      <h3 class=\"raml-console-resource-head\">\n" +
    "        Response\n" +
    "      </h3>\n" +
    "    </header>\n" +
    "\n" +
    "    <div class=\"raml-console-resource-response-jump\">\n" +
    "      <ul class=\"raml-console-resource-menu\">\n" +
    "        <li class=\"raml-console-resource-btns raml-console-resource-menu-item\" ng-repeat=\"code in methodInfo.responseCodes\">\n" +
    "          <button ng-click=\"showCodeDetails(code)\" class=\"raml-console-resource-btn raml-console-resource-menu-button raml-console-resource-menu-btn-{{getColorCode(code)}}\" ng-class=\"{ 'raml-console-button-is-active': isActiveCode(code) }\" href=\"#code{{code}}\">{{code}}</button>\n" +
    "        </li>\n" +
    "      </ul>\n" +
    "    </div>\n" +
    "\n" +
    "    <div class=\"raml-console-resource-panel-primary-row raml-console-resource-panel-content raml-console-is-active raml-console-response-container\" ng-class=\"{'raml-console-is-active':showResponseDocumentation}\">\n" +
    "      <section ng-if=\"isActiveCode(code)\" class=\"raml-console-resource-section raml-console-resource-response-section\" ng-repeat=\"code in methodInfo.responseCodes\">\n" +
    "        <a name=\"code{{code}}\"></a>\n" +
    "        <h3 class=\"raml-console-resource-heading-a\">Status {{code}}</h3>\n" +
    "\n" +
    "        <div class=\"raml-console-resource-response\">\n" +
    "          <p markdown=\"methodInfo.responses[code].description\" class=\"raml-console-marked-content\"></p>\n" +
    "        </div>\n" +
    "\n" +
    "        <div class=\"raml-console-resource-response\" ng-if=\"methodInfo.responses[code].headers\">\n" +
    "          <h4 class=\"raml-console-resource-body-heading\">Headers</h4>\n" +
    "          <properties list=\"methodInfo.responses[code].headers\"></properties>\n" +
    "        </div>\n" +
    "\n" +
    "        <div class=\"raml-console-resource-response\" ng-if=\"methodInfo.responses[code].body\">\n" +
    "          <h4 class=\"raml-console-resource-body-heading\">\n" +
    "            Body\n" +
    "            <span\n" +
    "              ng-click=\"changeType($event, key, code)\"\n" +
    "              ng-class=\"{ 'raml-console-is-active': responseInfo[code].currentType === key}\"\n" +
    "              class=\"raml-console-flag\"\n" +
    "              ng-repeat=\"(key, value) in methodInfo.responses[code].body\">\n" +
    "                {{key}}\n" +
    "            </span>\n" +
    "          </h4>\n" +
    "\n" +
    "          <div ng-repeat=\"(key, value) in methodInfo.responses[code].body\">\n" +
    "            <div ng-if=\"responseInfo[code].currentType === key\">\n" +
    "              <examples\n" +
    "                ng-if=\"responseInfo[code] && responseInfo[code].currentType\"\n" +
    "                example-container=\"value\"\n" +
    "                get-beatified-example-ref=\"getBeatifiedExample\">\n" +
    "              </examples>\n" +
    "\n" +
    "              <raml-body\n" +
    "                ng-if=\"responseInfo[code] && responseInfo[code].currentType\"\n" +
    "                body=\"value\"\n" +
    "                get-beatified-example-ref=\"getBeatifiedExample\">\n" +
    "              </raml-body>\n" +
    "            </div>\n" +
    "          </div>\n" +
    "        </div>\n" +
    "      </section>\n" +
    "\n" +
    "    </div>\n" +
    "  </div>\n" +
    "</div>\n"
  );


  $templateCache.put('directives/examples.tpl.html',
    "<div class=\"raml-console-examples-container\" ng-if=\"examples && examples.length\">\n" +
    "  <span>Examples:</span>\n" +
    "  <span\n" +
    "    class=\"raml-console-flag\"\n" +
    "    ng-class=\"{ 'raml-console-is-active': currentExample === $index }\"\n" +
    "    ng-repeat=\"example in examples\"\n" +
    "    ng-click=\"changeExample($index)\">{{example.name}}</span>\n" +
    "\n" +
    "  <div\n" +
    "      class=\"raml-console-resource-param-instructional\"\n" +
    "      ng-if=\"isXML\">\n" +
    "    Examples are shown as JSON string for demonstrative purposes only. Actual API output will be in a different format.\n" +
    "  </div>\n" +
    "  <pre class=\"raml-console-resource-pre\">\n" +
    "    <code class=\"raml-console-hljs\" hljs source=\"getBeatifiedExample(examples[currentExample].content)\"></code>\n" +
    "  </pre>\n" +
    "</div>\n"
  );


  $templateCache.put('directives/method-list.tpl.html',
    "<div class=\"raml-console-tab-list\">\n" +
    "  <div class=\"raml-console-tab\" ng-repeat=\"method in resource.methods\" ng-click=\"showResource($event, $index)\">\n" +
    "    <span class=\"raml-console-tab-label raml-console-tab-{{method.method}}\">{{method.method.toLocaleUpperCase()}}</span>\n" +
    "  </div>\n" +
    "</div>\n"
  );


  $templateCache.put('directives/named-parameters.tpl.html',
    "<section>\n" +
    "  <header class=\"raml-console-sidebar-row raml-console-sidebar-subheader\">\n" +
    "    <h4 class=\"raml-console-sidebar-subhead\">{{title}}</h4>\n" +
    "    <button class=\"raml-console-sidebar-add-btn\" ng-click=\"addCustomParameter()\" ng-if=\"enableCustomParameters\"></button>\n" +
    "  </header>\n" +
    "\n" +
    "  <div class=\"raml-console-sidebar-row\">\n" +
    "    <p class=\"raml-console-sidebar-input-container raml-console-sidebar-input-container-custom\" ng-repeat=\"customParam in context.customParameters[type]\">\n" +
    "      <button class=\"raml-console-sidebar-input-delete\" ng-click=\"removeCutomParam(customParam)\"></button>\n" +
    "      <label for=\"custom-header\" class=\"raml-console-sidebar-label raml-console-sidebar-label-custom\">\n" +
    "        <input class=\"raml-console-sidebar-custom-input-for-label\" ng-model=\"customParam.name\" placeholder=\"custom key\">\n" +
    "      </label>\n" +
    "      <input name=\"custom-header\" class=\"raml-console-sidebar-input raml-console-sidebar-input-custom\" placeholder=\"custom value\" ng-model=\"customParam.value\">\n" +
    "    </p>\n" +
    "\n" +
    "    <p ng-show=\"showBaseUrl\" class=\"raml-console-sidebar-method\">{{$parent.methodInfo.method.toUpperCase()}}</p>\n" +
    "    <div ng-show=\"showBaseUrl\" class=\"raml-console-sidebar-method-content\">\n" +
    "      <div class=\"raml-console-sidebar-url\" ng-repeat=\"segment in segments\">\n" +
    "        <div ng-hide=\"segment.templated\">{{segment.name}}</div>\n" +
    "        <div ng-show=\"segment.templated\" ng-if=\"isValueProvided(context[type].values[segment.name][0])\" class=\"raml-console-sidebar-url-segment\">{{cleanupValue(context[type].values[segment.name][0])}}</div>\n" +
    "        <div ng-show=\"segment.templated\" ng-if=\"!isValueProvided(context[type].values[segment.name][0])\" class=\"raml-console-sidebar-url-segment\"><span ng-non-bindable>&#123;</span>{{segment.name}}<span ng-non-bindable>&#125;</span></div>\n" +
    "      </div>\n" +
    "    </div>\n" +
    "\n" +
    "    <p class=\"raml-console-sidebar-input-container\" ng-repeat=\"param in context[type].plain\">\n" +
    "      <span class=\"raml-console-sidebar-input-tooltip-container\" ng-if=\"param.definitions[0].description\" ng-class=\"{'raml-console-sidebar-input-tooltip-container-enum': param.definitions[0].enum}\">\n" +
    "        <button tabindex=\"-1\" class=\"raml-console-sidebar-input-tooltip\"><span class=\"raml-console-visuallyhidden\">Show documentation</span></button>\n" +
    "        <span class=\"raml-console-sidebar-tooltip-flyout\">\n" +
    "          <span markdown=\"param.definitions[0].description\" class=\"raml-console-marked-content\"></span>\n" +
    "        </span>\n" +
    "      </span>\n" +
    "\n" +
    "      <raml-field context=\"context\" type=\"type\" param=\"param.definitions[0]\" model=\"context[type].values[param.definitions[0].id]\"></raml-field>\n" +
    "    </p>\n" +
    "  </div>\n" +
    "</section>\n"
  );


  $templateCache.put('directives/properties.tpl.html',
    "<div>\n" +
    "  <div class=\"raml-console-resource-param\" ng-repeat=\"property in listArray\" ng-if=\"!property[0].isFromSecurityScheme && !isPattern(property[0].displayName)\" ng-init=\"vm.isCollapsed = !!collapsible\">\n" +
    "    <div ng-init=\"type = getType(property[0])\">\n" +
    "      <h4 class=\"raml-console-resource-param-heading\" style=\"position: relative\">\n" +
    "        <span ng-if=\"isCollapsible(type)\" ng-click=\"vm.isCollapsed = !vm.isCollapsed\" style=\"cursor: pointer\">{{ vm.isCollapsed ? '▶' : '▼' }}</span>&nbsp;{{type.displayName}}\n" +
    "        <span ng-if=\"!hidePropertyDetails\" class=\"raml-console-resource-param-instructional\">{{parameterDocumentation(type)}}</span>\n" +
    "        <span ng-if=\"hidePropertyDetails\" class=\"raml-console-resource-param-instructional\">{{typeDocumentation(type)}}</span>\n" +
    "        <span class=\"raml-console-resource-param-instructional\" ng-repeat=\"typeName in type.type\">\n" +
    "          <span ng-if=\"isNativeType(typeName)\">{{typeName}}</span>\n" +
    "          <span ng-if=\"isSchema(typeName)\">Schema</span>\n" +
    "          <span ng-if=\"!isNativeType(typeName) && !isSchema(typeName)\">\n" +
    "            <type type-name=\"typeName\" hide-type-links=\"hideTypeLinks\"></type>\n" +
    "          </span>\n" +
    "        </span>\n" +
    "      </h4>\n" +
    "\n" +
    "      <div ng-if=\"!vm.isCollapsed\">\n" +
    "        <p ng-if=\"type.description\" markdown=\"type.description\" class=\"raml-console-marked-content\"></p>\n" +
    "\n" +
    "        <p ng-if=\"type.example !== undefined && showExamples\">\n" +
    "          <span class=\"raml-console-resource-param-example\"><b>Example:</b> {{type.example}}</span>\n" +
    "        </p>\n" +
    "\n" +
    "        <pre ng-if=\"isSchema(type.type[0])\" class=\"raml-console-resource-pre\">\n" +
    "          <code class=\"raml-console-hljs\" hljs source=\"type.type[0]\"></code>\n" +
    "        </pre>\n" +
    "\n" +
    "        <properties\n" +
    "          style=\"padding-left: 10px; margin-top: 11px;\"\n" +
    "          list=\"type.properties\"\n" +
    "          ng-if=\"type.properties\"\n" +
    "          hide-type-links=\"hideTypeLinks\"\n" +
    "          is-nested-property=\"true\">\n" +
    "        </properties>\n" +
    "      </div>\n" +
    "    </div>\n" +
    "  </div>\n" +
    "</div>\n"
  );


  $templateCache.put('directives/raml-body.tpl.html',
    "<div class=\"raml-console-schema-container\" ng-if=\"isSchema\">\n" +
    "  <p><button ng-click=\"showSchema($event)\" class=\"raml-console-resource-btn\">Show Schema</button></p>\n" +
    "  <pre class=\"raml-console-resource-pre raml-console-resource-pre-toggle\">\n" +
    "    <code class=\"raml-console-hljs\" hljs source=\"getBeatifiedExample(definition)\"></code>\n" +
    "  </pre>\n" +
    "</div>\n" +
    "\n" +
    "<div class=\"raml-console-schema-container\" ng-if=\"isType\">\n" +
    "  <type-properties type=\"body\"></type-properties>\n" +
    "</div>\n"
  );


  $templateCache.put('directives/raml-client-generator.tpl.html',
    "<div class=\"raml-console-meta-button-container\">\n" +
    "  <a\n" +
    "    class=\"raml-console-meta-button raml-console-meta-button-first\"\n" +
    "    ng-click=\"open = !open\"\n" +
    "    click-outside=\"open = false\">\n" +
    "    Download API Client\n" +
    "  </a>\n" +
    "\n" +
    "  <div class=\"raml-console-meta-button-dropdown\" ng-show=\"open\">\n" +
    "    <a class=\"raml-console-meta-button-dropdown-item\" ng-click=\"downloadJavaScriptClient()\">\n" +
    "      JavaScript\n" +
    "    </a>\n" +
    "  </div>\n" +
    "</div>\n"
  );


  $templateCache.put('directives/raml-console-loader.tpl.html',
    "<div class=\"raml-console-error-container raml-console-error-primary\">\n" +
    "  <raml-console-spinner ng-if=\"!vm.loaded\"></raml-console-spinner>\n" +
    "\n" +
    "  <raml-console ng-if=\"vm.raml\" raml=\"vm.raml\" options=\"vm.options\"></raml-console>\n" +
    "\n" +
    "  <div ng-if=\"vm.error\">\n" +
    "    <div class=\"raml-console-initializer-container raml-console-initializer-primary\">\n" +
    "      <h1 class=\"raml-console-title\">RAML Console</h1>\n" +
    "\n" +
    "      <section>\n" +
    "        <header class=\"raml-console-initializer-row raml-console-initializer-subheader\">\n" +
    "          <h4 class=\"raml-console-initializer-subhead\">Error while parsing</h4>\n" +
    "        </header>\n" +
    "\n" +
    "        <div class=\"raml-console-initializer-row\">\n" +
    "          <p class=\"raml-console-initializer-input-container\" style=\"height: 550px;\">\n" +
    "            <textarea id=\"raml\" ui-codemirror=\"{\n" +
    "              gutters:      ['CodeMirror-lint-markers'],\n" +
    "              lineNumbers:  true,\n" +
    "              lineWrapping: false,\n" +
    "              lint:         true,\n" +
    "              mode:         'yaml',\n" +
    "              tabSize:      2,\n" +
    "              theme:        'raml-console'\n" +
    "            }\" ng-model=\"vm.error.buffer\"></textarea>\n" +
    "          </p>\n" +
    "        </div>\n" +
    "      </section>\n" +
    "    </div>\n" +
    "\n" +
    "    {{vm.raml}}\n" +
    "  </div>\n" +
    "</div>\n"
  );


  $templateCache.put('directives/raml-console-spinner.tpl.html',
    "<div class=\"raml-console-spinner\">\n" +
    "  <div class=\"raml-console-rect1\"></div>\n" +
    "  <div class=\"raml-console-rect2\"></div>\n" +
    "  <div class=\"raml-console-rect3\"></div>\n" +
    "  <div class=\"raml-console-rect4\"></div>\n" +
    "  <div class=\"raml-console-rect5\"></div>\n" +
    "</div>\n"
  );


  $templateCache.put('directives/raml-console.tpl.html',
    "<div>\n" +
    "  <div class=\"raml-console-meta-button-group\">\n" +
    "    <theme-switcher ng-if=\"!disableThemeSwitcher\"></theme-switcher>\n" +
    "    <raml-client-generator ng-if=\"!disableRamlClientGenerator\"></raml-client-generator>\n" +
    "  </div>\n" +
    "\n" +
    "  <h1 ng-if=\"!disableTitle\" class=\"raml-console-title\">{{raml.title}}</h1>\n" +
    "\n" +
    "  <root-documentation></root-documentation>\n" +
    "\n" +
    "  <root-types types=\"types\" ng-if=\"types\"></root-types>\n" +
    "\n" +
    "  <ol ng-class=\"{'raml-console-resources-container-no-title': disableTitle, 'raml-console-resources-container': !disableTitle}\" id=\"raml-console-resources-container\" class=\"raml-console-resource-list raml-console-resource-list-root raml-console-resources-resourcesCollapsed\">\n" +
    "    <li id=\"raml_documentation\" class=\"raml-console-resource-list-item raml-console-documentation-header\">\n" +
    "      <div ng-if=\"proxy\" align=\"right\" class=\"raml-console-resource-proxy\">\n" +
    "        <label for=\"raml-console-api-behind-firewall\">API is behind a firewall <a href=\"http://www.mulesoft.org/documentation/display/current/Accessing+Your+API+Behind+a+Firewall\" target=\"_blank\">(?)</a></label>\n" +
    "        <input id=\"raml-console-api-behind-firewall\" type=\"checkbox\" ng-model=\"disableProxy\" ng-change=\"updateProxyConfig(disableProxy)\">\n" +
    "      </div>\n" +
    "      <header class=\"raml-console-resource raml-console-resource-root raml-console-clearfix\">\n" +
    "        <span ng-if=\"hasResourcesWithChilds()\" class=\"raml-console-flag raml-console-resource-heading-flag raml-console-toggle-all\" ng-click=\"collapseAll($event, resourceList, 'resourcesCollapsed')\" ng-class=\"{'raml-console-resources-expanded':!resourcesCollapsed}\">\n" +
    "          <span ng-if=\"!resourcesCollapsed\">collapse</span>\n" +
    "          <span ng-if=\"resourcesCollapsed\">expand</span> all\n" +
    "        </span>\n" +
    "\n" +
    "        <div class=\"raml-console-resource-path-container\">\n" +
    "          <h2 class=\"raml-console-resource-section-title\">\n" +
    "            <span class=\"raml-console-resource-path-active\">Resources</span>\n" +
    "          </h2>\n" +
    "        </div>\n" +
    "        <close-button></close-button>\n" +
    "      </header>\n" +
    "    </li>\n" +
    "\n" +
    "    <li id=\"{{generateId(resource.pathSegments)}}\" class=\"raml-console-resource-list-item\" ng-repeat=\"resourceGroup in inspectedRaml.resourceGroups\">\n" +
    "      <header class=\"raml-console-resource raml-console-resource-root raml-console-clearfix\" ng-class=\"{ 'raml-console-is-active':showPanel }\" ng-init=\"resource = resourceGroup[0]\">\n" +
    "        <div class=\"raml-console-resource-path-container\" ng-init=\"index=$index\" ng-class=\"{'raml-console-resource-with-description': resource.description}\">\n" +
    "          <button class=\"raml-console-resource-root-toggle\" ng-class=\"{'raml-console-is-active': resourceList[$index]}\" ng-if=\"resourceGroup.length > 1\" ng-click=\"toggle($event, index, resourceList, 'resourcesCollapsed')\"></button>\n" +
    "\n" +
    "          <h2 class=\"raml-console-resource-heading raml-console-resource-heading-large\">\n" +
    "            <a ng-if=\"resourceGroup.length > 1\" class=\"raml-console-resource-path-active\" ng-class=\"{'raml-console-resource-heading-hover':resourceGroup.length > 1}\" ng-repeat='segment in resource.pathSegments' ng-click=\"toggle($event, index, resourceList, 'resourcesCollapsed')\">{{segment.toString()}}</a>\n" +
    "\n" +
    "            <a ng-if=\"resourceGroup.length == 1\" style=\"cursor: default;\" class=\"raml-console-resource-path-active\" ng-repeat='segment in resource.pathSegments'>{{segment.toString()}}</a>\n" +
    "          </h2>\n" +
    "\n" +
    "          <resource-type></resource-type>\n" +
    "\n" +
    "          <span ng-if=\"methodInfo.is\" class=\"raml-console-flag raml-console-resource-heading-flag raml-console-resource-trait\"><b>Traits:</b> {{readTraits(methodInfo.is)}}</span>\n" +
    "\n" +
    "          <span ng-hide=\"methodInfo.is\" ng-if=\"resource.traits\" class=\"raml-console-flag raml-console-resource-heading-flag\"><b>Traits:</b> {{readResourceTraits(resource.traits)}}</span>\n" +
    "\n" +
    "          <span class=\"raml-console-resource-level-description raml-console-marked-content\" markdown=\"resource.description\"></span>\n" +
    "\n" +
    "        </div>\n" +
    "        <method-list></method-list>\n" +
    "        <close-button></close-button>\n" +
    "      </header>\n" +
    "\n" +
    "      <resource-panel></resource-panel>\n" +
    "\n" +
    "      <!-- Child Resources -->\n" +
    "      <ol class=\"raml-console-resource-list\" ng-class=\"{'raml-console-is-collapsed': resourcesCollapsed}\">\n" +
    "\n" +
    "        <li id=\"{{generateId(resource.pathSegments)}}\" class=\"raml-console-resource-list-item\" ng-repeat=\"resource in resourceGroup\" ng-if=\"!$first\">\n" +
    "          <div class=\"raml-console-resource raml-console-clearfix\" ng-class=\"{ 'raml-console-is-active':showPanel }\">\n" +
    "            <div class=\"raml-console-resource-path-container\" ng-class=\"{'raml-console-resource-with-description': resource.description}\">\n" +
    "              <h3 class=\"raml-console-resource-heading\" style=\"cursor: default;\">\n" +
    "                <span ng-repeat-start='segment in resource.pathSegments' ng-if=\"!$last\">{{segment.toString()}}</span><span ng-repeat-end ng-if=\"$last\" class=\"raml-console-resource-path-active\">{{segment.toString()}}</span>\n" +
    "              </h3>\n" +
    "\n" +
    "              <resource-type></resource-type>\n" +
    "              <span ng-if=\"methodInfo.is\" class=\"raml-console-flag raml-console-resource-heading-flag raml-console-resource-trait\"><b>Traits:</b> {{readTraits(methodInfo.is)}}</span>\n" +
    "\n" +
    "              <span ng-hide=\"methodInfo.is\" ng-if=\"resource.traits\" class=\"raml-console-flag raml-console-resource-heading-flag\"><b>Traits:</b> {{readResourceTraits(resource.traits)}}</span>\n" +
    "\n" +
    "              <span class=\"raml-console-resource-level-description raml-console-marked-content\" markdown=\"resource.description\"></span>\n" +
    "            </div>\n" +
    "\n" +
    "            <method-list></method-list>\n" +
    "            <close-button></close-button>\n" +
    "          </div>\n" +
    "\n" +
    "          <resource-panel></resource-panel>\n" +
    "        </li>\n" +
    "      </ol>\n" +
    "\n" +
    "    </li>\n" +
    "  </ol>\n" +
    "</div>\n"
  );


  $templateCache.put('directives/raml-field.tpl.html',
    "<div style=\"position: relative;\">\n" +
    "  <label for=\"{{param.id}}\" class=\"raml-console-sidebar-label\">\n" +
    "    {{param.displayName}}\n" +
    "    <a class=\"raml-console-sidebar-override\" ng-if=\"canOverride(param)\" ng-click=\"overrideField($event, param)\">Override</a>\n" +
    "    <span class=\"raml-console-side-bar-required-field\" ng-if=\"param.required\">*</span>\n" +
    "    <label ng-if=\"param.isFromSecurityScheme\" class=\"raml-console-sidebar-security-label\">from security scheme</label>\n" +
    "    <span class=\"raml-console-resource-param-instructional\">{{toString(param.type)}}</span>\n" +
    "  </label>\n" +
    "\n" +
    "  <div ng-if=\"!param.properties && !isArray(param)\">\n" +
    "    <span class=\"raml-console-sidebar-input-tooltip-container raml-console-sidebar-input-left\" ng-if=\"hasExampleValue(param)\">\n" +
    "      <button tabindex=\"-1\" class=\"raml-console-sidebar-input-reset\" ng-click=\"reset(param)\"><span class=\"raml-console-visuallyhidden\">Reset field</span></button>\n" +
    "      <span class=\"raml-console-sidebar-tooltip-flyout-left\">\n" +
    "        <span>Use example value</span>\n" +
    "      </span>\n" +
    "    </span>\n" +
    "\n" +
    "    <select id=\"select_{{param.id}}\" ng-if=\"isEnum(param)\" name=\"param.id\" class=\"raml-console-sidebar-input\" ng-model=\"model[0]\" style=\"margin-bottom: 0;\" ng-change=\"onChange()\">\n" +
    "     <option ng-repeat=\"enum in unique(param.enum)\" value=\"{{enum}}\" ng-selected=\"{{param.example === enum}}\">{{enum}}</option>\n" +
    "    </select>\n" +
    "\n" +
    "    <input id=\"{{param.id}}\" ng-hide=\"!isDefault(param)\" class=\"raml-console-sidebar-input\" ng-model=\"model[0]\" ng-class=\"{'raml-console-sidebar-field-no-default': !hasExampleValue(param)}\" validate=\"param\" dynamic-name=\"param.id\" ng-change=\"onChange()\"/>\n" +
    "\n" +
    "    <input id=\"checkbox_{{param.id}}\" ng-if=\"isBoolean(param)\" class=\"raml-console-sidebar-input\" type=\"checkbox\" ng-model=\"model[0]\" dynamic-name=\"param.id\" ng-change=\"onChange()\" />\n" +
    "\n" +
    "    <span class=\"raml-console-field-validation-error\"></span>\n" +
    "  </div>\n" +
    "\n" +
    "  <div ng-if=\"!param.properties && isArray(param)\" ng-init=\"model[0] = [[undefined]]\">\n" +
    "    <button class=\"raml-console-sidebar-add-btn\" ng-click=\"addArrayElement(model[0])\"></button>\n" +
    "    <div ng-repeat=\"aModel in model[0] track by $index\" style=\"position: relative;\">\n" +
    "      <button class=\"raml-console-sidebar-input-delete\" ng-click=\"removeArrayElement(model[0], $index)\"></button>\n" +
    "      <span class=\"raml-console-sidebar-input-tooltip-container raml-console-sidebar-input-left\" ng-if=\"hasExampleValue(param)\">\n" +
    "        <button tabindex=\"-1\" class=\"raml-console-sidebar-input-reset\" ng-click=\"reset(param)\"><span class=\"raml-console-visuallyhidden\">Reset field</span></button>\n" +
    "        <span class=\"raml-console-sidebar-tooltip-flyout-left\">\n" +
    "          <span>Use example value</span>\n" +
    "        </span>\n" +
    "      </span>\n" +
    "\n" +
    "      <select id=\"select_{{param.id}}\" ng-if=\"isEnum(param)\" name=\"param.id\" class=\"raml-console-sidebar-input\" ng-model=\"aModel[0]\" style=\"margin-bottom: 0;\" ng-change=\"onChange()\">\n" +
    "       <option ng-repeat=\"enum in unique(param.enum)\" value=\"{{enum}}\" ng-selected=\"{{param.example === enum}}\">{{enum}}</option>\n" +
    "      </select>\n" +
    "\n" +
    "      <input id=\"{{param.id}}\" ng-hide=\"!isDefault(param)\" class=\"raml-console-sidebar-input\" ng-model=\"aModel[0]\" validate=\"param\" dynamic-name=\"param.id\" ng-change=\"onChange()\"/>\n" +
    "\n" +
    "      <input id=\"checkbox_{{param.id}}\" ng-if=\"isBoolean(param)\" class=\"raml-console-sidebar-input\" type=\"checkbox\" ng-model=\"aModel[0]\" dynamic-name=\"param.id\" ng-change=\"onChange()\" />\n" +
    "\n" +
    "      <span class=\"raml-console-field-validation-error\"></span>\n" +
    "    </div>\n" +
    "  </div>\n" +
    "\n" +
    "  <div ng-if=\"param.properties\" style=\"padding-left: 10px\">\n" +
    "    <raml-field ng-repeat=\"aParam in param.properties\" context=\"context\" type=\"type\" param=\"aParam[0]\" ng-init=\"model[0][aParam[0].name] = [undefined]\" model=\"model[0][aParam[0].name]\"></raml-field>\n" +
    "  </div>\n" +
    "</div>\n"
  );


  $templateCache.put('directives/raml-initializer.tpl.html',
    "<div class=\"raml-console-initializer-container raml-console-initializer-primary\">\n" +
    "  <div ng-if=\"!vm.isLoading && !vm.raml\">\n" +
    "    <h1 class=\"raml-console-title\">RAML Console</h1>\n" +
    "\n" +
    "    <div class=\"raml-console-initializer-content-wrapper\">\n" +
    "      <section>\n" +
    "        <header class=\"raml-console-initializer-row raml-console-initializer-subheader\">\n" +
    "          <h4 class=\"raml-console-initializer-subhead\">Initialize from the URL of a RAML file</h4>\n" +
    "        </header>\n" +
    "\n" +
    "        <div class=\"raml-console-initializer-row\">\n" +
    "          <form novalidate ng-submit=\"vm.loadFromUrl(vm.ramlUrl)\">\n" +
    "            <p class=\"raml-console-initializer-input-container\" ng-class=\"{'raml-console-initializer-input-container-error': vm.isLoadedFromUrl && vm.error}\">\n" +
    "              <input id=\"ramlPath\" autofocus class=\"raml-console-initializer-input raml-console-initializer-raml-field\" ng-model=\"vm.ramlUrl\">\n" +
    "            </p>\n" +
    "            <div class=\"raml-console-parser-error\" ng-if=\"vm.isLoadedFromUrl && vm.error\">\n" +
    "              <span>{{ vm.error.message }}</span>\n" +
    "            </div>\n" +
    "            <div class=\"raml-console-initializer-action-group\" align=\"right\">\n" +
    "              <button id=\"loadRamlFromUrl\" class=\"raml-console-initializer-action raml-console-initializer-action-btn\" type=\"submit\">Load from URL</button>\n" +
    "            </div>\n" +
    "          </form>\n" +
    "        </div>\n" +
    "      </section>\n" +
    "\n" +
    "      <section>\n" +
    "        <header class=\"raml-console-initializer-row raml-console-initializer-subheader\">\n" +
    "          <h4 class=\"raml-console-initializer-subhead\">or parse RAML in here</h4>\n" +
    "        </header>\n" +
    "\n" +
    "        <div class=\"raml-console-initializer-row\">\n" +
    "          <p class=\"raml-console-initializer-input-container\" ng-class=\"{'raml-console-initializer-input-container-error': !vm.isLoadedFromUrl && vm.error}\">\n" +
    "            <textarea id=\"raml\" ui-codemirror=\"vm.codeMirror\" ng-model=\"vm.ramlString\"></textarea>\n" +
    "          </p>\n" +
    "          <div class=\"raml-console-initializer-action-group\" align=\"right\">\n" +
    "            <button id=\"loadRaml\" class=\"raml-console-initializer-action raml-console-initializer-action-btn\" ng-click=\"vm.loadFromString(vm.ramlString)\">Load RAML</button>\n" +
    "          </div>\n" +
    "        </div>\n" +
    "      </section>\n" +
    "    </div>\n" +
    "  </div>\n" +
    "\n" +
    "  <raml-console ng-if=\"vm.raml\" raml=\"vm.raml\"></raml-console>\n" +
    "\n" +
    "  <raml-console-spinner ng-if=\"vm.isLoading\"></raml-console-spinner>\n" +
    "</div>\n"
  );


  $templateCache.put('directives/resource-panel.tpl.html',
    "<div class=\"raml-console-resource-panel\" ng-if=\"showPanel\" ng-class=\"{ 'raml-console-has-sidebar-collapsed': singleView }\">\n" +
    "  <div class=\"raml-console-resource-no-baseuri\" ng-hide=\"raml.baseUri\">\n" +
    "    <strong>Try-it</strong> is disabled because <strong>baseUri</strong> is not present\n" +
    "  </div>\n" +
    "  <div class=\"raml-console-resource-panel-wrapper\">\n" +
    "    <documentation></documentation>\n" +
    "\n" +
    "    <sidebar ng-show=\"raml.baseUri\"></sidebar>\n" +
    "\n" +
    "    <div class=\"raml-console-sidebar-controls raml-console-sidebar-controls-collapse\" ng-click=\"collapseSidebar($event)\" style=\"right: -1px; position: absolute;\"ng-hide=\"!raml.baseUri\" ng-if=\"!disableTryIt\">\n" +
    "      <button class=\"raml-console-collapse\" style=\"height: 21px; margin-top: 9px;\">\n" +
    "        <svg style=\"transform: rotate(-180deg); display: inline;\" version=\"1.1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\" viewBox=\"0 0 612 792\" enable-background=\"new 0 0 612 792\" xml:space=\"preserve\">\n" +
    "          <g id=\"Layer_3\">\n" +
    "            <polygon fill=\"#585961\" points=\"480.9,396 142.1,46.2 142.1,745.8  \"/>\n" +
    "          </g>\n" +
    "        </svg>\n" +
    "        <span class=\"raml-console-discoverable\">Try it</span>\n" +
    "      </button>\n" +
    "    </div>\n" +
    "\n" +
    "    <div class=\"raml-console-sidebar-controls raml-console-sidebar-controls-fullscreen\" ng-click=\"toggleSidebar($event)\" style=\"right: -1px; position: absolute;\">\n" +
    "      <button class=\"raml-console-collapse\" style=\"height: 21px; margin-top: 9px;\">\n" +
    "\n" +
    "        <svg style=\"transform: rotate(-180deg); display: inline;\" version=\"1.1\" xmlns=\"http://www.w3.org/2000/svg\" xmlns:xlink=\"http://www.w3.org/1999/xlink\" x=\"0px\" y=\"0px\" viewBox=\"0 0 612 792\" enable-background=\"new 0 0 612 792\" xml:space=\"preserve\">\n" +
    "          <g id=\"Layer_3\">\n" +
    "            <polygon fill=\"#585961\" points=\"480.9,396 142.1,46.2 142.1,745.8  \"/>\n" +
    "          </g>\n" +
    "        </svg>\n" +
    "        <span class=\"raml-console-discoverable\">Try it</span>\n" +
    "      </button>\n" +
    "    </div>\n" +
    "  </div>\n" +
    "</div>\n"
  );


  $templateCache.put('directives/resource-type.tpl.html',
    "<span ng-if=\"resource.resourceType\" class=\"raml-console-flag raml-console-resource-heading-flag\"><b>Type:</b> {{resource.resourceType}}</span>\n"
  );


  $templateCache.put('directives/root-documentation.tpl.html',
    "<ol id=\"raml-console-documentation-container\" ng-if=\"raml.documentation\" class=\"raml-console-resource-list raml-console-resource-list-root raml-console-root-documentation raml-console-resources-documentationCollapsed\">\n" +
    "  <li class=\"raml-console-resource-list-item raml-console-documentation-header\" ng-if=\"raml.documentation.length > 0\">\n" +
    "    <header class=\"raml-console-resource raml-console-resource-root raml-console-clearfix\">\n" +
    "      <span ng-if=\"hasDocumentationWithIndex()\" class=\"raml-console-flag raml-console-resource-heading-flag raml-console-toggle-all\" ng-click=\"collapseAll($event, documentList, 'documentationCollapsed')\" ng-class=\"{'raml-console-resources-expanded':!documentationCollapsed}\"><span ng-if=\"!documentationCollapsed\">collapse</span><span ng-if=\"documentationCollapsed\">expand</span> all</span>\n" +
    "      <div class=\"raml-console-resource-path-container\">\n" +
    "        <h2 class=\"raml-console-resource-section-title\">\n" +
    "          <span class=\"raml-console-resource-path-active\">Documentation</span>\n" +
    "        </h2>\n" +
    "      </div>\n" +
    "    </header>\n" +
    "  </li>\n" +
    "\n" +
    "  <li id=\"{{generateDocId(doc.title)}}\" class=\"raml-console-resource-list-item raml-console-documentation\" ng-repeat=\"doc in raml.documentation\">\n" +
    "    <div ng-init=\"content = getMarkdownHeaders(doc.content)\">\n" +
    "      <div class=\"raml-console-resource raml-console-clearfix raml-console-document-header\">\n" +
    "        <div class=\"raml-console-resource-path-container\" style=\"padding-top: 11px;\" ng-init=\"index=$index\">\n" +
    "          <h3 class=\"raml-console-resource-heading\">\n" +
    "            <button class=\"raml-console-resource-root-toggle\" ng-if=\"content.length > 0\" ng-click=\"toggle($event, index, documentList, 'documentationCollapsed')\" ng-class=\"{'raml-console-is-active': documentList[index]}\"></button>\n" +
    "            <span class=\"raml-console-resource-path-active raml-console-document-heading\" ng-click=\"toggleSection($event, 'all', doc.title)\">{{doc.title}}</span>\n" +
    "          </h3>\n" +
    "          <select ng-if=\"content.length > 0\" ng-model=\"selectedSection\" ng-if=\"documentationEnabled\" class=\"raml-console-document-section-selector\" ng-change=\"sectionChange(selectedSection)\">\n" +
    "            <option value=\"all\">-- choose a section --</option>\n" +
    "            <option ng-repeat=\"header in filterHeaders(content)\" value=\"{{header.value}}\" ng-selected=\"header.value == selectedDocumentSection\">{{header.label}}</option>\n" +
    "          </select>\n" +
    "        </div>\n" +
    "        <button class=\"raml-console-resource-close-btn\" ng-click=\"closeDocumentation($event)\">\n" +
    "          Close\n" +
    "        </button>\n" +
    "      </div>\n" +
    "\n" +
    "      <div class=\"raml-console-resource-panel raml-console-documentation-content\" ng-if=\"documentationEnabled\">\n" +
    "        <div class=\"raml-console-resource-panel-wrapper\">\n" +
    "          <div class=\"raml-console-documentation-section-content raml-console-marked-content\" markdown=\"getDocumentationContent(doc.content, selectedDocumentSection)\"></div>\n" +
    "        </div>\n" +
    "      </div>\n" +
    "\n" +
    "      <ol class=\"raml-console-resource-list raml-console-documentation-contents\" ng-if=\"content.length > 0\" ng-class=\"{'raml-console-is-collapsed': documentationCollapsed}\">\n" +
    "        <li ng-repeat=\"header in content\" class=\"raml-console-resource-list-item\">\n" +
    "           <div class=\"raml-console-resource raml-console-clearfix raml-console-documentation-clearfix\">\n" +
    "            <div class=\"raml-console-resource-path-container raml-console-documentation-path-container\">\n" +
    "              <h3 class=\"raml-console-resource-heading raml-console-documentation-heading raml-console-md-heading-{{header.heading}}\">\n" +
    "                <div class=\"raml-console-resource-path-active\">\n" +
    "                  <div class=\"raml-consoledocumentation-title raml-console-document-heading\" ng-click=\"toggleSection($event, header.value, doc.title)\">{{header.label}}</div>\n" +
    "                </div>\n" +
    "              </h3>\n" +
    "            </div>\n" +
    "          </div>\n" +
    "        </li>\n" +
    "      </ol>\n" +
    "    </div>\n" +
    "  </li>\n" +
    "</ol>\n"
  );


  $templateCache.put('directives/root-types.tpl.html',
    "<ol id=\"raml-console-documentation-container\" class=\"raml-console-resource-list raml-console-resource-list-root raml-console-root-documentation raml-console-resources-documentationCollapsed\" ng-init=\"vm.isCollapsed = true\">\n" +
    "  <li class=\"raml-console-resource-list-item raml-console-documentation-header\">\n" +
    "    <header class=\"raml-console-resource raml-console-resource-root raml-console-clearfix\">\n" +
    "      <div class=\"raml-console-resource-path-container\">\n" +
    "        <h2 class=\"raml-console-resource-section-title raml-console-documentation-heading\" ng-click=\"vm.isCollapsed = !vm.isCollapsed\">\n" +
    "          <button class=\"raml-console-resource-root-toggle\" ng-class=\"{'raml-console-is-active': vm.isCollapsed}\"></button>\n" +
    "          <span class=\"raml-console-resource-path-active\">Types</span>\n" +
    "        </h2>\n" +
    "      </div>\n" +
    "    </header>\n" +
    "  </li>\n" +
    "  <li ng-if=\"!vm.isCollapsed\" class=\"raml-console-resource-panel raml-console-type-panel\" style=\"background: white; padding: 32px;\">\n" +
    "    <properties list=\"theTypes\" collapsible=\"true\" hide-property-details=\"true\"></types>\n" +
    "  </li>\n" +
    "</ol>\n"
  );


  $templateCache.put('directives/sidebar.tpl.html',
    "  <form name=\"form\" class=\"raml-console-sidebar\" novalidate ng-class=\"{ 'raml-console-is-collapsed': singleView }\" ng-if=\"!disableTryIt\" ng-init=\"setFormScope(this)\">\n" +
    "    <div class=\"raml-console-sidebar-flex-wrapper\">\n" +
    "      <div class=\"raml-console-sidebar-content\">\n" +
    "        <header class=\"raml-console-sidebar-row raml-console-sidebar-header\">\n" +
    "          <h3 class=\"raml-console-sidebar-head\">\n" +
    "            Try it\n" +
    "            <a ng-if=\"!singleView\" class=\"raml-console-sidebar-fullscreen-toggle\" ng-click=\"collapseSidebar($event)\"><div class=\"raml-console-close-sidebar\">&times;</div></a>\n" +
    "            <a ng-if=\"!singleView\" class=\"raml-console-sidebar-collapse-toggle\" ng-click=\"closeSidebar($event)\"><div class=\"raml-console-close-sidebar\">&times;</div></a>\n" +
    "\n" +
    "            <a ng-if=\"singleView\" class=\"raml-console-sidebar-collapse-toggle\" ng-click=\"toggleSidebar($event)\"><div class=\"raml-console-close-sidebar\">&times;</div></a>\n" +
    "\n" +
    "            <a ng-if=\"!singleView\" class=\"raml-console-sidebar-resize-toggle raml-console-sidebar-resize\" ng-click=\"toggleSidebar($event)\">\n" +
    "              <svg x=\"0px\" y=\"0px\" viewBox=\"0 0 850 1000\" class=\"raml-console-full-resize\" fill=\"#808080\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\"><path d=\"M421.29 589.312q0 7.254 -5.58 12.834l-185.256 185.256 80.352 80.352q10.602 10.602 10.602 25.11t-10.602 25.11 -25.11 10.602h-249.984q-14.508 0 -25.11 -10.602t-10.602 -25.11v-249.984q0 -14.508 10.602 -25.11t25.11 -10.602 25.11 10.602l80.352 80.352 185.256 -185.256q5.58 -5.58 12.834 -5.58t12.834 5.58l63.612 63.612q5.58 5.58 5.58 12.834zm435.798 -482.112v249.984q0 14.508 -10.602 25.11t-25.11 10.602 -25.11 -10.602l-80.352 -80.352 -185.256 185.256q-5.58 5.58 -12.834 5.58t-12.834 -5.58l-63.612 -63.612q-5.58 -5.58 -5.58 -12.834t5.58 -12.834l185.256 -185.256 -80.352 -80.352q-10.602 -10.602 -10.602 -25.11t10.602 -25.11 25.11 -10.602h249.984q14.508 0 25.11 10.602t10.602 25.11z\"/></svg>\n" +
    "\n" +
    "              <svg x=\"0px\" y=\"0px\" viewBox=\"0 0 850 1000\" class=\"raml-console-small-resize\" fill=\"#808080\" xmlns=\"http://www.w3.org/2000/svg\" version=\"1.1\"><path d=\"M428.544 535.744v249.984q0 14.508 -10.602 25.11t-25.11 10.602 -25.11 -10.602l-80.352 -80.352 -185.256 185.256q-5.58 5.58 -12.834 5.58t-12.834 -5.58l-63.612 -63.612q-5.58 -5.58 -5.58 -12.834t5.58 -12.834l185.256 -185.256 -80.352 -80.352q-10.602 -10.602 -10.602 -25.11t10.602 -25.11 25.11 -10.602h249.984q14.508 0 25.11 10.602t10.602 25.11zm421.29 -374.976q0 7.254 -5.58 12.834l-185.256 185.256 80.352 80.352q10.602 10.602 10.602 25.11t-10.602 25.11 -25.11 10.602h-249.984q-14.508 0 -25.11 -10.602t-10.602 -25.11v-249.984q0 -14.508 10.602 -25.11t25.11 -10.602 25.11 10.602l80.352 80.352 185.256 -185.256q5.58 -5.58 12.834 -5.58t12.834 5.58l63.612 63.612q5.58 5.58 5.58 12.834z\"/></svg>\n" +
    "            </a>\n" +
    "          </h3>\n" +
    "        </header>\n" +
    "\n" +
    "        <div class=\"raml-console-sidebar-content-wrapper\">\n" +
    "          <section ng-if=\"protocols.length > 1\">\n" +
    "            <header class=\"raml-console-sidebar-row raml-console-sidebar-subheader raml-console-sidebar-subheader-top\">\n" +
    "              <h4 class=\"raml-console-sidebar-subhead\">Protocols</h4>\n" +
    "            </header>\n" +
    "            <div class=\"raml-console-sidebar-row raml-console-sidebar-securty\">\n" +
    "              <select ng-change=\"protocolChanged(currentProtocol)\" class=\"raml-console-sidebar-input\" ng-model=\"currentProtocol\" style=\"margin-bottom: 0;\">\n" +
    "               <option ng-repeat=\"protocol in protocols\" value=\"{{protocol}}\">{{protocol}}</option>\n" +
    "              </select>\n" +
    "            </div>\n" +
    "          </section>\n" +
    "\n" +
    "          <section>\n" +
    "            <header class=\"raml-console-sidebar-row raml-console-sidebar-subheader\" ng-class=\"{'raml-console-sidebar-subheader-top':raml.protocols.length == 1}\">\n" +
    "              <h4 class=\"raml-console-sidebar-subhead\">Authentication</h4>\n" +
    "            </header>\n" +
    "            <div class=\"raml-console-sidebar-row raml-console-sidebar-securty\">\n" +
    "              <div class=\"raml-console-toggle-group raml-console-sidebar-toggle-group\">\n" +
    "                <label class=\"raml-console-sidebar-label\">Security Scheme</label>\n" +
    "                <span class=\"raml-console-resource-param-instructional\">Custom Security Schemes are not supported in Try It</span>\n" +
    "                <select ng-change=\"securitySchemeChanged(currentScheme)\" class=\"raml-console-sidebar-input\" ng-model=\"currentScheme\" style=\"margin-bottom: 0;\">\n" +
    "                 <option ng-repeat=\"(key, scheme) in securitySchemes\" value=\"{{scheme.id}}\">{{scheme.name}}</option>\n" +
    "                </select>\n" +
    "              </div>\n" +
    "            </div>\n" +
    "\n" +
    "            <div ng-switch=\"currentSchemeType\">\n" +
    "              <basic-auth ng-switch-when=\"Basic Authentication\" credentials='credentials'></basic-auth>\n" +
    "              <oauth1 ng-switch-when=\"OAuth 1.0\" credentials='credentials'></oauth1>\n" +
    "              <oauth2 ng-switch-when=\"OAuth 2.0\" credentials='credentials'></oauth2>\n" +
    "            </div>\n" +
    "          </section>\n" +
    "\n" +
    "          <named-parameters ng-if=\"resource.uriParametersForDocumentation\" src=\"resource.uriParametersForDocumentation\" context=\"context\" type=\"uriParameters\" title=\"URI Parameters\" show-base-url></named-parameters>\n" +
    "\n" +
    "          <named-parameters src=\"methodInfo.headers.plain\" context=\"context\" type=\"headers\" title=\"Headers\" enable-custom-parameters></named-parameters>\n" +
    "\n" +
    "          <named-parameters src=\"methodInfo.queryParameters\" context=\"context\" type=\"queryParameters\" title=\"Query Parameters\" enable-custom-parameters></named-parameters>\n" +
    "\n" +
    "          <section ng-if=\"methodInfo.queryString\">\n" +
    "            <header class=\"raml-console-sidebar-row raml-console-sidebar-subheader\">\n" +
    "              <h4 class=\"raml-console-sidebar-subhead\">Query String</h4>\n" +
    "            </header>\n" +
    "\n" +
    "            <div class=\"raml-console-sidebar-row\" style=\"padding-bottom: 0;\">\n" +
    "              <div\n" +
    "                class=\"raml-console-resource-param-instructional\"\n" +
    "                ng-show=\"queryStringHasError\"\n" +
    "                style=\"color: red;\">\n" +
    "                  Query String format is invalid, JSON string expected\n" +
    "              </div>\n" +
    "              <div\n" +
    "                class=\"raml-console-codemirror-body-editor\"\n" +
    "                ui-codemirror=\"{ lineNumbers: true, tabSize: 2, theme : 'raml-console', mode: context.bodyContent.selected }\"\n" +
    "                ng-model=\"context.queryString\">\n" +
    "              </div>\n" +
    "            </div>\n" +
    "          </section>\n" +
    "\n" +
    "          <section id=\"sidebar-body\" ng-if=\"methodInfo.body\">\n" +
    "            <header class=\"raml-console-sidebar-row raml-console-sidebar-subheader\">\n" +
    "              <h4 class=\"raml-console-sidebar-subhead\">Body</h4>\n" +
    "            </header>\n" +
    "\n" +
    "            <div class=\"raml-console-sidebar-row\" style=\"padding-bottom: 0;\">\n" +
    "              <select ng-change=\"requestBodySelectionChange(context.bodyContent.selected)\" class=\"raml-console-sidebar-input\" ng-model=\"context.bodyContent.selected\" style=\"margin-bottom: 0;\">\n" +
    "               <option ng-repeat=\"(key, scheme) in methodInfo.body\" value=\"{{key}}\">{{key}}</option>\n" +
    "              </select>\n" +
    "            </div>\n" +
    "\n" +
    "            <div class=\"raml-console-sidebar-row\" ng-switch=\"context.bodyContent.isForm(context.bodyContent.selected)\">\n" +
    "              <div ng-switch-when=\"false\">\n" +
    "                <div class=\"raml-console-codemirror-body-editor\" ui-codemirror=\"{ lineNumbers: true, tabSize: 2, theme : 'raml-console', mode: context.bodyContent.selected }\" ng-model=\"context.bodyContent.definitions[context.bodyContent.selected].value\"></div>\n" +
    "                <div class=\"raml-console-sidebar-prefill raml-console-sidebar-row\" align=\"right\" ng-if=\"context.bodyContent.definitions[context.bodyContent.selected].hasExample()\">\n" +
    "                  <button class=\"raml-console-sidebar-action-prefill\" ng-click=\"prefillBody(context.bodyContent.selected)\">Prefill with example</button>\n" +
    "                </div>\n" +
    "              </div>\n" +
    "\n" +
    "\n" +
    "              <div ng-switch-when=\"true\">\n" +
    "                <p class=\"raml-console-sidebar-input-container\" ng-repeat=\"param in context.bodyContent.definitions[context.bodyContent.selected].plain\">\n" +
    "                  <span class=\"raml-console-sidebar-input-tooltip-container\" ng-if=\"param.definitions[0].description\">\n" +
    "                    <button tabindex=\"-1\" class=\"raml-console-sidebar-input-tooltip\"><span class=\"raml-console-visuallyhidden\">Show documentation</span></button>\n" +
    "                    <span class=\"raml-console-sidebar-tooltip-flyout\">\n" +
    "                      <span markdown=\"param.definitions[0].description\" class=\"raml-console-marked-content\"></span>\n" +
    "                    </span>\n" +
    "                  </span>\n" +
    "\n" +
    "                  <raml-field context=\"context\" type=\"type\" param=\"param.definitions[0]\" model=\"context.bodyContent.definitions[context.bodyContent.selected].values[param.definitions[0].id]\"></raml-field>\n" +
    "                </p>\n" +
    "              </div>\n" +
    "            </div>\n" +
    "          </section>\n" +
    "\n" +
    "          <section>\n" +
    "            <div class=\"raml-console-sidebar-row\">\n" +
    "              <span\n" +
    "                class=\"raml-console-resource-param-instructional\"\n" +
    "                ng-show=\"customStrategyError\"\n" +
    "                style=\"color: red;\">\n" +
    "                  Custom Security Schemes are not supported in Try It\n" +
    "              </span>\n" +
    "              <div class=\"raml-console-sidebar-action-group\">\n" +
    "                <button ng-hide=\"showSpinner\" type=\"submit\" class=\"raml-console-sidebar-action raml-console-sidebar-action-{{methodInfo.method}}\" ng-click=\"tryIt($event)\" ng-class=\"{'raml-console-sidebar-action-force':context.forceRequest}\"><span ng-if=\"context.forceRequest\">Force</span> {{methodInfo.method.toUpperCase()}}\n" +
    "                </button>\n" +
    "                <button ng-if=\"showSpinner\" type=\"submit\" class=\"raml-console-sidebar-action raml-console-sidebar-action-{{methodInfo.method}} raml-console-sidebar-action-cancel-request\" ng-click=\"cancelRequest()\">Cancel <div class=\"raml-console-spinner-request\" ng-if=\"showSpinner\">Loading ...</div></button>\n" +
    "                <button class=\"raml-console-sidebar-action raml-console-sidebar-action-clear\" ng-click=\"clearFields()\">Clear</button>\n" +
    "                <button class=\"raml-console-sidebar-action raml-console-sidebar-action-reset\" ng-click=\"resetFields()\">Reset</button>\n" +
    "              </div>\n" +
    "            </div>\n" +
    "          </section>\n" +
    "\n" +
    "          <div ng-if=\"responseDetails\">\n" +
    "            <section id=\"request_{{generateId(resource.pathSegments)}}\" class=\"raml-console-side-bar-try-it-description\">\n" +
    "              <header class=\"raml-console-sidebar-row raml-console-sidebar-header\">\n" +
    "                <h3 class=\"raml-console-sidebar-head raml-console-sidebar-head-expand\">\n" +
    "                  <button ng-class=\"{'raml-console-is-open':showRequestMetadata, 'raml-console-is-collapsed':!showRequestMetadata}\" class=\"raml-console-sidebar-expand-btn\" ng-click=\"toggleRequestMetadata()\">\n" +
    "                    Request\n" +
    "                  </button>\n" +
    "                </h3>\n" +
    "              </header>\n" +
    "              <div class=\"raml-console-sidebar-request-metadata\" ng-class=\"{'raml-console-is-active':showRequestMetadata}\">\n" +
    "\n" +
    "                <div class=\"raml-console-sidebar-row\">\n" +
    "                  <div ng-if=\"requestOptions.url\">\n" +
    "                    <h3 class=\"raml-console-sidebar-response-head raml-console-sidebar-response-head-pre\">Request URL</h3>\n" +
    "                    <div class=\"raml-console-sidebar-response-item\">\n" +
    "                      <p class=\"raml-console-sidebar-response-metadata raml-console-sidebar-request-url\">{{requestOptions.url}}</p>\n" +
    "                    </div>\n" +
    "                  </div>\n" +
    "\n" +
    "                  <div ng-if=\"requestOptions.headers\">\n" +
    "                    <h3 class=\"raml-console-sidebar-response-head\">Headers</h3>\n" +
    "                    <div class=\"raml-console-sidebar-response-item\">\n" +
    "                      <p class=\"raml-console-sidebar-response-metadata\" ng-repeat=\"(key, value) in requestOptions.headers\">\n" +
    "                        <b>{{key}}:</b> <br>{{getHeaderValue(value)}}\n" +
    "                      </p>\n" +
    "                    </div>\n" +
    "                  </div>\n" +
    "\n" +
    "                  <div ng-if=\"requestOptions.data\">\n" +
    "                    <h3 class=\"raml-console-sidebar-response-head raml-console-sidebar-response-head-pre\">Body</h3>\n" +
    "                    <div ng-switch=\"context.bodyContent.isForm(context.bodyContent.selected)\">\n" +
    "                      <div ng-switch-when=\"false\" class=\"raml-console-sidebar-pre raml-console-sidebar-request-body\">\n" +
    "                        <div ui-codemirror=\"{ readOnly: 'nocursor', tabSize: 2, lineNumbers: true, theme : 'raml-console', mode: context.bodyContent.selected }\" ng-model=\"requestOptions.data\"></div>\n" +
    "                      </div>\n" +
    "                      <div ng-switch-when=\"true\" class=\"raml-console-sidebar-response-item\">\n" +
    "                        <p class=\"raml-console-sidebar-response-metadata\" ng-repeat=\"(key, value) in context.bodyContent.definitions[context.bodyContent.selected].values\">\n" +
    "                          <b>{{key}}:</b> <br>{{value}}\n" +
    "                        </p>\n" +
    "                      </div>\n" +
    "                    </div>\n" +
    "                  </div>\n" +
    "                </div>\n" +
    "              </div>\n" +
    "            </section>\n" +
    "\n" +
    "            <section class=\"raml-console-side-bar-try-it-description\">\n" +
    "              <header class=\"raml-console-sidebar-row raml-console-sidebar-header\">\n" +
    "                <h3 class=\"raml-console-sidebar-head\">\n" +
    "                  <button ng-class=\"{'raml-console-is-open':showResponseMetadata, 'raml-console-is-collapsed':!showResponseMetadata}\" class=\"raml-console-sidebar-expand-btn\" ng-click=\"toggleResponseMetadata()\">\n" +
    "                    Response\n" +
    "                  </button>\n" +
    "                </h3>\n" +
    "              </header>\n" +
    "\n" +
    "              <div class=\"raml-console-sidebar-row raml-console-sidebar-response\" ng-class=\"{'raml-console-is-active':showResponseMetadata}\">\n" +
    "                <h3 class=\"raml-console-sidebar-response-head\">Status</h3>\n" +
    "                <p class=\"raml-console-sidebar-response-item\">{{response.status}}</p>\n" +
    "\n" +
    "                <h3 class=\"raml-console-sidebar-response-head\" ng-if=\"response.headers\">Headers</h3>\n" +
    "                <div class=\"raml-console-sidebar-response-item\">\n" +
    "                  <p class=\"raml-console-sidebar-response-metadata\" ng-repeat=\"(key, value) in response.headers\">\n" +
    "                    <b>{{key}}:</b> <br>{{value}}\n" +
    "                  </p>\n" +
    "                </div>\n" +
    "                <div ng-if=\"response.body\">\n" +
    "                  <h3 class=\"raml-console-sidebar-response-head raml-console-sidebar-response-head-pre\">Body</h3>\n" +
    "                  <div class=\"raml-console-sidebar-pre\">\n" +
    "                    <div ui-codemirror=\"{ readOnly: true, tabSize: 2, lineNumbers: true, theme : 'raml-console', mode: response.contentType }\" ng-model=\"response.body\" ng-style=\"editorStyle\">\n" +
    "                    </div>\n" +
    "                  </div>\n" +
    "                </div>\n" +
    "              </div>\n" +
    "            </section>\n" +
    "          </div>\n" +
    "      </div>\n" +
    "    </div>\n" +
    "  </div>\n" +
    "</form>\n"
  );


  $templateCache.put('directives/spinner.tpl.html',
    "<img src=\"img/spinner.gif\">\n"
  );


  $templateCache.put('directives/theme-switcher.tpl.html',
    "<div class=\"raml-console-meta-button-container\">\n" +
    "  <a class=\"raml-console-meta-button\">Switch Theme</a>\n" +
    "</div>\n"
  );


  $templateCache.put('directives/type-properties.tpl.html',
    "<div>\n" +
    "  <properties list=\"properties\" hide-property-details=\"true\" show-examples=\"true\"></properties>\n" +
    "<div>\n"
  );


  $templateCache.put('directives/type.tpl.html',
    "<span ng-repeat=\"type in typeInfo.parts\">\n" +
    "  <span ng-if=\"$first && typeInfo.isArray\">(</span>\n" +
    "  <span ng-if=\"!$first && typeInfo.type === 'union'\"> | </span>\n" +
    "  <a href=\"\" ng-click=\"selectType($event, cleanupTypeName(type))\" ng-if=\"showTypeLink(type)\">{{cleanupTypeName(type)}}</a>\n" +
    "  <span ng-if=\"!showTypeLink(type)\">{{type}}</span>\n" +
    "  <span ng-if=\"typeInfo.type === 'array'\">[]</span>\n" +
    "  <span ng-if=\"$last && typeInfo.isArray\">)[]</span>\n" +
    "</span>\n" +
    "<div ng-if=\"selectedType\" class=\"raml-console-type-info-popover\">\n" +
    "  <h3>\n" +
    "    <span>{{selectedType.displayName}}</span>\n" +
    "    <div class=\"raml-console-subtitle\">\n" +
    "      <span ng-repeat-start=\"superType in getSupertTypes(selectedType)\">{{superType}}</span>\n" +
    "      <span ng-if=\"!$last\" ng-repeat-end>, </span>\n" +
    "    </div>\n" +
    "  </h3>\n" +
    "  <properties\n" +
    "    ng-click=\"$event.preventDefault()\"\n" +
    "    list=\"selectedType.properties\"\n" +
    "    ng-if=\"selectedType.properties\"\n" +
    "    is-nested-property=\"true\"\n" +
    "    hide-type-links=\"true\">\n" +
    "  </properties>\n" +
    "</div>\n"
  );


  $templateCache.put('security/basic_auth.tpl.html',
    "<div class=\"raml-console-sidebar-row\">\n" +
    "  <p class=\"raml-console-sidebar-input-container\">\n" +
    "    <label for=\"username\" class=\"raml-console-sidebar-label\">Username <span class=\"raml-console-side-bar-required-field\">*</span></label>\n" +
    "    <input required=\"true\" type=\"text\" name=\"username\" class=\"raml-console-sidebar-input raml-console-sidebar-security-field\" ng-model=\"credentials.username\" ng-change=\"onChange()\"/>\n" +
    "    <span class=\"raml-console-field-validation-error\"></span>\n" +
    "  </p>\n" +
    "\n" +
    "  <p class=\"raml-console-sidebar-input-container\">\n" +
    "    <label for=\"password\" class=\"raml-console-sidebar-label\">Password <span class=\"raml-console-side-bar-required-field\">*</span></label>\n" +
    "    <input required=\"true\" type=\"password\" name=\"password\" class=\"raml-console-sidebar-input raml-console-sidebar-security-field\" ng-model=\"credentials.password\" ng-change=\"onChange()\"/>\n" +
    "    <span class=\"raml-console-field-validation-error\"></span>\n" +
    "  </p>\n" +
    "</div>\n"
  );


  $templateCache.put('security/oauth1.tpl.html',
    "<div class=\"raml-console-sidebar-row\">\n" +
    "  <p class=\"raml-console-sidebar-input-container\">\n" +
    "    <label for=\"consumerKey\" class=\"raml-console-sidebar-label\">Consumer Key <span class=\"raml-console-side-bar-required-field\">*</span></label>\n" +
    "    <input required=\"true\" type=\"text\" name=\"consumerKey\" class=\"raml-console-sidebar-input raml-console-sidebar-security-field\" ng-model=\"credentials.consumerKey\" ng-change=\"onChange()\"/>\n" +
    "    <span class=\"raml-console-field-validation-error\"></span>\n" +
    "  </p>\n" +
    "\n" +
    "  <p class=\"raml-console-sidebar-input-container\">\n" +
    "    <label for=\"consumerSecret\" class=\"raml-console-sidebar-label\">Consumer Secret <span class=\"raml-console-side-bar-required-field\">*</span></label>\n" +
    "    <input required=\"true\" type=\"password\" name=\"consumerSecret\" class=\"raml-console-sidebar-input raml-console-sidebar-security-field\" ng-model=\"credentials.consumerSecret\" ng-change=\"onChange()\"/>\n" +
    "    <span class=\"raml-console-field-validation-error\"></span>\n" +
    "  </p>\n" +
    "</div>\n"
  );


  $templateCache.put('security/oauth2.tpl.html',
    "<div class=\"raml-console-sidebar-row\">\n" +
    "  <p class=\"raml-console-sidebar-input-container\">\n" +
    "    <label for=\"clientId\" class=\"raml-console-sidebar-label\">Authorization Grant</label>\n" +
    "    <select class=\"raml-console-sidebar-input\" ng-model=\"credentials.grant\">\n" +
    "     <option ng-repeat=\"grant in grants\" value=\"{{grant.value}}\" ng-selected=\"grant.value=='token'\">{{grant.label}}</option>\n" +
    "    </select>\n" +
    "  </p>\n" +
    "\n" +
    "  <p class=\"raml-console-sidebar-input-container\">\n" +
    "    <label for=\"clientId\" class=\"raml-console-sidebar-label\">Client ID <span class=\"raml-console-side-bar-required-field\">*</span></label>\n" +
    "    <input required=\"true\" type=\"text\" name=\"clientId\" class=\"raml-console-sidebar-input raml-console-sidebar-security-field\" ng-model=\"credentials.clientId\" ng-change=\"onChange()\"/>\n" +
    "    <span class=\"raml-console-field-validation-error\"></span>\n" +
    "  </p>\n" +
    "\n" +
    "  <p class=\"raml-console-sidebar-input-container\" ng-if=\"!isImplicitEnabled()\">\n" +
    "    <label for=\"clientSecret\" class=\"raml-console-sidebar-label\">Client Secret <span class=\"raml-console-side-bar-required-field\">*</span></label>\n" +
    "    <input required=\"true\" type=\"password\" name=\"clientSecret\" class=\"raml-console-sidebar-input raml-console-sidebar-security-field\" ng-model=\"credentials.clientSecret\" ng-change=\"onChange()\"/>\n" +
    "    <span class=\"raml-console-field-validation-error\"></span>\n" +
    "  </p>\n" +
    "\n" +
    "  <p class=\"raml-console-sidebar-input-container\" ng-if=\"ownerOptionsEnabled()\">\n" +
    "    <label for=\"username\" class=\"raml-console-sidebar-label\">Username <span class=\"raml-console-side-bar-required-field\">*</span></label>\n" +
    "    <input required=\"true\" type=\"text\" name=\"username\" class=\"raml-console-sidebar-input raml-console-sidebar-security-field\" ng-model=\"credentials.username\" ng-change=\"onChange()\"/>\n" +
    "    <span class=\"raml-console-field-validation-error\"></span>\n" +
    "  </p>\n" +
    "\n" +
    "  <p class=\"raml-console-sidebar-input-container\" ng-if=\"ownerOptionsEnabled()\">\n" +
    "    <label for=\"password\" class=\"raml-console-sidebar-label\">Password <span class=\"raml-console-side-bar-required-field\">*</span></label>\n" +
    "    <input required=\"true\" type=\"password\" name=\"password\" class=\"raml-console-sidebar-input raml-console-sidebar-security-field\" ng-model=\"credentials.password\" ng-change=\"onChange()\"/>\n" +
    "    <span class=\"raml-console-field-validation-error\"></span>\n" +
    "  </p>\n" +
    "\n" +
    "  <p class=\"raml-console-sidebar-input-container\">\n" +
    "    <label for=\"password\" class=\"raml-console-sidebar-label\">Scopes</label>\n" +
    "    <ol class=\"raml-console-sidebar-oauth-scopes\">\n" +
    "      <li ng-repeat=\"scope in scopes\">\n" +
    "        <input type=\"checkbox\" ng-model=\"credentials.scopes[scope]\"> {{scope}}\n" +
    "      </li>\n" +
    "    </ol>\n" +
    "  </p>\n" +
    "</div>\n"
  );

}]);

/* FileSaver.js
 * A saveAs() FileSaver implementation.
 * 2015-03-04
 *
 * By Eli Grey, http://eligrey.com
 * License: X11/MIT
 *   See https://github.com/eligrey/FileSaver.js/blob/master/LICENSE.md
 */

/*global self */
/*jslint bitwise: true, indent: 4, laxbreak: true, laxcomma: true, smarttabs: true, plusplus: true */

/*! @source http://purl.eligrey.com/github/FileSaver.js/blob/master/FileSaver.js */

var saveAs = saveAs
  // IE 10+ (native saveAs)
  || (typeof navigator !== "undefined" &&
      navigator.msSaveOrOpenBlob && navigator.msSaveOrOpenBlob.bind(navigator))
  // Everyone else
  || (function(view) {
	"use strict";
	// IE <10 is explicitly unsupported
	if (typeof navigator !== "undefined" &&
	    /MSIE [1-9]\./.test(navigator.userAgent)) {
		return;
	}
	var
		  doc = view.document
		  // only get URL when necessary in case Blob.js hasn't overridden it yet
		, get_URL = function() {
			return view.URL || view.webkitURL || view;
		}
		, save_link = doc.createElementNS("http://www.w3.org/1999/xhtml", "a")
		, can_use_save_link = "download" in save_link
		, click = function(node) {
			var event = doc.createEvent("MouseEvents");
			event.initMouseEvent(
				"click", true, false, view, 0, 0, 0, 0, 0
				, false, false, false, false, 0, null
			);
			node.dispatchEvent(event);
		}
		, webkit_req_fs = view.webkitRequestFileSystem
		, req_fs = view.requestFileSystem || webkit_req_fs || view.mozRequestFileSystem
		, throw_outside = function(ex) {
			(view.setImmediate || view.setTimeout)(function() {
				throw ex;
			}, 0);
		}
		, force_saveable_type = "application/octet-stream"
		, fs_min_size = 0
		// See https://code.google.com/p/chromium/issues/detail?id=375297#c7 and
		// https://github.com/eligrey/FileSaver.js/commit/485930a#commitcomment-8768047
		// for the reasoning behind the timeout and revocation flow
		, arbitrary_revoke_timeout = 500 // in ms
		, revoke = function(file) {
			var revoker = function() {
				if (typeof file === "string") { // file is an object URL
					get_URL().revokeObjectURL(file);
				} else { // file is a File
					file.remove();
				}
			};
			if (view.chrome) {
				revoker();
			} else {
				setTimeout(revoker, arbitrary_revoke_timeout);
			}
		}
		, dispatch = function(filesaver, event_types, event) {
			event_types = [].concat(event_types);
			var i = event_types.length;
			while (i--) {
				var listener = filesaver["on" + event_types[i]];
				if (typeof listener === "function") {
					try {
						listener.call(filesaver, event || filesaver);
					} catch (ex) {
						throw_outside(ex);
					}
				}
			}
		}
		, FileSaver = function(blob, name) {
			// First try a.download, then web filesystem, then object URLs
			var
				  filesaver = this
				, type = blob.type
				, blob_changed = false
				, object_url
				, target_view
				, dispatch_all = function() {
					dispatch(filesaver, "writestart progress write writeend".split(" "));
				}
				// on any filesys errors revert to saving with object URLs
				, fs_error = function() {
					// don't create more object URLs than needed
					if (blob_changed || !object_url) {
						object_url = get_URL().createObjectURL(blob);
					}
					if (target_view) {
						target_view.location.href = object_url;
					} else {
						var new_tab = view.open(object_url, "_blank");
						if (new_tab == undefined && typeof safari !== "undefined") {
							//Apple do not allow window.open, see http://bit.ly/1kZffRI
							view.location.href = object_url
						}
					}
					filesaver.readyState = filesaver.DONE;
					dispatch_all();
					revoke(object_url);
				}
				, abortable = function(func) {
					return function() {
						if (filesaver.readyState !== filesaver.DONE) {
							return func.apply(this, arguments);
						}
					};
				}
				, create_if_not_found = {create: true, exclusive: false}
				, slice
			;
			filesaver.readyState = filesaver.INIT;
			if (!name) {
				name = "download";
			}
			if (can_use_save_link) {
				object_url = get_URL().createObjectURL(blob);
				save_link.href = object_url;
				save_link.download = name;
				click(save_link);
				filesaver.readyState = filesaver.DONE;
				dispatch_all();
				revoke(object_url);
				return;
			}
			// prepend BOM for UTF-8 XML and text/plain types
			if (/^\s*(?:text\/(?:plain|xml)|application\/xml|\S*\/\S*\+xml)\s*;.*charset\s*=\s*utf-8/i.test(blob.type)) {
				blob = new Blob(["\ufeff", blob], {type: blob.type});
			}
			// Object and web filesystem URLs have a problem saving in Google Chrome when
			// viewed in a tab, so I force save with application/octet-stream
			// http://code.google.com/p/chromium/issues/detail?id=91158
			// Update: Google errantly closed 91158, I submitted it again:
			// https://code.google.com/p/chromium/issues/detail?id=389642
			if (view.chrome && type && type !== force_saveable_type) {
				slice = blob.slice || blob.webkitSlice;
				blob = slice.call(blob, 0, blob.size, force_saveable_type);
				blob_changed = true;
			}
			// Since I can't be sure that the guessed media type will trigger a download
			// in WebKit, I append .download to the filename.
			// https://bugs.webkit.org/show_bug.cgi?id=65440
			if (webkit_req_fs && name !== "download") {
				name += ".download";
			}
			if (type === force_saveable_type || webkit_req_fs) {
				target_view = view;
			}
			if (!req_fs) {
				fs_error();
				return;
			}
			fs_min_size += blob.size;
			req_fs(view.TEMPORARY, fs_min_size, abortable(function(fs) {
				fs.root.getDirectory("saved", create_if_not_found, abortable(function(dir) {
					var save = function() {
						dir.getFile(name, create_if_not_found, abortable(function(file) {
							file.createWriter(abortable(function(writer) {
								writer.onwriteend = function(event) {
									target_view.location.href = file.toURL();
									filesaver.readyState = filesaver.DONE;
									dispatch(filesaver, "writeend", event);
									revoke(file);
								};
								writer.onerror = function() {
									var error = writer.error;
									if (error.code !== error.ABORT_ERR) {
										fs_error();
									}
								};
								"writestart progress write abort".split(" ").forEach(function(event) {
									writer["on" + event] = filesaver["on" + event];
								});
								writer.write(blob);
								filesaver.abort = function() {
									writer.abort();
									filesaver.readyState = filesaver.DONE;
								};
								filesaver.readyState = filesaver.WRITING;
							}), fs_error);
						}), fs_error);
					};
					dir.getFile(name, {create: false}, abortable(function(file) {
						// delete file if it already exists
						file.remove();
						save();
					}), abortable(function(ex) {
						if (ex.code === ex.NOT_FOUND_ERR) {
							save();
						} else {
							fs_error();
						}
					}));
				}), fs_error);
			}), fs_error);
		}
		, FS_proto = FileSaver.prototype
		, saveAs = function(blob, name) {
			return new FileSaver(blob, name);
		}
	;
	FS_proto.abort = function() {
		var filesaver = this;
		filesaver.readyState = filesaver.DONE;
		dispatch(filesaver, "abort");
	};
	FS_proto.readyState = FS_proto.INIT = 0;
	FS_proto.WRITING = 1;
	FS_proto.DONE = 2;

	FS_proto.error =
	FS_proto.onwritestart =
	FS_proto.onprogress =
	FS_proto.onwrite =
	FS_proto.onabort =
	FS_proto.onerror =
	FS_proto.onwriteend =
		null;

	return saveAs;
}(
	   typeof self !== "undefined" && self
	|| typeof window !== "undefined" && window
	|| this.content
));
// `self` is undefined in Firefox for Android content script context
// while `this` is nsIContentFrameMessageManager
// with an attribute `content` that corresponds to the window

if (typeof module !== "undefined" && module.exports) {
  module.exports.saveAs = saveAs;
} else if ((typeof define !== "undefined" && define !== null) && (define.amd != null)) {
  define([], function() {
    return saveAs;
  });
}

(function(f){if(typeof exports==="object"&&typeof module!=="undefined"){module.exports=f()}else if(typeof define==="function"&&define.amd){define([],f)}else{var g;if(typeof window!=="undefined"){g=window}else if(typeof global!=="undefined"){g=global}else if(typeof self!=="undefined"){g=self}else{g=this}g.$RefParser = f()}})(function(){var define,module,exports;return (function e(t,n,r){function s(o,u){if(!n[o]){if(!t[o]){var a=typeof require=="function"&&require;if(!u&&a)return a(o,!0);if(i)return i(o,!0);var f=new Error("Cannot find module '"+o+"'");throw f.code="MODULE_NOT_FOUND",f}var l=n[o]={exports:{}};t[o][0].call(l.exports,function(e){var n=t[o][1][e];return s(n?n:e)},l,l.exports,e,t,n,r)}return n[o].exports}var i=typeof require=="function"&&require;for(var o=0;o<r.length;o++)s(r[o]);return s})({1:[function(require,module,exports){
/** !
 * JSON Schema $Ref Parser v2.2.1
 *
 * @link https://github.com/BigstickCarpet/json-schema-ref-parser
 * @license MIT
 */
'use strict';

var $Ref    = require('./ref'),
    Pointer = require('./pointer'),
    util    = require('./util'),
    url     = require('url');

module.exports = bundle;

/**
 * Bundles all external JSON references into the main JSON schema, thus resulting in a schema that
 * only has *internal* references, not any *external* references.
 * This method mutates the JSON schema object, adding new references and re-mapping existing ones.
 *
 * @param {$RefParser} parser
 * @param {$RefParserOptions} options
 */
function bundle(parser, options) {
  util.debug('Bundling $ref pointers in %s', parser.$refs._basePath);

  // Build an inventory of all $ref pointers in the JSON Schema
  var inventory = [];
  crawl(parser.schema, parser.$refs._basePath + '#', '#', inventory, parser.$refs, options);

  // Remap all $ref pointers
  remap(inventory);
}

/**
 * Recursively crawls the given value, and inventories all JSON references.
 *
 * @param {*} obj - The value to crawl. If it's not an object or array, it will be ignored.
 * @param {string} path - The full path of `obj`, possibly with a JSON Pointer in the hash
 * @param {string} pathFromRoot - The path of `obj` from the schema root
 * @param {object[]} inventory - An array of already-inventoried $ref pointers
 * @param {$Refs} $refs
 * @param {$RefParserOptions} options
 */
function crawl(obj, path, pathFromRoot, inventory, $refs, options) {
  if (obj && typeof obj === 'object') {
    var keys = Object.keys(obj);

    // Most people will expect references to be bundled into the the "definitions" property,
    // so we always crawl that property first, if it exists.
    var defs = keys.indexOf('definitions');
    if (defs > 0) {
      keys.splice(0, 0, keys.splice(defs, 1)[0]);
    }

    keys.forEach(function(key) {
      var keyPath = Pointer.join(path, key);
      var keyPathFromRoot = Pointer.join(pathFromRoot, key);
      var value = obj[key];

      if ($Ref.is$Ref(value)) {
        // Skip this $ref if we've already inventoried it
        if (!inventory.some(function(i) { return i.parent === obj && i.key === key; })) {
          inventory$Ref(obj, key, path, keyPathFromRoot, inventory, $refs, options);
        }
      }
      else {
        crawl(value, keyPath, keyPathFromRoot, inventory, $refs, options);
      }
    });
  }
}

/**
 * Inventories the given JSON Reference (i.e. records detailed information about it so we can
 * optimize all $refs in the schema), and then crawls the resolved value.
 *
 * @param {object} $refParent - The object that contains a JSON Reference as one of its keys
 * @param {string} $refKey - The key in `$refParent` that is a JSON Reference
 * @param {string} path - The full path of the JSON Reference at `$refKey`, possibly with a JSON Pointer in the hash
 * @param {string} pathFromRoot - The path of the JSON Reference at `$refKey`, from the schema root
 * @param {object[]} inventory - An array of already-inventoried $ref pointers
 * @param {$Refs} $refs
 * @param {$RefParserOptions} options
 */
function inventory$Ref($refParent, $refKey, path, pathFromRoot, inventory, $refs, options) {
  var $ref = $refParent[$refKey];
  var $refPath = url.resolve(path, $ref.$ref);
  var pointer = $refs._resolve($refPath, options);
  var depth = Pointer.parse(pathFromRoot).length;
  var file = util.path.stripHash(pointer.path);
  var hash = util.path.getHash(pointer.path);
  var external = file !== $refs._basePath;
  var extended = Object.keys($ref).length > 1;

  inventory.push({
    $ref: $ref,                   // The JSON Reference (e.g. {$ref: string})
    parent: $refParent,           // The object that contains this $ref pointer
    key: $refKey,                 // The key in `parent` that is the $ref pointer
    pathFromRoot: pathFromRoot,   // The path to the $ref pointer, from the JSON Schema root
    depth: depth,                 // How far from the JSON Schema root is this $ref pointer?
    file: file,                   // The file that the $ref pointer resolves to
    hash: hash,                   // The hash within `file` that the $ref pointer resolves to
    value: pointer.value,         // The resolved value of the $ref pointer
    circular: pointer.circular,   // Is this $ref pointer DIRECTLY circular? (i.e. it references itself)
    extended: extended,           // Does this $ref extend its resolved value? (i.e. it has extra properties, in addition to "$ref")
    external: external            // Does this $ref pointer point to a file other than the main JSON Schema file?
  });

  // Recursively crawl the resolved value
  crawl(pointer.value, pointer.path, pathFromRoot, inventory, $refs, options);
}

/**
 * Re-maps every $ref pointer, so that they're all relative to the root of the JSON Schema.
 * Each referenced value is dereferenced EXACTLY ONCE.  All subsequent references to the same
 * value are re-mapped to point to the first reference.
 *
 * @example:
 *  {
 *    first: { $ref: somefile.json#/some/part },
 *    second: { $ref: somefile.json#/another/part },
 *    third: { $ref: somefile.json },
 *    fourth: { $ref: somefile.json#/some/part/sub/part }
 *  }
 *
 * In this example, there are four references to the same file, but since the third reference points
 * to the ENTIRE file, that's the only one we need to dereference.  The other three can just be
 * remapped to point inside the third one.
 *
 * On the other hand, if the third reference DIDN'T exist, then the first and second would both need
 * to be dereferenced, since they point to different parts of the file. The fourth reference does NOT
 * need to be dereferenced, because it can be remapped to point inside the first one.
 *
 * @param {object[]} inventory
 */
function remap(inventory) {
  // Group & sort all the $ref pointers, so they're in the order that we need to dereference/remap them
  inventory.sort(function(a, b) {
    if (a.file !== b.file) {
      return a.file < b.file ? -1 : +1;   // Group all the $refs that point to the same file
    }
    else if (a.hash !== b.hash) {
      return a.hash < b.hash ? -1 : +1;   // Group all the $refs that point to the same part of the file
    }
    else if (a.circular !== b.circular) {
      return a.circular ? -1 : +1;        // If the $ref points to itself, then sort it higher than other $refs that point to this $ref
    }
    else if (a.extended !== b.extended) {
      return a.extended ? +1 : -1;        // If the $ref extends the resolved value, then sort it lower than other $refs that don't extend the value
    }
    else if (a.depth !== b.depth) {
      return a.depth - b.depth;           // Sort $refs by how close they are to the JSON Schema root
    }
    else {
      // If all else is equal, use the $ref that's in the "definitions" property
      return b.pathFromRoot.lastIndexOf('/definitions') - a.pathFromRoot.lastIndexOf('/definitions');
    }
  });

  var file, hash, pathFromRoot;
  inventory.forEach(function(i) {
    util.debug('Re-mapping $ref pointer "%s" at %s', i.$ref.$ref, i.pathFromRoot);

    if (!i.external) {
      // This $ref already resolves to the main JSON Schema file
      i.$ref.$ref = i.hash;
    }
    else if (i.file !== file || i.hash.indexOf(hash) !== 0) {
      // We've moved to a new file or new hash
      file = i.file;
      hash = i.hash;
      pathFromRoot = i.pathFromRoot;

      // This is the first $ref to point to this value, so dereference the value.
      // Any other $refs that point to the same value will point to this $ref instead
      i.$ref = i.parent[i.key] = util.dereference(i.$ref, i.value);

      if (i.circular) {
        // This $ref points to itself
        i.$ref.$ref = i.pathFromRoot;
      }
    }
    else {
      // This $ref points to the same value as the prevous $ref
      i.$ref.$ref = Pointer.join(pathFromRoot, Pointer.parse(i.hash));
    }

    util.debug('    new value: %s', (i.$ref && i.$ref.$ref) ? i.$ref.$ref : '[object Object]');
  });
}

},{"./pointer":8,"./ref":11,"./util":14,"url":91}],2:[function(require,module,exports){
'use strict';

var $Ref    = require('./ref'),
    Pointer = require('./pointer'),
    util    = require('./util'),
    ono     = require('ono'),
    url     = require('url');

module.exports = dereference;

/**
 * Crawls the JSON schema, finds all JSON references, and dereferences them.
 * This method mutates the JSON schema object, replacing JSON references with their resolved value.
 *
 * @param {$RefParser} parser
 * @param {$RefParserOptions} options
 */
function dereference(parser, options) {
  util.debug('Dereferencing $ref pointers in %s', parser.$refs._basePath);
  parser.$refs.circular = false;
  crawl(parser.schema, parser.$refs._basePath, '#', [], parser.$refs, options);
}

/**
 * Recursively crawls the given value, and dereferences any JSON references.
 *
 * @param {*} obj - The value to crawl. If it's not an object or array, it will be ignored.
 * @param {string} path - The full path of `obj`, possibly with a JSON Pointer in the hash
 * @param {string} pathFromRoot - The path of `obj` from the schema root
 * @param {object[]} parents - An array of the parent objects that have already been dereferenced
 * @param {$Refs} $refs
 * @param {$RefParserOptions} options
 * @returns {boolean} - Returns true if a circular reference was found
 */
function crawl(obj, path, pathFromRoot, parents, $refs, options) {
  var isCircular = false;

  if (obj && typeof obj === 'object') {
    parents.push(obj);

    Object.keys(obj).forEach(function(key) {
      var keyPath = Pointer.join(path, key);
      var keyPathFromRoot = Pointer.join(pathFromRoot, key);
      var value = obj[key];
      var circular = false;

      if ($Ref.isAllowed$Ref(value, options)) {
        var dereferenced = dereference$Ref(value, keyPath, keyPathFromRoot, parents, $refs, options);
        circular = dereferenced.circular;
        obj[key] = dereferenced.value;
      }
      else {
        if (parents.indexOf(value) === -1) {
          circular = crawl(value, keyPath, keyPathFromRoot, parents, $refs, options);
        }
        else {
          circular = foundCircularReference(keyPath, $refs, options);
        }
      }

      // Set the "isCircular" flag if this or any other property is circular
      isCircular = isCircular || circular;
    });

    parents.pop();
  }
  return isCircular;
}

/**
 * Dereferences the given JSON Reference, and then crawls the resulting value.
 *
 * @param {{$ref: string}} $ref - The JSON Reference to resolve
 * @param {string} path - The full path of `$ref`, possibly with a JSON Pointer in the hash
 * @param {string} pathFromRoot - The path of `$ref` from the schema root
 * @param {object[]} parents - An array of the parent objects that have already been dereferenced
 * @param {$Refs} $refs
 * @param {$RefParserOptions} options
 * @returns {object}
 */
function dereference$Ref($ref, path, pathFromRoot, parents, $refs, options) {
  util.debug('Dereferencing $ref pointer "%s" at %s', $ref.$ref, path);

  var $refPath = url.resolve(path, $ref.$ref);
  var pointer = $refs._resolve($refPath, options);

  // Check for circular references
  var directCircular = pointer.circular;
  var circular = directCircular || parents.indexOf(pointer.value) !== -1;
  circular && foundCircularReference(path, $refs, options);

  // Dereference the JSON reference
  var dereferencedValue = util.dereference($ref, pointer.value);

  // Crawl the dereferenced value (unless it's circular)
  if (!circular) {
    // If the `crawl` method returns true, then dereferenced value is circular
    circular = crawl(dereferencedValue, pointer.path, pathFromRoot, parents, $refs, options);
  }

  if (circular && !directCircular && options.$refs.circular === 'ignore') {
    // The user has chosen to "ignore" circular references, so don't change the value
    dereferencedValue = $ref;
  }

  if (directCircular) {
    // The pointer is a DIRECT circular reference (i.e. it references itself).
    // So replace the $ref path with the absolute path from the JSON Schema root
    dereferencedValue.$ref = pathFromRoot;
  }

  return {
    circular: circular,
    value: dereferencedValue
  };
}

/**
 * Called when a circular reference is found.
 * It sets the {@link $Refs#circular} flag, and throws an error if options.$refs.circular is false.
 *
 * @param {string} keyPath - The JSON Reference path of the circular reference
 * @param {$Refs} $refs
 * @param {$RefParserOptions} options
 * @returns {boolean} - always returns true, to indicate that a circular reference was found
 */
function foundCircularReference(keyPath, $refs, options) {
  $refs.circular = true;
  if (!options.$refs.circular) {
    throw ono.reference('Circular $ref pointer found at %s', keyPath);
  }
  return true;
}

},{"./pointer":8,"./ref":11,"./util":14,"ono":54,"url":91}],3:[function(require,module,exports){
(function (Buffer){
'use strict';

var http    = require('http'),
    https   = require('https'),
    url     = require('url'),
    util    = require('./util'),
    Promise = require('./promise'),
    ono     = require('ono');

module.exports = download;

/**
 * Downloads the given file.
 *
 * @param {Url|string} u - The url to download (can be a parsed {@link Url} object)
 * @param {$RefParserOptions} options
 * @param {number} [redirects] - The redirect URLs that have already been followed
 *
 * @returns {Promise<Buffer>}
 * The promise resolves with the raw downloaded data, or rejects if there is an HTTP error.
 */
function download(u, options, redirects) {
  return new Promise(function(resolve, reject) {
    u = url.parse(u);
    redirects = redirects || [];
    redirects.push(u.href);

    get(u, options)
      .then(function(res) {
        if (res.statusCode >= 400) {
          throw ono({status: res.statusCode}, 'HTTP ERROR %d', res.statusCode);
        }
        else if (res.statusCode >= 300) {
          if (redirects.length > options.http.redirects) {
            reject(ono({status: res.statusCode}, 'Error downloading %s. \nToo many redirects: \n  %s',
              redirects[0], redirects.join(' \n  ')));
          }
          else if (!res.headers.location) {
            throw ono({status: res.statusCode}, 'HTTP %d redirect with no location header', res.statusCode);
          }
          else {
            util.debug('HTTP %d redirect %s -> %s', res.statusCode, u.href, res.headers.location);
            var redirectTo = url.resolve(u, res.headers.location);
            download(redirectTo, options, redirects).then(resolve, reject);
          }
        }
        else if (res.statusCode === 204 && !options.allow.empty) {
          throw ono({status: 204}, 'HTTP 204 (No Content)');
        }
        else {
          resolve(res.body || new Buffer(0));
        }
      })
      .catch(function(err) {
        reject(ono(err, 'Error downloading', u.href));
      });
  });
}

/**
 * Sends an HTTP GET request.
 *
 * @param {Url} u - A parsed {@link Url} object
 * @param {$RefParserOptions} options
 *
 * @returns {Promise<Response>}
 * The promise resolves with the HTTP Response object.
 */
function get(u, options) {
  return new Promise(function(resolve, reject) {
    util.debug('GET', u.href);

    var protocol = u.protocol === 'https:' ? https : http;
    var req = protocol.get({
      hostname: u.hostname,
      port: u.port,
      path: u.path,
      auth: u.auth,
      headers: options.http.headers,
      withCredentials: options.http.withCredentials
    });

    if (typeof req.setTimeout === 'function') {
      req.setTimeout(options.http.timeout);
    }

    req.on('timeout', function() {
      req.abort();
    });

    req.on('error', reject);

    req.once('response', function(res) {
      res.body = new Buffer(0);

      res.on('data', function(data) {
        res.body = Buffer.concat([res.body, new Buffer(data)]);
      });

      res.on('error', reject);

      res.on('end', function() {
        resolve(res);
      });
    });
  });
}

}).call(this,require("buffer").Buffer)

},{"./promise":9,"./util":14,"buffer":57,"http":85,"https":62,"ono":54,"url":91}],4:[function(require,module,exports){
(function (Buffer){
'use strict';

var Promise     = require('./promise'),
    Options     = require('./options'),
    $Refs       = require('./refs'),
    $Ref        = require('./ref'),
    read        = require('./read'),
    resolve     = require('./resolve'),
    bundle      = require('./bundle'),
    dereference = require('./dereference'),
    util        = require('./util'),
    url         = require('url'),
    maybe       = require('call-me-maybe'),
    ono         = require('ono');

module.exports = $RefParser;
module.exports.YAML = require('./yaml');

/**
 * This class parses a JSON schema, builds a map of its JSON references and their resolved values,
 * and provides methods for traversing, manipulating, and dereferencing those references.
 *
 * @constructor
 */
function $RefParser() {
  /**
   * The parsed (and possibly dereferenced) JSON schema object
   *
   * @type {object}
   * @readonly
   */
  this.schema = null;

  /**
   * The resolved JSON references
   *
   * @type {$Refs}
   */
  this.$refs = new $Refs();
}

/**
 * Parses the given JSON schema.
 * This method does not resolve any JSON references.
 * It just reads a single file in JSON or YAML format, and parse it as a JavaScript object.
 *
 * @param {string|object} schema - The file path or URL of the JSON schema. Or a JSON schema object.
 * @param {$RefParserOptions} [options] - Options that determine how the schema is parsed
 * @param {function} [callback] - An error-first callback. The second parameter is the parsed JSON schema object.
 * @returns {Promise} - The returned promise resolves with the parsed JSON schema object.
 */
$RefParser.parse = function(schema, options, callback) {
  var Class = this; // eslint-disable-line consistent-this
  return new Class().parse(schema, options, callback);
};

/**
 * Parses the given JSON schema.
 * This method does not resolve any JSON references.
 * It just reads a single file in JSON or YAML format, and parse it as a JavaScript object.
 *
 * @param {string|object} schema - The file path or URL of the JSON schema. Or a JSON schema object.
 * @param {$RefParserOptions} [options] - Options that determine how the schema is parsed
 * @param {function} [callback] - An error-first callback. The second parameter is the parsed JSON schema object.
 * @returns {Promise} - The returned promise resolves with the parsed JSON schema object.
 */
$RefParser.prototype.parse = function(schema, options, callback) {
  var args = normalizeArgs(arguments);

  if (args.schema && typeof args.schema === 'object') {
    // The schema is an object, not a path/url
    this.schema = args.schema;
    this.$refs._basePath = '';
    var $ref = new $Ref(this.$refs, this.$refs._basePath);
    $ref.setValue(this.schema, args.options);

    return maybe(args.callback, Promise.resolve(this.schema));
  }

  if (!args.schema || typeof args.schema !== 'string') {
    var err = ono('Expected a file path, URL, or object. Got %s', args.schema);
    return maybe(args.callback, Promise.reject(err));
  }

  var me = this;

  // Resolve the absolute path of the schema
  args.schema = util.path.localPathToUrl(args.schema);
  args.schema = url.resolve(util.path.cwd(), args.schema);
  this.$refs._basePath = util.path.stripHash(args.schema);

  // Read the schema file/url
  return read(args.schema, this.$refs, args.options)
    .then(function(result) {
      var value = result.$ref.value;
      if (!value || typeof value !== 'object' || value instanceof Buffer) {
        throw ono.syntax('"%s" is not a valid JSON Schema', me.$refs._basePath);
      }
      else {
        me.schema = value;
        return maybe(args.callback, Promise.resolve(me.schema));
      }
    })
    .catch(function(e) {
      return maybe(args.callback, Promise.reject(e));
    });
};

/**
 * Parses the given JSON schema and resolves any JSON references, including references in
 * externally-referenced files.
 *
 * @param {string|object} schema - The file path or URL of the JSON schema. Or a JSON schema object.
 * @param {$RefParserOptions} [options] - Options that determine how the schema is parsed and resolved
 * @param {function} [callback]
 * - An error-first callback. The second parameter is a {@link $Refs} object containing the resolved JSON references
 *
 * @returns {Promise}
 * The returned promise resolves with a {@link $Refs} object containing the resolved JSON references
 */
$RefParser.resolve = function(schema, options, callback) {
  var Class = this; // eslint-disable-line consistent-this
  return new Class().resolve(schema, options, callback);
};

/**
 * Parses the given JSON schema and resolves any JSON references, including references in
 * externally-referenced files.
 *
 * @param {string|object} schema - The file path or URL of the JSON schema. Or a JSON schema object.
 * @param {$RefParserOptions} [options] - Options that determine how the schema is parsed and resolved
 * @param {function} [callback]
 * - An error-first callback. The second parameter is a {@link $Refs} object containing the resolved JSON references
 *
 * @returns {Promise}
 * The returned promise resolves with a {@link $Refs} object containing the resolved JSON references
 */
$RefParser.prototype.resolve = function(schema, options, callback) {
  var me = this;
  var args = normalizeArgs(arguments);

  return this.parse(args.schema, args.options)
    .then(function() {
      return resolve(me, args.options);
    })
    .then(function() {
      return maybe(args.callback, Promise.resolve(me.$refs));
    })
    .catch(function(err) {
      return maybe(args.callback, Promise.reject(err));
    });
};

/**
 * Parses the given JSON schema, resolves any JSON references, and bundles all external references
 * into the main JSON schema. This produces a JSON schema that only has *internal* references,
 * not any *external* references.
 *
 * @param {string|object} schema - The file path or URL of the JSON schema. Or a JSON schema object.
 * @param {$RefParserOptions} [options] - Options that determine how the schema is parsed, resolved, and dereferenced
 * @param {function} [callback] - An error-first callback. The second parameter is the bundled JSON schema object
 * @returns {Promise} - The returned promise resolves with the bundled JSON schema object.
 */
$RefParser.bundle = function(schema, options, callback) {
  var Class = this; // eslint-disable-line consistent-this
  return new Class().bundle(schema, options, callback);
};

/**
 * Parses the given JSON schema, resolves any JSON references, and bundles all external references
 * into the main JSON schema. This produces a JSON schema that only has *internal* references,
 * not any *external* references.
 *
 * @param {string|object} schema - The file path or URL of the JSON schema. Or a JSON schema object.
 * @param {$RefParserOptions} [options] - Options that determine how the schema is parsed, resolved, and dereferenced
 * @param {function} [callback] - An error-first callback. The second parameter is the bundled JSON schema object
 * @returns {Promise} - The returned promise resolves with the bundled JSON schema object.
 */
$RefParser.prototype.bundle = function(schema, options, callback) {
  var me = this;
  var args = normalizeArgs(arguments);

  return this.resolve(args.schema, args.options)
    .then(function() {
      bundle(me, args.options);
      return maybe(args.callback, Promise.resolve(me.schema));
    })
    .catch(function(err) {
      return maybe(args.callback, Promise.reject(err));
    });
};

/**
 * Parses the given JSON schema, resolves any JSON references, and dereferences the JSON schema.
 * That is, all JSON references are replaced with their resolved values.
 *
 * @param {string|object} schema - The file path or URL of the JSON schema. Or a JSON schema object.
 * @param {$RefParserOptions} [options] - Options that determine how the schema is parsed, resolved, and dereferenced
 * @param {function} [callback] - An error-first callback. The second parameter is the dereferenced JSON schema object
 * @returns {Promise} - The returned promise resolves with the dereferenced JSON schema object.
 */
$RefParser.dereference = function(schema, options, callback) {
  var Class = this; // eslint-disable-line consistent-this
  return new Class().dereference(schema, options, callback);
};

/**
 * Parses the given JSON schema, resolves any JSON references, and dereferences the JSON schema.
 * That is, all JSON references are replaced with their resolved values.
 *
 * @param {string|object} schema - The file path or URL of the JSON schema. Or a JSON schema object.
 * @param {$RefParserOptions} [options] - Options that determine how the schema is parsed, resolved, and dereferenced
 * @param {function} [callback] - An error-first callback. The second parameter is the dereferenced JSON schema object
 * @returns {Promise} - The returned promise resolves with the dereferenced JSON schema object.
 */
$RefParser.prototype.dereference = function(schema, options, callback) {
  var me = this;
  var args = normalizeArgs(arguments);

  return this.resolve(args.schema, args.options)
    .then(function() {
      dereference(me, args.options);
      return maybe(args.callback, Promise.resolve(me.schema));
    })
    .catch(function(err) {
      return maybe(args.callback, Promise.reject(err));
    });
};

/**
 * Normalizes the given arguments, accounting for optional args.
 *
 * @param {Arguments} args
 * @returns {object}
 */
function normalizeArgs(args) {
  var options = args[1], callback = args[2];
  if (typeof options === 'function') {
    callback = options;
    options = undefined;
  }
  if (!(options instanceof Options)) {
    options = new Options(options);
  }
  return {
    schema: args[0],
    options: options,
    callback: callback
  };
}

}).call(this,require("buffer").Buffer)

},{"./bundle":1,"./dereference":2,"./options":5,"./promise":9,"./read":10,"./ref":11,"./refs":12,"./resolve":13,"./util":14,"./yaml":15,"buffer":57,"call-me-maybe":16,"ono":54,"url":91}],5:[function(require,module,exports){
/* eslint lines-around-comment: [2, {beforeBlockComment: false}] */
'use strict';

module.exports = $RefParserOptions;

/**
 * Options that determine how JSON schemas are parsed, dereferenced, and cached.
 *
 * @param {object|$RefParserOptions} [options] - Overridden options
 * @constructor
 */
function $RefParserOptions(options) {
  /**
   * Determines what types of files can be parsed
   */
  this.allow = {
    /**
     * Are JSON files allowed?
     * If false, then all schemas must be in YAML format.
     * @type {boolean}
     */
    json: true,

    /**
     * Are YAML files allowed?
     * If false, then all schemas must be in JSON format.
     * @type {boolean}
     */
    yaml: true,

    /**
     * Are zero-byte files allowed?
     * If false, then an error will be thrown if a file is empty.
     * @type {boolean}
     */
    empty: true,

    /**
     * Can unknown file types be $referenced?
     * If true, then they will be parsed as Buffers (byte arrays).
     * If false, then an error will be thrown.
     * @type {boolean}
     */
    unknown: true
  };

  /**
   * Determines the types of JSON references that are allowed.
   */
  this.$refs = {
    /**
     * Allow JSON references to other parts of the same file?
     * @type {boolean}
     */
    internal: true,

    /**
     * Allow JSON references to external files/URLs?
     * @type {boolean}
     */
    external: true,

    /**
     * Allow circular (recursive) JSON references?
     * If false, then a {@link ReferenceError} will be thrown if a circular reference is found.
     * If "ignore", then circular references will not be dereferenced.
     * @type {boolean|string}
     */
    circular: true,

    /**
     * Overrides implementation of internal reader. Default implementation looks at $ref value and decides
     * whether it should use local file or URL reader.
     * @type {function|null}
     */
    read$Ref: null,

    /**
     * Overrides implementation of internal reader for local files.
     * @type {function|null}
     */
    read$RefFile: null,

    /**
     * Overrides implementation of internal reader for URLs.
     * @type {function|null}
     */
    read$RefUrl: null
  };

  /**
   * How long to cache files (in seconds).
   */
  this.cache = {
    /**
     * How long to cache local files, in seconds.
     * @type {number}
     */
    fs: 60, // 1 minute

    /**
     * How long to cache files downloaded via HTTP, in seconds.
     * @type {number}
     */
    http: 5 * 60, // 5 minutes

    /**
     * How long to cache files downloaded via HTTPS, in seconds.
     * @type {number}
     */
    https: 5 * 60 // 5 minutes
  };

  /**
   * HTTP request options
   */
  this.http = {
    /**
     * HTTP headers to send when downloading files.
     */
    headers: {},

    /**
     * HTTP request timeout (in milliseconds).
     */
    timeout: 5000,

    /**
     * The maximum number of HTTP redirects to follow.
     * To disable automatic following of redirects, set this to zero.
     */
    redirects: 5,

    /**
     * The `withCredentials` option of XMLHttpRequest.
     * Set this to `true` if you're downloading files from a CORS-enabled server that requires authentication
     */
    withCredentials: false,

  };

  merge(options, this);
}

/**
 * Fast, two-level object merge.
 *
 * @param {?object} src - The object to merge into dest
 * @param {object} dest - The object to be modified
 */
function merge(src, dest) {
  if (src) {
    var topKeys = Object.keys(src);
    for (var i = 0; i < topKeys.length; i++) {
      var topKey = topKeys[i];
      var srcChild = src[topKey];
      if (dest[topKey] === undefined) {
        dest[topKey] = srcChild;
      }
      else {
        var childKeys = Object.keys(srcChild);
        for (var j = 0; j < childKeys.length; j++) {
          var childKey = childKeys[j];
          var srcChildValue = srcChild[childKey];
          if (srcChildValue !== undefined) {
            dest[topKey][childKey] = srcChildValue;
          }
        }
      }
    }
  }
}

},{}],6:[function(require,module,exports){
(function (Buffer){
'use strict';

var YAML = require('./yaml'),
    util = require('./util'),
    ono  = require('ono');

module.exports = parse;

/**
 * Parses the given data as YAML, JSON, or a raw Buffer (byte array), depending on the options.
 *
 * @param {string|Buffer} data - The data to be parsed
 * @param {string} path - The file path or URL that `data` came from
 * @param {$RefParserOptions} options
 *
 * @returns {string|Buffer|object}
 * If `data` can be parsed as YAML or JSON, then the returned value is a JavaScript object.
 * Otherwise, the returned value is the raw string or Buffer that was passed in.
 */
function parse(data, path, options) {
  var parsed;

  try {
    if (options.allow.yaml) {
      util.debug('Parsing YAML file: %s', path);
      parsed = YAML.parse(data.toString());
      util.debug('    Parsed successfully');
    }
    else if (options.allow.json) {
      util.debug('Parsing JSON file: %s', path);
      parsed = JSON.parse(data.toString());
      util.debug('    Parsed successfully');
    }
    else {
      parsed = data;
    }
  }
  catch (e) {
    var ext = util.path.extname(path);
    if (options.allow.unknown && ['.json', '.yaml', '.yml'].indexOf(ext) === -1) {
      // It's not a YAML or JSON file, and unknown formats are allowed,
      // so ignore the parsing error and just return the raw data
      util.debug('    Unknown file format. Not parsed.');
      parsed = data;
    }
    else {
      throw ono.syntax(e, 'Error parsing "%s"', path);
    }
  }

  if (isEmpty(parsed) && !options.allow.empty) {
    throw ono.syntax('Error parsing "%s". \nParsed value is empty', path);
  }

  return parsed;
}

/**
 * Determines whether the parsed value is "empty".
 *
 * @param {*} value
 * @returns {boolean}
 */
function isEmpty(value) {
  return !value ||
    (typeof value === 'object' && Object.keys(value).length === 0) ||
    (typeof value === 'string' && value.trim().length === 0) ||
    (value instanceof Buffer && value.length === 0);
}

}).call(this,require("buffer").Buffer)

},{"./util":14,"./yaml":15,"buffer":57,"ono":54}],7:[function(require,module,exports){
(function (process){
'use strict';

var isWindows           = /^win/.test(process.platform),
    forwardSlashPattern = /\//g,
    protocolPattern     = /^([a-z0-9.+-]+):\/\//i;

// RegExp patterns to URL-encode special characters in local filesystem paths
var urlEncodePatterns = [
  /\?/g, '%3F',
  /\#/g, '%23',
  isWindows ? /\\/g : /\//, '/'
];

// RegExp patterns to URL-decode special characters for local filesystem paths
var urlDecodePatterns = [
  /\%23/g, '#',
  /\%24/g, '$',
  /\%26/g, '&',
  /\%2C/g, ',',
  /\%40/g, '@'
];

/**
 * Returns the current working directory (in Node) or the current page URL (in browsers).
 *
 * @returns {string}
 */
exports.cwd = function cwd() {
  return process.browser ? location.href : process.cwd() + '/';
};

/**
 * Determines whether the given path is a URL.
 *
 * @param   {string} path
 * @returns {boolean}
 */
exports.isUrl = function isUrl(path) {
  var protocol = protocolPattern.exec(path);
  if (protocol) {
    protocol = protocol[1].toLowerCase();
    return protocol !== 'file';
  }
  return false;
};

/**
 * If the given path is a local filesystem path, it is converted to a URL.
 *
 * @param {string} path
 * @returns {string}
 */
exports.localPathToUrl = function localPathToUrl(path) {
  if (!process.browser && !exports.isUrl(path)) {
    // Manually encode characters that are not encoded by `encodeURI`
    for (var i = 0; i < urlEncodePatterns.length; i += 2) {
      path = path.replace(urlEncodePatterns[i], urlEncodePatterns[i + 1]);
    }
    path = encodeURI(path);
  }
  return path;
};

/**
 * Converts a URL to a local filesystem path
 *
 * @param {string} url
 * @param {boolean} [keepFileProtocol] - If true, then "file://" will NOT be stripped
 * @returns {string}
 */
exports.urlToLocalPath = function urlToLocalPath(url, keepFileProtocol) {
  // Decode URL-encoded characters
  url = decodeURI(url);

  // Manually decode characters that are not decoded by `decodeURI`
  for (var i = 0; i < urlDecodePatterns.length; i += 2) {
    url = url.replace(urlDecodePatterns[i], urlDecodePatterns[i + 1]);
  }

  // Handle "file://" URLs
  var isFileUrl = url.substr(0, 7).toLowerCase() === 'file://';
  if (isFileUrl) {
    var protocol = 'file:///';

    // Remove the third "/" if there is one
    var path = url[7] === '/' ? url.substr(8) : url.substr(7);

    if (isWindows && path[1] === '/') {
      // insert a colon (":") after the drive letter on Windows
      path = path[0] + ':' + path.substr(1);
    }

    if (keepFileProtocol) {
      url = protocol + path;
    }
    else {
      isFileUrl = false;
      url = isWindows ? path : '/' + path;
    }
  }

  // Format path separators on Windows
  if (isWindows && !isFileUrl) {
    url = url.replace(forwardSlashPattern, '\\');
  }

  return url;
};

/**
 * Returns the hash (URL fragment), of the given path.
 * If there is no hash, then the root hash ("#") is returned.
 *
 * @param   {string} path
 * @returns {string}
 */
exports.getHash = function getHash(path) {
  var hashIndex = path.indexOf('#');
  if (hashIndex >= 0) {
    return path.substr(hashIndex);
  }
  return '#';
};

/**
 * Removes the hash (URL fragment), if any, from the given path.
 *
 * @param   {string} path
 * @returns {string}
 */
exports.stripHash = function stripHash(path) {
  var hashIndex = path.indexOf('#');
  if (hashIndex >= 0) {
    path = path.substr(0, hashIndex);
  }
  return path;
};

/**
 * Returns the file extension of the given path.
 *
 * @param   {string} path
 * @returns {string}
 */
exports.extname = function extname(path) {
  var lastDot = path.lastIndexOf('.');
  if (lastDot >= 0) {
    return path.substr(lastDot).toLowerCase();
  }
  return '';
};

}).call(this,require('_process'))

},{"_process":66}],8:[function(require,module,exports){
'use strict';

module.exports = Pointer;

var $Ref         = require('./ref'),
    util         = require('./util'),
    url          = require('url'),
    ono          = require('ono'),
    slashes      = /\//g,
    tildes       = /~/g,
    escapedSlash = /~1/g,
    escapedTilde = /~0/g;

/**
 * This class represents a single JSON pointer and its resolved value.
 *
 * @param {$Ref} $ref
 * @param {string} path
 * @constructor
 */
function Pointer($ref, path) {
  /**
   * The {@link $Ref} object that contains this {@link Pointer} object.
   * @type {$Ref}
   */
  this.$ref = $ref;

  /**
   * The file path or URL, containing the JSON pointer in the hash.
   * This path is relative to the path of the main JSON schema file.
   * @type {string}
   */
  this.path = path;

  /**
   * The value of the JSON pointer.
   * Can be any JSON type, not just objects. Unknown file types are represented as Buffers (byte arrays).
   * @type {?*}
   */
  this.value = undefined;

  /**
   * Indicates whether the pointer references itself.
   * @type {boolean}
   */
  this.circular = false;
}

/**
 * Resolves the value of a nested property within the given object.
 *
 * @param {*} obj - The object that will be crawled
 * @param {$RefParserOptions} [options]
 *
 * @returns {Pointer}
 * Returns a JSON pointer whose {@link Pointer#value} is the resolved value.
 * If resolving this value required resolving other JSON references, then
 * the {@link Pointer#$ref} and {@link Pointer#path} will reflect the resolution path
 * of the resolved value.
 */
Pointer.prototype.resolve = function(obj, options) {
  var tokens = Pointer.parse(this.path);

  // Crawl the object, one token at a time
  this.value = obj;
  for (var i = 0; i < tokens.length; i++) {
    if (resolveIf$Ref(this, options)) {
      // The $ref path has changed, so append the remaining tokens to the path
      this.path = Pointer.join(this.path, tokens.slice(i));
    }

    var token = tokens[i];
    if (this.value[token] === undefined) {
      throw ono.syntax('Error resolving $ref pointer "%s". \nToken "%s" does not exist.', this.path, token);
    }
    else {
      this.value = this.value[token];
    }
  }

  // Resolve the final value
  resolveIf$Ref(this, options);
  return this;
};

/**
 * Sets the value of a nested property within the given object.
 *
 * @param {*} obj - The object that will be crawled
 * @param {*} value - the value to assign
 * @param {$RefParserOptions} [options]
 *
 * @returns {*}
 * Returns the modified object, or an entirely new object if the entire object is overwritten.
 */
Pointer.prototype.set = function(obj, value, options) {
  var tokens = Pointer.parse(this.path);
  var token;

  if (tokens.length === 0) {
    // There are no tokens, replace the entire object with the new value
    this.value = value;
    return value;
  }

  // Crawl the object, one token at a time
  this.value = obj;
  for (var i = 0; i < tokens.length - 1; i++) {
    resolveIf$Ref(this, options);

    token = tokens[i];
    if (this.value && this.value[token] !== undefined) {
      // The token exists
      this.value = this.value[token];
    }
    else {
      // The token doesn't exist, so create it
      this.value = setValue(this, token, {});
    }
  }

  // Set the value of the final token
  resolveIf$Ref(this, options);
  token = tokens[tokens.length - 1];
  setValue(this, token, value);

  // Return the updated object
  return obj;
};

/**
 * Parses a JSON pointer (or a path containing a JSON pointer in the hash)
 * and returns an array of the pointer's tokens.
 * (e.g. "schema.json#/definitions/person/name" => ["definitions", "person", "name"])
 *
 * The pointer is parsed according to RFC 6901
 * {@link https://tools.ietf.org/html/rfc6901#section-3}
 *
 * @param {string} path
 * @returns {string[]}
 */
Pointer.parse = function(path) {
  // Get the JSON pointer from the path's hash
  var pointer = util.path.getHash(path).substr(1);

  // If there's no pointer, then there are no tokens,
  // so return an empty array
  if (!pointer) {
    return [];
  }

  // Split into an array
  pointer = pointer.split('/');

  // Decode each part, according to RFC 6901
  for (var i = 0; i < pointer.length; i++) {
    pointer[i] = decodeURI(pointer[i].replace(escapedSlash, '/').replace(escapedTilde, '~'));
  }

  if (pointer[0] !== '') {
    throw ono.syntax('Invalid $ref pointer "%s". Pointers must begin with "#/"', pointer);
  }

  return pointer.slice(1);
};

/**
 * Creates a JSON pointer path, by joining one or more tokens to a base path.
 *
 * @param {string} base - The base path (e.g. "schema.json#/definitions/person")
 * @param {string|string[]} tokens - The token(s) to append (e.g. ["name", "first"])
 * @returns {string}
 */
Pointer.join = function(base, tokens) {
  // Ensure that the base path contains a hash
  if (base.indexOf('#') === -1) {
    base += '#';
  }

  // Append each token to the base path
  tokens = Array.isArray(tokens) ? tokens : [tokens];
  for (var i = 0; i < tokens.length; i++) {
    var token = tokens[i];
    // Encode the token, according to RFC 6901
    base += '/' + encodeURI(token.replace(tildes, '~0').replace(slashes, '~1'));
  }

  return base;
};

/**
 * If the given pointer's {@link Pointer#value} is a JSON reference,
 * then the reference is resolved and {@link Pointer#value} is replaced with the resolved value.
 * In addition, {@link Pointer#path} and {@link Pointer#$ref} are updated to reflect the
 * resolution path of the new value.
 *
 * @param {Pointer} pointer
 * @param {$RefParserOptions} [options]
 * @returns {boolean} - Returns `true` if the resolution path changed
 */
function resolveIf$Ref(pointer, options) {
  // Is the value a JSON reference? (and allowed?)

  if ($Ref.isAllowed$Ref(pointer.value, options)) {
    var $refPath = url.resolve(pointer.path, pointer.value.$ref);

    if ($refPath === pointer.path) {
      // The value is a reference to itself, so there's nothing to do.
      pointer.circular = true;
    }
    else {
      var resolved = pointer.$ref.$refs._resolve($refPath);

      if (Object.keys(pointer.value).length === 1) {
        // Resolve the reference
        pointer.$ref = resolved.$ref;
        pointer.path = resolved.path;
        pointer.value = resolved.value;
      }
      else {
        // This JSON reference has additional properties (other than "$ref"),
        // so it "extends" the resolved value, rather than simply pointing to it.
        pointer.value = util.dereference(pointer.value, resolved.value);
      }

      return true;
    }
  }
}

/**
 * Sets the specified token value of the {@link Pointer#value}.
 *
 * The token is evaluated according to RFC 6901.
 * {@link https://tools.ietf.org/html/rfc6901#section-4}
 *
 * @param {Pointer} pointer - The JSON Pointer whose value will be modified
 * @param {string} token - A JSON Pointer token that indicates how to modify `obj`
 * @param {*} value - The value to assign
 * @returns {*} - Returns the assigned value
 */
function setValue(pointer, token, value) {
  if (pointer.value && typeof pointer.value === 'object') {
    if (token === '-' && Array.isArray(pointer.value)) {
      pointer.value.push(value);
    }
    else {
      pointer.value[token] = value;
    }
  }
  else {
    throw ono.syntax('Error assigning $ref pointer "%s". \nCannot set "%s" of a non-object.', pointer.path, token);
  }
  return value;
}

},{"./ref":11,"./util":14,"ono":54,"url":91}],9:[function(require,module,exports){
'use strict';

/** @type {Promise} **/
module.exports = typeof Promise === 'function' ? Promise : require('es6-promise').Promise;

},{"es6-promise":20}],10:[function(require,module,exports){
(function (process){
'use strict';

var fs       = require('fs'),
    download = require('./download'),
    parse    = require('./parse'),
    util     = require('./util'),
    $Ref     = require('./ref'),
    Promise  = require('./promise'),
    url      = require('url'),
    ono      = require('ono');

module.exports = read;

/**
 * Reads the specified file path or URL, possibly from cache.
 *
 * @param {string} path - This path MUST already be resolved, since `read` doesn't know the resolution context
 * @param {$Refs} $refs
 * @param {$RefParserOptions} options
 *
 * @returns {Promise}
 * The promise resolves with an object that contains a {@link $Ref}
 * and a flag indicating whether the {@link $Ref} came from cache or not.
 */
function read(path, $refs, options) {
  try {
    // Remove the URL fragment, if any
    path = util.path.stripHash(path);
    util.debug('Reading %s', path);

    // Return from cache, if possible
    var $ref = $refs._get$Ref(path);
    if ($ref && !$ref.isExpired()) {
      util.debug('    cached from %s', $ref.pathType);
      return Promise.resolve({
        $ref: $ref,
        cached: true
      });
    }

    // Add a placeholder $ref to the cache, so we don't read this URL multiple times
    $ref = new $Ref($refs, path);

    // Read and return the $ref
    return read$Ref($ref, options);
  }
  catch (e) {
    return Promise.reject(e);
  }
}

/**
 * Reads the specified file path or URL and updates the given {@link $Ref} accordingly.
 *
 * @param {$Ref} $ref - The {@link $Ref} to read and update
 * @param {$RefParserOptions} options
 *
 * @returns {Promise}
 * The promise resolves with the updated {@link $Ref} object (the same instance that was passed in)
 */
function read$Ref($ref, options) {
  try {
    var promise = options.$refs.external && (
      (options.$refs.read$Ref     && options.$refs.read$Ref($ref, options)) ||
      (options.$refs.read$RefFile || read$RefFile)($ref, options) ||
      (options.$refs.read$RefUrl  || read$RefUrl)($ref, options)
    );

    if (promise) {
      return promise
        .then(function(data) {
          // Update the $ref with the parsed file contents
          var value = parse(data, $ref.path, options);
          $ref.setValue(value, options);

          return {
            $ref: $ref,
            cached: false
          };
        });
    }
    else {
      return Promise.reject(ono.syntax('Unable to resolve $ref pointer "%s"', $ref.path));
    }
  }
  catch (e) {
    return Promise.reject(e);
  }
}

/**
 * If the given {@link $Ref#path} is a local file, then the file is read
 * and {@link $Ref#type} is set to "fs".
 *
 * @param {$Ref} $ref - The {@link $Ref} to read and update
 * @param {$RefParserOptions} options
 *
 * @returns {Promise|undefined}
 * Returns a promise if {@link $Ref#path} is a local file.
 * The promise resolves with the raw file contents.
 */
function read$RefFile($ref, options) {
  if (process.browser || util.path.isUrl($ref.path)) {
    return;
  }

  $ref.pathType = 'fs';
  return new Promise(function(resolve, reject) {
    var file;
    try {
      file = util.path.urlToLocalPath($ref.path);
    }
    catch (err) {
      reject(ono.uri(err, 'Malformed URI: %s', $ref.path));
    }

    util.debug('Opening file: %s', file);

    try {
      fs.readFile(file, function(err, data) {
        if (err) {
          reject(ono(err, 'Error opening file "%s"', $ref.path));
        }
        else {
          resolve(data);
        }
      });
    }
    catch (err) {
      reject(ono(err, 'Error opening file "%s"', file));
    }
  });
}

/**
 * If the given {@link $Ref#path} is a URL, then the file is downloaded
 * and {@link $Ref#type} is set to "http" or "https".
 *
 * @param {$Ref} $ref - The {@link $Ref} to read and update
 * @param {$RefParserOptions} options
 *
 * @returns {Promise|undefined}
 * Returns a promise if {@link $Ref#path} is a URL.
 * The promise resolves with the raw file contents.
 */
function read$RefUrl($ref, options) {
  var u = url.parse($ref.path);

  if (process.browser && !u.protocol) {
    // Use the protocol of the current page
    u.protocol = url.parse(location.href).protocol;
  }

  if (u.protocol === 'http:') {
    $ref.pathType = 'http';
    return download(u, options);
  }
  else if (u.protocol === 'https:') {
    $ref.pathType = 'https';
    return download(u, options);
  }
}

}).call(this,require('_process'))

},{"./download":3,"./parse":6,"./promise":9,"./ref":11,"./util":14,"_process":66,"fs":55,"ono":54,"url":91}],11:[function(require,module,exports){
'use strict';

module.exports = $Ref;

var Pointer = require('./pointer'),
    util    = require('./util');

/**
 * This class represents a single JSON reference and its resolved value.
 *
 * @param {$Refs} $refs
 * @param {string} path
 * @constructor
 */
function $Ref($refs, path) {
  path = util.path.stripHash(path);

  // Add this $ref to its parent collection
  $refs._$refs[path] = this;

  /**
   * The {@link $Refs} object that contains this {@link $Ref} object.
   * @type {$Refs}
   */
  this.$refs = $refs;

  /**
   * The file path or URL of the referenced file.
   * This path is relative to the path of the main JSON schema file.
   *
   * This path does NOT contain document fragments (JSON pointers). It always references an ENTIRE file.
   * Use methods such as {@link $Ref#get}, {@link $Ref#resolve}, and {@link $Ref#exists} to get
   * specific JSON pointers within the file.
   *
   * @type {string}
   */
  this.path = path;

  /**
   * Indicates the type of {@link $Ref#path} (e.g. "fs", "http", or "https")
   * @type {?string}
   */
  this.pathType = undefined;

  /**
   * The resolved value of the JSON reference.
   * Can be any JSON type, not just objects. Unknown file types are represented as Buffers (byte arrays).
   * @type {?*}
   */
  this.value = undefined;

  /**
   * The date/time that the cached value will expire.
   * @type {?Date}
   */
  this.expires = undefined;
}

/**
 * Determines whether the {@link $Ref#value} has expired.
 *
 * @returns {boolean}
 */
$Ref.prototype.isExpired = function() {
  return !!(this.expires && this.expires <= new Date());
};

/**
 * Immediately expires the {@link $Ref#value}.
 */
$Ref.prototype.expire = function() {
  this.expires = new Date();
};

/**
 * Sets the {@link $Ref#value} and renews the cache expiration.
 *
 * @param {*} value
 * @param {$RefParserOptions} options
 */
$Ref.prototype.setValue = function(value, options) {
  this.value = value;

  // Extend the cache expiration
  var cacheDuration = options.cache[this.pathType];
  if (cacheDuration > 0) {
    var expires = Date.now() + (cacheDuration * 1000);
    this.expires = new Date(expires);
  }
};

/**
 * Determines whether the given JSON reference exists within this {@link $Ref#value}.
 *
 * @param {string} path - The full path being resolved, optionally with a JSON pointer in the hash
 * @returns {boolean}
 */
$Ref.prototype.exists = function(path) {
  try {
    this.resolve(path);
    return true;
  }
  catch (e) {
    return false;
  }
};

/**
 * Resolves the given JSON reference within this {@link $Ref#value} and returns the resolved value.
 *
 * @param {string} path - The full path being resolved, optionally with a JSON pointer in the hash
 * @param {$RefParserOptions} options
 * @returns {*} - Returns the resolved value
 */
$Ref.prototype.get = function(path, options) {
  return this.resolve(path, options).value;
};

/**
 * Resolves the given JSON reference within this {@link $Ref#value}.
 *
 * @param {string} path - The full path being resolved, optionally with a JSON pointer in the hash
 * @param {$RefParserOptions} options
 * @returns {Pointer}
 */
$Ref.prototype.resolve = function(path, options) {
  var pointer = new Pointer(this, path);
  return pointer.resolve(this.value, options);
};

/**
 * Sets the value of a nested property within this {@link $Ref#value}.
 * If the property, or any of its parents don't exist, they will be created.
 *
 * @param {string} path - The full path of the property to set, optionally with a JSON pointer in the hash
 * @param {*} value - The value to assign
 * @param {$RefParserOptions} options
 */
$Ref.prototype.set = function(path, value, options) {
  var pointer = new Pointer(this, path);
  this.value = pointer.set(this.value, value, options);
};

/**
 * Determines whether the given value is a JSON reference.
 *
 * @param {*} value - The value to inspect
 * @returns {boolean}
 */
$Ref.is$Ref = function(value) {
  return value && typeof value === 'object' && typeof value.$ref === 'string' && value.$ref.length > 0;
};

/**
 * Determines whether the given value is an external JSON reference.
 *
 * @param {*} value - The value to inspect
 * @returns {boolean}
 */
$Ref.isExternal$Ref = function(value) {
  return $Ref.is$Ref(value) && value.$ref[0] !== '#';
};

/**
 * Determines whether the given value is a JSON reference, and whether it is allowed by the options.
 * For example, if it references an external file, then options.$refs.external must be true.
 *
 * @param {*} value - The value to inspect
 * @param {$RefParserOptions} options
 * @returns {boolean}
 */
$Ref.isAllowed$Ref = function(value, options) {
  if ($Ref.is$Ref(value)) {
    if (value.$ref[0] === '#') {
      if (options.$refs.internal) {
        return true;
      }
    }
    else if (options.$refs.external) {
      return true;
    }
  }
};

},{"./pointer":8,"./util":14}],12:[function(require,module,exports){
'use strict';

var Options = require('./options'),
    util    = require('./util'),
    url     = require('url'),
    ono     = require('ono');

module.exports = $Refs;

/**
 * This class is a map of JSON references and their resolved values.
 */
function $Refs() {
  /**
   * Indicates whether the schema contains any circular references.
   *
   * @type {boolean}
   */
  this.circular = false;

  /**
   * The file path or URL of the main JSON schema file.
   * This will be empty if the schema was passed as an object rather than a path.
   *
   * @type {string}
   * @protected
   */
  this._basePath = '';

  /**
   * A map of paths/urls to {@link $Ref} objects
   *
   * @type {object}
   * @protected
   */
  this._$refs = {};
}

/**
 * Returns the paths of all the files/URLs that are referenced by the JSON schema,
 * including the schema itself.
 *
 * @param {...string|string[]} [types] - Only return paths of the given types ("fs", "http", "https")
 * @returns {string[]}
 */
$Refs.prototype.paths = function(types) {
  var paths = getPaths(this._$refs, arguments);
  return paths.map(function(path) {
    return path.decoded;
  });
};

/**
 * Returns the map of JSON references and their resolved values.
 *
 * @param {...string|string[]} [types] - Only return references of the given types ("fs", "http", "https")
 * @returns {object}
 */
$Refs.prototype.values = function(types) {
  var $refs = this._$refs;
  var paths = getPaths($refs, arguments);
  return paths.reduce(function(obj, path) {
    obj[path.decoded] = $refs[path.encoded].value;
    return obj;
  }, {});
};

/**
 * Returns a POJO (plain old JavaScript object) for serialization as JSON.
 *
 * @returns {object}
 */
$Refs.prototype.toJSON = $Refs.prototype.values;

/**
 * Determines whether the given JSON reference has expired.
 * Returns true if the reference does not exist.
 *
 * @param {string} path - The path being resolved, optionally with a JSON pointer in the hash
 * @returns {boolean}
 */
$Refs.prototype.isExpired = function(path) {
  var $ref = this._get$Ref(path);
  return $ref === undefined || $ref.isExpired();
};

/**
 * Immediately expires the given JSON reference.
 * If the reference does not exist, nothing happens.
 *
 * @param {string} path - The path being resolved, optionally with a JSON pointer in the hash
 */
$Refs.prototype.expire = function(path) {
  var $ref = this._get$Ref(path);
  if ($ref) {
    $ref.expire();
  }
};

/**
 * Determines whether the given JSON reference exists.
 *
 * @param {string} path - The path being resolved, optionally with a JSON pointer in the hash
 * @returns {boolean}
 */
$Refs.prototype.exists = function(path) {
  try {
    this._resolve(path);
    return true;
  }
  catch (e) {
    return false;
  }
};

/**
 * Resolves the given JSON reference and returns the resolved value.
 *
 * @param {string} path - The path being resolved, with a JSON pointer in the hash
 * @param {$RefParserOptions} options
 * @returns {*} - Returns the resolved value
 */
$Refs.prototype.get = function(path, options) {
  return this._resolve(path, options).value;
};

/**
 * Sets the value of a nested property within this {@link $Ref#value}.
 * If the property, or any of its parents don't exist, they will be created.
 *
 * @param {string} path - The path of the property to set, optionally with a JSON pointer in the hash
 * @param {*} value - The value to assign
 * @param {$RefParserOptions} options
 */
$Refs.prototype.set = function(path, value, options) {
  path = url.resolve(this._basePath, path);
  var withoutHash = util.path.stripHash(path);
  var $ref = this._$refs[withoutHash];

  if (!$ref) {
    throw ono('Error resolving $ref pointer "%s". \n"%s" not found.', path, withoutHash);
  }

  options = new Options(options);
  $ref.set(path, value, options);
};

/**
 * Resolves the given JSON reference.
 *
 * @param {string} path - The path being resolved, optionally with a JSON pointer in the hash
 * @param {$RefParserOptions} options
 * @returns {Pointer}
 * @protected
 */
$Refs.prototype._resolve = function(path, options) {
  path = url.resolve(this._basePath, path);
  var withoutHash = util.path.stripHash(path);
  var $ref = this._$refs[withoutHash];

  if (!$ref) {
    throw ono('Error resolving $ref pointer "%s". \n"%s" not found.', path, withoutHash);
  }

  options = new Options(options);
  return $ref.resolve(path, options);
};

/**
 * Returns the specified {@link $Ref} object, or undefined.
 *
 * @param {string} path - The path being resolved, optionally with a JSON pointer in the hash
 * @returns {$Ref|undefined}
 * @protected
 */
$Refs.prototype._get$Ref = function(path) {
  path = url.resolve(this._basePath, path);
  var withoutHash = util.path.stripHash(path);
  return this._$refs[withoutHash];
};

/**
 * Returns the encoded and decoded paths keys of the given object.
 *
 * @param {object} $refs - The object whose keys are URL-encoded paths
 * @param {...string|string[]} [types] - Only return paths of the given types ("fs", "http", "https")
 * @returns {object[]}
 */
function getPaths($refs, types) {
  var paths = Object.keys($refs);

  // Filter the paths by type
  types = Array.isArray(types[0]) ? types[0] : Array.prototype.slice.call(types);
  if (types.length > 0 && types[0]) {
    paths = paths.filter(function(key) {
      return types.indexOf($refs[key].pathType) !== -1;
    });
  }

  // Decode local filesystem paths
  return paths.map(function(path) {
    return {
      encoded: path,
      decoded: $refs[path].pathType === 'fs' ? util.path.urlToLocalPath(path, true) : path
    };
  });
}

},{"./options":5,"./util":14,"ono":54,"url":91}],13:[function(require,module,exports){
'use strict';

var Promise = require('./promise'),
    $Ref    = require('./ref'),
    Pointer = require('./pointer'),
    read    = require('./read'),
    util    = require('./util'),
    url     = require('url');

module.exports = resolve;

/**
 * Crawls the JSON schema, finds all external JSON references, and resolves their values.
 * This method does not mutate the JSON schema. The resolved values are added to {@link $RefParser#$refs}.
 *
 * NOTE: We only care about EXTERNAL references here. INTERNAL references are only relevant when dereferencing.
 *
 * @param {$RefParser} parser
 * @param {$RefParserOptions} options
 *
 * @returns {Promise}
 * The promise resolves once all JSON references in the schema have been resolved,
 * including nested references that are contained in externally-referenced files.
 */
function resolve(parser, options) {
  try {
    if (!options.$refs.external) {
      // Nothing to resolve, so exit early
      return Promise.resolve();
    }

    util.debug('Resolving $ref pointers in %s', parser.$refs._basePath);
    var promises = crawl(parser.schema, parser.$refs._basePath + '#', parser.$refs, options);
    return Promise.all(promises);
  }
  catch (e) {
    return Promise.reject(e);
  }
}

/**
 * Recursively crawls the given value, and resolves any external JSON references.
 *
 * @param {*} obj - The value to crawl. If it's not an object or array, it will be ignored.
 * @param {string} path - The full path of `obj`, possibly with a JSON Pointer in the hash
 * @param {$Refs} $refs
 * @param {$RefParserOptions} options
 *
 * @returns {Promise[]}
 * Returns an array of promises. There will be one promise for each JSON reference in `obj`.
 * If `obj` does not contain any JSON references, then the array will be empty.
 * If any of the JSON references point to files that contain additional JSON references,
 * then the corresponding promise will internally reference an array of promises.
 */
function crawl(obj, path, $refs, options) {
  var promises = [];

  if (obj && typeof obj === 'object') {
    Object.keys(obj).forEach(function(key) {
      var keyPath = Pointer.join(path, key);
      var value = obj[key];

      if ($Ref.isExternal$Ref(value)) {
        var promise = resolve$Ref(value, keyPath, $refs, options);
        promises.push(promise);
      }
      else {
        promises = promises.concat(crawl(value, keyPath, $refs, options));
      }
    });
  }
  return promises;
}

/**
 * Resolves the given JSON Reference, and then crawls the resulting value.
 *
 * @param {{$ref: string}} $ref - The JSON Reference to resolve
 * @param {string} path - The full path of `$ref`, possibly with a JSON Pointer in the hash
 * @param {$Refs} $refs
 * @param {$RefParserOptions} options
 *
 * @returns {Promise}
 * The promise resolves once all JSON references in the object have been resolved,
 * including nested references that are contained in externally-referenced files.
 */
function resolve$Ref($ref, path, $refs, options) {
  util.debug('Resolving $ref pointer "%s" at %s', $ref.$ref, path);
  var resolvedPath = url.resolve(path, $ref.$ref);

  return read(resolvedPath, $refs, options)
    .then(function(result) {
      // If the result was already cached, then we DON'T need to crawl it
      if (!result.cached) {
        // Crawl the new $ref
        util.debug('Resolving $ref pointers in %s', result.$ref.path);
        var promises = crawl(result.$ref.value, result.$ref.path + '#', $refs, options);
        return Promise.all(promises);
      }
    });
}

},{"./pointer":8,"./promise":9,"./read":10,"./ref":11,"./util":14,"url":91}],14:[function(require,module,exports){
'use strict';

var debug = require('debug'),
    path  = require('./path');

/**
 * Writes messages to stdout.
 * Log messages are suppressed by default, but can be enabled by setting the DEBUG variable.
 * @type {function}
 */
exports.debug = debug('json-schema-ref-parser');

exports.path = path;

/**
 * Returns the resolved value of a JSON Reference.
 * If necessary, the resolved value is merged with the JSON Reference to create a new object
 *
 * @example:
 *  {
 *    person: {
 *      properties: {
 *        firstName: { type: string }
 *        lastName: { type: string }
 *      }
 *    }
 *    employee: {
 *      properties: {
 *        $ref: #/person/properties
 *        salary: { type: number }
 *      }
 *    }
 *  }
 *
 *  When "person" and "employee" are merged, you end up with the following object:
 *
 *  {
 *    properties: {
 *      firstName: { type: string }
 *      lastName: { type: string }
 *      salary: { type: number }
 *    }
 *  }
 *
 * @param {object} $ref - The JSON reference object (the one with the "$ref" property)
 * @param {*} resolvedValue - The resolved value, which can be any type
 * @returns {*} - Returns the dereferenced value
 */
exports.dereference = function($ref, resolvedValue) {
  if (resolvedValue && typeof resolvedValue === 'object' && Object.keys($ref).length > 1) {
    var merged = {};
    Object.keys($ref).forEach(function(key) {
      if (key !== '$ref') {
        merged[key] = $ref[key];
      }
    });
    Object.keys(resolvedValue).forEach(function(key) {
      if (!(key in merged)) {
        merged[key] = resolvedValue[key];
      }
    });
    return merged;
  }
  else {
    // Completely replace the original reference with the resolved value
    return resolvedValue;
  }
};

},{"./path":7,"debug":17}],15:[function(require,module,exports){
/* eslint lines-around-comment: [2, {beforeBlockComment: false}] */
'use strict';

var yaml = require('js-yaml'),
    ono  = require('ono');

/**
 * Simple YAML parsing functions, similar to {@link JSON.parse} and {@link JSON.stringify}
 */
module.exports = {
  /**
   * Parses a YAML string and returns the value.
   *
   * @param {string} text - The YAML string to be parsed
   * @param {function} [reviver] - Not currently supported. Provided for consistency with {@link JSON.parse}
   * @returns {*}
   */
  parse: function yamlParse(text, reviver) {
    try {
      return yaml.safeLoad(text);
    }
    catch (e) {
      if (e instanceof Error) {
        throw e;
      }
      else {
        // https://github.com/nodeca/js-yaml/issues/153
        throw ono(e, e.message);
      }
    }
  },

  /**
   * Converts a JavaScript value to a YAML string.
   *
   * @param   {*} value - The value to convert to YAML
   * @param   {function|array} replacer - Not currently supported. Provided for consistency with {@link JSON.stringify}
   * @param   {string|number} space - The number of spaces to use for indentation, or a string containing the number of spaces.
   * @returns {string}
   */
  stringify: function yamlStringify(value, replacer, space) {
    try {
      var indent = (typeof space === 'string' ? space.length : space) || 2;
      return yaml.safeDump(value, {indent: indent});
    }
    catch (e) {
      if (e instanceof Error) {
        throw e;
      }
      else {
        // https://github.com/nodeca/js-yaml/issues/153
        throw ono(e, e.message);
      }
    }
  }
};

},{"js-yaml":21,"ono":54}],16:[function(require,module,exports){
(function (process,global){
"use strict"

var next = (global.process && process.nextTick) || global.setImmediate || function (f) {
  setTimeout(f, 0)
}

module.exports = function maybe (cb, promise) {
  if (cb) {
    promise
      .then(function (result) {
        next(function () { cb(null, result) })
      }, function (err) {
        next(function () { cb(err) })
      })
    return undefined
  }
  else {
    return promise
  }
}

}).call(this,require('_process'),typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {})

},{"_process":66}],17:[function(require,module,exports){

/**
 * This is the web browser implementation of `debug()`.
 *
 * Expose `debug()` as the module.
 */

exports = module.exports = require('./debug');
exports.log = log;
exports.formatArgs = formatArgs;
exports.save = save;
exports.load = load;
exports.useColors = useColors;
exports.storage = 'undefined' != typeof chrome
               && 'undefined' != typeof chrome.storage
                  ? chrome.storage.local
                  : localstorage();

/**
 * Colors.
 */

exports.colors = [
  'lightseagreen',
  'forestgreen',
  'goldenrod',
  'dodgerblue',
  'darkorchid',
  'crimson'
];

/**
 * Currently only WebKit-based Web Inspectors, Firefox >= v31,
 * and the Firebug extension (any Firefox version) are known
 * to support "%c" CSS customizations.
 *
 * TODO: add a `localStorage` variable to explicitly enable/disable colors
 */

function useColors() {
  // is webkit? http://stackoverflow.com/a/16459606/376773
  return ('WebkitAppearance' in document.documentElement.style) ||
    // is firebug? http://stackoverflow.com/a/398120/376773
    (window.console && (console.firebug || (console.exception && console.table))) ||
    // is firefox >= v31?
    // https://developer.mozilla.org/en-US/docs/Tools/Web_Console#Styling_messages
    (navigator.userAgent.toLowerCase().match(/firefox\/(\d+)/) && parseInt(RegExp.$1, 10) >= 31);
}

/**
 * Map %j to `JSON.stringify()`, since no Web Inspectors do that by default.
 */

exports.formatters.j = function(v) {
  return JSON.stringify(v);
};


/**
 * Colorize log arguments if enabled.
 *
 * @api public
 */

function formatArgs() {
  var args = arguments;
  var useColors = this.useColors;

  args[0] = (useColors ? '%c' : '')
    + this.namespace
    + (useColors ? ' %c' : ' ')
    + args[0]
    + (useColors ? '%c ' : ' ')
    + '+' + exports.humanize(this.diff);

  if (!useColors) return args;

  var c = 'color: ' + this.color;
  args = [args[0], c, 'color: inherit'].concat(Array.prototype.slice.call(args, 1));

  // the final "%c" is somewhat tricky, because there could be other
  // arguments passed either before or after the %c, so we need to
  // figure out the correct index to insert the CSS into
  var index = 0;
  var lastC = 0;
  args[0].replace(/%[a-z%]/g, function(match) {
    if ('%%' === match) return;
    index++;
    if ('%c' === match) {
      // we only are interested in the *last* %c
      // (the user may have provided their own)
      lastC = index;
    }
  });

  args.splice(lastC, 0, c);
  return args;
}

/**
 * Invokes `console.log()` when available.
 * No-op when `console.log` is not a "function".
 *
 * @api public
 */

function log() {
  // this hackery is required for IE8/9, where
  // the `console.log` function doesn't have 'apply'
  return 'object' === typeof console
    && console.log
    && Function.prototype.apply.call(console.log, console, arguments);
}

/**
 * Save `namespaces`.
 *
 * @param {String} namespaces
 * @api private
 */

function save(namespaces) {
  try {
    if (null == namespaces) {
      exports.storage.removeItem('debug');
    } else {
      exports.storage.debug = namespaces;
    }
  } catch(e) {}
}

/**
 * Load `namespaces`.
 *
 * @return {String} returns the previously persisted debug modes
 * @api private
 */

function load() {
  var r;
  try {
    r = exports.storage.debug;
  } catch(e) {}
  return r;
}

/**
 * Enable namespaces listed in `localStorage.debug` initially.
 */

exports.enable(load());

/**
 * Localstorage attempts to return the localstorage.
 *
 * This is necessary because safari throws
 * when a user disables cookies/localstorage
 * and you attempt to access it.
 *
 * @return {LocalStorage}
 * @api private
 */

function localstorage(){
  try {
    return window.localStorage;
  } catch (e) {}
}

},{"./debug":18}],18:[function(require,module,exports){

/**
 * This is the common logic for both the Node.js and web browser
 * implementations of `debug()`.
 *
 * Expose `debug()` as the module.
 */

exports = module.exports = debug;
exports.coerce = coerce;
exports.disable = disable;
exports.enable = enable;
exports.enabled = enabled;
exports.humanize = require('ms');

/**
 * The currently active debug mode names, and names to skip.
 */

exports.names = [];
exports.skips = [];

/**
 * Map of special "%n" handling functions, for the debug "format" argument.
 *
 * Valid key names are a single, lowercased letter, i.e. "n".
 */

exports.formatters = {};

/**
 * Previously assigned color.
 */

var prevColor = 0;

/**
 * Previous log timestamp.
 */

var prevTime;

/**
 * Select a color.
 *
 * @return {Number}
 * @api private
 */

function selectColor() {
  return exports.colors[prevColor++ % exports.colors.length];
}

/**
 * Create a debugger with the given `namespace`.
 *
 * @param {String} namespace
 * @return {Function}
 * @api public
 */

function debug(namespace) {

  // define the `disabled` version
  function disabled() {
  }
  disabled.enabled = false;

  // define the `enabled` version
  function enabled() {

    var self = enabled;

    // set `diff` timestamp
    var curr = +new Date();
    var ms = curr - (prevTime || curr);
    self.diff = ms;
    self.prev = prevTime;
    self.curr = curr;
    prevTime = curr;

    // add the `color` if not set
    if (null == self.useColors) self.useColors = exports.useColors();
    if (null == self.color && self.useColors) self.color = selectColor();

    var args = Array.prototype.slice.call(arguments);

    args[0] = exports.coerce(args[0]);

    if ('string' !== typeof args[0]) {
      // anything else let's inspect with %o
      args = ['%o'].concat(args);
    }

    // apply any `formatters` transformations
    var index = 0;
    args[0] = args[0].replace(/%([a-z%])/g, function(match, format) {
      // if we encounter an escaped % then don't increase the array index
      if (match === '%%') return match;
      index++;
      var formatter = exports.formatters[format];
      if ('function' === typeof formatter) {
        var val = args[index];
        match = formatter.call(self, val);

        // now we need to remove `args[index]` since it's inlined in the `format`
        args.splice(index, 1);
        index--;
      }
      return match;
    });

    if ('function' === typeof exports.formatArgs) {
      args = exports.formatArgs.apply(self, args);
    }
    var logFn = enabled.log || exports.log || console.log.bind(console);
    logFn.apply(self, args);
  }
  enabled.enabled = true;

  var fn = exports.enabled(namespace) ? enabled : disabled;

  fn.namespace = namespace;

  return fn;
}

/**
 * Enables a debug mode by namespaces. This can include modes
 * separated by a colon and wildcards.
 *
 * @param {String} namespaces
 * @api public
 */

function enable(namespaces) {
  exports.save(namespaces);

  var split = (namespaces || '').split(/[\s,]+/);
  var len = split.length;

  for (var i = 0; i < len; i++) {
    if (!split[i]) continue; // ignore empty strings
    namespaces = split[i].replace(/\*/g, '.*?');
    if (namespaces[0] === '-') {
      exports.skips.push(new RegExp('^' + namespaces.substr(1) + '$'));
    } else {
      exports.names.push(new RegExp('^' + namespaces + '$'));
    }
  }
}

/**
 * Disable debug output.
 *
 * @api public
 */

function disable() {
  exports.enable('');
}

/**
 * Returns true if the given mode name is enabled, false otherwise.
 *
 * @param {String} name
 * @return {Boolean}
 * @api public
 */

function enabled(name) {
  var i, len;
  for (i = 0, len = exports.skips.length; i < len; i++) {
    if (exports.skips[i].test(name)) {
      return false;
    }
  }
  for (i = 0, len = exports.names.length; i < len; i++) {
    if (exports.names[i].test(name)) {
      return true;
    }
  }
  return false;
}

/**
 * Coerce `val`.
 *
 * @param {Mixed} val
 * @return {Mixed}
 * @api private
 */

function coerce(val) {
  if (val instanceof Error) return val.stack || val.message;
  return val;
}

},{"ms":19}],19:[function(require,module,exports){
/**
 * Helpers.
 */

var s = 1000;
var m = s * 60;
var h = m * 60;
var d = h * 24;
var y = d * 365.25;

/**
 * Parse or format the given `val`.
 *
 * Options:
 *
 *  - `long` verbose formatting [false]
 *
 * @param {String|Number} val
 * @param {Object} options
 * @return {String|Number}
 * @api public
 */

module.exports = function(val, options){
  options = options || {};
  if ('string' == typeof val) return parse(val);
  return options.long
    ? long(val)
    : short(val);
};

/**
 * Parse the given `str` and return milliseconds.
 *
 * @param {String} str
 * @return {Number}
 * @api private
 */

function parse(str) {
  str = '' + str;
  if (str.length > 10000) return;
  var match = /^((?:\d+)?\.?\d+) *(milliseconds?|msecs?|ms|seconds?|secs?|s|minutes?|mins?|m|hours?|hrs?|h|days?|d|years?|yrs?|y)?$/i.exec(str);
  if (!match) return;
  var n = parseFloat(match[1]);
  var type = (match[2] || 'ms').toLowerCase();
  switch (type) {
    case 'years':
    case 'year':
    case 'yrs':
    case 'yr':
    case 'y':
      return n * y;
    case 'days':
    case 'day':
    case 'd':
      return n * d;
    case 'hours':
    case 'hour':
    case 'hrs':
    case 'hr':
    case 'h':
      return n * h;
    case 'minutes':
    case 'minute':
    case 'mins':
    case 'min':
    case 'm':
      return n * m;
    case 'seconds':
    case 'second':
    case 'secs':
    case 'sec':
    case 's':
      return n * s;
    case 'milliseconds':
    case 'millisecond':
    case 'msecs':
    case 'msec':
    case 'ms':
      return n;
  }
}

/**
 * Short format for `ms`.
 *
 * @param {Number} ms
 * @return {String}
 * @api private
 */

function short(ms) {
  if (ms >= d) return Math.round(ms / d) + 'd';
  if (ms >= h) return Math.round(ms / h) + 'h';
  if (ms >= m) return Math.round(ms / m) + 'm';
  if (ms >= s) return Math.round(ms / s) + 's';
  return ms + 'ms';
}

/**
 * Long format for `ms`.
 *
 * @param {Number} ms
 * @return {String}
 * @api private
 */

function long(ms) {
  return plural(ms, d, 'day')
    || plural(ms, h, 'hour')
    || plural(ms, m, 'minute')
    || plural(ms, s, 'second')
    || ms + ' ms';
}

/**
 * Pluralization helper.
 */

function plural(ms, n, name) {
  if (ms < n) return;
  if (ms < n * 1.5) return Math.floor(ms / n) + ' ' + name;
  return Math.ceil(ms / n) + ' ' + name + 's';
}

},{}],20:[function(require,module,exports){
(function (process,global){
/*!
 * @overview es6-promise - a tiny implementation of Promises/A+.
 * @copyright Copyright (c) 2014 Yehuda Katz, Tom Dale, Stefan Penner and contributors (Conversion to ES6 API by Jake Archibald)
 * @license   Licensed under MIT license
 *            See https://raw.githubusercontent.com/jakearchibald/es6-promise/master/LICENSE
 * @version   3.0.2
 */

(function() {
    "use strict";
    function lib$es6$promise$utils$$objectOrFunction(x) {
      return typeof x === 'function' || (typeof x === 'object' && x !== null);
    }

    function lib$es6$promise$utils$$isFunction(x) {
      return typeof x === 'function';
    }

    function lib$es6$promise$utils$$isMaybeThenable(x) {
      return typeof x === 'object' && x !== null;
    }

    var lib$es6$promise$utils$$_isArray;
    if (!Array.isArray) {
      lib$es6$promise$utils$$_isArray = function (x) {
        return Object.prototype.toString.call(x) === '[object Array]';
      };
    } else {
      lib$es6$promise$utils$$_isArray = Array.isArray;
    }

    var lib$es6$promise$utils$$isArray = lib$es6$promise$utils$$_isArray;
    var lib$es6$promise$asap$$len = 0;
    var lib$es6$promise$asap$$toString = {}.toString;
    var lib$es6$promise$asap$$vertxNext;
    var lib$es6$promise$asap$$customSchedulerFn;

    var lib$es6$promise$asap$$asap = function asap(callback, arg) {
      lib$es6$promise$asap$$queue[lib$es6$promise$asap$$len] = callback;
      lib$es6$promise$asap$$queue[lib$es6$promise$asap$$len + 1] = arg;
      lib$es6$promise$asap$$len += 2;
      if (lib$es6$promise$asap$$len === 2) {
        // If len is 2, that means that we need to schedule an async flush.
        // If additional callbacks are queued before the queue is flushed, they
        // will be processed by this flush that we are scheduling.
        if (lib$es6$promise$asap$$customSchedulerFn) {
          lib$es6$promise$asap$$customSchedulerFn(lib$es6$promise$asap$$flush);
        } else {
          lib$es6$promise$asap$$scheduleFlush();
        }
      }
    }

    function lib$es6$promise$asap$$setScheduler(scheduleFn) {
      lib$es6$promise$asap$$customSchedulerFn = scheduleFn;
    }

    function lib$es6$promise$asap$$setAsap(asapFn) {
      lib$es6$promise$asap$$asap = asapFn;
    }

    var lib$es6$promise$asap$$browserWindow = (typeof window !== 'undefined') ? window : undefined;
    var lib$es6$promise$asap$$browserGlobal = lib$es6$promise$asap$$browserWindow || {};
    var lib$es6$promise$asap$$BrowserMutationObserver = lib$es6$promise$asap$$browserGlobal.MutationObserver || lib$es6$promise$asap$$browserGlobal.WebKitMutationObserver;
    var lib$es6$promise$asap$$isNode = typeof process !== 'undefined' && {}.toString.call(process) === '[object process]';

    // test for web worker but not in IE10
    var lib$es6$promise$asap$$isWorker = typeof Uint8ClampedArray !== 'undefined' &&
      typeof importScripts !== 'undefined' &&
      typeof MessageChannel !== 'undefined';

    // node
    function lib$es6$promise$asap$$useNextTick() {
      // node version 0.10.x displays a deprecation warning when nextTick is used recursively
      // see https://github.com/cujojs/when/issues/410 for details
      return function() {
        process.nextTick(lib$es6$promise$asap$$flush);
      };
    }

    // vertx
    function lib$es6$promise$asap$$useVertxTimer() {
      return function() {
        lib$es6$promise$asap$$vertxNext(lib$es6$promise$asap$$flush);
      };
    }

    function lib$es6$promise$asap$$useMutationObserver() {
      var iterations = 0;
      var observer = new lib$es6$promise$asap$$BrowserMutationObserver(lib$es6$promise$asap$$flush);
      var node = document.createTextNode('');
      observer.observe(node, { characterData: true });

      return function() {
        node.data = (iterations = ++iterations % 2);
      };
    }

    // web worker
    function lib$es6$promise$asap$$useMessageChannel() {
      var channel = new MessageChannel();
      channel.port1.onmessage = lib$es6$promise$asap$$flush;
      return function () {
        channel.port2.postMessage(0);
      };
    }

    function lib$es6$promise$asap$$useSetTimeout() {
      return function() {
        setTimeout(lib$es6$promise$asap$$flush, 1);
      };
    }

    var lib$es6$promise$asap$$queue = new Array(1000);
    function lib$es6$promise$asap$$flush() {
      for (var i = 0; i < lib$es6$promise$asap$$len; i+=2) {
        var callback = lib$es6$promise$asap$$queue[i];
        var arg = lib$es6$promise$asap$$queue[i+1];

        callback(arg);

        lib$es6$promise$asap$$queue[i] = undefined;
        lib$es6$promise$asap$$queue[i+1] = undefined;
      }

      lib$es6$promise$asap$$len = 0;
    }

    function lib$es6$promise$asap$$attemptVertx() {
      try {
        var r = require;
        var vertx = r('vertx');
        lib$es6$promise$asap$$vertxNext = vertx.runOnLoop || vertx.runOnContext;
        return lib$es6$promise$asap$$useVertxTimer();
      } catch(e) {
        return lib$es6$promise$asap$$useSetTimeout();
      }
    }

    var lib$es6$promise$asap$$scheduleFlush;
    // Decide what async method to use to triggering processing of queued callbacks:
    if (lib$es6$promise$asap$$isNode) {
      lib$es6$promise$asap$$scheduleFlush = lib$es6$promise$asap$$useNextTick();
    } else if (lib$es6$promise$asap$$BrowserMutationObserver) {
      lib$es6$promise$asap$$scheduleFlush = lib$es6$promise$asap$$useMutationObserver();
    } else if (lib$es6$promise$asap$$isWorker) {
      lib$es6$promise$asap$$scheduleFlush = lib$es6$promise$asap$$useMessageChannel();
    } else if (lib$es6$promise$asap$$browserWindow === undefined && typeof require === 'function') {
      lib$es6$promise$asap$$scheduleFlush = lib$es6$promise$asap$$attemptVertx();
    } else {
      lib$es6$promise$asap$$scheduleFlush = lib$es6$promise$asap$$useSetTimeout();
    }

    function lib$es6$promise$$internal$$noop() {}

    var lib$es6$promise$$internal$$PENDING   = void 0;
    var lib$es6$promise$$internal$$FULFILLED = 1;
    var lib$es6$promise$$internal$$REJECTED  = 2;

    var lib$es6$promise$$internal$$GET_THEN_ERROR = new lib$es6$promise$$internal$$ErrorObject();

    function lib$es6$promise$$internal$$selfFulfillment() {
      return new TypeError("You cannot resolve a promise with itself");
    }

    function lib$es6$promise$$internal$$cannotReturnOwn() {
      return new TypeError('A promises callback cannot return that same promise.');
    }

    function lib$es6$promise$$internal$$getThen(promise) {
      try {
        return promise.then;
      } catch(error) {
        lib$es6$promise$$internal$$GET_THEN_ERROR.error = error;
        return lib$es6$promise$$internal$$GET_THEN_ERROR;
      }
    }

    function lib$es6$promise$$internal$$tryThen(then, value, fulfillmentHandler, rejectionHandler) {
      try {
        then.call(value, fulfillmentHandler, rejectionHandler);
      } catch(e) {
        return e;
      }
    }

    function lib$es6$promise$$internal$$handleForeignThenable(promise, thenable, then) {
       lib$es6$promise$asap$$asap(function(promise) {
        var sealed = false;
        var error = lib$es6$promise$$internal$$tryThen(then, thenable, function(value) {
          if (sealed) { return; }
          sealed = true;
          if (thenable !== value) {
            lib$es6$promise$$internal$$resolve(promise, value);
          } else {
            lib$es6$promise$$internal$$fulfill(promise, value);
          }
        }, function(reason) {
          if (sealed) { return; }
          sealed = true;

          lib$es6$promise$$internal$$reject(promise, reason);
        }, 'Settle: ' + (promise._label || ' unknown promise'));

        if (!sealed && error) {
          sealed = true;
          lib$es6$promise$$internal$$reject(promise, error);
        }
      }, promise);
    }

    function lib$es6$promise$$internal$$handleOwnThenable(promise, thenable) {
      if (thenable._state === lib$es6$promise$$internal$$FULFILLED) {
        lib$es6$promise$$internal$$fulfill(promise, thenable._result);
      } else if (thenable._state === lib$es6$promise$$internal$$REJECTED) {
        lib$es6$promise$$internal$$reject(promise, thenable._result);
      } else {
        lib$es6$promise$$internal$$subscribe(thenable, undefined, function(value) {
          lib$es6$promise$$internal$$resolve(promise, value);
        }, function(reason) {
          lib$es6$promise$$internal$$reject(promise, reason);
        });
      }
    }

    function lib$es6$promise$$internal$$handleMaybeThenable(promise, maybeThenable) {
      if (maybeThenable.constructor === promise.constructor) {
        lib$es6$promise$$internal$$handleOwnThenable(promise, maybeThenable);
      } else {
        var then = lib$es6$promise$$internal$$getThen(maybeThenable);

        if (then === lib$es6$promise$$internal$$GET_THEN_ERROR) {
          lib$es6$promise$$internal$$reject(promise, lib$es6$promise$$internal$$GET_THEN_ERROR.error);
        } else if (then === undefined) {
          lib$es6$promise$$internal$$fulfill(promise, maybeThenable);
        } else if (lib$es6$promise$utils$$isFunction(then)) {
          lib$es6$promise$$internal$$handleForeignThenable(promise, maybeThenable, then);
        } else {
          lib$es6$promise$$internal$$fulfill(promise, maybeThenable);
        }
      }
    }

    function lib$es6$promise$$internal$$resolve(promise, value) {
      if (promise === value) {
        lib$es6$promise$$internal$$reject(promise, lib$es6$promise$$internal$$selfFulfillment());
      } else if (lib$es6$promise$utils$$objectOrFunction(value)) {
        lib$es6$promise$$internal$$handleMaybeThenable(promise, value);
      } else {
        lib$es6$promise$$internal$$fulfill(promise, value);
      }
    }

    function lib$es6$promise$$internal$$publishRejection(promise) {
      if (promise._onerror) {
        promise._onerror(promise._result);
      }

      lib$es6$promise$$internal$$publish(promise);
    }

    function lib$es6$promise$$internal$$fulfill(promise, value) {
      if (promise._state !== lib$es6$promise$$internal$$PENDING) { return; }

      promise._result = value;
      promise._state = lib$es6$promise$$internal$$FULFILLED;

      if (promise._subscribers.length !== 0) {
        lib$es6$promise$asap$$asap(lib$es6$promise$$internal$$publish, promise);
      }
    }

    function lib$es6$promise$$internal$$reject(promise, reason) {
      if (promise._state !== lib$es6$promise$$internal$$PENDING) { return; }
      promise._state = lib$es6$promise$$internal$$REJECTED;
      promise._result = reason;

      lib$es6$promise$asap$$asap(lib$es6$promise$$internal$$publishRejection, promise);
    }

    function lib$es6$promise$$internal$$subscribe(parent, child, onFulfillment, onRejection) {
      var subscribers = parent._subscribers;
      var length = subscribers.length;

      parent._onerror = null;

      subscribers[length] = child;
      subscribers[length + lib$es6$promise$$internal$$FULFILLED] = onFulfillment;
      subscribers[length + lib$es6$promise$$internal$$REJECTED]  = onRejection;

      if (length === 0 && parent._state) {
        lib$es6$promise$asap$$asap(lib$es6$promise$$internal$$publish, parent);
      }
    }

    function lib$es6$promise$$internal$$publish(promise) {
      var subscribers = promise._subscribers;
      var settled = promise._state;

      if (subscribers.length === 0) { return; }

      var child, callback, detail = promise._result;

      for (var i = 0; i < subscribers.length; i += 3) {
        child = subscribers[i];
        callback = subscribers[i + settled];

        if (child) {
          lib$es6$promise$$internal$$invokeCallback(settled, child, callback, detail);
        } else {
          callback(detail);
        }
      }

      promise._subscribers.length = 0;
    }

    function lib$es6$promise$$internal$$ErrorObject() {
      this.error = null;
    }

    var lib$es6$promise$$internal$$TRY_CATCH_ERROR = new lib$es6$promise$$internal$$ErrorObject();

    function lib$es6$promise$$internal$$tryCatch(callback, detail) {
      try {
        return callback(detail);
      } catch(e) {
        lib$es6$promise$$internal$$TRY_CATCH_ERROR.error = e;
        return lib$es6$promise$$internal$$TRY_CATCH_ERROR;
      }
    }

    function lib$es6$promise$$internal$$invokeCallback(settled, promise, callback, detail) {
      var hasCallback = lib$es6$promise$utils$$isFunction(callback),
          value, error, succeeded, failed;

      if (hasCallback) {
        value = lib$es6$promise$$internal$$tryCatch(callback, detail);

        if (value === lib$es6$promise$$internal$$TRY_CATCH_ERROR) {
          failed = true;
          error = value.error;
          value = null;
        } else {
          succeeded = true;
        }

        if (promise === value) {
          lib$es6$promise$$internal$$reject(promise, lib$es6$promise$$internal$$cannotReturnOwn());
          return;
        }

      } else {
        value = detail;
        succeeded = true;
      }

      if (promise._state !== lib$es6$promise$$internal$$PENDING) {
        // noop
      } else if (hasCallback && succeeded) {
        lib$es6$promise$$internal$$resolve(promise, value);
      } else if (failed) {
        lib$es6$promise$$internal$$reject(promise, error);
      } else if (settled === lib$es6$promise$$internal$$FULFILLED) {
        lib$es6$promise$$internal$$fulfill(promise, value);
      } else if (settled === lib$es6$promise$$internal$$REJECTED) {
        lib$es6$promise$$internal$$reject(promise, value);
      }
    }

    function lib$es6$promise$$internal$$initializePromise(promise, resolver) {
      try {
        resolver(function resolvePromise(value){
          lib$es6$promise$$internal$$resolve(promise, value);
        }, function rejectPromise(reason) {
          lib$es6$promise$$internal$$reject(promise, reason);
        });
      } catch(e) {
        lib$es6$promise$$internal$$reject(promise, e);
      }
    }

    function lib$es6$promise$enumerator$$Enumerator(Constructor, input) {
      var enumerator = this;

      enumerator._instanceConstructor = Constructor;
      enumerator.promise = new Constructor(lib$es6$promise$$internal$$noop);

      if (enumerator._validateInput(input)) {
        enumerator._input     = input;
        enumerator.length     = input.length;
        enumerator._remaining = input.length;

        enumerator._init();

        if (enumerator.length === 0) {
          lib$es6$promise$$internal$$fulfill(enumerator.promise, enumerator._result);
        } else {
          enumerator.length = enumerator.length || 0;
          enumerator._enumerate();
          if (enumerator._remaining === 0) {
            lib$es6$promise$$internal$$fulfill(enumerator.promise, enumerator._result);
          }
        }
      } else {
        lib$es6$promise$$internal$$reject(enumerator.promise, enumerator._validationError());
      }
    }

    lib$es6$promise$enumerator$$Enumerator.prototype._validateInput = function(input) {
      return lib$es6$promise$utils$$isArray(input);
    };

    lib$es6$promise$enumerator$$Enumerator.prototype._validationError = function() {
      return new Error('Array Methods must be provided an Array');
    };

    lib$es6$promise$enumerator$$Enumerator.prototype._init = function() {
      this._result = new Array(this.length);
    };

    var lib$es6$promise$enumerator$$default = lib$es6$promise$enumerator$$Enumerator;

    lib$es6$promise$enumerator$$Enumerator.prototype._enumerate = function() {
      var enumerator = this;

      var length  = enumerator.length;
      var promise = enumerator.promise;
      var input   = enumerator._input;

      for (var i = 0; promise._state === lib$es6$promise$$internal$$PENDING && i < length; i++) {
        enumerator._eachEntry(input[i], i);
      }
    };

    lib$es6$promise$enumerator$$Enumerator.prototype._eachEntry = function(entry, i) {
      var enumerator = this;
      var c = enumerator._instanceConstructor;

      if (lib$es6$promise$utils$$isMaybeThenable(entry)) {
        if (entry.constructor === c && entry._state !== lib$es6$promise$$internal$$PENDING) {
          entry._onerror = null;
          enumerator._settledAt(entry._state, i, entry._result);
        } else {
          enumerator._willSettleAt(c.resolve(entry), i);
        }
      } else {
        enumerator._remaining--;
        enumerator._result[i] = entry;
      }
    };

    lib$es6$promise$enumerator$$Enumerator.prototype._settledAt = function(state, i, value) {
      var enumerator = this;
      var promise = enumerator.promise;

      if (promise._state === lib$es6$promise$$internal$$PENDING) {
        enumerator._remaining--;

        if (state === lib$es6$promise$$internal$$REJECTED) {
          lib$es6$promise$$internal$$reject(promise, value);
        } else {
          enumerator._result[i] = value;
        }
      }

      if (enumerator._remaining === 0) {
        lib$es6$promise$$internal$$fulfill(promise, enumerator._result);
      }
    };

    lib$es6$promise$enumerator$$Enumerator.prototype._willSettleAt = function(promise, i) {
      var enumerator = this;

      lib$es6$promise$$internal$$subscribe(promise, undefined, function(value) {
        enumerator._settledAt(lib$es6$promise$$internal$$FULFILLED, i, value);
      }, function(reason) {
        enumerator._settledAt(lib$es6$promise$$internal$$REJECTED, i, reason);
      });
    };
    function lib$es6$promise$promise$all$$all(entries) {
      return new lib$es6$promise$enumerator$$default(this, entries).promise;
    }
    var lib$es6$promise$promise$all$$default = lib$es6$promise$promise$all$$all;
    function lib$es6$promise$promise$race$$race(entries) {
      /*jshint validthis:true */
      var Constructor = this;

      var promise = new Constructor(lib$es6$promise$$internal$$noop);

      if (!lib$es6$promise$utils$$isArray(entries)) {
        lib$es6$promise$$internal$$reject(promise, new TypeError('You must pass an array to race.'));
        return promise;
      }

      var length = entries.length;

      function onFulfillment(value) {
        lib$es6$promise$$internal$$resolve(promise, value);
      }

      function onRejection(reason) {
        lib$es6$promise$$internal$$reject(promise, reason);
      }

      for (var i = 0; promise._state === lib$es6$promise$$internal$$PENDING && i < length; i++) {
        lib$es6$promise$$internal$$subscribe(Constructor.resolve(entries[i]), undefined, onFulfillment, onRejection);
      }

      return promise;
    }
    var lib$es6$promise$promise$race$$default = lib$es6$promise$promise$race$$race;
    function lib$es6$promise$promise$resolve$$resolve(object) {
      /*jshint validthis:true */
      var Constructor = this;

      if (object && typeof object === 'object' && object.constructor === Constructor) {
        return object;
      }

      var promise = new Constructor(lib$es6$promise$$internal$$noop);
      lib$es6$promise$$internal$$resolve(promise, object);
      return promise;
    }
    var lib$es6$promise$promise$resolve$$default = lib$es6$promise$promise$resolve$$resolve;
    function lib$es6$promise$promise$reject$$reject(reason) {
      /*jshint validthis:true */
      var Constructor = this;
      var promise = new Constructor(lib$es6$promise$$internal$$noop);
      lib$es6$promise$$internal$$reject(promise, reason);
      return promise;
    }
    var lib$es6$promise$promise$reject$$default = lib$es6$promise$promise$reject$$reject;

    var lib$es6$promise$promise$$counter = 0;

    function lib$es6$promise$promise$$needsResolver() {
      throw new TypeError('You must pass a resolver function as the first argument to the promise constructor');
    }

    function lib$es6$promise$promise$$needsNew() {
      throw new TypeError("Failed to construct 'Promise': Please use the 'new' operator, this object constructor cannot be called as a function.");
    }

    var lib$es6$promise$promise$$default = lib$es6$promise$promise$$Promise;
    /**
      Promise objects represent the eventual result of an asynchronous operation. The
      primary way of interacting with a promise is through its `then` method, which
      registers callbacks to receive either a promise's eventual value or the reason
      why the promise cannot be fulfilled.

      Terminology
      -----------

      - `promise` is an object or function with a `then` method whose behavior conforms to this specification.
      - `thenable` is an object or function that defines a `then` method.
      - `value` is any legal JavaScript value (including undefined, a thenable, or a promise).
      - `exception` is a value that is thrown using the throw statement.
      - `reason` is a value that indicates why a promise was rejected.
      - `settled` the final resting state of a promise, fulfilled or rejected.

      A promise can be in one of three states: pending, fulfilled, or rejected.

      Promises that are fulfilled have a fulfillment value and are in the fulfilled
      state.  Promises that are rejected have a rejection reason and are in the
      rejected state.  A fulfillment value is never a thenable.

      Promises can also be said to *resolve* a value.  If this value is also a
      promise, then the original promise's settled state will match the value's
      settled state.  So a promise that *resolves* a promise that rejects will
      itself reject, and a promise that *resolves* a promise that fulfills will
      itself fulfill.


      Basic Usage:
      ------------

      ```js
      var promise = new Promise(function(resolve, reject) {
        // on success
        resolve(value);

        // on failure
        reject(reason);
      });

      promise.then(function(value) {
        // on fulfillment
      }, function(reason) {
        // on rejection
      });
      ```

      Advanced Usage:
      ---------------

      Promises shine when abstracting away asynchronous interactions such as
      `XMLHttpRequest`s.

      ```js
      function getJSON(url) {
        return new Promise(function(resolve, reject){
          var xhr = new XMLHttpRequest();

          xhr.open('GET', url);
          xhr.onreadystatechange = handler;
          xhr.responseType = 'json';
          xhr.setRequestHeader('Accept', 'application/json');
          xhr.send();

          function handler() {
            if (this.readyState === this.DONE) {
              if (this.status === 200) {
                resolve(this.response);
              } else {
                reject(new Error('getJSON: `' + url + '` failed with status: [' + this.status + ']'));
              }
            }
          };
        });
      }

      getJSON('/posts.json').then(function(json) {
        // on fulfillment
      }, function(reason) {
        // on rejection
      });
      ```

      Unlike callbacks, promises are great composable primitives.

      ```js
      Promise.all([
        getJSON('/posts'),
        getJSON('/comments')
      ]).then(function(values){
        values[0] // => postsJSON
        values[1] // => commentsJSON

        return values;
      });
      ```

      @class Promise
      @param {function} resolver
      Useful for tooling.
      @constructor
    */
    function lib$es6$promise$promise$$Promise(resolver) {
      this._id = lib$es6$promise$promise$$counter++;
      this._state = undefined;
      this._result = undefined;
      this._subscribers = [];

      if (lib$es6$promise$$internal$$noop !== resolver) {
        if (!lib$es6$promise$utils$$isFunction(resolver)) {
          lib$es6$promise$promise$$needsResolver();
        }

        if (!(this instanceof lib$es6$promise$promise$$Promise)) {
          lib$es6$promise$promise$$needsNew();
        }

        lib$es6$promise$$internal$$initializePromise(this, resolver);
      }
    }

    lib$es6$promise$promise$$Promise.all = lib$es6$promise$promise$all$$default;
    lib$es6$promise$promise$$Promise.race = lib$es6$promise$promise$race$$default;
    lib$es6$promise$promise$$Promise.resolve = lib$es6$promise$promise$resolve$$default;
    lib$es6$promise$promise$$Promise.reject = lib$es6$promise$promise$reject$$default;
    lib$es6$promise$promise$$Promise._setScheduler = lib$es6$promise$asap$$setScheduler;
    lib$es6$promise$promise$$Promise._setAsap = lib$es6$promise$asap$$setAsap;
    lib$es6$promise$promise$$Promise._asap = lib$es6$promise$asap$$asap;

    lib$es6$promise$promise$$Promise.prototype = {
      constructor: lib$es6$promise$promise$$Promise,

    /**
      The primary way of interacting with a promise is through its `then` method,
      which registers callbacks to receive either a promise's eventual value or the
      reason why the promise cannot be fulfilled.

      ```js
      findUser().then(function(user){
        // user is available
      }, function(reason){
        // user is unavailable, and you are given the reason why
      });
      ```

      Chaining
      --------

      The return value of `then` is itself a promise.  This second, 'downstream'
      promise is resolved with the return value of the first promise's fulfillment
      or rejection handler, or rejected if the handler throws an exception.

      ```js
      findUser().then(function (user) {
        return user.name;
      }, function (reason) {
        return 'default name';
      }).then(function (userName) {
        // If `findUser` fulfilled, `userName` will be the user's name, otherwise it
        // will be `'default name'`
      });

      findUser().then(function (user) {
        throw new Error('Found user, but still unhappy');
      }, function (reason) {
        throw new Error('`findUser` rejected and we're unhappy');
      }).then(function (value) {
        // never reached
      }, function (reason) {
        // if `findUser` fulfilled, `reason` will be 'Found user, but still unhappy'.
        // If `findUser` rejected, `reason` will be '`findUser` rejected and we're unhappy'.
      });
      ```
      If the downstream promise does not specify a rejection handler, rejection reasons will be propagated further downstream.

      ```js
      findUser().then(function (user) {
        throw new PedagogicalException('Upstream error');
      }).then(function (value) {
        // never reached
      }).then(function (value) {
        // never reached
      }, function (reason) {
        // The `PedgagocialException` is propagated all the way down to here
      });
      ```

      Assimilation
      ------------

      Sometimes the value you want to propagate to a downstream promise can only be
      retrieved asynchronously. This can be achieved by returning a promise in the
      fulfillment or rejection handler. The downstream promise will then be pending
      until the returned promise is settled. This is called *assimilation*.

      ```js
      findUser().then(function (user) {
        return findCommentsByAuthor(user);
      }).then(function (comments) {
        // The user's comments are now available
      });
      ```

      If the assimliated promise rejects, then the downstream promise will also reject.

      ```js
      findUser().then(function (user) {
        return findCommentsByAuthor(user);
      }).then(function (comments) {
        // If `findCommentsByAuthor` fulfills, we'll have the value here
      }, function (reason) {
        // If `findCommentsByAuthor` rejects, we'll have the reason here
      });
      ```

      Simple Example
      --------------

      Synchronous Example

      ```javascript
      var result;

      try {
        result = findResult();
        // success
      } catch(reason) {
        // failure
      }
      ```

      Errback Example

      ```js
      findResult(function(result, err){
        if (err) {
          // failure
        } else {
          // success
        }
      });
      ```

      Promise Example;

      ```javascript
      findResult().then(function(result){
        // success
      }, function(reason){
        // failure
      });
      ```

      Advanced Example
      --------------

      Synchronous Example

      ```javascript
      var author, books;

      try {
        author = findAuthor();
        books  = findBooksByAuthor(author);
        // success
      } catch(reason) {
        // failure
      }
      ```

      Errback Example

      ```js

      function foundBooks(books) {

      }

      function failure(reason) {

      }

      findAuthor(function(author, err){
        if (err) {
          failure(err);
          // failure
        } else {
          try {
            findBoooksByAuthor(author, function(books, err) {
              if (err) {
                failure(err);
              } else {
                try {
                  foundBooks(books);
                } catch(reason) {
                  failure(reason);
                }
              }
            });
          } catch(error) {
            failure(err);
          }
          // success
        }
      });
      ```

      Promise Example;

      ```javascript
      findAuthor().
        then(findBooksByAuthor).
        then(function(books){
          // found books
      }).catch(function(reason){
        // something went wrong
      });
      ```

      @method then
      @param {Function} onFulfilled
      @param {Function} onRejected
      Useful for tooling.
      @return {Promise}
    */
      then: function(onFulfillment, onRejection) {
        var parent = this;
        var state = parent._state;

        if (state === lib$es6$promise$$internal$$FULFILLED && !onFulfillment || state === lib$es6$promise$$internal$$REJECTED && !onRejection) {
          return this;
        }

        var child = new this.constructor(lib$es6$promise$$internal$$noop);
        var result = parent._result;

        if (state) {
          var callback = arguments[state - 1];
          lib$es6$promise$asap$$asap(function(){
            lib$es6$promise$$internal$$invokeCallback(state, child, callback, result);
          });
        } else {
          lib$es6$promise$$internal$$subscribe(parent, child, onFulfillment, onRejection);
        }

        return child;
      },

    /**
      `catch` is simply sugar for `then(undefined, onRejection)` which makes it the same
      as the catch block of a try/catch statement.

      ```js
      function findAuthor(){
        throw new Error('couldn't find that author');
      }

      // synchronous
      try {
        findAuthor();
      } catch(reason) {
        // something went wrong
      }

      // async with promises
      findAuthor().catch(function(reason){
        // something went wrong
      });
      ```

      @method catch
      @param {Function} onRejection
      Useful for tooling.
      @return {Promise}
    */
      'catch': function(onRejection) {
        return this.then(null, onRejection);
      }
    };
    function lib$es6$promise$polyfill$$polyfill() {
      var local;

      if (typeof global !== 'undefined') {
          local = global;
      } else if (typeof self !== 'undefined') {
          local = self;
      } else {
          try {
              local = Function('return this')();
          } catch (e) {
              throw new Error('polyfill failed because global object is unavailable in this environment');
          }
      }

      var P = local.Promise;

      if (P && Object.prototype.toString.call(P.resolve()) === '[object Promise]' && !P.cast) {
        return;
      }

      local.Promise = lib$es6$promise$promise$$default;
    }
    var lib$es6$promise$polyfill$$default = lib$es6$promise$polyfill$$polyfill;

    var lib$es6$promise$umd$$ES6Promise = {
      'Promise': lib$es6$promise$promise$$default,
      'polyfill': lib$es6$promise$polyfill$$default
    };

    /* global define:true module:true window: true */
    if (typeof define === 'function' && define['amd']) {
      define(function() { return lib$es6$promise$umd$$ES6Promise; });
    } else if (typeof module !== 'undefined' && module['exports']) {
      module['exports'] = lib$es6$promise$umd$$ES6Promise;
    } else if (typeof this !== 'undefined') {
      this['ES6Promise'] = lib$es6$promise$umd$$ES6Promise;
    }

    lib$es6$promise$polyfill$$default();
}).call(this);


}).call(this,require('_process'),typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {})

},{"_process":66}],21:[function(require,module,exports){
'use strict';


var yaml = require('./lib/js-yaml.js');


module.exports = yaml;

},{"./lib/js-yaml.js":22}],22:[function(require,module,exports){
'use strict';


var loader = require('./js-yaml/loader');
var dumper = require('./js-yaml/dumper');


function deprecated(name) {
  return function () {
    throw new Error('Function ' + name + ' is deprecated and cannot be used.');
  };
}


module.exports.Type                = require('./js-yaml/type');
module.exports.Schema              = require('./js-yaml/schema');
module.exports.FAILSAFE_SCHEMA     = require('./js-yaml/schema/failsafe');
module.exports.JSON_SCHEMA         = require('./js-yaml/schema/json');
module.exports.CORE_SCHEMA         = require('./js-yaml/schema/core');
module.exports.DEFAULT_SAFE_SCHEMA = require('./js-yaml/schema/default_safe');
module.exports.DEFAULT_FULL_SCHEMA = require('./js-yaml/schema/default_full');
module.exports.load                = loader.load;
module.exports.loadAll             = loader.loadAll;
module.exports.safeLoad            = loader.safeLoad;
module.exports.safeLoadAll         = loader.safeLoadAll;
module.exports.dump                = dumper.dump;
module.exports.safeDump            = dumper.safeDump;
module.exports.YAMLException       = require('./js-yaml/exception');

// Deprecated schema names from JS-YAML 2.0.x
module.exports.MINIMAL_SCHEMA = require('./js-yaml/schema/failsafe');
module.exports.SAFE_SCHEMA    = require('./js-yaml/schema/default_safe');
module.exports.DEFAULT_SCHEMA = require('./js-yaml/schema/default_full');

// Deprecated functions from JS-YAML 1.x.x
module.exports.scan           = deprecated('scan');
module.exports.parse          = deprecated('parse');
module.exports.compose        = deprecated('compose');
module.exports.addConstructor = deprecated('addConstructor');

},{"./js-yaml/dumper":24,"./js-yaml/exception":25,"./js-yaml/loader":26,"./js-yaml/schema":28,"./js-yaml/schema/core":29,"./js-yaml/schema/default_full":30,"./js-yaml/schema/default_safe":31,"./js-yaml/schema/failsafe":32,"./js-yaml/schema/json":33,"./js-yaml/type":34}],23:[function(require,module,exports){
'use strict';


function isNothing(subject) {
  return (typeof subject === 'undefined') || (null === subject);
}


function isObject(subject) {
  return (typeof subject === 'object') && (null !== subject);
}


function toArray(sequence) {
  if (Array.isArray(sequence)) {
    return sequence;
  } else if (isNothing(sequence)) {
    return [];
  }
  return [ sequence ];
}


function extend(target, source) {
  var index, length, key, sourceKeys;

  if (source) {
    sourceKeys = Object.keys(source);

    for (index = 0, length = sourceKeys.length; index < length; index += 1) {
      key = sourceKeys[index];
      target[key] = source[key];
    }
  }

  return target;
}


function repeat(string, count) {
  var result = '', cycle;

  for (cycle = 0; cycle < count; cycle += 1) {
    result += string;
  }

  return result;
}


function isNegativeZero(number) {
  return (0 === number) && (Number.NEGATIVE_INFINITY === 1 / number);
}


module.exports.isNothing      = isNothing;
module.exports.isObject       = isObject;
module.exports.toArray        = toArray;
module.exports.repeat         = repeat;
module.exports.isNegativeZero = isNegativeZero;
module.exports.extend         = extend;

},{}],24:[function(require,module,exports){
'use strict';

/*eslint-disable no-use-before-define*/

var common              = require('./common');
var YAMLException       = require('./exception');
var DEFAULT_FULL_SCHEMA = require('./schema/default_full');
var DEFAULT_SAFE_SCHEMA = require('./schema/default_safe');

var _toString       = Object.prototype.toString;
var _hasOwnProperty = Object.prototype.hasOwnProperty;

var CHAR_TAB                  = 0x09; /* Tab */
var CHAR_LINE_FEED            = 0x0A; /* LF */
var CHAR_CARRIAGE_RETURN      = 0x0D; /* CR */
var CHAR_SPACE                = 0x20; /* Space */
var CHAR_EXCLAMATION          = 0x21; /* ! */
var CHAR_DOUBLE_QUOTE         = 0x22; /* " */
var CHAR_SHARP                = 0x23; /* # */
var CHAR_PERCENT              = 0x25; /* % */
var CHAR_AMPERSAND            = 0x26; /* & */
var CHAR_SINGLE_QUOTE         = 0x27; /* ' */
var CHAR_ASTERISK             = 0x2A; /* * */
var CHAR_COMMA                = 0x2C; /* , */
var CHAR_MINUS                = 0x2D; /* - */
var CHAR_COLON                = 0x3A; /* : */
var CHAR_GREATER_THAN         = 0x3E; /* > */
var CHAR_QUESTION             = 0x3F; /* ? */
var CHAR_COMMERCIAL_AT        = 0x40; /* @ */
var CHAR_LEFT_SQUARE_BRACKET  = 0x5B; /* [ */
var CHAR_RIGHT_SQUARE_BRACKET = 0x5D; /* ] */
var CHAR_GRAVE_ACCENT         = 0x60; /* ` */
var CHAR_LEFT_CURLY_BRACKET   = 0x7B; /* { */
var CHAR_VERTICAL_LINE        = 0x7C; /* | */
var CHAR_RIGHT_CURLY_BRACKET  = 0x7D; /* } */

var ESCAPE_SEQUENCES = {};

ESCAPE_SEQUENCES[0x00]   = '\\0';
ESCAPE_SEQUENCES[0x07]   = '\\a';
ESCAPE_SEQUENCES[0x08]   = '\\b';
ESCAPE_SEQUENCES[0x09]   = '\\t';
ESCAPE_SEQUENCES[0x0A]   = '\\n';
ESCAPE_SEQUENCES[0x0B]   = '\\v';
ESCAPE_SEQUENCES[0x0C]   = '\\f';
ESCAPE_SEQUENCES[0x0D]   = '\\r';
ESCAPE_SEQUENCES[0x1B]   = '\\e';
ESCAPE_SEQUENCES[0x22]   = '\\"';
ESCAPE_SEQUENCES[0x5C]   = '\\\\';
ESCAPE_SEQUENCES[0x85]   = '\\N';
ESCAPE_SEQUENCES[0xA0]   = '\\_';
ESCAPE_SEQUENCES[0x2028] = '\\L';
ESCAPE_SEQUENCES[0x2029] = '\\P';

var DEPRECATED_BOOLEANS_SYNTAX = [
  'y', 'Y', 'yes', 'Yes', 'YES', 'on', 'On', 'ON',
  'n', 'N', 'no', 'No', 'NO', 'off', 'Off', 'OFF'
];

function compileStyleMap(schema, map) {
  var result, keys, index, length, tag, style, type;

  if (null === map) {
    return {};
  }

  result = {};
  keys = Object.keys(map);

  for (index = 0, length = keys.length; index < length; index += 1) {
    tag = keys[index];
    style = String(map[tag]);

    if ('!!' === tag.slice(0, 2)) {
      tag = 'tag:yaml.org,2002:' + tag.slice(2);
    }

    type = schema.compiledTypeMap[tag];

    if (type && _hasOwnProperty.call(type.styleAliases, style)) {
      style = type.styleAliases[style];
    }

    result[tag] = style;
  }

  return result;
}

function encodeHex(character) {
  var string, handle, length;

  string = character.toString(16).toUpperCase();

  if (character <= 0xFF) {
    handle = 'x';
    length = 2;
  } else if (character <= 0xFFFF) {
    handle = 'u';
    length = 4;
  } else if (character <= 0xFFFFFFFF) {
    handle = 'U';
    length = 8;
  } else {
    throw new YAMLException('code point within a string may not be greater than 0xFFFFFFFF');
  }

  return '\\' + handle + common.repeat('0', length - string.length) + string;
}

function State(options) {
  this.schema      = options['schema'] || DEFAULT_FULL_SCHEMA;
  this.indent      = Math.max(1, (options['indent'] || 2));
  this.skipInvalid = options['skipInvalid'] || false;
  this.flowLevel   = (common.isNothing(options['flowLevel']) ? -1 : options['flowLevel']);
  this.styleMap    = compileStyleMap(this.schema, options['styles'] || null);
  this.sortKeys    = options['sortKeys'] || false;
  this.lineWidth    = options['lineWidth'] || 80;

  this.implicitTypes = this.schema.compiledImplicit;
  this.explicitTypes = this.schema.compiledExplicit;

  this.tag = null;
  this.result = '';

  this.duplicates = [];
  this.usedDuplicates = null;
}

function indentString(string, spaces) {
  var ind = common.repeat(' ', spaces),
      position = 0,
      next = -1,
      result = '',
      line,
      length = string.length;

  while (position < length) {
    next = string.indexOf('\n', position);
    if (next === -1) {
      line = string.slice(position);
      position = length;
    } else {
      line = string.slice(position, next + 1);
      position = next + 1;
    }
    if (line.length && line !== '\n') {
      result += ind;
    }
    result += line;
  }

  return result;
}

function generateNextLine(state, level) {
  return '\n' + common.repeat(' ', state.indent * level);
}

function testImplicitResolving(state, str) {
  var index, length, type;

  for (index = 0, length = state.implicitTypes.length; index < length; index += 1) {
    type = state.implicitTypes[index];

    if (type.resolve(str)) {
      return true;
    }
  }

  return false;
}

function StringBuilder(source) {
  this.source = source;
  this.result = '';
  this.checkpoint = 0;
}

StringBuilder.prototype.takeUpTo = function (position) {
  var er;

  if (position < this.checkpoint) {
    er = new Error('position should be > checkpoint');
    er.position = position;
    er.checkpoint = this.checkpoint;
    throw er;
  }

  this.result += this.source.slice(this.checkpoint, position);
  this.checkpoint = position;
  return this;
};

StringBuilder.prototype.escapeChar = function () {
  var character, esc;

  character = this.source.charCodeAt(this.checkpoint);
  esc = ESCAPE_SEQUENCES[character] || encodeHex(character);
  this.result += esc;
  this.checkpoint += 1;

  return this;
};

StringBuilder.prototype.finish = function () {
  if (this.source.length > this.checkpoint) {
    this.takeUpTo(this.source.length);
  }
};

function writeScalar(state, object, level, iskey) {
  var simple, first, spaceWrap, folded, literal, single, double,
      sawLineFeed, linePosition, longestLine, indent, max, character,
      position, escapeSeq, hexEsc, previous, lineLength, modifier,
      trailingLineBreaks, result;

  if (0 === object.length) {
    state.dump = "''";
    return;
  }

  if (-1 !== DEPRECATED_BOOLEANS_SYNTAX.indexOf(object)) {
    state.dump = "'" + object + "'";
    return;
  }

  simple = true;
  first = object.length ? object.charCodeAt(0) : 0;
  spaceWrap = (CHAR_SPACE === first ||
               CHAR_SPACE === object.charCodeAt(object.length - 1));

  // Simplified check for restricted first characters
  // http://www.yaml.org/spec/1.2/spec.html#ns-plain-first%28c%29
  if (CHAR_MINUS         === first ||
      CHAR_QUESTION      === first ||
      CHAR_COMMERCIAL_AT === first ||
      CHAR_GRAVE_ACCENT  === first) {
    simple = false;
  }

  // can only use > and | if not wrapped in spaces or is not a key.
  if (spaceWrap) {
    simple = false;
    folded = false;
    literal = false;
  } else {
    folded = !iskey;
    literal = !iskey;
  }

  single = true;
  double = new StringBuilder(object);

  sawLineFeed = false;
  linePosition = 0;
  longestLine = 0;

  indent = state.indent * level;
  max = state.lineWidth;
  if (max === -1) {
    // Replace -1 with biggest ingeger number according to
    // http://ecma262-5.com/ELS5_HTML.htm#Section_8.5
    max = 9007199254740991;
  }

  if (indent < 40) {
    max -= indent;
  } else {
    max = 40;
  }

  for (position = 0; position < object.length; position++) {
    character = object.charCodeAt(position);
    if (simple) {
      // Characters that can never appear in the simple scalar
      if (!simpleChar(character)) {
        simple = false;
      } else {
        // Still simple.  If we make it all the way through like
        // this, then we can just dump the string as-is.
        continue;
      }
    }

    if (single && character === CHAR_SINGLE_QUOTE) {
      single = false;
    }

    escapeSeq = ESCAPE_SEQUENCES[character];
    hexEsc = needsHexEscape(character);

    if (!escapeSeq && !hexEsc) {
      continue;
    }

    if (character !== CHAR_LINE_FEED &&
        character !== CHAR_DOUBLE_QUOTE &&
        character !== CHAR_SINGLE_QUOTE) {
      folded = false;
      literal = false;
    } else if (character === CHAR_LINE_FEED) {
      sawLineFeed = true;
      single = false;
      if (position > 0) {
        previous = object.charCodeAt(position - 1);
        if (previous === CHAR_SPACE) {
          literal = false;
          folded = false;
        }
      }
      if (folded) {
        lineLength = position - linePosition;
        linePosition = position;
        if (lineLength > longestLine) {
          longestLine = lineLength;
        }
      }
    }

    if (character !== CHAR_DOUBLE_QUOTE) {
      single = false;
    }

    double.takeUpTo(position);
    double.escapeChar();
  }

  if (simple && testImplicitResolving(state, object)) {
    simple = false;
  }

  modifier = '';
  if (folded || literal) {
    trailingLineBreaks = 0;
    if (object.charCodeAt(object.length - 1) === CHAR_LINE_FEED) {
      trailingLineBreaks += 1;
      if (object.charCodeAt(object.length - 2) === CHAR_LINE_FEED) {
        trailingLineBreaks += 1;
      }
    }

    if (trailingLineBreaks === 0) {
      modifier = '-';
    } else if (trailingLineBreaks === 2) {
      modifier = '+';
    }
  }

  if (literal && longestLine < max) {
    folded = false;
  }

  // If it's literally one line, then don't bother with the literal.
  // We may still want to do a fold, though, if it's a super long line.
  if (!sawLineFeed) {
    literal = false;
  }

  if (simple) {
    state.dump = object;
  } else if (single) {
    state.dump = '\'' + object + '\'';
  } else if (folded) {
    result = fold(object, max);
    state.dump = '>' + modifier + '\n' + indentString(result, indent);
  } else if (literal) {
    if (!modifier) {
      object = object.replace(/\n$/, '');
    }
    state.dump = '|' + modifier + '\n' + indentString(object, indent);
  } else if (double) {
    double.finish();
    state.dump = '"' + double.result + '"';
  } else {
    throw new Error('Failed to dump scalar value');
  }

  return;
}

// The `trailing` var is a regexp match of any trailing `\n` characters.
//
// There are three cases we care about:
//
// 1. One trailing `\n` on the string.  Just use `|` or `>`.
//    This is the assumed default. (trailing = null)
// 2. No trailing `\n` on the string.  Use `|-` or `>-` to "chomp" the end.
// 3. More than one trailing `\n` on the string.  Use `|+` or `>+`.
//
// In the case of `>+`, these line breaks are *not* doubled (like the line
// breaks within the string), so it's important to only end with the exact
// same number as we started.
function fold(object, max) {
  var result = '',
      position = 0,
      length = object.length,
      trailing = /\n+$/.exec(object),
      newLine;

  if (trailing) {
    length = trailing.index + 1;
  }

  while (position < length) {
    newLine = object.indexOf('\n', position);
    if (newLine > length || newLine === -1) {
      if (result) {
        result += '\n\n';
      }
      result += foldLine(object.slice(position, length), max);
      position = length;
    } else {
      if (result) {
        result += '\n\n';
      }
      result += foldLine(object.slice(position, newLine), max);
      position = newLine + 1;
    }
  }
  if (trailing && trailing[0] !== '\n') {
    result += trailing[0];
  }

  return result;
}

function foldLine(line, max) {
  if (line === '') {
    return line;
  }

  var foldRe = /[^\s] [^\s]/g,
      result = '',
      prevMatch = 0,
      foldStart = 0,
      match = foldRe.exec(line),
      index,
      foldEnd,
      folded;

  while (match) {
    index = match.index;

    // when we cross the max len, if the previous match would've
    // been ok, use that one, and carry on.  If there was no previous
    // match on this fold section, then just have a long line.
    if (index - foldStart > max) {
      if (prevMatch !== foldStart) {
        foldEnd = prevMatch;
      } else {
        foldEnd = index;
      }

      if (result) {
        result += '\n';
      }
      folded = line.slice(foldStart, foldEnd);
      result += folded;
      foldStart = foldEnd + 1;
    }
    prevMatch = index + 1;
    match = foldRe.exec(line);
  }

  if (result) {
    result += '\n';
  }

  // if we end up with one last word at the end, then the last bit might
  // be slightly bigger than we wanted, because we exited out of the loop.
  if (foldStart !== prevMatch && line.length - foldStart > max) {
    result += line.slice(foldStart, prevMatch) + '\n' +
              line.slice(prevMatch + 1);
  } else {
    result += line.slice(foldStart);
  }

  return result;
}

// Returns true if character can be found in a simple scalar
function simpleChar(character) {
  return CHAR_TAB                  !== character &&
         CHAR_LINE_FEED            !== character &&
         CHAR_CARRIAGE_RETURN      !== character &&
         CHAR_COMMA                !== character &&
         CHAR_LEFT_SQUARE_BRACKET  !== character &&
         CHAR_RIGHT_SQUARE_BRACKET !== character &&
         CHAR_LEFT_CURLY_BRACKET   !== character &&
         CHAR_RIGHT_CURLY_BRACKET  !== character &&
         CHAR_SHARP                !== character &&
         CHAR_AMPERSAND            !== character &&
         CHAR_ASTERISK             !== character &&
         CHAR_EXCLAMATION          !== character &&
         CHAR_VERTICAL_LINE        !== character &&
         CHAR_GREATER_THAN         !== character &&
         CHAR_SINGLE_QUOTE         !== character &&
         CHAR_DOUBLE_QUOTE         !== character &&
         CHAR_PERCENT              !== character &&
         CHAR_COLON                !== character &&
         !ESCAPE_SEQUENCES[character]            &&
         !needsHexEscape(character);
}

// Returns true if the character code needs to be escaped.
function needsHexEscape(character) {
  return !((0x00020 <= character && character <= 0x00007E) ||
           (0x00085 === character)                         ||
           (0x000A0 <= character && character <= 0x00D7FF) ||
           (0x0E000 <= character && character <= 0x00FFFD) ||
           (0x10000 <= character && character <= 0x10FFFF));
}

function writeFlowSequence(state, level, object) {
  var _result = '',
      _tag    = state.tag,
      index,
      length;

  for (index = 0, length = object.length; index < length; index += 1) {
    // Write only valid elements.
    if (writeNode(state, level, object[index], false, false)) {
      if (0 !== index) {
        _result += ', ';
      }
      _result += state.dump;
    }
  }

  state.tag = _tag;
  state.dump = '[' + _result + ']';
}

function writeBlockSequence(state, level, object, compact) {
  var _result = '',
      _tag    = state.tag,
      index,
      length;

  for (index = 0, length = object.length; index < length; index += 1) {
    // Write only valid elements.
    if (writeNode(state, level + 1, object[index], true, true)) {
      if (!compact || 0 !== index) {
        _result += generateNextLine(state, level);
      }
      _result += '- ' + state.dump;
    }
  }

  state.tag = _tag;
  state.dump = _result || '[]'; // Empty sequence if no valid values.
}

function writeFlowMapping(state, level, object) {
  var _result       = '',
      _tag          = state.tag,
      objectKeyList = Object.keys(object),
      index,
      length,
      objectKey,
      objectValue,
      pairBuffer;

  for (index = 0, length = objectKeyList.length; index < length; index += 1) {
    pairBuffer = '';

    if (0 !== index) {
      pairBuffer += ', ';
    }

    objectKey = objectKeyList[index];
    objectValue = object[objectKey];

    if (!writeNode(state, level, objectKey, false, false)) {
      continue; // Skip this pair because of invalid key;
    }

    if (state.dump.length > 1024) {
      pairBuffer += '? ';
    }

    pairBuffer += state.dump + ': ';

    if (!writeNode(state, level, objectValue, false, false)) {
      continue; // Skip this pair because of invalid value.
    }

    pairBuffer += state.dump;

    // Both key and value are valid.
    _result += pairBuffer;
  }

  state.tag = _tag;
  state.dump = '{' + _result + '}';
}

function writeBlockMapping(state, level, object, compact) {
  var _result       = '',
      _tag          = state.tag,
      objectKeyList = Object.keys(object),
      index,
      length,
      objectKey,
      objectValue,
      explicitPair,
      pairBuffer;

  // Allow sorting keys so that the output file is deterministic
  if (state.sortKeys === true) {
    // Default sorting
    objectKeyList.sort();
  } else if (typeof state.sortKeys === 'function') {
    // Custom sort function
    objectKeyList.sort(state.sortKeys);
  } else if (state.sortKeys) {
    // Something is wrong
    throw new YAMLException('sortKeys must be a boolean or a function');
  }

  for (index = 0, length = objectKeyList.length; index < length; index += 1) {
    pairBuffer = '';

    if (!compact || 0 !== index) {
      pairBuffer += generateNextLine(state, level);
    }

    objectKey = objectKeyList[index];
    objectValue = object[objectKey];

    if (!writeNode(state, level + 1, objectKey, true, true, true)) {
      continue; // Skip this pair because of invalid key.
    }

    explicitPair = (null !== state.tag && '?' !== state.tag) ||
                   (state.dump && state.dump.length > 1024);

    if (explicitPair) {
      if (state.dump && CHAR_LINE_FEED === state.dump.charCodeAt(0)) {
        pairBuffer += '?';
      } else {
        pairBuffer += '? ';
      }
    }

    pairBuffer += state.dump;

    if (explicitPair) {
      pairBuffer += generateNextLine(state, level);
    }

    if (!writeNode(state, level + 1, objectValue, true, explicitPair)) {
      continue; // Skip this pair because of invalid value.
    }

    if (state.dump && CHAR_LINE_FEED === state.dump.charCodeAt(0)) {
      pairBuffer += ':';
    } else {
      pairBuffer += ': ';
    }

    pairBuffer += state.dump;

    // Both key and value are valid.
    _result += pairBuffer;
  }

  state.tag = _tag;
  state.dump = _result || '{}'; // Empty mapping if no valid pairs.
}

function detectType(state, object, explicit) {
  var _result, typeList, index, length, type, style;

  typeList = explicit ? state.explicitTypes : state.implicitTypes;

  for (index = 0, length = typeList.length; index < length; index += 1) {
    type = typeList[index];

    if ((type.instanceOf  || type.predicate) &&
        (!type.instanceOf || (('object' === typeof object) && (object instanceof type.instanceOf))) &&
        (!type.predicate  || type.predicate(object))) {

      state.tag = explicit ? type.tag : '?';

      if (type.represent) {
        style = state.styleMap[type.tag] || type.defaultStyle;

        if ('[object Function]' === _toString.call(type.represent)) {
          _result = type.represent(object, style);
        } else if (_hasOwnProperty.call(type.represent, style)) {
          _result = type.represent[style](object, style);
        } else {
          throw new YAMLException('!<' + type.tag + '> tag resolver accepts not "' + style + '" style');
        }

        state.dump = _result;
      }

      return true;
    }
  }

  return false;
}

// Serializes `object` and writes it to global `result`.
// Returns true on success, or false on invalid object.
//
function writeNode(state, level, object, block, compact, iskey) {
  state.tag = null;
  state.dump = object;

  if (!detectType(state, object, false)) {
    detectType(state, object, true);
  }

  var type = _toString.call(state.dump);

  if (block) {
    block = (0 > state.flowLevel || state.flowLevel > level);
  }

  var objectOrArray = '[object Object]' === type || '[object Array]' === type,
      duplicateIndex,
      duplicate;

  if (objectOrArray) {
    duplicateIndex = state.duplicates.indexOf(object);
    duplicate = duplicateIndex !== -1;
  }

  if ((null !== state.tag && '?' !== state.tag) || duplicate || (2 !== state.indent && level > 0)) {
    compact = false;
  }

  if (duplicate && state.usedDuplicates[duplicateIndex]) {
    state.dump = '*ref_' + duplicateIndex;
  } else {
    if (objectOrArray && duplicate && !state.usedDuplicates[duplicateIndex]) {
      state.usedDuplicates[duplicateIndex] = true;
    }
    if ('[object Object]' === type) {
      if (block && (0 !== Object.keys(state.dump).length)) {
        writeBlockMapping(state, level, state.dump, compact);
        if (duplicate) {
          state.dump = '&ref_' + duplicateIndex + state.dump;
        }
      } else {
        writeFlowMapping(state, level, state.dump);
        if (duplicate) {
          state.dump = '&ref_' + duplicateIndex + ' ' + state.dump;
        }
      }
    } else if ('[object Array]' === type) {
      if (block && (0 !== state.dump.length)) {
        writeBlockSequence(state, level, state.dump, compact);
        if (duplicate) {
          state.dump = '&ref_' + duplicateIndex + state.dump;
        }
      } else {
        writeFlowSequence(state, level, state.dump);
        if (duplicate) {
          state.dump = '&ref_' + duplicateIndex + ' ' + state.dump;
        }
      }
    } else if ('[object String]' === type) {
      if ('?' !== state.tag) {
        writeScalar(state, state.dump, level, iskey);
      }
    } else {
      if (state.skipInvalid) {
        return false;
      }
      throw new YAMLException('unacceptable kind of an object to dump ' + type);
    }

    if (null !== state.tag && '?' !== state.tag) {
      state.dump = '!<' + state.tag + '> ' + state.dump;
    }
  }

  return true;
}

function getDuplicateReferences(object, state) {
  var objects = [],
      duplicatesIndexes = [],
      index,
      length;

  inspectNode(object, objects, duplicatesIndexes);

  for (index = 0, length = duplicatesIndexes.length; index < length; index += 1) {
    state.duplicates.push(objects[duplicatesIndexes[index]]);
  }
  state.usedDuplicates = new Array(length);
}

function inspectNode(object, objects, duplicatesIndexes) {
  var objectKeyList,
      index,
      length;

  if (null !== object && 'object' === typeof object) {
    index = objects.indexOf(object);
    if (-1 !== index) {
      if (-1 === duplicatesIndexes.indexOf(index)) {
        duplicatesIndexes.push(index);
      }
    } else {
      objects.push(object);

      if (Array.isArray(object)) {
        for (index = 0, length = object.length; index < length; index += 1) {
          inspectNode(object[index], objects, duplicatesIndexes);
        }
      } else {
        objectKeyList = Object.keys(object);

        for (index = 0, length = objectKeyList.length; index < length; index += 1) {
          inspectNode(object[objectKeyList[index]], objects, duplicatesIndexes);
        }
      }
    }
  }
}

function dump(input, options) {
  options = options || {};

  var state = new State(options);

  getDuplicateReferences(input, state);

  if (writeNode(state, 0, input, true, true)) {
    return state.dump + '\n';
  }
  return '';
}

function safeDump(input, options) {
  return dump(input, common.extend({ schema: DEFAULT_SAFE_SCHEMA }, options));
}

module.exports.dump     = dump;
module.exports.safeDump = safeDump;

},{"./common":23,"./exception":25,"./schema/default_full":30,"./schema/default_safe":31}],25:[function(require,module,exports){
// YAML error class. http://stackoverflow.com/questions/8458984
//
'use strict';


var inherits = require('inherit');


function YAMLException(reason, mark) {
  // Super constructor
  Error.call(this);

  // Include stack trace in error object
  if (Error.captureStackTrace) {
    // Chrome and NodeJS
    Error.captureStackTrace(this, this.constructor);
  } else {
    // FF, IE 10+ and Safari 6+. Fallback for others
    this.stack = (new Error()).stack || '';
  }

  this.name = 'YAMLException';
  this.reason = reason;
  this.mark = mark;
  this.message = (this.reason || '(unknown reason)') + (this.mark ? ' ' + this.mark.toString() : '');
}


// Inherit from Error
inherits(YAMLException, Error);


YAMLException.prototype.toString = function toString(compact) {
  var result = this.name + ': ';

  result += this.reason || '(unknown reason)';

  if (!compact && this.mark) {
    result += ' ' + this.mark.toString();
  }

  return result;
};


module.exports = YAMLException;

},{"inherit":52}],26:[function(require,module,exports){
'use strict';

/*eslint-disable max-len,no-use-before-define*/

var common              = require('./common');
var YAMLException       = require('./exception');
var Mark                = require('./mark');
var DEFAULT_SAFE_SCHEMA = require('./schema/default_safe');
var DEFAULT_FULL_SCHEMA = require('./schema/default_full');


var _hasOwnProperty = Object.prototype.hasOwnProperty;


var CONTEXT_FLOW_IN   = 1;
var CONTEXT_FLOW_OUT  = 2;
var CONTEXT_BLOCK_IN  = 3;
var CONTEXT_BLOCK_OUT = 4;


var CHOMPING_CLIP  = 1;
var CHOMPING_STRIP = 2;
var CHOMPING_KEEP  = 3;


var PATTERN_NON_PRINTABLE         = /[\x00-\x08\x0B\x0C\x0E-\x1F\x7F-\x84\x86-\x9F\uFFFE\uFFFF]|[\uD800-\uDBFF](?![\uDC00-\uDFFF])|(?:[^\uD800-\uDBFF]|^)[\uDC00-\uDFFF]/;
var PATTERN_NON_ASCII_LINE_BREAKS = /[\x85\u2028\u2029]/;
var PATTERN_FLOW_INDICATORS       = /[,\[\]\{\}]/;
var PATTERN_TAG_HANDLE            = /^(?:!|!!|![a-z\-]+!)$/i;
var PATTERN_TAG_URI               = /^(?:!|[^,\[\]\{\}])(?:%[0-9a-f]{2}|[0-9a-z\-#;\/\?:@&=\+\$,_\.!~\*'\(\)\[\]])*$/i;


function is_EOL(c) {
  return (c === 0x0A/* LF */) || (c === 0x0D/* CR */);
}

function is_WHITE_SPACE(c) {
  return (c === 0x09/* Tab */) || (c === 0x20/* Space */);
}

function is_WS_OR_EOL(c) {
  return (c === 0x09/* Tab */) ||
         (c === 0x20/* Space */) ||
         (c === 0x0A/* LF */) ||
         (c === 0x0D/* CR */);
}

function is_FLOW_INDICATOR(c) {
  return 0x2C/* , */ === c ||
         0x5B/* [ */ === c ||
         0x5D/* ] */ === c ||
         0x7B/* { */ === c ||
         0x7D/* } */ === c;
}

function fromHexCode(c) {
  var lc;

  if ((0x30/* 0 */ <= c) && (c <= 0x39/* 9 */)) {
    return c - 0x30;
  }

  /*eslint-disable no-bitwise*/
  lc = c | 0x20;

  if ((0x61/* a */ <= lc) && (lc <= 0x66/* f */)) {
    return lc - 0x61 + 10;
  }

  return -1;
}

function escapedHexLen(c) {
  if (c === 0x78/* x */) { return 2; }
  if (c === 0x75/* u */) { return 4; }
  if (c === 0x55/* U */) { return 8; }
  return 0;
}

function fromDecimalCode(c) {
  if ((0x30/* 0 */ <= c) && (c <= 0x39/* 9 */)) {
    return c - 0x30;
  }

  return -1;
}

function simpleEscapeSequence(c) {
  return (c === 0x30/* 0 */) ? '\x00' :
        (c === 0x61/* a */) ? '\x07' :
        (c === 0x62/* b */) ? '\x08' :
        (c === 0x74/* t */) ? '\x09' :
        (c === 0x09/* Tab */) ? '\x09' :
        (c === 0x6E/* n */) ? '\x0A' :
        (c === 0x76/* v */) ? '\x0B' :
        (c === 0x66/* f */) ? '\x0C' :
        (c === 0x72/* r */) ? '\x0D' :
        (c === 0x65/* e */) ? '\x1B' :
        (c === 0x20/* Space */) ? ' ' :
        (c === 0x22/* " */) ? '\x22' :
        (c === 0x2F/* / */) ? '/' :
        (c === 0x5C/* \ */) ? '\x5C' :
        (c === 0x4E/* N */) ? '\x85' :
        (c === 0x5F/* _ */) ? '\xA0' :
        (c === 0x4C/* L */) ? '\u2028' :
        (c === 0x50/* P */) ? '\u2029' : '';
}

function charFromCodepoint(c) {
  if (c <= 0xFFFF) {
    return String.fromCharCode(c);
  }
  // Encode UTF-16 surrogate pair
  // https://en.wikipedia.org/wiki/UTF-16#Code_points_U.2B010000_to_U.2B10FFFF
  return String.fromCharCode(((c - 0x010000) >> 10) + 0xD800,
                             ((c - 0x010000) & 0x03FF) + 0xDC00);
}

var simpleEscapeCheck = new Array(256); // integer, for fast access
var simpleEscapeMap = new Array(256);
for (var i = 0; i < 256; i++) {
  simpleEscapeCheck[i] = simpleEscapeSequence(i) ? 1 : 0;
  simpleEscapeMap[i] = simpleEscapeSequence(i);
}


function State(input, options) {
  this.input = input;

  this.filename  = options['filename']  || null;
  this.schema    = options['schema']    || DEFAULT_FULL_SCHEMA;
  this.onWarning = options['onWarning'] || null;
  this.legacy    = options['legacy']    || false;

  this.implicitTypes = this.schema.compiledImplicit;
  this.typeMap       = this.schema.compiledTypeMap;

  this.length     = input.length;
  this.position   = 0;
  this.line       = 0;
  this.lineStart  = 0;
  this.lineIndent = 0;

  this.documents = [];

  /*
  this.version;
  this.checkLineBreaks;
  this.tagMap;
  this.anchorMap;
  this.tag;
  this.anchor;
  this.kind;
  this.result;*/

}


function generateError(state, message) {
  return new YAMLException(
    message,
    new Mark(state.filename, state.input, state.position, state.line, (state.position - state.lineStart)));
}

function throwError(state, message) {
  throw generateError(state, message);
}

function throwWarning(state, message) {
  if (state.onWarning) {
    state.onWarning.call(null, generateError(state, message));
  }
}


var directiveHandlers = {

  YAML: function handleYamlDirective(state, name, args) {

      var match, major, minor;

      if (null !== state.version) {
        throwError(state, 'duplication of %YAML directive');
      }

      if (1 !== args.length) {
        throwError(state, 'YAML directive accepts exactly one argument');
      }

      match = /^([0-9]+)\.([0-9]+)$/.exec(args[0]);

      if (null === match) {
        throwError(state, 'ill-formed argument of the YAML directive');
      }

      major = parseInt(match[1], 10);
      minor = parseInt(match[2], 10);

      if (1 !== major) {
        throwError(state, 'unacceptable YAML version of the document');
      }

      state.version = args[0];
      state.checkLineBreaks = (minor < 2);

      if (1 !== minor && 2 !== minor) {
        throwWarning(state, 'unsupported YAML version of the document');
      }
    },

  TAG: function handleTagDirective(state, name, args) {

      var handle, prefix;

      if (2 !== args.length) {
        throwError(state, 'TAG directive accepts exactly two arguments');
      }

      handle = args[0];
      prefix = args[1];

      if (!PATTERN_TAG_HANDLE.test(handle)) {
        throwError(state, 'ill-formed tag handle (first argument) of the TAG directive');
      }

      if (_hasOwnProperty.call(state.tagMap, handle)) {
        throwError(state, 'there is a previously declared suffix for "' + handle + '" tag handle');
      }

      if (!PATTERN_TAG_URI.test(prefix)) {
        throwError(state, 'ill-formed tag prefix (second argument) of the TAG directive');
      }

      state.tagMap[handle] = prefix;
    }
};


function captureSegment(state, start, end, checkJson) {
  var _position, _length, _character, _result;

  if (start < end) {
    _result = state.input.slice(start, end);

    if (checkJson) {
      for (_position = 0, _length = _result.length;
           _position < _length;
           _position += 1) {
        _character = _result.charCodeAt(_position);
        if (!(0x09 === _character ||
              0x20 <= _character && _character <= 0x10FFFF)) {
          throwError(state, 'expected valid JSON character');
        }
      }
    } else if (PATTERN_NON_PRINTABLE.test(_result)) {
      throwError(state, 'the stream contains non-printable characters');
    }

    state.result += _result;
  }
}

function mergeMappings(state, destination, source) {
  var sourceKeys, key, index, quantity;

  if (!common.isObject(source)) {
    throwError(state, 'cannot merge mappings; the provided source object is unacceptable');
  }

  sourceKeys = Object.keys(source);

  for (index = 0, quantity = sourceKeys.length; index < quantity; index += 1) {
    key = sourceKeys[index];

    if (!_hasOwnProperty.call(destination, key)) {
      destination[key] = source[key];
    }
  }
}

function storeMappingPair(state, _result, keyTag, keyNode, valueNode) {
  var index, quantity;

  keyNode = String(keyNode);

  if (null === _result) {
    _result = {};
  }

  if ('tag:yaml.org,2002:merge' === keyTag) {
    if (Array.isArray(valueNode)) {
      for (index = 0, quantity = valueNode.length; index < quantity; index += 1) {
        mergeMappings(state, _result, valueNode[index]);
      }
    } else {
      mergeMappings(state, _result, valueNode);
    }
  } else {
    _result[keyNode] = valueNode;
  }

  return _result;
}

function readLineBreak(state) {
  var ch;

  ch = state.input.charCodeAt(state.position);

  if (0x0A/* LF */ === ch) {
    state.position++;
  } else if (0x0D/* CR */ === ch) {
    state.position++;
    if (0x0A/* LF */ === state.input.charCodeAt(state.position)) {
      state.position++;
    }
  } else {
    throwError(state, 'a line break is expected');
  }

  state.line += 1;
  state.lineStart = state.position;
}

function skipSeparationSpace(state, allowComments, checkIndent) {
  var lineBreaks = 0,
      ch = state.input.charCodeAt(state.position);

  while (0 !== ch) {
    while (is_WHITE_SPACE(ch)) {
      ch = state.input.charCodeAt(++state.position);
    }

    if (allowComments && 0x23/* # */ === ch) {
      do {
        ch = state.input.charCodeAt(++state.position);
      } while (ch !== 0x0A/* LF */ && ch !== 0x0D/* CR */ && 0 !== ch);
    }

    if (is_EOL(ch)) {
      readLineBreak(state);

      ch = state.input.charCodeAt(state.position);
      lineBreaks++;
      state.lineIndent = 0;

      while (0x20/* Space */ === ch) {
        state.lineIndent++;
        ch = state.input.charCodeAt(++state.position);
      }
    } else {
      break;
    }
  }

  if (-1 !== checkIndent && 0 !== lineBreaks && state.lineIndent < checkIndent) {
    throwWarning(state, 'deficient indentation');
  }

  return lineBreaks;
}

function testDocumentSeparator(state) {
  var _position = state.position,
      ch;

  ch = state.input.charCodeAt(_position);

  // Condition state.position === state.lineStart is tested
  // in parent on each call, for efficiency. No needs to test here again.
  if ((0x2D/* - */ === ch || 0x2E/* . */ === ch) &&
      state.input.charCodeAt(_position + 1) === ch &&
      state.input.charCodeAt(_position + 2) === ch) {

    _position += 3;

    ch = state.input.charCodeAt(_position);

    if (ch === 0 || is_WS_OR_EOL(ch)) {
      return true;
    }
  }

  return false;
}

function writeFoldedLines(state, count) {
  if (1 === count) {
    state.result += ' ';
  } else if (count > 1) {
    state.result += common.repeat('\n', count - 1);
  }
}


function readPlainScalar(state, nodeIndent, withinFlowCollection) {
  var preceding,
      following,
      captureStart,
      captureEnd,
      hasPendingContent,
      _line,
      _lineStart,
      _lineIndent,
      _kind = state.kind,
      _result = state.result,
      ch;

  ch = state.input.charCodeAt(state.position);

  if (is_WS_OR_EOL(ch)             ||
      is_FLOW_INDICATOR(ch)        ||
      0x23/* # */           === ch ||
      0x26/* & */           === ch ||
      0x2A/* * */           === ch ||
      0x21/* ! */           === ch ||
      0x7C/* | */           === ch ||
      0x3E/* > */           === ch ||
      0x27/* ' */           === ch ||
      0x22/* " */           === ch ||
      0x25/* % */           === ch ||
      0x40/* @ */           === ch ||
      0x60/* ` */           === ch) {
    return false;
  }

  if (0x3F/* ? */ === ch || 0x2D/* - */ === ch) {
    following = state.input.charCodeAt(state.position + 1);

    if (is_WS_OR_EOL(following) ||
        withinFlowCollection && is_FLOW_INDICATOR(following)) {
      return false;
    }
  }

  state.kind = 'scalar';
  state.result = '';
  captureStart = captureEnd = state.position;
  hasPendingContent = false;

  while (0 !== ch) {
    if (0x3A/* : */ === ch) {
      following = state.input.charCodeAt(state.position + 1);

      if (is_WS_OR_EOL(following) ||
          withinFlowCollection && is_FLOW_INDICATOR(following)) {
        break;
      }

    } else if (0x23/* # */ === ch) {
      preceding = state.input.charCodeAt(state.position - 1);

      if (is_WS_OR_EOL(preceding)) {
        break;
      }

    } else if ((state.position === state.lineStart && testDocumentSeparator(state)) ||
               withinFlowCollection && is_FLOW_INDICATOR(ch)) {
      break;

    } else if (is_EOL(ch)) {
      _line = state.line;
      _lineStart = state.lineStart;
      _lineIndent = state.lineIndent;
      skipSeparationSpace(state, false, -1);

      if (state.lineIndent >= nodeIndent) {
        hasPendingContent = true;
        ch = state.input.charCodeAt(state.position);
        continue;
      } else {
        state.position = captureEnd;
        state.line = _line;
        state.lineStart = _lineStart;
        state.lineIndent = _lineIndent;
        break;
      }
    }

    if (hasPendingContent) {
      captureSegment(state, captureStart, captureEnd, false);
      writeFoldedLines(state, state.line - _line);
      captureStart = captureEnd = state.position;
      hasPendingContent = false;
    }

    if (!is_WHITE_SPACE(ch)) {
      captureEnd = state.position + 1;
    }

    ch = state.input.charCodeAt(++state.position);
  }

  captureSegment(state, captureStart, captureEnd, false);

  if (state.result) {
    return true;
  }

  state.kind = _kind;
  state.result = _result;
  return false;
}

function readSingleQuotedScalar(state, nodeIndent) {
  var ch,
      captureStart, captureEnd;

  ch = state.input.charCodeAt(state.position);

  if (0x27/* ' */ !== ch) {
    return false;
  }

  state.kind = 'scalar';
  state.result = '';
  state.position++;
  captureStart = captureEnd = state.position;

  while (0 !== (ch = state.input.charCodeAt(state.position))) {
    if (0x27/* ' */ === ch) {
      captureSegment(state, captureStart, state.position, true);
      ch = state.input.charCodeAt(++state.position);

      if (0x27/* ' */ === ch) {
        captureStart = captureEnd = state.position;
        state.position++;
      } else {
        return true;
      }

    } else if (is_EOL(ch)) {
      captureSegment(state, captureStart, captureEnd, true);
      writeFoldedLines(state, skipSeparationSpace(state, false, nodeIndent));
      captureStart = captureEnd = state.position;

    } else if (state.position === state.lineStart && testDocumentSeparator(state)) {
      throwError(state, 'unexpected end of the document within a single quoted scalar');

    } else {
      state.position++;
      captureEnd = state.position;
    }
  }

  throwError(state, 'unexpected end of the stream within a single quoted scalar');
}

function readDoubleQuotedScalar(state, nodeIndent) {
  var captureStart,
      captureEnd,
      hexLength,
      hexResult,
      tmp,
      ch;

  ch = state.input.charCodeAt(state.position);

  if (0x22/* " */ !== ch) {
    return false;
  }

  state.kind = 'scalar';
  state.result = '';
  state.position++;
  captureStart = captureEnd = state.position;

  while (0 !== (ch = state.input.charCodeAt(state.position))) {
    if (0x22/* " */ === ch) {
      captureSegment(state, captureStart, state.position, true);
      state.position++;
      return true;

    } else if (0x5C/* \ */ === ch) {
      captureSegment(state, captureStart, state.position, true);
      ch = state.input.charCodeAt(++state.position);

      if (is_EOL(ch)) {
        skipSeparationSpace(state, false, nodeIndent);

        // TODO: rework to inline fn with no type cast?
      } else if (ch < 256 && simpleEscapeCheck[ch]) {
        state.result += simpleEscapeMap[ch];
        state.position++;

      } else if ((tmp = escapedHexLen(ch)) > 0) {
        hexLength = tmp;
        hexResult = 0;

        for (; hexLength > 0; hexLength--) {
          ch = state.input.charCodeAt(++state.position);

          if ((tmp = fromHexCode(ch)) >= 0) {
            hexResult = (hexResult << 4) + tmp;

          } else {
            throwError(state, 'expected hexadecimal character');
          }
        }

        state.result += charFromCodepoint(hexResult);

        state.position++;

      } else {
        throwError(state, 'unknown escape sequence');
      }

      captureStart = captureEnd = state.position;

    } else if (is_EOL(ch)) {
      captureSegment(state, captureStart, captureEnd, true);
      writeFoldedLines(state, skipSeparationSpace(state, false, nodeIndent));
      captureStart = captureEnd = state.position;

    } else if (state.position === state.lineStart && testDocumentSeparator(state)) {
      throwError(state, 'unexpected end of the document within a double quoted scalar');

    } else {
      state.position++;
      captureEnd = state.position;
    }
  }

  throwError(state, 'unexpected end of the stream within a double quoted scalar');
}

function readFlowCollection(state, nodeIndent) {
  var readNext = true,
      _line,
      _tag     = state.tag,
      _result,
      _anchor  = state.anchor,
      following,
      terminator,
      isPair,
      isExplicitPair,
      isMapping,
      keyNode,
      keyTag,
      valueNode,
      ch;

  ch = state.input.charCodeAt(state.position);

  if (ch === 0x5B/* [ */) {
    terminator = 0x5D;/* ] */
    isMapping = false;
    _result = [];
  } else if (ch === 0x7B/* { */) {
    terminator = 0x7D;/* } */
    isMapping = true;
    _result = {};
  } else {
    return false;
  }

  if (null !== state.anchor) {
    state.anchorMap[state.anchor] = _result;
  }

  ch = state.input.charCodeAt(++state.position);

  while (0 !== ch) {
    skipSeparationSpace(state, true, nodeIndent);

    ch = state.input.charCodeAt(state.position);

    if (ch === terminator) {
      state.position++;
      state.tag = _tag;
      state.anchor = _anchor;
      state.kind = isMapping ? 'mapping' : 'sequence';
      state.result = _result;
      return true;
    } else if (!readNext) {
      throwError(state, 'missed comma between flow collection entries');
    }

    keyTag = keyNode = valueNode = null;
    isPair = isExplicitPair = false;

    if (0x3F/* ? */ === ch) {
      following = state.input.charCodeAt(state.position + 1);

      if (is_WS_OR_EOL(following)) {
        isPair = isExplicitPair = true;
        state.position++;
        skipSeparationSpace(state, true, nodeIndent);
      }
    }

    _line = state.line;
    composeNode(state, nodeIndent, CONTEXT_FLOW_IN, false, true);
    keyTag = state.tag;
    keyNode = state.result;
    skipSeparationSpace(state, true, nodeIndent);

    ch = state.input.charCodeAt(state.position);

    if ((isExplicitPair || state.line === _line) && 0x3A/* : */ === ch) {
      isPair = true;
      ch = state.input.charCodeAt(++state.position);
      skipSeparationSpace(state, true, nodeIndent);
      composeNode(state, nodeIndent, CONTEXT_FLOW_IN, false, true);
      valueNode = state.result;
    }

    if (isMapping) {
      storeMappingPair(state, _result, keyTag, keyNode, valueNode);
    } else if (isPair) {
      _result.push(storeMappingPair(state, null, keyTag, keyNode, valueNode));
    } else {
      _result.push(keyNode);
    }

    skipSeparationSpace(state, true, nodeIndent);

    ch = state.input.charCodeAt(state.position);

    if (0x2C/* , */ === ch) {
      readNext = true;
      ch = state.input.charCodeAt(++state.position);
    } else {
      readNext = false;
    }
  }

  throwError(state, 'unexpected end of the stream within a flow collection');
}

function readBlockScalar(state, nodeIndent) {
  var captureStart,
      folding,
      chomping       = CHOMPING_CLIP,
      detectedIndent = false,
      textIndent     = nodeIndent,
      emptyLines     = 0,
      atMoreIndented = false,
      tmp,
      ch;

  ch = state.input.charCodeAt(state.position);

  if (ch === 0x7C/* | */) {
    folding = false;
  } else if (ch === 0x3E/* > */) {
    folding = true;
  } else {
    return false;
  }

  state.kind = 'scalar';
  state.result = '';

  while (0 !== ch) {
    ch = state.input.charCodeAt(++state.position);

    if (0x2B/* + */ === ch || 0x2D/* - */ === ch) {
      if (CHOMPING_CLIP === chomping) {
        chomping = (0x2B/* + */ === ch) ? CHOMPING_KEEP : CHOMPING_STRIP;
      } else {
        throwError(state, 'repeat of a chomping mode identifier');
      }

    } else if ((tmp = fromDecimalCode(ch)) >= 0) {
      if (tmp === 0) {
        throwError(state, 'bad explicit indentation width of a block scalar; it cannot be less than one');
      } else if (!detectedIndent) {
        textIndent = nodeIndent + tmp - 1;
        detectedIndent = true;
      } else {
        throwError(state, 'repeat of an indentation width identifier');
      }

    } else {
      break;
    }
  }

  if (is_WHITE_SPACE(ch)) {
    do { ch = state.input.charCodeAt(++state.position); }
    while (is_WHITE_SPACE(ch));

    if (0x23/* # */ === ch) {
      do { ch = state.input.charCodeAt(++state.position); }
      while (!is_EOL(ch) && (0 !== ch));
    }
  }

  while (0 !== ch) {
    readLineBreak(state);
    state.lineIndent = 0;

    ch = state.input.charCodeAt(state.position);

    while ((!detectedIndent || state.lineIndent < textIndent) &&
           (0x20/* Space */ === ch)) {
      state.lineIndent++;
      ch = state.input.charCodeAt(++state.position);
    }

    if (!detectedIndent && state.lineIndent > textIndent) {
      textIndent = state.lineIndent;
    }

    if (is_EOL(ch)) {
      emptyLines++;
      continue;
    }

    // End of the scalar.
    if (state.lineIndent < textIndent) {

      // Perform the chomping.
      if (chomping === CHOMPING_KEEP) {
        state.result += common.repeat('\n', emptyLines);
      } else if (chomping === CHOMPING_CLIP) {
        if (detectedIndent) { // i.e. only if the scalar is not empty.
          state.result += '\n';
        }
      }

      // Break this `while` cycle and go to the funciton's epilogue.
      break;
    }

    // Folded style: use fancy rules to handle line breaks.
    if (folding) {

      // Lines starting with white space characters (more-indented lines) are not folded.
      if (is_WHITE_SPACE(ch)) {
        atMoreIndented = true;
        state.result += common.repeat('\n', emptyLines + 1);

      // End of more-indented block.
      } else if (atMoreIndented) {
        atMoreIndented = false;
        state.result += common.repeat('\n', emptyLines + 1);

      // Just one line break - perceive as the same line.
      } else if (0 === emptyLines) {
        if (detectedIndent) { // i.e. only if we have already read some scalar content.
          state.result += ' ';
        }

      // Several line breaks - perceive as different lines.
      } else {
        state.result += common.repeat('\n', emptyLines);
      }

    // Literal style: just add exact number of line breaks between content lines.
    } else if (detectedIndent) {
      // If current line isn't the first one - count line break from the last content line.
      state.result += common.repeat('\n', emptyLines + 1);
    } else {
      // In case of the first content line - count only empty lines.
      state.result += common.repeat('\n', emptyLines);
    }

    detectedIndent = true;
    emptyLines = 0;
    captureStart = state.position;

    while (!is_EOL(ch) && (0 !== ch)) {
      ch = state.input.charCodeAt(++state.position);
    }

    captureSegment(state, captureStart, state.position, false);
  }

  return true;
}

function readBlockSequence(state, nodeIndent) {
  var _line,
      _tag      = state.tag,
      _anchor   = state.anchor,
      _result   = [],
      following,
      detected  = false,
      ch;

  if (null !== state.anchor) {
    state.anchorMap[state.anchor] = _result;
  }

  ch = state.input.charCodeAt(state.position);

  while (0 !== ch) {

    if (0x2D/* - */ !== ch) {
      break;
    }

    following = state.input.charCodeAt(state.position + 1);

    if (!is_WS_OR_EOL(following)) {
      break;
    }

    detected = true;
    state.position++;

    if (skipSeparationSpace(state, true, -1)) {
      if (state.lineIndent <= nodeIndent) {
        _result.push(null);
        ch = state.input.charCodeAt(state.position);
        continue;
      }
    }

    _line = state.line;
    composeNode(state, nodeIndent, CONTEXT_BLOCK_IN, false, true);
    _result.push(state.result);
    skipSeparationSpace(state, true, -1);

    ch = state.input.charCodeAt(state.position);

    if ((state.line === _line || state.lineIndent > nodeIndent) && (0 !== ch)) {
      throwError(state, 'bad indentation of a sequence entry');
    } else if (state.lineIndent < nodeIndent) {
      break;
    }
  }

  if (detected) {
    state.tag = _tag;
    state.anchor = _anchor;
    state.kind = 'sequence';
    state.result = _result;
    return true;
  }
  return false;
}

function readBlockMapping(state, nodeIndent, flowIndent) {
  var following,
      allowCompact,
      _line,
      _tag          = state.tag,
      _anchor       = state.anchor,
      _result       = {},
      keyTag        = null,
      keyNode       = null,
      valueNode     = null,
      atExplicitKey = false,
      detected      = false,
      ch;

  if (null !== state.anchor) {
    state.anchorMap[state.anchor] = _result;
  }

  ch = state.input.charCodeAt(state.position);

  while (0 !== ch) {
    following = state.input.charCodeAt(state.position + 1);
    _line = state.line; // Save the current line.

    //
    // Explicit notation case. There are two separate blocks:
    // first for the key (denoted by "?") and second for the value (denoted by ":")
    //
    if ((0x3F/* ? */ === ch || 0x3A/* : */  === ch) && is_WS_OR_EOL(following)) {

      if (0x3F/* ? */ === ch) {
        if (atExplicitKey) {
          storeMappingPair(state, _result, keyTag, keyNode, null);
          keyTag = keyNode = valueNode = null;
        }

        detected = true;
        atExplicitKey = true;
        allowCompact = true;

      } else if (atExplicitKey) {
        // i.e. 0x3A/* : */ === character after the explicit key.
        atExplicitKey = false;
        allowCompact = true;

      } else {
        throwError(state, 'incomplete explicit mapping pair; a key node is missed');
      }

      state.position += 1;
      ch = following;

    //
    // Implicit notation case. Flow-style node as the key first, then ":", and the value.
    //
    } else if (composeNode(state, flowIndent, CONTEXT_FLOW_OUT, false, true)) {

      if (state.line === _line) {
        ch = state.input.charCodeAt(state.position);

        while (is_WHITE_SPACE(ch)) {
          ch = state.input.charCodeAt(++state.position);
        }

        if (0x3A/* : */ === ch) {
          ch = state.input.charCodeAt(++state.position);

          if (!is_WS_OR_EOL(ch)) {
            throwError(state, 'a whitespace character is expected after the key-value separator within a block mapping');
          }

          if (atExplicitKey) {
            storeMappingPair(state, _result, keyTag, keyNode, null);
            keyTag = keyNode = valueNode = null;
          }

          detected = true;
          atExplicitKey = false;
          allowCompact = false;
          keyTag = state.tag;
          keyNode = state.result;

        } else if (detected) {
          throwError(state, 'can not read an implicit mapping pair; a colon is missed');

        } else {
          state.tag = _tag;
          state.anchor = _anchor;
          return true; // Keep the result of `composeNode`.
        }

      } else if (detected) {
        throwError(state, 'can not read a block mapping entry; a multiline key may not be an implicit key');

      } else {
        state.tag = _tag;
        state.anchor = _anchor;
        return true; // Keep the result of `composeNode`.
      }

    } else {
      break; // Reading is done. Go to the epilogue.
    }

    //
    // Common reading code for both explicit and implicit notations.
    //
    if (state.line === _line || state.lineIndent > nodeIndent) {
      if (composeNode(state, nodeIndent, CONTEXT_BLOCK_OUT, true, allowCompact)) {
        if (atExplicitKey) {
          keyNode = state.result;
        } else {
          valueNode = state.result;
        }
      }

      if (!atExplicitKey) {
        storeMappingPair(state, _result, keyTag, keyNode, valueNode);
        keyTag = keyNode = valueNode = null;
      }

      skipSeparationSpace(state, true, -1);
      ch = state.input.charCodeAt(state.position);
    }

    if (state.lineIndent > nodeIndent && (0 !== ch)) {
      throwError(state, 'bad indentation of a mapping entry');
    } else if (state.lineIndent < nodeIndent) {
      break;
    }
  }

  //
  // Epilogue.
  //

  // Special case: last mapping's node contains only the key in explicit notation.
  if (atExplicitKey) {
    storeMappingPair(state, _result, keyTag, keyNode, null);
  }

  // Expose the resulting mapping.
  if (detected) {
    state.tag = _tag;
    state.anchor = _anchor;
    state.kind = 'mapping';
    state.result = _result;
  }

  return detected;
}

function readTagProperty(state) {
  var _position,
      isVerbatim = false,
      isNamed    = false,
      tagHandle,
      tagName,
      ch;

  ch = state.input.charCodeAt(state.position);

  if (0x21/* ! */ !== ch) {
    return false;
  }

  if (null !== state.tag) {
    throwError(state, 'duplication of a tag property');
  }

  ch = state.input.charCodeAt(++state.position);

  if (0x3C/* < */ === ch) {
    isVerbatim = true;
    ch = state.input.charCodeAt(++state.position);

  } else if (0x21/* ! */ === ch) {
    isNamed = true;
    tagHandle = '!!';
    ch = state.input.charCodeAt(++state.position);

  } else {
    tagHandle = '!';
  }

  _position = state.position;

  if (isVerbatim) {
    do { ch = state.input.charCodeAt(++state.position); }
    while (0 !== ch && 0x3E/* > */ !== ch);

    if (state.position < state.length) {
      tagName = state.input.slice(_position, state.position);
      ch = state.input.charCodeAt(++state.position);
    } else {
      throwError(state, 'unexpected end of the stream within a verbatim tag');
    }
  } else {
    while (0 !== ch && !is_WS_OR_EOL(ch)) {

      if (0x21/* ! */ === ch) {
        if (!isNamed) {
          tagHandle = state.input.slice(_position - 1, state.position + 1);

          if (!PATTERN_TAG_HANDLE.test(tagHandle)) {
            throwError(state, 'named tag handle cannot contain such characters');
          }

          isNamed = true;
          _position = state.position + 1;
        } else {
          throwError(state, 'tag suffix cannot contain exclamation marks');
        }
      }

      ch = state.input.charCodeAt(++state.position);
    }

    tagName = state.input.slice(_position, state.position);

    if (PATTERN_FLOW_INDICATORS.test(tagName)) {
      throwError(state, 'tag suffix cannot contain flow indicator characters');
    }
  }

  if (tagName && !PATTERN_TAG_URI.test(tagName)) {
    throwError(state, 'tag name cannot contain such characters: ' + tagName);
  }

  if (isVerbatim) {
    state.tag = tagName;

  } else if (_hasOwnProperty.call(state.tagMap, tagHandle)) {
    state.tag = state.tagMap[tagHandle] + tagName;

  } else if ('!' === tagHandle) {
    state.tag = '!' + tagName;

  } else if ('!!' === tagHandle) {
    state.tag = 'tag:yaml.org,2002:' + tagName;

  } else {
    throwError(state, 'undeclared tag handle "' + tagHandle + '"');
  }

  return true;
}

function readAnchorProperty(state) {
  var _position,
      ch;

  ch = state.input.charCodeAt(state.position);

  if (0x26/* & */ !== ch) {
    return false;
  }

  if (null !== state.anchor) {
    throwError(state, 'duplication of an anchor property');
  }

  ch = state.input.charCodeAt(++state.position);
  _position = state.position;

  while (0 !== ch && !is_WS_OR_EOL(ch) && !is_FLOW_INDICATOR(ch)) {
    ch = state.input.charCodeAt(++state.position);
  }

  if (state.position === _position) {
    throwError(state, 'name of an anchor node must contain at least one character');
  }

  state.anchor = state.input.slice(_position, state.position);
  return true;
}

function readAlias(state) {
  var _position, alias,
      ch;

  ch = state.input.charCodeAt(state.position);

  if (0x2A/* * */ !== ch) {
    return false;
  }

  ch = state.input.charCodeAt(++state.position);
  _position = state.position;

  while (0 !== ch && !is_WS_OR_EOL(ch) && !is_FLOW_INDICATOR(ch)) {
    ch = state.input.charCodeAt(++state.position);
  }

  if (state.position === _position) {
    throwError(state, 'name of an alias node must contain at least one character');
  }

  alias = state.input.slice(_position, state.position);

  if (!state.anchorMap.hasOwnProperty(alias)) {
    throwError(state, 'unidentified alias "' + alias + '"');
  }

  state.result = state.anchorMap[alias];
  skipSeparationSpace(state, true, -1);
  return true;
}

function composeNode(state, parentIndent, nodeContext, allowToSeek, allowCompact) {
  var allowBlockStyles,
      allowBlockScalars,
      allowBlockCollections,
      indentStatus = 1, // 1: this>parent, 0: this=parent, -1: this<parent
      atNewLine  = false,
      hasContent = false,
      typeIndex,
      typeQuantity,
      type,
      flowIndent,
      blockIndent;

  state.tag    = null;
  state.anchor = null;
  state.kind   = null;
  state.result = null;

  allowBlockStyles = allowBlockScalars = allowBlockCollections =
    CONTEXT_BLOCK_OUT === nodeContext ||
    CONTEXT_BLOCK_IN  === nodeContext;

  if (allowToSeek) {
    if (skipSeparationSpace(state, true, -1)) {
      atNewLine = true;

      if (state.lineIndent > parentIndent) {
        indentStatus = 1;
      } else if (state.lineIndent === parentIndent) {
        indentStatus = 0;
      } else if (state.lineIndent < parentIndent) {
        indentStatus = -1;
      }
    }
  }

  if (1 === indentStatus) {
    while (readTagProperty(state) || readAnchorProperty(state)) {
      if (skipSeparationSpace(state, true, -1)) {
        atNewLine = true;
        allowBlockCollections = allowBlockStyles;

        if (state.lineIndent > parentIndent) {
          indentStatus = 1;
        } else if (state.lineIndent === parentIndent) {
          indentStatus = 0;
        } else if (state.lineIndent < parentIndent) {
          indentStatus = -1;
        }
      } else {
        allowBlockCollections = false;
      }
    }
  }

  if (allowBlockCollections) {
    allowBlockCollections = atNewLine || allowCompact;
  }

  if (1 === indentStatus || CONTEXT_BLOCK_OUT === nodeContext) {
    if (CONTEXT_FLOW_IN === nodeContext || CONTEXT_FLOW_OUT === nodeContext) {
      flowIndent = parentIndent;
    } else {
      flowIndent = parentIndent + 1;
    }

    blockIndent = state.position - state.lineStart;

    if (1 === indentStatus) {
      if (allowBlockCollections &&
          (readBlockSequence(state, blockIndent) ||
           readBlockMapping(state, blockIndent, flowIndent)) ||
          readFlowCollection(state, flowIndent)) {
        hasContent = true;
      } else {
        if ((allowBlockScalars && readBlockScalar(state, flowIndent)) ||
            readSingleQuotedScalar(state, flowIndent) ||
            readDoubleQuotedScalar(state, flowIndent)) {
          hasContent = true;

        } else if (readAlias(state)) {
          hasContent = true;

          if (null !== state.tag || null !== state.anchor) {
            throwError(state, 'alias node should not have any properties');
          }

        } else if (readPlainScalar(state, flowIndent, CONTEXT_FLOW_IN === nodeContext)) {
          hasContent = true;

          if (null === state.tag) {
            state.tag = '?';
          }
        }

        if (null !== state.anchor) {
          state.anchorMap[state.anchor] = state.result;
        }
      }
    } else if (0 === indentStatus) {
      // Special case: block sequences are allowed to have same indentation level as the parent.
      // http://www.yaml.org/spec/1.2/spec.html#id2799784
      hasContent = allowBlockCollections && readBlockSequence(state, blockIndent);
    }
  }

  if (null !== state.tag && '!' !== state.tag) {
    if ('?' === state.tag) {
      for (typeIndex = 0, typeQuantity = state.implicitTypes.length;
           typeIndex < typeQuantity;
           typeIndex += 1) {
        type = state.implicitTypes[typeIndex];

        // Implicit resolving is not allowed for non-scalar types, and '?'
        // non-specific tag is only assigned to plain scalars. So, it isn't
        // needed to check for 'kind' conformity.

        if (type.resolve(state.result)) { // `state.result` updated in resolver if matched
          state.result = type.construct(state.result);
          state.tag = type.tag;
          if (null !== state.anchor) {
            state.anchorMap[state.anchor] = state.result;
          }
          break;
        }
      }
    } else if (_hasOwnProperty.call(state.typeMap, state.tag)) {
      type = state.typeMap[state.tag];

      if (null !== state.result && type.kind !== state.kind) {
        throwError(state, 'unacceptable node kind for !<' + state.tag + '> tag; it should be "' + type.kind + '", not "' + state.kind + '"');
      }

      if (!type.resolve(state.result)) { // `state.result` updated in resolver if matched
        throwError(state, 'cannot resolve a node with !<' + state.tag + '> explicit tag');
      } else {
        state.result = type.construct(state.result);
        if (null !== state.anchor) {
          state.anchorMap[state.anchor] = state.result;
        }
      }
    } else {
      throwError(state, 'unknown tag !<' + state.tag + '>');
    }
  }

  return null !== state.tag || null !== state.anchor || hasContent;
}

function readDocument(state) {
  var documentStart = state.position,
      _position,
      directiveName,
      directiveArgs,
      hasDirectives = false,
      ch;

  state.version = null;
  state.checkLineBreaks = state.legacy;
  state.tagMap = {};
  state.anchorMap = {};

  while (0 !== (ch = state.input.charCodeAt(state.position))) {
    skipSeparationSpace(state, true, -1);

    ch = state.input.charCodeAt(state.position);

    if (state.lineIndent > 0 || 0x25/* % */ !== ch) {
      break;
    }

    hasDirectives = true;
    ch = state.input.charCodeAt(++state.position);
    _position = state.position;

    while (0 !== ch && !is_WS_OR_EOL(ch)) {
      ch = state.input.charCodeAt(++state.position);
    }

    directiveName = state.input.slice(_position, state.position);
    directiveArgs = [];

    if (directiveName.length < 1) {
      throwError(state, 'directive name must not be less than one character in length');
    }

    while (0 !== ch) {
      while (is_WHITE_SPACE(ch)) {
        ch = state.input.charCodeAt(++state.position);
      }

      if (0x23/* # */ === ch) {
        do { ch = state.input.charCodeAt(++state.position); }
        while (0 !== ch && !is_EOL(ch));
        break;
      }

      if (is_EOL(ch)) {
        break;
      }

      _position = state.position;

      while (0 !== ch && !is_WS_OR_EOL(ch)) {
        ch = state.input.charCodeAt(++state.position);
      }

      directiveArgs.push(state.input.slice(_position, state.position));
    }

    if (0 !== ch) {
      readLineBreak(state);
    }

    if (_hasOwnProperty.call(directiveHandlers, directiveName)) {
      directiveHandlers[directiveName](state, directiveName, directiveArgs);
    } else {
      throwWarning(state, 'unknown document directive "' + directiveName + '"');
    }
  }

  skipSeparationSpace(state, true, -1);

  if (0 === state.lineIndent &&
      0x2D/* - */ === state.input.charCodeAt(state.position) &&
      0x2D/* - */ === state.input.charCodeAt(state.position + 1) &&
      0x2D/* - */ === state.input.charCodeAt(state.position + 2)) {
    state.position += 3;
    skipSeparationSpace(state, true, -1);

  } else if (hasDirectives) {
    throwError(state, 'directives end mark is expected');
  }

  composeNode(state, state.lineIndent - 1, CONTEXT_BLOCK_OUT, false, true);
  skipSeparationSpace(state, true, -1);

  if (state.checkLineBreaks &&
      PATTERN_NON_ASCII_LINE_BREAKS.test(state.input.slice(documentStart, state.position))) {
    throwWarning(state, 'non-ASCII line breaks are interpreted as content');
  }

  state.documents.push(state.result);

  if (state.position === state.lineStart && testDocumentSeparator(state)) {

    if (0x2E/* . */ === state.input.charCodeAt(state.position)) {
      state.position += 3;
      skipSeparationSpace(state, true, -1);
    }
    return;
  }

  if (state.position < (state.length - 1)) {
    throwError(state, 'end of the stream or a document separator is expected');
  } else {
    return;
  }
}


function loadDocuments(input, options) {
  input = String(input);
  options = options || {};

  if (input.length !== 0) {

    // Add tailing `\n` if not exists
    if (0x0A/* LF */ !== input.charCodeAt(input.length - 1) &&
        0x0D/* CR */ !== input.charCodeAt(input.length - 1)) {
      input += '\n';
    }

    // Strip BOM
    if (input.charCodeAt(0) === 0xFEFF) {
      input = input.slice(1);
    }
  }

  var state = new State(input, options);

  // Use 0 as string terminator. That significantly simplifies bounds check.
  state.input += '\0';

  while (0x20/* Space */ === state.input.charCodeAt(state.position)) {
    state.lineIndent += 1;
    state.position += 1;
  }

  while (state.position < (state.length - 1)) {
    readDocument(state);
  }

  return state.documents;
}


function loadAll(input, iterator, options) {
  var documents = loadDocuments(input, options), index, length;

  for (index = 0, length = documents.length; index < length; index += 1) {
    iterator(documents[index]);
  }
}


function load(input, options) {
  var documents = loadDocuments(input, options);

  if (0 === documents.length) {
    /*eslint-disable no-undefined*/
    return undefined;
  } else if (1 === documents.length) {
    return documents[0];
  }
  throw new YAMLException('expected a single document in the stream, but found more');
}


function safeLoadAll(input, output, options) {
  loadAll(input, output, common.extend({ schema: DEFAULT_SAFE_SCHEMA }, options));
}


function safeLoad(input, options) {
  return load(input, common.extend({ schema: DEFAULT_SAFE_SCHEMA }, options));
}


module.exports.loadAll     = loadAll;
module.exports.load        = load;
module.exports.safeLoadAll = safeLoadAll;
module.exports.safeLoad    = safeLoad;

},{"./common":23,"./exception":25,"./mark":27,"./schema/default_full":30,"./schema/default_safe":31}],27:[function(require,module,exports){
'use strict';


var common = require('./common');


function Mark(name, buffer, position, line, column) {
  this.name     = name;
  this.buffer   = buffer;
  this.position = position;
  this.line     = line;
  this.column   = column;
}


Mark.prototype.getSnippet = function getSnippet(indent, maxLength) {
  var head, start, tail, end, snippet;

  if (!this.buffer) {
    return null;
  }

  indent = indent || 4;
  maxLength = maxLength || 75;

  head = '';
  start = this.position;

  while (start > 0 && -1 === '\x00\r\n\x85\u2028\u2029'.indexOf(this.buffer.charAt(start - 1))) {
    start -= 1;
    if (this.position - start > (maxLength / 2 - 1)) {
      head = ' ... ';
      start += 5;
      break;
    }
  }

  tail = '';
  end = this.position;

  while (end < this.buffer.length && -1 === '\x00\r\n\x85\u2028\u2029'.indexOf(this.buffer.charAt(end))) {
    end += 1;
    if (end - this.position > (maxLength / 2 - 1)) {
      tail = ' ... ';
      end -= 5;
      break;
    }
  }

  snippet = this.buffer.slice(start, end);

  return common.repeat(' ', indent) + head + snippet + tail + '\n' +
         common.repeat(' ', indent + this.position - start + head.length) + '^';
};


Mark.prototype.toString = function toString(compact) {
  var snippet, where = '';

  if (this.name) {
    where += 'in "' + this.name + '" ';
  }

  where += 'at line ' + (this.line + 1) + ', column ' + (this.column + 1);

  if (!compact) {
    snippet = this.getSnippet();

    if (snippet) {
      where += ':\n' + snippet;
    }
  }

  return where;
};


module.exports = Mark;

},{"./common":23}],28:[function(require,module,exports){
'use strict';

/*eslint-disable max-len*/

var common        = require('./common');
var YAMLException = require('./exception');
var Type          = require('./type');


function compileList(schema, name, result) {
  var exclude = [];

  schema.include.forEach(function (includedSchema) {
    result = compileList(includedSchema, name, result);
  });

  schema[name].forEach(function (currentType) {
    result.forEach(function (previousType, previousIndex) {
      if (previousType.tag === currentType.tag) {
        exclude.push(previousIndex);
      }
    });

    result.push(currentType);
  });

  return result.filter(function (type, index) {
    return -1 === exclude.indexOf(index);
  });
}


function compileMap(/* lists... */) {
  var result = {}, index, length;

  function collectType(type) {
    result[type.tag] = type;
  }

  for (index = 0, length = arguments.length; index < length; index += 1) {
    arguments[index].forEach(collectType);
  }

  return result;
}


function Schema(definition) {
  this.include  = definition.include  || [];
  this.implicit = definition.implicit || [];
  this.explicit = definition.explicit || [];

  this.implicit.forEach(function (type) {
    if (type.loadKind && 'scalar' !== type.loadKind) {
      throw new YAMLException('There is a non-scalar type in the implicit list of a schema. Implicit resolving of such types is not supported.');
    }
  });

  this.compiledImplicit = compileList(this, 'implicit', []);
  this.compiledExplicit = compileList(this, 'explicit', []);
  this.compiledTypeMap  = compileMap(this.compiledImplicit, this.compiledExplicit);
}


Schema.DEFAULT = null;


Schema.create = function createSchema() {
  var schemas, types;

  switch (arguments.length) {
  case 1:
    schemas = Schema.DEFAULT;
    types = arguments[0];
    break;

  case 2:
    schemas = arguments[0];
    types = arguments[1];
    break;

  default:
    throw new YAMLException('Wrong number of arguments for Schema.create function');
  }

  schemas = common.toArray(schemas);
  types = common.toArray(types);

  if (!schemas.every(function (schema) { return schema instanceof Schema; })) {
    throw new YAMLException('Specified list of super schemas (or a single Schema object) contains a non-Schema object.');
  }

  if (!types.every(function (type) { return type instanceof Type; })) {
    throw new YAMLException('Specified list of YAML types (or a single Type object) contains a non-Type object.');
  }

  return new Schema({
    include: schemas,
    explicit: types
  });
};


module.exports = Schema;

},{"./common":23,"./exception":25,"./type":34}],29:[function(require,module,exports){
// Standard YAML's Core schema.
// http://www.yaml.org/spec/1.2/spec.html#id2804923
//
// NOTE: JS-YAML does not support schema-specific tag resolution restrictions.
// So, Core schema has no distinctions from JSON schema is JS-YAML.


'use strict';


var Schema = require('../schema');


module.exports = new Schema({
  include: [
    require('./json')
  ]
});

},{"../schema":28,"./json":33}],30:[function(require,module,exports){
// JS-YAML's default schema for `load` function.
// It is not described in the YAML specification.
//
// This schema is based on JS-YAML's default safe schema and includes
// JavaScript-specific types: !!js/undefined, !!js/regexp and !!js/function.
//
// Also this schema is used as default base schema at `Schema.create` function.


'use strict';


var Schema = require('../schema');


module.exports = Schema.DEFAULT = new Schema({
  include: [
    require('./default_safe')
  ],
  explicit: [
    require('../type/js/undefined'),
    require('../type/js/regexp'),
    require('../type/js/function')
  ]
});

},{"../schema":28,"../type/js/function":39,"../type/js/regexp":40,"../type/js/undefined":41,"./default_safe":31}],31:[function(require,module,exports){
// JS-YAML's default schema for `safeLoad` function.
// It is not described in the YAML specification.
//
// This schema is based on standard YAML's Core schema and includes most of
// extra types described at YAML tag repository. (http://yaml.org/type/)


'use strict';


var Schema = require('../schema');


module.exports = new Schema({
  include: [
    require('./core')
  ],
  implicit: [
    require('../type/timestamp'),
    require('../type/merge')
  ],
  explicit: [
    require('../type/binary'),
    require('../type/omap'),
    require('../type/pairs'),
    require('../type/set')
  ]
});

},{"../schema":28,"../type/binary":35,"../type/merge":43,"../type/omap":45,"../type/pairs":46,"../type/set":48,"../type/timestamp":50,"./core":29}],32:[function(require,module,exports){
// Standard YAML's Failsafe schema.
// http://www.yaml.org/spec/1.2/spec.html#id2802346


'use strict';


var Schema = require('../schema');


module.exports = new Schema({
  explicit: [
    require('../type/str'),
    require('../type/seq'),
    require('../type/map')
  ]
});

},{"../schema":28,"../type/map":42,"../type/seq":47,"../type/str":49}],33:[function(require,module,exports){
// Standard YAML's JSON schema.
// http://www.yaml.org/spec/1.2/spec.html#id2803231
//
// NOTE: JS-YAML does not support schema-specific tag resolution restrictions.
// So, this schema is not such strict as defined in the YAML specification.
// It allows numbers in binary notaion, use `Null` and `NULL` as `null`, etc.


'use strict';


var Schema = require('../schema');


module.exports = new Schema({
  include: [
    require('./failsafe')
  ],
  implicit: [
    require('../type/null'),
    require('../type/bool'),
    require('../type/int'),
    require('../type/float')
  ]
});

},{"../schema":28,"../type/bool":36,"../type/float":37,"../type/int":38,"../type/null":44,"./failsafe":32}],34:[function(require,module,exports){
'use strict';

var YAMLException = require('./exception');

var TYPE_CONSTRUCTOR_OPTIONS = [
  'kind',
  'resolve',
  'construct',
  'instanceOf',
  'predicate',
  'represent',
  'defaultStyle',
  'styleAliases'
];

var YAML_NODE_KINDS = [
  'scalar',
  'sequence',
  'mapping'
];

function compileStyleAliases(map) {
  var result = {};

  if (null !== map) {
    Object.keys(map).forEach(function (style) {
      map[style].forEach(function (alias) {
        result[String(alias)] = style;
      });
    });
  }

  return result;
}

function Type(tag, options) {
  options = options || {};

  Object.keys(options).forEach(function (name) {
    if (-1 === TYPE_CONSTRUCTOR_OPTIONS.indexOf(name)) {
      throw new YAMLException('Unknown option "' + name + '" is met in definition of "' + tag + '" YAML type.');
    }
  });

  // TODO: Add tag format check.
  this.tag          = tag;
  this.kind         = options['kind']         || null;
  this.resolve      = options['resolve']      || function () { return true; };
  this.construct    = options['construct']    || function (data) { return data; };
  this.instanceOf   = options['instanceOf']   || null;
  this.predicate    = options['predicate']    || null;
  this.represent    = options['represent']    || null;
  this.defaultStyle = options['defaultStyle'] || null;
  this.styleAliases = compileStyleAliases(options['styleAliases'] || null);

  if (-1 === YAML_NODE_KINDS.indexOf(this.kind)) {
    throw new YAMLException('Unknown kind "' + this.kind + '" is specified for "' + tag + '" YAML type.');
  }
}

module.exports = Type;

},{"./exception":25}],35:[function(require,module,exports){
'use strict';

/*eslint-disable no-bitwise*/

// A trick for browserified version.
// Since we make browserifier to ignore `buffer` module, NodeBuffer will be undefined
var NodeBuffer = require('buffer').Buffer;
var Type       = require('../type');


// [ 64, 65, 66 ] -> [ padding, CR, LF ]
var BASE64_MAP = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/=\n\r';


function resolveYamlBinary(data) {
  if (null === data) {
    return false;
  }

  var code, idx, bitlen = 0, max = data.length, map = BASE64_MAP;

  // Convert one by one.
  for (idx = 0; idx < max; idx++) {
    code = map.indexOf(data.charAt(idx));

    // Skip CR/LF
    if (code > 64) { continue; }

    // Fail on illegal characters
    if (code < 0) { return false; }

    bitlen += 6;
  }

  // If there are any bits left, source was corrupted
  return (bitlen % 8) === 0;
}

function constructYamlBinary(data) {
  var idx, tailbits,
      input = data.replace(/[\r\n=]/g, ''), // remove CR/LF & padding to simplify scan
      max = input.length,
      map = BASE64_MAP,
      bits = 0,
      result = [];

  // Collect by 6*4 bits (3 bytes)

  for (idx = 0; idx < max; idx++) {
    if ((idx % 4 === 0) && idx) {
      result.push((bits >> 16) & 0xFF);
      result.push((bits >> 8) & 0xFF);
      result.push(bits & 0xFF);
    }

    bits = (bits << 6) | map.indexOf(input.charAt(idx));
  }

  // Dump tail

  tailbits = (max % 4) * 6;

  if (tailbits === 0) {
    result.push((bits >> 16) & 0xFF);
    result.push((bits >> 8) & 0xFF);
    result.push(bits & 0xFF);
  } else if (tailbits === 18) {
    result.push((bits >> 10) & 0xFF);
    result.push((bits >> 2) & 0xFF);
  } else if (tailbits === 12) {
    result.push((bits >> 4) & 0xFF);
  }

  // Wrap into Buffer for NodeJS and leave Array for browser
  if (NodeBuffer) {
    return new NodeBuffer(result);
  }

  return result;
}

function representYamlBinary(object /*, style*/) {
  var result = '', bits = 0, idx, tail,
      max = object.length,
      map = BASE64_MAP;

  // Convert every three bytes to 4 ASCII characters.

  for (idx = 0; idx < max; idx++) {
    if ((idx % 3 === 0) && idx) {
      result += map[(bits >> 18) & 0x3F];
      result += map[(bits >> 12) & 0x3F];
      result += map[(bits >> 6) & 0x3F];
      result += map[bits & 0x3F];
    }

    bits = (bits << 8) + object[idx];
  }

  // Dump tail

  tail = max % 3;

  if (tail === 0) {
    result += map[(bits >> 18) & 0x3F];
    result += map[(bits >> 12) & 0x3F];
    result += map[(bits >> 6) & 0x3F];
    result += map[bits & 0x3F];
  } else if (tail === 2) {
    result += map[(bits >> 10) & 0x3F];
    result += map[(bits >> 4) & 0x3F];
    result += map[(bits << 2) & 0x3F];
    result += map[64];
  } else if (tail === 1) {
    result += map[(bits >> 2) & 0x3F];
    result += map[(bits << 4) & 0x3F];
    result += map[64];
    result += map[64];
  }

  return result;
}

function isBinary(object) {
  return NodeBuffer && NodeBuffer.isBuffer(object);
}

module.exports = new Type('tag:yaml.org,2002:binary', {
  kind: 'scalar',
  resolve: resolveYamlBinary,
  construct: constructYamlBinary,
  predicate: isBinary,
  represent: representYamlBinary
});

},{"../type":34,"buffer":56}],36:[function(require,module,exports){
'use strict';

var Type = require('../type');

function resolveYamlBoolean(data) {
  if (null === data) {
    return false;
  }

  var max = data.length;

  return (max === 4 && (data === 'true' || data === 'True' || data === 'TRUE')) ||
         (max === 5 && (data === 'false' || data === 'False' || data === 'FALSE'));
}

function constructYamlBoolean(data) {
  return data === 'true' ||
         data === 'True' ||
         data === 'TRUE';
}

function isBoolean(object) {
  return '[object Boolean]' === Object.prototype.toString.call(object);
}

module.exports = new Type('tag:yaml.org,2002:bool', {
  kind: 'scalar',
  resolve: resolveYamlBoolean,
  construct: constructYamlBoolean,
  predicate: isBoolean,
  represent: {
    lowercase: function (object) { return object ? 'true' : 'false'; },
    uppercase: function (object) { return object ? 'TRUE' : 'FALSE'; },
    camelcase: function (object) { return object ? 'True' : 'False'; }
  },
  defaultStyle: 'lowercase'
});

},{"../type":34}],37:[function(require,module,exports){
'use strict';

var common = require('../common');
var Type   = require('../type');

var YAML_FLOAT_PATTERN = new RegExp(
  '^(?:[-+]?(?:[0-9][0-9_]*)\\.[0-9_]*(?:[eE][-+][0-9]+)?' +
  '|\\.[0-9_]+(?:[eE][-+][0-9]+)?' +
  '|[-+]?[0-9][0-9_]*(?::[0-5]?[0-9])+\\.[0-9_]*' +
  '|[-+]?\\.(?:inf|Inf|INF)' +
  '|\\.(?:nan|NaN|NAN))$');

function resolveYamlFloat(data) {
  if (null === data) {
    return false;
  }

  if (!YAML_FLOAT_PATTERN.test(data)) {
    return false;
  }
  return true;
}

function constructYamlFloat(data) {
  var value, sign, base, digits;

  value  = data.replace(/_/g, '').toLowerCase();
  sign   = '-' === value[0] ? -1 : 1;
  digits = [];

  if (0 <= '+-'.indexOf(value[0])) {
    value = value.slice(1);
  }

  if ('.inf' === value) {
    return (1 === sign) ? Number.POSITIVE_INFINITY : Number.NEGATIVE_INFINITY;

  } else if ('.nan' === value) {
    return NaN;

  } else if (0 <= value.indexOf(':')) {
    value.split(':').forEach(function (v) {
      digits.unshift(parseFloat(v, 10));
    });

    value = 0.0;
    base = 1;

    digits.forEach(function (d) {
      value += d * base;
      base *= 60;
    });

    return sign * value;

  }
  return sign * parseFloat(value, 10);
}


var SCIENTIFIC_WITHOUT_DOT = /^[-+]?[0-9]+e/;

function representYamlFloat(object, style) {
  var res;

  if (isNaN(object)) {
    switch (style) {
    case 'lowercase':
      return '.nan';
    case 'uppercase':
      return '.NAN';
    case 'camelcase':
      return '.NaN';
    }
  } else if (Number.POSITIVE_INFINITY === object) {
    switch (style) {
    case 'lowercase':
      return '.inf';
    case 'uppercase':
      return '.INF';
    case 'camelcase':
      return '.Inf';
    }
  } else if (Number.NEGATIVE_INFINITY === object) {
    switch (style) {
    case 'lowercase':
      return '-.inf';
    case 'uppercase':
      return '-.INF';
    case 'camelcase':
      return '-.Inf';
    }
  } else if (common.isNegativeZero(object)) {
    return '-0.0';
  }

  res = object.toString(10);

  // JS stringifier can build scientific format without dots: 5e-100,
  // while YAML requres dot: 5.e-100. Fix it with simple hack

  return SCIENTIFIC_WITHOUT_DOT.test(res) ? res.replace('e', '.e') : res;
}

function isFloat(object) {
  return ('[object Number]' === Object.prototype.toString.call(object)) &&
         (0 !== object % 1 || common.isNegativeZero(object));
}

module.exports = new Type('tag:yaml.org,2002:float', {
  kind: 'scalar',
  resolve: resolveYamlFloat,
  construct: constructYamlFloat,
  predicate: isFloat,
  represent: representYamlFloat,
  defaultStyle: 'lowercase'
});

},{"../common":23,"../type":34}],38:[function(require,module,exports){
'use strict';

var common = require('../common');
var Type   = require('../type');

function isHexCode(c) {
  return ((0x30/* 0 */ <= c) && (c <= 0x39/* 9 */)) ||
         ((0x41/* A */ <= c) && (c <= 0x46/* F */)) ||
         ((0x61/* a */ <= c) && (c <= 0x66/* f */));
}

function isOctCode(c) {
  return ((0x30/* 0 */ <= c) && (c <= 0x37/* 7 */));
}

function isDecCode(c) {
  return ((0x30/* 0 */ <= c) && (c <= 0x39/* 9 */));
}

function resolveYamlInteger(data) {
  if (null === data) {
    return false;
  }

  var max = data.length,
      index = 0,
      hasDigits = false,
      ch;

  if (!max) { return false; }

  ch = data[index];

  // sign
  if (ch === '-' || ch === '+') {
    ch = data[++index];
  }

  if (ch === '0') {
    // 0
    if (index + 1 === max) { return true; }
    ch = data[++index];

    // base 2, base 8, base 16

    if (ch === 'b') {
      // base 2
      index++;

      for (; index < max; index++) {
        ch = data[index];
        if (ch === '_') { continue; }
        if (ch !== '0' && ch !== '1') {
          return false;
        }
        hasDigits = true;
      }
      return hasDigits;
    }


    if (ch === 'x') {
      // base 16
      index++;

      for (; index < max; index++) {
        ch = data[index];
        if (ch === '_') { continue; }
        if (!isHexCode(data.charCodeAt(index))) {
          return false;
        }
        hasDigits = true;
      }
      return hasDigits;
    }

    // base 8
    for (; index < max; index++) {
      ch = data[index];
      if (ch === '_') { continue; }
      if (!isOctCode(data.charCodeAt(index))) {
        return false;
      }
      hasDigits = true;
    }
    return hasDigits;
  }

  // base 10 (except 0) or base 60

  for (; index < max; index++) {
    ch = data[index];
    if (ch === '_') { continue; }
    if (ch === ':') { break; }
    if (!isDecCode(data.charCodeAt(index))) {
      return false;
    }
    hasDigits = true;
  }

  if (!hasDigits) { return false; }

  // if !base60 - done;
  if (ch !== ':') { return true; }

  // base60 almost not used, no needs to optimize
  return /^(:[0-5]?[0-9])+$/.test(data.slice(index));
}

function constructYamlInteger(data) {
  var value = data, sign = 1, ch, base, digits = [];

  if (value.indexOf('_') !== -1) {
    value = value.replace(/_/g, '');
  }

  ch = value[0];

  if (ch === '-' || ch === '+') {
    if (ch === '-') { sign = -1; }
    value = value.slice(1);
    ch = value[0];
  }

  if ('0' === value) {
    return 0;
  }

  if (ch === '0') {
    if (value[1] === 'b') {
      return sign * parseInt(value.slice(2), 2);
    }
    if (value[1] === 'x') {
      return sign * parseInt(value, 16);
    }
    return sign * parseInt(value, 8);

  }

  if (value.indexOf(':') !== -1) {
    value.split(':').forEach(function (v) {
      digits.unshift(parseInt(v, 10));
    });

    value = 0;
    base = 1;

    digits.forEach(function (d) {
      value += (d * base);
      base *= 60;
    });

    return sign * value;

  }

  return sign * parseInt(value, 10);
}

function isInteger(object) {
  return ('[object Number]' === Object.prototype.toString.call(object)) &&
         (0 === object % 1 && !common.isNegativeZero(object));
}

module.exports = new Type('tag:yaml.org,2002:int', {
  kind: 'scalar',
  resolve: resolveYamlInteger,
  construct: constructYamlInteger,
  predicate: isInteger,
  represent: {
    binary:      function (object) { return '0b' + object.toString(2); },
    octal:       function (object) { return '0'  + object.toString(8); },
    decimal:     function (object) { return        object.toString(10); },
    hexadecimal: function (object) { return '0x' + object.toString(16).toUpperCase(); }
  },
  defaultStyle: 'decimal',
  styleAliases: {
    binary:      [ 2,  'bin' ],
    octal:       [ 8,  'oct' ],
    decimal:     [ 10, 'dec' ],
    hexadecimal: [ 16, 'hex' ]
  }
});

},{"../common":23,"../type":34}],39:[function(require,module,exports){
'use strict';

var esprima;

// Browserified version does not have esprima
//
// 1. For node.js just require module as deps
// 2. For browser try to require mudule via external AMD system.
//    If not found - try to fallback to window.esprima. If not
//    found too - then fail to parse.
//
try {
  esprima = require('esprima');
} catch (_) {
  /*global window */
  if (typeof window !== 'undefined') { esprima = window.esprima; }
}

var Type = require('../../type');

function resolveJavascriptFunction(data) {
  if (null === data) {
    return false;
  }

  try {
    var source = '(' + data + ')',
        ast    = esprima.parse(source, { range: true });

    if ('Program'             !== ast.type         ||
        1                     !== ast.body.length  ||
        'ExpressionStatement' !== ast.body[0].type ||
        'FunctionExpression'  !== ast.body[0].expression.type) {
      return false;
    }

    return true;
  } catch (err) {
    return false;
  }
}

function constructJavascriptFunction(data) {
  /*jslint evil:true*/

  var source = '(' + data + ')',
      ast    = esprima.parse(source, { range: true }),
      params = [],
      body;

  if ('Program'             !== ast.type         ||
      1                     !== ast.body.length  ||
      'ExpressionStatement' !== ast.body[0].type ||
      'FunctionExpression'  !== ast.body[0].expression.type) {
    throw new Error('Failed to resolve function');
  }

  ast.body[0].expression.params.forEach(function (param) {
    params.push(param.name);
  });

  body = ast.body[0].expression.body.range;

  // Esprima's ranges include the first '{' and the last '}' characters on
  // function expressions. So cut them out.
  /*eslint-disable no-new-func*/
  return new Function(params, source.slice(body[0] + 1, body[1] - 1));
}

function representJavascriptFunction(object /*, style*/) {
  return object.toString();
}

function isFunction(object) {
  return '[object Function]' === Object.prototype.toString.call(object);
}

module.exports = new Type('tag:yaml.org,2002:js/function', {
  kind: 'scalar',
  resolve: resolveJavascriptFunction,
  construct: constructJavascriptFunction,
  predicate: isFunction,
  represent: representJavascriptFunction
});

},{"../../type":34,"esprima":51}],40:[function(require,module,exports){
'use strict';

var Type = require('../../type');

function resolveJavascriptRegExp(data) {
  if (null === data) {
    return false;
  }

  if (0 === data.length) {
    return false;
  }

  var regexp = data,
      tail   = /\/([gim]*)$/.exec(data),
      modifiers = '';

  // if regexp starts with '/' it can have modifiers and must be properly closed
  // `/foo/gim` - modifiers tail can be maximum 3 chars
  if ('/' === regexp[0]) {
    if (tail) {
      modifiers = tail[1];
    }

    if (modifiers.length > 3) { return false; }
    // if expression starts with /, is should be properly terminated
    if (regexp[regexp.length - modifiers.length - 1] !== '/') { return false; }

    regexp = regexp.slice(1, regexp.length - modifiers.length - 1);
  }

  try {
    return true;
  } catch (error) {
    return false;
  }
}

function constructJavascriptRegExp(data) {
  var regexp = data,
      tail   = /\/([gim]*)$/.exec(data),
      modifiers = '';

  // `/foo/gim` - tail can be maximum 4 chars
  if ('/' === regexp[0]) {
    if (tail) {
      modifiers = tail[1];
    }
    regexp = regexp.slice(1, regexp.length - modifiers.length - 1);
  }

  return new RegExp(regexp, modifiers);
}

function representJavascriptRegExp(object /*, style*/) {
  var result = '/' + object.source + '/';

  if (object.global) {
    result += 'g';
  }

  if (object.multiline) {
    result += 'm';
  }

  if (object.ignoreCase) {
    result += 'i';
  }

  return result;
}

function isRegExp(object) {
  return '[object RegExp]' === Object.prototype.toString.call(object);
}

module.exports = new Type('tag:yaml.org,2002:js/regexp', {
  kind: 'scalar',
  resolve: resolveJavascriptRegExp,
  construct: constructJavascriptRegExp,
  predicate: isRegExp,
  represent: representJavascriptRegExp
});

},{"../../type":34}],41:[function(require,module,exports){
'use strict';

var Type = require('../../type');

function resolveJavascriptUndefined() {
  return true;
}

function constructJavascriptUndefined() {
  /*eslint-disable no-undefined*/
  return undefined;
}

function representJavascriptUndefined() {
  return '';
}

function isUndefined(object) {
  return 'undefined' === typeof object;
}

module.exports = new Type('tag:yaml.org,2002:js/undefined', {
  kind: 'scalar',
  resolve: resolveJavascriptUndefined,
  construct: constructJavascriptUndefined,
  predicate: isUndefined,
  represent: representJavascriptUndefined
});

},{"../../type":34}],42:[function(require,module,exports){
'use strict';

var Type = require('../type');

module.exports = new Type('tag:yaml.org,2002:map', {
  kind: 'mapping',
  construct: function (data) { return null !== data ? data : {}; }
});

},{"../type":34}],43:[function(require,module,exports){
'use strict';

var Type = require('../type');

function resolveYamlMerge(data) {
  return '<<' === data || null === data;
}

module.exports = new Type('tag:yaml.org,2002:merge', {
  kind: 'scalar',
  resolve: resolveYamlMerge
});

},{"../type":34}],44:[function(require,module,exports){
'use strict';

var Type = require('../type');

function resolveYamlNull(data) {
  if (null === data) {
    return true;
  }

  var max = data.length;

  return (max === 1 && data === '~') ||
         (max === 4 && (data === 'null' || data === 'Null' || data === 'NULL'));
}

function constructYamlNull() {
  return null;
}

function isNull(object) {
  return null === object;
}

module.exports = new Type('tag:yaml.org,2002:null', {
  kind: 'scalar',
  resolve: resolveYamlNull,
  construct: constructYamlNull,
  predicate: isNull,
  represent: {
    canonical: function () { return '~';    },
    lowercase: function () { return 'null'; },
    uppercase: function () { return 'NULL'; },
    camelcase: function () { return 'Null'; }
  },
  defaultStyle: 'lowercase'
});

},{"../type":34}],45:[function(require,module,exports){
'use strict';

var Type = require('../type');

var _hasOwnProperty = Object.prototype.hasOwnProperty;
var _toString       = Object.prototype.toString;

function resolveYamlOmap(data) {
  if (null === data) {
    return true;
  }

  var objectKeys = [], index, length, pair, pairKey, pairHasKey,
      object = data;

  for (index = 0, length = object.length; index < length; index += 1) {
    pair = object[index];
    pairHasKey = false;

    if ('[object Object]' !== _toString.call(pair)) {
      return false;
    }

    for (pairKey in pair) {
      if (_hasOwnProperty.call(pair, pairKey)) {
        if (!pairHasKey) {
          pairHasKey = true;
        } else {
          return false;
        }
      }
    }

    if (!pairHasKey) {
      return false;
    }

    if (-1 === objectKeys.indexOf(pairKey)) {
      objectKeys.push(pairKey);
    } else {
      return false;
    }
  }

  return true;
}

function constructYamlOmap(data) {
  return null !== data ? data : [];
}

module.exports = new Type('tag:yaml.org,2002:omap', {
  kind: 'sequence',
  resolve: resolveYamlOmap,
  construct: constructYamlOmap
});

},{"../type":34}],46:[function(require,module,exports){
'use strict';

var Type = require('../type');

var _toString = Object.prototype.toString;

function resolveYamlPairs(data) {
  if (null === data) {
    return true;
  }

  var index, length, pair, keys, result,
      object = data;

  result = new Array(object.length);

  for (index = 0, length = object.length; index < length; index += 1) {
    pair = object[index];

    if ('[object Object]' !== _toString.call(pair)) {
      return false;
    }

    keys = Object.keys(pair);

    if (1 !== keys.length) {
      return false;
    }

    result[index] = [ keys[0], pair[keys[0]] ];
  }

  return true;
}

function constructYamlPairs(data) {
  if (null === data) {
    return [];
  }

  var index, length, pair, keys, result,
      object = data;

  result = new Array(object.length);

  for (index = 0, length = object.length; index < length; index += 1) {
    pair = object[index];

    keys = Object.keys(pair);

    result[index] = [ keys[0], pair[keys[0]] ];
  }

  return result;
}

module.exports = new Type('tag:yaml.org,2002:pairs', {
  kind: 'sequence',
  resolve: resolveYamlPairs,
  construct: constructYamlPairs
});

},{"../type":34}],47:[function(require,module,exports){
'use strict';

var Type = require('../type');

module.exports = new Type('tag:yaml.org,2002:seq', {
  kind: 'sequence',
  construct: function (data) { return null !== data ? data : []; }
});

},{"../type":34}],48:[function(require,module,exports){
'use strict';

var Type = require('../type');

var _hasOwnProperty = Object.prototype.hasOwnProperty;

function resolveYamlSet(data) {
  if (null === data) {
    return true;
  }

  var key, object = data;

  for (key in object) {
    if (_hasOwnProperty.call(object, key)) {
      if (null !== object[key]) {
        return false;
      }
    }
  }

  return true;
}

function constructYamlSet(data) {
  return null !== data ? data : {};
}

module.exports = new Type('tag:yaml.org,2002:set', {
  kind: 'mapping',
  resolve: resolveYamlSet,
  construct: constructYamlSet
});

},{"../type":34}],49:[function(require,module,exports){
'use strict';

var Type = require('../type');

module.exports = new Type('tag:yaml.org,2002:str', {
  kind: 'scalar',
  construct: function (data) { return null !== data ? data : ''; }
});

},{"../type":34}],50:[function(require,module,exports){
'use strict';

var Type = require('../type');

var YAML_TIMESTAMP_REGEXP = new RegExp(
  '^([0-9][0-9][0-9][0-9])'          + // [1] year
  '-([0-9][0-9]?)'                   + // [2] month
  '-([0-9][0-9]?)'                   + // [3] day
  '(?:(?:[Tt]|[ \\t]+)'              + // ...
  '([0-9][0-9]?)'                    + // [4] hour
  ':([0-9][0-9])'                    + // [5] minute
  ':([0-9][0-9])'                    + // [6] second
  '(?:\\.([0-9]*))?'                 + // [7] fraction
  '(?:[ \\t]*(Z|([-+])([0-9][0-9]?)' + // [8] tz [9] tz_sign [10] tz_hour
  '(?::([0-9][0-9]))?))?)?$');         // [11] tz_minute

function resolveYamlTimestamp(data) {
  if (null === data) {
    return false;
  }

  if (YAML_TIMESTAMP_REGEXP.exec(data) === null) {
    return false;
  }

  return true;
}

function constructYamlTimestamp(data) {
  var match, year, month, day, hour, minute, second, fraction = 0,
      delta = null, tz_hour, tz_minute, date;

  match = YAML_TIMESTAMP_REGEXP.exec(data);

  if (null === match) {
    throw new Error('Date resolve error');
  }

  // match: [1] year [2] month [3] day

  year = +(match[1]);
  month = +(match[2]) - 1; // JS month starts with 0
  day = +(match[3]);

  if (!match[4]) { // no hour
    return new Date(Date.UTC(year, month, day));
  }

  // match: [4] hour [5] minute [6] second [7] fraction

  hour = +(match[4]);
  minute = +(match[5]);
  second = +(match[6]);

  if (match[7]) {
    fraction = match[7].slice(0, 3);
    while (fraction.length < 3) { // milli-seconds
      fraction += '0';
    }
    fraction = +fraction;
  }

  // match: [8] tz [9] tz_sign [10] tz_hour [11] tz_minute

  if (match[9]) {
    tz_hour = +(match[10]);
    tz_minute = +(match[11] || 0);
    delta = (tz_hour * 60 + tz_minute) * 60000; // delta in mili-seconds
    if ('-' === match[9]) {
      delta = -delta;
    }
  }

  date = new Date(Date.UTC(year, month, day, hour, minute, second, fraction));

  if (delta) {
    date.setTime(date.getTime() - delta);
  }

  return date;
}

function representYamlTimestamp(object /*, style*/) {
  return object.toISOString();
}

module.exports = new Type('tag:yaml.org,2002:timestamp', {
  kind: 'scalar',
  resolve: resolveYamlTimestamp,
  construct: constructYamlTimestamp,
  instanceOf: Date,
  represent: representYamlTimestamp
});

},{"../type":34}],51:[function(require,module,exports){
/*
  Copyright (c) jQuery Foundation, Inc. and Contributors, All Rights Reserved.

  Redistribution and use in source and binary forms, with or without
  modification, are permitted provided that the following conditions are met:

    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
  AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
  ARE DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
  DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
  (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

(function (root, factory) {
    'use strict';

    // Universal Module Definition (UMD) to support AMD, CommonJS/Node.js,
    // Rhino, and plain browser loading.

    /* istanbul ignore next */
    if (typeof define === 'function' && define.amd) {
        define(['exports'], factory);
    } else if (typeof exports !== 'undefined') {
        factory(exports);
    } else {
        factory((root.esprima = {}));
    }
}(this, function (exports) {
    'use strict';

    var Token,
        TokenName,
        FnExprTokens,
        Syntax,
        PlaceHolders,
        Messages,
        Regex,
        source,
        strict,
        index,
        lineNumber,
        lineStart,
        hasLineTerminator,
        lastIndex,
        lastLineNumber,
        lastLineStart,
        startIndex,
        startLineNumber,
        startLineStart,
        scanning,
        length,
        lookahead,
        state,
        extra,
        isBindingElement,
        isAssignmentTarget,
        firstCoverInitializedNameError;

    Token = {
        BooleanLiteral: 1,
        EOF: 2,
        Identifier: 3,
        Keyword: 4,
        NullLiteral: 5,
        NumericLiteral: 6,
        Punctuator: 7,
        StringLiteral: 8,
        RegularExpression: 9,
        Template: 10
    };

    TokenName = {};
    TokenName[Token.BooleanLiteral] = 'Boolean';
    TokenName[Token.EOF] = '<end>';
    TokenName[Token.Identifier] = 'Identifier';
    TokenName[Token.Keyword] = 'Keyword';
    TokenName[Token.NullLiteral] = 'Null';
    TokenName[Token.NumericLiteral] = 'Numeric';
    TokenName[Token.Punctuator] = 'Punctuator';
    TokenName[Token.StringLiteral] = 'String';
    TokenName[Token.RegularExpression] = 'RegularExpression';
    TokenName[Token.Template] = 'Template';

    // A function following one of those tokens is an expression.
    FnExprTokens = ['(', '{', '[', 'in', 'typeof', 'instanceof', 'new',
                    'return', 'case', 'delete', 'throw', 'void',
                    // assignment operators
                    '=', '+=', '-=', '*=', '/=', '%=', '<<=', '>>=', '>>>=',
                    '&=', '|=', '^=', ',',
                    // binary/unary operators
                    '+', '-', '*', '/', '%', '++', '--', '<<', '>>', '>>>', '&',
                    '|', '^', '!', '~', '&&', '||', '?', ':', '===', '==', '>=',
                    '<=', '<', '>', '!=', '!=='];

    Syntax = {
        AssignmentExpression: 'AssignmentExpression',
        AssignmentPattern: 'AssignmentPattern',
        ArrayExpression: 'ArrayExpression',
        ArrayPattern: 'ArrayPattern',
        ArrowFunctionExpression: 'ArrowFunctionExpression',
        BlockStatement: 'BlockStatement',
        BinaryExpression: 'BinaryExpression',
        BreakStatement: 'BreakStatement',
        CallExpression: 'CallExpression',
        CatchClause: 'CatchClause',
        ClassBody: 'ClassBody',
        ClassDeclaration: 'ClassDeclaration',
        ClassExpression: 'ClassExpression',
        ConditionalExpression: 'ConditionalExpression',
        ContinueStatement: 'ContinueStatement',
        DoWhileStatement: 'DoWhileStatement',
        DebuggerStatement: 'DebuggerStatement',
        EmptyStatement: 'EmptyStatement',
        ExportAllDeclaration: 'ExportAllDeclaration',
        ExportDefaultDeclaration: 'ExportDefaultDeclaration',
        ExportNamedDeclaration: 'ExportNamedDeclaration',
        ExportSpecifier: 'ExportSpecifier',
        ExpressionStatement: 'ExpressionStatement',
        ForStatement: 'ForStatement',
        ForOfStatement: 'ForOfStatement',
        ForInStatement: 'ForInStatement',
        FunctionDeclaration: 'FunctionDeclaration',
        FunctionExpression: 'FunctionExpression',
        Identifier: 'Identifier',
        IfStatement: 'IfStatement',
        ImportDeclaration: 'ImportDeclaration',
        ImportDefaultSpecifier: 'ImportDefaultSpecifier',
        ImportNamespaceSpecifier: 'ImportNamespaceSpecifier',
        ImportSpecifier: 'ImportSpecifier',
        Literal: 'Literal',
        LabeledStatement: 'LabeledStatement',
        LogicalExpression: 'LogicalExpression',
        MemberExpression: 'MemberExpression',
        MetaProperty: 'MetaProperty',
        MethodDefinition: 'MethodDefinition',
        NewExpression: 'NewExpression',
        ObjectExpression: 'ObjectExpression',
        ObjectPattern: 'ObjectPattern',
        Program: 'Program',
        Property: 'Property',
        RestElement: 'RestElement',
        ReturnStatement: 'ReturnStatement',
        SequenceExpression: 'SequenceExpression',
        SpreadElement: 'SpreadElement',
        Super: 'Super',
        SwitchCase: 'SwitchCase',
        SwitchStatement: 'SwitchStatement',
        TaggedTemplateExpression: 'TaggedTemplateExpression',
        TemplateElement: 'TemplateElement',
        TemplateLiteral: 'TemplateLiteral',
        ThisExpression: 'ThisExpression',
        ThrowStatement: 'ThrowStatement',
        TryStatement: 'TryStatement',
        UnaryExpression: 'UnaryExpression',
        UpdateExpression: 'UpdateExpression',
        VariableDeclaration: 'VariableDeclaration',
        VariableDeclarator: 'VariableDeclarator',
        WhileStatement: 'WhileStatement',
        WithStatement: 'WithStatement',
        YieldExpression: 'YieldExpression'
    };

    PlaceHolders = {
        ArrowParameterPlaceHolder: 'ArrowParameterPlaceHolder'
    };

    // Error messages should be identical to V8.
    Messages = {
        UnexpectedToken: 'Unexpected token %0',
        UnexpectedNumber: 'Unexpected number',
        UnexpectedString: 'Unexpected string',
        UnexpectedIdentifier: 'Unexpected identifier',
        UnexpectedReserved: 'Unexpected reserved word',
        UnexpectedTemplate: 'Unexpected quasi %0',
        UnexpectedEOS: 'Unexpected end of input',
        NewlineAfterThrow: 'Illegal newline after throw',
        InvalidRegExp: 'Invalid regular expression',
        UnterminatedRegExp: 'Invalid regular expression: missing /',
        InvalidLHSInAssignment: 'Invalid left-hand side in assignment',
        InvalidLHSInForIn: 'Invalid left-hand side in for-in',
        InvalidLHSInForLoop: 'Invalid left-hand side in for-loop',
        MultipleDefaultsInSwitch: 'More than one default clause in switch statement',
        NoCatchOrFinally: 'Missing catch or finally after try',
        UnknownLabel: 'Undefined label \'%0\'',
        Redeclaration: '%0 \'%1\' has already been declared',
        IllegalContinue: 'Illegal continue statement',
        IllegalBreak: 'Illegal break statement',
        IllegalReturn: 'Illegal return statement',
        StrictModeWith: 'Strict mode code may not include a with statement',
        StrictCatchVariable: 'Catch variable may not be eval or arguments in strict mode',
        StrictVarName: 'Variable name may not be eval or arguments in strict mode',
        StrictParamName: 'Parameter name eval or arguments is not allowed in strict mode',
        StrictParamDupe: 'Strict mode function may not have duplicate parameter names',
        StrictFunctionName: 'Function name may not be eval or arguments in strict mode',
        StrictOctalLiteral: 'Octal literals are not allowed in strict mode.',
        StrictDelete: 'Delete of an unqualified identifier in strict mode.',
        StrictLHSAssignment: 'Assignment to eval or arguments is not allowed in strict mode',
        StrictLHSPostfix: 'Postfix increment/decrement may not have eval or arguments operand in strict mode',
        StrictLHSPrefix: 'Prefix increment/decrement may not have eval or arguments operand in strict mode',
        StrictReservedWord: 'Use of future reserved word in strict mode',
        TemplateOctalLiteral: 'Octal literals are not allowed in template strings.',
        ParameterAfterRestParameter: 'Rest parameter must be last formal parameter',
        DefaultRestParameter: 'Unexpected token =',
        ObjectPatternAsRestParameter: 'Unexpected token {',
        DuplicateProtoProperty: 'Duplicate __proto__ fields are not allowed in object literals',
        ConstructorSpecialMethod: 'Class constructor may not be an accessor',
        DuplicateConstructor: 'A class may only have one constructor',
        StaticPrototype: 'Classes may not have static property named prototype',
        MissingFromClause: 'Unexpected token',
        NoAsAfterImportNamespace: 'Unexpected token',
        InvalidModuleSpecifier: 'Unexpected token',
        IllegalImportDeclaration: 'Unexpected token',
        IllegalExportDeclaration: 'Unexpected token',
        DuplicateBinding: 'Duplicate binding %0'
    };

    // See also tools/generate-unicode-regex.js.
    Regex = {
        // ECMAScript 6/Unicode v7.0.0 NonAsciiIdentifierStart:
        NonAsciiIdentifierStart: /[\xAA\xB5\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0370-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386\u0388-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u05D0-\u05EA\u05F0-\u05F2\u0620-\u064A\u066E\u066F\u0671-\u06D3\u06D5\u06E5\u06E6\u06EE\u06EF\u06FA-\u06FC\u06FF\u0710\u0712-\u072F\u074D-\u07A5\u07B1\u07CA-\u07EA\u07F4\u07F5\u07FA\u0800-\u0815\u081A\u0824\u0828\u0840-\u0858\u08A0-\u08B2\u0904-\u0939\u093D\u0950\u0958-\u0961\u0971-\u0980\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BD\u09CE\u09DC\u09DD\u09DF-\u09E1\u09F0\u09F1\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A59-\u0A5C\u0A5E\u0A72-\u0A74\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABD\u0AD0\u0AE0\u0AE1\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3D\u0B5C\u0B5D\u0B5F-\u0B61\u0B71\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BD0\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D\u0C58\u0C59\u0C60\u0C61\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBD\u0CDE\u0CE0\u0CE1\u0CF1\u0CF2\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D\u0D4E\u0D60\u0D61\u0D7A-\u0D7F\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0E01-\u0E30\u0E32\u0E33\u0E40-\u0E46\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB0\u0EB2\u0EB3\u0EBD\u0EC0-\u0EC4\u0EC6\u0EDC-\u0EDF\u0F00\u0F40-\u0F47\u0F49-\u0F6C\u0F88-\u0F8C\u1000-\u102A\u103F\u1050-\u1055\u105A-\u105D\u1061\u1065\u1066\u106E-\u1070\u1075-\u1081\u108E\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u1380-\u138F\u13A0-\u13F4\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1711\u1720-\u1731\u1740-\u1751\u1760-\u176C\u176E-\u1770\u1780-\u17B3\u17D7\u17DC\u1820-\u1877\u1880-\u18A8\u18AA\u18B0-\u18F5\u1900-\u191E\u1950-\u196D\u1970-\u1974\u1980-\u19AB\u19C1-\u19C7\u1A00-\u1A16\u1A20-\u1A54\u1AA7\u1B05-\u1B33\u1B45-\u1B4B\u1B83-\u1BA0\u1BAE\u1BAF\u1BBA-\u1BE5\u1C00-\u1C23\u1C4D-\u1C4F\u1C5A-\u1C7D\u1CE9-\u1CEC\u1CEE-\u1CF1\u1CF5\u1CF6\u1D00-\u1DBF\u1E00-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u2071\u207F\u2090-\u209C\u2102\u2107\u210A-\u2113\u2115\u2118-\u211D\u2124\u2126\u2128\u212A-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CEE\u2CF2\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D80-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u3005-\u3007\u3021-\u3029\u3031-\u3035\u3038-\u303C\u3041-\u3096\u309B-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FCC\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA61F\uA62A\uA62B\uA640-\uA66E\uA67F-\uA69D\uA6A0-\uA6EF\uA717-\uA71F\uA722-\uA788\uA78B-\uA78E\uA790-\uA7AD\uA7B0\uA7B1\uA7F7-\uA801\uA803-\uA805\uA807-\uA80A\uA80C-\uA822\uA840-\uA873\uA882-\uA8B3\uA8F2-\uA8F7\uA8FB\uA90A-\uA925\uA930-\uA946\uA960-\uA97C\uA984-\uA9B2\uA9CF\uA9E0-\uA9E4\uA9E6-\uA9EF\uA9FA-\uA9FE\uAA00-\uAA28\uAA40-\uAA42\uAA44-\uAA4B\uAA60-\uAA76\uAA7A\uAA7E-\uAAAF\uAAB1\uAAB5\uAAB6\uAAB9-\uAABD\uAAC0\uAAC2\uAADB-\uAADD\uAAE0-\uAAEA\uAAF2-\uAAF4\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB5F\uAB64\uAB65\uABC0-\uABE2\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D\uFB1F-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE70-\uFE74\uFE76-\uFEFC\uFF21-\uFF3A\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDD40-\uDD74\uDE80-\uDE9C\uDEA0-\uDED0\uDF00-\uDF1F\uDF30-\uDF4A\uDF50-\uDF75\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF\uDFD1-\uDFD5]|\uD801[\uDC00-\uDC9D\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00\uDE10-\uDE13\uDE15-\uDE17\uDE19-\uDE33\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE4\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48]|\uD804[\uDC03-\uDC37\uDC83-\uDCAF\uDCD0-\uDCE8\uDD03-\uDD26\uDD50-\uDD72\uDD76\uDD83-\uDDB2\uDDC1-\uDDC4\uDDDA\uDE00-\uDE11\uDE13-\uDE2B\uDEB0-\uDEDE\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3D\uDF5D-\uDF61]|\uD805[\uDC80-\uDCAF\uDCC4\uDCC5\uDCC7\uDD80-\uDDAE\uDE00-\uDE2F\uDE44\uDE80-\uDEAA]|\uD806[\uDCA0-\uDCDF\uDCFF\uDEC0-\uDEF8]|\uD808[\uDC00-\uDF98]|\uD809[\uDC00-\uDC6E]|[\uD80C\uD840-\uD868\uD86A-\uD86C][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDED0-\uDEED\uDF00-\uDF2F\uDF40-\uDF43\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDF00-\uDF44\uDF50\uDF93-\uDF9F]|\uD82C[\uDC00\uDC01]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB]|\uD83A[\uDC00-\uDCC4]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D]|\uD87E[\uDC00-\uDE1D]/,

        // ECMAScript 6/Unicode v7.0.0 NonAsciiIdentifierPart:
        NonAsciiIdentifierPart: /[\xAA\xB5\xB7\xBA\xC0-\xD6\xD8-\xF6\xF8-\u02C1\u02C6-\u02D1\u02E0-\u02E4\u02EC\u02EE\u0300-\u0374\u0376\u0377\u037A-\u037D\u037F\u0386-\u038A\u038C\u038E-\u03A1\u03A3-\u03F5\u03F7-\u0481\u0483-\u0487\u048A-\u052F\u0531-\u0556\u0559\u0561-\u0587\u0591-\u05BD\u05BF\u05C1\u05C2\u05C4\u05C5\u05C7\u05D0-\u05EA\u05F0-\u05F2\u0610-\u061A\u0620-\u0669\u066E-\u06D3\u06D5-\u06DC\u06DF-\u06E8\u06EA-\u06FC\u06FF\u0710-\u074A\u074D-\u07B1\u07C0-\u07F5\u07FA\u0800-\u082D\u0840-\u085B\u08A0-\u08B2\u08E4-\u0963\u0966-\u096F\u0971-\u0983\u0985-\u098C\u098F\u0990\u0993-\u09A8\u09AA-\u09B0\u09B2\u09B6-\u09B9\u09BC-\u09C4\u09C7\u09C8\u09CB-\u09CE\u09D7\u09DC\u09DD\u09DF-\u09E3\u09E6-\u09F1\u0A01-\u0A03\u0A05-\u0A0A\u0A0F\u0A10\u0A13-\u0A28\u0A2A-\u0A30\u0A32\u0A33\u0A35\u0A36\u0A38\u0A39\u0A3C\u0A3E-\u0A42\u0A47\u0A48\u0A4B-\u0A4D\u0A51\u0A59-\u0A5C\u0A5E\u0A66-\u0A75\u0A81-\u0A83\u0A85-\u0A8D\u0A8F-\u0A91\u0A93-\u0AA8\u0AAA-\u0AB0\u0AB2\u0AB3\u0AB5-\u0AB9\u0ABC-\u0AC5\u0AC7-\u0AC9\u0ACB-\u0ACD\u0AD0\u0AE0-\u0AE3\u0AE6-\u0AEF\u0B01-\u0B03\u0B05-\u0B0C\u0B0F\u0B10\u0B13-\u0B28\u0B2A-\u0B30\u0B32\u0B33\u0B35-\u0B39\u0B3C-\u0B44\u0B47\u0B48\u0B4B-\u0B4D\u0B56\u0B57\u0B5C\u0B5D\u0B5F-\u0B63\u0B66-\u0B6F\u0B71\u0B82\u0B83\u0B85-\u0B8A\u0B8E-\u0B90\u0B92-\u0B95\u0B99\u0B9A\u0B9C\u0B9E\u0B9F\u0BA3\u0BA4\u0BA8-\u0BAA\u0BAE-\u0BB9\u0BBE-\u0BC2\u0BC6-\u0BC8\u0BCA-\u0BCD\u0BD0\u0BD7\u0BE6-\u0BEF\u0C00-\u0C03\u0C05-\u0C0C\u0C0E-\u0C10\u0C12-\u0C28\u0C2A-\u0C39\u0C3D-\u0C44\u0C46-\u0C48\u0C4A-\u0C4D\u0C55\u0C56\u0C58\u0C59\u0C60-\u0C63\u0C66-\u0C6F\u0C81-\u0C83\u0C85-\u0C8C\u0C8E-\u0C90\u0C92-\u0CA8\u0CAA-\u0CB3\u0CB5-\u0CB9\u0CBC-\u0CC4\u0CC6-\u0CC8\u0CCA-\u0CCD\u0CD5\u0CD6\u0CDE\u0CE0-\u0CE3\u0CE6-\u0CEF\u0CF1\u0CF2\u0D01-\u0D03\u0D05-\u0D0C\u0D0E-\u0D10\u0D12-\u0D3A\u0D3D-\u0D44\u0D46-\u0D48\u0D4A-\u0D4E\u0D57\u0D60-\u0D63\u0D66-\u0D6F\u0D7A-\u0D7F\u0D82\u0D83\u0D85-\u0D96\u0D9A-\u0DB1\u0DB3-\u0DBB\u0DBD\u0DC0-\u0DC6\u0DCA\u0DCF-\u0DD4\u0DD6\u0DD8-\u0DDF\u0DE6-\u0DEF\u0DF2\u0DF3\u0E01-\u0E3A\u0E40-\u0E4E\u0E50-\u0E59\u0E81\u0E82\u0E84\u0E87\u0E88\u0E8A\u0E8D\u0E94-\u0E97\u0E99-\u0E9F\u0EA1-\u0EA3\u0EA5\u0EA7\u0EAA\u0EAB\u0EAD-\u0EB9\u0EBB-\u0EBD\u0EC0-\u0EC4\u0EC6\u0EC8-\u0ECD\u0ED0-\u0ED9\u0EDC-\u0EDF\u0F00\u0F18\u0F19\u0F20-\u0F29\u0F35\u0F37\u0F39\u0F3E-\u0F47\u0F49-\u0F6C\u0F71-\u0F84\u0F86-\u0F97\u0F99-\u0FBC\u0FC6\u1000-\u1049\u1050-\u109D\u10A0-\u10C5\u10C7\u10CD\u10D0-\u10FA\u10FC-\u1248\u124A-\u124D\u1250-\u1256\u1258\u125A-\u125D\u1260-\u1288\u128A-\u128D\u1290-\u12B0\u12B2-\u12B5\u12B8-\u12BE\u12C0\u12C2-\u12C5\u12C8-\u12D6\u12D8-\u1310\u1312-\u1315\u1318-\u135A\u135D-\u135F\u1369-\u1371\u1380-\u138F\u13A0-\u13F4\u1401-\u166C\u166F-\u167F\u1681-\u169A\u16A0-\u16EA\u16EE-\u16F8\u1700-\u170C\u170E-\u1714\u1720-\u1734\u1740-\u1753\u1760-\u176C\u176E-\u1770\u1772\u1773\u1780-\u17D3\u17D7\u17DC\u17DD\u17E0-\u17E9\u180B-\u180D\u1810-\u1819\u1820-\u1877\u1880-\u18AA\u18B0-\u18F5\u1900-\u191E\u1920-\u192B\u1930-\u193B\u1946-\u196D\u1970-\u1974\u1980-\u19AB\u19B0-\u19C9\u19D0-\u19DA\u1A00-\u1A1B\u1A20-\u1A5E\u1A60-\u1A7C\u1A7F-\u1A89\u1A90-\u1A99\u1AA7\u1AB0-\u1ABD\u1B00-\u1B4B\u1B50-\u1B59\u1B6B-\u1B73\u1B80-\u1BF3\u1C00-\u1C37\u1C40-\u1C49\u1C4D-\u1C7D\u1CD0-\u1CD2\u1CD4-\u1CF6\u1CF8\u1CF9\u1D00-\u1DF5\u1DFC-\u1F15\u1F18-\u1F1D\u1F20-\u1F45\u1F48-\u1F4D\u1F50-\u1F57\u1F59\u1F5B\u1F5D\u1F5F-\u1F7D\u1F80-\u1FB4\u1FB6-\u1FBC\u1FBE\u1FC2-\u1FC4\u1FC6-\u1FCC\u1FD0-\u1FD3\u1FD6-\u1FDB\u1FE0-\u1FEC\u1FF2-\u1FF4\u1FF6-\u1FFC\u200C\u200D\u203F\u2040\u2054\u2071\u207F\u2090-\u209C\u20D0-\u20DC\u20E1\u20E5-\u20F0\u2102\u2107\u210A-\u2113\u2115\u2118-\u211D\u2124\u2126\u2128\u212A-\u2139\u213C-\u213F\u2145-\u2149\u214E\u2160-\u2188\u2C00-\u2C2E\u2C30-\u2C5E\u2C60-\u2CE4\u2CEB-\u2CF3\u2D00-\u2D25\u2D27\u2D2D\u2D30-\u2D67\u2D6F\u2D7F-\u2D96\u2DA0-\u2DA6\u2DA8-\u2DAE\u2DB0-\u2DB6\u2DB8-\u2DBE\u2DC0-\u2DC6\u2DC8-\u2DCE\u2DD0-\u2DD6\u2DD8-\u2DDE\u2DE0-\u2DFF\u3005-\u3007\u3021-\u302F\u3031-\u3035\u3038-\u303C\u3041-\u3096\u3099-\u309F\u30A1-\u30FA\u30FC-\u30FF\u3105-\u312D\u3131-\u318E\u31A0-\u31BA\u31F0-\u31FF\u3400-\u4DB5\u4E00-\u9FCC\uA000-\uA48C\uA4D0-\uA4FD\uA500-\uA60C\uA610-\uA62B\uA640-\uA66F\uA674-\uA67D\uA67F-\uA69D\uA69F-\uA6F1\uA717-\uA71F\uA722-\uA788\uA78B-\uA78E\uA790-\uA7AD\uA7B0\uA7B1\uA7F7-\uA827\uA840-\uA873\uA880-\uA8C4\uA8D0-\uA8D9\uA8E0-\uA8F7\uA8FB\uA900-\uA92D\uA930-\uA953\uA960-\uA97C\uA980-\uA9C0\uA9CF-\uA9D9\uA9E0-\uA9FE\uAA00-\uAA36\uAA40-\uAA4D\uAA50-\uAA59\uAA60-\uAA76\uAA7A-\uAAC2\uAADB-\uAADD\uAAE0-\uAAEF\uAAF2-\uAAF6\uAB01-\uAB06\uAB09-\uAB0E\uAB11-\uAB16\uAB20-\uAB26\uAB28-\uAB2E\uAB30-\uAB5A\uAB5C-\uAB5F\uAB64\uAB65\uABC0-\uABEA\uABEC\uABED\uABF0-\uABF9\uAC00-\uD7A3\uD7B0-\uD7C6\uD7CB-\uD7FB\uF900-\uFA6D\uFA70-\uFAD9\uFB00-\uFB06\uFB13-\uFB17\uFB1D-\uFB28\uFB2A-\uFB36\uFB38-\uFB3C\uFB3E\uFB40\uFB41\uFB43\uFB44\uFB46-\uFBB1\uFBD3-\uFD3D\uFD50-\uFD8F\uFD92-\uFDC7\uFDF0-\uFDFB\uFE00-\uFE0F\uFE20-\uFE2D\uFE33\uFE34\uFE4D-\uFE4F\uFE70-\uFE74\uFE76-\uFEFC\uFF10-\uFF19\uFF21-\uFF3A\uFF3F\uFF41-\uFF5A\uFF66-\uFFBE\uFFC2-\uFFC7\uFFCA-\uFFCF\uFFD2-\uFFD7\uFFDA-\uFFDC]|\uD800[\uDC00-\uDC0B\uDC0D-\uDC26\uDC28-\uDC3A\uDC3C\uDC3D\uDC3F-\uDC4D\uDC50-\uDC5D\uDC80-\uDCFA\uDD40-\uDD74\uDDFD\uDE80-\uDE9C\uDEA0-\uDED0\uDEE0\uDF00-\uDF1F\uDF30-\uDF4A\uDF50-\uDF7A\uDF80-\uDF9D\uDFA0-\uDFC3\uDFC8-\uDFCF\uDFD1-\uDFD5]|\uD801[\uDC00-\uDC9D\uDCA0-\uDCA9\uDD00-\uDD27\uDD30-\uDD63\uDE00-\uDF36\uDF40-\uDF55\uDF60-\uDF67]|\uD802[\uDC00-\uDC05\uDC08\uDC0A-\uDC35\uDC37\uDC38\uDC3C\uDC3F-\uDC55\uDC60-\uDC76\uDC80-\uDC9E\uDD00-\uDD15\uDD20-\uDD39\uDD80-\uDDB7\uDDBE\uDDBF\uDE00-\uDE03\uDE05\uDE06\uDE0C-\uDE13\uDE15-\uDE17\uDE19-\uDE33\uDE38-\uDE3A\uDE3F\uDE60-\uDE7C\uDE80-\uDE9C\uDEC0-\uDEC7\uDEC9-\uDEE6\uDF00-\uDF35\uDF40-\uDF55\uDF60-\uDF72\uDF80-\uDF91]|\uD803[\uDC00-\uDC48]|\uD804[\uDC00-\uDC46\uDC66-\uDC6F\uDC7F-\uDCBA\uDCD0-\uDCE8\uDCF0-\uDCF9\uDD00-\uDD34\uDD36-\uDD3F\uDD50-\uDD73\uDD76\uDD80-\uDDC4\uDDD0-\uDDDA\uDE00-\uDE11\uDE13-\uDE37\uDEB0-\uDEEA\uDEF0-\uDEF9\uDF01-\uDF03\uDF05-\uDF0C\uDF0F\uDF10\uDF13-\uDF28\uDF2A-\uDF30\uDF32\uDF33\uDF35-\uDF39\uDF3C-\uDF44\uDF47\uDF48\uDF4B-\uDF4D\uDF57\uDF5D-\uDF63\uDF66-\uDF6C\uDF70-\uDF74]|\uD805[\uDC80-\uDCC5\uDCC7\uDCD0-\uDCD9\uDD80-\uDDB5\uDDB8-\uDDC0\uDE00-\uDE40\uDE44\uDE50-\uDE59\uDE80-\uDEB7\uDEC0-\uDEC9]|\uD806[\uDCA0-\uDCE9\uDCFF\uDEC0-\uDEF8]|\uD808[\uDC00-\uDF98]|\uD809[\uDC00-\uDC6E]|[\uD80C\uD840-\uD868\uD86A-\uD86C][\uDC00-\uDFFF]|\uD80D[\uDC00-\uDC2E]|\uD81A[\uDC00-\uDE38\uDE40-\uDE5E\uDE60-\uDE69\uDED0-\uDEED\uDEF0-\uDEF4\uDF00-\uDF36\uDF40-\uDF43\uDF50-\uDF59\uDF63-\uDF77\uDF7D-\uDF8F]|\uD81B[\uDF00-\uDF44\uDF50-\uDF7E\uDF8F-\uDF9F]|\uD82C[\uDC00\uDC01]|\uD82F[\uDC00-\uDC6A\uDC70-\uDC7C\uDC80-\uDC88\uDC90-\uDC99\uDC9D\uDC9E]|\uD834[\uDD65-\uDD69\uDD6D-\uDD72\uDD7B-\uDD82\uDD85-\uDD8B\uDDAA-\uDDAD\uDE42-\uDE44]|\uD835[\uDC00-\uDC54\uDC56-\uDC9C\uDC9E\uDC9F\uDCA2\uDCA5\uDCA6\uDCA9-\uDCAC\uDCAE-\uDCB9\uDCBB\uDCBD-\uDCC3\uDCC5-\uDD05\uDD07-\uDD0A\uDD0D-\uDD14\uDD16-\uDD1C\uDD1E-\uDD39\uDD3B-\uDD3E\uDD40-\uDD44\uDD46\uDD4A-\uDD50\uDD52-\uDEA5\uDEA8-\uDEC0\uDEC2-\uDEDA\uDEDC-\uDEFA\uDEFC-\uDF14\uDF16-\uDF34\uDF36-\uDF4E\uDF50-\uDF6E\uDF70-\uDF88\uDF8A-\uDFA8\uDFAA-\uDFC2\uDFC4-\uDFCB\uDFCE-\uDFFF]|\uD83A[\uDC00-\uDCC4\uDCD0-\uDCD6]|\uD83B[\uDE00-\uDE03\uDE05-\uDE1F\uDE21\uDE22\uDE24\uDE27\uDE29-\uDE32\uDE34-\uDE37\uDE39\uDE3B\uDE42\uDE47\uDE49\uDE4B\uDE4D-\uDE4F\uDE51\uDE52\uDE54\uDE57\uDE59\uDE5B\uDE5D\uDE5F\uDE61\uDE62\uDE64\uDE67-\uDE6A\uDE6C-\uDE72\uDE74-\uDE77\uDE79-\uDE7C\uDE7E\uDE80-\uDE89\uDE8B-\uDE9B\uDEA1-\uDEA3\uDEA5-\uDEA9\uDEAB-\uDEBB]|\uD869[\uDC00-\uDED6\uDF00-\uDFFF]|\uD86D[\uDC00-\uDF34\uDF40-\uDFFF]|\uD86E[\uDC00-\uDC1D]|\uD87E[\uDC00-\uDE1D]|\uDB40[\uDD00-\uDDEF]/
    };

    // Ensure the condition is true, otherwise throw an error.
    // This is only to have a better contract semantic, i.e. another safety net
    // to catch a logic error. The condition shall be fulfilled in normal case.
    // Do NOT use this to enforce a certain condition on any user input.

    function assert(condition, message) {
        /* istanbul ignore if */
        if (!condition) {
            throw new Error('ASSERT: ' + message);
        }
    }

    function isDecimalDigit(ch) {
        return (ch >= 0x30 && ch <= 0x39);   // 0..9
    }

    function isHexDigit(ch) {
        return '0123456789abcdefABCDEF'.indexOf(ch) >= 0;
    }

    function isOctalDigit(ch) {
        return '01234567'.indexOf(ch) >= 0;
    }

    function octalToDecimal(ch) {
        // \0 is not octal escape sequence
        var octal = (ch !== '0'), code = '01234567'.indexOf(ch);

        if (index < length && isOctalDigit(source[index])) {
            octal = true;
            code = code * 8 + '01234567'.indexOf(source[index++]);

            // 3 digits are only allowed when string starts
            // with 0, 1, 2, 3
            if ('0123'.indexOf(ch) >= 0 &&
                    index < length &&
                    isOctalDigit(source[index])) {
                code = code * 8 + '01234567'.indexOf(source[index++]);
            }
        }

        return {
            code: code,
            octal: octal
        };
    }

    // ECMA-262 11.2 White Space

    function isWhiteSpace(ch) {
        return (ch === 0x20) || (ch === 0x09) || (ch === 0x0B) || (ch === 0x0C) || (ch === 0xA0) ||
            (ch >= 0x1680 && [0x1680, 0x180E, 0x2000, 0x2001, 0x2002, 0x2003, 0x2004, 0x2005, 0x2006, 0x2007, 0x2008, 0x2009, 0x200A, 0x202F, 0x205F, 0x3000, 0xFEFF].indexOf(ch) >= 0);
    }

    // ECMA-262 11.3 Line Terminators

    function isLineTerminator(ch) {
        return (ch === 0x0A) || (ch === 0x0D) || (ch === 0x2028) || (ch === 0x2029);
    }

    // ECMA-262 11.6 Identifier Names and Identifiers

    function fromCodePoint(cp) {
        return (cp < 0x10000) ? String.fromCharCode(cp) :
            String.fromCharCode(0xD800 + ((cp - 0x10000) >> 10)) +
            String.fromCharCode(0xDC00 + ((cp - 0x10000) & 1023));
    }

    function isIdentifierStart(ch) {
        return (ch === 0x24) || (ch === 0x5F) ||  // $ (dollar) and _ (underscore)
            (ch >= 0x41 && ch <= 0x5A) ||         // A..Z
            (ch >= 0x61 && ch <= 0x7A) ||         // a..z
            (ch === 0x5C) ||                      // \ (backslash)
            ((ch >= 0x80) && Regex.NonAsciiIdentifierStart.test(fromCodePoint(ch)));
    }

    function isIdentifierPart(ch) {
        return (ch === 0x24) || (ch === 0x5F) ||  // $ (dollar) and _ (underscore)
            (ch >= 0x41 && ch <= 0x5A) ||         // A..Z
            (ch >= 0x61 && ch <= 0x7A) ||         // a..z
            (ch >= 0x30 && ch <= 0x39) ||         // 0..9
            (ch === 0x5C) ||                      // \ (backslash)
            ((ch >= 0x80) && Regex.NonAsciiIdentifierPart.test(fromCodePoint(ch)));
    }

    // ECMA-262 11.6.2.2 Future Reserved Words

    function isFutureReservedWord(id) {
        switch (id) {
        case 'enum':
        case 'export':
        case 'import':
        case 'super':
            return true;
        default:
            return false;
        }
    }

    function isStrictModeReservedWord(id) {
        switch (id) {
        case 'implements':
        case 'interface':
        case 'package':
        case 'private':
        case 'protected':
        case 'public':
        case 'static':
        case 'yield':
        case 'let':
            return true;
        default:
            return false;
        }
    }

    function isRestrictedWord(id) {
        return id === 'eval' || id === 'arguments';
    }

    // ECMA-262 11.6.2.1 Keywords

    function isKeyword(id) {
        switch (id.length) {
        case 2:
            return (id === 'if') || (id === 'in') || (id === 'do');
        case 3:
            return (id === 'var') || (id === 'for') || (id === 'new') ||
                (id === 'try') || (id === 'let');
        case 4:
            return (id === 'this') || (id === 'else') || (id === 'case') ||
                (id === 'void') || (id === 'with') || (id === 'enum');
        case 5:
            return (id === 'while') || (id === 'break') || (id === 'catch') ||
                (id === 'throw') || (id === 'const') || (id === 'yield') ||
                (id === 'class') || (id === 'super');
        case 6:
            return (id === 'return') || (id === 'typeof') || (id === 'delete') ||
                (id === 'switch') || (id === 'export') || (id === 'import');
        case 7:
            return (id === 'default') || (id === 'finally') || (id === 'extends');
        case 8:
            return (id === 'function') || (id === 'continue') || (id === 'debugger');
        case 10:
            return (id === 'instanceof');
        default:
            return false;
        }
    }

    // ECMA-262 11.4 Comments

    function addComment(type, value, start, end, loc) {
        var comment;

        assert(typeof start === 'number', 'Comment must have valid position');

        state.lastCommentStart = start;

        comment = {
            type: type,
            value: value
        };
        if (extra.range) {
            comment.range = [start, end];
        }
        if (extra.loc) {
            comment.loc = loc;
        }
        extra.comments.push(comment);
        if (extra.attachComment) {
            extra.leadingComments.push(comment);
            extra.trailingComments.push(comment);
        }
        if (extra.tokenize) {
            comment.type = comment.type + 'Comment';
            if (extra.delegate) {
                comment = extra.delegate(comment);
            }
            extra.tokens.push(comment);
        }
    }

    function skipSingleLineComment(offset) {
        var start, loc, ch, comment;

        start = index - offset;
        loc = {
            start: {
                line: lineNumber,
                column: index - lineStart - offset
            }
        };

        while (index < length) {
            ch = source.charCodeAt(index);
            ++index;
            if (isLineTerminator(ch)) {
                hasLineTerminator = true;
                if (extra.comments) {
                    comment = source.slice(start + offset, index - 1);
                    loc.end = {
                        line: lineNumber,
                        column: index - lineStart - 1
                    };
                    addComment('Line', comment, start, index - 1, loc);
                }
                if (ch === 13 && source.charCodeAt(index) === 10) {
                    ++index;
                }
                ++lineNumber;
                lineStart = index;
                return;
            }
        }

        if (extra.comments) {
            comment = source.slice(start + offset, index);
            loc.end = {
                line: lineNumber,
                column: index - lineStart
            };
            addComment('Line', comment, start, index, loc);
        }
    }

    function skipMultiLineComment() {
        var start, loc, ch, comment;

        if (extra.comments) {
            start = index - 2;
            loc = {
                start: {
                    line: lineNumber,
                    column: index - lineStart - 2
                }
            };
        }

        while (index < length) {
            ch = source.charCodeAt(index);
            if (isLineTerminator(ch)) {
                if (ch === 0x0D && source.charCodeAt(index + 1) === 0x0A) {
                    ++index;
                }
                hasLineTerminator = true;
                ++lineNumber;
                ++index;
                lineStart = index;
            } else if (ch === 0x2A) {
                // Block comment ends with '*/'.
                if (source.charCodeAt(index + 1) === 0x2F) {
                    ++index;
                    ++index;
                    if (extra.comments) {
                        comment = source.slice(start + 2, index - 2);
                        loc.end = {
                            line: lineNumber,
                            column: index - lineStart
                        };
                        addComment('Block', comment, start, index, loc);
                    }
                    return;
                }
                ++index;
            } else {
                ++index;
            }
        }

        // Ran off the end of the file - the whole thing is a comment
        if (extra.comments) {
            loc.end = {
                line: lineNumber,
                column: index - lineStart
            };
            comment = source.slice(start + 2, index);
            addComment('Block', comment, start, index, loc);
        }
        tolerateUnexpectedToken();
    }

    function skipComment() {
        var ch, start;
        hasLineTerminator = false;

        start = (index === 0);
        while (index < length) {
            ch = source.charCodeAt(index);

            if (isWhiteSpace(ch)) {
                ++index;
            } else if (isLineTerminator(ch)) {
                hasLineTerminator = true;
                ++index;
                if (ch === 0x0D && source.charCodeAt(index) === 0x0A) {
                    ++index;
                }
                ++lineNumber;
                lineStart = index;
                start = true;
            } else if (ch === 0x2F) { // U+002F is '/'
                ch = source.charCodeAt(index + 1);
                if (ch === 0x2F) {
                    ++index;
                    ++index;
                    skipSingleLineComment(2);
                    start = true;
                } else if (ch === 0x2A) {  // U+002A is '*'
                    ++index;
                    ++index;
                    skipMultiLineComment();
                } else {
                    break;
                }
            } else if (start && ch === 0x2D) { // U+002D is '-'
                // U+003E is '>'
                if ((source.charCodeAt(index + 1) === 0x2D) && (source.charCodeAt(index + 2) === 0x3E)) {
                    // '-->' is a single-line comment
                    index += 3;
                    skipSingleLineComment(3);
                } else {
                    break;
                }
            } else if (ch === 0x3C) { // U+003C is '<'
                if (source.slice(index + 1, index + 4) === '!--') {
                    ++index; // `<`
                    ++index; // `!`
                    ++index; // `-`
                    ++index; // `-`
                    skipSingleLineComment(4);
                } else {
                    break;
                }
            } else {
                break;
            }
        }
    }

    function scanHexEscape(prefix) {
        var i, len, ch, code = 0;

        len = (prefix === 'u') ? 4 : 2;
        for (i = 0; i < len; ++i) {
            if (index < length && isHexDigit(source[index])) {
                ch = source[index++];
                code = code * 16 + '0123456789abcdef'.indexOf(ch.toLowerCase());
            } else {
                return '';
            }
        }
        return String.fromCharCode(code);
    }

    function scanUnicodeCodePointEscape() {
        var ch, code;

        ch = source[index];
        code = 0;

        // At least, one hex digit is required.
        if (ch === '}') {
            throwUnexpectedToken();
        }

        while (index < length) {
            ch = source[index++];
            if (!isHexDigit(ch)) {
                break;
            }
            code = code * 16 + '0123456789abcdef'.indexOf(ch.toLowerCase());
        }

        if (code > 0x10FFFF || ch !== '}') {
            throwUnexpectedToken();
        }

        return fromCodePoint(code);
    }

    function codePointAt(i) {
        var cp, first, second;

        cp = source.charCodeAt(i);
        if (cp >= 0xD800 && cp <= 0xDBFF) {
            second = source.charCodeAt(i + 1);
            if (second >= 0xDC00 && second <= 0xDFFF) {
                first = cp;
                cp = (first - 0xD800) * 0x400 + second - 0xDC00 + 0x10000;
            }
        }

        return cp;
    }

    function getComplexIdentifier() {
        var cp, ch, id;

        cp = codePointAt(index);
        id = fromCodePoint(cp);
        index += id.length;

        // '\u' (U+005C, U+0075) denotes an escaped character.
        if (cp === 0x5C) {
            if (source.charCodeAt(index) !== 0x75) {
                throwUnexpectedToken();
            }
            ++index;
            if (source[index] === '{') {
                ++index;
                ch = scanUnicodeCodePointEscape();
            } else {
                ch = scanHexEscape('u');
                cp = ch.charCodeAt(0);
                if (!ch || ch === '\\' || !isIdentifierStart(cp)) {
                    throwUnexpectedToken();
                }
            }
            id = ch;
        }

        while (index < length) {
            cp = codePointAt(index);
            if (!isIdentifierPart(cp)) {
                break;
            }
            ch = fromCodePoint(cp);
            id += ch;
            index += ch.length;

            // '\u' (U+005C, U+0075) denotes an escaped character.
            if (cp === 0x5C) {
                id = id.substr(0, id.length - 1);
                if (source.charCodeAt(index) !== 0x75) {
                    throwUnexpectedToken();
                }
                ++index;
                if (source[index] === '{') {
                    ++index;
                    ch = scanUnicodeCodePointEscape();
                } else {
                    ch = scanHexEscape('u');
                    cp = ch.charCodeAt(0);
                    if (!ch || ch === '\\' || !isIdentifierPart(cp)) {
                        throwUnexpectedToken();
                    }
                }
                id += ch;
            }
        }

        return id;
    }

    function getIdentifier() {
        var start, ch;

        start = index++;
        while (index < length) {
            ch = source.charCodeAt(index);
            if (ch === 0x5C) {
                // Blackslash (U+005C) marks Unicode escape sequence.
                index = start;
                return getComplexIdentifier();
            } else if (ch >= 0xD800 && ch < 0xDFFF) {
                // Need to handle surrogate pairs.
                index = start;
                return getComplexIdentifier();
            }
            if (isIdentifierPart(ch)) {
                ++index;
            } else {
                break;
            }
        }

        return source.slice(start, index);
    }

    function scanIdentifier() {
        var start, id, type;

        start = index;

        // Backslash (U+005C) starts an escaped character.
        id = (source.charCodeAt(index) === 0x5C) ? getComplexIdentifier() : getIdentifier();

        // There is no keyword or literal with only one character.
        // Thus, it must be an identifier.
        if (id.length === 1) {
            type = Token.Identifier;
        } else if (isKeyword(id)) {
            type = Token.Keyword;
        } else if (id === 'null') {
            type = Token.NullLiteral;
        } else if (id === 'true' || id === 'false') {
            type = Token.BooleanLiteral;
        } else {
            type = Token.Identifier;
        }

        return {
            type: type,
            value: id,
            lineNumber: lineNumber,
            lineStart: lineStart,
            start: start,
            end: index
        };
    }


    // ECMA-262 11.7 Punctuators

    function scanPunctuator() {
        var token, str;

        token = {
            type: Token.Punctuator,
            value: '',
            lineNumber: lineNumber,
            lineStart: lineStart,
            start: index,
            end: index
        };

        // Check for most common single-character punctuators.
        str = source[index];
        switch (str) {

        case '(':
            if (extra.tokenize) {
                extra.openParenToken = extra.tokenValues.length;
            }
            ++index;
            break;

        case '{':
            if (extra.tokenize) {
                extra.openCurlyToken = extra.tokenValues.length;
            }
            state.curlyStack.push('{');
            ++index;
            break;

        case '.':
            ++index;
            if (source[index] === '.' && source[index + 1] === '.') {
                // Spread operator: ...
                index += 2;
                str = '...';
            }
            break;

        case '}':
            ++index;
            state.curlyStack.pop();
            break;
        case ')':
        case ';':
        case ',':
        case '[':
        case ']':
        case ':':
        case '?':
        case '~':
            ++index;
            break;

        default:
            // 4-character punctuator.
            str = source.substr(index, 4);
            if (str === '>>>=') {
                index += 4;
            } else {

                // 3-character punctuators.
                str = str.substr(0, 3);
                if (str === '===' || str === '!==' || str === '>>>' ||
                    str === '<<=' || str === '>>=') {
                    index += 3;
                } else {

                    // 2-character punctuators.
                    str = str.substr(0, 2);
                    if (str === '&&' || str === '||' || str === '==' || str === '!=' ||
                        str === '+=' || str === '-=' || str === '*=' || str === '/=' ||
                        str === '++' || str === '--' || str === '<<' || str === '>>' ||
                        str === '&=' || str === '|=' || str === '^=' || str === '%=' ||
                        str === '<=' || str === '>=' || str === '=>') {
                        index += 2;
                    } else {

                        // 1-character punctuators.
                        str = source[index];
                        if ('<>=!+-*%&|^/'.indexOf(str) >= 0) {
                            ++index;
                        }
                    }
                }
            }
        }

        if (index === token.start) {
            throwUnexpectedToken();
        }

        token.end = index;
        token.value = str;
        return token;
    }

    // ECMA-262 11.8.3 Numeric Literals

    function scanHexLiteral(start) {
        var number = '';

        while (index < length) {
            if (!isHexDigit(source[index])) {
                break;
            }
            number += source[index++];
        }

        if (number.length === 0) {
            throwUnexpectedToken();
        }

        if (isIdentifierStart(source.charCodeAt(index))) {
            throwUnexpectedToken();
        }

        return {
            type: Token.NumericLiteral,
            value: parseInt('0x' + number, 16),
            lineNumber: lineNumber,
            lineStart: lineStart,
            start: start,
            end: index
        };
    }

    function scanBinaryLiteral(start) {
        var ch, number;

        number = '';

        while (index < length) {
            ch = source[index];
            if (ch !== '0' && ch !== '1') {
                break;
            }
            number += source[index++];
        }

        if (number.length === 0) {
            // only 0b or 0B
            throwUnexpectedToken();
        }

        if (index < length) {
            ch = source.charCodeAt(index);
            /* istanbul ignore else */
            if (isIdentifierStart(ch) || isDecimalDigit(ch)) {
                throwUnexpectedToken();
            }
        }

        return {
            type: Token.NumericLiteral,
            value: parseInt(number, 2),
            lineNumber: lineNumber,
            lineStart: lineStart,
            start: start,
            end: index
        };
    }

    function scanOctalLiteral(prefix, start) {
        var number, octal;

        if (isOctalDigit(prefix)) {
            octal = true;
            number = '0' + source[index++];
        } else {
            octal = false;
            ++index;
            number = '';
        }

        while (index < length) {
            if (!isOctalDigit(source[index])) {
                break;
            }
            number += source[index++];
        }

        if (!octal && number.length === 0) {
            // only 0o or 0O
            throwUnexpectedToken();
        }

        if (isIdentifierStart(source.charCodeAt(index)) || isDecimalDigit(source.charCodeAt(index))) {
            throwUnexpectedToken();
        }

        return {
            type: Token.NumericLiteral,
            value: parseInt(number, 8),
            octal: octal,
            lineNumber: lineNumber,
            lineStart: lineStart,
            start: start,
            end: index
        };
    }

    function isImplicitOctalLiteral() {
        var i, ch;

        // Implicit octal, unless there is a non-octal digit.
        // (Annex B.1.1 on Numeric Literals)
        for (i = index + 1; i < length; ++i) {
            ch = source[i];
            if (ch === '8' || ch === '9') {
                return false;
            }
            if (!isOctalDigit(ch)) {
                return true;
            }
        }

        return true;
    }

    function scanNumericLiteral() {
        var number, start, ch;

        ch = source[index];
        assert(isDecimalDigit(ch.charCodeAt(0)) || (ch === '.'),
            'Numeric literal must start with a decimal digit or a decimal point');

        start = index;
        number = '';
        if (ch !== '.') {
            number = source[index++];
            ch = source[index];

            // Hex number starts with '0x'.
            // Octal number starts with '0'.
            // Octal number in ES6 starts with '0o'.
            // Binary number in ES6 starts with '0b'.
            if (number === '0') {
                if (ch === 'x' || ch === 'X') {
                    ++index;
                    return scanHexLiteral(start);
                }
                if (ch === 'b' || ch === 'B') {
                    ++index;
                    return scanBinaryLiteral(start);
                }
                if (ch === 'o' || ch === 'O') {
                    return scanOctalLiteral(ch, start);
                }

                if (isOctalDigit(ch)) {
                    if (isImplicitOctalLiteral()) {
                        return scanOctalLiteral(ch, start);
                    }
                }
            }

            while (isDecimalDigit(source.charCodeAt(index))) {
                number += source[index++];
            }
            ch = source[index];
        }

        if (ch === '.') {
            number += source[index++];
            while (isDecimalDigit(source.charCodeAt(index))) {
                number += source[index++];
            }
            ch = source[index];
        }

        if (ch === 'e' || ch === 'E') {
            number += source[index++];

            ch = source[index];
            if (ch === '+' || ch === '-') {
                number += source[index++];
            }
            if (isDecimalDigit(source.charCodeAt(index))) {
                while (isDecimalDigit(source.charCodeAt(index))) {
                    number += source[index++];
                }
            } else {
                throwUnexpectedToken();
            }
        }

        if (isIdentifierStart(source.charCodeAt(index))) {
            throwUnexpectedToken();
        }

        return {
            type: Token.NumericLiteral,
            value: parseFloat(number),
            lineNumber: lineNumber,
            lineStart: lineStart,
            start: start,
            end: index
        };
    }

    // ECMA-262 11.8.4 String Literals

    function scanStringLiteral() {
        var str = '', quote, start, ch, unescaped, octToDec, octal = false;

        quote = source[index];
        assert((quote === '\'' || quote === '"'),
            'String literal must starts with a quote');

        start = index;
        ++index;

        while (index < length) {
            ch = source[index++];

            if (ch === quote) {
                quote = '';
                break;
            } else if (ch === '\\') {
                ch = source[index++];
                if (!ch || !isLineTerminator(ch.charCodeAt(0))) {
                    switch (ch) {
                    case 'u':
                    case 'x':
                        if (source[index] === '{') {
                            ++index;
                            str += scanUnicodeCodePointEscape();
                        } else {
                            unescaped = scanHexEscape(ch);
                            if (!unescaped) {
                                throw throwUnexpectedToken();
                            }
                            str += unescaped;
                        }
                        break;
                    case 'n':
                        str += '\n';
                        break;
                    case 'r':
                        str += '\r';
                        break;
                    case 't':
                        str += '\t';
                        break;
                    case 'b':
                        str += '\b';
                        break;
                    case 'f':
                        str += '\f';
                        break;
                    case 'v':
                        str += '\x0B';
                        break;
                    case '8':
                    case '9':
                        str += ch;
                        tolerateUnexpectedToken();
                        break;

                    default:
                        if (isOctalDigit(ch)) {
                            octToDec = octalToDecimal(ch);

                            octal = octToDec.octal || octal;
                            str += String.fromCharCode(octToDec.code);
                        } else {
                            str += ch;
                        }
                        break;
                    }
                } else {
                    ++lineNumber;
                    if (ch === '\r' && source[index] === '\n') {
                        ++index;
                    }
                    lineStart = index;
                }
            } else if (isLineTerminator(ch.charCodeAt(0))) {
                break;
            } else {
                str += ch;
            }
        }

        if (quote !== '') {
            throwUnexpectedToken();
        }

        return {
            type: Token.StringLiteral,
            value: str,
            octal: octal,
            lineNumber: startLineNumber,
            lineStart: startLineStart,
            start: start,
            end: index
        };
    }

    // ECMA-262 11.8.6 Template Literal Lexical Components

    function scanTemplate() {
        var cooked = '', ch, start, rawOffset, terminated, head, tail, restore, unescaped;

        terminated = false;
        tail = false;
        start = index;
        head = (source[index] === '`');
        rawOffset = 2;

        ++index;

        while (index < length) {
            ch = source[index++];
            if (ch === '`') {
                rawOffset = 1;
                tail = true;
                terminated = true;
                break;
            } else if (ch === '$') {
                if (source[index] === '{') {
                    state.curlyStack.push('${');
                    ++index;
                    terminated = true;
                    break;
                }
                cooked += ch;
            } else if (ch === '\\') {
                ch = source[index++];
                if (!isLineTerminator(ch.charCodeAt(0))) {
                    switch (ch) {
                    case 'n':
                        cooked += '\n';
                        break;
                    case 'r':
                        cooked += '\r';
                        break;
                    case 't':
                        cooked += '\t';
                        break;
                    case 'u':
                    case 'x':
                        if (source[index] === '{') {
                            ++index;
                            cooked += scanUnicodeCodePointEscape();
                        } else {
                            restore = index;
                            unescaped = scanHexEscape(ch);
                            if (unescaped) {
                                cooked += unescaped;
                            } else {
                                index = restore;
                                cooked += ch;
                            }
                        }
                        break;
                    case 'b':
                        cooked += '\b';
                        break;
                    case 'f':
                        cooked += '\f';
                        break;
                    case 'v':
                        cooked += '\v';
                        break;

                    default:
                        if (ch === '0') {
                            if (isDecimalDigit(source.charCodeAt(index))) {
                                // Illegal: \01 \02 and so on
                                throwError(Messages.TemplateOctalLiteral);
                            }
                            cooked += '\0';
                        } else if (isOctalDigit(ch)) {
                            // Illegal: \1 \2
                            throwError(Messages.TemplateOctalLiteral);
                        } else {
                            cooked += ch;
                        }
                        break;
                    }
                } else {
                    ++lineNumber;
                    if (ch === '\r' && source[index] === '\n') {
                        ++index;
                    }
                    lineStart = index;
                }
            } else if (isLineTerminator(ch.charCodeAt(0))) {
                ++lineNumber;
                if (ch === '\r' && source[index] === '\n') {
                    ++index;
                }
                lineStart = index;
                cooked += '\n';
            } else {
                cooked += ch;
            }
        }

        if (!terminated) {
            throwUnexpectedToken();
        }

        if (!head) {
            state.curlyStack.pop();
        }

        return {
            type: Token.Template,
            value: {
                cooked: cooked,
                raw: source.slice(start + 1, index - rawOffset)
            },
            head: head,
            tail: tail,
            lineNumber: lineNumber,
            lineStart: lineStart,
            start: start,
            end: index
        };
    }

    // ECMA-262 11.8.5 Regular Expression Literals

    function testRegExp(pattern, flags) {
        // The BMP character to use as a replacement for astral symbols when
        // translating an ES6 "u"-flagged pattern to an ES5-compatible
        // approximation.
        // Note: replacing with '\uFFFF' enables false positives in unlikely
        // scenarios. For example, `[\u{1044f}-\u{10440}]` is an invalid
        // pattern that would not be detected by this substitution.
        var astralSubstitute = '\uFFFF',
            tmp = pattern;

        if (flags.indexOf('u') >= 0) {
            tmp = tmp
                // Replace every Unicode escape sequence with the equivalent
                // BMP character or a constant ASCII code point in the case of
                // astral symbols. (See the above note on `astralSubstitute`
                // for more information.)
                .replace(/\\u\{([0-9a-fA-F]+)\}|\\u([a-fA-F0-9]{4})/g, function ($0, $1, $2) {
                    var codePoint = parseInt($1 || $2, 16);
                    if (codePoint > 0x10FFFF) {
                        throwUnexpectedToken(null, Messages.InvalidRegExp);
                    }
                    if (codePoint <= 0xFFFF) {
                        return String.fromCharCode(codePoint);
                    }
                    return astralSubstitute;
                })
                // Replace each paired surrogate with a single ASCII symbol to
                // avoid throwing on regular expressions that are only valid in
                // combination with the "u" flag.
                .replace(
                    /[\uD800-\uDBFF][\uDC00-\uDFFF]/g,
                    astralSubstitute
                );
        }

        // First, detect invalid regular expressions.
        try {
            RegExp(tmp);
        } catch (e) {
            throwUnexpectedToken(null, Messages.InvalidRegExp);
        }

        // Return a regular expression object for this pattern-flag pair, or
        // `null` in case the current environment doesn't support the flags it
        // uses.
        try {
            return new RegExp(pattern, flags);
        } catch (exception) {
            return null;
        }
    }

    function scanRegExpBody() {
        var ch, str, classMarker, terminated, body;

        ch = source[index];
        assert(ch === '/', 'Regular expression literal must start with a slash');
        str = source[index++];

        classMarker = false;
        terminated = false;
        while (index < length) {
            ch = source[index++];
            str += ch;
            if (ch === '\\') {
                ch = source[index++];
                // ECMA-262 7.8.5
                if (isLineTerminator(ch.charCodeAt(0))) {
                    throwUnexpectedToken(null, Messages.UnterminatedRegExp);
                }
                str += ch;
            } else if (isLineTerminator(ch.charCodeAt(0))) {
                throwUnexpectedToken(null, Messages.UnterminatedRegExp);
            } else if (classMarker) {
                if (ch === ']') {
                    classMarker = false;
                }
            } else {
                if (ch === '/') {
                    terminated = true;
                    break;
                } else if (ch === '[') {
                    classMarker = true;
                }
            }
        }

        if (!terminated) {
            throwUnexpectedToken(null, Messages.UnterminatedRegExp);
        }

        // Exclude leading and trailing slash.
        body = str.substr(1, str.length - 2);
        return {
            value: body,
            literal: str
        };
    }

    function scanRegExpFlags() {
        var ch, str, flags, restore;

        str = '';
        flags = '';
        while (index < length) {
            ch = source[index];
            if (!isIdentifierPart(ch.charCodeAt(0))) {
                break;
            }

            ++index;
            if (ch === '\\' && index < length) {
                ch = source[index];
                if (ch === 'u') {
                    ++index;
                    restore = index;
                    ch = scanHexEscape('u');
                    if (ch) {
                        flags += ch;
                        for (str += '\\u'; restore < index; ++restore) {
                            str += source[restore];
                        }
                    } else {
                        index = restore;
                        flags += 'u';
                        str += '\\u';
                    }
                    tolerateUnexpectedToken();
                } else {
                    str += '\\';
                    tolerateUnexpectedToken();
                }
            } else {
                flags += ch;
                str += ch;
            }
        }

        return {
            value: flags,
            literal: str
        };
    }

    function scanRegExp() {
        var start, body, flags, value;
        scanning = true;

        lookahead = null;
        skipComment();
        start = index;

        body = scanRegExpBody();
        flags = scanRegExpFlags();
        value = testRegExp(body.value, flags.value);
        scanning = false;
        if (extra.tokenize) {
            return {
                type: Token.RegularExpression,
                value: value,
                regex: {
                    pattern: body.value,
                    flags: flags.value
                },
                lineNumber: lineNumber,
                lineStart: lineStart,
                start: start,
                end: index
            };
        }

        return {
            literal: body.literal + flags.literal,
            value: value,
            regex: {
                pattern: body.value,
                flags: flags.value
            },
            start: start,
            end: index
        };
    }

    function collectRegex() {
        var pos, loc, regex, token;

        skipComment();

        pos = index;
        loc = {
            start: {
                line: lineNumber,
                column: index - lineStart
            }
        };

        regex = scanRegExp();

        loc.end = {
            line: lineNumber,
            column: index - lineStart
        };

        /* istanbul ignore next */
        if (!extra.tokenize) {
            // Pop the previous token, which is likely '/' or '/='
            if (extra.tokens.length > 0) {
                token = extra.tokens[extra.tokens.length - 1];
                if (token.range[0] === pos && token.type === 'Punctuator') {
                    if (token.value === '/' || token.value === '/=') {
                        extra.tokens.pop();
                    }
                }
            }

            extra.tokens.push({
                type: 'RegularExpression',
                value: regex.literal,
                regex: regex.regex,
                range: [pos, index],
                loc: loc
            });
        }

        return regex;
    }

    function isIdentifierName(token) {
        return token.type === Token.Identifier ||
            token.type === Token.Keyword ||
            token.type === Token.BooleanLiteral ||
            token.type === Token.NullLiteral;
    }

    // Using the following algorithm:
    // https://github.com/mozilla/sweet.js/wiki/design

    function advanceSlash() {
        var regex, previous, check;

        function testKeyword(value) {
            return value && (value.length > 1) && (value[0] >= 'a') && (value[0] <= 'z');
        }

        previous = extra.tokenValues[extra.tokens.length - 1];
        regex = (previous !== null);

        switch (previous) {
        case 'this':
        case ']':
            regex = false;
            break;

        case ')':
            check = extra.tokenValues[extra.openParenToken - 1];
            regex = (check === 'if' || check === 'while' || check === 'for' || check === 'with');
            break;

        case '}':
            // Dividing a function by anything makes little sense,
            // but we have to check for that.
            regex = false;
            if (testKeyword(extra.tokenValues[extra.openCurlyToken - 3])) {
                // Anonymous function, e.g. function(){} /42
                check = extra.tokenValues[extra.openCurlyToken - 4];
                regex = check ? (FnExprTokens.indexOf(check) < 0) : false;
            } else if (testKeyword(extra.tokenValues[extra.openCurlyToken - 4])) {
                // Named function, e.g. function f(){} /42/
                check = extra.tokenValues[extra.openCurlyToken - 5];
                regex = check ? (FnExprTokens.indexOf(check) < 0) : true;
            }
        }

        return regex ? collectRegex() : scanPunctuator();
    }

    function advance() {
        var cp, token;

        if (index >= length) {
            return {
                type: Token.EOF,
                lineNumber: lineNumber,
                lineStart: lineStart,
                start: index,
                end: index
            };
        }

        cp = source.charCodeAt(index);

        if (isIdentifierStart(cp)) {
            token = scanIdentifier();
            if (strict && isStrictModeReservedWord(token.value)) {
                token.type = Token.Keyword;
            }
            return token;
        }

        // Very common: ( and ) and ;
        if (cp === 0x28 || cp === 0x29 || cp === 0x3B) {
            return scanPunctuator();
        }

        // String literal starts with single quote (U+0027) or double quote (U+0022).
        if (cp === 0x27 || cp === 0x22) {
            return scanStringLiteral();
        }

        // Dot (.) U+002E can also start a floating-point number, hence the need
        // to check the next character.
        if (cp === 0x2E) {
            if (isDecimalDigit(source.charCodeAt(index + 1))) {
                return scanNumericLiteral();
            }
            return scanPunctuator();
        }

        if (isDecimalDigit(cp)) {
            return scanNumericLiteral();
        }

        // Slash (/) U+002F can also start a regex.
        if (extra.tokenize && cp === 0x2F) {
            return advanceSlash();
        }

        // Template literals start with ` (U+0060) for template head
        // or } (U+007D) for template middle or template tail.
        if (cp === 0x60 || (cp === 0x7D && state.curlyStack[state.curlyStack.length - 1] === '${')) {
            return scanTemplate();
        }

        // Possible identifier start in a surrogate pair.
        if (cp >= 0xD800 && cp < 0xDFFF) {
            cp = codePointAt(index);
            if (isIdentifierStart(cp)) {
                return scanIdentifier();
            }
        }

        return scanPunctuator();
    }

    function collectToken() {
        var loc, token, value, entry;

        loc = {
            start: {
                line: lineNumber,
                column: index - lineStart
            }
        };

        token = advance();
        loc.end = {
            line: lineNumber,
            column: index - lineStart
        };

        if (token.type !== Token.EOF) {
            value = source.slice(token.start, token.end);
            entry = {
                type: TokenName[token.type],
                value: value,
                range: [token.start, token.end],
                loc: loc
            };
            if (token.regex) {
                entry.regex = {
                    pattern: token.regex.pattern,
                    flags: token.regex.flags
                };
            }
            if (extra.tokenValues) {
                extra.tokenValues.push((entry.type === 'Punctuator' || entry.type === 'Keyword') ? entry.value : null);
            }
            if (extra.tokenize) {
                if (!extra.range) {
                    delete entry.range;
                }
                if (!extra.loc) {
                    delete entry.loc;
                }
                if (extra.delegate) {
                    entry = extra.delegate(entry);
                }
            }
            extra.tokens.push(entry);
        }

        return token;
    }

    function lex() {
        var token;
        scanning = true;

        lastIndex = index;
        lastLineNumber = lineNumber;
        lastLineStart = lineStart;

        skipComment();

        token = lookahead;

        startIndex = index;
        startLineNumber = lineNumber;
        startLineStart = lineStart;

        lookahead = (typeof extra.tokens !== 'undefined') ? collectToken() : advance();
        scanning = false;
        return token;
    }

    function peek() {
        scanning = true;

        skipComment();

        lastIndex = index;
        lastLineNumber = lineNumber;
        lastLineStart = lineStart;

        startIndex = index;
        startLineNumber = lineNumber;
        startLineStart = lineStart;

        lookahead = (typeof extra.tokens !== 'undefined') ? collectToken() : advance();
        scanning = false;
    }

    function Position() {
        this.line = startLineNumber;
        this.column = startIndex - startLineStart;
    }

    function SourceLocation() {
        this.start = new Position();
        this.end = null;
    }

    function WrappingSourceLocation(startToken) {
        this.start = {
            line: startToken.lineNumber,
            column: startToken.start - startToken.lineStart
        };
        this.end = null;
    }

    function Node() {
        if (extra.range) {
            this.range = [startIndex, 0];
        }
        if (extra.loc) {
            this.loc = new SourceLocation();
        }
    }

    function WrappingNode(startToken) {
        if (extra.range) {
            this.range = [startToken.start, 0];
        }
        if (extra.loc) {
            this.loc = new WrappingSourceLocation(startToken);
        }
    }

    WrappingNode.prototype = Node.prototype = {

        processComment: function () {
            var lastChild,
                innerComments,
                leadingComments,
                trailingComments,
                bottomRight = extra.bottomRightStack,
                i,
                comment,
                last = bottomRight[bottomRight.length - 1];

            if (this.type === Syntax.Program) {
                if (this.body.length > 0) {
                    return;
                }
            }
            /**
             * patch innnerComments for properties empty block
             * `function a() {/** comments **\/}`
             */

            if (this.type === Syntax.BlockStatement && this.body.length === 0) {
                innerComments = [];
                for (i = extra.leadingComments.length - 1; i >= 0; --i) {
                    comment = extra.leadingComments[i];
                    if (this.range[1] >= comment.range[1]) {
                        innerComments.unshift(comment);
                        extra.leadingComments.splice(i, 1);
                        extra.trailingComments.splice(i, 1);
                    }
                }
                if (innerComments.length) {
                    this.innerComments = innerComments;
                    //bottomRight.push(this);
                    return;
                }
            }

            if (extra.trailingComments.length > 0) {
                trailingComments = [];
                for (i = extra.trailingComments.length - 1; i >= 0; --i) {
                    comment = extra.trailingComments[i];
                    if (comment.range[0] >= this.range[1]) {
                        trailingComments.unshift(comment);
                        extra.trailingComments.splice(i, 1);
                    }
                }
                extra.trailingComments = [];
            } else {
                if (last && last.trailingComments && last.trailingComments[0].range[0] >= this.range[1]) {
                    trailingComments = last.trailingComments;
                    delete last.trailingComments;
                }
            }

            // Eating the stack.
            while (last && last.range[0] >= this.range[0]) {
                lastChild = bottomRight.pop();
                last = bottomRight[bottomRight.length - 1];
            }

            if (lastChild) {
                if (lastChild.leadingComments) {
                    leadingComments = [];
                    for (i = lastChild.leadingComments.length - 1; i >= 0; --i) {
                        comment = lastChild.leadingComments[i];
                        if (comment.range[1] <= this.range[0]) {
                            leadingComments.unshift(comment);
                            lastChild.leadingComments.splice(i, 1);
                        }
                    }

                    if (!lastChild.leadingComments.length) {
                        lastChild.leadingComments = undefined;
                    }
                }
            } else if (extra.leadingComments.length > 0) {
                leadingComments = [];
                for (i = extra.leadingComments.length - 1; i >= 0; --i) {
                    comment = extra.leadingComments[i];
                    if (comment.range[1] <= this.range[0]) {
                        leadingComments.unshift(comment);
                        extra.leadingComments.splice(i, 1);
                    }
                }
            }


            if (leadingComments && leadingComments.length > 0) {
                this.leadingComments = leadingComments;
            }
            if (trailingComments && trailingComments.length > 0) {
                this.trailingComments = trailingComments;
            }

            bottomRight.push(this);
        },

        finish: function () {
            if (extra.range) {
                this.range[1] = lastIndex;
            }
            if (extra.loc) {
                this.loc.end = {
                    line: lastLineNumber,
                    column: lastIndex - lastLineStart
                };
                if (extra.source) {
                    this.loc.source = extra.source;
                }
            }

            if (extra.attachComment) {
                this.processComment();
            }
        },

        finishArrayExpression: function (elements) {
            this.type = Syntax.ArrayExpression;
            this.elements = elements;
            this.finish();
            return this;
        },

        finishArrayPattern: function (elements) {
            this.type = Syntax.ArrayPattern;
            this.elements = elements;
            this.finish();
            return this;
        },

        finishArrowFunctionExpression: function (params, defaults, body, expression) {
            this.type = Syntax.ArrowFunctionExpression;
            this.id = null;
            this.params = params;
            this.defaults = defaults;
            this.body = body;
            this.generator = false;
            this.expression = expression;
            this.finish();
            return this;
        },

        finishAssignmentExpression: function (operator, left, right) {
            this.type = Syntax.AssignmentExpression;
            this.operator = operator;
            this.left = left;
            this.right = right;
            this.finish();
            return this;
        },

        finishAssignmentPattern: function (left, right) {
            this.type = Syntax.AssignmentPattern;
            this.left = left;
            this.right = right;
            this.finish();
            return this;
        },

        finishBinaryExpression: function (operator, left, right) {
            this.type = (operator === '||' || operator === '&&') ? Syntax.LogicalExpression : Syntax.BinaryExpression;
            this.operator = operator;
            this.left = left;
            this.right = right;
            this.finish();
            return this;
        },

        finishBlockStatement: function (body) {
            this.type = Syntax.BlockStatement;
            this.body = body;
            this.finish();
            return this;
        },

        finishBreakStatement: function (label) {
            this.type = Syntax.BreakStatement;
            this.label = label;
            this.finish();
            return this;
        },

        finishCallExpression: function (callee, args) {
            this.type = Syntax.CallExpression;
            this.callee = callee;
            this.arguments = args;
            this.finish();
            return this;
        },

        finishCatchClause: function (param, body) {
            this.type = Syntax.CatchClause;
            this.param = param;
            this.body = body;
            this.finish();
            return this;
        },

        finishClassBody: function (body) {
            this.type = Syntax.ClassBody;
            this.body = body;
            this.finish();
            return this;
        },

        finishClassDeclaration: function (id, superClass, body) {
            this.type = Syntax.ClassDeclaration;
            this.id = id;
            this.superClass = superClass;
            this.body = body;
            this.finish();
            return this;
        },

        finishClassExpression: function (id, superClass, body) {
            this.type = Syntax.ClassExpression;
            this.id = id;
            this.superClass = superClass;
            this.body = body;
            this.finish();
            return this;
        },

        finishConditionalExpression: function (test, consequent, alternate) {
            this.type = Syntax.ConditionalExpression;
            this.test = test;
            this.consequent = consequent;
            this.alternate = alternate;
            this.finish();
            return this;
        },

        finishContinueStatement: function (label) {
            this.type = Syntax.ContinueStatement;
            this.label = label;
            this.finish();
            return this;
        },

        finishDebuggerStatement: function () {
            this.type = Syntax.DebuggerStatement;
            this.finish();
            return this;
        },

        finishDoWhileStatement: function (body, test) {
            this.type = Syntax.DoWhileStatement;
            this.body = body;
            this.test = test;
            this.finish();
            return this;
        },

        finishEmptyStatement: function () {
            this.type = Syntax.EmptyStatement;
            this.finish();
            return this;
        },

        finishExpressionStatement: function (expression) {
            this.type = Syntax.ExpressionStatement;
            this.expression = expression;
            this.finish();
            return this;
        },

        finishForStatement: function (init, test, update, body) {
            this.type = Syntax.ForStatement;
            this.init = init;
            this.test = test;
            this.update = update;
            this.body = body;
            this.finish();
            return this;
        },

        finishForOfStatement: function (left, right, body) {
            this.type = Syntax.ForOfStatement;
            this.left = left;
            this.right = right;
            this.body = body;
            this.finish();
            return this;
        },

        finishForInStatement: function (left, right, body) {
            this.type = Syntax.ForInStatement;
            this.left = left;
            this.right = right;
            this.body = body;
            this.each = false;
            this.finish();
            return this;
        },

        finishFunctionDeclaration: function (id, params, defaults, body, generator) {
            this.type = Syntax.FunctionDeclaration;
            this.id = id;
            this.params = params;
            this.defaults = defaults;
            this.body = body;
            this.generator = generator;
            this.expression = false;
            this.finish();
            return this;
        },

        finishFunctionExpression: function (id, params, defaults, body, generator) {
            this.type = Syntax.FunctionExpression;
            this.id = id;
            this.params = params;
            this.defaults = defaults;
            this.body = body;
            this.generator = generator;
            this.expression = false;
            this.finish();
            return this;
        },

        finishIdentifier: function (name) {
            this.type = Syntax.Identifier;
            this.name = name;
            this.finish();
            return this;
        },

        finishIfStatement: function (test, consequent, alternate) {
            this.type = Syntax.IfStatement;
            this.test = test;
            this.consequent = consequent;
            this.alternate = alternate;
            this.finish();
            return this;
        },

        finishLabeledStatement: function (label, body) {
            this.type = Syntax.LabeledStatement;
            this.label = label;
            this.body = body;
            this.finish();
            return this;
        },

        finishLiteral: function (token) {
            this.type = Syntax.Literal;
            this.value = token.value;
            this.raw = source.slice(token.start, token.end);
            if (token.regex) {
                this.regex = token.regex;
            }
            this.finish();
            return this;
        },

        finishMemberExpression: function (accessor, object, property) {
            this.type = Syntax.MemberExpression;
            this.computed = accessor === '[';
            this.object = object;
            this.property = property;
            this.finish();
            return this;
        },

        finishMetaProperty: function (meta, property) {
            this.type = Syntax.MetaProperty;
            this.meta = meta;
            this.property = property;
            this.finish();
            return this;
        },

        finishNewExpression: function (callee, args) {
            this.type = Syntax.NewExpression;
            this.callee = callee;
            this.arguments = args;
            this.finish();
            return this;
        },

        finishObjectExpression: function (properties) {
            this.type = Syntax.ObjectExpression;
            this.properties = properties;
            this.finish();
            return this;
        },

        finishObjectPattern: function (properties) {
            this.type = Syntax.ObjectPattern;
            this.properties = properties;
            this.finish();
            return this;
        },

        finishPostfixExpression: function (operator, argument) {
            this.type = Syntax.UpdateExpression;
            this.operator = operator;
            this.argument = argument;
            this.prefix = false;
            this.finish();
            return this;
        },

        finishProgram: function (body, sourceType) {
            this.type = Syntax.Program;
            this.body = body;
            this.sourceType = sourceType;
            this.finish();
            return this;
        },

        finishProperty: function (kind, key, computed, value, method, shorthand) {
            this.type = Syntax.Property;
            this.key = key;
            this.computed = computed;
            this.value = value;
            this.kind = kind;
            this.method = method;
            this.shorthand = shorthand;
            this.finish();
            return this;
        },

        finishRestElement: function (argument) {
            this.type = Syntax.RestElement;
            this.argument = argument;
            this.finish();
            return this;
        },

        finishReturnStatement: function (argument) {
            this.type = Syntax.ReturnStatement;
            this.argument = argument;
            this.finish();
            return this;
        },

        finishSequenceExpression: function (expressions) {
            this.type = Syntax.SequenceExpression;
            this.expressions = expressions;
            this.finish();
            return this;
        },

        finishSpreadElement: function (argument) {
            this.type = Syntax.SpreadElement;
            this.argument = argument;
            this.finish();
            return this;
        },

        finishSwitchCase: function (test, consequent) {
            this.type = Syntax.SwitchCase;
            this.test = test;
            this.consequent = consequent;
            this.finish();
            return this;
        },

        finishSuper: function () {
            this.type = Syntax.Super;
            this.finish();
            return this;
        },

        finishSwitchStatement: function (discriminant, cases) {
            this.type = Syntax.SwitchStatement;
            this.discriminant = discriminant;
            this.cases = cases;
            this.finish();
            return this;
        },

        finishTaggedTemplateExpression: function (tag, quasi) {
            this.type = Syntax.TaggedTemplateExpression;
            this.tag = tag;
            this.quasi = quasi;
            this.finish();
            return this;
        },

        finishTemplateElement: function (value, tail) {
            this.type = Syntax.TemplateElement;
            this.value = value;
            this.tail = tail;
            this.finish();
            return this;
        },

        finishTemplateLiteral: function (quasis, expressions) {
            this.type = Syntax.TemplateLiteral;
            this.quasis = quasis;
            this.expressions = expressions;
            this.finish();
            return this;
        },

        finishThisExpression: function () {
            this.type = Syntax.ThisExpression;
            this.finish();
            return this;
        },

        finishThrowStatement: function (argument) {
            this.type = Syntax.ThrowStatement;
            this.argument = argument;
            this.finish();
            return this;
        },

        finishTryStatement: function (block, handler, finalizer) {
            this.type = Syntax.TryStatement;
            this.block = block;
            this.guardedHandlers = [];
            this.handlers = handler ? [handler] : [];
            this.handler = handler;
            this.finalizer = finalizer;
            this.finish();
            return this;
        },

        finishUnaryExpression: function (operator, argument) {
            this.type = (operator === '++' || operator === '--') ? Syntax.UpdateExpression : Syntax.UnaryExpression;
            this.operator = operator;
            this.argument = argument;
            this.prefix = true;
            this.finish();
            return this;
        },

        finishVariableDeclaration: function (declarations) {
            this.type = Syntax.VariableDeclaration;
            this.declarations = declarations;
            this.kind = 'var';
            this.finish();
            return this;
        },

        finishLexicalDeclaration: function (declarations, kind) {
            this.type = Syntax.VariableDeclaration;
            this.declarations = declarations;
            this.kind = kind;
            this.finish();
            return this;
        },

        finishVariableDeclarator: function (id, init) {
            this.type = Syntax.VariableDeclarator;
            this.id = id;
            this.init = init;
            this.finish();
            return this;
        },

        finishWhileStatement: function (test, body) {
            this.type = Syntax.WhileStatement;
            this.test = test;
            this.body = body;
            this.finish();
            return this;
        },

        finishWithStatement: function (object, body) {
            this.type = Syntax.WithStatement;
            this.object = object;
            this.body = body;
            this.finish();
            return this;
        },

        finishExportSpecifier: function (local, exported) {
            this.type = Syntax.ExportSpecifier;
            this.exported = exported || local;
            this.local = local;
            this.finish();
            return this;
        },

        finishImportDefaultSpecifier: function (local) {
            this.type = Syntax.ImportDefaultSpecifier;
            this.local = local;
            this.finish();
            return this;
        },

        finishImportNamespaceSpecifier: function (local) {
            this.type = Syntax.ImportNamespaceSpecifier;
            this.local = local;
            this.finish();
            return this;
        },

        finishExportNamedDeclaration: function (declaration, specifiers, src) {
            this.type = Syntax.ExportNamedDeclaration;
            this.declaration = declaration;
            this.specifiers = specifiers;
            this.source = src;
            this.finish();
            return this;
        },

        finishExportDefaultDeclaration: function (declaration) {
            this.type = Syntax.ExportDefaultDeclaration;
            this.declaration = declaration;
            this.finish();
            return this;
        },

        finishExportAllDeclaration: function (src) {
            this.type = Syntax.ExportAllDeclaration;
            this.source = src;
            this.finish();
            return this;
        },

        finishImportSpecifier: function (local, imported) {
            this.type = Syntax.ImportSpecifier;
            this.local = local || imported;
            this.imported = imported;
            this.finish();
            return this;
        },

        finishImportDeclaration: function (specifiers, src) {
            this.type = Syntax.ImportDeclaration;
            this.specifiers = specifiers;
            this.source = src;
            this.finish();
            return this;
        },

        finishYieldExpression: function (argument, delegate) {
            this.type = Syntax.YieldExpression;
            this.argument = argument;
            this.delegate = delegate;
            this.finish();
            return this;
        }
    };


    function recordError(error) {
        var e, existing;

        for (e = 0; e < extra.errors.length; e++) {
            existing = extra.errors[e];
            // Prevent duplicated error.
            /* istanbul ignore next */
            if (existing.index === error.index && existing.message === error.message) {
                return;
            }
        }

        extra.errors.push(error);
    }

    function constructError(msg, column) {
        var error = new Error(msg);
        try {
            throw error;
        } catch (base) {
            /* istanbul ignore else */
            if (Object.create && Object.defineProperty) {
                error = Object.create(base);
                Object.defineProperty(error, 'column', { value: column });
            }
        } finally {
            return error;
        }
    }

    function createError(line, pos, description) {
        var msg, column, error;

        msg = 'Line ' + line + ': ' + description;
        column = pos - (scanning ? lineStart : lastLineStart) + 1;
        error = constructError(msg, column);
        error.lineNumber = line;
        error.description = description;
        error.index = pos;
        return error;
    }

    // Throw an exception

    function throwError(messageFormat) {
        var args, msg;

        args = Array.prototype.slice.call(arguments, 1);
        msg = messageFormat.replace(/%(\d)/g,
            function (whole, idx) {
                assert(idx < args.length, 'Message reference must be in range');
                return args[idx];
            }
        );

        throw createError(lastLineNumber, lastIndex, msg);
    }

    function tolerateError(messageFormat) {
        var args, msg, error;

        args = Array.prototype.slice.call(arguments, 1);
        /* istanbul ignore next */
        msg = messageFormat.replace(/%(\d)/g,
            function (whole, idx) {
                assert(idx < args.length, 'Message reference must be in range');
                return args[idx];
            }
        );

        error = createError(lineNumber, lastIndex, msg);
        if (extra.errors) {
            recordError(error);
        } else {
            throw error;
        }
    }

    // Throw an exception because of the token.

    function unexpectedTokenError(token, message) {
        var value, msg = message || Messages.UnexpectedToken;

        if (token) {
            if (!message) {
                msg = (token.type === Token.EOF) ? Messages.UnexpectedEOS :
                    (token.type === Token.Identifier) ? Messages.UnexpectedIdentifier :
                    (token.type === Token.NumericLiteral) ? Messages.UnexpectedNumber :
                    (token.type === Token.StringLiteral) ? Messages.UnexpectedString :
                    (token.type === Token.Template) ? Messages.UnexpectedTemplate :
                    Messages.UnexpectedToken;

                if (token.type === Token.Keyword) {
                    if (isFutureReservedWord(token.value)) {
                        msg = Messages.UnexpectedReserved;
                    } else if (strict && isStrictModeReservedWord(token.value)) {
                        msg = Messages.StrictReservedWord;
                    }
                }
            }

            value = (token.type === Token.Template) ? token.value.raw : token.value;
        } else {
            value = 'ILLEGAL';
        }

        msg = msg.replace('%0', value);

        return (token && typeof token.lineNumber === 'number') ?
            createError(token.lineNumber, token.start, msg) :
            createError(scanning ? lineNumber : lastLineNumber, scanning ? index : lastIndex, msg);
    }

    function throwUnexpectedToken(token, message) {
        throw unexpectedTokenError(token, message);
    }

    function tolerateUnexpectedToken(token, message) {
        var error = unexpectedTokenError(token, message);
        if (extra.errors) {
            recordError(error);
        } else {
            throw error;
        }
    }

    // Expect the next token to match the specified punctuator.
    // If not, an exception will be thrown.

    function expect(value) {
        var token = lex();
        if (token.type !== Token.Punctuator || token.value !== value) {
            throwUnexpectedToken(token);
        }
    }

    /**
     * @name expectCommaSeparator
     * @description Quietly expect a comma when in tolerant mode, otherwise delegates
     * to <code>expect(value)</code>
     * @since 2.0
     */
    function expectCommaSeparator() {
        var token;

        if (extra.errors) {
            token = lookahead;
            if (token.type === Token.Punctuator && token.value === ',') {
                lex();
            } else if (token.type === Token.Punctuator && token.value === ';') {
                lex();
                tolerateUnexpectedToken(token);
            } else {
                tolerateUnexpectedToken(token, Messages.UnexpectedToken);
            }
        } else {
            expect(',');
        }
    }

    // Expect the next token to match the specified keyword.
    // If not, an exception will be thrown.

    function expectKeyword(keyword) {
        var token = lex();
        if (token.type !== Token.Keyword || token.value !== keyword) {
            throwUnexpectedToken(token);
        }
    }

    // Return true if the next token matches the specified punctuator.

    function match(value) {
        return lookahead.type === Token.Punctuator && lookahead.value === value;
    }

    // Return true if the next token matches the specified keyword

    function matchKeyword(keyword) {
        return lookahead.type === Token.Keyword && lookahead.value === keyword;
    }

    // Return true if the next token matches the specified contextual keyword
    // (where an identifier is sometimes a keyword depending on the context)

    function matchContextualKeyword(keyword) {
        return lookahead.type === Token.Identifier && lookahead.value === keyword;
    }

    // Return true if the next token is an assignment operator

    function matchAssign() {
        var op;

        if (lookahead.type !== Token.Punctuator) {
            return false;
        }
        op = lookahead.value;
        return op === '=' ||
            op === '*=' ||
            op === '/=' ||
            op === '%=' ||
            op === '+=' ||
            op === '-=' ||
            op === '<<=' ||
            op === '>>=' ||
            op === '>>>=' ||
            op === '&=' ||
            op === '^=' ||
            op === '|=';
    }

    function consumeSemicolon() {
        // Catch the very common case first: immediately a semicolon (U+003B).
        if (source.charCodeAt(startIndex) === 0x3B || match(';')) {
            lex();
            return;
        }

        if (hasLineTerminator) {
            return;
        }

        // FIXME(ikarienator): this is seemingly an issue in the previous location info convention.
        lastIndex = startIndex;
        lastLineNumber = startLineNumber;
        lastLineStart = startLineStart;

        if (lookahead.type !== Token.EOF && !match('}')) {
            throwUnexpectedToken(lookahead);
        }
    }

    // Cover grammar support.
    //
    // When an assignment expression position starts with an left parenthesis, the determination of the type
    // of the syntax is to be deferred arbitrarily long until the end of the parentheses pair (plus a lookahead)
    // or the first comma. This situation also defers the determination of all the expressions nested in the pair.
    //
    // There are three productions that can be parsed in a parentheses pair that needs to be determined
    // after the outermost pair is closed. They are:
    //
    //   1. AssignmentExpression
    //   2. BindingElements
    //   3. AssignmentTargets
    //
    // In order to avoid exponential backtracking, we use two flags to denote if the production can be
    // binding element or assignment target.
    //
    // The three productions have the relationship:
    //
    //   BindingElements ⊆ AssignmentTargets ⊆ AssignmentExpression
    //
    // with a single exception that CoverInitializedName when used directly in an Expression, generates
    // an early error. Therefore, we need the third state, firstCoverInitializedNameError, to track the
    // first usage of CoverInitializedName and report it when we reached the end of the parentheses pair.
    //
    // isolateCoverGrammar function runs the given parser function with a new cover grammar context, and it does not
    // effect the current flags. This means the production the parser parses is only used as an expression. Therefore
    // the CoverInitializedName check is conducted.
    //
    // inheritCoverGrammar function runs the given parse function with a new cover grammar context, and it propagates
    // the flags outside of the parser. This means the production the parser parses is used as a part of a potential
    // pattern. The CoverInitializedName check is deferred.
    function isolateCoverGrammar(parser) {
        var oldIsBindingElement = isBindingElement,
            oldIsAssignmentTarget = isAssignmentTarget,
            oldFirstCoverInitializedNameError = firstCoverInitializedNameError,
            result;
        isBindingElement = true;
        isAssignmentTarget = true;
        firstCoverInitializedNameError = null;
        result = parser();
        if (firstCoverInitializedNameError !== null) {
            throwUnexpectedToken(firstCoverInitializedNameError);
        }
        isBindingElement = oldIsBindingElement;
        isAssignmentTarget = oldIsAssignmentTarget;
        firstCoverInitializedNameError = oldFirstCoverInitializedNameError;
        return result;
    }

    function inheritCoverGrammar(parser) {
        var oldIsBindingElement = isBindingElement,
            oldIsAssignmentTarget = isAssignmentTarget,
            oldFirstCoverInitializedNameError = firstCoverInitializedNameError,
            result;
        isBindingElement = true;
        isAssignmentTarget = true;
        firstCoverInitializedNameError = null;
        result = parser();
        isBindingElement = isBindingElement && oldIsBindingElement;
        isAssignmentTarget = isAssignmentTarget && oldIsAssignmentTarget;
        firstCoverInitializedNameError = oldFirstCoverInitializedNameError || firstCoverInitializedNameError;
        return result;
    }

    // ECMA-262 13.3.3 Destructuring Binding Patterns

    function parseArrayPattern(params, kind) {
        var node = new Node(), elements = [], rest, restNode;
        expect('[');

        while (!match(']')) {
            if (match(',')) {
                lex();
                elements.push(null);
            } else {
                if (match('...')) {
                    restNode = new Node();
                    lex();
                    params.push(lookahead);
                    rest = parseVariableIdentifier(kind);
                    elements.push(restNode.finishRestElement(rest));
                    break;
                } else {
                    elements.push(parsePatternWithDefault(params, kind));
                }
                if (!match(']')) {
                    expect(',');
                }
            }

        }

        expect(']');

        return node.finishArrayPattern(elements);
    }

    function parsePropertyPattern(params, kind) {
        var node = new Node(), key, keyToken, computed = match('['), init;
        if (lookahead.type === Token.Identifier) {
            keyToken = lookahead;
            key = parseVariableIdentifier();
            if (match('=')) {
                params.push(keyToken);
                lex();
                init = parseAssignmentExpression();

                return node.finishProperty(
                    'init', key, false,
                    new WrappingNode(keyToken).finishAssignmentPattern(key, init), false, false);
            } else if (!match(':')) {
                params.push(keyToken);
                return node.finishProperty('init', key, false, key, false, true);
            }
        } else {
            key = parseObjectPropertyKey();
        }
        expect(':');
        init = parsePatternWithDefault(params, kind);
        return node.finishProperty('init', key, computed, init, false, false);
    }

    function parseObjectPattern(params, kind) {
        var node = new Node(), properties = [];

        expect('{');

        while (!match('}')) {
            properties.push(parsePropertyPattern(params, kind));
            if (!match('}')) {
                expect(',');
            }
        }

        lex();

        return node.finishObjectPattern(properties);
    }

    function parsePattern(params, kind) {
        if (match('[')) {
            return parseArrayPattern(params, kind);
        } else if (match('{')) {
            return parseObjectPattern(params, kind);
        } else if (matchKeyword('let')) {
            if (kind === 'const' || kind === 'let') {
                tolerateUnexpectedToken(lookahead, Messages.UnexpectedToken);
            }
        }

        params.push(lookahead);
        return parseVariableIdentifier(kind);
    }

    function parsePatternWithDefault(params, kind) {
        var startToken = lookahead, pattern, previousAllowYield, right;
        pattern = parsePattern(params, kind);
        if (match('=')) {
            lex();
            previousAllowYield = state.allowYield;
            state.allowYield = true;
            right = isolateCoverGrammar(parseAssignmentExpression);
            state.allowYield = previousAllowYield;
            pattern = new WrappingNode(startToken).finishAssignmentPattern(pattern, right);
        }
        return pattern;
    }

    // ECMA-262 12.2.5 Array Initializer

    function parseArrayInitializer() {
        var elements = [], node = new Node(), restSpread;

        expect('[');

        while (!match(']')) {
            if (match(',')) {
                lex();
                elements.push(null);
            } else if (match('...')) {
                restSpread = new Node();
                lex();
                restSpread.finishSpreadElement(inheritCoverGrammar(parseAssignmentExpression));

                if (!match(']')) {
                    isAssignmentTarget = isBindingElement = false;
                    expect(',');
                }
                elements.push(restSpread);
            } else {
                elements.push(inheritCoverGrammar(parseAssignmentExpression));

                if (!match(']')) {
                    expect(',');
                }
            }
        }

        lex();

        return node.finishArrayExpression(elements);
    }

    // ECMA-262 12.2.6 Object Initializer

    function parsePropertyFunction(node, paramInfo, isGenerator) {
        var previousStrict, body;

        isAssignmentTarget = isBindingElement = false;

        previousStrict = strict;
        body = isolateCoverGrammar(parseFunctionSourceElements);

        if (strict && paramInfo.firstRestricted) {
            tolerateUnexpectedToken(paramInfo.firstRestricted, paramInfo.message);
        }
        if (strict && paramInfo.stricted) {
            tolerateUnexpectedToken(paramInfo.stricted, paramInfo.message);
        }

        strict = previousStrict;
        return node.finishFunctionExpression(null, paramInfo.params, paramInfo.defaults, body, isGenerator);
    }

    function parsePropertyMethodFunction() {
        var params, method, node = new Node(),
            previousAllowYield = state.allowYield;

        state.allowYield = false;
        params = parseParams();
        state.allowYield = previousAllowYield;

        state.allowYield = false;
        method = parsePropertyFunction(node, params, false);
        state.allowYield = previousAllowYield;

        return method;
    }

    function parseObjectPropertyKey() {
        var token, node = new Node(), expr;

        token = lex();

        // Note: This function is called only from parseObjectProperty(), where
        // EOF and Punctuator tokens are already filtered out.

        switch (token.type) {
        case Token.StringLiteral:
        case Token.NumericLiteral:
            if (strict && token.octal) {
                tolerateUnexpectedToken(token, Messages.StrictOctalLiteral);
            }
            return node.finishLiteral(token);
        case Token.Identifier:
        case Token.BooleanLiteral:
        case Token.NullLiteral:
        case Token.Keyword:
            return node.finishIdentifier(token.value);
        case Token.Punctuator:
            if (token.value === '[') {
                expr = isolateCoverGrammar(parseAssignmentExpression);
                expect(']');
                return expr;
            }
            break;
        }
        throwUnexpectedToken(token);
    }

    function lookaheadPropertyName() {
        switch (lookahead.type) {
        case Token.Identifier:
        case Token.StringLiteral:
        case Token.BooleanLiteral:
        case Token.NullLiteral:
        case Token.NumericLiteral:
        case Token.Keyword:
            return true;
        case Token.Punctuator:
            return lookahead.value === '[';
        }
        return false;
    }

    // This function is to try to parse a MethodDefinition as defined in 14.3. But in the case of object literals,
    // it might be called at a position where there is in fact a short hand identifier pattern or a data property.
    // This can only be determined after we consumed up to the left parentheses.
    //
    // In order to avoid back tracking, it returns `null` if the position is not a MethodDefinition and the caller
    // is responsible to visit other options.
    function tryParseMethodDefinition(token, key, computed, node) {
        var value, options, methodNode, params,
            previousAllowYield = state.allowYield;

        if (token.type === Token.Identifier) {
            // check for `get` and `set`;

            if (token.value === 'get' && lookaheadPropertyName()) {
                computed = match('[');
                key = parseObjectPropertyKey();
                methodNode = new Node();
                expect('(');
                expect(')');

                state.allowYield = false;
                value = parsePropertyFunction(methodNode, {
                    params: [],
                    defaults: [],
                    stricted: null,
                    firstRestricted: null,
                    message: null
                }, false);
                state.allowYield = previousAllowYield;

                return node.finishProperty('get', key, computed, value, false, false);
            } else if (token.value === 'set' && lookaheadPropertyName()) {
                computed = match('[');
                key = parseObjectPropertyKey();
                methodNode = new Node();
                expect('(');

                options = {
                    params: [],
                    defaultCount: 0,
                    defaults: [],
                    firstRestricted: null,
                    paramSet: {}
                };
                if (match(')')) {
                    tolerateUnexpectedToken(lookahead);
                } else {
                    state.allowYield = false;
                    parseParam(options);
                    state.allowYield = previousAllowYield;
                    if (options.defaultCount === 0) {
                        options.defaults = [];
                    }
                }
                expect(')');

                state.allowYield = false;
                value = parsePropertyFunction(methodNode, options, false);
                state.allowYield = previousAllowYield;

                return node.finishProperty('set', key, computed, value, false, false);
            }
        } else if (token.type === Token.Punctuator && token.value === '*' && lookaheadPropertyName()) {
            computed = match('[');
            key = parseObjectPropertyKey();
            methodNode = new Node();

            state.allowYield = true;
            params = parseParams();
            state.allowYield = previousAllowYield;

            state.allowYield = false;
            value = parsePropertyFunction(methodNode, params, true);
            state.allowYield = previousAllowYield;

            return node.finishProperty('init', key, computed, value, true, false);
        }

        if (key && match('(')) {
            value = parsePropertyMethodFunction();
            return node.finishProperty('init', key, computed, value, true, false);
        }

        // Not a MethodDefinition.
        return null;
    }

    function parseObjectProperty(hasProto) {
        var token = lookahead, node = new Node(), computed, key, maybeMethod, proto, value;

        computed = match('[');
        if (match('*')) {
            lex();
        } else {
            key = parseObjectPropertyKey();
        }
        maybeMethod = tryParseMethodDefinition(token, key, computed, node);
        if (maybeMethod) {
            return maybeMethod;
        }

        if (!key) {
            throwUnexpectedToken(lookahead);
        }

        // Check for duplicated __proto__
        if (!computed) {
            proto = (key.type === Syntax.Identifier && key.name === '__proto__') ||
                (key.type === Syntax.Literal && key.value === '__proto__');
            if (hasProto.value && proto) {
                tolerateError(Messages.DuplicateProtoProperty);
            }
            hasProto.value |= proto;
        }

        if (match(':')) {
            lex();
            value = inheritCoverGrammar(parseAssignmentExpression);
            return node.finishProperty('init', key, computed, value, false, false);
        }

        if (token.type === Token.Identifier) {
            if (match('=')) {
                firstCoverInitializedNameError = lookahead;
                lex();
                value = isolateCoverGrammar(parseAssignmentExpression);
                return node.finishProperty('init', key, computed,
                    new WrappingNode(token).finishAssignmentPattern(key, value), false, true);
            }
            return node.finishProperty('init', key, computed, key, false, true);
        }

        throwUnexpectedToken(lookahead);
    }

    function parseObjectInitializer() {
        var properties = [], hasProto = {value: false}, node = new Node();

        expect('{');

        while (!match('}')) {
            properties.push(parseObjectProperty(hasProto));

            if (!match('}')) {
                expectCommaSeparator();
            }
        }

        expect('}');

        return node.finishObjectExpression(properties);
    }

    function reinterpretExpressionAsPattern(expr) {
        var i;
        switch (expr.type) {
        case Syntax.Identifier:
        case Syntax.MemberExpression:
        case Syntax.RestElement:
        case Syntax.AssignmentPattern:
            break;
        case Syntax.SpreadElement:
            expr.type = Syntax.RestElement;
            reinterpretExpressionAsPattern(expr.argument);
            break;
        case Syntax.ArrayExpression:
            expr.type = Syntax.ArrayPattern;
            for (i = 0; i < expr.elements.length; i++) {
                if (expr.elements[i] !== null) {
                    reinterpretExpressionAsPattern(expr.elements[i]);
                }
            }
            break;
        case Syntax.ObjectExpression:
            expr.type = Syntax.ObjectPattern;
            for (i = 0; i < expr.properties.length; i++) {
                reinterpretExpressionAsPattern(expr.properties[i].value);
            }
            break;
        case Syntax.AssignmentExpression:
            expr.type = Syntax.AssignmentPattern;
            reinterpretExpressionAsPattern(expr.left);
            break;
        default:
            // Allow other node type for tolerant parsing.
            break;
        }
    }

    // ECMA-262 12.2.9 Template Literals

    function parseTemplateElement(option) {
        var node, token;

        if (lookahead.type !== Token.Template || (option.head && !lookahead.head)) {
            throwUnexpectedToken();
        }

        node = new Node();
        token = lex();

        return node.finishTemplateElement({ raw: token.value.raw, cooked: token.value.cooked }, token.tail);
    }

    function parseTemplateLiteral() {
        var quasi, quasis, expressions, node = new Node();

        quasi = parseTemplateElement({ head: true });
        quasis = [quasi];
        expressions = [];

        while (!quasi.tail) {
            expressions.push(parseExpression());
            quasi = parseTemplateElement({ head: false });
            quasis.push(quasi);
        }

        return node.finishTemplateLiteral(quasis, expressions);
    }

    // ECMA-262 12.2.10 The Grouping Operator

    function parseGroupExpression() {
        var expr, expressions, startToken, i, params = [];

        expect('(');

        if (match(')')) {
            lex();
            if (!match('=>')) {
                expect('=>');
            }
            return {
                type: PlaceHolders.ArrowParameterPlaceHolder,
                params: [],
                rawParams: []
            };
        }

        startToken = lookahead;
        if (match('...')) {
            expr = parseRestElement(params);
            expect(')');
            if (!match('=>')) {
                expect('=>');
            }
            return {
                type: PlaceHolders.ArrowParameterPlaceHolder,
                params: [expr]
            };
        }

        isBindingElement = true;
        expr = inheritCoverGrammar(parseAssignmentExpression);

        if (match(',')) {
            isAssignmentTarget = false;
            expressions = [expr];

            while (startIndex < length) {
                if (!match(',')) {
                    break;
                }
                lex();

                if (match('...')) {
                    if (!isBindingElement) {
                        throwUnexpectedToken(lookahead);
                    }
                    expressions.push(parseRestElement(params));
                    expect(')');
                    if (!match('=>')) {
                        expect('=>');
                    }
                    isBindingElement = false;
                    for (i = 0; i < expressions.length; i++) {
                        reinterpretExpressionAsPattern(expressions[i]);
                    }
                    return {
                        type: PlaceHolders.ArrowParameterPlaceHolder,
                        params: expressions
                    };
                }

                expressions.push(inheritCoverGrammar(parseAssignmentExpression));
            }

            expr = new WrappingNode(startToken).finishSequenceExpression(expressions);
        }


        expect(')');

        if (match('=>')) {
            if (expr.type === Syntax.Identifier && expr.name === 'yield') {
                return {
                    type: PlaceHolders.ArrowParameterPlaceHolder,
                    params: [expr]
                };
            }

            if (!isBindingElement) {
                throwUnexpectedToken(lookahead);
            }

            if (expr.type === Syntax.SequenceExpression) {
                for (i = 0; i < expr.expressions.length; i++) {
                    reinterpretExpressionAsPattern(expr.expressions[i]);
                }
            } else {
                reinterpretExpressionAsPattern(expr);
            }

            expr = {
                type: PlaceHolders.ArrowParameterPlaceHolder,
                params: expr.type === Syntax.SequenceExpression ? expr.expressions : [expr]
            };
        }
        isBindingElement = false;
        return expr;
    }


    // ECMA-262 12.2 Primary Expressions

    function parsePrimaryExpression() {
        var type, token, expr, node;

        if (match('(')) {
            isBindingElement = false;
            return inheritCoverGrammar(parseGroupExpression);
        }

        if (match('[')) {
            return inheritCoverGrammar(parseArrayInitializer);
        }

        if (match('{')) {
            return inheritCoverGrammar(parseObjectInitializer);
        }

        type = lookahead.type;
        node = new Node();

        if (type === Token.Identifier) {
            if (state.sourceType === 'module' && lookahead.value === 'await') {
                tolerateUnexpectedToken(lookahead);
            }
            expr = node.finishIdentifier(lex().value);
        } else if (type === Token.StringLiteral || type === Token.NumericLiteral) {
            isAssignmentTarget = isBindingElement = false;
            if (strict && lookahead.octal) {
                tolerateUnexpectedToken(lookahead, Messages.StrictOctalLiteral);
            }
            expr = node.finishLiteral(lex());
        } else if (type === Token.Keyword) {
            if (!strict && state.allowYield && matchKeyword('yield')) {
                return parseNonComputedProperty();
            }
            if (!strict && matchKeyword('let')) {
                return node.finishIdentifier(lex().value);
            }
            isAssignmentTarget = isBindingElement = false;
            if (matchKeyword('function')) {
                return parseFunctionExpression();
            }
            if (matchKeyword('this')) {
                lex();
                return node.finishThisExpression();
            }
            if (matchKeyword('class')) {
                return parseClassExpression();
            }
            throwUnexpectedToken(lex());
        } else if (type === Token.BooleanLiteral) {
            isAssignmentTarget = isBindingElement = false;
            token = lex();
            token.value = (token.value === 'true');
            expr = node.finishLiteral(token);
        } else if (type === Token.NullLiteral) {
            isAssignmentTarget = isBindingElement = false;
            token = lex();
            token.value = null;
            expr = node.finishLiteral(token);
        } else if (match('/') || match('/=')) {
            isAssignmentTarget = isBindingElement = false;
            index = startIndex;

            if (typeof extra.tokens !== 'undefined') {
                token = collectRegex();
            } else {
                token = scanRegExp();
            }
            lex();
            expr = node.finishLiteral(token);
        } else if (type === Token.Template) {
            expr = parseTemplateLiteral();
        } else {
            throwUnexpectedToken(lex());
        }

        return expr;
    }

    // ECMA-262 12.3 Left-Hand-Side Expressions

    function parseArguments() {
        var args = [], expr;

        expect('(');

        if (!match(')')) {
            while (startIndex < length) {
                if (match('...')) {
                    expr = new Node();
                    lex();
                    expr.finishSpreadElement(isolateCoverGrammar(parseAssignmentExpression));
                } else {
                    expr = isolateCoverGrammar(parseAssignmentExpression);
                }
                args.push(expr);
                if (match(')')) {
                    break;
                }
                expectCommaSeparator();
            }
        }

        expect(')');

        return args;
    }

    function parseNonComputedProperty() {
        var token, node = new Node();

        token = lex();

        if (!isIdentifierName(token)) {
            throwUnexpectedToken(token);
        }

        return node.finishIdentifier(token.value);
    }

    function parseNonComputedMember() {
        expect('.');

        return parseNonComputedProperty();
    }

    function parseComputedMember() {
        var expr;

        expect('[');

        expr = isolateCoverGrammar(parseExpression);

        expect(']');

        return expr;
    }

    // ECMA-262 12.3.3 The new Operator

    function parseNewExpression() {
        var callee, args, node = new Node();

        expectKeyword('new');

        if (match('.')) {
            lex();
            if (lookahead.type === Token.Identifier && lookahead.value === 'target') {
                if (state.inFunctionBody) {
                    lex();
                    return node.finishMetaProperty('new', 'target');
                }
            }
            throwUnexpectedToken(lookahead);
        }

        callee = isolateCoverGrammar(parseLeftHandSideExpression);
        args = match('(') ? parseArguments() : [];

        isAssignmentTarget = isBindingElement = false;

        return node.finishNewExpression(callee, args);
    }

    // ECMA-262 12.3.4 Function Calls

    function parseLeftHandSideExpressionAllowCall() {
        var quasi, expr, args, property, startToken, previousAllowIn = state.allowIn;

        startToken = lookahead;
        state.allowIn = true;

        if (matchKeyword('super') && state.inFunctionBody) {
            expr = new Node();
            lex();
            expr = expr.finishSuper();
            if (!match('(') && !match('.') && !match('[')) {
                throwUnexpectedToken(lookahead);
            }
        } else {
            expr = inheritCoverGrammar(matchKeyword('new') ? parseNewExpression : parsePrimaryExpression);
        }

        for (;;) {
            if (match('.')) {
                isBindingElement = false;
                isAssignmentTarget = true;
                property = parseNonComputedMember();
                expr = new WrappingNode(startToken).finishMemberExpression('.', expr, property);
            } else if (match('(')) {
                isBindingElement = false;
                isAssignmentTarget = false;
                args = parseArguments();
                expr = new WrappingNode(startToken).finishCallExpression(expr, args);
            } else if (match('[')) {
                isBindingElement = false;
                isAssignmentTarget = true;
                property = parseComputedMember();
                expr = new WrappingNode(startToken).finishMemberExpression('[', expr, property);
            } else if (lookahead.type === Token.Template && lookahead.head) {
                quasi = parseTemplateLiteral();
                expr = new WrappingNode(startToken).finishTaggedTemplateExpression(expr, quasi);
            } else {
                break;
            }
        }
        state.allowIn = previousAllowIn;

        return expr;
    }

    // ECMA-262 12.3 Left-Hand-Side Expressions

    function parseLeftHandSideExpression() {
        var quasi, expr, property, startToken;
        assert(state.allowIn, 'callee of new expression always allow in keyword.');

        startToken = lookahead;

        if (matchKeyword('super') && state.inFunctionBody) {
            expr = new Node();
            lex();
            expr = expr.finishSuper();
            if (!match('[') && !match('.')) {
                throwUnexpectedToken(lookahead);
            }
        } else {
            expr = inheritCoverGrammar(matchKeyword('new') ? parseNewExpression : parsePrimaryExpression);
        }

        for (;;) {
            if (match('[')) {
                isBindingElement = false;
                isAssignmentTarget = true;
                property = parseComputedMember();
                expr = new WrappingNode(startToken).finishMemberExpression('[', expr, property);
            } else if (match('.')) {
                isBindingElement = false;
                isAssignmentTarget = true;
                property = parseNonComputedMember();
                expr = new WrappingNode(startToken).finishMemberExpression('.', expr, property);
            } else if (lookahead.type === Token.Template && lookahead.head) {
                quasi = parseTemplateLiteral();
                expr = new WrappingNode(startToken).finishTaggedTemplateExpression(expr, quasi);
            } else {
                break;
            }
        }
        return expr;
    }

    // ECMA-262 12.4 Postfix Expressions

    function parsePostfixExpression() {
        var expr, token, startToken = lookahead;

        expr = inheritCoverGrammar(parseLeftHandSideExpressionAllowCall);

        if (!hasLineTerminator && lookahead.type === Token.Punctuator) {
            if (match('++') || match('--')) {
                // ECMA-262 11.3.1, 11.3.2
                if (strict && expr.type === Syntax.Identifier && isRestrictedWord(expr.name)) {
                    tolerateError(Messages.StrictLHSPostfix);
                }

                if (!isAssignmentTarget) {
                    tolerateError(Messages.InvalidLHSInAssignment);
                }

                isAssignmentTarget = isBindingElement = false;

                token = lex();
                expr = new WrappingNode(startToken).finishPostfixExpression(token.value, expr);
            }
        }

        return expr;
    }

    // ECMA-262 12.5 Unary Operators

    function parseUnaryExpression() {
        var token, expr, startToken;

        if (lookahead.type !== Token.Punctuator && lookahead.type !== Token.Keyword) {
            expr = parsePostfixExpression();
        } else if (match('++') || match('--')) {
            startToken = lookahead;
            token = lex();
            expr = inheritCoverGrammar(parseUnaryExpression);
            // ECMA-262 11.4.4, 11.4.5
            if (strict && expr.type === Syntax.Identifier && isRestrictedWord(expr.name)) {
                tolerateError(Messages.StrictLHSPrefix);
            }

            if (!isAssignmentTarget) {
                tolerateError(Messages.InvalidLHSInAssignment);
            }
            expr = new WrappingNode(startToken).finishUnaryExpression(token.value, expr);
            isAssignmentTarget = isBindingElement = false;
        } else if (match('+') || match('-') || match('~') || match('!')) {
            startToken = lookahead;
            token = lex();
            expr = inheritCoverGrammar(parseUnaryExpression);
            expr = new WrappingNode(startToken).finishUnaryExpression(token.value, expr);
            isAssignmentTarget = isBindingElement = false;
        } else if (matchKeyword('delete') || matchKeyword('void') || matchKeyword('typeof')) {
            startToken = lookahead;
            token = lex();
            expr = inheritCoverGrammar(parseUnaryExpression);
            expr = new WrappingNode(startToken).finishUnaryExpression(token.value, expr);
            if (strict && expr.operator === 'delete' && expr.argument.type === Syntax.Identifier) {
                tolerateError(Messages.StrictDelete);
            }
            isAssignmentTarget = isBindingElement = false;
        } else {
            expr = parsePostfixExpression();
        }

        return expr;
    }

    function binaryPrecedence(token, allowIn) {
        var prec = 0;

        if (token.type !== Token.Punctuator && token.type !== Token.Keyword) {
            return 0;
        }

        switch (token.value) {
        case '||':
            prec = 1;
            break;

        case '&&':
            prec = 2;
            break;

        case '|':
            prec = 3;
            break;

        case '^':
            prec = 4;
            break;

        case '&':
            prec = 5;
            break;

        case '==':
        case '!=':
        case '===':
        case '!==':
            prec = 6;
            break;

        case '<':
        case '>':
        case '<=':
        case '>=':
        case 'instanceof':
            prec = 7;
            break;

        case 'in':
            prec = allowIn ? 7 : 0;
            break;

        case '<<':
        case '>>':
        case '>>>':
            prec = 8;
            break;

        case '+':
        case '-':
            prec = 9;
            break;

        case '*':
        case '/':
        case '%':
            prec = 11;
            break;

        default:
            break;
        }

        return prec;
    }

    // ECMA-262 12.6 Multiplicative Operators
    // ECMA-262 12.7 Additive Operators
    // ECMA-262 12.8 Bitwise Shift Operators
    // ECMA-262 12.9 Relational Operators
    // ECMA-262 12.10 Equality Operators
    // ECMA-262 12.11 Binary Bitwise Operators
    // ECMA-262 12.12 Binary Logical Operators

    function parseBinaryExpression() {
        var marker, markers, expr, token, prec, stack, right, operator, left, i;

        marker = lookahead;
        left = inheritCoverGrammar(parseUnaryExpression);

        token = lookahead;
        prec = binaryPrecedence(token, state.allowIn);
        if (prec === 0) {
            return left;
        }
        isAssignmentTarget = isBindingElement = false;
        token.prec = prec;
        lex();

        markers = [marker, lookahead];
        right = isolateCoverGrammar(parseUnaryExpression);

        stack = [left, token, right];

        while ((prec = binaryPrecedence(lookahead, state.allowIn)) > 0) {

            // Reduce: make a binary expression from the three topmost entries.
            while ((stack.length > 2) && (prec <= stack[stack.length - 2].prec)) {
                right = stack.pop();
                operator = stack.pop().value;
                left = stack.pop();
                markers.pop();
                expr = new WrappingNode(markers[markers.length - 1]).finishBinaryExpression(operator, left, right);
                stack.push(expr);
            }

            // Shift.
            token = lex();
            token.prec = prec;
            stack.push(token);
            markers.push(lookahead);
            expr = isolateCoverGrammar(parseUnaryExpression);
            stack.push(expr);
        }

        // Final reduce to clean-up the stack.
        i = stack.length - 1;
        expr = stack[i];
        markers.pop();
        while (i > 1) {
            expr = new WrappingNode(markers.pop()).finishBinaryExpression(stack[i - 1].value, stack[i - 2], expr);
            i -= 2;
        }

        return expr;
    }


    // ECMA-262 12.13 Conditional Operator

    function parseConditionalExpression() {
        var expr, previousAllowIn, consequent, alternate, startToken;

        startToken = lookahead;

        expr = inheritCoverGrammar(parseBinaryExpression);
        if (match('?')) {
            lex();
            previousAllowIn = state.allowIn;
            state.allowIn = true;
            consequent = isolateCoverGrammar(parseAssignmentExpression);
            state.allowIn = previousAllowIn;
            expect(':');
            alternate = isolateCoverGrammar(parseAssignmentExpression);

            expr = new WrappingNode(startToken).finishConditionalExpression(expr, consequent, alternate);
            isAssignmentTarget = isBindingElement = false;
        }

        return expr;
    }

    // ECMA-262 14.2 Arrow Function Definitions

    function parseConciseBody() {
        if (match('{')) {
            return parseFunctionSourceElements();
        }
        return isolateCoverGrammar(parseAssignmentExpression);
    }

    function checkPatternParam(options, param) {
        var i;
        switch (param.type) {
        case Syntax.Identifier:
            validateParam(options, param, param.name);
            break;
        case Syntax.RestElement:
            checkPatternParam(options, param.argument);
            break;
        case Syntax.AssignmentPattern:
            checkPatternParam(options, param.left);
            break;
        case Syntax.ArrayPattern:
            for (i = 0; i < param.elements.length; i++) {
                if (param.elements[i] !== null) {
                    checkPatternParam(options, param.elements[i]);
                }
            }
            break;
        case Syntax.YieldExpression:
            break;
        default:
            assert(param.type === Syntax.ObjectPattern, 'Invalid type');
            for (i = 0; i < param.properties.length; i++) {
                checkPatternParam(options, param.properties[i].value);
            }
            break;
        }
    }
    function reinterpretAsCoverFormalsList(expr) {
        var i, len, param, params, defaults, defaultCount, options, token;

        defaults = [];
        defaultCount = 0;
        params = [expr];

        switch (expr.type) {
        case Syntax.Identifier:
            break;
        case PlaceHolders.ArrowParameterPlaceHolder:
            params = expr.params;
            break;
        default:
            return null;
        }

        options = {
            paramSet: {}
        };

        for (i = 0, len = params.length; i < len; i += 1) {
            param = params[i];
            switch (param.type) {
            case Syntax.AssignmentPattern:
                params[i] = param.left;
                if (param.right.type === Syntax.YieldExpression) {
                    if (param.right.argument) {
                        throwUnexpectedToken(lookahead);
                    }
                    param.right.type = Syntax.Identifier;
                    param.right.name = 'yield';
                    delete param.right.argument;
                    delete param.right.delegate;
                }
                defaults.push(param.right);
                ++defaultCount;
                checkPatternParam(options, param.left);
                break;
            default:
                checkPatternParam(options, param);
                params[i] = param;
                defaults.push(null);
                break;
            }
        }

        if (strict || !state.allowYield) {
            for (i = 0, len = params.length; i < len; i += 1) {
                param = params[i];
                if (param.type === Syntax.YieldExpression) {
                    throwUnexpectedToken(lookahead);
                }
            }
        }

        if (options.message === Messages.StrictParamDupe) {
            token = strict ? options.stricted : options.firstRestricted;
            throwUnexpectedToken(token, options.message);
        }

        if (defaultCount === 0) {
            defaults = [];
        }

        return {
            params: params,
            defaults: defaults,
            stricted: options.stricted,
            firstRestricted: options.firstRestricted,
            message: options.message
        };
    }

    function parseArrowFunctionExpression(options, node) {
        var previousStrict, previousAllowYield, body;

        if (hasLineTerminator) {
            tolerateUnexpectedToken(lookahead);
        }
        expect('=>');

        previousStrict = strict;
        previousAllowYield = state.allowYield;
        state.allowYield = true;

        body = parseConciseBody();

        if (strict && options.firstRestricted) {
            throwUnexpectedToken(options.firstRestricted, options.message);
        }
        if (strict && options.stricted) {
            tolerateUnexpectedToken(options.stricted, options.message);
        }

        strict = previousStrict;
        state.allowYield = previousAllowYield;

        return node.finishArrowFunctionExpression(options.params, options.defaults, body, body.type !== Syntax.BlockStatement);
    }

    // ECMA-262 14.4 Yield expression

    function parseYieldExpression() {
        var argument, expr, delegate, previousAllowYield;

        argument = null;
        expr = new Node();
        delegate = false;

        expectKeyword('yield');

        if (!hasLineTerminator) {
            previousAllowYield = state.allowYield;
            state.allowYield = false;
            delegate = match('*');
            if (delegate) {
                lex();
                argument = parseAssignmentExpression();
            } else {
                if (!match(';') && !match('}') && !match(')') && lookahead.type !== Token.EOF) {
                    argument = parseAssignmentExpression();
                }
            }
            state.allowYield = previousAllowYield;
        }

        return expr.finishYieldExpression(argument, delegate);
    }

    // ECMA-262 12.14 Assignment Operators

    function parseAssignmentExpression() {
        var token, expr, right, list, startToken;

        startToken = lookahead;
        token = lookahead;

        if (!state.allowYield && matchKeyword('yield')) {
            return parseYieldExpression();
        }

        expr = parseConditionalExpression();

        if (expr.type === PlaceHolders.ArrowParameterPlaceHolder || match('=>')) {
            isAssignmentTarget = isBindingElement = false;
            list = reinterpretAsCoverFormalsList(expr);

            if (list) {
                firstCoverInitializedNameError = null;
                return parseArrowFunctionExpression(list, new WrappingNode(startToken));
            }

            return expr;
        }

        if (matchAssign()) {
            if (!isAssignmentTarget) {
                tolerateError(Messages.InvalidLHSInAssignment);
            }

            // ECMA-262 12.1.1
            if (strict && expr.type === Syntax.Identifier) {
                if (isRestrictedWord(expr.name)) {
                    tolerateUnexpectedToken(token, Messages.StrictLHSAssignment);
                }
                if (isStrictModeReservedWord(expr.name)) {
                    tolerateUnexpectedToken(token, Messages.StrictReservedWord);
                }
            }

            if (!match('=')) {
                isAssignmentTarget = isBindingElement = false;
            } else {
                reinterpretExpressionAsPattern(expr);
            }

            token = lex();
            right = isolateCoverGrammar(parseAssignmentExpression);
            expr = new WrappingNode(startToken).finishAssignmentExpression(token.value, expr, right);
            firstCoverInitializedNameError = null;
        }

        return expr;
    }

    // ECMA-262 12.15 Comma Operator

    function parseExpression() {
        var expr, startToken = lookahead, expressions;

        expr = isolateCoverGrammar(parseAssignmentExpression);

        if (match(',')) {
            expressions = [expr];

            while (startIndex < length) {
                if (!match(',')) {
                    break;
                }
                lex();
                expressions.push(isolateCoverGrammar(parseAssignmentExpression));
            }

            expr = new WrappingNode(startToken).finishSequenceExpression(expressions);
        }

        return expr;
    }

    // ECMA-262 13.2 Block

    function parseStatementListItem() {
        if (lookahead.type === Token.Keyword) {
            switch (lookahead.value) {
            case 'export':
                if (state.sourceType !== 'module') {
                    tolerateUnexpectedToken(lookahead, Messages.IllegalExportDeclaration);
                }
                return parseExportDeclaration();
            case 'import':
                if (state.sourceType !== 'module') {
                    tolerateUnexpectedToken(lookahead, Messages.IllegalImportDeclaration);
                }
                return parseImportDeclaration();
            case 'const':
                return parseLexicalDeclaration({inFor: false});
            case 'function':
                return parseFunctionDeclaration(new Node());
            case 'class':
                return parseClassDeclaration();
            }
        }

        if (matchKeyword('let') && isLexicalDeclaration()) {
            return parseLexicalDeclaration({inFor: false});
        }

        return parseStatement();
    }

    function parseStatementList() {
        var list = [];
        while (startIndex < length) {
            if (match('}')) {
                break;
            }
            list.push(parseStatementListItem());
        }

        return list;
    }

    function parseBlock() {
        var block, node = new Node();

        expect('{');

        block = parseStatementList();

        expect('}');

        return node.finishBlockStatement(block);
    }

    // ECMA-262 13.3.2 Variable Statement

    function parseVariableIdentifier(kind) {
        var token, node = new Node();

        token = lex();

        if (token.type === Token.Keyword && token.value === 'yield') {
            if (strict) {
                tolerateUnexpectedToken(token, Messages.StrictReservedWord);
            } if (!state.allowYield) {
                throwUnexpectedToken(token);
            }
        } else if (token.type !== Token.Identifier) {
            if (strict && token.type === Token.Keyword && isStrictModeReservedWord(token.value)) {
                tolerateUnexpectedToken(token, Messages.StrictReservedWord);
            } else {
                if (strict || token.value !== 'let' || kind !== 'var') {
                    throwUnexpectedToken(token);
                }
            }
        } else if (state.sourceType === 'module' && token.type === Token.Identifier && token.value === 'await') {
            tolerateUnexpectedToken(token);
        }

        return node.finishIdentifier(token.value);
    }

    function parseVariableDeclaration(options) {
        var init = null, id, node = new Node(), params = [];

        id = parsePattern(params, 'var');

        // ECMA-262 12.2.1
        if (strict && isRestrictedWord(id.name)) {
            tolerateError(Messages.StrictVarName);
        }

        if (match('=')) {
            lex();
            init = isolateCoverGrammar(parseAssignmentExpression);
        } else if (id.type !== Syntax.Identifier && !options.inFor) {
            expect('=');
        }

        return node.finishVariableDeclarator(id, init);
    }

    function parseVariableDeclarationList(options) {
        var opt, list;

        opt = { inFor: options.inFor };
        list = [parseVariableDeclaration(opt)];

        while (match(',')) {
            lex();
            list.push(parseVariableDeclaration(opt));
        }

        return list;
    }

    function parseVariableStatement(node) {
        var declarations;

        expectKeyword('var');

        declarations = parseVariableDeclarationList({ inFor: false });

        consumeSemicolon();

        return node.finishVariableDeclaration(declarations);
    }

    // ECMA-262 13.3.1 Let and Const Declarations

    function parseLexicalBinding(kind, options) {
        var init = null, id, node = new Node(), params = [];

        id = parsePattern(params, kind);

        // ECMA-262 12.2.1
        if (strict && id.type === Syntax.Identifier && isRestrictedWord(id.name)) {
            tolerateError(Messages.StrictVarName);
        }

        if (kind === 'const') {
            if (!matchKeyword('in') && !matchContextualKeyword('of')) {
                expect('=');
                init = isolateCoverGrammar(parseAssignmentExpression);
            }
        } else if ((!options.inFor && id.type !== Syntax.Identifier) || match('=')) {
            expect('=');
            init = isolateCoverGrammar(parseAssignmentExpression);
        }

        return node.finishVariableDeclarator(id, init);
    }

    function parseBindingList(kind, options) {
        var list = [parseLexicalBinding(kind, options)];

        while (match(',')) {
            lex();
            list.push(parseLexicalBinding(kind, options));
        }

        return list;
    }


    function tokenizerState() {
        return {
            index: index,
            lineNumber: lineNumber,
            lineStart: lineStart,
            hasLineTerminator: hasLineTerminator,
            lastIndex: lastIndex,
            lastLineNumber: lastLineNumber,
            lastLineStart: lastLineStart,
            startIndex: startIndex,
            startLineNumber: startLineNumber,
            startLineStart: startLineStart,
            lookahead: lookahead,
            tokenCount: extra.tokens ? extra.tokens.length : 0
        };
    }

    function resetTokenizerState(ts) {
        index = ts.index;
        lineNumber = ts.lineNumber;
        lineStart = ts.lineStart;
        hasLineTerminator = ts.hasLineTerminator;
        lastIndex = ts.lastIndex;
        lastLineNumber = ts.lastLineNumber;
        lastLineStart = ts.lastLineStart;
        startIndex = ts.startIndex;
        startLineNumber = ts.startLineNumber;
        startLineStart = ts.startLineStart;
        lookahead = ts.lookahead;
        if (extra.tokens) {
            extra.tokens.splice(ts.tokenCount, extra.tokens.length);
        }
    }

    function isLexicalDeclaration() {
        var lexical, ts;

        ts = tokenizerState();

        lex();
        lexical = (lookahead.type === Token.Identifier) || match('[') || match('{') ||
            matchKeyword('let') || matchKeyword('yield');

        resetTokenizerState(ts);

        return lexical;
    }

    function parseLexicalDeclaration(options) {
        var kind, declarations, node = new Node();

        kind = lex().value;
        assert(kind === 'let' || kind === 'const', 'Lexical declaration must be either let or const');

        declarations = parseBindingList(kind, options);

        consumeSemicolon();

        return node.finishLexicalDeclaration(declarations, kind);
    }

    function parseRestElement(params) {
        var param, node = new Node();

        lex();

        if (match('{')) {
            throwError(Messages.ObjectPatternAsRestParameter);
        }

        params.push(lookahead);

        param = parseVariableIdentifier();

        if (match('=')) {
            throwError(Messages.DefaultRestParameter);
        }

        if (!match(')')) {
            throwError(Messages.ParameterAfterRestParameter);
        }

        return node.finishRestElement(param);
    }

    // ECMA-262 13.4 Empty Statement

    function parseEmptyStatement(node) {
        expect(';');
        return node.finishEmptyStatement();
    }

    // ECMA-262 12.4 Expression Statement

    function parseExpressionStatement(node) {
        var expr = parseExpression();
        consumeSemicolon();
        return node.finishExpressionStatement(expr);
    }

    // ECMA-262 13.6 If statement

    function parseIfStatement(node) {
        var test, consequent, alternate;

        expectKeyword('if');

        expect('(');

        test = parseExpression();

        expect(')');

        consequent = parseStatement();

        if (matchKeyword('else')) {
            lex();
            alternate = parseStatement();
        } else {
            alternate = null;
        }

        return node.finishIfStatement(test, consequent, alternate);
    }

    // ECMA-262 13.7 Iteration Statements

    function parseDoWhileStatement(node) {
        var body, test, oldInIteration;

        expectKeyword('do');

        oldInIteration = state.inIteration;
        state.inIteration = true;

        body = parseStatement();

        state.inIteration = oldInIteration;

        expectKeyword('while');

        expect('(');

        test = parseExpression();

        expect(')');

        if (match(';')) {
            lex();
        }

        return node.finishDoWhileStatement(body, test);
    }

    function parseWhileStatement(node) {
        var test, body, oldInIteration;

        expectKeyword('while');

        expect('(');

        test = parseExpression();

        expect(')');

        oldInIteration = state.inIteration;
        state.inIteration = true;

        body = parseStatement();

        state.inIteration = oldInIteration;

        return node.finishWhileStatement(test, body);
    }

    function parseForStatement(node) {
        var init, forIn, initSeq, initStartToken, test, update, left, right, kind, declarations,
            body, oldInIteration, previousAllowIn = state.allowIn;

        init = test = update = null;
        forIn = true;

        expectKeyword('for');

        expect('(');

        if (match(';')) {
            lex();
        } else {
            if (matchKeyword('var')) {
                init = new Node();
                lex();

                state.allowIn = false;
                declarations = parseVariableDeclarationList({ inFor: true });
                state.allowIn = previousAllowIn;

                if (declarations.length === 1 && matchKeyword('in')) {
                    init = init.finishVariableDeclaration(declarations);
                    lex();
                    left = init;
                    right = parseExpression();
                    init = null;
                } else if (declarations.length === 1 && declarations[0].init === null && matchContextualKeyword('of')) {
                    init = init.finishVariableDeclaration(declarations);
                    lex();
                    left = init;
                    right = parseAssignmentExpression();
                    init = null;
                    forIn = false;
                } else {
                    init = init.finishVariableDeclaration(declarations);
                    expect(';');
                }
            } else if (matchKeyword('const') || matchKeyword('let')) {
                init = new Node();
                kind = lex().value;

                if (!strict && lookahead.value === 'in') {
                    init = init.finishIdentifier(kind);
                    lex();
                    left = init;
                    right = parseExpression();
                    init = null;
                } else {
                    state.allowIn = false;
                    declarations = parseBindingList(kind, {inFor: true});
                    state.allowIn = previousAllowIn;

                    if (declarations.length === 1 && declarations[0].init === null && matchKeyword('in')) {
                        init = init.finishLexicalDeclaration(declarations, kind);
                        lex();
                        left = init;
                        right = parseExpression();
                        init = null;
                    } else if (declarations.length === 1 && declarations[0].init === null && matchContextualKeyword('of')) {
                        init = init.finishLexicalDeclaration(declarations, kind);
                        lex();
                        left = init;
                        right = parseAssignmentExpression();
                        init = null;
                        forIn = false;
                    } else {
                        consumeSemicolon();
                        init = init.finishLexicalDeclaration(declarations, kind);
                    }
                }
            } else {
                initStartToken = lookahead;
                state.allowIn = false;
                init = inheritCoverGrammar(parseAssignmentExpression);
                state.allowIn = previousAllowIn;

                if (matchKeyword('in')) {
                    if (!isAssignmentTarget) {
                        tolerateError(Messages.InvalidLHSInForIn);
                    }

                    lex();
                    reinterpretExpressionAsPattern(init);
                    left = init;
                    right = parseExpression();
                    init = null;
                } else if (matchContextualKeyword('of')) {
                    if (!isAssignmentTarget) {
                        tolerateError(Messages.InvalidLHSInForLoop);
                    }

                    lex();
                    reinterpretExpressionAsPattern(init);
                    left = init;
                    right = parseAssignmentExpression();
                    init = null;
                    forIn = false;
                } else {
                    if (match(',')) {
                        initSeq = [init];
                        while (match(',')) {
                            lex();
                            initSeq.push(isolateCoverGrammar(parseAssignmentExpression));
                        }
                        init = new WrappingNode(initStartToken).finishSequenceExpression(initSeq);
                    }
                    expect(';');
                }
            }
        }

        if (typeof left === 'undefined') {

            if (!match(';')) {
                test = parseExpression();
            }
            expect(';');

            if (!match(')')) {
                update = parseExpression();
            }
        }

        expect(')');

        oldInIteration = state.inIteration;
        state.inIteration = true;

        body = isolateCoverGrammar(parseStatement);

        state.inIteration = oldInIteration;

        return (typeof left === 'undefined') ?
                node.finishForStatement(init, test, update, body) :
                forIn ? node.finishForInStatement(left, right, body) :
                    node.finishForOfStatement(left, right, body);
    }

    // ECMA-262 13.8 The continue statement

    function parseContinueStatement(node) {
        var label = null, key;

        expectKeyword('continue');

        // Optimize the most common form: 'continue;'.
        if (source.charCodeAt(startIndex) === 0x3B) {
            lex();

            if (!state.inIteration) {
                throwError(Messages.IllegalContinue);
            }

            return node.finishContinueStatement(null);
        }

        if (hasLineTerminator) {
            if (!state.inIteration) {
                throwError(Messages.IllegalContinue);
            }

            return node.finishContinueStatement(null);
        }

        if (lookahead.type === Token.Identifier) {
            label = parseVariableIdentifier();

            key = '$' + label.name;
            if (!Object.prototype.hasOwnProperty.call(state.labelSet, key)) {
                throwError(Messages.UnknownLabel, label.name);
            }
        }

        consumeSemicolon();

        if (label === null && !state.inIteration) {
            throwError(Messages.IllegalContinue);
        }

        return node.finishContinueStatement(label);
    }

    // ECMA-262 13.9 The break statement

    function parseBreakStatement(node) {
        var label = null, key;

        expectKeyword('break');

        // Catch the very common case first: immediately a semicolon (U+003B).
        if (source.charCodeAt(lastIndex) === 0x3B) {
            lex();

            if (!(state.inIteration || state.inSwitch)) {
                throwError(Messages.IllegalBreak);
            }

            return node.finishBreakStatement(null);
        }

        if (hasLineTerminator) {
            if (!(state.inIteration || state.inSwitch)) {
                throwError(Messages.IllegalBreak);
            }
        } else if (lookahead.type === Token.Identifier) {
            label = parseVariableIdentifier();

            key = '$' + label.name;
            if (!Object.prototype.hasOwnProperty.call(state.labelSet, key)) {
                throwError(Messages.UnknownLabel, label.name);
            }
        }

        consumeSemicolon();

        if (label === null && !(state.inIteration || state.inSwitch)) {
            throwError(Messages.IllegalBreak);
        }

        return node.finishBreakStatement(label);
    }

    // ECMA-262 13.10 The return statement

    function parseReturnStatement(node) {
        var argument = null;

        expectKeyword('return');

        if (!state.inFunctionBody) {
            tolerateError(Messages.IllegalReturn);
        }

        // 'return' followed by a space and an identifier is very common.
        if (source.charCodeAt(lastIndex) === 0x20) {
            if (isIdentifierStart(source.charCodeAt(lastIndex + 1))) {
                argument = parseExpression();
                consumeSemicolon();
                return node.finishReturnStatement(argument);
            }
        }

        if (hasLineTerminator) {
            // HACK
            return node.finishReturnStatement(null);
        }

        if (!match(';')) {
            if (!match('}') && lookahead.type !== Token.EOF) {
                argument = parseExpression();
            }
        }

        consumeSemicolon();

        return node.finishReturnStatement(argument);
    }

    // ECMA-262 13.11 The with statement

    function parseWithStatement(node) {
        var object, body;

        if (strict) {
            tolerateError(Messages.StrictModeWith);
        }

        expectKeyword('with');

        expect('(');

        object = parseExpression();

        expect(')');

        body = parseStatement();

        return node.finishWithStatement(object, body);
    }

    // ECMA-262 13.12 The switch statement

    function parseSwitchCase() {
        var test, consequent = [], statement, node = new Node();

        if (matchKeyword('default')) {
            lex();
            test = null;
        } else {
            expectKeyword('case');
            test = parseExpression();
        }
        expect(':');

        while (startIndex < length) {
            if (match('}') || matchKeyword('default') || matchKeyword('case')) {
                break;
            }
            statement = parseStatementListItem();
            consequent.push(statement);
        }

        return node.finishSwitchCase(test, consequent);
    }

    function parseSwitchStatement(node) {
        var discriminant, cases, clause, oldInSwitch, defaultFound;

        expectKeyword('switch');

        expect('(');

        discriminant = parseExpression();

        expect(')');

        expect('{');

        cases = [];

        if (match('}')) {
            lex();
            return node.finishSwitchStatement(discriminant, cases);
        }

        oldInSwitch = state.inSwitch;
        state.inSwitch = true;
        defaultFound = false;

        while (startIndex < length) {
            if (match('}')) {
                break;
            }
            clause = parseSwitchCase();
            if (clause.test === null) {
                if (defaultFound) {
                    throwError(Messages.MultipleDefaultsInSwitch);
                }
                defaultFound = true;
            }
            cases.push(clause);
        }

        state.inSwitch = oldInSwitch;

        expect('}');

        return node.finishSwitchStatement(discriminant, cases);
    }

    // ECMA-262 13.14 The throw statement

    function parseThrowStatement(node) {
        var argument;

        expectKeyword('throw');

        if (hasLineTerminator) {
            throwError(Messages.NewlineAfterThrow);
        }

        argument = parseExpression();

        consumeSemicolon();

        return node.finishThrowStatement(argument);
    }

    // ECMA-262 13.15 The try statement

    function parseCatchClause() {
        var param, params = [], paramMap = {}, key, i, body, node = new Node();

        expectKeyword('catch');

        expect('(');
        if (match(')')) {
            throwUnexpectedToken(lookahead);
        }

        param = parsePattern(params);
        for (i = 0; i < params.length; i++) {
            key = '$' + params[i].value;
            if (Object.prototype.hasOwnProperty.call(paramMap, key)) {
                tolerateError(Messages.DuplicateBinding, params[i].value);
            }
            paramMap[key] = true;
        }

        // ECMA-262 12.14.1
        if (strict && isRestrictedWord(param.name)) {
            tolerateError(Messages.StrictCatchVariable);
        }

        expect(')');
        body = parseBlock();
        return node.finishCatchClause(param, body);
    }

    function parseTryStatement(node) {
        var block, handler = null, finalizer = null;

        expectKeyword('try');

        block = parseBlock();

        if (matchKeyword('catch')) {
            handler = parseCatchClause();
        }

        if (matchKeyword('finally')) {
            lex();
            finalizer = parseBlock();
        }

        if (!handler && !finalizer) {
            throwError(Messages.NoCatchOrFinally);
        }

        return node.finishTryStatement(block, handler, finalizer);
    }

    // ECMA-262 13.16 The debugger statement

    function parseDebuggerStatement(node) {
        expectKeyword('debugger');

        consumeSemicolon();

        return node.finishDebuggerStatement();
    }

    // 13 Statements

    function parseStatement() {
        var type = lookahead.type,
            expr,
            labeledBody,
            key,
            node;

        if (type === Token.EOF) {
            throwUnexpectedToken(lookahead);
        }

        if (type === Token.Punctuator && lookahead.value === '{') {
            return parseBlock();
        }
        isAssignmentTarget = isBindingElement = true;
        node = new Node();

        if (type === Token.Punctuator) {
            switch (lookahead.value) {
            case ';':
                return parseEmptyStatement(node);
            case '(':
                return parseExpressionStatement(node);
            default:
                break;
            }
        } else if (type === Token.Keyword) {
            switch (lookahead.value) {
            case 'break':
                return parseBreakStatement(node);
            case 'continue':
                return parseContinueStatement(node);
            case 'debugger':
                return parseDebuggerStatement(node);
            case 'do':
                return parseDoWhileStatement(node);
            case 'for':
                return parseForStatement(node);
            case 'function':
                return parseFunctionDeclaration(node);
            case 'if':
                return parseIfStatement(node);
            case 'return':
                return parseReturnStatement(node);
            case 'switch':
                return parseSwitchStatement(node);
            case 'throw':
                return parseThrowStatement(node);
            case 'try':
                return parseTryStatement(node);
            case 'var':
                return parseVariableStatement(node);
            case 'while':
                return parseWhileStatement(node);
            case 'with':
                return parseWithStatement(node);
            default:
                break;
            }
        }

        expr = parseExpression();

        // ECMA-262 12.12 Labelled Statements
        if ((expr.type === Syntax.Identifier) && match(':')) {
            lex();

            key = '$' + expr.name;
            if (Object.prototype.hasOwnProperty.call(state.labelSet, key)) {
                throwError(Messages.Redeclaration, 'Label', expr.name);
            }

            state.labelSet[key] = true;
            labeledBody = parseStatement();
            delete state.labelSet[key];
            return node.finishLabeledStatement(expr, labeledBody);
        }

        consumeSemicolon();

        return node.finishExpressionStatement(expr);
    }

    // ECMA-262 14.1 Function Definition

    function parseFunctionSourceElements() {
        var statement, body = [], token, directive, firstRestricted,
            oldLabelSet, oldInIteration, oldInSwitch, oldInFunctionBody, oldParenthesisCount,
            node = new Node();

        expect('{');

        while (startIndex < length) {
            if (lookahead.type !== Token.StringLiteral) {
                break;
            }
            token = lookahead;

            statement = parseStatementListItem();
            body.push(statement);
            if (statement.expression.type !== Syntax.Literal) {
                // this is not directive
                break;
            }
            directive = source.slice(token.start + 1, token.end - 1);
            if (directive === 'use strict') {
                strict = true;
                if (firstRestricted) {
                    tolerateUnexpectedToken(firstRestricted, Messages.StrictOctalLiteral);
                }
            } else {
                if (!firstRestricted && token.octal) {
                    firstRestricted = token;
                }
            }
        }

        oldLabelSet = state.labelSet;
        oldInIteration = state.inIteration;
        oldInSwitch = state.inSwitch;
        oldInFunctionBody = state.inFunctionBody;
        oldParenthesisCount = state.parenthesizedCount;

        state.labelSet = {};
        state.inIteration = false;
        state.inSwitch = false;
        state.inFunctionBody = true;
        state.parenthesizedCount = 0;

        while (startIndex < length) {
            if (match('}')) {
                break;
            }
            body.push(parseStatementListItem());
        }

        expect('}');

        state.labelSet = oldLabelSet;
        state.inIteration = oldInIteration;
        state.inSwitch = oldInSwitch;
        state.inFunctionBody = oldInFunctionBody;
        state.parenthesizedCount = oldParenthesisCount;

        return node.finishBlockStatement(body);
    }

    function validateParam(options, param, name) {
        var key = '$' + name;
        if (strict) {
            if (isRestrictedWord(name)) {
                options.stricted = param;
                options.message = Messages.StrictParamName;
            }
            if (Object.prototype.hasOwnProperty.call(options.paramSet, key)) {
                options.stricted = param;
                options.message = Messages.StrictParamDupe;
            }
        } else if (!options.firstRestricted) {
            if (isRestrictedWord(name)) {
                options.firstRestricted = param;
                options.message = Messages.StrictParamName;
            } else if (isStrictModeReservedWord(name)) {
                options.firstRestricted = param;
                options.message = Messages.StrictReservedWord;
            } else if (Object.prototype.hasOwnProperty.call(options.paramSet, key)) {
                options.stricted = param;
                options.message = Messages.StrictParamDupe;
            }
        }
        options.paramSet[key] = true;
    }

    function parseParam(options) {
        var token, param, params = [], i, def;

        token = lookahead;
        if (token.value === '...') {
            param = parseRestElement(params);
            validateParam(options, param.argument, param.argument.name);
            options.params.push(param);
            options.defaults.push(null);
            return false;
        }

        param = parsePatternWithDefault(params);
        for (i = 0; i < params.length; i++) {
            validateParam(options, params[i], params[i].value);
        }

        if (param.type === Syntax.AssignmentPattern) {
            def = param.right;
            param = param.left;
            ++options.defaultCount;
        }

        options.params.push(param);
        options.defaults.push(def);

        return !match(')');
    }

    function parseParams(firstRestricted) {
        var options;

        options = {
            params: [],
            defaultCount: 0,
            defaults: [],
            firstRestricted: firstRestricted
        };

        expect('(');

        if (!match(')')) {
            options.paramSet = {};
            while (startIndex < length) {
                if (!parseParam(options)) {
                    break;
                }
                expect(',');
            }
        }

        expect(')');

        if (options.defaultCount === 0) {
            options.defaults = [];
        }

        return {
            params: options.params,
            defaults: options.defaults,
            stricted: options.stricted,
            firstRestricted: options.firstRestricted,
            message: options.message
        };
    }

    function parseFunctionDeclaration(node, identifierIsOptional) {
        var id = null, params = [], defaults = [], body, token, stricted, tmp, firstRestricted, message, previousStrict,
            isGenerator, previousAllowYield;

        previousAllowYield = state.allowYield;

        expectKeyword('function');

        isGenerator = match('*');
        if (isGenerator) {
            lex();
        }

        if (!identifierIsOptional || !match('(')) {
            token = lookahead;
            id = parseVariableIdentifier();
            if (strict) {
                if (isRestrictedWord(token.value)) {
                    tolerateUnexpectedToken(token, Messages.StrictFunctionName);
                }
            } else {
                if (isRestrictedWord(token.value)) {
                    firstRestricted = token;
                    message = Messages.StrictFunctionName;
                } else if (isStrictModeReservedWord(token.value)) {
                    firstRestricted = token;
                    message = Messages.StrictReservedWord;
                }
            }
        }

        state.allowYield = !isGenerator;
        tmp = parseParams(firstRestricted);
        params = tmp.params;
        defaults = tmp.defaults;
        stricted = tmp.stricted;
        firstRestricted = tmp.firstRestricted;
        if (tmp.message) {
            message = tmp.message;
        }


        previousStrict = strict;
        body = parseFunctionSourceElements();
        if (strict && firstRestricted) {
            throwUnexpectedToken(firstRestricted, message);
        }
        if (strict && stricted) {
            tolerateUnexpectedToken(stricted, message);
        }

        strict = previousStrict;
        state.allowYield = previousAllowYield;

        return node.finishFunctionDeclaration(id, params, defaults, body, isGenerator);
    }

    function parseFunctionExpression() {
        var token, id = null, stricted, firstRestricted, message, tmp,
            params = [], defaults = [], body, previousStrict, node = new Node(),
            isGenerator, previousAllowYield;

        previousAllowYield = state.allowYield;

        expectKeyword('function');

        isGenerator = match('*');
        if (isGenerator) {
            lex();
        }

        state.allowYield = !isGenerator;
        if (!match('(')) {
            token = lookahead;
            id = (!strict && !isGenerator && matchKeyword('yield')) ? parseNonComputedProperty() : parseVariableIdentifier();
            if (strict) {
                if (isRestrictedWord(token.value)) {
                    tolerateUnexpectedToken(token, Messages.StrictFunctionName);
                }
            } else {
                if (isRestrictedWord(token.value)) {
                    firstRestricted = token;
                    message = Messages.StrictFunctionName;
                } else if (isStrictModeReservedWord(token.value)) {
                    firstRestricted = token;
                    message = Messages.StrictReservedWord;
                }
            }
        }

        tmp = parseParams(firstRestricted);
        params = tmp.params;
        defaults = tmp.defaults;
        stricted = tmp.stricted;
        firstRestricted = tmp.firstRestricted;
        if (tmp.message) {
            message = tmp.message;
        }

        previousStrict = strict;
        body = parseFunctionSourceElements();
        if (strict && firstRestricted) {
            throwUnexpectedToken(firstRestricted, message);
        }
        if (strict && stricted) {
            tolerateUnexpectedToken(stricted, message);
        }
        strict = previousStrict;
        state.allowYield = previousAllowYield;

        return node.finishFunctionExpression(id, params, defaults, body, isGenerator);
    }

    // ECMA-262 14.5 Class Definitions

    function parseClassBody() {
        var classBody, token, isStatic, hasConstructor = false, body, method, computed, key;

        classBody = new Node();

        expect('{');
        body = [];
        while (!match('}')) {
            if (match(';')) {
                lex();
            } else {
                method = new Node();
                token = lookahead;
                isStatic = false;
                computed = match('[');
                if (match('*')) {
                    lex();
                } else {
                    key = parseObjectPropertyKey();
                    if (key.name === 'static' && (lookaheadPropertyName() || match('*'))) {
                        token = lookahead;
                        isStatic = true;
                        computed = match('[');
                        if (match('*')) {
                            lex();
                        } else {
                            key = parseObjectPropertyKey();
                        }
                    }
                }
                method = tryParseMethodDefinition(token, key, computed, method);
                if (method) {
                    method['static'] = isStatic; // jscs:ignore requireDotNotation
                    if (method.kind === 'init') {
                        method.kind = 'method';
                    }
                    if (!isStatic) {
                        if (!method.computed && (method.key.name || method.key.value.toString()) === 'constructor') {
                            if (method.kind !== 'method' || !method.method || method.value.generator) {
                                throwUnexpectedToken(token, Messages.ConstructorSpecialMethod);
                            }
                            if (hasConstructor) {
                                throwUnexpectedToken(token, Messages.DuplicateConstructor);
                            } else {
                                hasConstructor = true;
                            }
                            method.kind = 'constructor';
                        }
                    } else {
                        if (!method.computed && (method.key.name || method.key.value.toString()) === 'prototype') {
                            throwUnexpectedToken(token, Messages.StaticPrototype);
                        }
                    }
                    method.type = Syntax.MethodDefinition;
                    delete method.method;
                    delete method.shorthand;
                    body.push(method);
                } else {
                    throwUnexpectedToken(lookahead);
                }
            }
        }
        lex();
        return classBody.finishClassBody(body);
    }

    function parseClassDeclaration(identifierIsOptional) {
        var id = null, superClass = null, classNode = new Node(), classBody, previousStrict = strict;
        strict = true;

        expectKeyword('class');

        if (!identifierIsOptional || lookahead.type === Token.Identifier) {
            id = parseVariableIdentifier();
        }

        if (matchKeyword('extends')) {
            lex();
            superClass = isolateCoverGrammar(parseLeftHandSideExpressionAllowCall);
        }
        classBody = parseClassBody();
        strict = previousStrict;

        return classNode.finishClassDeclaration(id, superClass, classBody);
    }

    function parseClassExpression() {
        var id = null, superClass = null, classNode = new Node(), classBody, previousStrict = strict;
        strict = true;

        expectKeyword('class');

        if (lookahead.type === Token.Identifier) {
            id = parseVariableIdentifier();
        }

        if (matchKeyword('extends')) {
            lex();
            superClass = isolateCoverGrammar(parseLeftHandSideExpressionAllowCall);
        }
        classBody = parseClassBody();
        strict = previousStrict;

        return classNode.finishClassExpression(id, superClass, classBody);
    }

    // ECMA-262 15.2 Modules

    function parseModuleSpecifier() {
        var node = new Node();

        if (lookahead.type !== Token.StringLiteral) {
            throwError(Messages.InvalidModuleSpecifier);
        }
        return node.finishLiteral(lex());
    }

    // ECMA-262 15.2.3 Exports

    function parseExportSpecifier() {
        var exported, local, node = new Node(), def;
        if (matchKeyword('default')) {
            // export {default} from 'something';
            def = new Node();
            lex();
            local = def.finishIdentifier('default');
        } else {
            local = parseVariableIdentifier();
        }
        if (matchContextualKeyword('as')) {
            lex();
            exported = parseNonComputedProperty();
        }
        return node.finishExportSpecifier(local, exported);
    }

    function parseExportNamedDeclaration(node) {
        var declaration = null,
            isExportFromIdentifier,
            src = null, specifiers = [];

        // non-default export
        if (lookahead.type === Token.Keyword) {
            // covers:
            // export var f = 1;
            switch (lookahead.value) {
                case 'let':
                case 'const':
                    declaration = parseLexicalDeclaration({inFor: false});
                    return node.finishExportNamedDeclaration(declaration, specifiers, null);
                case 'var':
                case 'class':
                case 'function':
                    declaration = parseStatementListItem();
                    return node.finishExportNamedDeclaration(declaration, specifiers, null);
            }
        }

        expect('{');
        while (!match('}')) {
            isExportFromIdentifier = isExportFromIdentifier || matchKeyword('default');
            specifiers.push(parseExportSpecifier());
            if (!match('}')) {
                expect(',');
                if (match('}')) {
                    break;
                }
            }
        }
        expect('}');

        if (matchContextualKeyword('from')) {
            // covering:
            // export {default} from 'foo';
            // export {foo} from 'foo';
            lex();
            src = parseModuleSpecifier();
            consumeSemicolon();
        } else if (isExportFromIdentifier) {
            // covering:
            // export {default}; // missing fromClause
            throwError(lookahead.value ?
                    Messages.UnexpectedToken : Messages.MissingFromClause, lookahead.value);
        } else {
            // cover
            // export {foo};
            consumeSemicolon();
        }
        return node.finishExportNamedDeclaration(declaration, specifiers, src);
    }

    function parseExportDefaultDeclaration(node) {
        var declaration = null,
            expression = null;

        // covers:
        // export default ...
        expectKeyword('default');

        if (matchKeyword('function')) {
            // covers:
            // export default function foo () {}
            // export default function () {}
            declaration = parseFunctionDeclaration(new Node(), true);
            return node.finishExportDefaultDeclaration(declaration);
        }
        if (matchKeyword('class')) {
            declaration = parseClassDeclaration(true);
            return node.finishExportDefaultDeclaration(declaration);
        }

        if (matchContextualKeyword('from')) {
            throwError(Messages.UnexpectedToken, lookahead.value);
        }

        // covers:
        // export default {};
        // export default [];
        // export default (1 + 2);
        if (match('{')) {
            expression = parseObjectInitializer();
        } else if (match('[')) {
            expression = parseArrayInitializer();
        } else {
            expression = parseAssignmentExpression();
        }
        consumeSemicolon();
        return node.finishExportDefaultDeclaration(expression);
    }

    function parseExportAllDeclaration(node) {
        var src;

        // covers:
        // export * from 'foo';
        expect('*');
        if (!matchContextualKeyword('from')) {
            throwError(lookahead.value ?
                    Messages.UnexpectedToken : Messages.MissingFromClause, lookahead.value);
        }
        lex();
        src = parseModuleSpecifier();
        consumeSemicolon();

        return node.finishExportAllDeclaration(src);
    }

    function parseExportDeclaration() {
        var node = new Node();
        if (state.inFunctionBody) {
            throwError(Messages.IllegalExportDeclaration);
        }

        expectKeyword('export');

        if (matchKeyword('default')) {
            return parseExportDefaultDeclaration(node);
        }
        if (match('*')) {
            return parseExportAllDeclaration(node);
        }
        return parseExportNamedDeclaration(node);
    }

    // ECMA-262 15.2.2 Imports

    function parseImportSpecifier() {
        // import {<foo as bar>} ...;
        var local, imported, node = new Node();

        imported = parseNonComputedProperty();
        if (matchContextualKeyword('as')) {
            lex();
            local = parseVariableIdentifier();
        }

        return node.finishImportSpecifier(local, imported);
    }

    function parseNamedImports() {
        var specifiers = [];
        // {foo, bar as bas}
        expect('{');
        while (!match('}')) {
            specifiers.push(parseImportSpecifier());
            if (!match('}')) {
                expect(',');
                if (match('}')) {
                    break;
                }
            }
        }
        expect('}');
        return specifiers;
    }

    function parseImportDefaultSpecifier() {
        // import <foo> ...;
        var local, node = new Node();

        local = parseNonComputedProperty();

        return node.finishImportDefaultSpecifier(local);
    }

    function parseImportNamespaceSpecifier() {
        // import <* as foo> ...;
        var local, node = new Node();

        expect('*');
        if (!matchContextualKeyword('as')) {
            throwError(Messages.NoAsAfterImportNamespace);
        }
        lex();
        local = parseNonComputedProperty();

        return node.finishImportNamespaceSpecifier(local);
    }

    function parseImportDeclaration() {
        var specifiers = [], src, node = new Node();

        if (state.inFunctionBody) {
            throwError(Messages.IllegalImportDeclaration);
        }

        expectKeyword('import');

        if (lookahead.type === Token.StringLiteral) {
            // import 'foo';
            src = parseModuleSpecifier();
        } else {

            if (match('{')) {
                // import {bar}
                specifiers = specifiers.concat(parseNamedImports());
            } else if (match('*')) {
                // import * as foo
                specifiers.push(parseImportNamespaceSpecifier());
            } else if (isIdentifierName(lookahead) && !matchKeyword('default')) {
                // import foo
                specifiers.push(parseImportDefaultSpecifier());
                if (match(',')) {
                    lex();
                    if (match('*')) {
                        // import foo, * as foo
                        specifiers.push(parseImportNamespaceSpecifier());
                    } else if (match('{')) {
                        // import foo, {bar}
                        specifiers = specifiers.concat(parseNamedImports());
                    } else {
                        throwUnexpectedToken(lookahead);
                    }
                }
            } else {
                throwUnexpectedToken(lex());
            }

            if (!matchContextualKeyword('from')) {
                throwError(lookahead.value ?
                        Messages.UnexpectedToken : Messages.MissingFromClause, lookahead.value);
            }
            lex();
            src = parseModuleSpecifier();
        }

        consumeSemicolon();
        return node.finishImportDeclaration(specifiers, src);
    }

    // ECMA-262 15.1 Scripts

    function parseScriptBody() {
        var statement, body = [], token, directive, firstRestricted;

        while (startIndex < length) {
            token = lookahead;
            if (token.type !== Token.StringLiteral) {
                break;
            }

            statement = parseStatementListItem();
            body.push(statement);
            if (statement.expression.type !== Syntax.Literal) {
                // this is not directive
                break;
            }
            directive = source.slice(token.start + 1, token.end - 1);
            if (directive === 'use strict') {
                strict = true;
                if (firstRestricted) {
                    tolerateUnexpectedToken(firstRestricted, Messages.StrictOctalLiteral);
                }
            } else {
                if (!firstRestricted && token.octal) {
                    firstRestricted = token;
                }
            }
        }

        while (startIndex < length) {
            statement = parseStatementListItem();
            /* istanbul ignore if */
            if (typeof statement === 'undefined') {
                break;
            }
            body.push(statement);
        }
        return body;
    }

    function parseProgram() {
        var body, node;

        peek();
        node = new Node();

        body = parseScriptBody();
        return node.finishProgram(body, state.sourceType);
    }

    function filterTokenLocation() {
        var i, entry, token, tokens = [];

        for (i = 0; i < extra.tokens.length; ++i) {
            entry = extra.tokens[i];
            token = {
                type: entry.type,
                value: entry.value
            };
            if (entry.regex) {
                token.regex = {
                    pattern: entry.regex.pattern,
                    flags: entry.regex.flags
                };
            }
            if (extra.range) {
                token.range = entry.range;
            }
            if (extra.loc) {
                token.loc = entry.loc;
            }
            tokens.push(token);
        }

        extra.tokens = tokens;
    }

    function tokenize(code, options, delegate) {
        var toString,
            tokens;

        toString = String;
        if (typeof code !== 'string' && !(code instanceof String)) {
            code = toString(code);
        }

        source = code;
        index = 0;
        lineNumber = (source.length > 0) ? 1 : 0;
        lineStart = 0;
        startIndex = index;
        startLineNumber = lineNumber;
        startLineStart = lineStart;
        length = source.length;
        lookahead = null;
        state = {
            allowIn: true,
            allowYield: true,
            labelSet: {},
            inFunctionBody: false,
            inIteration: false,
            inSwitch: false,
            lastCommentStart: -1,
            curlyStack: []
        };

        extra = {};

        // Options matching.
        options = options || {};

        // Of course we collect tokens here.
        options.tokens = true;
        extra.tokens = [];
        extra.tokenValues = [];
        extra.tokenize = true;
        extra.delegate = delegate;

        // The following two fields are necessary to compute the Regex tokens.
        extra.openParenToken = -1;
        extra.openCurlyToken = -1;

        extra.range = (typeof options.range === 'boolean') && options.range;
        extra.loc = (typeof options.loc === 'boolean') && options.loc;

        if (typeof options.comment === 'boolean' && options.comment) {
            extra.comments = [];
        }
        if (typeof options.tolerant === 'boolean' && options.tolerant) {
            extra.errors = [];
        }

        try {
            peek();
            if (lookahead.type === Token.EOF) {
                return extra.tokens;
            }

            lex();
            while (lookahead.type !== Token.EOF) {
                try {
                    lex();
                } catch (lexError) {
                    if (extra.errors) {
                        recordError(lexError);
                        // We have to break on the first error
                        // to avoid infinite loops.
                        break;
                    } else {
                        throw lexError;
                    }
                }
            }

            tokens = extra.tokens;
            if (typeof extra.errors !== 'undefined') {
                tokens.errors = extra.errors;
            }
        } catch (e) {
            throw e;
        } finally {
            extra = {};
        }
        return tokens;
    }

    function parse(code, options) {
        var program, toString;

        toString = String;
        if (typeof code !== 'string' && !(code instanceof String)) {
            code = toString(code);
        }

        source = code;
        index = 0;
        lineNumber = (source.length > 0) ? 1 : 0;
        lineStart = 0;
        startIndex = index;
        startLineNumber = lineNumber;
        startLineStart = lineStart;
        length = source.length;
        lookahead = null;
        state = {
            allowIn: true,
            allowYield: true,
            labelSet: {},
            inFunctionBody: false,
            inIteration: false,
            inSwitch: false,
            lastCommentStart: -1,
            curlyStack: [],
            sourceType: 'script'
        };
        strict = false;

        extra = {};
        if (typeof options !== 'undefined') {
            extra.range = (typeof options.range === 'boolean') && options.range;
            extra.loc = (typeof options.loc === 'boolean') && options.loc;
            extra.attachComment = (typeof options.attachComment === 'boolean') && options.attachComment;

            if (extra.loc && options.source !== null && options.source !== undefined) {
                extra.source = toString(options.source);
            }

            if (typeof options.tokens === 'boolean' && options.tokens) {
                extra.tokens = [];
            }
            if (typeof options.comment === 'boolean' && options.comment) {
                extra.comments = [];
            }
            if (typeof options.tolerant === 'boolean' && options.tolerant) {
                extra.errors = [];
            }
            if (extra.attachComment) {
                extra.range = true;
                extra.comments = [];
                extra.bottomRightStack = [];
                extra.trailingComments = [];
                extra.leadingComments = [];
            }
            if (options.sourceType === 'module') {
                // very restrictive condition for now
                state.sourceType = options.sourceType;
                strict = true;
            }
        }

        try {
            program = parseProgram();
            if (typeof extra.comments !== 'undefined') {
                program.comments = extra.comments;
            }
            if (typeof extra.tokens !== 'undefined') {
                filterTokenLocation();
                program.tokens = extra.tokens;
            }
            if (typeof extra.errors !== 'undefined') {
                program.errors = extra.errors;
            }
        } catch (e) {
            throw e;
        } finally {
            extra = {};
        }

        return program;
    }

    // Sync with *.json manifests.
    exports.version = '2.7.1';

    exports.tokenize = tokenize;

    exports.parse = parse;

    // Deep copy.
    /* istanbul ignore next */
    exports.Syntax = (function () {
        var name, types = {};

        if (typeof Object.create === 'function') {
            types = Object.create(null);
        }

        for (name in Syntax) {
            if (Syntax.hasOwnProperty(name)) {
                types[name] = Syntax[name];
            }
        }

        if (typeof Object.freeze === 'function') {
            Object.freeze(types);
        }

        return types;
    }());

}));
/* vim: set sw=4 ts=4 et tw=80 : */

},{}],52:[function(require,module,exports){
/*!
 * node-inherit
 * Copyright(c) 2011 Dmitry Filatov <dfilatov@yandex-team.ru>
 * MIT Licensed
 */

module.exports = require('./lib/inherit');

},{"./lib/inherit":53}],53:[function(require,module,exports){
/**
 * @module inherit
 * @version 2.2.2
 * @author Filatov Dmitry <dfilatov@yandex-team.ru>
 * @description This module provides some syntax sugar for "class" declarations, constructors, mixins, "super" calls and static members.
 */

(function(global) {

var hasIntrospection = (function(){'_';}).toString().indexOf('_') > -1,
    emptyBase = function() {},
    hasOwnProperty = Object.prototype.hasOwnProperty,
    objCreate = Object.create || function(ptp) {
        var inheritance = function() {};
        inheritance.prototype = ptp;
        return new inheritance();
    },
    objKeys = Object.keys || function(obj) {
        var res = [];
        for(var i in obj) {
            hasOwnProperty.call(obj, i) && res.push(i);
        }
        return res;
    },
    extend = function(o1, o2) {
        for(var i in o2) {
            hasOwnProperty.call(o2, i) && (o1[i] = o2[i]);
        }

        return o1;
    },
    toStr = Object.prototype.toString,
    isArray = Array.isArray || function(obj) {
        return toStr.call(obj) === '[object Array]';
    },
    isFunction = function(obj) {
        return toStr.call(obj) === '[object Function]';
    },
    noOp = function() {},
    needCheckProps = true,
    testPropObj = { toString : '' };

for(var i in testPropObj) { // fucking ie hasn't toString, valueOf in for
    testPropObj.hasOwnProperty(i) && (needCheckProps = false);
}

var specProps = needCheckProps? ['toString', 'valueOf'] : null;

function getPropList(obj) {
    var res = objKeys(obj);
    if(needCheckProps) {
        var specProp, i = 0;
        while(specProp = specProps[i++]) {
            obj.hasOwnProperty(specProp) && res.push(specProp);
        }
    }

    return res;
}

function override(base, res, add) {
    var addList = getPropList(add),
        j = 0, len = addList.length,
        name, prop;
    while(j < len) {
        if((name = addList[j++]) === '__self') {
            continue;
        }
        prop = add[name];
        if(isFunction(prop) &&
                (!hasIntrospection || prop.toString().indexOf('.__base') > -1)) {
            res[name] = (function(name, prop) {
                var baseMethod = base[name]?
                        base[name] :
                        name === '__constructor'? // case of inheritance from plane function
                            res.__self.__parent :
                            noOp;
                return function() {
                    var baseSaved = this.__base;
                    this.__base = baseMethod;
                    var res = prop.apply(this, arguments);
                    this.__base = baseSaved;
                    return res;
                };
            })(name, prop);
        } else {
            res[name] = prop;
        }
    }
}

function applyMixins(mixins, res) {
    var i = 1, mixin;
    while(mixin = mixins[i++]) {
        res?
            isFunction(mixin)?
                inherit.self(res, mixin.prototype, mixin) :
                inherit.self(res, mixin) :
            res = isFunction(mixin)?
                inherit(mixins[0], mixin.prototype, mixin) :
                inherit(mixins[0], mixin);
    }
    return res || mixins[0];
}

/**
* Creates class
* @exports
* @param {Function|Array} [baseClass|baseClassAndMixins] class (or class and mixins) to inherit from
* @param {Object} prototypeFields
* @param {Object} [staticFields]
* @returns {Function} class
*/
function inherit() {
    var args = arguments,
        withMixins = isArray(args[0]),
        hasBase = withMixins || isFunction(args[0]),
        base = hasBase? withMixins? applyMixins(args[0]) : args[0] : emptyBase,
        props = args[hasBase? 1 : 0] || {},
        staticProps = args[hasBase? 2 : 1],
        res = props.__constructor || (hasBase && base.prototype.__constructor)?
            function() {
                return this.__constructor.apply(this, arguments);
            } :
            hasBase?
                function() {
                    return base.apply(this, arguments);
                } :
                function() {};

    if(!hasBase) {
        res.prototype = props;
        res.prototype.__self = res.prototype.constructor = res;
        return extend(res, staticProps);
    }

    extend(res, base);

    res.__parent = base;

    var basePtp = base.prototype,
        resPtp = res.prototype = objCreate(basePtp);

    resPtp.__self = resPtp.constructor = res;

    props && override(basePtp, resPtp, props);
    staticProps && override(base, res, staticProps);

    return res;
}

inherit.self = function() {
    var args = arguments,
        withMixins = isArray(args[0]),
        base = withMixins? applyMixins(args[0], args[0][0]) : args[0],
        props = args[1],
        staticProps = args[2],
        basePtp = base.prototype;

    props && override(basePtp, basePtp, props);
    staticProps && override(base, base, staticProps);

    return base;
};

var defineAsGlobal = true;
if(typeof exports === 'object') {
    module.exports = inherit;
    defineAsGlobal = false;
}

if(typeof modules === 'object') {
    modules.define('inherit', function(provide) {
        provide(inherit);
    });
    defineAsGlobal = false;
}

if(typeof define === 'function') {
    define(function(require, exports, module) {
        module.exports = inherit;
    });
    defineAsGlobal = false;
}

defineAsGlobal && (global.inherit = inherit);

})(this);

},{}],54:[function(require,module,exports){
/**!
 * Ono v2.0.1
 *
 * @link https://github.com/BigstickCarpet/ono
 * @license MIT
 */
'use strict';

var util  = require('util'),
    slice = Array.prototype.slice,
    vendorSpecificErrorProperties = [
      'name', 'message', 'description', 'number', 'fileName', 'lineNumber', 'columnNumber',
      'sourceURL', 'line', 'column', 'stack'
    ];

module.exports = create(Error);
module.exports.error = create(Error);
module.exports.eval = create(EvalError);
module.exports.range = create(RangeError);
module.exports.reference = create(ReferenceError);
module.exports.syntax = create(SyntaxError);
module.exports.type = create(TypeError);
module.exports.uri = create(URIError);
module.exports.formatter = util.format;

/**
 * Creates a new {@link ono} function that creates the given Error class.
 *
 * @param {Class} Klass - The Error subclass to create
 * @returns {ono}
 */
function create(Klass) {
  /**
   * @param {Error}   [err]     - The original error, if any
   * @param {object}  [props]   - An object whose properties will be added to the error object
   * @param {string}  [message] - The error message. May contain {@link util#format} placeholders
   * @param {...*}    [params]  - Parameters that map to the `message` placeholders
   * @returns {Error}
   */
  return function ono(err, props, message, params) {
    var formattedMessage, stack;
    var formatter = module.exports.formatter;

    if (typeof(err) === 'string') {
      formattedMessage = formatter.apply(null, arguments);
      err = props = undefined;
    }
    else if (typeof(props) === 'string') {
      formattedMessage = formatter.apply(null, slice.call(arguments, 1));
    }
    else {
      formattedMessage = formatter.apply(null, slice.call(arguments, 2));
    }

    if (!(err instanceof Error)) {
      props = err;
      err = undefined;
    }

    if (err) {
      // The inner-error's message will be added to the new message
      formattedMessage += (formattedMessage ? ' \n' : '') + err.message;
    }

    // Create the new error
    // NOTE: DON'T move this to a separate function! We don't want to pollute the stack trace
    var newError = new Klass(formattedMessage);

    // Extend the new error with the additional properties
    extendError(newError, err);   // Copy properties of the original error
    extendToJSON(newError);       // Replace the original toJSON method
    extend(newError, props);      // Copy custom properties, possibly including a custom toJSON method

    return newError;
  };
}

/**
 * Extends the targetError with the properties of the source error.
 *
 * @param {Error}   targetError - The error object to extend
 * @param {?Error}  sourceError - The source error object, if any
 */
function extendError(targetError, sourceError) {
  if (sourceError) {
    var stack = sourceError.stack;
    if (stack) {
      targetError.stack += ' \n\n' + sourceError.stack;
    }

    extend(targetError, sourceError, true);
  }
}

/**
 * JavaScript engines differ in how errors are serialized to JSON - especially when it comes
 * to custom error properties and stack traces.  So we add our own toJSON method that ALWAYS
 * outputs every property of the error.
 */
function extendToJSON(error) {
  error.toJSON = errorToJSON;

  // Also add an inspect() method, for compatibility with Node.js' `util.inspect()` method
  error.inspect = errorToJSON;
}

/**
 * Extends the target object with the properties of the source object.
 *
 * @param {object}  target - The object to extend
 * @param {?source} source - The object whose properties are copied
 * @param {boolean} omitVendorSpecificProperties - Skip vendor-specific Error properties
 */
function extend(target, source, omitVendorSpecificProperties) {
  if (source && typeof(source) === 'object') {
    var keys = Object.keys(source);
    for (var i = 0; i < keys.length; i++) {
      var key = keys[i];

      // Don't bother trying to copy read-only vendor-specific Error properties
      if (omitVendorSpecificProperties && vendorSpecificErrorProperties.indexOf(key) >= 0) {
        continue;
      }

      try {
        target[key] = source[key];
      }
      catch (e) {
        // This property is read-only, so it can't be copied
      }
    }
  }
}

/**
 * Custom JSON serializer for Error objects.
 * Returns all built-in error properties, as well as extended properties.
 *
 * @returns {object}
 */
function errorToJSON() {
  // jshint -W040
  var json = {};

  // Get all the properties of this error
  var keys = Object.keys(this);

  // Also include vendor-specific properties from the prototype
  keys = keys.concat(vendorSpecificErrorProperties);

  for (var i = 0; i < keys.length; i++) {
    var key = keys[i];
    var value = this[key];
    if (value !== undefined) {
      json[key] = value;
    }
  }

  return json;
}

},{"util":94}],55:[function(require,module,exports){

},{}],56:[function(require,module,exports){
arguments[4][55][0].apply(exports,arguments)
},{"dup":55}],57:[function(require,module,exports){
(function (global){
/*!
 * The buffer module from node.js, for the browser.
 *
 * @author   Feross Aboukhadijeh <feross@feross.org> <http://feross.org>
 * @license  MIT
 */
/* eslint-disable no-proto */

'use strict'

var base64 = require('base64-js')
var ieee754 = require('ieee754')
var isArray = require('isarray')

exports.Buffer = Buffer
exports.SlowBuffer = SlowBuffer
exports.INSPECT_MAX_BYTES = 50
Buffer.poolSize = 8192 // not used by this implementation

var rootParent = {}

/**
 * If `Buffer.TYPED_ARRAY_SUPPORT`:
 *   === true    Use Uint8Array implementation (fastest)
 *   === false   Use Object implementation (most compatible, even IE6)
 *
 * Browsers that support typed arrays are IE 10+, Firefox 4+, Chrome 7+, Safari 5.1+,
 * Opera 11.6+, iOS 4.2+.
 *
 * Due to various browser bugs, sometimes the Object implementation will be used even
 * when the browser supports typed arrays.
 *
 * Note:
 *
 *   - Firefox 4-29 lacks support for adding new properties to `Uint8Array` instances,
 *     See: https://bugzilla.mozilla.org/show_bug.cgi?id=695438.
 *
 *   - Safari 5-7 lacks support for changing the `Object.prototype.constructor` property
 *     on objects.
 *
 *   - Chrome 9-10 is missing the `TypedArray.prototype.subarray` function.
 *
 *   - IE10 has a broken `TypedArray.prototype.subarray` function which returns arrays of
 *     incorrect length in some situations.

 * We detect these buggy browsers and set `Buffer.TYPED_ARRAY_SUPPORT` to `false` so they
 * get the Object implementation, which is slower but behaves correctly.
 */
Buffer.TYPED_ARRAY_SUPPORT = global.TYPED_ARRAY_SUPPORT !== undefined
  ? global.TYPED_ARRAY_SUPPORT
  : typedArraySupport()

function typedArraySupport () {
  function Bar () {}
  try {
    var arr = new Uint8Array(1)
    arr.foo = function () { return 42 }
    arr.constructor = Bar
    return arr.foo() === 42 && // typed array instances can be augmented
        arr.constructor === Bar && // constructor can be set
        typeof arr.subarray === 'function' && // chrome 9-10 lack `subarray`
        arr.subarray(1, 1).byteLength === 0 // ie10 has broken `subarray`
  } catch (e) {
    return false
  }
}

function kMaxLength () {
  return Buffer.TYPED_ARRAY_SUPPORT
    ? 0x7fffffff
    : 0x3fffffff
}

/**
 * Class: Buffer
 * =============
 *
 * The Buffer constructor returns instances of `Uint8Array` that are augmented
 * with function properties for all the node `Buffer` API functions. We use
 * `Uint8Array` so that square bracket notation works as expected -- it returns
 * a single octet.
 *
 * By augmenting the instances, we can avoid modifying the `Uint8Array`
 * prototype.
 */
function Buffer (arg) {
  if (!(this instanceof Buffer)) {
    // Avoid going through an ArgumentsAdaptorTrampoline in the common case.
    if (arguments.length > 1) return new Buffer(arg, arguments[1])
    return new Buffer(arg)
  }

  if (!Buffer.TYPED_ARRAY_SUPPORT) {
    this.length = 0
    this.parent = undefined
  }

  // Common case.
  if (typeof arg === 'number') {
    return fromNumber(this, arg)
  }

  // Slightly less common case.
  if (typeof arg === 'string') {
    return fromString(this, arg, arguments.length > 1 ? arguments[1] : 'utf8')
  }

  // Unusual.
  return fromObject(this, arg)
}

function fromNumber (that, length) {
  that = allocate(that, length < 0 ? 0 : checked(length) | 0)
  if (!Buffer.TYPED_ARRAY_SUPPORT) {
    for (var i = 0; i < length; i++) {
      that[i] = 0
    }
  }
  return that
}

function fromString (that, string, encoding) {
  if (typeof encoding !== 'string' || encoding === '') encoding = 'utf8'

  // Assumption: byteLength() return value is always < kMaxLength.
  var length = byteLength(string, encoding) | 0
  that = allocate(that, length)

  that.write(string, encoding)
  return that
}

function fromObject (that, object) {
  if (Buffer.isBuffer(object)) return fromBuffer(that, object)

  if (isArray(object)) return fromArray(that, object)

  if (object == null) {
    throw new TypeError('must start with number, buffer, array or string')
  }

  if (typeof ArrayBuffer !== 'undefined') {
    if (object.buffer instanceof ArrayBuffer) {
      return fromTypedArray(that, object)
    }
    if (object instanceof ArrayBuffer) {
      return fromArrayBuffer(that, object)
    }
  }

  if (object.length) return fromArrayLike(that, object)

  return fromJsonObject(that, object)
}

function fromBuffer (that, buffer) {
  var length = checked(buffer.length) | 0
  that = allocate(that, length)
  buffer.copy(that, 0, 0, length)
  return that
}

function fromArray (that, array) {
  var length = checked(array.length) | 0
  that = allocate(that, length)
  for (var i = 0; i < length; i += 1) {
    that[i] = array[i] & 255
  }
  return that
}

// Duplicate of fromArray() to keep fromArray() monomorphic.
function fromTypedArray (that, array) {
  var length = checked(array.length) | 0
  that = allocate(that, length)
  // Truncating the elements is probably not what people expect from typed
  // arrays with BYTES_PER_ELEMENT > 1 but it's compatible with the behavior
  // of the old Buffer constructor.
  for (var i = 0; i < length; i += 1) {
    that[i] = array[i] & 255
  }
  return that
}

function fromArrayBuffer (that, array) {
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    // Return an augmented `Uint8Array` instance, for best performance
    array.byteLength
    that = Buffer._augment(new Uint8Array(array))
  } else {
    // Fallback: Return an object instance of the Buffer class
    that = fromTypedArray(that, new Uint8Array(array))
  }
  return that
}

function fromArrayLike (that, array) {
  var length = checked(array.length) | 0
  that = allocate(that, length)
  for (var i = 0; i < length; i += 1) {
    that[i] = array[i] & 255
  }
  return that
}

// Deserialize { type: 'Buffer', data: [1,2,3,...] } into a Buffer object.
// Returns a zero-length buffer for inputs that don't conform to the spec.
function fromJsonObject (that, object) {
  var array
  var length = 0

  if (object.type === 'Buffer' && isArray(object.data)) {
    array = object.data
    length = checked(array.length) | 0
  }
  that = allocate(that, length)

  for (var i = 0; i < length; i += 1) {
    that[i] = array[i] & 255
  }
  return that
}

if (Buffer.TYPED_ARRAY_SUPPORT) {
  Buffer.prototype.__proto__ = Uint8Array.prototype
  Buffer.__proto__ = Uint8Array
} else {
  // pre-set for values that may exist in the future
  Buffer.prototype.length = undefined
  Buffer.prototype.parent = undefined
}

function allocate (that, length) {
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    // Return an augmented `Uint8Array` instance, for best performance
    that = Buffer._augment(new Uint8Array(length))
    that.__proto__ = Buffer.prototype
  } else {
    // Fallback: Return an object instance of the Buffer class
    that.length = length
    that._isBuffer = true
  }

  var fromPool = length !== 0 && length <= Buffer.poolSize >>> 1
  if (fromPool) that.parent = rootParent

  return that
}

function checked (length) {
  // Note: cannot use `length < kMaxLength` here because that fails when
  // length is NaN (which is otherwise coerced to zero.)
  if (length >= kMaxLength()) {
    throw new RangeError('Attempt to allocate Buffer larger than maximum ' +
                         'size: 0x' + kMaxLength().toString(16) + ' bytes')
  }
  return length | 0
}

function SlowBuffer (subject, encoding) {
  if (!(this instanceof SlowBuffer)) return new SlowBuffer(subject, encoding)

  var buf = new Buffer(subject, encoding)
  delete buf.parent
  return buf
}

Buffer.isBuffer = function isBuffer (b) {
  return !!(b != null && b._isBuffer)
}

Buffer.compare = function compare (a, b) {
  if (!Buffer.isBuffer(a) || !Buffer.isBuffer(b)) {
    throw new TypeError('Arguments must be Buffers')
  }

  if (a === b) return 0

  var x = a.length
  var y = b.length

  var i = 0
  var len = Math.min(x, y)
  while (i < len) {
    if (a[i] !== b[i]) break

    ++i
  }

  if (i !== len) {
    x = a[i]
    y = b[i]
  }

  if (x < y) return -1
  if (y < x) return 1
  return 0
}

Buffer.isEncoding = function isEncoding (encoding) {
  switch (String(encoding).toLowerCase()) {
    case 'hex':
    case 'utf8':
    case 'utf-8':
    case 'ascii':
    case 'binary':
    case 'base64':
    case 'raw':
    case 'ucs2':
    case 'ucs-2':
    case 'utf16le':
    case 'utf-16le':
      return true
    default:
      return false
  }
}

Buffer.concat = function concat (list, length) {
  if (!isArray(list)) throw new TypeError('list argument must be an Array of Buffers.')

  if (list.length === 0) {
    return new Buffer(0)
  }

  var i
  if (length === undefined) {
    length = 0
    for (i = 0; i < list.length; i++) {
      length += list[i].length
    }
  }

  var buf = new Buffer(length)
  var pos = 0
  for (i = 0; i < list.length; i++) {
    var item = list[i]
    item.copy(buf, pos)
    pos += item.length
  }
  return buf
}

function byteLength (string, encoding) {
  if (typeof string !== 'string') string = '' + string

  var len = string.length
  if (len === 0) return 0

  // Use a for loop to avoid recursion
  var loweredCase = false
  for (;;) {
    switch (encoding) {
      case 'ascii':
      case 'binary':
      // Deprecated
      case 'raw':
      case 'raws':
        return len
      case 'utf8':
      case 'utf-8':
        return utf8ToBytes(string).length
      case 'ucs2':
      case 'ucs-2':
      case 'utf16le':
      case 'utf-16le':
        return len * 2
      case 'hex':
        return len >>> 1
      case 'base64':
        return base64ToBytes(string).length
      default:
        if (loweredCase) return utf8ToBytes(string).length // assume utf8
        encoding = ('' + encoding).toLowerCase()
        loweredCase = true
    }
  }
}
Buffer.byteLength = byteLength

function slowToString (encoding, start, end) {
  var loweredCase = false

  start = start | 0
  end = end === undefined || end === Infinity ? this.length : end | 0

  if (!encoding) encoding = 'utf8'
  if (start < 0) start = 0
  if (end > this.length) end = this.length
  if (end <= start) return ''

  while (true) {
    switch (encoding) {
      case 'hex':
        return hexSlice(this, start, end)

      case 'utf8':
      case 'utf-8':
        return utf8Slice(this, start, end)

      case 'ascii':
        return asciiSlice(this, start, end)

      case 'binary':
        return binarySlice(this, start, end)

      case 'base64':
        return base64Slice(this, start, end)

      case 'ucs2':
      case 'ucs-2':
      case 'utf16le':
      case 'utf-16le':
        return utf16leSlice(this, start, end)

      default:
        if (loweredCase) throw new TypeError('Unknown encoding: ' + encoding)
        encoding = (encoding + '').toLowerCase()
        loweredCase = true
    }
  }
}

Buffer.prototype.toString = function toString () {
  var length = this.length | 0
  if (length === 0) return ''
  if (arguments.length === 0) return utf8Slice(this, 0, length)
  return slowToString.apply(this, arguments)
}

Buffer.prototype.equals = function equals (b) {
  if (!Buffer.isBuffer(b)) throw new TypeError('Argument must be a Buffer')
  if (this === b) return true
  return Buffer.compare(this, b) === 0
}

Buffer.prototype.inspect = function inspect () {
  var str = ''
  var max = exports.INSPECT_MAX_BYTES
  if (this.length > 0) {
    str = this.toString('hex', 0, max).match(/.{2}/g).join(' ')
    if (this.length > max) str += ' ... '
  }
  return '<Buffer ' + str + '>'
}

Buffer.prototype.compare = function compare (b) {
  if (!Buffer.isBuffer(b)) throw new TypeError('Argument must be a Buffer')
  if (this === b) return 0
  return Buffer.compare(this, b)
}

Buffer.prototype.indexOf = function indexOf (val, byteOffset) {
  if (byteOffset > 0x7fffffff) byteOffset = 0x7fffffff
  else if (byteOffset < -0x80000000) byteOffset = -0x80000000
  byteOffset >>= 0

  if (this.length === 0) return -1
  if (byteOffset >= this.length) return -1

  // Negative offsets start from the end of the buffer
  if (byteOffset < 0) byteOffset = Math.max(this.length + byteOffset, 0)

  if (typeof val === 'string') {
    if (val.length === 0) return -1 // special case: looking for empty string always fails
    return String.prototype.indexOf.call(this, val, byteOffset)
  }
  if (Buffer.isBuffer(val)) {
    return arrayIndexOf(this, val, byteOffset)
  }
  if (typeof val === 'number') {
    if (Buffer.TYPED_ARRAY_SUPPORT && Uint8Array.prototype.indexOf === 'function') {
      return Uint8Array.prototype.indexOf.call(this, val, byteOffset)
    }
    return arrayIndexOf(this, [ val ], byteOffset)
  }

  function arrayIndexOf (arr, val, byteOffset) {
    var foundIndex = -1
    for (var i = 0; byteOffset + i < arr.length; i++) {
      if (arr[byteOffset + i] === val[foundIndex === -1 ? 0 : i - foundIndex]) {
        if (foundIndex === -1) foundIndex = i
        if (i - foundIndex + 1 === val.length) return byteOffset + foundIndex
      } else {
        foundIndex = -1
      }
    }
    return -1
  }

  throw new TypeError('val must be string, number or Buffer')
}

// `get` is deprecated
Buffer.prototype.get = function get (offset) {
  console.log('.get() is deprecated. Access using array indexes instead.')
  return this.readUInt8(offset)
}

// `set` is deprecated
Buffer.prototype.set = function set (v, offset) {
  console.log('.set() is deprecated. Access using array indexes instead.')
  return this.writeUInt8(v, offset)
}

function hexWrite (buf, string, offset, length) {
  offset = Number(offset) || 0
  var remaining = buf.length - offset
  if (!length) {
    length = remaining
  } else {
    length = Number(length)
    if (length > remaining) {
      length = remaining
    }
  }

  // must be an even number of digits
  var strLen = string.length
  if (strLen % 2 !== 0) throw new Error('Invalid hex string')

  if (length > strLen / 2) {
    length = strLen / 2
  }
  for (var i = 0; i < length; i++) {
    var parsed = parseInt(string.substr(i * 2, 2), 16)
    if (isNaN(parsed)) throw new Error('Invalid hex string')
    buf[offset + i] = parsed
  }
  return i
}

function utf8Write (buf, string, offset, length) {
  return blitBuffer(utf8ToBytes(string, buf.length - offset), buf, offset, length)
}

function asciiWrite (buf, string, offset, length) {
  return blitBuffer(asciiToBytes(string), buf, offset, length)
}

function binaryWrite (buf, string, offset, length) {
  return asciiWrite(buf, string, offset, length)
}

function base64Write (buf, string, offset, length) {
  return blitBuffer(base64ToBytes(string), buf, offset, length)
}

function ucs2Write (buf, string, offset, length) {
  return blitBuffer(utf16leToBytes(string, buf.length - offset), buf, offset, length)
}

Buffer.prototype.write = function write (string, offset, length, encoding) {
  // Buffer#write(string)
  if (offset === undefined) {
    encoding = 'utf8'
    length = this.length
    offset = 0
  // Buffer#write(string, encoding)
  } else if (length === undefined && typeof offset === 'string') {
    encoding = offset
    length = this.length
    offset = 0
  // Buffer#write(string, offset[, length][, encoding])
  } else if (isFinite(offset)) {
    offset = offset | 0
    if (isFinite(length)) {
      length = length | 0
      if (encoding === undefined) encoding = 'utf8'
    } else {
      encoding = length
      length = undefined
    }
  // legacy write(string, encoding, offset, length) - remove in v0.13
  } else {
    var swap = encoding
    encoding = offset
    offset = length | 0
    length = swap
  }

  var remaining = this.length - offset
  if (length === undefined || length > remaining) length = remaining

  if ((string.length > 0 && (length < 0 || offset < 0)) || offset > this.length) {
    throw new RangeError('attempt to write outside buffer bounds')
  }

  if (!encoding) encoding = 'utf8'

  var loweredCase = false
  for (;;) {
    switch (encoding) {
      case 'hex':
        return hexWrite(this, string, offset, length)

      case 'utf8':
      case 'utf-8':
        return utf8Write(this, string, offset, length)

      case 'ascii':
        return asciiWrite(this, string, offset, length)

      case 'binary':
        return binaryWrite(this, string, offset, length)

      case 'base64':
        // Warning: maxLength not taken into account in base64Write
        return base64Write(this, string, offset, length)

      case 'ucs2':
      case 'ucs-2':
      case 'utf16le':
      case 'utf-16le':
        return ucs2Write(this, string, offset, length)

      default:
        if (loweredCase) throw new TypeError('Unknown encoding: ' + encoding)
        encoding = ('' + encoding).toLowerCase()
        loweredCase = true
    }
  }
}

Buffer.prototype.toJSON = function toJSON () {
  return {
    type: 'Buffer',
    data: Array.prototype.slice.call(this._arr || this, 0)
  }
}

function base64Slice (buf, start, end) {
  if (start === 0 && end === buf.length) {
    return base64.fromByteArray(buf)
  } else {
    return base64.fromByteArray(buf.slice(start, end))
  }
}

function utf8Slice (buf, start, end) {
  end = Math.min(buf.length, end)
  var res = []

  var i = start
  while (i < end) {
    var firstByte = buf[i]
    var codePoint = null
    var bytesPerSequence = (firstByte > 0xEF) ? 4
      : (firstByte > 0xDF) ? 3
      : (firstByte > 0xBF) ? 2
      : 1

    if (i + bytesPerSequence <= end) {
      var secondByte, thirdByte, fourthByte, tempCodePoint

      switch (bytesPerSequence) {
        case 1:
          if (firstByte < 0x80) {
            codePoint = firstByte
          }
          break
        case 2:
          secondByte = buf[i + 1]
          if ((secondByte & 0xC0) === 0x80) {
            tempCodePoint = (firstByte & 0x1F) << 0x6 | (secondByte & 0x3F)
            if (tempCodePoint > 0x7F) {
              codePoint = tempCodePoint
            }
          }
          break
        case 3:
          secondByte = buf[i + 1]
          thirdByte = buf[i + 2]
          if ((secondByte & 0xC0) === 0x80 && (thirdByte & 0xC0) === 0x80) {
            tempCodePoint = (firstByte & 0xF) << 0xC | (secondByte & 0x3F) << 0x6 | (thirdByte & 0x3F)
            if (tempCodePoint > 0x7FF && (tempCodePoint < 0xD800 || tempCodePoint > 0xDFFF)) {
              codePoint = tempCodePoint
            }
          }
          break
        case 4:
          secondByte = buf[i + 1]
          thirdByte = buf[i + 2]
          fourthByte = buf[i + 3]
          if ((secondByte & 0xC0) === 0x80 && (thirdByte & 0xC0) === 0x80 && (fourthByte & 0xC0) === 0x80) {
            tempCodePoint = (firstByte & 0xF) << 0x12 | (secondByte & 0x3F) << 0xC | (thirdByte & 0x3F) << 0x6 | (fourthByte & 0x3F)
            if (tempCodePoint > 0xFFFF && tempCodePoint < 0x110000) {
              codePoint = tempCodePoint
            }
          }
      }
    }

    if (codePoint === null) {
      // we did not generate a valid codePoint so insert a
      // replacement char (U+FFFD) and advance only 1 byte
      codePoint = 0xFFFD
      bytesPerSequence = 1
    } else if (codePoint > 0xFFFF) {
      // encode to utf16 (surrogate pair dance)
      codePoint -= 0x10000
      res.push(codePoint >>> 10 & 0x3FF | 0xD800)
      codePoint = 0xDC00 | codePoint & 0x3FF
    }

    res.push(codePoint)
    i += bytesPerSequence
  }

  return decodeCodePointsArray(res)
}

// Based on http://stackoverflow.com/a/22747272/680742, the browser with
// the lowest limit is Chrome, with 0x10000 args.
// We go 1 magnitude less, for safety
var MAX_ARGUMENTS_LENGTH = 0x1000

function decodeCodePointsArray (codePoints) {
  var len = codePoints.length
  if (len <= MAX_ARGUMENTS_LENGTH) {
    return String.fromCharCode.apply(String, codePoints) // avoid extra slice()
  }

  // Decode in chunks to avoid "call stack size exceeded".
  var res = ''
  var i = 0
  while (i < len) {
    res += String.fromCharCode.apply(
      String,
      codePoints.slice(i, i += MAX_ARGUMENTS_LENGTH)
    )
  }
  return res
}

function asciiSlice (buf, start, end) {
  var ret = ''
  end = Math.min(buf.length, end)

  for (var i = start; i < end; i++) {
    ret += String.fromCharCode(buf[i] & 0x7F)
  }
  return ret
}

function binarySlice (buf, start, end) {
  var ret = ''
  end = Math.min(buf.length, end)

  for (var i = start; i < end; i++) {
    ret += String.fromCharCode(buf[i])
  }
  return ret
}

function hexSlice (buf, start, end) {
  var len = buf.length

  if (!start || start < 0) start = 0
  if (!end || end < 0 || end > len) end = len

  var out = ''
  for (var i = start; i < end; i++) {
    out += toHex(buf[i])
  }
  return out
}

function utf16leSlice (buf, start, end) {
  var bytes = buf.slice(start, end)
  var res = ''
  for (var i = 0; i < bytes.length; i += 2) {
    res += String.fromCharCode(bytes[i] + bytes[i + 1] * 256)
  }
  return res
}

Buffer.prototype.slice = function slice (start, end) {
  var len = this.length
  start = ~~start
  end = end === undefined ? len : ~~end

  if (start < 0) {
    start += len
    if (start < 0) start = 0
  } else if (start > len) {
    start = len
  }

  if (end < 0) {
    end += len
    if (end < 0) end = 0
  } else if (end > len) {
    end = len
  }

  if (end < start) end = start

  var newBuf
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    newBuf = Buffer._augment(this.subarray(start, end))
  } else {
    var sliceLen = end - start
    newBuf = new Buffer(sliceLen, undefined)
    for (var i = 0; i < sliceLen; i++) {
      newBuf[i] = this[i + start]
    }
  }

  if (newBuf.length) newBuf.parent = this.parent || this

  return newBuf
}

/*
 * Need to make sure that buffer isn't trying to write out of bounds.
 */
function checkOffset (offset, ext, length) {
  if ((offset % 1) !== 0 || offset < 0) throw new RangeError('offset is not uint')
  if (offset + ext > length) throw new RangeError('Trying to access beyond buffer length')
}

Buffer.prototype.readUIntLE = function readUIntLE (offset, byteLength, noAssert) {
  offset = offset | 0
  byteLength = byteLength | 0
  if (!noAssert) checkOffset(offset, byteLength, this.length)

  var val = this[offset]
  var mul = 1
  var i = 0
  while (++i < byteLength && (mul *= 0x100)) {
    val += this[offset + i] * mul
  }

  return val
}

Buffer.prototype.readUIntBE = function readUIntBE (offset, byteLength, noAssert) {
  offset = offset | 0
  byteLength = byteLength | 0
  if (!noAssert) {
    checkOffset(offset, byteLength, this.length)
  }

  var val = this[offset + --byteLength]
  var mul = 1
  while (byteLength > 0 && (mul *= 0x100)) {
    val += this[offset + --byteLength] * mul
  }

  return val
}

Buffer.prototype.readUInt8 = function readUInt8 (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 1, this.length)
  return this[offset]
}

Buffer.prototype.readUInt16LE = function readUInt16LE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 2, this.length)
  return this[offset] | (this[offset + 1] << 8)
}

Buffer.prototype.readUInt16BE = function readUInt16BE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 2, this.length)
  return (this[offset] << 8) | this[offset + 1]
}

Buffer.prototype.readUInt32LE = function readUInt32LE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 4, this.length)

  return ((this[offset]) |
      (this[offset + 1] << 8) |
      (this[offset + 2] << 16)) +
      (this[offset + 3] * 0x1000000)
}

Buffer.prototype.readUInt32BE = function readUInt32BE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 4, this.length)

  return (this[offset] * 0x1000000) +
    ((this[offset + 1] << 16) |
    (this[offset + 2] << 8) |
    this[offset + 3])
}

Buffer.prototype.readIntLE = function readIntLE (offset, byteLength, noAssert) {
  offset = offset | 0
  byteLength = byteLength | 0
  if (!noAssert) checkOffset(offset, byteLength, this.length)

  var val = this[offset]
  var mul = 1
  var i = 0
  while (++i < byteLength && (mul *= 0x100)) {
    val += this[offset + i] * mul
  }
  mul *= 0x80

  if (val >= mul) val -= Math.pow(2, 8 * byteLength)

  return val
}

Buffer.prototype.readIntBE = function readIntBE (offset, byteLength, noAssert) {
  offset = offset | 0
  byteLength = byteLength | 0
  if (!noAssert) checkOffset(offset, byteLength, this.length)

  var i = byteLength
  var mul = 1
  var val = this[offset + --i]
  while (i > 0 && (mul *= 0x100)) {
    val += this[offset + --i] * mul
  }
  mul *= 0x80

  if (val >= mul) val -= Math.pow(2, 8 * byteLength)

  return val
}

Buffer.prototype.readInt8 = function readInt8 (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 1, this.length)
  if (!(this[offset] & 0x80)) return (this[offset])
  return ((0xff - this[offset] + 1) * -1)
}

Buffer.prototype.readInt16LE = function readInt16LE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 2, this.length)
  var val = this[offset] | (this[offset + 1] << 8)
  return (val & 0x8000) ? val | 0xFFFF0000 : val
}

Buffer.prototype.readInt16BE = function readInt16BE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 2, this.length)
  var val = this[offset + 1] | (this[offset] << 8)
  return (val & 0x8000) ? val | 0xFFFF0000 : val
}

Buffer.prototype.readInt32LE = function readInt32LE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 4, this.length)

  return (this[offset]) |
    (this[offset + 1] << 8) |
    (this[offset + 2] << 16) |
    (this[offset + 3] << 24)
}

Buffer.prototype.readInt32BE = function readInt32BE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 4, this.length)

  return (this[offset] << 24) |
    (this[offset + 1] << 16) |
    (this[offset + 2] << 8) |
    (this[offset + 3])
}

Buffer.prototype.readFloatLE = function readFloatLE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 4, this.length)
  return ieee754.read(this, offset, true, 23, 4)
}

Buffer.prototype.readFloatBE = function readFloatBE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 4, this.length)
  return ieee754.read(this, offset, false, 23, 4)
}

Buffer.prototype.readDoubleLE = function readDoubleLE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 8, this.length)
  return ieee754.read(this, offset, true, 52, 8)
}

Buffer.prototype.readDoubleBE = function readDoubleBE (offset, noAssert) {
  if (!noAssert) checkOffset(offset, 8, this.length)
  return ieee754.read(this, offset, false, 52, 8)
}

function checkInt (buf, value, offset, ext, max, min) {
  if (!Buffer.isBuffer(buf)) throw new TypeError('buffer must be a Buffer instance')
  if (value > max || value < min) throw new RangeError('value is out of bounds')
  if (offset + ext > buf.length) throw new RangeError('index out of range')
}

Buffer.prototype.writeUIntLE = function writeUIntLE (value, offset, byteLength, noAssert) {
  value = +value
  offset = offset | 0
  byteLength = byteLength | 0
  if (!noAssert) checkInt(this, value, offset, byteLength, Math.pow(2, 8 * byteLength), 0)

  var mul = 1
  var i = 0
  this[offset] = value & 0xFF
  while (++i < byteLength && (mul *= 0x100)) {
    this[offset + i] = (value / mul) & 0xFF
  }

  return offset + byteLength
}

Buffer.prototype.writeUIntBE = function writeUIntBE (value, offset, byteLength, noAssert) {
  value = +value
  offset = offset | 0
  byteLength = byteLength | 0
  if (!noAssert) checkInt(this, value, offset, byteLength, Math.pow(2, 8 * byteLength), 0)

  var i = byteLength - 1
  var mul = 1
  this[offset + i] = value & 0xFF
  while (--i >= 0 && (mul *= 0x100)) {
    this[offset + i] = (value / mul) & 0xFF
  }

  return offset + byteLength
}

Buffer.prototype.writeUInt8 = function writeUInt8 (value, offset, noAssert) {
  value = +value
  offset = offset | 0
  if (!noAssert) checkInt(this, value, offset, 1, 0xff, 0)
  if (!Buffer.TYPED_ARRAY_SUPPORT) value = Math.floor(value)
  this[offset] = (value & 0xff)
  return offset + 1
}

function objectWriteUInt16 (buf, value, offset, littleEndian) {
  if (value < 0) value = 0xffff + value + 1
  for (var i = 0, j = Math.min(buf.length - offset, 2); i < j; i++) {
    buf[offset + i] = (value & (0xff << (8 * (littleEndian ? i : 1 - i)))) >>>
      (littleEndian ? i : 1 - i) * 8
  }
}

Buffer.prototype.writeUInt16LE = function writeUInt16LE (value, offset, noAssert) {
  value = +value
  offset = offset | 0
  if (!noAssert) checkInt(this, value, offset, 2, 0xffff, 0)
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = (value & 0xff)
    this[offset + 1] = (value >>> 8)
  } else {
    objectWriteUInt16(this, value, offset, true)
  }
  return offset + 2
}

Buffer.prototype.writeUInt16BE = function writeUInt16BE (value, offset, noAssert) {
  value = +value
  offset = offset | 0
  if (!noAssert) checkInt(this, value, offset, 2, 0xffff, 0)
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = (value >>> 8)
    this[offset + 1] = (value & 0xff)
  } else {
    objectWriteUInt16(this, value, offset, false)
  }
  return offset + 2
}

function objectWriteUInt32 (buf, value, offset, littleEndian) {
  if (value < 0) value = 0xffffffff + value + 1
  for (var i = 0, j = Math.min(buf.length - offset, 4); i < j; i++) {
    buf[offset + i] = (value >>> (littleEndian ? i : 3 - i) * 8) & 0xff
  }
}

Buffer.prototype.writeUInt32LE = function writeUInt32LE (value, offset, noAssert) {
  value = +value
  offset = offset | 0
  if (!noAssert) checkInt(this, value, offset, 4, 0xffffffff, 0)
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset + 3] = (value >>> 24)
    this[offset + 2] = (value >>> 16)
    this[offset + 1] = (value >>> 8)
    this[offset] = (value & 0xff)
  } else {
    objectWriteUInt32(this, value, offset, true)
  }
  return offset + 4
}

Buffer.prototype.writeUInt32BE = function writeUInt32BE (value, offset, noAssert) {
  value = +value
  offset = offset | 0
  if (!noAssert) checkInt(this, value, offset, 4, 0xffffffff, 0)
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = (value >>> 24)
    this[offset + 1] = (value >>> 16)
    this[offset + 2] = (value >>> 8)
    this[offset + 3] = (value & 0xff)
  } else {
    objectWriteUInt32(this, value, offset, false)
  }
  return offset + 4
}

Buffer.prototype.writeIntLE = function writeIntLE (value, offset, byteLength, noAssert) {
  value = +value
  offset = offset | 0
  if (!noAssert) {
    var limit = Math.pow(2, 8 * byteLength - 1)

    checkInt(this, value, offset, byteLength, limit - 1, -limit)
  }

  var i = 0
  var mul = 1
  var sub = value < 0 ? 1 : 0
  this[offset] = value & 0xFF
  while (++i < byteLength && (mul *= 0x100)) {
    this[offset + i] = ((value / mul) >> 0) - sub & 0xFF
  }

  return offset + byteLength
}

Buffer.prototype.writeIntBE = function writeIntBE (value, offset, byteLength, noAssert) {
  value = +value
  offset = offset | 0
  if (!noAssert) {
    var limit = Math.pow(2, 8 * byteLength - 1)

    checkInt(this, value, offset, byteLength, limit - 1, -limit)
  }

  var i = byteLength - 1
  var mul = 1
  var sub = value < 0 ? 1 : 0
  this[offset + i] = value & 0xFF
  while (--i >= 0 && (mul *= 0x100)) {
    this[offset + i] = ((value / mul) >> 0) - sub & 0xFF
  }

  return offset + byteLength
}

Buffer.prototype.writeInt8 = function writeInt8 (value, offset, noAssert) {
  value = +value
  offset = offset | 0
  if (!noAssert) checkInt(this, value, offset, 1, 0x7f, -0x80)
  if (!Buffer.TYPED_ARRAY_SUPPORT) value = Math.floor(value)
  if (value < 0) value = 0xff + value + 1
  this[offset] = (value & 0xff)
  return offset + 1
}

Buffer.prototype.writeInt16LE = function writeInt16LE (value, offset, noAssert) {
  value = +value
  offset = offset | 0
  if (!noAssert) checkInt(this, value, offset, 2, 0x7fff, -0x8000)
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = (value & 0xff)
    this[offset + 1] = (value >>> 8)
  } else {
    objectWriteUInt16(this, value, offset, true)
  }
  return offset + 2
}

Buffer.prototype.writeInt16BE = function writeInt16BE (value, offset, noAssert) {
  value = +value
  offset = offset | 0
  if (!noAssert) checkInt(this, value, offset, 2, 0x7fff, -0x8000)
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = (value >>> 8)
    this[offset + 1] = (value & 0xff)
  } else {
    objectWriteUInt16(this, value, offset, false)
  }
  return offset + 2
}

Buffer.prototype.writeInt32LE = function writeInt32LE (value, offset, noAssert) {
  value = +value
  offset = offset | 0
  if (!noAssert) checkInt(this, value, offset, 4, 0x7fffffff, -0x80000000)
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = (value & 0xff)
    this[offset + 1] = (value >>> 8)
    this[offset + 2] = (value >>> 16)
    this[offset + 3] = (value >>> 24)
  } else {
    objectWriteUInt32(this, value, offset, true)
  }
  return offset + 4
}

Buffer.prototype.writeInt32BE = function writeInt32BE (value, offset, noAssert) {
  value = +value
  offset = offset | 0
  if (!noAssert) checkInt(this, value, offset, 4, 0x7fffffff, -0x80000000)
  if (value < 0) value = 0xffffffff + value + 1
  if (Buffer.TYPED_ARRAY_SUPPORT) {
    this[offset] = (value >>> 24)
    this[offset + 1] = (value >>> 16)
    this[offset + 2] = (value >>> 8)
    this[offset + 3] = (value & 0xff)
  } else {
    objectWriteUInt32(this, value, offset, false)
  }
  return offset + 4
}

function checkIEEE754 (buf, value, offset, ext, max, min) {
  if (value > max || value < min) throw new RangeError('value is out of bounds')
  if (offset + ext > buf.length) throw new RangeError('index out of range')
  if (offset < 0) throw new RangeError('index out of range')
}

function writeFloat (buf, value, offset, littleEndian, noAssert) {
  if (!noAssert) {
    checkIEEE754(buf, value, offset, 4, 3.4028234663852886e+38, -3.4028234663852886e+38)
  }
  ieee754.write(buf, value, offset, littleEndian, 23, 4)
  return offset + 4
}

Buffer.prototype.writeFloatLE = function writeFloatLE (value, offset, noAssert) {
  return writeFloat(this, value, offset, true, noAssert)
}

Buffer.prototype.writeFloatBE = function writeFloatBE (value, offset, noAssert) {
  return writeFloat(this, value, offset, false, noAssert)
}

function writeDouble (buf, value, offset, littleEndian, noAssert) {
  if (!noAssert) {
    checkIEEE754(buf, value, offset, 8, 1.7976931348623157E+308, -1.7976931348623157E+308)
  }
  ieee754.write(buf, value, offset, littleEndian, 52, 8)
  return offset + 8
}

Buffer.prototype.writeDoubleLE = function writeDoubleLE (value, offset, noAssert) {
  return writeDouble(this, value, offset, true, noAssert)
}

Buffer.prototype.writeDoubleBE = function writeDoubleBE (value, offset, noAssert) {
  return writeDouble(this, value, offset, false, noAssert)
}

// copy(targetBuffer, targetStart=0, sourceStart=0, sourceEnd=buffer.length)
Buffer.prototype.copy = function copy (target, targetStart, start, end) {
  if (!start) start = 0
  if (!end && end !== 0) end = this.length
  if (targetStart >= target.length) targetStart = target.length
  if (!targetStart) targetStart = 0
  if (end > 0 && end < start) end = start

  // Copy 0 bytes; we're done
  if (end === start) return 0
  if (target.length === 0 || this.length === 0) return 0

  // Fatal error conditions
  if (targetStart < 0) {
    throw new RangeError('targetStart out of bounds')
  }
  if (start < 0 || start >= this.length) throw new RangeError('sourceStart out of bounds')
  if (end < 0) throw new RangeError('sourceEnd out of bounds')

  // Are we oob?
  if (end > this.length) end = this.length
  if (target.length - targetStart < end - start) {
    end = target.length - targetStart + start
  }

  var len = end - start
  var i

  if (this === target && start < targetStart && targetStart < end) {
    // descending copy from end
    for (i = len - 1; i >= 0; i--) {
      target[i + targetStart] = this[i + start]
    }
  } else if (len < 1000 || !Buffer.TYPED_ARRAY_SUPPORT) {
    // ascending copy from start
    for (i = 0; i < len; i++) {
      target[i + targetStart] = this[i + start]
    }
  } else {
    target._set(this.subarray(start, start + len), targetStart)
  }

  return len
}

// fill(value, start=0, end=buffer.length)
Buffer.prototype.fill = function fill (value, start, end) {
  if (!value) value = 0
  if (!start) start = 0
  if (!end) end = this.length

  if (end < start) throw new RangeError('end < start')

  // Fill 0 bytes; we're done
  if (end === start) return
  if (this.length === 0) return

  if (start < 0 || start >= this.length) throw new RangeError('start out of bounds')
  if (end < 0 || end > this.length) throw new RangeError('end out of bounds')

  var i
  if (typeof value === 'number') {
    for (i = start; i < end; i++) {
      this[i] = value
    }
  } else {
    var bytes = utf8ToBytes(value.toString())
    var len = bytes.length
    for (i = start; i < end; i++) {
      this[i] = bytes[i % len]
    }
  }

  return this
}

/**
 * Creates a new `ArrayBuffer` with the *copied* memory of the buffer instance.
 * Added in Node 0.12. Only available in browsers that support ArrayBuffer.
 */
Buffer.prototype.toArrayBuffer = function toArrayBuffer () {
  if (typeof Uint8Array !== 'undefined') {
    if (Buffer.TYPED_ARRAY_SUPPORT) {
      return (new Buffer(this)).buffer
    } else {
      var buf = new Uint8Array(this.length)
      for (var i = 0, len = buf.length; i < len; i += 1) {
        buf[i] = this[i]
      }
      return buf.buffer
    }
  } else {
    throw new TypeError('Buffer.toArrayBuffer not supported in this browser')
  }
}

// HELPER FUNCTIONS
// ================

var BP = Buffer.prototype

/**
 * Augment a Uint8Array *instance* (not the Uint8Array class!) with Buffer methods
 */
Buffer._augment = function _augment (arr) {
  arr.constructor = Buffer
  arr._isBuffer = true

  // save reference to original Uint8Array set method before overwriting
  arr._set = arr.set

  // deprecated
  arr.get = BP.get
  arr.set = BP.set

  arr.write = BP.write
  arr.toString = BP.toString
  arr.toLocaleString = BP.toString
  arr.toJSON = BP.toJSON
  arr.equals = BP.equals
  arr.compare = BP.compare
  arr.indexOf = BP.indexOf
  arr.copy = BP.copy
  arr.slice = BP.slice
  arr.readUIntLE = BP.readUIntLE
  arr.readUIntBE = BP.readUIntBE
  arr.readUInt8 = BP.readUInt8
  arr.readUInt16LE = BP.readUInt16LE
  arr.readUInt16BE = BP.readUInt16BE
  arr.readUInt32LE = BP.readUInt32LE
  arr.readUInt32BE = BP.readUInt32BE
  arr.readIntLE = BP.readIntLE
  arr.readIntBE = BP.readIntBE
  arr.readInt8 = BP.readInt8
  arr.readInt16LE = BP.readInt16LE
  arr.readInt16BE = BP.readInt16BE
  arr.readInt32LE = BP.readInt32LE
  arr.readInt32BE = BP.readInt32BE
  arr.readFloatLE = BP.readFloatLE
  arr.readFloatBE = BP.readFloatBE
  arr.readDoubleLE = BP.readDoubleLE
  arr.readDoubleBE = BP.readDoubleBE
  arr.writeUInt8 = BP.writeUInt8
  arr.writeUIntLE = BP.writeUIntLE
  arr.writeUIntBE = BP.writeUIntBE
  arr.writeUInt16LE = BP.writeUInt16LE
  arr.writeUInt16BE = BP.writeUInt16BE
  arr.writeUInt32LE = BP.writeUInt32LE
  arr.writeUInt32BE = BP.writeUInt32BE
  arr.writeIntLE = BP.writeIntLE
  arr.writeIntBE = BP.writeIntBE
  arr.writeInt8 = BP.writeInt8
  arr.writeInt16LE = BP.writeInt16LE
  arr.writeInt16BE = BP.writeInt16BE
  arr.writeInt32LE = BP.writeInt32LE
  arr.writeInt32BE = BP.writeInt32BE
  arr.writeFloatLE = BP.writeFloatLE
  arr.writeFloatBE = BP.writeFloatBE
  arr.writeDoubleLE = BP.writeDoubleLE
  arr.writeDoubleBE = BP.writeDoubleBE
  arr.fill = BP.fill
  arr.inspect = BP.inspect
  arr.toArrayBuffer = BP.toArrayBuffer

  return arr
}

var INVALID_BASE64_RE = /[^+\/0-9A-Za-z-_]/g

function base64clean (str) {
  // Node strips out invalid characters like \n and \t from the string, base64-js does not
  str = stringtrim(str).replace(INVALID_BASE64_RE, '')
  // Node converts strings with length < 2 to ''
  if (str.length < 2) return ''
  // Node allows for non-padded base64 strings (missing trailing ===), base64-js does not
  while (str.length % 4 !== 0) {
    str = str + '='
  }
  return str
}

function stringtrim (str) {
  if (str.trim) return str.trim()
  return str.replace(/^\s+|\s+$/g, '')
}

function toHex (n) {
  if (n < 16) return '0' + n.toString(16)
  return n.toString(16)
}

function utf8ToBytes (string, units) {
  units = units || Infinity
  var codePoint
  var length = string.length
  var leadSurrogate = null
  var bytes = []

  for (var i = 0; i < length; i++) {
    codePoint = string.charCodeAt(i)

    // is surrogate component
    if (codePoint > 0xD7FF && codePoint < 0xE000) {
      // last char was a lead
      if (!leadSurrogate) {
        // no lead yet
        if (codePoint > 0xDBFF) {
          // unexpected trail
          if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD)
          continue
        } else if (i + 1 === length) {
          // unpaired lead
          if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD)
          continue
        }

        // valid lead
        leadSurrogate = codePoint

        continue
      }

      // 2 leads in a row
      if (codePoint < 0xDC00) {
        if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD)
        leadSurrogate = codePoint
        continue
      }

      // valid surrogate pair
      codePoint = (leadSurrogate - 0xD800 << 10 | codePoint - 0xDC00) + 0x10000
    } else if (leadSurrogate) {
      // valid bmp char, but last char was a lead
      if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD)
    }

    leadSurrogate = null

    // encode utf8
    if (codePoint < 0x80) {
      if ((units -= 1) < 0) break
      bytes.push(codePoint)
    } else if (codePoint < 0x800) {
      if ((units -= 2) < 0) break
      bytes.push(
        codePoint >> 0x6 | 0xC0,
        codePoint & 0x3F | 0x80
      )
    } else if (codePoint < 0x10000) {
      if ((units -= 3) < 0) break
      bytes.push(
        codePoint >> 0xC | 0xE0,
        codePoint >> 0x6 & 0x3F | 0x80,
        codePoint & 0x3F | 0x80
      )
    } else if (codePoint < 0x110000) {
      if ((units -= 4) < 0) break
      bytes.push(
        codePoint >> 0x12 | 0xF0,
        codePoint >> 0xC & 0x3F | 0x80,
        codePoint >> 0x6 & 0x3F | 0x80,
        codePoint & 0x3F | 0x80
      )
    } else {
      throw new Error('Invalid code point')
    }
  }

  return bytes
}

function asciiToBytes (str) {
  var byteArray = []
  for (var i = 0; i < str.length; i++) {
    // Node's code seems to be doing this and not & 0x7F..
    byteArray.push(str.charCodeAt(i) & 0xFF)
  }
  return byteArray
}

function utf16leToBytes (str, units) {
  var c, hi, lo
  var byteArray = []
  for (var i = 0; i < str.length; i++) {
    if ((units -= 2) < 0) break

    c = str.charCodeAt(i)
    hi = c >> 8
    lo = c % 256
    byteArray.push(lo)
    byteArray.push(hi)
  }

  return byteArray
}

function base64ToBytes (str) {
  return base64.toByteArray(base64clean(str))
}

function blitBuffer (src, dst, offset, length) {
  for (var i = 0; i < length; i++) {
    if ((i + offset >= dst.length) || (i >= src.length)) break
    dst[i + offset] = src[i]
  }
  return i
}

}).call(this,typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {})

},{"base64-js":58,"ieee754":59,"isarray":60}],58:[function(require,module,exports){
var lookup = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';

;(function (exports) {
	'use strict';

  var Arr = (typeof Uint8Array !== 'undefined')
    ? Uint8Array
    : Array

	var PLUS   = '+'.charCodeAt(0)
	var SLASH  = '/'.charCodeAt(0)
	var NUMBER = '0'.charCodeAt(0)
	var LOWER  = 'a'.charCodeAt(0)
	var UPPER  = 'A'.charCodeAt(0)
	var PLUS_URL_SAFE = '-'.charCodeAt(0)
	var SLASH_URL_SAFE = '_'.charCodeAt(0)

	function decode (elt) {
		var code = elt.charCodeAt(0)
		if (code === PLUS ||
		    code === PLUS_URL_SAFE)
			return 62 // '+'
		if (code === SLASH ||
		    code === SLASH_URL_SAFE)
			return 63 // '/'
		if (code < NUMBER)
			return -1 //no match
		if (code < NUMBER + 10)
			return code - NUMBER + 26 + 26
		if (code < UPPER + 26)
			return code - UPPER
		if (code < LOWER + 26)
			return code - LOWER + 26
	}

	function b64ToByteArray (b64) {
		var i, j, l, tmp, placeHolders, arr

		if (b64.length % 4 > 0) {
			throw new Error('Invalid string. Length must be a multiple of 4')
		}

		// the number of equal signs (place holders)
		// if there are two placeholders, than the two characters before it
		// represent one byte
		// if there is only one, then the three characters before it represent 2 bytes
		// this is just a cheap hack to not do indexOf twice
		var len = b64.length
		placeHolders = '=' === b64.charAt(len - 2) ? 2 : '=' === b64.charAt(len - 1) ? 1 : 0

		// base64 is 4/3 + up to two characters of the original data
		arr = new Arr(b64.length * 3 / 4 - placeHolders)

		// if there are placeholders, only get up to the last complete 4 chars
		l = placeHolders > 0 ? b64.length - 4 : b64.length

		var L = 0

		function push (v) {
			arr[L++] = v
		}

		for (i = 0, j = 0; i < l; i += 4, j += 3) {
			tmp = (decode(b64.charAt(i)) << 18) | (decode(b64.charAt(i + 1)) << 12) | (decode(b64.charAt(i + 2)) << 6) | decode(b64.charAt(i + 3))
			push((tmp & 0xFF0000) >> 16)
			push((tmp & 0xFF00) >> 8)
			push(tmp & 0xFF)
		}

		if (placeHolders === 2) {
			tmp = (decode(b64.charAt(i)) << 2) | (decode(b64.charAt(i + 1)) >> 4)
			push(tmp & 0xFF)
		} else if (placeHolders === 1) {
			tmp = (decode(b64.charAt(i)) << 10) | (decode(b64.charAt(i + 1)) << 4) | (decode(b64.charAt(i + 2)) >> 2)
			push((tmp >> 8) & 0xFF)
			push(tmp & 0xFF)
		}

		return arr
	}

	function uint8ToBase64 (uint8) {
		var i,
			extraBytes = uint8.length % 3, // if we have 1 byte left, pad 2 bytes
			output = "",
			temp, length

		function encode (num) {
			return lookup.charAt(num)
		}

		function tripletToBase64 (num) {
			return encode(num >> 18 & 0x3F) + encode(num >> 12 & 0x3F) + encode(num >> 6 & 0x3F) + encode(num & 0x3F)
		}

		// go through the array every three bytes, we'll deal with trailing stuff later
		for (i = 0, length = uint8.length - extraBytes; i < length; i += 3) {
			temp = (uint8[i] << 16) + (uint8[i + 1] << 8) + (uint8[i + 2])
			output += tripletToBase64(temp)
		}

		// pad the end with zeros, but make sure to not forget the extra bytes
		switch (extraBytes) {
			case 1:
				temp = uint8[uint8.length - 1]
				output += encode(temp >> 2)
				output += encode((temp << 4) & 0x3F)
				output += '=='
				break
			case 2:
				temp = (uint8[uint8.length - 2] << 8) + (uint8[uint8.length - 1])
				output += encode(temp >> 10)
				output += encode((temp >> 4) & 0x3F)
				output += encode((temp << 2) & 0x3F)
				output += '='
				break
		}

		return output
	}

	exports.toByteArray = b64ToByteArray
	exports.fromByteArray = uint8ToBase64
}(typeof exports === 'undefined' ? (this.base64js = {}) : exports))

},{}],59:[function(require,module,exports){
exports.read = function (buffer, offset, isLE, mLen, nBytes) {
  var e, m
  var eLen = nBytes * 8 - mLen - 1
  var eMax = (1 << eLen) - 1
  var eBias = eMax >> 1
  var nBits = -7
  var i = isLE ? (nBytes - 1) : 0
  var d = isLE ? -1 : 1
  var s = buffer[offset + i]

  i += d

  e = s & ((1 << (-nBits)) - 1)
  s >>= (-nBits)
  nBits += eLen
  for (; nBits > 0; e = e * 256 + buffer[offset + i], i += d, nBits -= 8) {}

  m = e & ((1 << (-nBits)) - 1)
  e >>= (-nBits)
  nBits += mLen
  for (; nBits > 0; m = m * 256 + buffer[offset + i], i += d, nBits -= 8) {}

  if (e === 0) {
    e = 1 - eBias
  } else if (e === eMax) {
    return m ? NaN : ((s ? -1 : 1) * Infinity)
  } else {
    m = m + Math.pow(2, mLen)
    e = e - eBias
  }
  return (s ? -1 : 1) * m * Math.pow(2, e - mLen)
}

exports.write = function (buffer, value, offset, isLE, mLen, nBytes) {
  var e, m, c
  var eLen = nBytes * 8 - mLen - 1
  var eMax = (1 << eLen) - 1
  var eBias = eMax >> 1
  var rt = (mLen === 23 ? Math.pow(2, -24) - Math.pow(2, -77) : 0)
  var i = isLE ? 0 : (nBytes - 1)
  var d = isLE ? 1 : -1
  var s = value < 0 || (value === 0 && 1 / value < 0) ? 1 : 0

  value = Math.abs(value)

  if (isNaN(value) || value === Infinity) {
    m = isNaN(value) ? 1 : 0
    e = eMax
  } else {
    e = Math.floor(Math.log(value) / Math.LN2)
    if (value * (c = Math.pow(2, -e)) < 1) {
      e--
      c *= 2
    }
    if (e + eBias >= 1) {
      value += rt / c
    } else {
      value += rt * Math.pow(2, 1 - eBias)
    }
    if (value * c >= 2) {
      e++
      c /= 2
    }

    if (e + eBias >= eMax) {
      m = 0
      e = eMax
    } else if (e + eBias >= 1) {
      m = (value * c - 1) * Math.pow(2, mLen)
      e = e + eBias
    } else {
      m = value * Math.pow(2, eBias - 1) * Math.pow(2, mLen)
      e = 0
    }
  }

  for (; mLen >= 8; buffer[offset + i] = m & 0xff, i += d, m /= 256, mLen -= 8) {}

  e = (e << mLen) | m
  eLen += mLen
  for (; eLen > 0; buffer[offset + i] = e & 0xff, i += d, e /= 256, eLen -= 8) {}

  buffer[offset + i - d] |= s * 128
}

},{}],60:[function(require,module,exports){
var toString = {}.toString;

module.exports = Array.isArray || function (arr) {
  return toString.call(arr) == '[object Array]';
};

},{}],61:[function(require,module,exports){
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.

function EventEmitter() {
  this._events = this._events || {};
  this._maxListeners = this._maxListeners || undefined;
}
module.exports = EventEmitter;

// Backwards-compat with node 0.10.x
EventEmitter.EventEmitter = EventEmitter;

EventEmitter.prototype._events = undefined;
EventEmitter.prototype._maxListeners = undefined;

// By default EventEmitters will print a warning if more than 10 listeners are
// added to it. This is a useful default which helps finding memory leaks.
EventEmitter.defaultMaxListeners = 10;

// Obviously not all Emitters should be limited to 10. This function allows
// that to be increased. Set to zero for unlimited.
EventEmitter.prototype.setMaxListeners = function(n) {
  if (!isNumber(n) || n < 0 || isNaN(n))
    throw TypeError('n must be a positive number');
  this._maxListeners = n;
  return this;
};

EventEmitter.prototype.emit = function(type) {
  var er, handler, len, args, i, listeners;

  if (!this._events)
    this._events = {};

  // If there is no 'error' event listener then throw.
  if (type === 'error') {
    if (!this._events.error ||
        (isObject(this._events.error) && !this._events.error.length)) {
      er = arguments[1];
      if (er instanceof Error) {
        throw er; // Unhandled 'error' event
      }
      throw TypeError('Uncaught, unspecified "error" event.');
    }
  }

  handler = this._events[type];

  if (isUndefined(handler))
    return false;

  if (isFunction(handler)) {
    switch (arguments.length) {
      // fast cases
      case 1:
        handler.call(this);
        break;
      case 2:
        handler.call(this, arguments[1]);
        break;
      case 3:
        handler.call(this, arguments[1], arguments[2]);
        break;
      // slower
      default:
        args = Array.prototype.slice.call(arguments, 1);
        handler.apply(this, args);
    }
  } else if (isObject(handler)) {
    args = Array.prototype.slice.call(arguments, 1);
    listeners = handler.slice();
    len = listeners.length;
    for (i = 0; i < len; i++)
      listeners[i].apply(this, args);
  }

  return true;
};

EventEmitter.prototype.addListener = function(type, listener) {
  var m;

  if (!isFunction(listener))
    throw TypeError('listener must be a function');

  if (!this._events)
    this._events = {};

  // To avoid recursion in the case that type === "newListener"! Before
  // adding it to the listeners, first emit "newListener".
  if (this._events.newListener)
    this.emit('newListener', type,
              isFunction(listener.listener) ?
              listener.listener : listener);

  if (!this._events[type])
    // Optimize the case of one listener. Don't need the extra array object.
    this._events[type] = listener;
  else if (isObject(this._events[type]))
    // If we've already got an array, just append.
    this._events[type].push(listener);
  else
    // Adding the second element, need to change to array.
    this._events[type] = [this._events[type], listener];

  // Check for listener leak
  if (isObject(this._events[type]) && !this._events[type].warned) {
    if (!isUndefined(this._maxListeners)) {
      m = this._maxListeners;
    } else {
      m = EventEmitter.defaultMaxListeners;
    }

    if (m && m > 0 && this._events[type].length > m) {
      this._events[type].warned = true;
      console.error('(node) warning: possible EventEmitter memory ' +
                    'leak detected. %d listeners added. ' +
                    'Use emitter.setMaxListeners() to increase limit.',
                    this._events[type].length);
      if (typeof console.trace === 'function') {
        // not supported in IE 10
        console.trace();
      }
    }
  }

  return this;
};

EventEmitter.prototype.on = EventEmitter.prototype.addListener;

EventEmitter.prototype.once = function(type, listener) {
  if (!isFunction(listener))
    throw TypeError('listener must be a function');

  var fired = false;

  function g() {
    this.removeListener(type, g);

    if (!fired) {
      fired = true;
      listener.apply(this, arguments);
    }
  }

  g.listener = listener;
  this.on(type, g);

  return this;
};

// emits a 'removeListener' event iff the listener was removed
EventEmitter.prototype.removeListener = function(type, listener) {
  var list, position, length, i;

  if (!isFunction(listener))
    throw TypeError('listener must be a function');

  if (!this._events || !this._events[type])
    return this;

  list = this._events[type];
  length = list.length;
  position = -1;

  if (list === listener ||
      (isFunction(list.listener) && list.listener === listener)) {
    delete this._events[type];
    if (this._events.removeListener)
      this.emit('removeListener', type, listener);

  } else if (isObject(list)) {
    for (i = length; i-- > 0;) {
      if (list[i] === listener ||
          (list[i].listener && list[i].listener === listener)) {
        position = i;
        break;
      }
    }

    if (position < 0)
      return this;

    if (list.length === 1) {
      list.length = 0;
      delete this._events[type];
    } else {
      list.splice(position, 1);
    }

    if (this._events.removeListener)
      this.emit('removeListener', type, listener);
  }

  return this;
};

EventEmitter.prototype.removeAllListeners = function(type) {
  var key, listeners;

  if (!this._events)
    return this;

  // not listening for removeListener, no need to emit
  if (!this._events.removeListener) {
    if (arguments.length === 0)
      this._events = {};
    else if (this._events[type])
      delete this._events[type];
    return this;
  }

  // emit removeListener for all listeners on all events
  if (arguments.length === 0) {
    for (key in this._events) {
      if (key === 'removeListener') continue;
      this.removeAllListeners(key);
    }
    this.removeAllListeners('removeListener');
    this._events = {};
    return this;
  }

  listeners = this._events[type];

  if (isFunction(listeners)) {
    this.removeListener(type, listeners);
  } else if (listeners) {
    // LIFO order
    while (listeners.length)
      this.removeListener(type, listeners[listeners.length - 1]);
  }
  delete this._events[type];

  return this;
};

EventEmitter.prototype.listeners = function(type) {
  var ret;
  if (!this._events || !this._events[type])
    ret = [];
  else if (isFunction(this._events[type]))
    ret = [this._events[type]];
  else
    ret = this._events[type].slice();
  return ret;
};

EventEmitter.prototype.listenerCount = function(type) {
  if (this._events) {
    var evlistener = this._events[type];

    if (isFunction(evlistener))
      return 1;
    else if (evlistener)
      return evlistener.length;
  }
  return 0;
};

EventEmitter.listenerCount = function(emitter, type) {
  return emitter.listenerCount(type);
};

function isFunction(arg) {
  return typeof arg === 'function';
}

function isNumber(arg) {
  return typeof arg === 'number';
}

function isObject(arg) {
  return typeof arg === 'object' && arg !== null;
}

function isUndefined(arg) {
  return arg === void 0;
}

},{}],62:[function(require,module,exports){
var http = require('http');

var https = module.exports;

for (var key in http) {
    if (http.hasOwnProperty(key)) https[key] = http[key];
};

https.request = function (params, cb) {
    if (!params) params = {};
    params.scheme = 'https';
    params.protocol = 'https:';
    return http.request.call(this, params, cb);
}

},{"http":85}],63:[function(require,module,exports){
if (typeof Object.create === 'function') {
  // implementation from standard node.js 'util' module
  module.exports = function inherits(ctor, superCtor) {
    ctor.super_ = superCtor
    ctor.prototype = Object.create(superCtor.prototype, {
      constructor: {
        value: ctor,
        enumerable: false,
        writable: true,
        configurable: true
      }
    });
  };
} else {
  // old school shim for old browsers
  module.exports = function inherits(ctor, superCtor) {
    ctor.super_ = superCtor
    var TempCtor = function () {}
    TempCtor.prototype = superCtor.prototype
    ctor.prototype = new TempCtor()
    ctor.prototype.constructor = ctor
  }
}

},{}],64:[function(require,module,exports){
/**
 * Determine if an object is Buffer
 *
 * Author:   Feross Aboukhadijeh <feross@feross.org> <http://feross.org>
 * License:  MIT
 *
 * `npm install is-buffer`
 */

module.exports = function (obj) {
  return !!(obj != null &&
    (obj._isBuffer || // For Safari 5-7 (missing Object.prototype.constructor)
      (obj.constructor &&
      typeof obj.constructor.isBuffer === 'function' &&
      obj.constructor.isBuffer(obj))
    ))
}

},{}],65:[function(require,module,exports){
module.exports = Array.isArray || function (arr) {
  return Object.prototype.toString.call(arr) == '[object Array]';
};

},{}],66:[function(require,module,exports){
// shim for using process in browser

var process = module.exports = {};
var queue = [];
var draining = false;
var currentQueue;
var queueIndex = -1;

function cleanUpNextTick() {
    draining = false;
    if (currentQueue.length) {
        queue = currentQueue.concat(queue);
    } else {
        queueIndex = -1;
    }
    if (queue.length) {
        drainQueue();
    }
}

function drainQueue() {
    if (draining) {
        return;
    }
    var timeout = setTimeout(cleanUpNextTick);
    draining = true;

    var len = queue.length;
    while(len) {
        currentQueue = queue;
        queue = [];
        while (++queueIndex < len) {
            if (currentQueue) {
                currentQueue[queueIndex].run();
            }
        }
        queueIndex = -1;
        len = queue.length;
    }
    currentQueue = null;
    draining = false;
    clearTimeout(timeout);
}

process.nextTick = function (fun) {
    var args = new Array(arguments.length - 1);
    if (arguments.length > 1) {
        for (var i = 1; i < arguments.length; i++) {
            args[i - 1] = arguments[i];
        }
    }
    queue.push(new Item(fun, args));
    if (queue.length === 1 && !draining) {
        setTimeout(drainQueue, 0);
    }
};

// v8 likes predictible objects
function Item(fun, array) {
    this.fun = fun;
    this.array = array;
}
Item.prototype.run = function () {
    this.fun.apply(null, this.array);
};
process.title = 'browser';
process.browser = true;
process.env = {};
process.argv = [];
process.version = ''; // empty string to avoid regexp issues
process.versions = {};

function noop() {}

process.on = noop;
process.addListener = noop;
process.once = noop;
process.off = noop;
process.removeListener = noop;
process.removeAllListeners = noop;
process.emit = noop;

process.binding = function (name) {
    throw new Error('process.binding is not supported');
};

process.cwd = function () { return '/' };
process.chdir = function (dir) {
    throw new Error('process.chdir is not supported');
};
process.umask = function() { return 0; };

},{}],67:[function(require,module,exports){
(function (global){
/*! https://mths.be/punycode v1.4.0 by @mathias */
;(function(root) {

	/** Detect free variables */
	var freeExports = typeof exports == 'object' && exports &&
		!exports.nodeType && exports;
	var freeModule = typeof module == 'object' && module &&
		!module.nodeType && module;
	var freeGlobal = typeof global == 'object' && global;
	if (
		freeGlobal.global === freeGlobal ||
		freeGlobal.window === freeGlobal ||
		freeGlobal.self === freeGlobal
	) {
		root = freeGlobal;
	}

	/**
	 * The `punycode` object.
	 * @name punycode
	 * @type Object
	 */
	var punycode,

	/** Highest positive signed 32-bit float value */
	maxInt = 2147483647, // aka. 0x7FFFFFFF or 2^31-1

	/** Bootstring parameters */
	base = 36,
	tMin = 1,
	tMax = 26,
	skew = 38,
	damp = 700,
	initialBias = 72,
	initialN = 128, // 0x80
	delimiter = '-', // '\x2D'

	/** Regular expressions */
	regexPunycode = /^xn--/,
	regexNonASCII = /[^\x20-\x7E]/, // unprintable ASCII chars + non-ASCII chars
	regexSeparators = /[\x2E\u3002\uFF0E\uFF61]/g, // RFC 3490 separators

	/** Error messages */
	errors = {
		'overflow': 'Overflow: input needs wider integers to process',
		'not-basic': 'Illegal input >= 0x80 (not a basic code point)',
		'invalid-input': 'Invalid input'
	},

	/** Convenience shortcuts */
	baseMinusTMin = base - tMin,
	floor = Math.floor,
	stringFromCharCode = String.fromCharCode,

	/** Temporary variable */
	key;

	/*--------------------------------------------------------------------------*/

	/**
	 * A generic error utility function.
	 * @private
	 * @param {String} type The error type.
	 * @returns {Error} Throws a `RangeError` with the applicable error message.
	 */
	function error(type) {
		throw new RangeError(errors[type]);
	}

	/**
	 * A generic `Array#map` utility function.
	 * @private
	 * @param {Array} array The array to iterate over.
	 * @param {Function} callback The function that gets called for every array
	 * item.
	 * @returns {Array} A new array of values returned by the callback function.
	 */
	function map(array, fn) {
		var length = array.length;
		var result = [];
		while (length--) {
			result[length] = fn(array[length]);
		}
		return result;
	}

	/**
	 * A simple `Array#map`-like wrapper to work with domain name strings or email
	 * addresses.
	 * @private
	 * @param {String} domain The domain name or email address.
	 * @param {Function} callback The function that gets called for every
	 * character.
	 * @returns {Array} A new string of characters returned by the callback
	 * function.
	 */
	function mapDomain(string, fn) {
		var parts = string.split('@');
		var result = '';
		if (parts.length > 1) {
			// In email addresses, only the domain name should be punycoded. Leave
			// the local part (i.e. everything up to `@`) intact.
			result = parts[0] + '@';
			string = parts[1];
		}
		// Avoid `split(regex)` for IE8 compatibility. See #17.
		string = string.replace(regexSeparators, '\x2E');
		var labels = string.split('.');
		var encoded = map(labels, fn).join('.');
		return result + encoded;
	}

	/**
	 * Creates an array containing the numeric code points of each Unicode
	 * character in the string. While JavaScript uses UCS-2 internally,
	 * this function will convert a pair of surrogate halves (each of which
	 * UCS-2 exposes as separate characters) into a single code point,
	 * matching UTF-16.
	 * @see `punycode.ucs2.encode`
	 * @see <https://mathiasbynens.be/notes/javascript-encoding>
	 * @memberOf punycode.ucs2
	 * @name decode
	 * @param {String} string The Unicode input string (UCS-2).
	 * @returns {Array} The new array of code points.
	 */
	function ucs2decode(string) {
		var output = [],
		    counter = 0,
		    length = string.length,
		    value,
		    extra;
		while (counter < length) {
			value = string.charCodeAt(counter++);
			if (value >= 0xD800 && value <= 0xDBFF && counter < length) {
				// high surrogate, and there is a next character
				extra = string.charCodeAt(counter++);
				if ((extra & 0xFC00) == 0xDC00) { // low surrogate
					output.push(((value & 0x3FF) << 10) + (extra & 0x3FF) + 0x10000);
				} else {
					// unmatched surrogate; only append this code unit, in case the next
					// code unit is the high surrogate of a surrogate pair
					output.push(value);
					counter--;
				}
			} else {
				output.push(value);
			}
		}
		return output;
	}

	/**
	 * Creates a string based on an array of numeric code points.
	 * @see `punycode.ucs2.decode`
	 * @memberOf punycode.ucs2
	 * @name encode
	 * @param {Array} codePoints The array of numeric code points.
	 * @returns {String} The new Unicode string (UCS-2).
	 */
	function ucs2encode(array) {
		return map(array, function(value) {
			var output = '';
			if (value > 0xFFFF) {
				value -= 0x10000;
				output += stringFromCharCode(value >>> 10 & 0x3FF | 0xD800);
				value = 0xDC00 | value & 0x3FF;
			}
			output += stringFromCharCode(value);
			return output;
		}).join('');
	}

	/**
	 * Converts a basic code point into a digit/integer.
	 * @see `digitToBasic()`
	 * @private
	 * @param {Number} codePoint The basic numeric code point value.
	 * @returns {Number} The numeric value of a basic code point (for use in
	 * representing integers) in the range `0` to `base - 1`, or `base` if
	 * the code point does not represent a value.
	 */
	function basicToDigit(codePoint) {
		if (codePoint - 48 < 10) {
			return codePoint - 22;
		}
		if (codePoint - 65 < 26) {
			return codePoint - 65;
		}
		if (codePoint - 97 < 26) {
			return codePoint - 97;
		}
		return base;
	}

	/**
	 * Converts a digit/integer into a basic code point.
	 * @see `basicToDigit()`
	 * @private
	 * @param {Number} digit The numeric value of a basic code point.
	 * @returns {Number} The basic code point whose value (when used for
	 * representing integers) is `digit`, which needs to be in the range
	 * `0` to `base - 1`. If `flag` is non-zero, the uppercase form is
	 * used; else, the lowercase form is used. The behavior is undefined
	 * if `flag` is non-zero and `digit` has no uppercase form.
	 */
	function digitToBasic(digit, flag) {
		//  0..25 map to ASCII a..z or A..Z
		// 26..35 map to ASCII 0..9
		return digit + 22 + 75 * (digit < 26) - ((flag != 0) << 5);
	}

	/**
	 * Bias adaptation function as per section 3.4 of RFC 3492.
	 * https://tools.ietf.org/html/rfc3492#section-3.4
	 * @private
	 */
	function adapt(delta, numPoints, firstTime) {
		var k = 0;
		delta = firstTime ? floor(delta / damp) : delta >> 1;
		delta += floor(delta / numPoints);
		for (/* no initialization */; delta > baseMinusTMin * tMax >> 1; k += base) {
			delta = floor(delta / baseMinusTMin);
		}
		return floor(k + (baseMinusTMin + 1) * delta / (delta + skew));
	}

	/**
	 * Converts a Punycode string of ASCII-only symbols to a string of Unicode
	 * symbols.
	 * @memberOf punycode
	 * @param {String} input The Punycode string of ASCII-only symbols.
	 * @returns {String} The resulting string of Unicode symbols.
	 */
	function decode(input) {
		// Don't use UCS-2
		var output = [],
		    inputLength = input.length,
		    out,
		    i = 0,
		    n = initialN,
		    bias = initialBias,
		    basic,
		    j,
		    index,
		    oldi,
		    w,
		    k,
		    digit,
		    t,
		    /** Cached calculation results */
		    baseMinusT;

		// Handle the basic code points: let `basic` be the number of input code
		// points before the last delimiter, or `0` if there is none, then copy
		// the first basic code points to the output.

		basic = input.lastIndexOf(delimiter);
		if (basic < 0) {
			basic = 0;
		}

		for (j = 0; j < basic; ++j) {
			// if it's not a basic code point
			if (input.charCodeAt(j) >= 0x80) {
				error('not-basic');
			}
			output.push(input.charCodeAt(j));
		}

		// Main decoding loop: start just after the last delimiter if any basic code
		// points were copied; start at the beginning otherwise.

		for (index = basic > 0 ? basic + 1 : 0; index < inputLength; /* no final expression */) {

			// `index` is the index of the next character to be consumed.
			// Decode a generalized variable-length integer into `delta`,
			// which gets added to `i`. The overflow checking is easier
			// if we increase `i` as we go, then subtract off its starting
			// value at the end to obtain `delta`.
			for (oldi = i, w = 1, k = base; /* no condition */; k += base) {

				if (index >= inputLength) {
					error('invalid-input');
				}

				digit = basicToDigit(input.charCodeAt(index++));

				if (digit >= base || digit > floor((maxInt - i) / w)) {
					error('overflow');
				}

				i += digit * w;
				t = k <= bias ? tMin : (k >= bias + tMax ? tMax : k - bias);

				if (digit < t) {
					break;
				}

				baseMinusT = base - t;
				if (w > floor(maxInt / baseMinusT)) {
					error('overflow');
				}

				w *= baseMinusT;

			}

			out = output.length + 1;
			bias = adapt(i - oldi, out, oldi == 0);

			// `i` was supposed to wrap around from `out` to `0`,
			// incrementing `n` each time, so we'll fix that now:
			if (floor(i / out) > maxInt - n) {
				error('overflow');
			}

			n += floor(i / out);
			i %= out;

			// Insert `n` at position `i` of the output
			output.splice(i++, 0, n);

		}

		return ucs2encode(output);
	}

	/**
	 * Converts a string of Unicode symbols (e.g. a domain name label) to a
	 * Punycode string of ASCII-only symbols.
	 * @memberOf punycode
	 * @param {String} input The string of Unicode symbols.
	 * @returns {String} The resulting Punycode string of ASCII-only symbols.
	 */
	function encode(input) {
		var n,
		    delta,
		    handledCPCount,
		    basicLength,
		    bias,
		    j,
		    m,
		    q,
		    k,
		    t,
		    currentValue,
		    output = [],
		    /** `inputLength` will hold the number of code points in `input`. */
		    inputLength,
		    /** Cached calculation results */
		    handledCPCountPlusOne,
		    baseMinusT,
		    qMinusT;

		// Convert the input in UCS-2 to Unicode
		input = ucs2decode(input);

		// Cache the length
		inputLength = input.length;

		// Initialize the state
		n = initialN;
		delta = 0;
		bias = initialBias;

		// Handle the basic code points
		for (j = 0; j < inputLength; ++j) {
			currentValue = input[j];
			if (currentValue < 0x80) {
				output.push(stringFromCharCode(currentValue));
			}
		}

		handledCPCount = basicLength = output.length;

		// `handledCPCount` is the number of code points that have been handled;
		// `basicLength` is the number of basic code points.

		// Finish the basic string - if it is not empty - with a delimiter
		if (basicLength) {
			output.push(delimiter);
		}

		// Main encoding loop:
		while (handledCPCount < inputLength) {

			// All non-basic code points < n have been handled already. Find the next
			// larger one:
			for (m = maxInt, j = 0; j < inputLength; ++j) {
				currentValue = input[j];
				if (currentValue >= n && currentValue < m) {
					m = currentValue;
				}
			}

			// Increase `delta` enough to advance the decoder's <n,i> state to <m,0>,
			// but guard against overflow
			handledCPCountPlusOne = handledCPCount + 1;
			if (m - n > floor((maxInt - delta) / handledCPCountPlusOne)) {
				error('overflow');
			}

			delta += (m - n) * handledCPCountPlusOne;
			n = m;

			for (j = 0; j < inputLength; ++j) {
				currentValue = input[j];

				if (currentValue < n && ++delta > maxInt) {
					error('overflow');
				}

				if (currentValue == n) {
					// Represent delta as a generalized variable-length integer
					for (q = delta, k = base; /* no condition */; k += base) {
						t = k <= bias ? tMin : (k >= bias + tMax ? tMax : k - bias);
						if (q < t) {
							break;
						}
						qMinusT = q - t;
						baseMinusT = base - t;
						output.push(
							stringFromCharCode(digitToBasic(t + qMinusT % baseMinusT, 0))
						);
						q = floor(qMinusT / baseMinusT);
					}

					output.push(stringFromCharCode(digitToBasic(q, 0)));
					bias = adapt(delta, handledCPCountPlusOne, handledCPCount == basicLength);
					delta = 0;
					++handledCPCount;
				}
			}

			++delta;
			++n;

		}
		return output.join('');
	}

	/**
	 * Converts a Punycode string representing a domain name or an email address
	 * to Unicode. Only the Punycoded parts of the input will be converted, i.e.
	 * it doesn't matter if you call it on a string that has already been
	 * converted to Unicode.
	 * @memberOf punycode
	 * @param {String} input The Punycoded domain name or email address to
	 * convert to Unicode.
	 * @returns {String} The Unicode representation of the given Punycode
	 * string.
	 */
	function toUnicode(input) {
		return mapDomain(input, function(string) {
			return regexPunycode.test(string)
				? decode(string.slice(4).toLowerCase())
				: string;
		});
	}

	/**
	 * Converts a Unicode string representing a domain name or an email address to
	 * Punycode. Only the non-ASCII parts of the domain name will be converted,
	 * i.e. it doesn't matter if you call it with a domain that's already in
	 * ASCII.
	 * @memberOf punycode
	 * @param {String} input The domain name or email address to convert, as a
	 * Unicode string.
	 * @returns {String} The Punycode representation of the given domain name or
	 * email address.
	 */
	function toASCII(input) {
		return mapDomain(input, function(string) {
			return regexNonASCII.test(string)
				? 'xn--' + encode(string)
				: string;
		});
	}

	/*--------------------------------------------------------------------------*/

	/** Define the public API */
	punycode = {
		/**
		 * A string representing the current Punycode.js version number.
		 * @memberOf punycode
		 * @type String
		 */
		'version': '1.3.2',
		/**
		 * An object of methods to convert from JavaScript's internal character
		 * representation (UCS-2) to Unicode code points, and back.
		 * @see <https://mathiasbynens.be/notes/javascript-encoding>
		 * @memberOf punycode
		 * @type Object
		 */
		'ucs2': {
			'decode': ucs2decode,
			'encode': ucs2encode
		},
		'decode': decode,
		'encode': encode,
		'toASCII': toASCII,
		'toUnicode': toUnicode
	};

	/** Expose `punycode` */
	// Some AMD build optimizers, like r.js, check for specific condition patterns
	// like the following:
	if (
		typeof define == 'function' &&
		typeof define.amd == 'object' &&
		define.amd
	) {
		define('punycode', function() {
			return punycode;
		});
	} else if (freeExports && freeModule) {
		if (module.exports == freeExports) {
			// in Node.js, io.js, or RingoJS v0.8.0+
			freeModule.exports = punycode;
		} else {
			// in Narwhal or RingoJS v0.7.0-
			for (key in punycode) {
				punycode.hasOwnProperty(key) && (freeExports[key] = punycode[key]);
			}
		}
	} else {
		// in Rhino or a web browser
		root.punycode = punycode;
	}

}(this));

}).call(this,typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {})

},{}],68:[function(require,module,exports){
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.

'use strict';

// If obj.hasOwnProperty has been overridden, then calling
// obj.hasOwnProperty(prop) will break.
// See: https://github.com/joyent/node/issues/1707
function hasOwnProperty(obj, prop) {
  return Object.prototype.hasOwnProperty.call(obj, prop);
}

module.exports = function(qs, sep, eq, options) {
  sep = sep || '&';
  eq = eq || '=';
  var obj = {};

  if (typeof qs !== 'string' || qs.length === 0) {
    return obj;
  }

  var regexp = /\+/g;
  qs = qs.split(sep);

  var maxKeys = 1000;
  if (options && typeof options.maxKeys === 'number') {
    maxKeys = options.maxKeys;
  }

  var len = qs.length;
  // maxKeys <= 0 means that we should not limit keys count
  if (maxKeys > 0 && len > maxKeys) {
    len = maxKeys;
  }

  for (var i = 0; i < len; ++i) {
    var x = qs[i].replace(regexp, '%20'),
        idx = x.indexOf(eq),
        kstr, vstr, k, v;

    if (idx >= 0) {
      kstr = x.substr(0, idx);
      vstr = x.substr(idx + 1);
    } else {
      kstr = x;
      vstr = '';
    }

    k = decodeURIComponent(kstr);
    v = decodeURIComponent(vstr);

    if (!hasOwnProperty(obj, k)) {
      obj[k] = v;
    } else if (isArray(obj[k])) {
      obj[k].push(v);
    } else {
      obj[k] = [obj[k], v];
    }
  }

  return obj;
};

var isArray = Array.isArray || function (xs) {
  return Object.prototype.toString.call(xs) === '[object Array]';
};

},{}],69:[function(require,module,exports){
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.

'use strict';

var stringifyPrimitive = function(v) {
  switch (typeof v) {
    case 'string':
      return v;

    case 'boolean':
      return v ? 'true' : 'false';

    case 'number':
      return isFinite(v) ? v : '';

    default:
      return '';
  }
};

module.exports = function(obj, sep, eq, name) {
  sep = sep || '&';
  eq = eq || '=';
  if (obj === null) {
    obj = undefined;
  }

  if (typeof obj === 'object') {
    return map(objectKeys(obj), function(k) {
      var ks = encodeURIComponent(stringifyPrimitive(k)) + eq;
      if (isArray(obj[k])) {
        return map(obj[k], function(v) {
          return ks + encodeURIComponent(stringifyPrimitive(v));
        }).join(sep);
      } else {
        return ks + encodeURIComponent(stringifyPrimitive(obj[k]));
      }
    }).join(sep);

  }

  if (!name) return '';
  return encodeURIComponent(stringifyPrimitive(name)) + eq +
         encodeURIComponent(stringifyPrimitive(obj));
};

var isArray = Array.isArray || function (xs) {
  return Object.prototype.toString.call(xs) === '[object Array]';
};

function map (xs, f) {
  if (xs.map) return xs.map(f);
  var res = [];
  for (var i = 0; i < xs.length; i++) {
    res.push(f(xs[i], i));
  }
  return res;
}

var objectKeys = Object.keys || function (obj) {
  var res = [];
  for (var key in obj) {
    if (Object.prototype.hasOwnProperty.call(obj, key)) res.push(key);
  }
  return res;
};

},{}],70:[function(require,module,exports){
'use strict';

exports.decode = exports.parse = require('./decode');
exports.encode = exports.stringify = require('./encode');

},{"./decode":68,"./encode":69}],71:[function(require,module,exports){
module.exports = require("./lib/_stream_duplex.js")

},{"./lib/_stream_duplex.js":72}],72:[function(require,module,exports){
// a duplex stream is just a stream that is both readable and writable.
// Since JS doesn't have multiple prototypal inheritance, this class
// prototypally inherits from Readable, and then parasitically from
// Writable.

'use strict';

/*<replacement>*/
var objectKeys = Object.keys || function (obj) {
  var keys = [];
  for (var key in obj) keys.push(key);
  return keys;
}
/*</replacement>*/


module.exports = Duplex;

/*<replacement>*/
var processNextTick = require('process-nextick-args');
/*</replacement>*/



/*<replacement>*/
var util = require('core-util-is');
util.inherits = require('inherits');
/*</replacement>*/

var Readable = require('./_stream_readable');
var Writable = require('./_stream_writable');

util.inherits(Duplex, Readable);

var keys = objectKeys(Writable.prototype);
for (var v = 0; v < keys.length; v++) {
  var method = keys[v];
  if (!Duplex.prototype[method])
    Duplex.prototype[method] = Writable.prototype[method];
}

function Duplex(options) {
  if (!(this instanceof Duplex))
    return new Duplex(options);

  Readable.call(this, options);
  Writable.call(this, options);

  if (options && options.readable === false)
    this.readable = false;

  if (options && options.writable === false)
    this.writable = false;

  this.allowHalfOpen = true;
  if (options && options.allowHalfOpen === false)
    this.allowHalfOpen = false;

  this.once('end', onend);
}

// the no-half-open enforcer
function onend() {
  // if we allow half-open state, or if the writable side ended,
  // then we're ok.
  if (this.allowHalfOpen || this._writableState.ended)
    return;

  // no more data can be written.
  // But allow more writes to happen in this tick.
  processNextTick(onEndNT, this);
}

function onEndNT(self) {
  self.end();
}

function forEach (xs, f) {
  for (var i = 0, l = xs.length; i < l; i++) {
    f(xs[i], i);
  }
}

},{"./_stream_readable":74,"./_stream_writable":76,"core-util-is":77,"inherits":63,"process-nextick-args":78}],73:[function(require,module,exports){
// a passthrough stream.
// basically just the most minimal sort of Transform stream.
// Every written chunk gets output as-is.

'use strict';

module.exports = PassThrough;

var Transform = require('./_stream_transform');

/*<replacement>*/
var util = require('core-util-is');
util.inherits = require('inherits');
/*</replacement>*/

util.inherits(PassThrough, Transform);

function PassThrough(options) {
  if (!(this instanceof PassThrough))
    return new PassThrough(options);

  Transform.call(this, options);
}

PassThrough.prototype._transform = function(chunk, encoding, cb) {
  cb(null, chunk);
};

},{"./_stream_transform":75,"core-util-is":77,"inherits":63}],74:[function(require,module,exports){
(function (process){
'use strict';

module.exports = Readable;

/*<replacement>*/
var processNextTick = require('process-nextick-args');
/*</replacement>*/


/*<replacement>*/
var isArray = require('isarray');
/*</replacement>*/


/*<replacement>*/
var Buffer = require('buffer').Buffer;
/*</replacement>*/

Readable.ReadableState = ReadableState;

var EE = require('events');

/*<replacement>*/
var EElistenerCount = function(emitter, type) {
  return emitter.listeners(type).length;
};
/*</replacement>*/



/*<replacement>*/
var Stream;
(function (){try{
  Stream = require('st' + 'ream');
}catch(_){}finally{
  if (!Stream)
    Stream = require('events').EventEmitter;
}}())
/*</replacement>*/

var Buffer = require('buffer').Buffer;

/*<replacement>*/
var util = require('core-util-is');
util.inherits = require('inherits');
/*</replacement>*/



/*<replacement>*/
var debugUtil = require('util');
var debug;
if (debugUtil && debugUtil.debuglog) {
  debug = debugUtil.debuglog('stream');
} else {
  debug = function () {};
}
/*</replacement>*/

var StringDecoder;

util.inherits(Readable, Stream);

var Duplex;
function ReadableState(options, stream) {
  Duplex = Duplex || require('./_stream_duplex');

  options = options || {};

  // object stream flag. Used to make read(n) ignore n and to
  // make all the buffer merging and length checks go away
  this.objectMode = !!options.objectMode;

  if (stream instanceof Duplex)
    this.objectMode = this.objectMode || !!options.readableObjectMode;

  // the point at which it stops calling _read() to fill the buffer
  // Note: 0 is a valid value, means "don't call _read preemptively ever"
  var hwm = options.highWaterMark;
  var defaultHwm = this.objectMode ? 16 : 16 * 1024;
  this.highWaterMark = (hwm || hwm === 0) ? hwm : defaultHwm;

  // cast to ints.
  this.highWaterMark = ~~this.highWaterMark;

  this.buffer = [];
  this.length = 0;
  this.pipes = null;
  this.pipesCount = 0;
  this.flowing = null;
  this.ended = false;
  this.endEmitted = false;
  this.reading = false;

  // a flag to be able to tell if the onwrite cb is called immediately,
  // or on a later tick.  We set this to true at first, because any
  // actions that shouldn't happen until "later" should generally also
  // not happen before the first write call.
  this.sync = true;

  // whenever we return null, then we set a flag to say
  // that we're awaiting a 'readable' event emission.
  this.needReadable = false;
  this.emittedReadable = false;
  this.readableListening = false;

  // Crypto is kind of old and crusty.  Historically, its default string
  // encoding is 'binary' so we have to make this configurable.
  // Everything else in the universe uses 'utf8', though.
  this.defaultEncoding = options.defaultEncoding || 'utf8';

  // when piping, we only care about 'readable' events that happen
  // after read()ing all the bytes and not getting any pushback.
  this.ranOut = false;

  // the number of writers that are awaiting a drain event in .pipe()s
  this.awaitDrain = 0;

  // if true, a maybeReadMore has been scheduled
  this.readingMore = false;

  this.decoder = null;
  this.encoding = null;
  if (options.encoding) {
    if (!StringDecoder)
      StringDecoder = require('string_decoder/').StringDecoder;
    this.decoder = new StringDecoder(options.encoding);
    this.encoding = options.encoding;
  }
}

var Duplex;
function Readable(options) {
  Duplex = Duplex || require('./_stream_duplex');

  if (!(this instanceof Readable))
    return new Readable(options);

  this._readableState = new ReadableState(options, this);

  // legacy
  this.readable = true;

  if (options && typeof options.read === 'function')
    this._read = options.read;

  Stream.call(this);
}

// Manually shove something into the read() buffer.
// This returns true if the highWaterMark has not been hit yet,
// similar to how Writable.write() returns true if you should
// write() some more.
Readable.prototype.push = function(chunk, encoding) {
  var state = this._readableState;

  if (!state.objectMode && typeof chunk === 'string') {
    encoding = encoding || state.defaultEncoding;
    if (encoding !== state.encoding) {
      chunk = new Buffer(chunk, encoding);
      encoding = '';
    }
  }

  return readableAddChunk(this, state, chunk, encoding, false);
};

// Unshift should *always* be something directly out of read()
Readable.prototype.unshift = function(chunk) {
  var state = this._readableState;
  return readableAddChunk(this, state, chunk, '', true);
};

Readable.prototype.isPaused = function() {
  return this._readableState.flowing === false;
};

function readableAddChunk(stream, state, chunk, encoding, addToFront) {
  var er = chunkInvalid(state, chunk);
  if (er) {
    stream.emit('error', er);
  } else if (chunk === null) {
    state.reading = false;
    onEofChunk(stream, state);
  } else if (state.objectMode || chunk && chunk.length > 0) {
    if (state.ended && !addToFront) {
      var e = new Error('stream.push() after EOF');
      stream.emit('error', e);
    } else if (state.endEmitted && addToFront) {
      var e = new Error('stream.unshift() after end event');
      stream.emit('error', e);
    } else {
      if (state.decoder && !addToFront && !encoding)
        chunk = state.decoder.write(chunk);

      if (!addToFront)
        state.reading = false;

      // if we want the data now, just emit it.
      if (state.flowing && state.length === 0 && !state.sync) {
        stream.emit('data', chunk);
        stream.read(0);
      } else {
        // update the buffer info.
        state.length += state.objectMode ? 1 : chunk.length;
        if (addToFront)
          state.buffer.unshift(chunk);
        else
          state.buffer.push(chunk);

        if (state.needReadable)
          emitReadable(stream);
      }

      maybeReadMore(stream, state);
    }
  } else if (!addToFront) {
    state.reading = false;
  }

  return needMoreData(state);
}


// if it's past the high water mark, we can push in some more.
// Also, if we have no data yet, we can stand some
// more bytes.  This is to work around cases where hwm=0,
// such as the repl.  Also, if the push() triggered a
// readable event, and the user called read(largeNumber) such that
// needReadable was set, then we ought to push more, so that another
// 'readable' event will be triggered.
function needMoreData(state) {
  return !state.ended &&
         (state.needReadable ||
          state.length < state.highWaterMark ||
          state.length === 0);
}

// backwards compatibility.
Readable.prototype.setEncoding = function(enc) {
  if (!StringDecoder)
    StringDecoder = require('string_decoder/').StringDecoder;
  this._readableState.decoder = new StringDecoder(enc);
  this._readableState.encoding = enc;
  return this;
};

// Don't raise the hwm > 8MB
var MAX_HWM = 0x800000;
function computeNewHighWaterMark(n) {
  if (n >= MAX_HWM) {
    n = MAX_HWM;
  } else {
    // Get the next highest power of 2
    n--;
    n |= n >>> 1;
    n |= n >>> 2;
    n |= n >>> 4;
    n |= n >>> 8;
    n |= n >>> 16;
    n++;
  }
  return n;
}

function howMuchToRead(n, state) {
  if (state.length === 0 && state.ended)
    return 0;

  if (state.objectMode)
    return n === 0 ? 0 : 1;

  if (n === null || isNaN(n)) {
    // only flow one buffer at a time
    if (state.flowing && state.buffer.length)
      return state.buffer[0].length;
    else
      return state.length;
  }

  if (n <= 0)
    return 0;

  // If we're asking for more than the target buffer level,
  // then raise the water mark.  Bump up to the next highest
  // power of 2, to prevent increasing it excessively in tiny
  // amounts.
  if (n > state.highWaterMark)
    state.highWaterMark = computeNewHighWaterMark(n);

  // don't have that much.  return null, unless we've ended.
  if (n > state.length) {
    if (!state.ended) {
      state.needReadable = true;
      return 0;
    } else {
      return state.length;
    }
  }

  return n;
}

// you can override either this method, or the async _read(n) below.
Readable.prototype.read = function(n) {
  debug('read', n);
  var state = this._readableState;
  var nOrig = n;

  if (typeof n !== 'number' || n > 0)
    state.emittedReadable = false;

  // if we're doing read(0) to trigger a readable event, but we
  // already have a bunch of data in the buffer, then just trigger
  // the 'readable' event and move on.
  if (n === 0 &&
      state.needReadable &&
      (state.length >= state.highWaterMark || state.ended)) {
    debug('read: emitReadable', state.length, state.ended);
    if (state.length === 0 && state.ended)
      endReadable(this);
    else
      emitReadable(this);
    return null;
  }

  n = howMuchToRead(n, state);

  // if we've ended, and we're now clear, then finish it up.
  if (n === 0 && state.ended) {
    if (state.length === 0)
      endReadable(this);
    return null;
  }

  // All the actual chunk generation logic needs to be
  // *below* the call to _read.  The reason is that in certain
  // synthetic stream cases, such as passthrough streams, _read
  // may be a completely synchronous operation which may change
  // the state of the read buffer, providing enough data when
  // before there was *not* enough.
  //
  // So, the steps are:
  // 1. Figure out what the state of things will be after we do
  // a read from the buffer.
  //
  // 2. If that resulting state will trigger a _read, then call _read.
  // Note that this may be asynchronous, or synchronous.  Yes, it is
  // deeply ugly to write APIs this way, but that still doesn't mean
  // that the Readable class should behave improperly, as streams are
  // designed to be sync/async agnostic.
  // Take note if the _read call is sync or async (ie, if the read call
  // has returned yet), so that we know whether or not it's safe to emit
  // 'readable' etc.
  //
  // 3. Actually pull the requested chunks out of the buffer and return.

  // if we need a readable event, then we need to do some reading.
  var doRead = state.needReadable;
  debug('need readable', doRead);

  // if we currently have less than the highWaterMark, then also read some
  if (state.length === 0 || state.length - n < state.highWaterMark) {
    doRead = true;
    debug('length less than watermark', doRead);
  }

  // however, if we've ended, then there's no point, and if we're already
  // reading, then it's unnecessary.
  if (state.ended || state.reading) {
    doRead = false;
    debug('reading or ended', doRead);
  }

  if (doRead) {
    debug('do read');
    state.reading = true;
    state.sync = true;
    // if the length is currently zero, then we *need* a readable event.
    if (state.length === 0)
      state.needReadable = true;
    // call internal read method
    this._read(state.highWaterMark);
    state.sync = false;
  }

  // If _read pushed data synchronously, then `reading` will be false,
  // and we need to re-evaluate how much data we can return to the user.
  if (doRead && !state.reading)
    n = howMuchToRead(nOrig, state);

  var ret;
  if (n > 0)
    ret = fromList(n, state);
  else
    ret = null;

  if (ret === null) {
    state.needReadable = true;
    n = 0;
  }

  state.length -= n;

  // If we have nothing in the buffer, then we want to know
  // as soon as we *do* get something into the buffer.
  if (state.length === 0 && !state.ended)
    state.needReadable = true;

  // If we tried to read() past the EOF, then emit end on the next tick.
  if (nOrig !== n && state.ended && state.length === 0)
    endReadable(this);

  if (ret !== null)
    this.emit('data', ret);

  return ret;
};

function chunkInvalid(state, chunk) {
  var er = null;
  if (!(Buffer.isBuffer(chunk)) &&
      typeof chunk !== 'string' &&
      chunk !== null &&
      chunk !== undefined &&
      !state.objectMode) {
    er = new TypeError('Invalid non-string/buffer chunk');
  }
  return er;
}


function onEofChunk(stream, state) {
  if (state.ended) return;
  if (state.decoder) {
    var chunk = state.decoder.end();
    if (chunk && chunk.length) {
      state.buffer.push(chunk);
      state.length += state.objectMode ? 1 : chunk.length;
    }
  }
  state.ended = true;

  // emit 'readable' now to make sure it gets picked up.
  emitReadable(stream);
}

// Don't emit readable right away in sync mode, because this can trigger
// another read() call => stack overflow.  This way, it might trigger
// a nextTick recursion warning, but that's not so bad.
function emitReadable(stream) {
  var state = stream._readableState;
  state.needReadable = false;
  if (!state.emittedReadable) {
    debug('emitReadable', state.flowing);
    state.emittedReadable = true;
    if (state.sync)
      processNextTick(emitReadable_, stream);
    else
      emitReadable_(stream);
  }
}

function emitReadable_(stream) {
  debug('emit readable');
  stream.emit('readable');
  flow(stream);
}


// at this point, the user has presumably seen the 'readable' event,
// and called read() to consume some data.  that may have triggered
// in turn another _read(n) call, in which case reading = true if
// it's in progress.
// However, if we're not ended, or reading, and the length < hwm,
// then go ahead and try to read some more preemptively.
function maybeReadMore(stream, state) {
  if (!state.readingMore) {
    state.readingMore = true;
    processNextTick(maybeReadMore_, stream, state);
  }
}

function maybeReadMore_(stream, state) {
  var len = state.length;
  while (!state.reading && !state.flowing && !state.ended &&
         state.length < state.highWaterMark) {
    debug('maybeReadMore read 0');
    stream.read(0);
    if (len === state.length)
      // didn't get any data, stop spinning.
      break;
    else
      len = state.length;
  }
  state.readingMore = false;
}

// abstract method.  to be overridden in specific implementation classes.
// call cb(er, data) where data is <= n in length.
// for virtual (non-string, non-buffer) streams, "length" is somewhat
// arbitrary, and perhaps not very meaningful.
Readable.prototype._read = function(n) {
  this.emit('error', new Error('not implemented'));
};

Readable.prototype.pipe = function(dest, pipeOpts) {
  var src = this;
  var state = this._readableState;

  switch (state.pipesCount) {
    case 0:
      state.pipes = dest;
      break;
    case 1:
      state.pipes = [state.pipes, dest];
      break;
    default:
      state.pipes.push(dest);
      break;
  }
  state.pipesCount += 1;
  debug('pipe count=%d opts=%j', state.pipesCount, pipeOpts);

  var doEnd = (!pipeOpts || pipeOpts.end !== false) &&
              dest !== process.stdout &&
              dest !== process.stderr;

  var endFn = doEnd ? onend : cleanup;
  if (state.endEmitted)
    processNextTick(endFn);
  else
    src.once('end', endFn);

  dest.on('unpipe', onunpipe);
  function onunpipe(readable) {
    debug('onunpipe');
    if (readable === src) {
      cleanup();
    }
  }

  function onend() {
    debug('onend');
    dest.end();
  }

  // when the dest drains, it reduces the awaitDrain counter
  // on the source.  This would be more elegant with a .once()
  // handler in flow(), but adding and removing repeatedly is
  // too slow.
  var ondrain = pipeOnDrain(src);
  dest.on('drain', ondrain);

  var cleanedUp = false;
  function cleanup() {
    debug('cleanup');
    // cleanup event handlers once the pipe is broken
    dest.removeListener('close', onclose);
    dest.removeListener('finish', onfinish);
    dest.removeListener('drain', ondrain);
    dest.removeListener('error', onerror);
    dest.removeListener('unpipe', onunpipe);
    src.removeListener('end', onend);
    src.removeListener('end', cleanup);
    src.removeListener('data', ondata);

    cleanedUp = true;

    // if the reader is waiting for a drain event from this
    // specific writer, then it would cause it to never start
    // flowing again.
    // So, if this is awaiting a drain, then we just call it now.
    // If we don't know, then assume that we are waiting for one.
    if (state.awaitDrain &&
        (!dest._writableState || dest._writableState.needDrain))
      ondrain();
  }

  src.on('data', ondata);
  function ondata(chunk) {
    debug('ondata');
    var ret = dest.write(chunk);
    if (false === ret) {
      // If the user unpiped during `dest.write()`, it is possible
      // to get stuck in a permanently paused state if that write
      // also returned false.
      if (state.pipesCount === 1 &&
          state.pipes[0] === dest &&
          src.listenerCount('data') === 1 &&
          !cleanedUp) {
        debug('false write response, pause', src._readableState.awaitDrain);
        src._readableState.awaitDrain++;
      }
      src.pause();
    }
  }

  // if the dest has an error, then stop piping into it.
  // however, don't suppress the throwing behavior for this.
  function onerror(er) {
    debug('onerror', er);
    unpipe();
    dest.removeListener('error', onerror);
    if (EElistenerCount(dest, 'error') === 0)
      dest.emit('error', er);
  }
  // This is a brutally ugly hack to make sure that our error handler
  // is attached before any userland ones.  NEVER DO THIS.
  if (!dest._events || !dest._events.error)
    dest.on('error', onerror);
  else if (isArray(dest._events.error))
    dest._events.error.unshift(onerror);
  else
    dest._events.error = [onerror, dest._events.error];


  // Both close and finish should trigger unpipe, but only once.
  function onclose() {
    dest.removeListener('finish', onfinish);
    unpipe();
  }
  dest.once('close', onclose);
  function onfinish() {
    debug('onfinish');
    dest.removeListener('close', onclose);
    unpipe();
  }
  dest.once('finish', onfinish);

  function unpipe() {
    debug('unpipe');
    src.unpipe(dest);
  }

  // tell the dest that it's being piped to
  dest.emit('pipe', src);

  // start the flow if it hasn't been started already.
  if (!state.flowing) {
    debug('pipe resume');
    src.resume();
  }

  return dest;
};

function pipeOnDrain(src) {
  return function() {
    var state = src._readableState;
    debug('pipeOnDrain', state.awaitDrain);
    if (state.awaitDrain)
      state.awaitDrain--;
    if (state.awaitDrain === 0 && EElistenerCount(src, 'data')) {
      state.flowing = true;
      flow(src);
    }
  };
}


Readable.prototype.unpipe = function(dest) {
  var state = this._readableState;

  // if we're not piping anywhere, then do nothing.
  if (state.pipesCount === 0)
    return this;

  // just one destination.  most common case.
  if (state.pipesCount === 1) {
    // passed in one, but it's not the right one.
    if (dest && dest !== state.pipes)
      return this;

    if (!dest)
      dest = state.pipes;

    // got a match.
    state.pipes = null;
    state.pipesCount = 0;
    state.flowing = false;
    if (dest)
      dest.emit('unpipe', this);
    return this;
  }

  // slow case. multiple pipe destinations.

  if (!dest) {
    // remove all.
    var dests = state.pipes;
    var len = state.pipesCount;
    state.pipes = null;
    state.pipesCount = 0;
    state.flowing = false;

    for (var i = 0; i < len; i++)
      dests[i].emit('unpipe', this);
    return this;
  }

  // try to find the right one.
  var i = indexOf(state.pipes, dest);
  if (i === -1)
    return this;

  state.pipes.splice(i, 1);
  state.pipesCount -= 1;
  if (state.pipesCount === 1)
    state.pipes = state.pipes[0];

  dest.emit('unpipe', this);

  return this;
};

// set up data events if they are asked for
// Ensure readable listeners eventually get something
Readable.prototype.on = function(ev, fn) {
  var res = Stream.prototype.on.call(this, ev, fn);

  // If listening to data, and it has not explicitly been paused,
  // then call resume to start the flow of data on the next tick.
  if (ev === 'data' && false !== this._readableState.flowing) {
    this.resume();
  }

  if (ev === 'readable' && this.readable) {
    var state = this._readableState;
    if (!state.readableListening) {
      state.readableListening = true;
      state.emittedReadable = false;
      state.needReadable = true;
      if (!state.reading) {
        processNextTick(nReadingNextTick, this);
      } else if (state.length) {
        emitReadable(this, state);
      }
    }
  }

  return res;
};
Readable.prototype.addListener = Readable.prototype.on;

function nReadingNextTick(self) {
  debug('readable nexttick read 0');
  self.read(0);
}

// pause() and resume() are remnants of the legacy readable stream API
// If the user uses them, then switch into old mode.
Readable.prototype.resume = function() {
  var state = this._readableState;
  if (!state.flowing) {
    debug('resume');
    state.flowing = true;
    resume(this, state);
  }
  return this;
};

function resume(stream, state) {
  if (!state.resumeScheduled) {
    state.resumeScheduled = true;
    processNextTick(resume_, stream, state);
  }
}

function resume_(stream, state) {
  if (!state.reading) {
    debug('resume read 0');
    stream.read(0);
  }

  state.resumeScheduled = false;
  stream.emit('resume');
  flow(stream);
  if (state.flowing && !state.reading)
    stream.read(0);
}

Readable.prototype.pause = function() {
  debug('call pause flowing=%j', this._readableState.flowing);
  if (false !== this._readableState.flowing) {
    debug('pause');
    this._readableState.flowing = false;
    this.emit('pause');
  }
  return this;
};

function flow(stream) {
  var state = stream._readableState;
  debug('flow', state.flowing);
  if (state.flowing) {
    do {
      var chunk = stream.read();
    } while (null !== chunk && state.flowing);
  }
}

// wrap an old-style stream as the async data source.
// This is *not* part of the readable stream interface.
// It is an ugly unfortunate mess of history.
Readable.prototype.wrap = function(stream) {
  var state = this._readableState;
  var paused = false;

  var self = this;
  stream.on('end', function() {
    debug('wrapped end');
    if (state.decoder && !state.ended) {
      var chunk = state.decoder.end();
      if (chunk && chunk.length)
        self.push(chunk);
    }

    self.push(null);
  });

  stream.on('data', function(chunk) {
    debug('wrapped data');
    if (state.decoder)
      chunk = state.decoder.write(chunk);

    // don't skip over falsy values in objectMode
    if (state.objectMode && (chunk === null || chunk === undefined))
      return;
    else if (!state.objectMode && (!chunk || !chunk.length))
      return;

    var ret = self.push(chunk);
    if (!ret) {
      paused = true;
      stream.pause();
    }
  });

  // proxy all the other methods.
  // important when wrapping filters and duplexes.
  for (var i in stream) {
    if (this[i] === undefined && typeof stream[i] === 'function') {
      this[i] = function(method) { return function() {
        return stream[method].apply(stream, arguments);
      }; }(i);
    }
  }

  // proxy certain important events.
  var events = ['error', 'close', 'destroy', 'pause', 'resume'];
  forEach(events, function(ev) {
    stream.on(ev, self.emit.bind(self, ev));
  });

  // when we try to consume some more bytes, simply unpause the
  // underlying stream.
  self._read = function(n) {
    debug('wrapped _read', n);
    if (paused) {
      paused = false;
      stream.resume();
    }
  };

  return self;
};


// exposed for testing purposes only.
Readable._fromList = fromList;

// Pluck off n bytes from an array of buffers.
// Length is the combined lengths of all the buffers in the list.
function fromList(n, state) {
  var list = state.buffer;
  var length = state.length;
  var stringMode = !!state.decoder;
  var objectMode = !!state.objectMode;
  var ret;

  // nothing in the list, definitely empty.
  if (list.length === 0)
    return null;

  if (length === 0)
    ret = null;
  else if (objectMode)
    ret = list.shift();
  else if (!n || n >= length) {
    // read it all, truncate the array.
    if (stringMode)
      ret = list.join('');
    else if (list.length === 1)
      ret = list[0];
    else
      ret = Buffer.concat(list, length);
    list.length = 0;
  } else {
    // read just some of it.
    if (n < list[0].length) {
      // just take a part of the first list item.
      // slice is the same for buffers and strings.
      var buf = list[0];
      ret = buf.slice(0, n);
      list[0] = buf.slice(n);
    } else if (n === list[0].length) {
      // first list is a perfect match
      ret = list.shift();
    } else {
      // complex case.
      // we have enough to cover it, but it spans past the first buffer.
      if (stringMode)
        ret = '';
      else
        ret = new Buffer(n);

      var c = 0;
      for (var i = 0, l = list.length; i < l && c < n; i++) {
        var buf = list[0];
        var cpy = Math.min(n - c, buf.length);

        if (stringMode)
          ret += buf.slice(0, cpy);
        else
          buf.copy(ret, c, 0, cpy);

        if (cpy < buf.length)
          list[0] = buf.slice(cpy);
        else
          list.shift();

        c += cpy;
      }
    }
  }

  return ret;
}

function endReadable(stream) {
  var state = stream._readableState;

  // If we get here before consuming all the bytes, then that is a
  // bug in node.  Should never happen.
  if (state.length > 0)
    throw new Error('endReadable called on non-empty stream');

  if (!state.endEmitted) {
    state.ended = true;
    processNextTick(endReadableNT, state, stream);
  }
}

function endReadableNT(state, stream) {
  // Check that we didn't get one last unshift.
  if (!state.endEmitted && state.length === 0) {
    state.endEmitted = true;
    stream.readable = false;
    stream.emit('end');
  }
}

function forEach (xs, f) {
  for (var i = 0, l = xs.length; i < l; i++) {
    f(xs[i], i);
  }
}

function indexOf (xs, x) {
  for (var i = 0, l = xs.length; i < l; i++) {
    if (xs[i] === x) return i;
  }
  return -1;
}

}).call(this,require('_process'))

},{"./_stream_duplex":72,"_process":66,"buffer":57,"core-util-is":77,"events":61,"inherits":63,"isarray":65,"process-nextick-args":78,"string_decoder/":90,"util":56}],75:[function(require,module,exports){
// a transform stream is a readable/writable stream where you do
// something with the data.  Sometimes it's called a "filter",
// but that's not a great name for it, since that implies a thing where
// some bits pass through, and others are simply ignored.  (That would
// be a valid example of a transform, of course.)
//
// While the output is causally related to the input, it's not a
// necessarily symmetric or synchronous transformation.  For example,
// a zlib stream might take multiple plain-text writes(), and then
// emit a single compressed chunk some time in the future.
//
// Here's how this works:
//
// The Transform stream has all the aspects of the readable and writable
// stream classes.  When you write(chunk), that calls _write(chunk,cb)
// internally, and returns false if there's a lot of pending writes
// buffered up.  When you call read(), that calls _read(n) until
// there's enough pending readable data buffered up.
//
// In a transform stream, the written data is placed in a buffer.  When
// _read(n) is called, it transforms the queued up data, calling the
// buffered _write cb's as it consumes chunks.  If consuming a single
// written chunk would result in multiple output chunks, then the first
// outputted bit calls the readcb, and subsequent chunks just go into
// the read buffer, and will cause it to emit 'readable' if necessary.
//
// This way, back-pressure is actually determined by the reading side,
// since _read has to be called to start processing a new chunk.  However,
// a pathological inflate type of transform can cause excessive buffering
// here.  For example, imagine a stream where every byte of input is
// interpreted as an integer from 0-255, and then results in that many
// bytes of output.  Writing the 4 bytes {ff,ff,ff,ff} would result in
// 1kb of data being output.  In this case, you could write a very small
// amount of input, and end up with a very large amount of output.  In
// such a pathological inflating mechanism, there'd be no way to tell
// the system to stop doing the transform.  A single 4MB write could
// cause the system to run out of memory.
//
// However, even in such a pathological case, only a single written chunk
// would be consumed, and then the rest would wait (un-transformed) until
// the results of the previous transformed chunk were consumed.

'use strict';

module.exports = Transform;

var Duplex = require('./_stream_duplex');

/*<replacement>*/
var util = require('core-util-is');
util.inherits = require('inherits');
/*</replacement>*/

util.inherits(Transform, Duplex);


function TransformState(stream) {
  this.afterTransform = function(er, data) {
    return afterTransform(stream, er, data);
  };

  this.needTransform = false;
  this.transforming = false;
  this.writecb = null;
  this.writechunk = null;
}

function afterTransform(stream, er, data) {
  var ts = stream._transformState;
  ts.transforming = false;

  var cb = ts.writecb;

  if (!cb)
    return stream.emit('error', new Error('no writecb in Transform class'));

  ts.writechunk = null;
  ts.writecb = null;

  if (data !== null && data !== undefined)
    stream.push(data);

  if (cb)
    cb(er);

  var rs = stream._readableState;
  rs.reading = false;
  if (rs.needReadable || rs.length < rs.highWaterMark) {
    stream._read(rs.highWaterMark);
  }
}


function Transform(options) {
  if (!(this instanceof Transform))
    return new Transform(options);

  Duplex.call(this, options);

  this._transformState = new TransformState(this);

  // when the writable side finishes, then flush out anything remaining.
  var stream = this;

  // start out asking for a readable event once data is transformed.
  this._readableState.needReadable = true;

  // we have implemented the _read method, and done the other things
  // that Readable wants before the first _read call, so unset the
  // sync guard flag.
  this._readableState.sync = false;

  if (options) {
    if (typeof options.transform === 'function')
      this._transform = options.transform;

    if (typeof options.flush === 'function')
      this._flush = options.flush;
  }

  this.once('prefinish', function() {
    if (typeof this._flush === 'function')
      this._flush(function(er) {
        done(stream, er);
      });
    else
      done(stream);
  });
}

Transform.prototype.push = function(chunk, encoding) {
  this._transformState.needTransform = false;
  return Duplex.prototype.push.call(this, chunk, encoding);
};

// This is the part where you do stuff!
// override this function in implementation classes.
// 'chunk' is an input chunk.
//
// Call `push(newChunk)` to pass along transformed output
// to the readable side.  You may call 'push' zero or more times.
//
// Call `cb(err)` when you are done with this chunk.  If you pass
// an error, then that'll put the hurt on the whole operation.  If you
// never call cb(), then you'll never get another chunk.
Transform.prototype._transform = function(chunk, encoding, cb) {
  throw new Error('not implemented');
};

Transform.prototype._write = function(chunk, encoding, cb) {
  var ts = this._transformState;
  ts.writecb = cb;
  ts.writechunk = chunk;
  ts.writeencoding = encoding;
  if (!ts.transforming) {
    var rs = this._readableState;
    if (ts.needTransform ||
        rs.needReadable ||
        rs.length < rs.highWaterMark)
      this._read(rs.highWaterMark);
  }
};

// Doesn't matter what the args are here.
// _transform does all the work.
// That we got here means that the readable side wants more data.
Transform.prototype._read = function(n) {
  var ts = this._transformState;

  if (ts.writechunk !== null && ts.writecb && !ts.transforming) {
    ts.transforming = true;
    this._transform(ts.writechunk, ts.writeencoding, ts.afterTransform);
  } else {
    // mark that we need a transform, so that any data that comes in
    // will get processed, now that we've asked for it.
    ts.needTransform = true;
  }
};


function done(stream, er) {
  if (er)
    return stream.emit('error', er);

  // if there's nothing in the write buffer, then that means
  // that nothing more will ever be provided
  var ws = stream._writableState;
  var ts = stream._transformState;

  if (ws.length)
    throw new Error('calling transform done when ws.length != 0');

  if (ts.transforming)
    throw new Error('calling transform done when still transforming');

  return stream.push(null);
}

},{"./_stream_duplex":72,"core-util-is":77,"inherits":63}],76:[function(require,module,exports){
// A bit simpler than readable streams.
// Implement an async ._write(chunk, encoding, cb), and it'll handle all
// the drain event emission and buffering.

'use strict';

module.exports = Writable;

/*<replacement>*/
var processNextTick = require('process-nextick-args');
/*</replacement>*/


/*<replacement>*/
var Buffer = require('buffer').Buffer;
/*</replacement>*/

Writable.WritableState = WritableState;


/*<replacement>*/
var util = require('core-util-is');
util.inherits = require('inherits');
/*</replacement>*/


/*<replacement>*/
var internalUtil = {
  deprecate: require('util-deprecate')
};
/*</replacement>*/



/*<replacement>*/
var Stream;
(function (){try{
  Stream = require('st' + 'ream');
}catch(_){}finally{
  if (!Stream)
    Stream = require('events').EventEmitter;
}}())
/*</replacement>*/

var Buffer = require('buffer').Buffer;

util.inherits(Writable, Stream);

function nop() {}

function WriteReq(chunk, encoding, cb) {
  this.chunk = chunk;
  this.encoding = encoding;
  this.callback = cb;
  this.next = null;
}

var Duplex;
function WritableState(options, stream) {
  Duplex = Duplex || require('./_stream_duplex');

  options = options || {};

  // object stream flag to indicate whether or not this stream
  // contains buffers or objects.
  this.objectMode = !!options.objectMode;

  if (stream instanceof Duplex)
    this.objectMode = this.objectMode || !!options.writableObjectMode;

  // the point at which write() starts returning false
  // Note: 0 is a valid value, means that we always return false if
  // the entire buffer is not flushed immediately on write()
  var hwm = options.highWaterMark;
  var defaultHwm = this.objectMode ? 16 : 16 * 1024;
  this.highWaterMark = (hwm || hwm === 0) ? hwm : defaultHwm;

  // cast to ints.
  this.highWaterMark = ~~this.highWaterMark;

  this.needDrain = false;
  // at the start of calling end()
  this.ending = false;
  // when end() has been called, and returned
  this.ended = false;
  // when 'finish' is emitted
  this.finished = false;

  // should we decode strings into buffers before passing to _write?
  // this is here so that some node-core streams can optimize string
  // handling at a lower level.
  var noDecode = options.decodeStrings === false;
  this.decodeStrings = !noDecode;

  // Crypto is kind of old and crusty.  Historically, its default string
  // encoding is 'binary' so we have to make this configurable.
  // Everything else in the universe uses 'utf8', though.
  this.defaultEncoding = options.defaultEncoding || 'utf8';

  // not an actual buffer we keep track of, but a measurement
  // of how much we're waiting to get pushed to some underlying
  // socket or file.
  this.length = 0;

  // a flag to see when we're in the middle of a write.
  this.writing = false;

  // when true all writes will be buffered until .uncork() call
  this.corked = 0;

  // a flag to be able to tell if the onwrite cb is called immediately,
  // or on a later tick.  We set this to true at first, because any
  // actions that shouldn't happen until "later" should generally also
  // not happen before the first write call.
  this.sync = true;

  // a flag to know if we're processing previously buffered items, which
  // may call the _write() callback in the same tick, so that we don't
  // end up in an overlapped onwrite situation.
  this.bufferProcessing = false;

  // the callback that's passed to _write(chunk,cb)
  this.onwrite = function(er) {
    onwrite(stream, er);
  };

  // the callback that the user supplies to write(chunk,encoding,cb)
  this.writecb = null;

  // the amount that is being written when _write is called.
  this.writelen = 0;

  this.bufferedRequest = null;
  this.lastBufferedRequest = null;

  // number of pending user-supplied write callbacks
  // this must be 0 before 'finish' can be emitted
  this.pendingcb = 0;

  // emit prefinish if the only thing we're waiting for is _write cbs
  // This is relevant for synchronous Transform streams
  this.prefinished = false;

  // True if the error was already emitted and should not be thrown again
  this.errorEmitted = false;
}

WritableState.prototype.getBuffer = function writableStateGetBuffer() {
  var current = this.bufferedRequest;
  var out = [];
  while (current) {
    out.push(current);
    current = current.next;
  }
  return out;
};

(function (){try {
Object.defineProperty(WritableState.prototype, 'buffer', {
  get: internalUtil.deprecate(function() {
    return this.getBuffer();
  }, '_writableState.buffer is deprecated. Use _writableState.getBuffer ' +
     'instead.')
});
}catch(_){}}());


var Duplex;
function Writable(options) {
  Duplex = Duplex || require('./_stream_duplex');

  // Writable ctor is applied to Duplexes, though they're not
  // instanceof Writable, they're instanceof Readable.
  if (!(this instanceof Writable) && !(this instanceof Duplex))
    return new Writable(options);

  this._writableState = new WritableState(options, this);

  // legacy.
  this.writable = true;

  if (options) {
    if (typeof options.write === 'function')
      this._write = options.write;

    if (typeof options.writev === 'function')
      this._writev = options.writev;
  }

  Stream.call(this);
}

// Otherwise people can pipe Writable streams, which is just wrong.
Writable.prototype.pipe = function() {
  this.emit('error', new Error('Cannot pipe. Not readable.'));
};


function writeAfterEnd(stream, cb) {
  var er = new Error('write after end');
  // TODO: defer error events consistently everywhere, not just the cb
  stream.emit('error', er);
  processNextTick(cb, er);
}

// If we get something that is not a buffer, string, null, or undefined,
// and we're not in objectMode, then that's an error.
// Otherwise stream chunks are all considered to be of length=1, and the
// watermarks determine how many objects to keep in the buffer, rather than
// how many bytes or characters.
function validChunk(stream, state, chunk, cb) {
  var valid = true;

  if (!(Buffer.isBuffer(chunk)) &&
      typeof chunk !== 'string' &&
      chunk !== null &&
      chunk !== undefined &&
      !state.objectMode) {
    var er = new TypeError('Invalid non-string/buffer chunk');
    stream.emit('error', er);
    processNextTick(cb, er);
    valid = false;
  }
  return valid;
}

Writable.prototype.write = function(chunk, encoding, cb) {
  var state = this._writableState;
  var ret = false;

  if (typeof encoding === 'function') {
    cb = encoding;
    encoding = null;
  }

  if (Buffer.isBuffer(chunk))
    encoding = 'buffer';
  else if (!encoding)
    encoding = state.defaultEncoding;

  if (typeof cb !== 'function')
    cb = nop;

  if (state.ended)
    writeAfterEnd(this, cb);
  else if (validChunk(this, state, chunk, cb)) {
    state.pendingcb++;
    ret = writeOrBuffer(this, state, chunk, encoding, cb);
  }

  return ret;
};

Writable.prototype.cork = function() {
  var state = this._writableState;

  state.corked++;
};

Writable.prototype.uncork = function() {
  var state = this._writableState;

  if (state.corked) {
    state.corked--;

    if (!state.writing &&
        !state.corked &&
        !state.finished &&
        !state.bufferProcessing &&
        state.bufferedRequest)
      clearBuffer(this, state);
  }
};

Writable.prototype.setDefaultEncoding = function setDefaultEncoding(encoding) {
  // node::ParseEncoding() requires lower case.
  if (typeof encoding === 'string')
    encoding = encoding.toLowerCase();
  if (!(['hex', 'utf8', 'utf-8', 'ascii', 'binary', 'base64',
'ucs2', 'ucs-2','utf16le', 'utf-16le', 'raw']
.indexOf((encoding + '').toLowerCase()) > -1))
    throw new TypeError('Unknown encoding: ' + encoding);
  this._writableState.defaultEncoding = encoding;
};

function decodeChunk(state, chunk, encoding) {
  if (!state.objectMode &&
      state.decodeStrings !== false &&
      typeof chunk === 'string') {
    chunk = new Buffer(chunk, encoding);
  }
  return chunk;
}

// if we're already writing something, then just put this
// in the queue, and wait our turn.  Otherwise, call _write
// If we return false, then we need a drain event, so set that flag.
function writeOrBuffer(stream, state, chunk, encoding, cb) {
  chunk = decodeChunk(state, chunk, encoding);

  if (Buffer.isBuffer(chunk))
    encoding = 'buffer';
  var len = state.objectMode ? 1 : chunk.length;

  state.length += len;

  var ret = state.length < state.highWaterMark;
  // we must ensure that previous needDrain will not be reset to false.
  if (!ret)
    state.needDrain = true;

  if (state.writing || state.corked) {
    var last = state.lastBufferedRequest;
    state.lastBufferedRequest = new WriteReq(chunk, encoding, cb);
    if (last) {
      last.next = state.lastBufferedRequest;
    } else {
      state.bufferedRequest = state.lastBufferedRequest;
    }
  } else {
    doWrite(stream, state, false, len, chunk, encoding, cb);
  }

  return ret;
}

function doWrite(stream, state, writev, len, chunk, encoding, cb) {
  state.writelen = len;
  state.writecb = cb;
  state.writing = true;
  state.sync = true;
  if (writev)
    stream._writev(chunk, state.onwrite);
  else
    stream._write(chunk, encoding, state.onwrite);
  state.sync = false;
}

function onwriteError(stream, state, sync, er, cb) {
  --state.pendingcb;
  if (sync)
    processNextTick(cb, er);
  else
    cb(er);

  stream._writableState.errorEmitted = true;
  stream.emit('error', er);
}

function onwriteStateUpdate(state) {
  state.writing = false;
  state.writecb = null;
  state.length -= state.writelen;
  state.writelen = 0;
}

function onwrite(stream, er) {
  var state = stream._writableState;
  var sync = state.sync;
  var cb = state.writecb;

  onwriteStateUpdate(state);

  if (er)
    onwriteError(stream, state, sync, er, cb);
  else {
    // Check if we're actually ready to finish, but don't emit yet
    var finished = needFinish(state);

    if (!finished &&
        !state.corked &&
        !state.bufferProcessing &&
        state.bufferedRequest) {
      clearBuffer(stream, state);
    }

    if (sync) {
      processNextTick(afterWrite, stream, state, finished, cb);
    } else {
      afterWrite(stream, state, finished, cb);
    }
  }
}

function afterWrite(stream, state, finished, cb) {
  if (!finished)
    onwriteDrain(stream, state);
  state.pendingcb--;
  cb();
  finishMaybe(stream, state);
}

// Must force callback to be called on nextTick, so that we don't
// emit 'drain' before the write() consumer gets the 'false' return
// value, and has a chance to attach a 'drain' listener.
function onwriteDrain(stream, state) {
  if (state.length === 0 && state.needDrain) {
    state.needDrain = false;
    stream.emit('drain');
  }
}


// if there's something in the buffer waiting, then process it
function clearBuffer(stream, state) {
  state.bufferProcessing = true;
  var entry = state.bufferedRequest;

  if (stream._writev && entry && entry.next) {
    // Fast case, write everything using _writev()
    var buffer = [];
    var cbs = [];
    while (entry) {
      cbs.push(entry.callback);
      buffer.push(entry);
      entry = entry.next;
    }

    // count the one we are adding, as well.
    // TODO(isaacs) clean this up
    state.pendingcb++;
    state.lastBufferedRequest = null;
    doWrite(stream, state, true, state.length, buffer, '', function(err) {
      for (var i = 0; i < cbs.length; i++) {
        state.pendingcb--;
        cbs[i](err);
      }
    });

    // Clear buffer
  } else {
    // Slow case, write chunks one-by-one
    while (entry) {
      var chunk = entry.chunk;
      var encoding = entry.encoding;
      var cb = entry.callback;
      var len = state.objectMode ? 1 : chunk.length;

      doWrite(stream, state, false, len, chunk, encoding, cb);
      entry = entry.next;
      // if we didn't call the onwrite immediately, then
      // it means that we need to wait until it does.
      // also, that means that the chunk and cb are currently
      // being processed, so move the buffer counter past them.
      if (state.writing) {
        break;
      }
    }

    if (entry === null)
      state.lastBufferedRequest = null;
  }
  state.bufferedRequest = entry;
  state.bufferProcessing = false;
}

Writable.prototype._write = function(chunk, encoding, cb) {
  cb(new Error('not implemented'));
};

Writable.prototype._writev = null;

Writable.prototype.end = function(chunk, encoding, cb) {
  var state = this._writableState;

  if (typeof chunk === 'function') {
    cb = chunk;
    chunk = null;
    encoding = null;
  } else if (typeof encoding === 'function') {
    cb = encoding;
    encoding = null;
  }

  if (chunk !== null && chunk !== undefined)
    this.write(chunk, encoding);

  // .end() fully uncorks
  if (state.corked) {
    state.corked = 1;
    this.uncork();
  }

  // ignore unnecessary end() calls.
  if (!state.ending && !state.finished)
    endWritable(this, state, cb);
};


function needFinish(state) {
  return (state.ending &&
          state.length === 0 &&
          state.bufferedRequest === null &&
          !state.finished &&
          !state.writing);
}

function prefinish(stream, state) {
  if (!state.prefinished) {
    state.prefinished = true;
    stream.emit('prefinish');
  }
}

function finishMaybe(stream, state) {
  var need = needFinish(state);
  if (need) {
    if (state.pendingcb === 0) {
      prefinish(stream, state);
      state.finished = true;
      stream.emit('finish');
    } else {
      prefinish(stream, state);
    }
  }
  return need;
}

function endWritable(stream, state, cb) {
  state.ending = true;
  finishMaybe(stream, state);
  if (cb) {
    if (state.finished)
      processNextTick(cb);
    else
      stream.once('finish', cb);
  }
  state.ended = true;
}

},{"./_stream_duplex":72,"buffer":57,"core-util-is":77,"events":61,"inherits":63,"process-nextick-args":78,"util-deprecate":79}],77:[function(require,module,exports){
(function (Buffer){
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.

// NOTE: These type checking functions intentionally don't use `instanceof`
// because it is fragile and can be easily faked with `Object.create()`.

function isArray(arg) {
  if (Array.isArray) {
    return Array.isArray(arg);
  }
  return objectToString(arg) === '[object Array]';
}
exports.isArray = isArray;

function isBoolean(arg) {
  return typeof arg === 'boolean';
}
exports.isBoolean = isBoolean;

function isNull(arg) {
  return arg === null;
}
exports.isNull = isNull;

function isNullOrUndefined(arg) {
  return arg == null;
}
exports.isNullOrUndefined = isNullOrUndefined;

function isNumber(arg) {
  return typeof arg === 'number';
}
exports.isNumber = isNumber;

function isString(arg) {
  return typeof arg === 'string';
}
exports.isString = isString;

function isSymbol(arg) {
  return typeof arg === 'symbol';
}
exports.isSymbol = isSymbol;

function isUndefined(arg) {
  return arg === void 0;
}
exports.isUndefined = isUndefined;

function isRegExp(re) {
  return objectToString(re) === '[object RegExp]';
}
exports.isRegExp = isRegExp;

function isObject(arg) {
  return typeof arg === 'object' && arg !== null;
}
exports.isObject = isObject;

function isDate(d) {
  return objectToString(d) === '[object Date]';
}
exports.isDate = isDate;

function isError(e) {
  return (objectToString(e) === '[object Error]' || e instanceof Error);
}
exports.isError = isError;

function isFunction(arg) {
  return typeof arg === 'function';
}
exports.isFunction = isFunction;

function isPrimitive(arg) {
  return arg === null ||
         typeof arg === 'boolean' ||
         typeof arg === 'number' ||
         typeof arg === 'string' ||
         typeof arg === 'symbol' ||  // ES6 symbol
         typeof arg === 'undefined';
}
exports.isPrimitive = isPrimitive;

exports.isBuffer = Buffer.isBuffer;

function objectToString(o) {
  return Object.prototype.toString.call(o);
}

}).call(this,{"isBuffer":require("../../../../insert-module-globals/node_modules/is-buffer/index.js")})

},{"../../../../insert-module-globals/node_modules/is-buffer/index.js":64}],78:[function(require,module,exports){
(function (process){
'use strict';

if (!process.version ||
    process.version.indexOf('v0.') === 0 ||
    process.version.indexOf('v1.') === 0 && process.version.indexOf('v1.8.') !== 0) {
  module.exports = nextTick;
} else {
  module.exports = process.nextTick;
}

function nextTick(fn) {
  var args = new Array(arguments.length - 1);
  var i = 0;
  while (i < args.length) {
    args[i++] = arguments[i];
  }
  process.nextTick(function afterTick() {
    fn.apply(null, args);
  });
}

}).call(this,require('_process'))

},{"_process":66}],79:[function(require,module,exports){
(function (global){

/**
 * Module exports.
 */

module.exports = deprecate;

/**
 * Mark that a method should not be used.
 * Returns a modified function which warns once by default.
 *
 * If `localStorage.noDeprecation = true` is set, then it is a no-op.
 *
 * If `localStorage.throwDeprecation = true` is set, then deprecated functions
 * will throw an Error when invoked.
 *
 * If `localStorage.traceDeprecation = true` is set, then deprecated functions
 * will invoke `console.trace()` instead of `console.error()`.
 *
 * @param {Function} fn - the function to deprecate
 * @param {String} msg - the string to print to the console when `fn` is invoked
 * @returns {Function} a new "deprecated" version of `fn`
 * @api public
 */

function deprecate (fn, msg) {
  if (config('noDeprecation')) {
    return fn;
  }

  var warned = false;
  function deprecated() {
    if (!warned) {
      if (config('throwDeprecation')) {
        throw new Error(msg);
      } else if (config('traceDeprecation')) {
        console.trace(msg);
      } else {
        console.warn(msg);
      }
      warned = true;
    }
    return fn.apply(this, arguments);
  }

  return deprecated;
}

/**
 * Checks `localStorage` for boolean values for the given `name`.
 *
 * @param {String} name
 * @returns {Boolean}
 * @api private
 */

function config (name) {
  // accessing global.localStorage can trigger a DOMException in sandboxed iframes
  try {
    if (!global.localStorage) return false;
  } catch (_) {
    return false;
  }
  var val = global.localStorage[name];
  if (null == val) return false;
  return String(val).toLowerCase() === 'true';
}

}).call(this,typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {})

},{}],80:[function(require,module,exports){
module.exports = require("./lib/_stream_passthrough.js")

},{"./lib/_stream_passthrough.js":73}],81:[function(require,module,exports){
var Stream = (function (){
  try {
    return require('st' + 'ream'); // hack to fix a circular dependency issue when used with browserify
  } catch(_){}
}());
exports = module.exports = require('./lib/_stream_readable.js');
exports.Stream = Stream || exports;
exports.Readable = exports;
exports.Writable = require('./lib/_stream_writable.js');
exports.Duplex = require('./lib/_stream_duplex.js');
exports.Transform = require('./lib/_stream_transform.js');
exports.PassThrough = require('./lib/_stream_passthrough.js');

},{"./lib/_stream_duplex.js":72,"./lib/_stream_passthrough.js":73,"./lib/_stream_readable.js":74,"./lib/_stream_transform.js":75,"./lib/_stream_writable.js":76}],82:[function(require,module,exports){
module.exports = require("./lib/_stream_transform.js")

},{"./lib/_stream_transform.js":75}],83:[function(require,module,exports){
module.exports = require("./lib/_stream_writable.js")

},{"./lib/_stream_writable.js":76}],84:[function(require,module,exports){
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.

module.exports = Stream;

var EE = require('events').EventEmitter;
var inherits = require('inherits');

inherits(Stream, EE);
Stream.Readable = require('readable-stream/readable.js');
Stream.Writable = require('readable-stream/writable.js');
Stream.Duplex = require('readable-stream/duplex.js');
Stream.Transform = require('readable-stream/transform.js');
Stream.PassThrough = require('readable-stream/passthrough.js');

// Backwards-compat with node 0.4.x
Stream.Stream = Stream;



// old-style streams.  Note that the pipe method (the only relevant
// part of this class) is overridden in the Readable class.

function Stream() {
  EE.call(this);
}

Stream.prototype.pipe = function(dest, options) {
  var source = this;

  function ondata(chunk) {
    if (dest.writable) {
      if (false === dest.write(chunk) && source.pause) {
        source.pause();
      }
    }
  }

  source.on('data', ondata);

  function ondrain() {
    if (source.readable && source.resume) {
      source.resume();
    }
  }

  dest.on('drain', ondrain);

  // If the 'end' option is not supplied, dest.end() will be called when
  // source gets the 'end' or 'close' events.  Only dest.end() once.
  if (!dest._isStdio && (!options || options.end !== false)) {
    source.on('end', onend);
    source.on('close', onclose);
  }

  var didOnEnd = false;
  function onend() {
    if (didOnEnd) return;
    didOnEnd = true;

    dest.end();
  }


  function onclose() {
    if (didOnEnd) return;
    didOnEnd = true;

    if (typeof dest.destroy === 'function') dest.destroy();
  }

  // don't leave dangling pipes when there are errors.
  function onerror(er) {
    cleanup();
    if (EE.listenerCount(this, 'error') === 0) {
      throw er; // Unhandled stream error in pipe.
    }
  }

  source.on('error', onerror);
  dest.on('error', onerror);

  // remove all the event listeners that were added.
  function cleanup() {
    source.removeListener('data', ondata);
    dest.removeListener('drain', ondrain);

    source.removeListener('end', onend);
    source.removeListener('close', onclose);

    source.removeListener('error', onerror);
    dest.removeListener('error', onerror);

    source.removeListener('end', cleanup);
    source.removeListener('close', cleanup);

    dest.removeListener('close', cleanup);
  }

  source.on('end', cleanup);
  source.on('close', cleanup);

  dest.on('close', cleanup);

  dest.emit('pipe', source);

  // Allow for unix-like usage: A.pipe(B).pipe(C)
  return dest;
};

},{"events":61,"inherits":63,"readable-stream/duplex.js":71,"readable-stream/passthrough.js":80,"readable-stream/readable.js":81,"readable-stream/transform.js":82,"readable-stream/writable.js":83}],85:[function(require,module,exports){
var ClientRequest = require('./lib/request')
var extend = require('xtend')
var statusCodes = require('builtin-status-codes')
var url = require('url')

var http = exports

http.request = function (opts, cb) {
	if (typeof opts === 'string')
		opts = url.parse(opts)
	else
		opts = extend(opts)

	var protocol = opts.protocol || ''
	var host = opts.hostname || opts.host
	var port = opts.port
	var path = opts.path || '/'

	// Necessary for IPv6 addresses
	if (host && host.indexOf(':') !== -1)
		host = '[' + host + ']'

	// This may be a relative url. The browser should always be able to interpret it correctly.
	opts.url = (host ? (protocol + '//' + host) : '') + (port ? ':' + port : '') + path
	opts.method = (opts.method || 'GET').toUpperCase()
	opts.headers = opts.headers || {}

	// Also valid opts.auth, opts.mode

	var req = new ClientRequest(opts)
	if (cb)
		req.on('response', cb)
	return req
}

http.get = function get (opts, cb) {
	var req = http.request(opts, cb)
	req.end()
	return req
}

http.Agent = function () {}
http.Agent.defaultMaxSockets = 4

http.STATUS_CODES = statusCodes

http.METHODS = [
	'CHECKOUT',
	'CONNECT',
	'COPY',
	'DELETE',
	'GET',
	'HEAD',
	'LOCK',
	'M-SEARCH',
	'MERGE',
	'MKACTIVITY',
	'MKCOL',
	'MOVE',
	'NOTIFY',
	'OPTIONS',
	'PATCH',
	'POST',
	'PROPFIND',
	'PROPPATCH',
	'PURGE',
	'PUT',
	'REPORT',
	'SEARCH',
	'SUBSCRIBE',
	'TRACE',
	'UNLOCK',
	'UNSUBSCRIBE'
]
},{"./lib/request":87,"builtin-status-codes":89,"url":91,"xtend":95}],86:[function(require,module,exports){
(function (global){
exports.fetch = isFunction(global.fetch) && isFunction(global.ReadableByteStream)

exports.blobConstructor = false
try {
	new Blob([new ArrayBuffer(1)])
	exports.blobConstructor = true
} catch (e) {}

var xhr = new global.XMLHttpRequest()
// If location.host is empty, e.g. if this page/worker was loaded
// from a Blob, then use example.com to avoid an error
xhr.open('GET', global.location.host ? '/' : 'https://example.com')

function checkTypeSupport (type) {
	try {
		xhr.responseType = type
		return xhr.responseType === type
	} catch (e) {}
	return false
}

// For some strange reason, Safari 7.0 reports typeof global.ArrayBuffer === 'object'.
// Safari 7.1 appears to have fixed this bug.
var haveArrayBuffer = typeof global.ArrayBuffer !== 'undefined'
var haveSlice = haveArrayBuffer && isFunction(global.ArrayBuffer.prototype.slice)

exports.arraybuffer = haveArrayBuffer && checkTypeSupport('arraybuffer')
// These next two tests unavoidably show warnings in Chrome. Since fetch will always
// be used if it's available, just return false for these to avoid the warnings.
exports.msstream = !exports.fetch && haveSlice && checkTypeSupport('ms-stream')
exports.mozchunkedarraybuffer = !exports.fetch && haveArrayBuffer &&
	checkTypeSupport('moz-chunked-arraybuffer')
exports.overrideMimeType = isFunction(xhr.overrideMimeType)
exports.vbArray = isFunction(global.VBArray)

function isFunction (value) {
  return typeof value === 'function'
}

xhr = null // Help gc

}).call(this,typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {})

},{}],87:[function(require,module,exports){
(function (process,global,Buffer){
// var Base64 = require('Base64')
var capability = require('./capability')
var inherits = require('inherits')
var response = require('./response')
var stream = require('stream')

var IncomingMessage = response.IncomingMessage
var rStates = response.readyStates

function decideMode (preferBinary) {
	if (capability.fetch) {
		return 'fetch'
	} else if (capability.mozchunkedarraybuffer) {
		return 'moz-chunked-arraybuffer'
	} else if (capability.msstream) {
		return 'ms-stream'
	} else if (capability.arraybuffer && preferBinary) {
		return 'arraybuffer'
	} else if (capability.vbArray && preferBinary) {
		return 'text:vbarray'
	} else {
		return 'text'
	}
}

var ClientRequest = module.exports = function (opts) {
	var self = this
	stream.Writable.call(self)

	self._opts = opts
	self._body = []
	self._headers = {}
	if (opts.auth)
		self.setHeader('Authorization', 'Basic ' + new Buffer(opts.auth).toString('base64'))
	Object.keys(opts.headers).forEach(function (name) {
		self.setHeader(name, opts.headers[name])
	})

	var preferBinary
	if (opts.mode === 'prefer-streaming') {
		// If streaming is a high priority but binary compatibility and
		// the accuracy of the 'content-type' header aren't
		preferBinary = false
	} else if (opts.mode === 'allow-wrong-content-type') {
		// If streaming is more important than preserving the 'content-type' header
		preferBinary = !capability.overrideMimeType
	} else if (!opts.mode || opts.mode === 'default' || opts.mode === 'prefer-fast') {
		// Use binary if text streaming may corrupt data or the content-type header, or for speed
		preferBinary = true
	} else {
		throw new Error('Invalid value for opts.mode')
	}
	self._mode = decideMode(preferBinary)

	self.on('finish', function () {
		self._onFinish()
	})
}

inherits(ClientRequest, stream.Writable)

ClientRequest.prototype.setHeader = function (name, value) {
	var self = this
	var lowerName = name.toLowerCase()
	// This check is not necessary, but it prevents warnings from browsers about setting unsafe
	// headers. To be honest I'm not entirely sure hiding these warnings is a good thing, but
	// http-browserify did it, so I will too.
	if (unsafeHeaders.indexOf(lowerName) !== -1)
		return

	self._headers[lowerName] = {
		name: name,
		value: value
	}
}

ClientRequest.prototype.getHeader = function (name) {
	var self = this
	return self._headers[name.toLowerCase()].value
}

ClientRequest.prototype.removeHeader = function (name) {
	var self = this
	delete self._headers[name.toLowerCase()]
}

ClientRequest.prototype._onFinish = function () {
	var self = this

	if (self._destroyed)
		return
	var opts = self._opts

	var headersObj = self._headers
	var body
	if (opts.method === 'POST' || opts.method === 'PUT' || opts.method === 'PATCH') {
		if (capability.blobConstructor) {
			body = new global.Blob(self._body.map(function (buffer) {
				return buffer.toArrayBuffer()
			}), {
				type: (headersObj['content-type'] || {}).value || ''
			})
		} else {
			// get utf8 string
			body = Buffer.concat(self._body).toString()
		}
	}

	if (self._mode === 'fetch') {
		var headers = Object.keys(headersObj).map(function (name) {
			return [headersObj[name].name, headersObj[name].value]
		})

		global.fetch(self._opts.url, {
			method: self._opts.method,
			headers: headers,
			body: body,
			mode: 'cors',
			credentials: opts.withCredentials ? 'include' : 'same-origin'
		}).then(function (response) {
			self._fetchResponse = response
			self._connect()
		}, function (reason) {
			self.emit('error', reason)
		})
	} else {
		var xhr = self._xhr = new global.XMLHttpRequest()
		try {
			xhr.open(self._opts.method, self._opts.url, true)
		} catch (err) {
			process.nextTick(function () {
				self.emit('error', err)
			})
			return
		}

		// Can't set responseType on really old browsers
		if ('responseType' in xhr)
			xhr.responseType = self._mode.split(':')[0]

		if ('withCredentials' in xhr)
			xhr.withCredentials = !!opts.withCredentials

		if (self._mode === 'text' && 'overrideMimeType' in xhr)
			xhr.overrideMimeType('text/plain; charset=x-user-defined')

		Object.keys(headersObj).forEach(function (name) {
			xhr.setRequestHeader(headersObj[name].name, headersObj[name].value)
		})

		self._response = null
		xhr.onreadystatechange = function () {
			switch (xhr.readyState) {
				case rStates.LOADING:
				case rStates.DONE:
					self._onXHRProgress()
					break
			}
		}
		// Necessary for streaming in Firefox, since xhr.response is ONLY defined
		// in onprogress, not in onreadystatechange with xhr.readyState = 3
		if (self._mode === 'moz-chunked-arraybuffer') {
			xhr.onprogress = function () {
				self._onXHRProgress()
			}
		}

		xhr.onerror = function () {
			if (self._destroyed)
				return
			self.emit('error', new Error('XHR error'))
		}

		try {
			xhr.send(body)
		} catch (err) {
			process.nextTick(function () {
				self.emit('error', err)
			})
			return
		}
	}
}

/**
 * Checks if xhr.status is readable. Even though the spec says it should
 * be available in readyState 3, accessing it throws an exception in IE8
 */
function statusValid (xhr) {
	try {
		return (xhr.status !== null)
	} catch (e) {
		return false
	}
}

ClientRequest.prototype._onXHRProgress = function () {
	var self = this

	if (!statusValid(self._xhr) || self._destroyed)
		return

	if (!self._response)
		self._connect()

	self._response._onXHRProgress()
}

ClientRequest.prototype._connect = function () {
	var self = this

	if (self._destroyed)
		return

	self._response = new IncomingMessage(self._xhr, self._fetchResponse, self._mode)
	self.emit('response', self._response)
}

ClientRequest.prototype._write = function (chunk, encoding, cb) {
	var self = this

	self._body.push(chunk)
	cb()
}

ClientRequest.prototype.abort = ClientRequest.prototype.destroy = function () {
	var self = this
	self._destroyed = true
	if (self._response)
		self._response._destroyed = true
	if (self._xhr)
		self._xhr.abort()
	// Currently, there isn't a way to truly abort a fetch.
	// If you like bikeshedding, see https://github.com/whatwg/fetch/issues/27
}

ClientRequest.prototype.end = function (data, encoding, cb) {
	var self = this
	if (typeof data === 'function') {
		cb = data
		data = undefined
	}

	stream.Writable.prototype.end.call(self, data, encoding, cb)
}

ClientRequest.prototype.flushHeaders = function () {}
ClientRequest.prototype.setTimeout = function () {}
ClientRequest.prototype.setNoDelay = function () {}
ClientRequest.prototype.setSocketKeepAlive = function () {}

// Taken from http://www.w3.org/TR/XMLHttpRequest/#the-setrequestheader%28%29-method
var unsafeHeaders = [
	'accept-charset',
	'accept-encoding',
	'access-control-request-headers',
	'access-control-request-method',
	'connection',
	'content-length',
	'cookie',
	'cookie2',
	'date',
	'dnt',
	'expect',
	'host',
	'keep-alive',
	'origin',
	'referer',
	'te',
	'trailer',
	'transfer-encoding',
	'upgrade',
	'user-agent',
	'via'
]

}).call(this,require('_process'),typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {},require("buffer").Buffer)

},{"./capability":86,"./response":88,"_process":66,"buffer":57,"inherits":63,"stream":84}],88:[function(require,module,exports){
(function (process,global,Buffer){
var capability = require('./capability')
var inherits = require('inherits')
var stream = require('stream')

var rStates = exports.readyStates = {
	UNSENT: 0,
	OPENED: 1,
	HEADERS_RECEIVED: 2,
	LOADING: 3,
	DONE: 4
}

var IncomingMessage = exports.IncomingMessage = function (xhr, response, mode) {
	var self = this
	stream.Readable.call(self)

	self._mode = mode
	self.headers = {}
	self.rawHeaders = []
	self.trailers = {}
	self.rawTrailers = []

	// Fake the 'close' event, but only once 'end' fires
	self.on('end', function () {
		// The nextTick is necessary to prevent the 'request' module from causing an infinite loop
		process.nextTick(function () {
			self.emit('close')
		})
	})

	if (mode === 'fetch') {
		self._fetchResponse = response

		self.statusCode = response.status
		self.statusMessage = response.statusText
		// backwards compatible version of for (<item> of <iterable>):
		// for (var <item>,_i,_it = <iterable>[Symbol.iterator](); <item> = (_i = _it.next()).value,!_i.done;)
		for (var header, _i, _it = response.headers[Symbol.iterator](); header = (_i = _it.next()).value, !_i.done;) {
			self.headers[header[0].toLowerCase()] = header[1]
			self.rawHeaders.push(header[0], header[1])
		}

		// TODO: this doesn't respect backpressure. Once WritableStream is available, this can be fixed
		var reader = response.body.getReader()
		function read () {
			reader.read().then(function (result) {
				if (self._destroyed)
					return
				if (result.done) {
					self.push(null)
					return
				}
				self.push(new Buffer(result.value))
				read()
			})
		}
		read()

	} else {
		self._xhr = xhr
		self._pos = 0

		self.statusCode = xhr.status
		self.statusMessage = xhr.statusText
		var headers = xhr.getAllResponseHeaders().split(/\r?\n/)
		headers.forEach(function (header) {
			var matches = header.match(/^([^:]+):\s*(.*)/)
			if (matches) {
				var key = matches[1].toLowerCase()
				if (self.headers[key] !== undefined)
					self.headers[key] += ', ' + matches[2]
				else
					self.headers[key] = matches[2]
				self.rawHeaders.push(matches[1], matches[2])
			}
		})

		self._charset = 'x-user-defined'
		if (!capability.overrideMimeType) {
			var mimeType = self.rawHeaders['mime-type']
			if (mimeType) {
				var charsetMatch = mimeType.match(/;\s*charset=([^;])(;|$)/)
				if (charsetMatch) {
					self._charset = charsetMatch[1].toLowerCase()
				}
			}
			if (!self._charset)
				self._charset = 'utf-8' // best guess
		}
	}
}

inherits(IncomingMessage, stream.Readable)

IncomingMessage.prototype._read = function () {}

IncomingMessage.prototype._onXHRProgress = function () {
	var self = this

	var xhr = self._xhr

	var response = null
	switch (self._mode) {
		case 'text:vbarray': // For IE9
			if (xhr.readyState !== rStates.DONE)
				break
			try {
				// This fails in IE8
				response = new global.VBArray(xhr.responseBody).toArray()
			} catch (e) {}
			if (response !== null) {
				self.push(new Buffer(response))
				break
			}
			// Falls through in IE8	
		case 'text':
			try { // This will fail when readyState = 3 in IE9. Switch mode and wait for readyState = 4
				response = xhr.responseText
			} catch (e) {
				self._mode = 'text:vbarray'
				break
			}
			if (response.length > self._pos) {
				var newData = response.substr(self._pos)
				if (self._charset === 'x-user-defined') {
					var buffer = new Buffer(newData.length)
					for (var i = 0; i < newData.length; i++)
						buffer[i] = newData.charCodeAt(i) & 0xff

					self.push(buffer)
				} else {
					self.push(newData, self._charset)
				}
				self._pos = response.length
			}
			break
		case 'arraybuffer':
			if (xhr.readyState !== rStates.DONE)
				break
			response = xhr.response
			self.push(new Buffer(new Uint8Array(response)))
			break
		case 'moz-chunked-arraybuffer': // take whole
			response = xhr.response
			if (xhr.readyState !== rStates.LOADING || !response)
				break
			self.push(new Buffer(new Uint8Array(response)))
			break
		case 'ms-stream':
			response = xhr.response
			if (xhr.readyState !== rStates.LOADING)
				break
			var reader = new global.MSStreamReader()
			reader.onprogress = function () {
				if (reader.result.byteLength > self._pos) {
					self.push(new Buffer(new Uint8Array(reader.result.slice(self._pos))))
					self._pos = reader.result.byteLength
				}
			}
			reader.onload = function () {
				self.push(null)
			}
			// reader.onerror = ??? // TODO: this
			reader.readAsArrayBuffer(response)
			break
	}

	// The ms-stream case handles end separately in reader.onload()
	if (self._xhr.readyState === rStates.DONE && self._mode !== 'ms-stream') {
		self.push(null)
	}
}

}).call(this,require('_process'),typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {},require("buffer").Buffer)

},{"./capability":86,"_process":66,"buffer":57,"inherits":63,"stream":84}],89:[function(require,module,exports){
module.exports = {
  "100": "Continue",
  "101": "Switching Protocols",
  "102": "Processing",
  "200": "OK",
  "201": "Created",
  "202": "Accepted",
  "203": "Non-Authoritative Information",
  "204": "No Content",
  "205": "Reset Content",
  "206": "Partial Content",
  "207": "Multi-Status",
  "300": "Multiple Choices",
  "301": "Moved Permanently",
  "302": "Moved Temporarily",
  "303": "See Other",
  "304": "Not Modified",
  "305": "Use Proxy",
  "307": "Temporary Redirect",
  "308": "Permanent Redirect",
  "400": "Bad Request",
  "401": "Unauthorized",
  "402": "Payment Required",
  "403": "Forbidden",
  "404": "Not Found",
  "405": "Method Not Allowed",
  "406": "Not Acceptable",
  "407": "Proxy Authentication Required",
  "408": "Request Time-out",
  "409": "Conflict",
  "410": "Gone",
  "411": "Length Required",
  "412": "Precondition Failed",
  "413": "Request Entity Too Large",
  "414": "Request-URI Too Large",
  "415": "Unsupported Media Type",
  "416": "Requested Range Not Satisfiable",
  "417": "Expectation Failed",
  "418": "I'm a teapot",
  "422": "Unprocessable Entity",
  "423": "Locked",
  "424": "Failed Dependency",
  "425": "Unordered Collection",
  "426": "Upgrade Required",
  "428": "Precondition Required",
  "429": "Too Many Requests",
  "431": "Request Header Fields Too Large",
  "500": "Internal Server Error",
  "501": "Not Implemented",
  "502": "Bad Gateway",
  "503": "Service Unavailable",
  "504": "Gateway Time-out",
  "505": "HTTP Version Not Supported",
  "506": "Variant Also Negotiates",
  "507": "Insufficient Storage",
  "509": "Bandwidth Limit Exceeded",
  "510": "Not Extended",
  "511": "Network Authentication Required"
}

},{}],90:[function(require,module,exports){
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.

var Buffer = require('buffer').Buffer;

var isBufferEncoding = Buffer.isEncoding
  || function(encoding) {
       switch (encoding && encoding.toLowerCase()) {
         case 'hex': case 'utf8': case 'utf-8': case 'ascii': case 'binary': case 'base64': case 'ucs2': case 'ucs-2': case 'utf16le': case 'utf-16le': case 'raw': return true;
         default: return false;
       }
     }


function assertEncoding(encoding) {
  if (encoding && !isBufferEncoding(encoding)) {
    throw new Error('Unknown encoding: ' + encoding);
  }
}

// StringDecoder provides an interface for efficiently splitting a series of
// buffers into a series of JS strings without breaking apart multi-byte
// characters. CESU-8 is handled as part of the UTF-8 encoding.
//
// @TODO Handling all encodings inside a single object makes it very difficult
// to reason about this code, so it should be split up in the future.
// @TODO There should be a utf8-strict encoding that rejects invalid UTF-8 code
// points as used by CESU-8.
var StringDecoder = exports.StringDecoder = function(encoding) {
  this.encoding = (encoding || 'utf8').toLowerCase().replace(/[-_]/, '');
  assertEncoding(encoding);
  switch (this.encoding) {
    case 'utf8':
      // CESU-8 represents each of Surrogate Pair by 3-bytes
      this.surrogateSize = 3;
      break;
    case 'ucs2':
    case 'utf16le':
      // UTF-16 represents each of Surrogate Pair by 2-bytes
      this.surrogateSize = 2;
      this.detectIncompleteChar = utf16DetectIncompleteChar;
      break;
    case 'base64':
      // Base-64 stores 3 bytes in 4 chars, and pads the remainder.
      this.surrogateSize = 3;
      this.detectIncompleteChar = base64DetectIncompleteChar;
      break;
    default:
      this.write = passThroughWrite;
      return;
  }

  // Enough space to store all bytes of a single character. UTF-8 needs 4
  // bytes, but CESU-8 may require up to 6 (3 bytes per surrogate).
  this.charBuffer = new Buffer(6);
  // Number of bytes received for the current incomplete multi-byte character.
  this.charReceived = 0;
  // Number of bytes expected for the current incomplete multi-byte character.
  this.charLength = 0;
};


// write decodes the given buffer and returns it as JS string that is
// guaranteed to not contain any partial multi-byte characters. Any partial
// character found at the end of the buffer is buffered up, and will be
// returned when calling write again with the remaining bytes.
//
// Note: Converting a Buffer containing an orphan surrogate to a String
// currently works, but converting a String to a Buffer (via `new Buffer`, or
// Buffer#write) will replace incomplete surrogates with the unicode
// replacement character. See https://codereview.chromium.org/121173009/ .
StringDecoder.prototype.write = function(buffer) {
  var charStr = '';
  // if our last write ended with an incomplete multibyte character
  while (this.charLength) {
    // determine how many remaining bytes this buffer has to offer for this char
    var available = (buffer.length >= this.charLength - this.charReceived) ?
        this.charLength - this.charReceived :
        buffer.length;

    // add the new bytes to the char buffer
    buffer.copy(this.charBuffer, this.charReceived, 0, available);
    this.charReceived += available;

    if (this.charReceived < this.charLength) {
      // still not enough chars in this buffer? wait for more ...
      return '';
    }

    // remove bytes belonging to the current character from the buffer
    buffer = buffer.slice(available, buffer.length);

    // get the character that was split
    charStr = this.charBuffer.slice(0, this.charLength).toString(this.encoding);

    // CESU-8: lead surrogate (D800-DBFF) is also the incomplete character
    var charCode = charStr.charCodeAt(charStr.length - 1);
    if (charCode >= 0xD800 && charCode <= 0xDBFF) {
      this.charLength += this.surrogateSize;
      charStr = '';
      continue;
    }
    this.charReceived = this.charLength = 0;

    // if there are no more bytes in this buffer, just emit our char
    if (buffer.length === 0) {
      return charStr;
    }
    break;
  }

  // determine and set charLength / charReceived
  this.detectIncompleteChar(buffer);

  var end = buffer.length;
  if (this.charLength) {
    // buffer the incomplete character bytes we got
    buffer.copy(this.charBuffer, 0, buffer.length - this.charReceived, end);
    end -= this.charReceived;
  }

  charStr += buffer.toString(this.encoding, 0, end);

  var end = charStr.length - 1;
  var charCode = charStr.charCodeAt(end);
  // CESU-8: lead surrogate (D800-DBFF) is also the incomplete character
  if (charCode >= 0xD800 && charCode <= 0xDBFF) {
    var size = this.surrogateSize;
    this.charLength += size;
    this.charReceived += size;
    this.charBuffer.copy(this.charBuffer, size, 0, size);
    buffer.copy(this.charBuffer, 0, 0, size);
    return charStr.substring(0, end);
  }

  // or just emit the charStr
  return charStr;
};

// detectIncompleteChar determines if there is an incomplete UTF-8 character at
// the end of the given buffer. If so, it sets this.charLength to the byte
// length that character, and sets this.charReceived to the number of bytes
// that are available for this character.
StringDecoder.prototype.detectIncompleteChar = function(buffer) {
  // determine how many bytes we have to check at the end of this buffer
  var i = (buffer.length >= 3) ? 3 : buffer.length;

  // Figure out if one of the last i bytes of our buffer announces an
  // incomplete char.
  for (; i > 0; i--) {
    var c = buffer[buffer.length - i];

    // See http://en.wikipedia.org/wiki/UTF-8#Description

    // 110XXXXX
    if (i == 1 && c >> 5 == 0x06) {
      this.charLength = 2;
      break;
    }

    // 1110XXXX
    if (i <= 2 && c >> 4 == 0x0E) {
      this.charLength = 3;
      break;
    }

    // 11110XXX
    if (i <= 3 && c >> 3 == 0x1E) {
      this.charLength = 4;
      break;
    }
  }
  this.charReceived = i;
};

StringDecoder.prototype.end = function(buffer) {
  var res = '';
  if (buffer && buffer.length)
    res = this.write(buffer);

  if (this.charReceived) {
    var cr = this.charReceived;
    var buf = this.charBuffer;
    var enc = this.encoding;
    res += buf.slice(0, cr).toString(enc);
  }

  return res;
};

function passThroughWrite(buffer) {
  return buffer.toString(this.encoding);
}

function utf16DetectIncompleteChar(buffer) {
  this.charReceived = buffer.length % 2;
  this.charLength = this.charReceived ? 2 : 0;
}

function base64DetectIncompleteChar(buffer) {
  this.charReceived = buffer.length % 3;
  this.charLength = this.charReceived ? 3 : 0;
}

},{"buffer":57}],91:[function(require,module,exports){
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.

'use strict';

var punycode = require('punycode');
var util = require('./util');

exports.parse = urlParse;
exports.resolve = urlResolve;
exports.resolveObject = urlResolveObject;
exports.format = urlFormat;

exports.Url = Url;

function Url() {
  this.protocol = null;
  this.slashes = null;
  this.auth = null;
  this.host = null;
  this.port = null;
  this.hostname = null;
  this.hash = null;
  this.search = null;
  this.query = null;
  this.pathname = null;
  this.path = null;
  this.href = null;
}

// Reference: RFC 3986, RFC 1808, RFC 2396

// define these here so at least they only have to be
// compiled once on the first module load.
var protocolPattern = /^([a-z0-9.+-]+:)/i,
    portPattern = /:[0-9]*$/,

    // Special case for a simple path URL
    simplePathPattern = /^(\/\/?(?!\/)[^\?\s]*)(\?[^\s]*)?$/,

    // RFC 2396: characters reserved for delimiting URLs.
    // We actually just auto-escape these.
    delims = ['<', '>', '"', '`', ' ', '\r', '\n', '\t'],

    // RFC 2396: characters not allowed for various reasons.
    unwise = ['{', '}', '|', '\\', '^', '`'].concat(delims),

    // Allowed by RFCs, but cause of XSS attacks.  Always escape these.
    autoEscape = ['\''].concat(unwise),
    // Characters that are never ever allowed in a hostname.
    // Note that any invalid chars are also handled, but these
    // are the ones that are *expected* to be seen, so we fast-path
    // them.
    nonHostChars = ['%', '/', '?', ';', '#'].concat(autoEscape),
    hostEndingChars = ['/', '?', '#'],
    hostnameMaxLen = 255,
    hostnamePartPattern = /^[+a-z0-9A-Z_-]{0,63}$/,
    hostnamePartStart = /^([+a-z0-9A-Z_-]{0,63})(.*)$/,
    // protocols that can allow "unsafe" and "unwise" chars.
    unsafeProtocol = {
      'javascript': true,
      'javascript:': true
    },
    // protocols that never have a hostname.
    hostlessProtocol = {
      'javascript': true,
      'javascript:': true
    },
    // protocols that always contain a // bit.
    slashedProtocol = {
      'http': true,
      'https': true,
      'ftp': true,
      'gopher': true,
      'file': true,
      'http:': true,
      'https:': true,
      'ftp:': true,
      'gopher:': true,
      'file:': true
    },
    querystring = require('querystring');

function urlParse(url, parseQueryString, slashesDenoteHost) {
  if (url && util.isObject(url) && url instanceof Url) return url;

  var u = new Url;
  u.parse(url, parseQueryString, slashesDenoteHost);
  return u;
}

Url.prototype.parse = function(url, parseQueryString, slashesDenoteHost) {
  if (!util.isString(url)) {
    throw new TypeError("Parameter 'url' must be a string, not " + typeof url);
  }

  // Copy chrome, IE, opera backslash-handling behavior.
  // Back slashes before the query string get converted to forward slashes
  // See: https://code.google.com/p/chromium/issues/detail?id=25916
  var queryIndex = url.indexOf('?'),
      splitter =
          (queryIndex !== -1 && queryIndex < url.indexOf('#')) ? '?' : '#',
      uSplit = url.split(splitter),
      slashRegex = /\\/g;
  uSplit[0] = uSplit[0].replace(slashRegex, '/');
  url = uSplit.join(splitter);

  var rest = url;

  // trim before proceeding.
  // This is to support parse stuff like "  http://foo.com  \n"
  rest = rest.trim();

  if (!slashesDenoteHost && url.split('#').length === 1) {
    // Try fast path regexp
    var simplePath = simplePathPattern.exec(rest);
    if (simplePath) {
      this.path = rest;
      this.href = rest;
      this.pathname = simplePath[1];
      if (simplePath[2]) {
        this.search = simplePath[2];
        if (parseQueryString) {
          this.query = querystring.parse(this.search.substr(1));
        } else {
          this.query = this.search.substr(1);
        }
      } else if (parseQueryString) {
        this.search = '';
        this.query = {};
      }
      return this;
    }
  }

  var proto = protocolPattern.exec(rest);
  if (proto) {
    proto = proto[0];
    var lowerProto = proto.toLowerCase();
    this.protocol = lowerProto;
    rest = rest.substr(proto.length);
  }

  // figure out if it's got a host
  // user@server is *always* interpreted as a hostname, and url
  // resolution will treat //foo/bar as host=foo,path=bar because that's
  // how the browser resolves relative URLs.
  if (slashesDenoteHost || proto || rest.match(/^\/\/[^@\/]+@[^@\/]+/)) {
    var slashes = rest.substr(0, 2) === '//';
    if (slashes && !(proto && hostlessProtocol[proto])) {
      rest = rest.substr(2);
      this.slashes = true;
    }
  }

  if (!hostlessProtocol[proto] &&
      (slashes || (proto && !slashedProtocol[proto]))) {

    // there's a hostname.
    // the first instance of /, ?, ;, or # ends the host.
    //
    // If there is an @ in the hostname, then non-host chars *are* allowed
    // to the left of the last @ sign, unless some host-ending character
    // comes *before* the @-sign.
    // URLs are obnoxious.
    //
    // ex:
    // http://a@b@c/ => user:a@b host:c
    // http://a@b?@c => user:a host:c path:/?@c

    // v0.12 TODO(isaacs): This is not quite how Chrome does things.
    // Review our test case against browsers more comprehensively.

    // find the first instance of any hostEndingChars
    var hostEnd = -1;
    for (var i = 0; i < hostEndingChars.length; i++) {
      var hec = rest.indexOf(hostEndingChars[i]);
      if (hec !== -1 && (hostEnd === -1 || hec < hostEnd))
        hostEnd = hec;
    }

    // at this point, either we have an explicit point where the
    // auth portion cannot go past, or the last @ char is the decider.
    var auth, atSign;
    if (hostEnd === -1) {
      // atSign can be anywhere.
      atSign = rest.lastIndexOf('@');
    } else {
      // atSign must be in auth portion.
      // http://a@b/c@d => host:b auth:a path:/c@d
      atSign = rest.lastIndexOf('@', hostEnd);
    }

    // Now we have a portion which is definitely the auth.
    // Pull that off.
    if (atSign !== -1) {
      auth = rest.slice(0, atSign);
      rest = rest.slice(atSign + 1);
      this.auth = decodeURIComponent(auth);
    }

    // the host is the remaining to the left of the first non-host char
    hostEnd = -1;
    for (var i = 0; i < nonHostChars.length; i++) {
      var hec = rest.indexOf(nonHostChars[i]);
      if (hec !== -1 && (hostEnd === -1 || hec < hostEnd))
        hostEnd = hec;
    }
    // if we still have not hit it, then the entire thing is a host.
    if (hostEnd === -1)
      hostEnd = rest.length;

    this.host = rest.slice(0, hostEnd);
    rest = rest.slice(hostEnd);

    // pull out port.
    this.parseHost();

    // we've indicated that there is a hostname,
    // so even if it's empty, it has to be present.
    this.hostname = this.hostname || '';

    // if hostname begins with [ and ends with ]
    // assume that it's an IPv6 address.
    var ipv6Hostname = this.hostname[0] === '[' &&
        this.hostname[this.hostname.length - 1] === ']';

    // validate a little.
    if (!ipv6Hostname) {
      var hostparts = this.hostname.split(/\./);
      for (var i = 0, l = hostparts.length; i < l; i++) {
        var part = hostparts[i];
        if (!part) continue;
        if (!part.match(hostnamePartPattern)) {
          var newpart = '';
          for (var j = 0, k = part.length; j < k; j++) {
            if (part.charCodeAt(j) > 127) {
              // we replace non-ASCII char with a temporary placeholder
              // we need this to make sure size of hostname is not
              // broken by replacing non-ASCII by nothing
              newpart += 'x';
            } else {
              newpart += part[j];
            }
          }
          // we test again with ASCII char only
          if (!newpart.match(hostnamePartPattern)) {
            var validParts = hostparts.slice(0, i);
            var notHost = hostparts.slice(i + 1);
            var bit = part.match(hostnamePartStart);
            if (bit) {
              validParts.push(bit[1]);
              notHost.unshift(bit[2]);
            }
            if (notHost.length) {
              rest = '/' + notHost.join('.') + rest;
            }
            this.hostname = validParts.join('.');
            break;
          }
        }
      }
    }

    if (this.hostname.length > hostnameMaxLen) {
      this.hostname = '';
    } else {
      // hostnames are always lower case.
      this.hostname = this.hostname.toLowerCase();
    }

    if (!ipv6Hostname) {
      // IDNA Support: Returns a punycoded representation of "domain".
      // It only converts parts of the domain name that
      // have non-ASCII characters, i.e. it doesn't matter if
      // you call it with a domain that already is ASCII-only.
      this.hostname = punycode.toASCII(this.hostname);
    }

    var p = this.port ? ':' + this.port : '';
    var h = this.hostname || '';
    this.host = h + p;
    this.href += this.host;

    // strip [ and ] from the hostname
    // the host field still retains them, though
    if (ipv6Hostname) {
      this.hostname = this.hostname.substr(1, this.hostname.length - 2);
      if (rest[0] !== '/') {
        rest = '/' + rest;
      }
    }
  }

  // now rest is set to the post-host stuff.
  // chop off any delim chars.
  if (!unsafeProtocol[lowerProto]) {

    // First, make 100% sure that any "autoEscape" chars get
    // escaped, even if encodeURIComponent doesn't think they
    // need to be.
    for (var i = 0, l = autoEscape.length; i < l; i++) {
      var ae = autoEscape[i];
      if (rest.indexOf(ae) === -1)
        continue;
      var esc = encodeURIComponent(ae);
      if (esc === ae) {
        esc = escape(ae);
      }
      rest = rest.split(ae).join(esc);
    }
  }


  // chop off from the tail first.
  var hash = rest.indexOf('#');
  if (hash !== -1) {
    // got a fragment string.
    this.hash = rest.substr(hash);
    rest = rest.slice(0, hash);
  }
  var qm = rest.indexOf('?');
  if (qm !== -1) {
    this.search = rest.substr(qm);
    this.query = rest.substr(qm + 1);
    if (parseQueryString) {
      this.query = querystring.parse(this.query);
    }
    rest = rest.slice(0, qm);
  } else if (parseQueryString) {
    // no query string, but parseQueryString still requested
    this.search = '';
    this.query = {};
  }
  if (rest) this.pathname = rest;
  if (slashedProtocol[lowerProto] &&
      this.hostname && !this.pathname) {
    this.pathname = '/';
  }

  //to support http.request
  if (this.pathname || this.search) {
    var p = this.pathname || '';
    var s = this.search || '';
    this.path = p + s;
  }

  // finally, reconstruct the href based on what has been validated.
  this.href = this.format();
  return this;
};

// format a parsed object into a url string
function urlFormat(obj) {
  // ensure it's an object, and not a string url.
  // If it's an obj, this is a no-op.
  // this way, you can call url_format() on strings
  // to clean up potentially wonky urls.
  if (util.isString(obj)) obj = urlParse(obj);
  if (!(obj instanceof Url)) return Url.prototype.format.call(obj);
  return obj.format();
}

Url.prototype.format = function() {
  var auth = this.auth || '';
  if (auth) {
    auth = encodeURIComponent(auth);
    auth = auth.replace(/%3A/i, ':');
    auth += '@';
  }

  var protocol = this.protocol || '',
      pathname = this.pathname || '',
      hash = this.hash || '',
      host = false,
      query = '';

  if (this.host) {
    host = auth + this.host;
  } else if (this.hostname) {
    host = auth + (this.hostname.indexOf(':') === -1 ?
        this.hostname :
        '[' + this.hostname + ']');
    if (this.port) {
      host += ':' + this.port;
    }
  }

  if (this.query &&
      util.isObject(this.query) &&
      Object.keys(this.query).length) {
    query = querystring.stringify(this.query);
  }

  var search = this.search || (query && ('?' + query)) || '';

  if (protocol && protocol.substr(-1) !== ':') protocol += ':';

  // only the slashedProtocols get the //.  Not mailto:, xmpp:, etc.
  // unless they had them to begin with.
  if (this.slashes ||
      (!protocol || slashedProtocol[protocol]) && host !== false) {
    host = '//' + (host || '');
    if (pathname && pathname.charAt(0) !== '/') pathname = '/' + pathname;
  } else if (!host) {
    host = '';
  }

  if (hash && hash.charAt(0) !== '#') hash = '#' + hash;
  if (search && search.charAt(0) !== '?') search = '?' + search;

  pathname = pathname.replace(/[?#]/g, function(match) {
    return encodeURIComponent(match);
  });
  search = search.replace('#', '%23');

  return protocol + host + pathname + search + hash;
};

function urlResolve(source, relative) {
  return urlParse(source, false, true).resolve(relative);
}

Url.prototype.resolve = function(relative) {
  return this.resolveObject(urlParse(relative, false, true)).format();
};

function urlResolveObject(source, relative) {
  if (!source) return relative;
  return urlParse(source, false, true).resolveObject(relative);
}

Url.prototype.resolveObject = function(relative) {
  if (util.isString(relative)) {
    var rel = new Url();
    rel.parse(relative, false, true);
    relative = rel;
  }

  var result = new Url();
  var tkeys = Object.keys(this);
  for (var tk = 0; tk < tkeys.length; tk++) {
    var tkey = tkeys[tk];
    result[tkey] = this[tkey];
  }

  // hash is always overridden, no matter what.
  // even href="" will remove it.
  result.hash = relative.hash;

  // if the relative url is empty, then there's nothing left to do here.
  if (relative.href === '') {
    result.href = result.format();
    return result;
  }

  // hrefs like //foo/bar always cut to the protocol.
  if (relative.slashes && !relative.protocol) {
    // take everything except the protocol from relative
    var rkeys = Object.keys(relative);
    for (var rk = 0; rk < rkeys.length; rk++) {
      var rkey = rkeys[rk];
      if (rkey !== 'protocol')
        result[rkey] = relative[rkey];
    }

    //urlParse appends trailing / to urls like http://www.example.com
    if (slashedProtocol[result.protocol] &&
        result.hostname && !result.pathname) {
      result.path = result.pathname = '/';
    }

    result.href = result.format();
    return result;
  }

  if (relative.protocol && relative.protocol !== result.protocol) {
    // if it's a known url protocol, then changing
    // the protocol does weird things
    // first, if it's not file:, then we MUST have a host,
    // and if there was a path
    // to begin with, then we MUST have a path.
    // if it is file:, then the host is dropped,
    // because that's known to be hostless.
    // anything else is assumed to be absolute.
    if (!slashedProtocol[relative.protocol]) {
      var keys = Object.keys(relative);
      for (var v = 0; v < keys.length; v++) {
        var k = keys[v];
        result[k] = relative[k];
      }
      result.href = result.format();
      return result;
    }

    result.protocol = relative.protocol;
    if (!relative.host && !hostlessProtocol[relative.protocol]) {
      var relPath = (relative.pathname || '').split('/');
      while (relPath.length && !(relative.host = relPath.shift()));
      if (!relative.host) relative.host = '';
      if (!relative.hostname) relative.hostname = '';
      if (relPath[0] !== '') relPath.unshift('');
      if (relPath.length < 2) relPath.unshift('');
      result.pathname = relPath.join('/');
    } else {
      result.pathname = relative.pathname;
    }
    result.search = relative.search;
    result.query = relative.query;
    result.host = relative.host || '';
    result.auth = relative.auth;
    result.hostname = relative.hostname || relative.host;
    result.port = relative.port;
    // to support http.request
    if (result.pathname || result.search) {
      var p = result.pathname || '';
      var s = result.search || '';
      result.path = p + s;
    }
    result.slashes = result.slashes || relative.slashes;
    result.href = result.format();
    return result;
  }

  var isSourceAbs = (result.pathname && result.pathname.charAt(0) === '/'),
      isRelAbs = (
          relative.host ||
          relative.pathname && relative.pathname.charAt(0) === '/'
      ),
      mustEndAbs = (isRelAbs || isSourceAbs ||
                    (result.host && relative.pathname)),
      removeAllDots = mustEndAbs,
      srcPath = result.pathname && result.pathname.split('/') || [],
      relPath = relative.pathname && relative.pathname.split('/') || [],
      psychotic = result.protocol && !slashedProtocol[result.protocol];

  // if the url is a non-slashed url, then relative
  // links like ../.. should be able
  // to crawl up to the hostname, as well.  This is strange.
  // result.protocol has already been set by now.
  // Later on, put the first path part into the host field.
  if (psychotic) {
    result.hostname = '';
    result.port = null;
    if (result.host) {
      if (srcPath[0] === '') srcPath[0] = result.host;
      else srcPath.unshift(result.host);
    }
    result.host = '';
    if (relative.protocol) {
      relative.hostname = null;
      relative.port = null;
      if (relative.host) {
        if (relPath[0] === '') relPath[0] = relative.host;
        else relPath.unshift(relative.host);
      }
      relative.host = null;
    }
    mustEndAbs = mustEndAbs && (relPath[0] === '' || srcPath[0] === '');
  }

  if (isRelAbs) {
    // it's absolute.
    result.host = (relative.host || relative.host === '') ?
                  relative.host : result.host;
    result.hostname = (relative.hostname || relative.hostname === '') ?
                      relative.hostname : result.hostname;
    result.search = relative.search;
    result.query = relative.query;
    srcPath = relPath;
    // fall through to the dot-handling below.
  } else if (relPath.length) {
    // it's relative
    // throw away the existing file, and take the new path instead.
    if (!srcPath) srcPath = [];
    srcPath.pop();
    srcPath = srcPath.concat(relPath);
    result.search = relative.search;
    result.query = relative.query;
  } else if (!util.isNullOrUndefined(relative.search)) {
    // just pull out the search.
    // like href='?foo'.
    // Put this after the other two cases because it simplifies the booleans
    if (psychotic) {
      result.hostname = result.host = srcPath.shift();
      //occationaly the auth can get stuck only in host
      //this especially happens in cases like
      //url.resolveObject('mailto:local1@domain1', 'local2@domain2')
      var authInHost = result.host && result.host.indexOf('@') > 0 ?
                       result.host.split('@') : false;
      if (authInHost) {
        result.auth = authInHost.shift();
        result.host = result.hostname = authInHost.shift();
      }
    }
    result.search = relative.search;
    result.query = relative.query;
    //to support http.request
    if (!util.isNull(result.pathname) || !util.isNull(result.search)) {
      result.path = (result.pathname ? result.pathname : '') +
                    (result.search ? result.search : '');
    }
    result.href = result.format();
    return result;
  }

  if (!srcPath.length) {
    // no path at all.  easy.
    // we've already handled the other stuff above.
    result.pathname = null;
    //to support http.request
    if (result.search) {
      result.path = '/' + result.search;
    } else {
      result.path = null;
    }
    result.href = result.format();
    return result;
  }

  // if a url ENDs in . or .., then it must get a trailing slash.
  // however, if it ends in anything else non-slashy,
  // then it must NOT get a trailing slash.
  var last = srcPath.slice(-1)[0];
  var hasTrailingSlash = (
      (result.host || relative.host || srcPath.length > 1) &&
      (last === '.' || last === '..') || last === '');

  // strip single dots, resolve double dots to parent dir
  // if the path tries to go above the root, `up` ends up > 0
  var up = 0;
  for (var i = srcPath.length; i >= 0; i--) {
    last = srcPath[i];
    if (last === '.') {
      srcPath.splice(i, 1);
    } else if (last === '..') {
      srcPath.splice(i, 1);
      up++;
    } else if (up) {
      srcPath.splice(i, 1);
      up--;
    }
  }

  // if the path is allowed to go above the root, restore leading ..s
  if (!mustEndAbs && !removeAllDots) {
    for (; up--; up) {
      srcPath.unshift('..');
    }
  }

  if (mustEndAbs && srcPath[0] !== '' &&
      (!srcPath[0] || srcPath[0].charAt(0) !== '/')) {
    srcPath.unshift('');
  }

  if (hasTrailingSlash && (srcPath.join('/').substr(-1) !== '/')) {
    srcPath.push('');
  }

  var isAbsolute = srcPath[0] === '' ||
      (srcPath[0] && srcPath[0].charAt(0) === '/');

  // put the host back
  if (psychotic) {
    result.hostname = result.host = isAbsolute ? '' :
                                    srcPath.length ? srcPath.shift() : '';
    //occationaly the auth can get stuck only in host
    //this especially happens in cases like
    //url.resolveObject('mailto:local1@domain1', 'local2@domain2')
    var authInHost = result.host && result.host.indexOf('@') > 0 ?
                     result.host.split('@') : false;
    if (authInHost) {
      result.auth = authInHost.shift();
      result.host = result.hostname = authInHost.shift();
    }
  }

  mustEndAbs = mustEndAbs || (result.host && srcPath.length);

  if (mustEndAbs && !isAbsolute) {
    srcPath.unshift('');
  }

  if (!srcPath.length) {
    result.pathname = null;
    result.path = null;
  } else {
    result.pathname = srcPath.join('/');
  }

  //to support request.http
  if (!util.isNull(result.pathname) || !util.isNull(result.search)) {
    result.path = (result.pathname ? result.pathname : '') +
                  (result.search ? result.search : '');
  }
  result.auth = relative.auth || result.auth;
  result.slashes = result.slashes || relative.slashes;
  result.href = result.format();
  return result;
};

Url.prototype.parseHost = function() {
  var host = this.host;
  var port = portPattern.exec(host);
  if (port) {
    port = port[0];
    if (port !== ':') {
      this.port = port.substr(1);
    }
    host = host.substr(0, host.length - port.length);
  }
  if (host) this.hostname = host;
};

},{"./util":92,"punycode":67,"querystring":70}],92:[function(require,module,exports){
'use strict';

module.exports = {
  isString: function(arg) {
    return typeof(arg) === 'string';
  },
  isObject: function(arg) {
    return typeof(arg) === 'object' && arg !== null;
  },
  isNull: function(arg) {
    return arg === null;
  },
  isNullOrUndefined: function(arg) {
    return arg == null;
  }
};

},{}],93:[function(require,module,exports){
module.exports = function isBuffer(arg) {
  return arg && typeof arg === 'object'
    && typeof arg.copy === 'function'
    && typeof arg.fill === 'function'
    && typeof arg.readUInt8 === 'function';
}
},{}],94:[function(require,module,exports){
(function (process,global){
// Copyright Joyent, Inc. and other Node contributors.
//
// Permission is hereby granted, free of charge, to any person obtaining a
// copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to permit
// persons to whom the Software is furnished to do so, subject to the
// following conditions:
//
// The above copyright notice and this permission notice shall be included
// in all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN
// NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
// DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR
// OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE
// USE OR OTHER DEALINGS IN THE SOFTWARE.

var formatRegExp = /%[sdj%]/g;
exports.format = function(f) {
  if (!isString(f)) {
    var objects = [];
    for (var i = 0; i < arguments.length; i++) {
      objects.push(inspect(arguments[i]));
    }
    return objects.join(' ');
  }

  var i = 1;
  var args = arguments;
  var len = args.length;
  var str = String(f).replace(formatRegExp, function(x) {
    if (x === '%%') return '%';
    if (i >= len) return x;
    switch (x) {
      case '%s': return String(args[i++]);
      case '%d': return Number(args[i++]);
      case '%j':
        try {
          return JSON.stringify(args[i++]);
        } catch (_) {
          return '[Circular]';
        }
      default:
        return x;
    }
  });
  for (var x = args[i]; i < len; x = args[++i]) {
    if (isNull(x) || !isObject(x)) {
      str += ' ' + x;
    } else {
      str += ' ' + inspect(x);
    }
  }
  return str;
};


// Mark that a method should not be used.
// Returns a modified function which warns once by default.
// If --no-deprecation is set, then it is a no-op.
exports.deprecate = function(fn, msg) {
  // Allow for deprecating things in the process of starting up.
  if (isUndefined(global.process)) {
    return function() {
      return exports.deprecate(fn, msg).apply(this, arguments);
    };
  }

  if (process.noDeprecation === true) {
    return fn;
  }

  var warned = false;
  function deprecated() {
    if (!warned) {
      if (process.throwDeprecation) {
        throw new Error(msg);
      } else if (process.traceDeprecation) {
        console.trace(msg);
      } else {
        console.error(msg);
      }
      warned = true;
    }
    return fn.apply(this, arguments);
  }

  return deprecated;
};


var debugs = {};
var debugEnviron;
exports.debuglog = function(set) {
  if (isUndefined(debugEnviron))
    debugEnviron = process.env.NODE_DEBUG || '';
  set = set.toUpperCase();
  if (!debugs[set]) {
    if (new RegExp('\\b' + set + '\\b', 'i').test(debugEnviron)) {
      var pid = process.pid;
      debugs[set] = function() {
        var msg = exports.format.apply(exports, arguments);
        console.error('%s %d: %s', set, pid, msg);
      };
    } else {
      debugs[set] = function() {};
    }
  }
  return debugs[set];
};


/**
 * Echos the value of a value. Trys to print the value out
 * in the best way possible given the different types.
 *
 * @param {Object} obj The object to print out.
 * @param {Object} opts Optional options object that alters the output.
 */
/* legacy: obj, showHidden, depth, colors*/
function inspect(obj, opts) {
  // default options
  var ctx = {
    seen: [],
    stylize: stylizeNoColor
  };
  // legacy...
  if (arguments.length >= 3) ctx.depth = arguments[2];
  if (arguments.length >= 4) ctx.colors = arguments[3];
  if (isBoolean(opts)) {
    // legacy...
    ctx.showHidden = opts;
  } else if (opts) {
    // got an "options" object
    exports._extend(ctx, opts);
  }
  // set default options
  if (isUndefined(ctx.showHidden)) ctx.showHidden = false;
  if (isUndefined(ctx.depth)) ctx.depth = 2;
  if (isUndefined(ctx.colors)) ctx.colors = false;
  if (isUndefined(ctx.customInspect)) ctx.customInspect = true;
  if (ctx.colors) ctx.stylize = stylizeWithColor;
  return formatValue(ctx, obj, ctx.depth);
}
exports.inspect = inspect;


// http://en.wikipedia.org/wiki/ANSI_escape_code#graphics
inspect.colors = {
  'bold' : [1, 22],
  'italic' : [3, 23],
  'underline' : [4, 24],
  'inverse' : [7, 27],
  'white' : [37, 39],
  'grey' : [90, 39],
  'black' : [30, 39],
  'blue' : [34, 39],
  'cyan' : [36, 39],
  'green' : [32, 39],
  'magenta' : [35, 39],
  'red' : [31, 39],
  'yellow' : [33, 39]
};

// Don't use 'blue' not visible on cmd.exe
inspect.styles = {
  'special': 'cyan',
  'number': 'yellow',
  'boolean': 'yellow',
  'undefined': 'grey',
  'null': 'bold',
  'string': 'green',
  'date': 'magenta',
  // "name": intentionally not styling
  'regexp': 'red'
};


function stylizeWithColor(str, styleType) {
  var style = inspect.styles[styleType];

  if (style) {
    return '\u001b[' + inspect.colors[style][0] + 'm' + str +
           '\u001b[' + inspect.colors[style][1] + 'm';
  } else {
    return str;
  }
}


function stylizeNoColor(str, styleType) {
  return str;
}


function arrayToHash(array) {
  var hash = {};

  array.forEach(function(val, idx) {
    hash[val] = true;
  });

  return hash;
}


function formatValue(ctx, value, recurseTimes) {
  // Provide a hook for user-specified inspect functions.
  // Check that value is an object with an inspect function on it
  if (ctx.customInspect &&
      value &&
      isFunction(value.inspect) &&
      // Filter out the util module, it's inspect function is special
      value.inspect !== exports.inspect &&
      // Also filter out any prototype objects using the circular check.
      !(value.constructor && value.constructor.prototype === value)) {
    var ret = value.inspect(recurseTimes, ctx);
    if (!isString(ret)) {
      ret = formatValue(ctx, ret, recurseTimes);
    }
    return ret;
  }

  // Primitive types cannot have properties
  var primitive = formatPrimitive(ctx, value);
  if (primitive) {
    return primitive;
  }

  // Look up the keys of the object.
  var keys = Object.keys(value);
  var visibleKeys = arrayToHash(keys);

  if (ctx.showHidden) {
    keys = Object.getOwnPropertyNames(value);
  }

  // IE doesn't make error fields non-enumerable
  // http://msdn.microsoft.com/en-us/library/ie/dww52sbt(v=vs.94).aspx
  if (isError(value)
      && (keys.indexOf('message') >= 0 || keys.indexOf('description') >= 0)) {
    return formatError(value);
  }

  // Some type of object without properties can be shortcutted.
  if (keys.length === 0) {
    if (isFunction(value)) {
      var name = value.name ? ': ' + value.name : '';
      return ctx.stylize('[Function' + name + ']', 'special');
    }
    if (isRegExp(value)) {
      return ctx.stylize(RegExp.prototype.toString.call(value), 'regexp');
    }
    if (isDate(value)) {
      return ctx.stylize(Date.prototype.toString.call(value), 'date');
    }
    if (isError(value)) {
      return formatError(value);
    }
  }

  var base = '', array = false, braces = ['{', '}'];

  // Make Array say that they are Array
  if (isArray(value)) {
    array = true;
    braces = ['[', ']'];
  }

  // Make functions say that they are functions
  if (isFunction(value)) {
    var n = value.name ? ': ' + value.name : '';
    base = ' [Function' + n + ']';
  }

  // Make RegExps say that they are RegExps
  if (isRegExp(value)) {
    base = ' ' + RegExp.prototype.toString.call(value);
  }

  // Make dates with properties first say the date
  if (isDate(value)) {
    base = ' ' + Date.prototype.toUTCString.call(value);
  }

  // Make error with message first say the error
  if (isError(value)) {
    base = ' ' + formatError(value);
  }

  if (keys.length === 0 && (!array || value.length == 0)) {
    return braces[0] + base + braces[1];
  }

  if (recurseTimes < 0) {
    if (isRegExp(value)) {
      return ctx.stylize(RegExp.prototype.toString.call(value), 'regexp');
    } else {
      return ctx.stylize('[Object]', 'special');
    }
  }

  ctx.seen.push(value);

  var output;
  if (array) {
    output = formatArray(ctx, value, recurseTimes, visibleKeys, keys);
  } else {
    output = keys.map(function(key) {
      return formatProperty(ctx, value, recurseTimes, visibleKeys, key, array);
    });
  }

  ctx.seen.pop();

  return reduceToSingleString(output, base, braces);
}


function formatPrimitive(ctx, value) {
  if (isUndefined(value))
    return ctx.stylize('undefined', 'undefined');
  if (isString(value)) {
    var simple = '\'' + JSON.stringify(value).replace(/^"|"$/g, '')
                                             .replace(/'/g, "\\'")
                                             .replace(/\\"/g, '"') + '\'';
    return ctx.stylize(simple, 'string');
  }
  if (isNumber(value))
    return ctx.stylize('' + value, 'number');
  if (isBoolean(value))
    return ctx.stylize('' + value, 'boolean');
  // For some reason typeof null is "object", so special case here.
  if (isNull(value))
    return ctx.stylize('null', 'null');
}


function formatError(value) {
  return '[' + Error.prototype.toString.call(value) + ']';
}


function formatArray(ctx, value, recurseTimes, visibleKeys, keys) {
  var output = [];
  for (var i = 0, l = value.length; i < l; ++i) {
    if (hasOwnProperty(value, String(i))) {
      output.push(formatProperty(ctx, value, recurseTimes, visibleKeys,
          String(i), true));
    } else {
      output.push('');
    }
  }
  keys.forEach(function(key) {
    if (!key.match(/^\d+$/)) {
      output.push(formatProperty(ctx, value, recurseTimes, visibleKeys,
          key, true));
    }
  });
  return output;
}


function formatProperty(ctx, value, recurseTimes, visibleKeys, key, array) {
  var name, str, desc;
  desc = Object.getOwnPropertyDescriptor(value, key) || { value: value[key] };
  if (desc.get) {
    if (desc.set) {
      str = ctx.stylize('[Getter/Setter]', 'special');
    } else {
      str = ctx.stylize('[Getter]', 'special');
    }
  } else {
    if (desc.set) {
      str = ctx.stylize('[Setter]', 'special');
    }
  }
  if (!hasOwnProperty(visibleKeys, key)) {
    name = '[' + key + ']';
  }
  if (!str) {
    if (ctx.seen.indexOf(desc.value) < 0) {
      if (isNull(recurseTimes)) {
        str = formatValue(ctx, desc.value, null);
      } else {
        str = formatValue(ctx, desc.value, recurseTimes - 1);
      }
      if (str.indexOf('\n') > -1) {
        if (array) {
          str = str.split('\n').map(function(line) {
            return '  ' + line;
          }).join('\n').substr(2);
        } else {
          str = '\n' + str.split('\n').map(function(line) {
            return '   ' + line;
          }).join('\n');
        }
      }
    } else {
      str = ctx.stylize('[Circular]', 'special');
    }
  }
  if (isUndefined(name)) {
    if (array && key.match(/^\d+$/)) {
      return str;
    }
    name = JSON.stringify('' + key);
    if (name.match(/^"([a-zA-Z_][a-zA-Z_0-9]*)"$/)) {
      name = name.substr(1, name.length - 2);
      name = ctx.stylize(name, 'name');
    } else {
      name = name.replace(/'/g, "\\'")
                 .replace(/\\"/g, '"')
                 .replace(/(^"|"$)/g, "'");
      name = ctx.stylize(name, 'string');
    }
  }

  return name + ': ' + str;
}


function reduceToSingleString(output, base, braces) {
  var numLinesEst = 0;
  var length = output.reduce(function(prev, cur) {
    numLinesEst++;
    if (cur.indexOf('\n') >= 0) numLinesEst++;
    return prev + cur.replace(/\u001b\[\d\d?m/g, '').length + 1;
  }, 0);

  if (length > 60) {
    return braces[0] +
           (base === '' ? '' : base + '\n ') +
           ' ' +
           output.join(',\n  ') +
           ' ' +
           braces[1];
  }

  return braces[0] + base + ' ' + output.join(', ') + ' ' + braces[1];
}


// NOTE: These type checking functions intentionally don't use `instanceof`
// because it is fragile and can be easily faked with `Object.create()`.
function isArray(ar) {
  return Array.isArray(ar);
}
exports.isArray = isArray;

function isBoolean(arg) {
  return typeof arg === 'boolean';
}
exports.isBoolean = isBoolean;

function isNull(arg) {
  return arg === null;
}
exports.isNull = isNull;

function isNullOrUndefined(arg) {
  return arg == null;
}
exports.isNullOrUndefined = isNullOrUndefined;

function isNumber(arg) {
  return typeof arg === 'number';
}
exports.isNumber = isNumber;

function isString(arg) {
  return typeof arg === 'string';
}
exports.isString = isString;

function isSymbol(arg) {
  return typeof arg === 'symbol';
}
exports.isSymbol = isSymbol;

function isUndefined(arg) {
  return arg === void 0;
}
exports.isUndefined = isUndefined;

function isRegExp(re) {
  return isObject(re) && objectToString(re) === '[object RegExp]';
}
exports.isRegExp = isRegExp;

function isObject(arg) {
  return typeof arg === 'object' && arg !== null;
}
exports.isObject = isObject;

function isDate(d) {
  return isObject(d) && objectToString(d) === '[object Date]';
}
exports.isDate = isDate;

function isError(e) {
  return isObject(e) &&
      (objectToString(e) === '[object Error]' || e instanceof Error);
}
exports.isError = isError;

function isFunction(arg) {
  return typeof arg === 'function';
}
exports.isFunction = isFunction;

function isPrimitive(arg) {
  return arg === null ||
         typeof arg === 'boolean' ||
         typeof arg === 'number' ||
         typeof arg === 'string' ||
         typeof arg === 'symbol' ||  // ES6 symbol
         typeof arg === 'undefined';
}
exports.isPrimitive = isPrimitive;

exports.isBuffer = require('./support/isBuffer');

function objectToString(o) {
  return Object.prototype.toString.call(o);
}


function pad(n) {
  return n < 10 ? '0' + n.toString(10) : n.toString(10);
}


var months = ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep',
              'Oct', 'Nov', 'Dec'];

// 26 Feb 16:19:34
function timestamp() {
  var d = new Date();
  var time = [pad(d.getHours()),
              pad(d.getMinutes()),
              pad(d.getSeconds())].join(':');
  return [d.getDate(), months[d.getMonth()], time].join(' ');
}


// log is just a thin wrapper to console.log that prepends a timestamp
exports.log = function() {
  console.log('%s - %s', timestamp(), exports.format.apply(exports, arguments));
};


/**
 * Inherit the prototype methods from one constructor into another.
 *
 * The Function.prototype.inherits from lang.js rewritten as a standalone
 * function (not on Function.prototype). NOTE: If this file is to be loaded
 * during bootstrapping this function needs to be rewritten using some native
 * functions as prototype setup using normal JavaScript does not work as
 * expected during bootstrapping (see mirror.js in r114903).
 *
 * @param {function} ctor Constructor function which needs to inherit the
 *     prototype.
 * @param {function} superCtor Constructor function to inherit prototype from.
 */
exports.inherits = require('inherits');

exports._extend = function(origin, add) {
  // Don't do anything if add isn't an object
  if (!add || !isObject(add)) return origin;

  var keys = Object.keys(add);
  var i = keys.length;
  while (i--) {
    origin[keys[i]] = add[keys[i]];
  }
  return origin;
};

function hasOwnProperty(obj, prop) {
  return Object.prototype.hasOwnProperty.call(obj, prop);
}

}).call(this,require('_process'),typeof global !== "undefined" ? global : typeof self !== "undefined" ? self : typeof window !== "undefined" ? window : {})

},{"./support/isBuffer":93,"_process":66,"inherits":63}],95:[function(require,module,exports){
module.exports = extend

var hasOwnProperty = Object.prototype.hasOwnProperty;

function extend() {
    var target = {}

    for (var i = 0; i < arguments.length; i++) {
        var source = arguments[i]

        for (var key in source) {
            if (hasOwnProperty.call(source, key)) {
                target[key] = source[key]
            }
        }
    }

    return target
}

},{}]},{},[4])(4)
});
//# sourceMappingURL=ref-parser.js.map
